oui={
    "002272": {
        "oui_hex": "00-22-72",
        "organization": "American Micro-Fuel Device Corp.",
        "address_1": "2181 Buchanan Loop",
        "address_2": "Ferndale  WA  98248",
        "country": "US"
    },
    "00D0EF": {
        "oui_hex": "00-D0-EF",
        "organization": "IGT",
        "address_1": "9295 PROTOTYPE DRIVE",
        "address_2": "RENO  NV  89511",
        "country": "US"
    },
    "086195": {
        "oui_hex": "08-61-95",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "F4BD9E": {
        "oui_hex": "F4-BD-9E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5885E9": {
        "oui_hex": "58-85-E9",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "BC2392": {
        "oui_hex": "BC-23-92",
        "organization": "BYD Precision Manufacture Company Ltd.",
        "address_1": "No.3001, Bao He Road, Baolong Industrial, Longgang Street,Longgang Zone, Shenzhen",
        "address_2": "shenzhen    518116",
        "country": "CN"
    },
    "405582": {
        "oui_hex": "40-55-82",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "A4E31B": {
        "oui_hex": "A4-E3-1B",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "D89790": {
        "oui_hex": "D8-97-90",
        "organization": "Commonwealth Scientific and Industrial Research Organisation",
        "address_1": "GPO Box 1700",
        "address_2": "Canberra  ACT  2601",
        "country": "AU"
    },
    "883A30": {
        "oui_hex": "88-3A-30",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B8A58D": {
        "oui_hex": "B8-A5-8D",
        "organization": "Axe Group Holdings Limited",
        "address_1": "Road Town",
        "address_2": "tortola    VG1110",
        "country": "VG"
    },
    "50CEE3": {
        "oui_hex": "50-CE-E3",
        "organization": "Gigafirm.co.LTD",
        "address_1": "3-21-8,kisonishi",
        "address_2": "machida-city  tokyo  1940037",
        "country": "JP"
    },
    "98E743": {
        "oui_hex": "98-E7-43",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "C419D1": {
        "oui_hex": "C4-19-D1",
        "organization": "Telink Semiconductor (Shanghai) Co., Ltd.",
        "address_1": "No. 1500 Zuchongzhi Rd, Building #3",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "887E25": {
        "oui_hex": "88-7E-25",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "086083": {
        "oui_hex": "08-60-83",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E01954": {
        "oui_hex": "E0-19-54",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "10327E": {
        "oui_hex": "10-32-7E",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F8084F": {
        "oui_hex": "F8-08-4F",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "30FBB8": {
        "oui_hex": "30-FB-B8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F497C2": {
        "oui_hex": "F4-97-C2",
        "organization": "Nebulon Inc",
        "address_1": "3089 Skyway Court",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "A44519": {
        "oui_hex": "A4-45-19",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "68DBF5": {
        "oui_hex": "68-DB-F5",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "2446C8": {
        "oui_hex": "24-46-C8",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "1802AE": {
        "oui_hex": "18-02-AE",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "0C20D3": {
        "oui_hex": "0C-20-D3",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "44D791": {
        "oui_hex": "44-D7-91",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8446FE": {
        "oui_hex": "84-46-FE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D82918": {
        "oui_hex": "D8-29-18",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D0D003": {
        "oui_hex": "D0-D0-03",
        "organization": "Samsung Electronics Co.,LTD",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "64B21D": {
        "oui_hex": "64-B2-1D",
        "organization": "Chengdu Phycom Tech Co., Ltd.",
        "address_1": "No.216 beisen road",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "C42996": {
        "oui_hex": "C4-29-96",
        "organization": "Signify B.V.",
        "address_1": "High Tech Campus 7",
        "address_2": "Eindhoven    5656AE",
        "country": "NL"
    },
    "980637": {
        "oui_hex": "98-06-37",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8CB84A": {
        "oui_hex": "8C-B8-4A",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "98E8FA": {
        "oui_hex": "98-E8-FA",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "38C4E8": {
        "oui_hex": "38-C4-E8",
        "organization": "NSS Sp. z o.o.",
        "address_1": "Modularna 11",
        "address_2": "Warszawa    02-238",
        "country": "PL"
    },
    "34DD7E": {
        "oui_hex": "34-DD-7E",
        "organization": "Umeox Innovations Co.,Ltd",
        "address_1": "Room 1208-09, Research Building, Tsinghua Information Port, No. 1, Xindong Road, Nanshan District, Shenzhen",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "CCCD64": {
        "oui_hex": "CC-CD-64",
        "organization": "SM-Electronic GmbH",
        "address_1": "Waldweg 2",
        "address_2": "Stapelfeld / Braak    22145",
        "country": "DE"
    },
    "24DFA7": {
        "oui_hex": "24-DF-A7",
        "organization": "Hangzhou BroadLink Technology Co.,Ltd",
        "address_1": "Room 101,1/F,Unit C,Building 1,No.57 Jiang'er Road,Changhe Street,Binjiang District,Hangzhou,Zhejiang,P.R.China",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "B065F1": {
        "oui_hex": "B0-65-F1",
        "organization": "WIO Manufacturing HK Limited",
        "address_1": "15/F OTB Building, 160 Glocester Road",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "901234": {
        "oui_hex": "90-12-34",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "542A1B": {
        "oui_hex": "54-2A-1B",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "5C925E": {
        "oui_hex": "5C-92-5E",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "A1&A2 Building,Lantian Technology Park, Xinyu Road, Xingqiao Henggang Block, Shajing Street, Baoan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "084FA9": {
        "oui_hex": "08-4F-A9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "084FF9": {
        "oui_hex": "08-4F-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5098B8": {
        "oui_hex": "50-98-B8",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "1100AA": {
        "oui_hex": "11-00-AA",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "B84DEE": {
        "oui_hex": "B8-4D-EE",
        "organization": "Hisense broadband multimedia technology Co.,Ltd",
        "address_1": "Song ling Road 399",
        "address_2": "Qingdao    266000",
        "country": "CN"
    },
    "A89352": {
        "oui_hex": "A8-93-52",
        "organization": "SHANGHAI ZHONGMI COMMUNICATION TECHNOLOGY CO.,LTD",
        "address_1": "RM510,418 Guiping Road,xuhui-Park",
        "address_2": "shanghai  shanghai  200233",
        "country": "CN"
    },
    "E4CC9D": {
        "oui_hex": "E4-CC-9D",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "A8D0E3": {
        "oui_hex": "A8-D0-E3",
        "organization": "Systech Electronics Ltd",
        "address_1": "Lever Tech Centre, 69-71 King Yip Street,",
        "address_2": ",    852",
        "country": "HK"
    },
    "98BA39": {
        "oui_hex": "98-BA-39",
        "organization": "Doro AB",
        "address_1": "Jörgen Kocksgatan 1B",
        "address_2": "Malmö  Skane  211 20",
        "country": "SE"
    },
    "D46BA6": {
        "oui_hex": "D4-6B-A6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CC0577": {
        "oui_hex": "CC-05-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "308BB2": {
        "oui_hex": "30-8B-B2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0EB62": {
        "oui_hex": "E0-EB-62",
        "organization": "Shanghai Hulu Devices Co., Ltd",
        "address_1": "509 Caobao Road,  Rm 101-2 Bld 9",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "08688D": {
        "oui_hex": "08-68-8D",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "E86F38": {
        "oui_hex": "E8-6F-38",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "48216C": {
        "oui_hex": "48-21-6C",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "Building D3,No.8 Yangliu North Road,Yubei District",
        "address_2": "CHONGQING  CHONGQING  401121",
        "country": "CN"
    },
    "8CBE24": {
        "oui_hex": "8C-BE-24",
        "organization": "Tashang Semiconductor(Shanghai) Co., Ltd.",
        "address_1": "Room 903, Building 5, Minggu Science Park,No. 7001, Zhong Chun Road, Minhang District ,Shanghai 201101, P.R. China",
        "address_2": "Shanghai    123456",
        "country": "CN"
    },
    "08B3AF": {
        "oui_hex": "08-B3-AF",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "30862D": {
        "oui_hex": "30-86-2D",
        "organization": "Arista Network, Inc.",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "6CE8C6": {
        "oui_hex": "6C-E8-C6",
        "organization": "Earda Technologies co Ltd",
        "address_1": "Block A,Lianfeng Creative Park, #2 Jisheng Rd., Nansha District",
        "address_2": "Guangzhou  Guangdong  511455",
        "country": "CN"
    },
    "1C4176": {
        "oui_hex": "1C-41-76",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "608B0E": {
        "oui_hex": "60-8B-0E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1871D5": {
        "oui_hex": "18-71-D5",
        "organization": "Hazens Automotive Electronics(SZ)Co.,Ltd.",
        "address_1": "C8 Building, Building 13, Zhongxin Innovation Industry City, No.12, Ganli No.6 Road, Ganli Industrial Park, Buji Street, Longgang District",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "ACB1EE": {
        "oui_hex": "AC-B1-EE",
        "organization": "SHENZHEN FENDA TECHNOLOGY CO., LTD",
        "address_1": "Fenda Hi-Tech Park, Zhoushi Road, Shiyan, Baoan",
        "address_2": "ShenZhen  GuangDong  518108",
        "country": "CN"
    },
    "F8ADCB": {
        "oui_hex": "F8-AD-CB",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "D462EA": {
        "oui_hex": "D4-62-EA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "54BAD6": {
        "oui_hex": "54-BA-D6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94DC4E": {
        "oui_hex": "94-DC-4E",
        "organization": "AEV, spol. s r. o.",
        "address_1": "Jozky Silneho 2783/9",
        "address_2": "Kromeriz    76701",
        "country": "CZ"
    },
    "1442FC": {
        "oui_hex": "14-42-FC",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "AC5D5C": {
        "oui_hex": "AC-5D-5C",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "A4AE11": {
        "oui_hex": "A4-AE-11",
        "organization": "Hon Hai Precision Ind. Co., Ltd.",
        "address_1": "GuangDongShenZhen",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "54DED0": {
        "oui_hex": "54-DE-D0",
        "organization": "Sevio Srl",
        "address_1": "Via Dei Caniana 6/A",
        "address_2": "Bergamo  Bergamo  24127",
        "country": "IT"
    },
    "6C5E3B": {
        "oui_hex": "6C-5E-3B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "401920": {
        "oui_hex": "40-19-20",
        "organization": "Movon Corporation",
        "address_1": "3Fl, Hyunjuk Bldg. 7 selleung-ro, 94gil,  Gangnam-gu",
        "address_2": "Seoul    06161",
        "country": "KR"
    },
    "D03745": {
        "oui_hex": "D0-37-45",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "603A7C": {
        "oui_hex": "60-3A-7C",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "000178": {
        "oui_hex": "00-01-78",
        "organization": "MARGI Systems, Inc.",
        "address_1": "3155 Kearney Street. - Ste.#200",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0CB771": {
        "oui_hex": "0C-B7-71",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "58C876": {
        "oui_hex": "58-C8-76",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "2C1E4F": {
        "oui_hex": "2C-1E-4F",
        "organization": "Chengdu Qianli Network Technology Co., Ltd.",
        "address_1": "Room 1208, 4 Building, Ideal Center, NO.38 Tianyi Street, Chengdu High-tech Zone",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "009052": {
        "oui_hex": "00-90-52",
        "organization": "SELCOM ELETTRONICA S.R.L.",
        "address_1": "VIA GRANDI, 5",
        "address_2": "40013 CASTELMAGGIORE BO",
        "country": "IT"
    },
    "001A83": {
        "oui_hex": "00-1A-83",
        "organization": "Pegasus Technologies Inc.",
        "address_1": "108 Pawnook Farm Rd.",
        "address_2": "Lenoir City  TN  37771",
        "country": "US"
    },
    "24166D": {
        "oui_hex": "24-16-6D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "940B19": {
        "oui_hex": "94-0B-19",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "70C7F2": {
        "oui_hex": "70-C7-F2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "3894ED": {
        "oui_hex": "38-94-ED",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "700433": {
        "oui_hex": "70-04-33",
        "organization": "California Things Inc.",
        "address_1": "650 main st",
        "address_2": "redwood city  CA  94063",
        "country": "US"
    },
    "DCA632": {
        "oui_hex": "DC-A6-32",
        "organization": "Raspberry Pi Trading Ltd",
        "address_1": "Maurice Wilkes Building, Cowley Road",
        "address_2": "Cambridge    CB4 0DS",
        "country": "GB"
    },
    "88F56E": {
        "oui_hex": "88-F5-6E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "BC97E1": {
        "oui_hex": "BC-97-E1",
        "organization": "Broadcom Limited",
        "address_1": "15191 Alton Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "28D1B7": {
        "oui_hex": "28-D1-B7",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "C8C2FA": {
        "oui_hex": "C8-C2-FA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "88B362": {
        "oui_hex": "88-B3-62",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai 201206,P.R.China",
        "address_2": "Shanghai   Pudong  201206",
        "country": "CN"
    },
    "0847D0": {
        "oui_hex": "08-47-D0",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai 201206,P.R.China",
        "address_2": "Shanghai   Pudong  201206",
        "country": "CN"
    },
    "089C86": {
        "oui_hex": "08-9C-86",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai 201206,P.R.China",
        "address_2": "Shanghai   Pudong  201206",
        "country": "CN"
    },
    "7C8956": {
        "oui_hex": "7C-89-56",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C93E4": {
        "oui_hex": "9C-93-E4",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "88299C": {
        "oui_hex": "88-29-9C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC9093": {
        "oui_hex": "CC-90-93",
        "organization": "Hansong Tehnologies",
        "address_1": "8 Kangping road, New development zone",
        "address_2": "Nanjing  Jiangsu  210006",
        "country": "CN"
    },
    "CC64A6": {
        "oui_hex": "CC-64-A6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "30317D": {
        "oui_hex": "30-31-7D",
        "organization": "Hosiden Corporation",
        "address_1": "4-33, Kitakyuhoji 1-chome",
        "address_2": "Yao  Osaka  5810071",
        "country": "JP"
    },
    "F0A968": {
        "oui_hex": "F0-A9-68",
        "organization": "Antailiye Technology Co.,Ltd",
        "address_1": "7/F,Zhengjiyuan Buiding,2 Road,Qianjing, Xixiang, Baoan District,Shenzhen",
        "address_2": "SHEN ZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "48E1E9": {
        "oui_hex": "48-E1-E9",
        "organization": "Chengdu Meross Technology Co., Ltd.",
        "address_1": "No. 25, Yizhou Avenue, Gaoxin",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "D81399": {
        "oui_hex": "D8-13-99",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "54E019": {
        "oui_hex": "54-E0-19",
        "organization": "Ring LLC",
        "address_1": "1523 26th St",
        "address_2": "Santa Monica  CA  90404",
        "country": "US"
    },
    "148430": {
        "oui_hex": "14-84-30",
        "organization": "MITAC COMPUTING TECHNOLOGY CORPORATION",
        "address_1": "3F., NO.1, R&D ROAD 2, HSINCHU SCIENCE PARK",
        "address_2": "HSINCHU    30076",
        "country": "TW"
    },
    "B8A44F": {
        "oui_hex": "B8-A4-4F",
        "organization": "Axis Communications AB",
        "address_1": "Emdalavägen 14",
        "address_2": "LUND    22369",
        "country": "SE"
    },
    "0024EB": {
        "oui_hex": "00-24-EB",
        "organization": "ClearPath Networks, Inc.",
        "address_1": "1940 E. Mariposa Ave",
        "address_2": "El Segundo  CA  90245",
        "country": "US"
    },
    "50AF4D": {
        "oui_hex": "50-AF-4D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C8EAF8": {
        "oui_hex": "C8-EA-F8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "709F2D": {
        "oui_hex": "70-9F-2D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "383B26": {
        "oui_hex": "38-3B-26",
        "organization": "Jiangsu Qinheng Co., Ltd.",
        "address_1": "No. 18, Ningshuang Road",
        "address_2": "Nanjing  Jiangsu  210012",
        "country": "CN"
    },
    "5CFAFB": {
        "oui_hex": "5C-FA-FB",
        "organization": "Acubit",
        "address_1": "Afred Nobels Vej 21A",
        "address_2": "Aalborg Ø    9220",
        "country": "DK"
    },
    "9C7BEF": {
        "oui_hex": "9C-7B-EF",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "742EDB": {
        "oui_hex": "74-2E-DB",
        "organization": "Perinet GmbH",
        "address_1": "Rudower Chaussee 29",
        "address_2": "Berlin  Berlin  12489",
        "country": "DE"
    },
    "201742": {
        "oui_hex": "20-17-42",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "CC8826": {
        "oui_hex": "CC-88-26",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "EC5B73": {
        "oui_hex": "EC-5B-73",
        "organization": "Advanced & Wise Technology Corp.",
        "address_1": "5F, No. 3-2, Industry East 9th Road, Hsinchu Science Park,",
        "address_2": "Hsinchu City  Hsinchu  30075",
        "country": "TW"
    },
    "E0CB1D": {
        "oui_hex": "E0-CB-1D",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "848BCD": {
        "oui_hex": "84-8B-CD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "14C03E": {
        "oui_hex": "14-C0-3E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C089AB": {
        "oui_hex": "C0-89-AB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D44DA4": {
        "oui_hex": "D4-4D-A4",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "F8E5CF": {
        "oui_hex": "F8-E5-CF",
        "organization": "CGI IT UK LIMITED",
        "address_1": "20 Fenchurch Street, 14th Floor",
        "address_2": "London    EC3M 3BY",
        "country": "GB"
    },
    "6882F2": {
        "oui_hex": "68-82-F2",
        "organization": "grandcentrix GmbH",
        "address_1": "Holzmarkt 1",
        "address_2": "Cologne  NW  50676",
        "country": "DE"
    },
    "D420B0": {
        "oui_hex": "D4-20-B0",
        "organization": "Mist Systems, Inc.",
        "address_1": "1601 South De Anza Blvd, Suite 248",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "08EDED": {
        "oui_hex": "08-ED-ED",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "6092F5": {
        "oui_hex": "60-92-F5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0022AF": {
        "oui_hex": "00-22-AF",
        "organization": "Safety Vision, LLC",
        "address_1": "6100 W. Sam Houston Pkwy. North",
        "address_2": "Houston    77041",
        "country": "US"
    },
    "A091A2": {
        "oui_hex": "A0-91-A2",
        "organization": "OnePlus Electronics (Shenzhen) Co., Ltd.",
        "address_1": "Room 201, Block A, No.1, 1st Qian Wan Road, Qianhai Shenzhen-Hong Kong Cooperation Zone, Shenzhen, China.",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0080B5": {
        "oui_hex": "00-80-B5",
        "organization": "UNITED NETWORKS INC.",
        "address_1": "2178 PARAGON DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "1C697A": {
        "oui_hex": "1C-69-7A",
        "organization": "EliteGroup Computer Systems Co., LTD",
        "address_1": "No.239, Sec. 2, TiDing Blvd. Nei-Hu Dist.",
        "address_2": "Taipei  Taiwan  11439",
        "country": "TW"
    },
    "4C1744": {
        "oui_hex": "4C-17-44",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O. Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "B03055": {
        "oui_hex": "B0-30-55",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "905C34": {
        "oui_hex": "90-5C-34",
        "organization": "Sirius Electronic Systems Srl",
        "address_1": "via Robinie, 33",
        "address_2": "Gravellona Toce  VB  28883",
        "country": "IT"
    },
    "D46A35": {
        "oui_hex": "D4-6A-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D09C7A": {
        "oui_hex": "D0-9C-7A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C82C2B": {
        "oui_hex": "C8-2C-2B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8020DA": {
        "oui_hex": "80-20-DA",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "68847E": {
        "oui_hex": "68-84-7E",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "003085": {
        "oui_hex": "00-30-85",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "605F8D": {
        "oui_hex": "60-5F-8D",
        "organization": "eero inc.",
        "address_1": "500 Howard Street, Suite 900",
        "address_2": "SAN FRANCISCO  CA  94105",
        "country": "US"
    },
    "C4B36A": {
        "oui_hex": "C4-B3-6A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "70F754": {
        "oui_hex": "70-F7-54",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "6C8BD3": {
        "oui_hex": "6C-8B-D3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "68974B": {
        "oui_hex": "68-97-4B",
        "organization": "Shenzhen Costar Electronics Co. Ltd.",
        "address_1": "No.94 Fuyuan 1st Road,Yuyuan Industrial Park,",
        "address_2": "Shenzhen   Guangdong  518103",
        "country": "CN"
    },
    "34E1D1": {
        "oui_hex": "34-E1-D1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0021B7": {
        "oui_hex": "00-21-B7",
        "organization": "LEXMARK INTERNATIONAL, INC.",
        "address_1": "740 West New Circle Road",
        "address_2": "Lexington  KY  40550",
        "country": "US"
    },
    "00A0B0": {
        "oui_hex": "00-A0-B0",
        "organization": "I-O DATA DEVICE,INC.",
        "address_1": "24-1, SAKURADA-MACHI",
        "address_2": "KANAZAWA, ISHIKAWA 920    na",
        "country": "JP"
    },
    "2479F3": {
        "oui_hex": "24-79-F3",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "80A235": {
        "oui_hex": "80-A2-35",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "C8C64A": {
        "oui_hex": "C8-C6-4A",
        "organization": "Flextronics Tech.(Ind) Pvt Ltd",
        "address_1": "SURVEYNO.381, PADUR ROAD, KUTHAMBAKKAM VILLAGE, 602107 POONAMALLEE TALUK, THIRUVALLUR DISTRIC",
        "address_2": "Chennai    602107",
        "country": "IN"
    },
    "30EA26": {
        "oui_hex": "30-EA-26",
        "organization": "Sycada BV",
        "address_1": "Burgemeester Stramanweg 105B",
        "address_2": "Amsterdam    1101 AA",
        "country": "NL"
    },
    "9C497F": {
        "oui_hex": "9C-49-7F",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "C4E39F": {
        "oui_hex": "C4-E3-9F",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "F89A78": {
        "oui_hex": "F8-9A-78",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "88F872": {
        "oui_hex": "88-F8-72",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC5623": {
        "oui_hex": "EC-56-23",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5486BC": {
        "oui_hex": "54-86-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "402343": {
        "oui_hex": "40-23-43",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "18F18E": {
        "oui_hex": "18-F1-8E",
        "organization": "ChipER Technology co. ltd",
        "address_1": "907 University Ave#299",
        "address_2": "Middleton  WI  53562",
        "country": "US"
    },
    "000422": {
        "oui_hex": "00-04-22",
        "organization": "Studio Technologies, Inc",
        "address_1": "7440 Frontage Rd",
        "address_2": "Skokie  IL   60077-3212",
        "country": "US"
    },
    "80DA13": {
        "oui_hex": "80-DA-13",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "50EC50": {
        "oui_hex": "50-EC-50",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "6061DF": {
        "oui_hex": "60-61-DF",
        "organization": "Z-meta Research LLC",
        "address_1": "8365 Quay Drive",
        "address_2": "Arvada  CO  80003",
        "country": "US"
    },
    "7057BF": {
        "oui_hex": "70-57-BF",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "8CE748": {
        "oui_hex": "8C-E7-48",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "108286": {
        "oui_hex": "10-82-86",
        "organization": "Luxshare Precision Industry Co.,Ltd",
        "address_1": "2nd floor, A building, Sanyo New Industrial Area, West of Maoyi, Shajing  Baoan District",
        "address_2": "Shenzhen  Shenzhen  518104",
        "country": "CN"
    },
    "14B457": {
        "oui_hex": "14-B4-57",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "DC962C": {
        "oui_hex": "DC-96-2C",
        "organization": "NST Audio Ltd",
        "address_1": "32 Whitewall",
        "address_2": "Norton  North Yorkshire  YO17 9EH",
        "country": "GB"
    },
    "18022D": {
        "oui_hex": "18-02-2D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D8BC59": {
        "oui_hex": "D8-BC-59",
        "organization": "Shenzhen DAPU Microelectronics Co., Ltd",
        "address_1": "Room B 503, No.2 Building, Tian’an Digital New Town, Huangge Middle Road, Longgang District",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "089798": {
        "oui_hex": "08-97-98",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "246F28": {
        "oui_hex": "24-6F-28",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "8C79F5": {
        "oui_hex": "8C-79-F5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "48F8DB": {
        "oui_hex": "48-F8-DB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00122A": {
        "oui_hex": "00-12-2A",
        "organization": "VTech Telecommunications Ltd.",
        "address_1": "23/F, Tai Ping Industrial Centre, Block 1",
        "address_2": " NA    00000",
        "country": "HK"
    },
    "B0518E": {
        "oui_hex": "B0-51-8E",
        "organization": "Holl technology CO.Ltd.",
        "address_1": "F2,Bld 27,Anle Industrial Park,Nantou Guankou No.2 Road",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "2852E0": {
        "oui_hex": "28-52-E0",
        "organization": "Layon international Electronic & Telecom Co.,Ltd",
        "address_1": "4rd Floor, Building 15, Juda Industrial Zone, ShiBei Industrial Road, HuiJiang , Da Shi Street, PanYu District,Guangzhou,China",
        "address_2": "guangzhou  guangdong  511430",
        "country": "CN"
    },
    "58CB52": {
        "oui_hex": "58-CB-52",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "7C6166": {
        "oui_hex": "7C-61-66",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "989BCB": {
        "oui_hex": "98-9B-CB",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "94F7AD": {
        "oui_hex": "94-F7-AD",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "6063F9": {
        "oui_hex": "60-63-F9",
        "organization": "Ciholas, Inc.",
        "address_1": "3700 Bell Rd",
        "address_2": "Newburgh  IN  47630-7907",
        "country": "US"
    },
    "AC8FF8": {
        "oui_hex": "AC-8F-F8",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "6003A6": {
        "oui_hex": "60-03-A6",
        "organization": "Inteno Broadband Technology AB",
        "address_1": "Stensätravägen 13",
        "address_2": "Skärholmen  SE  127 39",
        "country": "SE"
    },
    "7C5259": {
        "oui_hex": "7C-52-59",
        "organization": "Sichuan Jiuzhou Electronic Technology Co., Ltd.",
        "address_1": "No. 259, Jiuzhou Road",
        "address_2": "Mianyang City  Sichuan Province  621000",
        "country": "CN"
    },
    "44B295": {
        "oui_hex": "44-B2-95",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "9424E1": {
        "oui_hex": "94-24-E1",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Rd",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "F8CA59": {
        "oui_hex": "F8-CA-59",
        "organization": "NetComm Wireless",
        "address_1": "LEVEL 5, 18-20 ORION RD. LANE COVE",
        "address_2": "LANE COVE WEST  NSW  2066",
        "country": "AU"
    },
    "88B291": {
        "oui_hex": "88-B2-91",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C42AD0": {
        "oui_hex": "C4-2A-D0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CCD281": {
        "oui_hex": "CC-D2-81",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "200DB0": {
        "oui_hex": "20-0D-B0",
        "organization": "Shenzhen Four Seas Global Link Network Technology Co., Ltd.",
        "address_1": "Room 607-610, Block B, TAOJINDI Electronic Business Incubation Base",
        "address_2": "Tenglong Road, Longhua District,   Shenzhen Guangdong  518000",
        "country": "CN"
    },
    "D81EDD": {
        "oui_hex": "D8-1E-DD",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D43FCB": {
        "oui_hex": "D4-3F-CB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5C7695": {
        "oui_hex": "5C-76-95",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "F84D33": {
        "oui_hex": "F8-4D-33",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "C08ACD": {
        "oui_hex": "C0-8A-CD",
        "organization": "Guangzhou Shiyuan Electronic Technology Company Limited",
        "address_1": "No.6, 4th Yunpu Road, Yunpu industry District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "ACF6F7": {
        "oui_hex": "AC-F6-F7",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "E89E0C": {
        "oui_hex": "E8-9E-0C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "48E6C0": {
        "oui_hex": "48-E6-C0",
        "organization": "SIMCom Wireless Solutions Co.,Ltd.",
        "address_1": "Building B,SIM Technology Building,No.633,Jinzhong Road",
        "address_2": "Shanghai    200335",
        "country": "CN"
    },
    "383C9C": {
        "oui_hex": "38-3C-9C",
        "organization": "Fujian Newland Payment Technology Co.,Ltd.",
        "address_1": "No. B602,Building #1,Haixia Jingmao Plaza,Fuzhou Bonded Area",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "C02E25": {
        "oui_hex": "C0-2E-25",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "107717": {
        "oui_hex": "10-77-17",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "A86D5F": {
        "oui_hex": "A8-6D-5F",
        "organization": "Raisecom Technology CO., LTD",
        "address_1": "No. 11, East Area, No. 10 Block, East Xibeiwang Road",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "58ECED": {
        "oui_hex": "58-EC-ED",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "A468BC": {
        "oui_hex": "A4-68-BC",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "005079": {
        "oui_hex": "00-50-79",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "100C6B": {
        "oui_hex": "10-0C-6B",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "505FB5": {
        "oui_hex": "50-5F-B5",
        "organization": "Askey Computer Corp.",
        "address_1": "10F, NO. 119, JIANKANG RD., ZHONGHE DIST.",
        "address_2": "NEW TAIPEI     235",
        "country": "TW"
    },
    "C4F0EC": {
        "oui_hex": "C4-F0-EC",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E80FC8": {
        "oui_hex": "E8-0F-C8",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "E45D37": {
        "oui_hex": "E4-5D-37",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00EEAB": {
        "oui_hex": "00-EE-AB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "54A703": {
        "oui_hex": "54-A7-03",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "907A58": {
        "oui_hex": "90-7A-58",
        "organization": "Zegna-Daidong Limited",
        "address_1": " Rooms 14-17, 18/F, Nan Fung Commercial, Centre 19 Lam Lok Street, Kowloon Bay",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "E009BF": {
        "oui_hex": "E0-09-BF",
        "organization": "SHENZHEN TONG BO WEI TECHNOLOGY Co.,LTD",
        "address_1": "5th floor building 4 pengtengda industrial，langkou community，dalang street longhua newly developed area",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "00131E": {
        "oui_hex": "00-13-1E",
        "organization": "peiker acustic GmbH",
        "address_1": "Max-Planck-Strasse 28-32",
        "address_2": "Friedrichsdorf    61381",
        "country": "DE"
    },
    "846991": {
        "oui_hex": "84-69-91",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "001BF7": {
        "oui_hex": "00-1B-F7",
        "organization": "Lund IP Products AB",
        "address_1": "Dalbyv. 1",
        "address_2": "Lund  Skåne  224 60",
        "country": "SE"
    },
    "783607": {
        "oui_hex": "78-36-07",
        "organization": "Cermate Technologies Inc.",
        "address_1": "7F-1, No 168 Lien-Chen Rd.",
        "address_2": "Chung-Ho Dist  New Taipei City",
        "country": "TW"
    },
    "B00073": {
        "oui_hex": "B0-00-73",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "D88DC8": {
        "oui_hex": "D8-8D-C8",
        "organization": "Atil Technology Co., LTD",
        "address_1": "Rm. 3, 21F., No.93, Sec. 2, Roosevelt Rd.,",
        "address_2": "Da’an Dist., Taipei City    106",
        "country": "TW"
    },
    "88DE7C": {
        "oui_hex": "88-DE-7C",
        "organization": "Askey Computer Corp.",
        "address_1": "10F, No.119, JIANKANG RD.,ZHINGHE DIST,",
        "address_2": "NEW TAIPEI CITY    23585",
        "country": "TW"
    },
    "A8E2C1": {
        "oui_hex": "A8-E2-C1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "909A77": {
        "oui_hex": "90-9A-77",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "04EE03": {
        "oui_hex": "04-EE-03",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "4C2498": {
        "oui_hex": "4C-24-98",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "7CD95C": {
        "oui_hex": "7C-D9-5C",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "C8AACC": {
        "oui_hex": "C8-AA-CC",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002167": {
        "oui_hex": "00-21-67",
        "organization": "HWA JIN T&I Corp.",
        "address_1": "5F., SEHWA Bldg 164-24, Poi-dong, Gangnam-gu, Seoul, Korea",
        "address_2": "Gangnam-gu  Seoul  135-960",
        "country": "KR"
    },
    "000B86": {
        "oui_hex": "00-0B-86",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "DC31D1": {
        "oui_hex": "DC-31-D1",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "C8F750": {
        "oui_hex": "C8-F7-50",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "D49234": {
        "oui_hex": "D4-92-34",
        "organization": "NEC Corporation",
        "address_1": "7-1 Shiba 5-chome",
        "address_2": "Minato-Ku  Tokyo  108-8001",
        "country": "JP"
    },
    "0007CB": {
        "oui_hex": "00-07-CB",
        "organization": "FREEBOX SAS",
        "address_1": "8 rue de la Ville l'Eveque",
        "address_2": "Paris    75008",
        "country": "FR"
    },
    "149FB6": {
        "oui_hex": "14-9F-B6",
        "organization": "GUANGDONG GENIUS TECHNOLOGY CO., LTD.",
        "address_1": "#126,BBK Road,Wusha,Chang'An",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "00115A": {
        "oui_hex": "00-11-5A",
        "organization": "Ivoclar Vivadent AG",
        "address_1": "Bendererstrasse 2",
        "address_2": "Schaan    9494",
        "country": "LI"
    },
    "4CAEA3": {
        "oui_hex": "4C-AE-A3",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "1C2E1B": {
        "oui_hex": "1C-2E-1B",
        "organization": "Suzhou Tremenet Communication Technology Co., Ltd.",
        "address_1": "Room 413, Nangong Building, 399 Linquan Street, SIP",
        "address_2": "Suzhou  Jiangsu  215123",
        "country": "CN"
    },
    "1C24EB": {
        "oui_hex": "1C-24-EB",
        "organization": "Burlywood",
        "address_1": "1501 S Sunset Street",
        "address_2": "Longmont  CO  80501",
        "country": "US"
    },
    "001013": {
        "oui_hex": "00-10-13",
        "organization": "Kontron America, Inc.",
        "address_1": "14118 Stowe Drive",
        "address_2": "Poway,  CA  9206",
        "country": "US"
    },
    "2C2BF9": {
        "oui_hex": "2C-2B-F9",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "D8C7C8": {
        "oui_hex": "D8-C7-C8",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "703A0E": {
        "oui_hex": "70-3A-0E",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "204C03": {
        "oui_hex": "20-4C-03",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "58C6F0": {
        "oui_hex": "58-C6-F0",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "84A06E": {
        "oui_hex": "84-A0-6E",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "A43EA0": {
        "oui_hex": "A4-3E-A0",
        "organization": "iComm HK LIMITED",
        "address_1": "Room 702 Kowloon Building 555 Nathan Road Kowloon HongKong",
        "address_2": "Kowloon    NA",
        "country": "HK"
    },
    "64C2DE": {
        "oui_hex": "64-C2-DE",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "8C444F": {
        "oui_hex": "8C-44-4F",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "006762": {
        "oui_hex": "00-67-62",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "2CC407": {
        "oui_hex": "2C-C4-07",
        "organization": "machineQ",
        "address_1": "1900 market st",
        "address_2": "philadelphia  PA  19103",
        "country": "US"
    },
    "B4ED19": {
        "oui_hex": "B4-ED-19",
        "organization": "Pie Digital, Inc.",
        "address_1": "575 Market st., 8th floor",
        "address_2": "San Francisco  CA  94105-2823",
        "country": "US"
    },
    "40DF02": {
        "oui_hex": "40-DF-02",
        "organization": "LINE BIZ Plus",
        "address_1": "Alphadom Tower IV (6F), Bundangnaegok-ro 117, Bundang-gu",
        "address_2": "Seongnam  Gyeonggi  13529",
        "country": "KR"
    },
    "CCE194": {
        "oui_hex": "CC-E1-94",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "900218": {
        "oui_hex": "90-02-18",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "144E2A": {
        "oui_hex": "14-4E-2A",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "84139F": {
        "oui_hex": "84-13-9F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F051EA": {
        "oui_hex": "F0-51-EA",
        "organization": "Fitbit, Inc.",
        "address_1": "199 Fremont Street, 14th Fl",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "5033F0": {
        "oui_hex": "50-33-F0",
        "organization": "YICHEN (SHENZHEN) TECHNOLOGY CO.LTD",
        "address_1": "23F, Building C1, Nanshan iPark, No. 1001 Xueyuan Road, Nanshan District, Shenzhen City, Guangdong, China",
        "address_2": "shenzhen    518044",
        "country": "CN"
    },
    "FC2BB2": {
        "oui_hex": "FC-2B-B2",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "E09F2A": {
        "oui_hex": "E0-9F-2A",
        "organization": "Iton Technology Corp.",
        "address_1": "Room 1302, Block A, Building 4，Huangge Road, Longgang District",
        "address_2": "Shenzhen   Guangdong   518116",
        "country": "CN"
    },
    "4CE19E": {
        "oui_hex": "4C-E1-9E",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "7495EC": {
        "oui_hex": "74-95-EC",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "AC5AEE": {
        "oui_hex": "AC-5A-EE",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "70BC10": {
        "oui_hex": "70-BC-10",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "884A18": {
        "oui_hex": "88-4A-18",
        "organization": "Opulinks",
        "address_1": "F 28, No.328, Huashan Rd",
        "address_2": "Shanghai    200040",
        "country": "CN"
    },
    "0006F7": {
        "oui_hex": "00-06-F7",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "000704": {
        "oui_hex": "00-07-04",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "0006F5": {
        "oui_hex": "00-06-F5",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "34C731": {
        "oui_hex": "34-C7-31",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "9C69B4": {
        "oui_hex": "9C-69-B4",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "500084": {
        "oui_hex": "50-00-84",
        "organization": "Siemens Canada",
        "address_1": "300 Applewood Crescent",
        "address_2": "Concord  Ontario  L4K 5C7",
        "country": "CA"
    },
    "64D4BD": {
        "oui_hex": "64-D4-BD",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "KAKUDA-CITY  MIYAGI-PREF  981-1595",
        "country": "JP"
    },
    "0498F3": {
        "oui_hex": "04-98-F3",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1 NISHIDA",
        "address_2": "KAKUDA  MIYAGI PREF  9876-8501",
        "country": "JP"
    },
    "00214F": {
        "oui_hex": "00-21-4F",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "44B433": {
        "oui_hex": "44-B4-33",
        "organization": "tide.co.,ltd",
        "address_1": "9F Kapeul GreatValley A-dong, Digitalro 9-ghil 32, Geumcheon-gu",
        "address_2": "seoul  seoul  ASIKRKS006",
        "country": "KR"
    },
    "D8A6FD": {
        "oui_hex": "D8-A6-FD",
        "organization": "Ghost Locomotion",
        "address_1": "800 California St.  Suite 200",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "DC21B9": {
        "oui_hex": "DC-21-B9",
        "organization": "Sentec Co.Ltd",
        "address_1": "10, Baekseokgongdan 1-ro, Seobuk-gu",
        "address_2": " Cheonan-si  Chungcheongnam-do  31094",
        "country": "KR"
    },
    "6CDFFB": {
        "oui_hex": "6C-DF-FB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "247D4D": {
        "oui_hex": "24-7D-4D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "8850F6": {
        "oui_hex": "88-50-F6",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan Distric",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "E498BB": {
        "oui_hex": "E4-98-BB",
        "organization": "Phyplus Microelectronics Limited",
        "address_1": "304 Building 1 No.608 Sheng Xia Road",
        "address_2": "Shanghai    200000",
        "country": "CN"
    },
    "60A11E": {
        "oui_hex": "60-A1-1E",
        "organization": "Wuhan Maxsine Electric Co.,Ltd.",
        "address_1": "Building A6, Hangyu Building, No 7, Wuhan University Science Park Road, East Lake Development District,Wuhan,China.",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "C45BF7": {
        "oui_hex": "C4-5B-F7",
        "organization": "ants",
        "address_1": "1164-21,Haeun-daero, Haeundae-gu,",
        "address_2": "Busan    48069",
        "country": "KR"
    },
    "8CDF9D": {
        "oui_hex": "8C-DF-9D",
        "organization": "NEC Corporation",
        "address_1": "7-1, Shiba 5-chome,",
        "address_2": "Tokyo  Tokyo  108-8001",
        "country": "JP"
    },
    "5C415A": {
        "oui_hex": "5C-41-5A",
        "organization": "Amazon.com, LLC",
        "address_1": "1200 12th Ave. South, Suite 1200",
        "address_2": "Seattle    98144",
        "country": "US"
    },
    "705E55": {
        "oui_hex": "70-5E-55",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "B0D568": {
        "oui_hex": "B0-D5-68",
        "organization": "Shenzhen Cultraview Digital Technology Co., Ltd",
        "address_1": "F6,M6,Maqueling, High-tech park, Nanshan district",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F00EBF": {
        "oui_hex": "F0-0E-BF",
        "organization": "ZettaHash Inc.",
        "address_1": "6F Chiyoda Ogawamachi Crosta, 1-11, Kanda Ogawamachi",
        "address_2": "Chiyoda-ku  Tokyo  101-0052",
        "country": "JP"
    },
    "703509": {
        "oui_hex": "70-35-09",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "441AFA": {
        "oui_hex": "44-1A-FA",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "04072E": {
        "oui_hex": "04-07-2E",
        "organization": "VTech Electronics Ltd.",
        "address_1": "23rd Floor, Block 1, Tai Ping Industrial Centre, 57 Ting Kok Road",
        "address_2": "Tai Po, N.T.    NA",
        "country": "HK"
    },
    "780ED1": {
        "oui_hex": "78-0E-D1",
        "organization": "TRUMPF Werkzeugmaschinen GmbH+Co.KG",
        "address_1": "Johann-Maus-Straße 2",
        "address_2": "Ditzingen    71254",
        "country": "DE"
    },
    "44ECCE": {
        "oui_hex": "44-EC-CE",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F82F08": {
        "oui_hex": "F8-2F-08",
        "organization": "Molex CMS",
        "address_1": "2222 Wellington Court",
        "address_2": "Lisle  IL  60532",
        "country": "US"
    },
    "441C12": {
        "oui_hex": "44-1C-12",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "4428A3": {
        "oui_hex": "44-28-A3",
        "organization": "Jiangsu fulian  Communication Technology Co., Ltd.",
        "address_1": "The south of lanling road, yongan new district",
        "address_2": "Danyang   Jiangsu  212300",
        "country": "CN"
    },
    "10C595": {
        "oui_hex": "10-C5-95",
        "organization": "Lenovo",
        "address_1": "1009 Think Place",
        "address_2": "Morrisvilee  NC  27560",
        "country": "US"
    },
    "203233": {
        "oui_hex": "20-32-33",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "6829DC": {
        "oui_hex": "68-29-DC",
        "organization": "Ficosa Electronics S.L.U.",
        "address_1": "Pol.Ind Can Mitjans s/n Viladecavalls Barcelona",
        "address_2": "Viladecavalls  Barcelona  ES08232",
        "country": "ES"
    },
    "9454DF": {
        "oui_hex": "94-54-DF",
        "organization": "YST CORP.",
        "address_1": "A-1407, 767, Sinsu-ro, Suji-gu,",
        "address_2": "Yongin-si  Gyeonggi-do  16827",
        "country": "KR"
    },
    "7CBC84": {
        "oui_hex": "7C-BC-84",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F80DF1": {
        "oui_hex": "F8-0D-F1",
        "organization": "Sontex SA",
        "address_1": "rue de la gare",
        "address_2": "sonceboz  Bern  2605",
        "country": "CH"
    },
    "A49426": {
        "oui_hex": "A4-94-26",
        "organization": "Elgama-Elektronika Ltd.",
        "address_1": "Visoriu str. 2",
        "address_2": "Vilnius    LT-08300",
        "country": "LT"
    },
    "E4F14C": {
        "oui_hex": "E4-F1-4C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "A8B456": {
        "oui_hex": "A8-B4-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2CA9F0": {
        "oui_hex": "2C-A9-F0",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "549B72": {
        "oui_hex": "54-9B-72",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "A047D7": {
        "oui_hex": "A0-47-D7",
        "organization": "Best IT World (India) Pvt Ltd",
        "address_1": "87, Mistry Complex,, Midc Cross Road A, Andheri-East",
        "address_2": "Mumbai  Maharashtra  400093",
        "country": "IN"
    },
    "6899CD": {
        "oui_hex": "68-99-CD",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1040F3": {
        "oui_hex": "10-40-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "586B14": {
        "oui_hex": "58-6B-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BCB863": {
        "oui_hex": "BC-B8-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C1CF6": {
        "oui_hex": "2C-1C-F6",
        "organization": "Alien Green LLC",
        "address_1": "A. Kazbegi Ave., No24g, apt 227",
        "address_2": "Tbilisi  Tbilisi  0160",
        "country": "GE"
    },
    "6C2B59": {
        "oui_hex": "6C-2B-59",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "44E66E": {
        "oui_hex": "44-E6-6E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0E862": {
        "oui_hex": "C0-E8-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F40616": {
        "oui_hex": "F4-06-16",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0CFE5D": {
        "oui_hex": "0C-FE-5D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "3C8D20": {
        "oui_hex": "3C-8D-20",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "601D91": {
        "oui_hex": "60-1D-91",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "D4C94B": {
        "oui_hex": "D4-C9-4B",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "08351B": {
        "oui_hex": "08-35-1B",
        "organization": "Shenzhen Jialihua Electronic Technology Co., Ltd",
        "address_1": "Building 26,Xin'e Industrial Area,E'gongling Village,Pinghu Town,Longgang District",
        "address_2": "Shenzhen  Guangdong  518111",
        "country": "CN"
    },
    "AC1585": {
        "oui_hex": "AC-15-85",
        "organization": "silergy corp",
        "address_1": "Oleander  Way，802 West  Bay  Road，P.O. BOX    32052",
        "address_2": "Grand   Cayman  KYI-1208，Cayman Islands    32052",
        "country": "US"
    },
    "AC5093": {
        "oui_hex": "AC-50-93",
        "organization": "Magna Electronics Europe GmbH & Co. OHG",
        "address_1": "Kurfürst-Eppstein-Ring 9",
        "address_2": "Sailauf  Bavaria  63877",
        "country": "DE"
    },
    "70BBE9": {
        "oui_hex": "70-BB-E9",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "50A0A4": {
        "oui_hex": "50-A0-A4",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "00D02D": {
        "oui_hex": "00-D0-2D",
        "organization": "Resideo",
        "address_1": "2 Corporate Center Dr.",
        "address_2": "Melville  NY  11747",
        "country": "US"
    },
    "806940": {
        "oui_hex": "80-69-40",
        "organization": "LEXAR CO.,LIMITED",
        "address_1": "10TH FLOOR,CHINA AEROSPACE CENTRE,143 HOI BUN ROAD,KWUN TONG,KOWLOON, HONG KONG",
        "address_2": "HONG KONG    999077",
        "country": "HK"
    },
    "64F81C": {
        "oui_hex": "64-F8-1C",
        "organization": "Huawei Technologies Co., Ltd.",
        "address_1": " Bantian, Longgang District, Shenzhen, 518129, P.R.C",
        "address_2": "Shenzhen  GUANGDONG Province  518000",
        "country": "CN"
    },
    "1098C3": {
        "oui_hex": "10-98-C3",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "9CC8FC": {
        "oui_hex": "9C-C8-FC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "B07E11": {
        "oui_hex": "B0-7E-11",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "10C753": {
        "oui_hex": "10-C7-53",
        "organization": "Qingdao Intelligent&Precise Electronics Co.,Ltd.",
        "address_1": "No.218 Qianwangang Road",
        "address_2": "Qingdao  Shangdong  266510",
        "country": "CN"
    },
    "F4951B": {
        "oui_hex": "F4-95-1B",
        "organization": "Hefei Radio Communication Technology Co., Ltd",
        "address_1": " No.108, YinXing Road, High-tech Development Zone",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "6C3845": {
        "oui_hex": "6C-38-45",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "2C6104": {
        "oui_hex": "2C-61-04",
        "organization": "SHENZHEN FENGLIAN TECHNOLOGY CO., LTD.",
        "address_1": "ORIENTAL CYBERPORT, HIGHTECH 6 ROAD",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "BC9325": {
        "oui_hex": "BC-93-25",
        "organization": "Ningbo Joyson Preh Car Connect Co.,Ltd.",
        "address_1": "No. 99, Qingyi Road",
        "address_2": "Ningbo   Zhejiang  315040",
        "country": "CN"
    },
    "D0B60A": {
        "oui_hex": "D0-B6-0A",
        "organization": "Xingluo Technology Company  Limited",
        "address_1": "28F, Building A, Aerospace Science And Technology Square, Nanshan District",
        "address_2": "ShenZhen  GuangDong   518067",
        "country": "CN"
    },
    "049226": {
        "oui_hex": "04-92-26",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "E8ADA6": {
        "oui_hex": "E8-AD-A6",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "0C1C19": {
        "oui_hex": "0C-1C-19",
        "organization": "LONGCONN ELECTRONICS(SHENZHEN) CO.,LTD",
        "address_1": "Building B, No. 42 Xingye Road, Phoenix First Industrial Zone, Fuyong, Baoan District",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "90E710": {
        "oui_hex": "90-E7-10",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "302952": {
        "oui_hex": "30-29-52",
        "organization": "Hillstone Networks Inc",
        "address_1": "North Olympic Science & Technology Park Building #20， Floor #5, SouthBaosheng",
        "address_2": "Beijing    100192",
        "country": "CN"
    },
    "E013B5": {
        "oui_hex": "E0-13-B5",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "E0795E": {
        "oui_hex": "E0-79-5E",
        "organization": "Wuxi Xiaohu Technology Co.,Ltd.",
        "address_1": "FL.2, Building A10, 777 West Jianzhu Road, Binhu District",
        "address_2": "Wuxi  Jiangsu Province  214000",
        "country": "CN"
    },
    "00B1E3": {
        "oui_hex": "00-B1-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A41194": {
        "oui_hex": "A4-11-94",
        "organization": "Lenovo",
        "address_1": "1009 Think Place",
        "address_2": "Morrisvilee  NC  27560",
        "country": "US"
    },
    "00CB00": {
        "oui_hex": "00-CB-00",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "DCF401": {
        "oui_hex": "DC-F4-01",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "0C4101": {
        "oui_hex": "0C-41-01",
        "organization": "Ruichi Auto Technology (Guangzhou) Co., Ltd.",
        "address_1": "No. 171 Haibin Road, Nansha District, Guangzhou, China",
        "address_2": "Guangzhou  Guangdong Province  511400",
        "country": "CN"
    },
    "00B771": {
        "oui_hex": "00-B7-71",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E4B2FB": {
        "oui_hex": "E4-B2-FB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2CCA0C": {
        "oui_hex": "2C-CA-0C",
        "organization": "WITHUS PLANET",
        "address_1": "1604, O'BIZTOWER, Pyeong Chon, 126, Beolmal-ro, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  14057",
        "country": "KR"
    },
    "84326F": {
        "oui_hex": "84-32-6F",
        "organization": "GUANGZHOU AVA ELECTRONICS TECHNOLOGY CO.,LTD",
        "address_1": "Science town luogang district guangzhou city branch bead road 232 profit people park 301, building 2",
        "address_2": "guangzhou   guangdong  510000",
        "country": "CN"
    },
    "C89C13": {
        "oui_hex": "C8-9C-13",
        "organization": "Inspiremobile",
        "address_1": "Rm1412, Daeryung Techno-Town, 15th, 401 , Simin-daero, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  14057",
        "country": "KR"
    },
    "8C85E6": {
        "oui_hex": "8C-85-E6",
        "organization": "Cleondris GmbH",
        "address_1": "Zuercherstrasse 42",
        "address_2": "Uitikon  ZH  8142",
        "country": "CH"
    },
    "807D14": {
        "oui_hex": "80-7D-14",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "20283E": {
        "oui_hex": "20-28-3E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4FC77": {
        "oui_hex": "A4-FC-77",
        "organization": "Mega Well Limited",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "4C569D": {
        "oui_hex": "4C-56-9D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38539C": {
        "oui_hex": "38-53-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "402619": {
        "oui_hex": "40-26-19",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6CE85C": {
        "oui_hex": "6C-E8-5C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "049162": {
        "oui_hex": "04-91-62",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "F83880": {
        "oui_hex": "F8-38-80",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C79D7": {
        "oui_hex": "2C-79-D7",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "00B4F5": {
        "oui_hex": "00-B4-F5",
        "organization": "DongGuan Siyoto Electronics Co., Ltd",
        "address_1": "Hecheng Industrial District, QiaoTou Town",
        "address_2": "DongGuan City  Guangdong  523520",
        "country": "CN"
    },
    "BC3F4E": {
        "oui_hex": "BC-3F-4E",
        "organization": "Teleepoch Ltd",
        "address_1": "No.13 Langshan Rd,HiTech Park,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "1838AE": {
        "oui_hex": "18-38-AE",
        "organization": "CONSPIN SOLUTION",
        "address_1": "2F, Geonwoong Bldg. 109, Gwanak-ro, Gwanak-gu",
        "address_2": "Seoul    08833",
        "country": "KR"
    },
    "04CF8C": {
        "oui_hex": "04-CF-8C",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "0C7512": {
        "oui_hex": "0C-75-12",
        "organization": "Shenzhen Kunlun TongTai Technology  Co.,Ltd.",
        "address_1": "Room 2401,B,Building 3,Tianan Yungu Industry Park,Gangtou community,bantian streets,Longgang District",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "7483C2": {
        "oui_hex": "74-83-C2",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "E063DA": {
        "oui_hex": "E0-63-DA",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "50579C": {
        "oui_hex": "50-57-9C",
        "organization": "Seiko Epson Corporation",
        "address_1": "2070 Kotobuki Koaka",
        "address_2": "Matsumoto-shi  Nagano-ken  399-8702",
        "country": "JP"
    },
    "54278D": {
        "oui_hex": "54-27-8D",
        "organization": "NXP (China) Management Ltd.",
        "address_1": "21F, BM InterContinental Business Center, 100 Yu Tong Road",
        "address_2": "Shanghai  Shanghai  200070",
        "country": "CN"
    },
    "B0BE76": {
        "oui_hex": "B0-BE-76",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4447CC": {
        "oui_hex": "44-47-CC",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "4CD98F": {
        "oui_hex": "4C-D9-8F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "B0AE25": {
        "oui_hex": "B0-AE-25",
        "organization": "Varikorea",
        "address_1": "#505 kolon digital tower aston, gasan, geumcheon",
        "address_2": "seoul    08502",
        "country": "KR"
    },
    "4C1B86": {
        "oui_hex": "4C-1B-86",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "ECC40D": {
        "oui_hex": "EC-C4-0D",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "440049": {
        "oui_hex": "44-00-49",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "E86A64": {
        "oui_hex": "E8-6A-64",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "10A24E": {
        "oui_hex": "10-A2-4E",
        "organization": "GOLD3LINK ELECTRONICS CO., LTD",
        "address_1": "No.90,Sec.1,Com Lin Rd,Taipei 114,Taiwan,R.O.C",
        "address_2": "Taipei  Taiwan  114",
        "country": "TW"
    },
    "CCC5E5": {
        "oui_hex": "CC-C5-E5",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "6CC374": {
        "oui_hex": "6C-C3-74",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "684749": {
        "oui_hex": "68-47-49",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F8D9B8": {
        "oui_hex": "F8-D9-B8",
        "organization": "Open Mesh, Inc.",
        "address_1": "111 SW 5th Ave Ste1150",
        "address_2": "Portland  OR  97204",
        "country": "US"
    },
    "7C696B": {
        "oui_hex": "7C-69-6B",
        "organization": "Atmosic Technologies",
        "address_1": "12930 Saratoga Ave, Suite B6",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "5CD20B": {
        "oui_hex": "5C-D2-0B",
        "organization": "Yytek Co., Ltd.",
        "address_1": "No.1 Bao Sheng South Road, Room 401, Ao Bei Technology Park, Ling Zhi Center",
        "address_2": "Beijing    100192",
        "country": "CN"
    },
    "70037E": {
        "oui_hex": "70-03-7E",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "D003DF": {
        "oui_hex": "D0-03-DF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "C423A2": {
        "oui_hex": "C4-23-A2",
        "organization": "PT. Emsonic Indonesia",
        "address_1": "Jl.Timor Blok E5, MM2100 Industrial Town Jatiwangi Cikarang Barat",
        "address_2": "Bekasi  Jawa Barat  17530",
        "country": "ID"
    },
    "B4CB57": {
        "oui_hex": "B4-CB-57",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "4C1265": {
        "oui_hex": "4C-12-65",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00500C": {
        "oui_hex": "00-50-0C",
        "organization": "e-Tek Labs, Inc.",
        "address_1": "1057 EAST HENRIETTA RD.",
        "address_2": "ROCHESTER  NY  14623",
        "country": "US"
    },
    "485F99": {
        "oui_hex": "48-5F-99",
        "organization": "Cloud Network Technology (Samoa) Limited",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "8834FE": {
        "oui_hex": "88-34-FE",
        "organization": "Bosch Automotive Products (Suzhou) Co. Ltd",
        "address_1": "No. 455 Xing Long Street,Suzhou Industrial Park,Suzhou P.R., 215021 China",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "88F7BF": {
        "oui_hex": "88-F7-BF",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "D87D7F": {
        "oui_hex": "D8-7D-7F",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "00051A": {
        "oui_hex": "00-05-1A",
        "organization": "3COM EUROPE LTD",
        "address_1": "3COM CENTRE",
        "address_2": "vvvvv  UNITED  KINGDOM",
        "country": "GB"
    },
    "08004E": {
        "oui_hex": "08-00-4E",
        "organization": "3COM EUROPE LTD",
        "address_1": "3COM CENTRE",
        "address_2": "vvvvv  UNITED  KINGDOM",
        "country": "GB"
    },
    "00301E": {
        "oui_hex": "00-30-1E",
        "organization": "3COM EUROPE LTD",
        "address_1": "BOUNDARY WAY",
        "address_2": "vvvvv  UNITED  KINGDOM",
        "country": "GB"
    },
    "005004": {
        "oui_hex": "00-50-04",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "000103": {
        "oui_hex": "00-01-03",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "58B568": {
        "oui_hex": "58-B5-68",
        "organization": "SECURITAS DIRECT ESPAÑA, SAU",
        "address_1": "C/ Priégola, 2",
        "address_2": "Pozuelo de Alarcon  Madrid  28224",
        "country": "ES"
    },
    "484AE9": {
        "oui_hex": "48-4A-E9",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "846A66": {
        "oui_hex": "84-6A-66",
        "organization": "Sumitomo Kizai  Co.,Ltd.",
        "address_1": "1-45-1higashiikebukuro",
        "address_2": "tosimaku  tokyo  170-0013",
        "country": "JP"
    },
    "18D717": {
        "oui_hex": "18-D7-17",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "80B624": {
        "oui_hex": "80-B6-24",
        "organization": "IVS",
        "address_1": "807-809 , Woorim E-biz center, 35, Gwangnaru-ro 6-gil",
        "address_2": "Seoul  Seongdong-gu  04799",
        "country": "KR"
    },
    "DCF505": {
        "oui_hex": "DC-F5-05",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "CCF0FD": {
        "oui_hex": "CC-F0-FD",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District, Hangzhou, Zhejiang",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "8489EC": {
        "oui_hex": "84-89-EC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "88108F": {
        "oui_hex": "88-10-8F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4631F": {
        "oui_hex": "F4-63-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A49B4F": {
        "oui_hex": "A4-9B-4F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00073A": {
        "oui_hex": "00-07-3A",
        "organization": "INVENTEL",
        "address_1": "35, rue Toumefort",
        "address_2": "000    0000",
        "country": "FR"
    },
    "00266C": {
        "oui_hex": "00-26-6C",
        "organization": "INVENTEC CORPORATION",
        "address_1": "Inventec Building, 66 Hou-Kang Street Shih-Lin District,",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "008CFA": {
        "oui_hex": "00-8C-FA",
        "organization": "INVENTEC CORPORATION",
        "address_1": "No. 255, Jen-Ho Road Sec. 2, 33547,",
        "address_2": "Tachi  Taoyuan  33547",
        "country": "TW"
    },
    "5CFB7C": {
        "oui_hex": "5C-FB-7C",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "FC039F": {
        "oui_hex": "FC-03-9F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "02C08C": {
        "oui_hex": "02-C0-8C",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "0057C1": {
        "oui_hex": "00-57-C1",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "7C240C": {
        "oui_hex": "7C-24-0C",
        "organization": "Telechips, Inc.",
        "address_1": "19F~23F,Luther Bldg.42, Olympic-ro 35da-gil, Songpa-gu,",
        "address_2": "Seoul  Seoul  05510",
        "country": "KR"
    },
    "00203D": {
        "oui_hex": "00-20-3D",
        "organization": "Honeywell Environmental & Combustion Controls",
        "address_1": "1985 Douglas Drive",
        "address_2": "Golden Valley  MN  55422",
        "country": "US"
    },
    "004084": {
        "oui_hex": "00-40-84",
        "organization": "Honeywell International HPS",
        "address_1": "consolidation",
        "address_2": "Fort Washington  PA  19034",
        "country": "US"
    },
    "A4D990": {
        "oui_hex": "A4-D9-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "006087": {
        "oui_hex": "00-60-87",
        "organization": "KANSAI ELECTRIC CO., LTD.",
        "address_1": "6-14-9 MIDORII, ASAMINAMI-KU",
        "address_2": "HIROSHIMA 731-01",
        "country": "JO"
    },
    "DCF719": {
        "oui_hex": "DC-F7-19",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A0950C": {
        "oui_hex": "A0-95-0C",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "D4741B": {
        "oui_hex": "D4-74-1B",
        "organization": "Beijing HuaDa ZhiBao Electronic System Co.,Ltd.",
        "address_1": "No.1 Gaojiayuan,Chaoyang District,Beijing,China",
        "address_2": "Beijing  Beijing  100015",
        "country": "CN"
    },
    "001BC0": {
        "oui_hex": "00-1B-C0",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2C15E1": {
        "oui_hex": "2C-15-E1",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "30D16B": {
        "oui_hex": "30-D1-6B",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "98AE71": {
        "oui_hex": "98-AE-71",
        "organization": "VVDN Technologies Pvt Ltd",
        "address_1": "B-22, Sec-34 , Info-city -I",
        "address_2": "Gurugram  Haryana  122001",
        "country": "IN"
    },
    "A456CC": {
        "oui_hex": "A4-56-CC",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "AC6E1A": {
        "oui_hex": "AC-6E-1A",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "B116,B118,A211-A213,B201-B213,A311-A313,B411-413,BF08-09 Nanshan Medical Instrument Industry Park,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "0080EB": {
        "oui_hex": "00-80-EB",
        "organization": "COMPCONTROL B.V.",
        "address_1": "STRATUMSED K31",
        "address_2": "  THE",
        "country": "NL"
    },
    "0002EB": {
        "oui_hex": "00-02-EB",
        "organization": "Pico Communications",
        "address_1": "20085 Stevens Creek Blvd.",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "342EB6": {
        "oui_hex": "34-2E-B6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC9232": {
        "oui_hex": "AC-92-32",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "000FB0": {
        "oui_hex": "00-0F-B0",
        "organization": "Compal Electronics INC.",
        "address_1": "No.8 , Nandong Road , PingZhen Dist.",
        "address_2": "Taoyuan   Taiwan   32455",
        "country": "TW"
    },
    "00023F": {
        "oui_hex": "00-02-3F",
        "organization": "Compal Electronics INC.",
        "address_1": "No.8 , Nandong Road , PingZhen Dist.",
        "address_2": "Taoyuan   Taiwan   32455",
        "country": "TW"
    },
    "68A8E1": {
        "oui_hex": "68-A8-E1",
        "organization": "Wacom Co.,Ltd.",
        "address_1": "Sumitomo Fudosan Shinjuku Grand Tower 31F,8-17-1",
        "address_2": "Nishi-shinjuku,Shinjuku-ku  Tokyo  160-6131",
        "country": "JP"
    },
    "30D32D": {
        "oui_hex": "30-D3-2D",
        "organization": "devolo AG",
        "address_1": "Charlottenburger Allee 67",
        "address_2": "Aachen  NRW  52068",
        "country": "DE"
    },
    "BCF2AF": {
        "oui_hex": "BC-F2-AF",
        "organization": "devolo AG",
        "address_1": "Charlottenburger Allee 67",
        "address_2": "Aachen  NRW  52068",
        "country": "DE"
    },
    "E0AF4F": {
        "oui_hex": "E0-AF-4F",
        "organization": "Deutsche Telekom AG",
        "address_1": "Friedrich-Ebert-Allee 140",
        "address_2": "Bonn    53113",
        "country": "DE"
    },
    "B869F4": {
        "oui_hex": "B8-69-F4",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "283A4D": {
        "oui_hex": "28-3A-4D",
        "organization": "Cloud Network Technology (Samoa) Limited",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B87C6F": {
        "oui_hex": "B8-7C-6F",
        "organization": "NXP (China) Management Ltd.",
        "address_1": "21F, BM InterContinental Business Center, 100 Yu Tong Road",
        "address_2": "Shanghai  Shanghai  200070",
        "country": "CN"
    },
    "305DA6": {
        "oui_hex": "30-5D-A6",
        "organization": "ADVALY SYSTEM Inc.",
        "address_1": "7 KITA2 NISHI2 CYUO-KU",
        "address_2": "SAPPORO  HOKKAIDO  060-0002",
        "country": "JP"
    },
    "BC30D9": {
        "oui_hex": "BC-30-D9",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "0479B7": {
        "oui_hex": "04-79-B7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C0D0FF": {
        "oui_hex": "C0-D0-FF",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "88DF9E": {
        "oui_hex": "88-DF-9E",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "2C7CE4": {
        "oui_hex": "2C-7C-E4",
        "organization": "Wuhan Tianyu Information Industry Co., Ltd.",
        "address_1": "HUST Industry Park, East-Lake Development Zone",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "5803FB": {
        "oui_hex": "58-03-FB",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "144802": {
        "oui_hex": "14-48-02",
        "organization": "THE YEOLRIM Co.,Ltd.",
        "address_1": "D-311,H Business Park,26,Beobwon-ro 9-gil Songpa-gu,Seoul Korea",
        "address_2": "Seoul    05836",
        "country": "KR"
    },
    "FC4AE9": {
        "oui_hex": "FC-4A-E9",
        "organization": "Castlenet Technology Inc.",
        "address_1": "No.64, Chung-Shan Rd.",
        "address_2": "New Taipei City    23680",
        "country": "TW"
    },
    "40313C": {
        "oui_hex": "40-31-3C",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "FC4596": {
        "oui_hex": "FC-45-96",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": " NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZON",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "A0E534": {
        "oui_hex": "A0-E5-34",
        "organization": "Stratec Biomedical AG",
        "address_1": "Gewerbestrasse 37",
        "address_2": "Birkenfeld  Baden Wuertemberg  75217",
        "country": "DE"
    },
    "444B5D": {
        "oui_hex": "44-4B-5D",
        "organization": "GE Healthcare",
        "address_1": "Kuortaneenkatu 2",
        "address_2": "Helsinki    00510",
        "country": "FI"
    },
    "001555": {
        "oui_hex": "00-15-55",
        "organization": "DFM GmbH",
        "address_1": "Lahrer Strasse 6",
        "address_2": "Lahr  Baden-Württemberg  77933",
        "country": "US"
    },
    "1C7508": {
        "oui_hex": "1C-75-08",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU   215300",
        "country": "CN"
    },
    "001B38": {
        "oui_hex": "00-1B-38",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD AVENUE",
        "address_2": "KUNSHAN CITY  SUZHOU PROVINCE  215300",
        "country": "CN"
    },
    "00235A": {
        "oui_hex": "00-23-5A",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO 25, The 3rd street,",
        "address_2": "KuanShan  SUZHOU  215300",
        "country": "CN"
    },
    "24D76B": {
        "oui_hex": "24-D7-6B",
        "organization": "Syntronic AB",
        "address_1": "Utmarksvägen 33c",
        "address_2": "Gävle    80291",
        "country": "SE"
    },
    "C4FEE2": {
        "oui_hex": "C4-FE-E2",
        "organization": "AMICCOM Electronics Corporation",
        "address_1": "10F, No.18, Taiyuan St., Zhubei City",
        "address_2": "Hsinchu Country  Taiwan  30265",
        "country": "TW"
    },
    "780CF0": {
        "oui_hex": "78-0C-F0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0C8C24": {
        "oui_hex": "0C-8C-24",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "8C6D77": {
        "oui_hex": "8C-6D-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8C57A": {
        "oui_hex": "E8-C5-7A",
        "organization": "Ufispace Co., LTD.",
        "address_1": "9F., No. 81 Jhongcheng Rd., Tucheng Dist.,",
        "address_2": "New Taipei    23674",
        "country": "TW"
    },
    "E01283": {
        "oui_hex": "E0-12-83",
        "organization": " Shenzhen Fanzhuo Communication Technology Co., Lt",
        "address_1": " No.1003 Kesi Road, Hi-Tech Park,",
        "address_2": "Shenzhen  Nanshan District  2602-2603",
        "country": "CN"
    },
    "A0CF5B": {
        "oui_hex": "A0-CF-5B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002421": {
        "oui_hex": "00-24-21",
        "organization": "MICRO-STAR INT'L CO., LTD.",
        "address_1": "No.69, Li-De St",
        "address_2": "Taipei Hsien    235",
        "country": "TW"
    },
    "0060D1": {
        "oui_hex": "00-60-D1",
        "organization": "CASCADE COMMUNICATIONS",
        "address_1": "6 TECHNOLOGY PARK DRIVE",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "84C9C6": {
        "oui_hex": "84-C9-C6",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "88B66B": {
        "oui_hex": "88-B6-6B",
        "organization": "easynetworks",
        "address_1": " Rd kaituo 1# kaituohuiyuan B 1020, shangdi",
        "address_2": "Beijing    100084",
        "country": "CN"
    },
    "24F57E": {
        "oui_hex": "24-F5-7E",
        "organization": "HWH CO., LTD.",
        "address_1": "102-708, Digital Empire2, Sin-dong, Youngtong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  443-734",
        "country": "KR"
    },
    "8CA048": {
        "oui_hex": "8C-A0-48",
        "organization": "Beijing NeTopChip Technology Co.,LTD",
        "address_1": "309,Intergration Building Olympic Center, No.1 An Ding Road,Chao Yang District,,",
        "address_2": "Beijing    100029",
        "country": "CN"
    },
    "24D3F2": {
        "oui_hex": "24-D3-F2",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D469A5": {
        "oui_hex": "D4-69-A5",
        "organization": "Miura Systems Ltd.",
        "address_1": "Axis 40, Oxford Road, Stokenchurch",
        "address_2": "High Wycombe  Buckinghamshire  HP143SX",
        "country": "GB"
    },
    "8C8126": {
        "oui_hex": "8C-81-26",
        "organization": "ARCOM",
        "address_1": "ZAC de la Loyère",
        "address_2": "FRAGNES LA LOYERE    71530",
        "country": "FR"
    },
    "D47C44": {
        "oui_hex": "D4-7C-44",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "805E4F": {
        "oui_hex": "80-5E-4F",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "8417EF": {
        "oui_hex": "84-17-EF",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "3856B5": {
        "oui_hex": "38-56-B5",
        "organization": "Peerbridge Health Inc",
        "address_1": "3 Columbus Circle 15th Fl",
        "address_2": "New York  NY  10019",
        "country": "US"
    },
    "7C96D2": {
        "oui_hex": "7C-96-D2",
        "organization": "Fihonest communication co.,Ltd",
        "address_1": "The Frist Building ,ShangKeng Industrial Zone,  Changping Town",
        "address_2": "Dongguan  Guangdong  523560",
        "country": "CN"
    },
    "C042D0": {
        "oui_hex": "C0-42-D0",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D0C5D8": {
        "oui_hex": "D0-C5-D8",
        "organization": "LATECOERE",
        "address_1": "135 Rue de Périole, BP25211",
        "address_2": "Toulouse Cedex 5  31 Haute-Garonne  31079",
        "country": "FR"
    },
    "7054B4": {
        "oui_hex": "70-54-B4",
        "organization": "Vestel Elektronik San ve Tic. A.Ş.",
        "address_1": "Organize san",
        "address_2": "Manisa  Turket  45030",
        "country": "TR"
    },
    "20A60C": {
        "oui_hex": "20-A6-0C",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "488AD2": {
        "oui_hex": "48-8A-D2",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "DCE838": {
        "oui_hex": "DC-E8-38",
        "organization": "CK Telecom (Shenzhen) Limited",
        "address_1": "Floor 9th, Building 4C,Software Industry Base, Xuefu Road, Hi-Tech Park, Nanshan Dist.",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A8D498": {
        "oui_hex": "A8-D4-98",
        "organization": "Avira Operations GmbH & Co. KG",
        "address_1": "Kaplaneiweg 1",
        "address_2": "Tettnang  Baden-Wuerttermberg  88069",
        "country": "DE"
    },
    "505967": {
        "oui_hex": "50-59-67",
        "organization": "Intent Solutions Inc",
        "address_1": "730 Peachtree St NE, Suite 550",
        "address_2": "ATLANTA  GA  30308",
        "country": "US"
    },
    "000680": {
        "oui_hex": "00-06-80",
        "organization": "Card Access, Inc.",
        "address_1": "11778 S. Election Rd",
        "address_2": "Salt Lake City  UT  80420",
        "country": "US"
    },
    "3C576C": {
        "oui_hex": "3C-57-6C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "841766": {
        "oui_hex": "84-17-66",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road,Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Wei Fang  Shan Dong",
        "country": "CN"
    },
    "2C4D79": {
        "oui_hex": "2C-4D-79",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "No.268 Dongfang Road",
        "address_2": "Weifang  Shandong  261000",
        "country": "CN"
    },
    "000C42": {
        "oui_hex": "00-0C-42",
        "organization": "Routerboard.com",
        "address_1": "Pernavas 46",
        "address_2": "Riga    LV-1009",
        "country": "LV"
    },
    "0026BD": {
        "oui_hex": "00-26-BD",
        "organization": "JTEC Card &amp; Communication Co., Ltd",
        "address_1": "Dabo Bldg, 4F, 61-1, Gyesu-dong, Sosa-gu",
        "address_2": "Bucheon  Gyunggi-do  422-070",
        "country": "KR"
    },
    "60D02C": {
        "oui_hex": "60-D0-2C",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D058FC": {
        "oui_hex": "D0-58-FC",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "14579F": {
        "oui_hex": "14-57-9F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B44326": {
        "oui_hex": "B4-43-26",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "04AB18": {
        "oui_hex": "04-AB-18",
        "organization": "ELECOM CO.,LTD.",
        "address_1": "11F Tokyubancho Bldg. 6-2,",
        "address_2": "Chiyoda-ku  Tokyo  102-0081",
        "country": "JP"
    },
    "78D294": {
        "oui_hex": "78-D2-94",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "709FA9": {
        "oui_hex": "70-9F-A9",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "0C01DB": {
        "oui_hex": "0C-01-DB",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "08C5E1": {
        "oui_hex": "08-C5-E1",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "1866C7": {
        "oui_hex": "18-66-C7",
        "organization": "Shenzhen Libre Technology Co., Ltd",
        "address_1": "634, Tian Hui Building #B, You Song Lu, Long Hua District",
        "address_2": "Shenzhen    511700",
        "country": "CN"
    },
    "5CB3F6": {
        "oui_hex": "5C-B3-F6",
        "organization": "Human, Incorporated",
        "address_1": "3100 Airport Way S, 25-512",
        "address_2": "Seattle  WA  98134",
        "country": "US"
    },
    "2C4835": {
        "oui_hex": "2C-48-35",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "482AE3": {
        "oui_hex": "48-2A-E3",
        "organization": "Wistron InfoComm(Kunshan)Co.,Ltd.",
        "address_1": "168# First Avenue,Kunshan Integrated Free Trade Zone,Kunshan,Jiangsu,China",
        "address_2": "Kunshan  Jiangsu  215300",
        "country": "CN"
    },
    "FCA6CD": {
        "oui_hex": "FC-A6-CD",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "44C874": {
        "oui_hex": "44-C8-74",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "74C14F": {
        "oui_hex": "74-C1-4F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B0EB57": {
        "oui_hex": "B0-EB-57",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1869DA": {
        "oui_hex": "18-69-DA",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "F85C4D": {
        "oui_hex": "F8-5C-4D",
        "organization": "Nokia",
        "address_1": "1 Robbins Road",
        "address_2": "Westford  MA  01886-4113",
        "country": "US"
    },
    "2C584F": {
        "oui_hex": "2C-58-4F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F04B3A": {
        "oui_hex": "F0-4B-3A",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "54BF64": {
        "oui_hex": "54-BF-64",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "A85B6C": {
        "oui_hex": "A8-5B-6C",
        "organization": "Robert Bosch Gmbh, CM-CI2",
        "address_1": "Renningen",
        "address_2": "Stuttgart    D-70465",
        "country": "DE"
    },
    "C8B1EE": {
        "oui_hex": "C8-B1-EE",
        "organization": "Qorvo",
        "address_1": "1 Changi Business Park Crescent, Avenue 1, #04-01",
        "address_2": "NA    486058",
        "country": "SG"
    },
    "00FCBA": {
        "oui_hex": "00-FC-BA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00CBB4": {
        "oui_hex": "00-CB-B4",
        "organization": "SHENZHEN ATEKO PHOTOELECTRICITY CO.,LTD",
        "address_1": "4-5F,E1 Building,TCL International E City,No.1001 Zhongshanyuan Road,Nanshan District,Shenzhen",
        "address_2": "SHENZHEN  GUANGDONG  518052",
        "country": "CN"
    },
    "4CC00A": {
        "oui_hex": "4C-C0-0A",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "9CE82B": {
        "oui_hex": "9C-E8-2B",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "7079B3": {
        "oui_hex": "70-79-B3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D818D3": {
        "oui_hex": "D8-18-D3",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "149B2F": {
        "oui_hex": "14-9B-2F",
        "organization": "JiangSu ZhongXie Intelligent Technology co., LTD",
        "address_1": "Room 201,building 15, 16,FengJi set avenue (C08),YuHua district economic development zone ,NanJing city,JiangSu province,China,PRC.",
        "address_2": "NanJing   JiangSu   210000",
        "country": "CN"
    },
    "3835FB": {
        "oui_hex": "38-35-FB",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "48DD9D": {
        "oui_hex": "48-DD-9D",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "A075EA": {
        "oui_hex": "A0-75-EA",
        "organization": "BoxLock, Inc.",
        "address_1": "931 Monroe Dr Ste A 102-405",
        "address_2": "Atlanta  GA  30308",
        "country": "US"
    },
    "F04CD5": {
        "oui_hex": "F0-4C-D5",
        "organization": "Maxlinear, Inc",
        "address_1": "5966 La Place Ct. Ste# 100",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "0001AE": {
        "oui_hex": "00-01-AE",
        "organization": "Trex Enterprises",
        "address_1": "590 Lipoa Parkway",
        "address_2": "Kihei  HI  96753",
        "country": "US"
    },
    "00E009": {
        "oui_hex": "00-E0-09",
        "organization": "Stratus Technologies",
        "address_1": "5 Mill and Main Place, Suite 500",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "E4EA83": {
        "oui_hex": "E4-EA-83",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "74EC42": {
        "oui_hex": "74-EC-42",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D4FC13": {
        "oui_hex": "D4-FC-13",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "807D3A": {
        "oui_hex": "80-7D-3A",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "ECAF97": {
        "oui_hex": "EC-AF-97",
        "organization": "GIT",
        "address_1": "05655, GIT Bldg., 87, Macheon-ro, Songpa-gu, Seoul, Korea",
        "address_2": "Songpa-gu  Seoul  05655",
        "country": "KR"
    },
    "A0B045": {
        "oui_hex": "A0-B0-45",
        "organization": "Halong Mining",
        "address_1": "13/F TCL Tower,  No.8 Tai Chung Road",
        "address_2": "Tsuen Wan New Territories    Tsuen Wan New Territories",
        "country": "HK"
    },
    "E0BAB4": {
        "oui_hex": "E0-BA-B4",
        "organization": "Arrcus, Inc",
        "address_1": "2077 Gateway Pl, Suite 250,",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "589B0B": {
        "oui_hex": "58-9B-0B",
        "organization": "Shineway Technologies, Inc.",
        "address_1": "Floor 5, Huanxing Building",
        "address_2": "Beijing    100191",
        "country": "CN"
    },
    "D8160A": {
        "oui_hex": "D8-16-0A",
        "organization": "Nippon Electro-Sensory Devices",
        "address_1": "Itachibori 2-5-12",
        "address_2": "Nishi-ku  Osaka  550-0012",
        "country": "JP"
    },
    "10C07C": {
        "oui_hex": "10-C0-7C",
        "organization": "Blu-ray Disc Association",
        "address_1": "4444 Riverside Drive #103",
        "address_2": "Burbank  California  91505",
        "country": "US"
    },
    "40A677": {
        "oui_hex": "40-A6-77",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E4B021": {
        "oui_hex": "E4-B0-21",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C7F57": {
        "oui_hex": "9C-7F-57",
        "organization": "UNIC Memory Technology Co Ltd",
        "address_1": "15/F, Building B, Truth Plaza, No.7 Zhichun Road",
        "address_2": "Beijing  Haidian District  102208",
        "country": "CN"
    },
    "B4E01D": {
        "oui_hex": "B4-E0-1D",
        "organization": "CONCEPTION ELECTRONIQUE",
        "address_1": "3 boulevard de l'europe",
        "address_2": "NEUFCHATEL EN BRAY    76270",
        "country": "FR"
    },
    "1C0042": {
        "oui_hex": "1C-00-42",
        "organization": "NARI Technology Co., Ltd.",
        "address_1": "NO.19 Chengxin Avenue, Nanjing",
        "address_2": "Nanjing    211106",
        "country": "CN"
    },
    "4434A7": {
        "oui_hex": "44-34-A7",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3CE1A1": {
        "oui_hex": "3C-E1-A1",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Road, Sec.1,Tsao Tuen",
        "address_2": "Nan-Tou  Taiwan  54261",
        "country": "TW"
    },
    "F898EF": {
        "oui_hex": "F8-98-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "58F987": {
        "oui_hex": "58-F9-87",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8F5AC": {
        "oui_hex": "A8-F5-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "58BAD4": {
        "oui_hex": "58-BA-D4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "701D08": {
        "oui_hex": "70-1D-08",
        "organization": "99IOT Shenzhen co.,ltd",
        "address_1": "609C north block, Cangsong Building, Tairan Seven Road, Futian District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "7412BB": {
        "oui_hex": "74-12-BB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "001027": {
        "oui_hex": "00-10-27",
        "organization": "L-3 COMMUNICATIONS EAST",
        "address_1": "ONE FEDERAL STREET - A&E-3ES",
        "address_2": "CAMDEN  NJ  08102",
        "country": "US"
    },
    "BC2643": {
        "oui_hex": "BC-26-43",
        "organization": "Elprotronic Inc.",
        "address_1": "35 Austin Rumble Crt.",
        "address_2": "King City  ON  L7B0B2",
        "country": "CA"
    },
    "04E229": {
        "oui_hex": "04-E2-29",
        "organization": "Qingdao Haier Technology Co.,Ltd",
        "address_1": "Building A01,Haier Information Park, No.1 Haier Road,",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "348B75": {
        "oui_hex": "34-8B-75",
        "organization": "LAVA INTERNATIONAL(H.K) LIMITED",
        "address_1": "UNIT L 1/F MAU LAM COMM BLDG 16-18 MAU LAM ST, JORDAN KL, HK",
        "address_2": "Hong kong    999077",
        "country": "CN"
    },
    "9CE895": {
        "oui_hex": "9C-E8-95",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "00583F": {
        "oui_hex": "00-58-3F",
        "organization": "PC Aquarius",
        "address_1": "Comcity Office Park, Kievskoe shosse, est.6, bld. 1, Rumyantsevo, Moscow, 108811, RF",
        "address_2": "Moscow    108811",
        "country": "RU"
    },
    "903D68": {
        "oui_hex": "90-3D-68",
        "organization": "G-Printec, Inc.",
        "address_1": "Kawasaki Tech Center 5F, 580-16, Horikawacho",
        "address_2": "Saiwai-ku, Kawasaki-shi  Kanagawa  212-0013",
        "country": "JP"
    },
    "1094BB": {
        "oui_hex": "10-94-BB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "781D4A": {
        "oui_hex": "78-1D-4A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "94E1AC": {
        "oui_hex": "94-E1-AC",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "34E894": {
        "oui_hex": "34-E8-94",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F86FC1": {
        "oui_hex": "F8-6F-C1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28FF3C": {
        "oui_hex": "28-FF-3C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F099B6": {
        "oui_hex": "F0-99-B6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88E9FE": {
        "oui_hex": "88-E9-FE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38892C": {
        "oui_hex": "38-89-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "749EAF": {
        "oui_hex": "74-9E-AF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "94BF2D": {
        "oui_hex": "94-BF-2D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68CAE4": {
        "oui_hex": "68-CA-E4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00BE3B": {
        "oui_hex": "00-BE-3B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CA177": {
        "oui_hex": "7C-A1-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "242E02": {
        "oui_hex": "24-2E-02",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "78B6EC": {
        "oui_hex": "78-B6-EC",
        "organization": "Scuf Gaming International LLC",
        "address_1": "3970 Johns Creek Court Suite 325 Suwanee",
        "address_2": "Atlanta  GA  30024",
        "country": "US"
    },
    "8035C1": {
        "oui_hex": "80-35-C1",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "58B3FC": {
        "oui_hex": "58-B3-FC",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "2047DA": {
        "oui_hex": "20-47-DA",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "2429FE": {
        "oui_hex": "24-29-FE",
        "organization": "KYOCERA Corporation",
        "address_1": "30 Hoji",
        "address_2": "Kitami,  Hokkaido  099-1595",
        "country": "JP"
    },
    "7C49EB": {
        "oui_hex": "7C-49-EB",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "C43306": {
        "oui_hex": "C4-33-06",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "08DFCB": {
        "oui_hex": "08-DF-CB",
        "organization": "Systrome Networks",
        "address_1": "Sohna Road",
        "address_2": "Gurgaon  Haryana  122018",
        "country": "IN"
    },
    "A4933F": {
        "oui_hex": "A4-93-3F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "28AC9E": {
        "oui_hex": "28-AC-9E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2CB8ED": {
        "oui_hex": "2C-B8-ED",
        "organization": "SonicWall",
        "address_1": "5455 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "68D482": {
        "oui_hex": "68-D4-82",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "984562": {
        "oui_hex": "98-45-62",
        "organization": "Shanghai Baud Data Communication Co.,Ltd.",
        "address_1": "NO.123 JULI RD",
        "address_2": "PUDONG ZHANGJIANG HIGH-TECH PARK  SHANGHAI  201203",
        "country": "CN"
    },
    "E4C483": {
        "oui_hex": "E4-C4-83",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "001FBA": {
        "oui_hex": "00-1F-BA",
        "organization": "Boyoung Tech",
        "address_1": "Youngdeungpo-Gu Munrae3ga 84-2",
        "address_2": "Seoul    150-093",
        "country": "KR"
    },
    "A433D7": {
        "oui_hex": "A4-33-D7",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "B0ACD2": {
        "oui_hex": "B0-AC-D2",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "200F70": {
        "oui_hex": "20-0F-70",
        "organization": "FOXTECH",
        "address_1": "152-160 City Road",
        "address_2": "LONDON  KEMP HOUSE  EC1V 2NX",
        "country": "GB"
    },
    "202D23": {
        "oui_hex": "20-2D-23",
        "organization": "Collinear Networks Inc.",
        "address_1": "2901 Tasman Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "90834B": {
        "oui_hex": "90-83-4B",
        "organization": "BEIJING YUNYI TIMES TECHNOLOGY CO,.LTD",
        "address_1": "1-411Room 19#Building No.26 Xihuan South Rd. BDA Daxing District,",
        "address_2": "BEIJING    100176",
        "country": "CN"
    },
    "18502A": {
        "oui_hex": "18-50-2A",
        "organization": "SOARNEX",
        "address_1": "NO.158, RUIHU ST., NEIHU DIST.,",
        "address_2": "TAIPEI CITY  TAIWAN (R.O.C.)  11494",
        "country": "TW"
    },
    "A8367A": {
        "oui_hex": "A8-36-7A",
        "organization": "frogblue TECHNOLOGY GmbH",
        "address_1": "Luxemburger Straße 6",
        "address_2": "Kaiserslautern  Rheinland-Pfalz  67657",
        "country": "DE"
    },
    "6CE4DA": {
        "oui_hex": "6C-E4-DA",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "2-3 Kandatsukasamachi",
        "address_2": "Chiyodaku  Tokyo  101-8532",
        "country": "JP"
    },
    "10E7C6": {
        "oui_hex": "10-E7-C6",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "1831BF": {
        "oui_hex": "18-31-BF",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "C8FAE1": {
        "oui_hex": "C8-FA-E1",
        "organization": "ARQ Digital LLC",
        "address_1": "2430 Auto Park Way",
        "address_2": "Escondido  CA  92029",
        "country": "US"
    },
    "DCA333": {
        "oui_hex": "DC-A3-33",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "788C54": {
        "oui_hex": "78-8C-54",
        "organization": "Ping Communication",
        "address_1": "Brenden 18",
        "address_2": "Appenzell Meistersrüte  AI  9050",
        "country": "CH"
    },
    "B8AF67": {
        "oui_hex": "B8-AF-67",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "C098DA": {
        "oui_hex": "C0-98-DA",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "F00FEC": {
        "oui_hex": "F0-0F-EC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC075F": {
        "oui_hex": "AC-07-5F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C048E6": {
        "oui_hex": "C0-48-E6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "882E5A": {
        "oui_hex": "88-2E-5A",
        "organization": "storONE",
        "address_1": "POB 2660",
        "address_2": "Ra'anana",
        "country": "IL"
    },
    "007147": {
        "oui_hex": "00-71-47",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "00BE75": {
        "oui_hex": "00-BE-75",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "64DB8B": {
        "oui_hex": "64-DB-8B",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "78257A": {
        "oui_hex": "78-25-7A",
        "organization": "LEO Innovation Lab",
        "address_1": "Silkegade 8",
        "address_2": "Copenhagen K  Denmark  1113",
        "country": "DK"
    },
    "10A4B9": {
        "oui_hex": "10-A4-B9",
        "organization": "Baidu Online Network Technology (Beijing) Co., Ltd",
        "address_1": "Baidu Campus, No.10 Shangdi 10th Street, Haidian District",
        "address_2": " Beijing    100085",
        "country": "CN"
    },
    "501CB0": {
        "oui_hex": "50-1C-B0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "04AC44": {
        "oui_hex": "04-AC-44",
        "organization": "Holtek Semiconductor Inc.",
        "address_1": "No.3, Creation Rd. II, Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "F4DCA5": {
        "oui_hex": "F4-DC-A5",
        "organization": "DAWON DNS",
        "address_1": "217ho, Sauphwajiwon-dong, KETI, 226, Cheomdangwagi-ro, Buk-gu",
        "address_2": "Gwangju    61011",
        "country": "KR"
    },
    "80CE62": {
        "oui_hex": "80-CE-62",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "801F12": {
        "oui_hex": "80-1F-12",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "506CBE": {
        "oui_hex": "50-6C-BE",
        "organization": "InnosiliconTechnology Ltd",
        "address_1": "WuHan East Lake Wuhan New Technology Development Zone",
        "address_2": "Wuhan  Hubei Province  430223",
        "country": "CN"
    },
    "247E12": {
        "oui_hex": "24-7E-12",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "04C241": {
        "oui_hex": "04-C2-41",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "3C479B": {
        "oui_hex": "3C-47-9B",
        "organization": "Theissen Training Systems, Inc.",
        "address_1": "1225 SE 4th Terrace",
        "address_2": "Chiefland  FL  32626",
        "country": "US"
    },
    "606BFF": {
        "oui_hex": "60-6B-FF",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "8CF710": {
        "oui_hex": "8C-F7-10",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "307BAC": {
        "oui_hex": "30-7B-AC",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "785DC8": {
        "oui_hex": "78-5D-C8",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "3C0461": {
        "oui_hex": "3C-04-61",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "883D24": {
        "oui_hex": "88-3D-24",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "E8C1B8": {
        "oui_hex": "E8-C1-B8",
        "organization": " Nanjing Bangzhong Electronic Commerce Limited",
        "address_1": "No.22, Liuzhou East Road, High - tech Zone",
        "address_2": "Nanjing    210000",
        "country": "CN"
    },
    "D8D775": {
        "oui_hex": "D8-D7-75",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "E8330D": {
        "oui_hex": "E8-33-0D",
        "organization": "Xaptec GmbH",
        "address_1": "Neidenburger Str. 10",
        "address_2": "Gelsenkirchen    45897",
        "country": "DE"
    },
    "D460E3": {
        "oui_hex": "D4-60-E3",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "B4A8B9": {
        "oui_hex": "B4-A8-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "50DCE7": {
        "oui_hex": "50-DC-E7",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "649829": {
        "oui_hex": "64-98-29",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "081DC4": {
        "oui_hex": "08-1D-C4",
        "organization": "Thermo Fisher Scientific Messtechnik GmbH",
        "address_1": "Frauenauracher Strasse 96",
        "address_2": "Erlangen    91056",
        "country": "DE"
    },
    "785364": {
        "oui_hex": "78-53-64",
        "organization": "SHIFT GmbH",
        "address_1": "Am Gänsemarkt 6",
        "address_2": "Wabern Falkenberg  Hessen  34590",
        "country": "DE"
    },
    "38E60A": {
        "oui_hex": "38-E6-0A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "40CBC0": {
        "oui_hex": "40-CB-C0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C4618B": {
        "oui_hex": "C4-61-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC6EA4": {
        "oui_hex": "CC-6E-A4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "803A59": {
        "oui_hex": "80-3A-59",
        "organization": "AT&T",
        "address_1": "1025 Lenox Park Blvd",
        "address_2": "Atlanta  GA  30319",
        "country": "US"
    },
    "588D64": {
        "oui_hex": "58-8D-64",
        "organization": "Xi'an Clevbee Technology Co.,Ltd",
        "address_1": "FLOOR 7, TOWER B, POSCO CENTER, NO. 13 ZONE FOUR WANGJING EAST PARK, CHAOYANG DISTRICT, BEIJING",
        "address_2": "Beijing    100012",
        "country": "CN"
    },
    "005D73": {
        "oui_hex": "00-5D-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "606D3C": {
        "oui_hex": "60-6D-3C",
        "organization": "Luxshare Precision Industry Company Limited",
        "address_1": "Floor 2, Block A, Sanyo New Industrial Area",
        "address_2": "West Haoyi Community, Shajing Subdistrict Office  Bao'an District, Shenzhen, Guangdong  523000",
        "country": "CN"
    },
    "44F034": {
        "oui_hex": "44-F0-34",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "884-3, Seongnam-daero, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13517",
        "country": "KR"
    },
    "002790": {
        "oui_hex": "00-27-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "34BA38": {
        "oui_hex": "34-BA-38",
        "organization": "PAL MOHAN ELECTRONICS PVT LTD",
        "address_1": "40 DLF, INDUSTRIAL AREA, KIRTI NAGAR",
        "address_2": "NEW DELHI  DELHI  110015",
        "country": "IN"
    },
    "9829A6": {
        "oui_hex": "98-29-A6",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "CC4D38": {
        "oui_hex": "CC-4D-38",
        "organization": "Carnegie Technologies",
        "address_1": "9737 Great Hills Trail #260",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "08E689": {
        "oui_hex": "08-E6-89",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC56E7": {
        "oui_hex": "DC-56-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A816D0": {
        "oui_hex": "A8-16-D0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A46CF1": {
        "oui_hex": "A4-6C-F1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "08AED6": {
        "oui_hex": "08-AE-D6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DCBFE9": {
        "oui_hex": "DC-BF-E9",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "B42D56": {
        "oui_hex": "B4-2D-56",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "4064A4": {
        "oui_hex": "40-64-A4",
        "organization": "THE FURUKAWA ELECTRIC CO., LTD",
        "address_1": "2-2-3,Marunouchi",
        "address_2": "Chiyoda-ku  Tokyo  100-8322",
        "country": "JP"
    },
    "6CB2AE": {
        "oui_hex": "6C-B2-AE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B0982B": {
        "oui_hex": "B0-98-2B",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "34FA9F": {
        "oui_hex": "34-FA-9F",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F065C2": {
        "oui_hex": "F0-65-C2",
        "organization": "Yanfeng Visteon Electronics Technology (Shanghai) Co.,Ltd.",
        "address_1": "1001 North Qin Zhou Road",
        "address_2": "Shang Hai    200233",
        "country": "CN"
    },
    "70B7E2": {
        "oui_hex": "70-B7-E2",
        "organization": "Jiangsu Miter Technology Co.,Ltd.",
        "address_1": "No.86 fuyuan community,the town of houbei",
        "address_2": "Jurong  Jiangsu  212400",
        "country": "CN"
    },
    "808DB7": {
        "oui_hex": "80-8D-B7",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "A09D86": {
        "oui_hex": "A0-9D-86",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "00C0FF": {
        "oui_hex": "00-C0-FF",
        "organization": "Seagate Cloud Systems Inc",
        "address_1": "6305 El Camino Real",
        "address_2": "Carlsbad  CA  92009",
        "country": "US"
    },
    "D45DDF": {
        "oui_hex": "D4-5D-DF",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "F8B568": {
        "oui_hex": "F8-B5-68",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2C6B7D": {
        "oui_hex": "2C-6B-7D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "88D171": {
        "oui_hex": "88-D1-71",
        "organization": "BEGHELLI S.P.A",
        "address_1": "VIA MOZZEGHINE 13/15",
        "address_2": "LOCALITA' MONTEVEGLIO - COMUNE VALSAMOGGIA  BOLOGNA  40053",
        "country": "IT"
    },
    "A09DC1": {
        "oui_hex": "A0-9D-C1",
        "organization": "China Dragon Technology Limited",
        "address_1": "B4 Bldg.Haoshan 1st Industry Park,",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "2C4205": {
        "oui_hex": "2C-42-05",
        "organization": "Lytx",
        "address_1": "9785 Towne Centre Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A825EB": {
        "oui_hex": "A8-25-EB",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "5/F,Building 8, 2388 ChenHang Road, MinHang District",
        "address_2": "shanghai    201114",
        "country": "CN"
    },
    "34E380": {
        "oui_hex": "34-E3-80",
        "organization": "Genexis B.V.",
        "address_1": "Lodewijkstraat 1A",
        "address_2": "Eindhoven    5652AC",
        "country": "NL"
    },
    "5C5819": {
        "oui_hex": "5C-58-19",
        "organization": "Jingsheng Technology Co., Ltd.",
        "address_1": "Linyin street 5#",
        "address_2": "chengdu  sichuan  610000",
        "country": "CN"
    },
    "B8CA04": {
        "oui_hex": "B8-CA-04",
        "organization": "Holtek Semiconductor Inc.",
        "address_1": "No.3, Creation Rd. II, Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "C4C563": {
        "oui_hex": "C4-C5-63",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "80B708": {
        "oui_hex": "80-B7-08",
        "organization": "Blue Danube Systems, Inc",
        "address_1": "3131 Jay Street, Suite 201",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "08BC20": {
        "oui_hex": "08-BC-20",
        "organization": "Hangzhou Royal Cloud Technology Co., Ltd",
        "address_1": "Hangzhou Xixi Road 957, 24, Unit 2, 302",
        "address_2": "Hangzhou    310030",
        "country": "CN"
    },
    "942A3F": {
        "oui_hex": "94-2A-3F",
        "organization": "Diversey Inc",
        "address_1": "2415 Cascade Pointe Blvd",
        "address_2": "Charlotte  NC  28208",
        "country": "US"
    },
    "2031EB": {
        "oui_hex": "20-31-EB",
        "organization": "HDSN",
        "address_1": "4 allée des roseaux",
        "address_2": "Saint mitre les remparts  BDR  13920",
        "country": "FR"
    },
    "F8C96C": {
        "oui_hex": "F8-C9-6C",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "844823": {
        "oui_hex": "84-48-23",
        "organization": "WOXTER TECHNOLOGY Co. Ltd",
        "address_1": "23F Doushiyangguang, Chegongmiao",
        "address_2": "Shenzhen    518040",
        "country": "CN"
    },
    "F41E5E": {
        "oui_hex": "F4-1E-5E",
        "organization": "RtBrick Inc.",
        "address_1": "26 Kingston Terrace",
        "address_2": "Princeton  NJ  08540",
        "country": "US"
    },
    "6C7660": {
        "oui_hex": "6C-76-60",
        "organization": "KYOCERA CORPORATION",
        "address_1": "2-1-1 Kagahara",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "002102": {
        "oui_hex": "00-21-02",
        "organization": "UpdateLogic Inc.",
        "address_1": "2 Willow Street, Suite 101",
        "address_2": "Southborough  MA  01745",
        "country": "US"
    },
    "505800": {
        "oui_hex": "50-58-00",
        "organization": "WyTec International, Inc.",
        "address_1": "19206 Huebner Rd Suite 202",
        "address_2": "San Antonio  Texas  78258",
        "country": "US"
    },
    "C8D12A": {
        "oui_hex": "C8-D1-2A",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "0CEAC9": {
        "oui_hex": "0C-EA-C9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E82A44": {
        "oui_hex": "E8-2A-44",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "10A4BE": {
        "oui_hex": "10-A4-BE",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "947BBE": {
        "oui_hex": "94-7B-BE",
        "organization": "Ubicquia",
        "address_1": "3281 Fairlane Farms Rd",
        "address_2": "Wellington   FL  33449",
        "country": "US"
    },
    "ECC06A": {
        "oui_hex": "EC-C0-6A",
        "organization": "PowerChord Group Limited",
        "address_1": "1 Blythe Road",
        "address_2": "London    W14 0HG",
        "country": "GB"
    },
    "944996": {
        "oui_hex": "94-49-96",
        "organization": "WiSilica Inc",
        "address_1": "23282 Mill Creek Dr #340",
        "address_2": "Laguna Hills  CA  92653",
        "country": "US"
    },
    "F81D0F": {
        "oui_hex": "F8-1D-0F",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "58C935": {
        "oui_hex": "58-C9-35",
        "organization": "Chiun Mai Communication Systems, Inc",
        "address_1": "No.4, Minsheng St., Tucheng District",
        "address_2": "New Taipei City    23678",
        "country": "TW"
    },
    "0094A1": {
        "oui_hex": "00-94-A1",
        "organization": "F5 Networks, Inc.",
        "address_1": "401 Elliott Ave. W.",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "BCF292": {
        "oui_hex": "BC-F2-92",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "0450DA": {
        "oui_hex": "04-50-DA",
        "organization": "Qiku Internet Network Scientific (Shenzhen) Co., Ltd",
        "address_1": "Building A2, Chi Yuen Technology Park  1001 College Avenue, Nanshan District Shenzhen, Guangdong",
        "address_2": " Shenzhen  Guangdong   518000",
        "country": "CN"
    },
    "E820E2": {
        "oui_hex": "E8-20-E2",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "0026A8": {
        "oui_hex": "00-26-A8",
        "organization": "DAEHAP HYPER-TECH",
        "address_1": "Mega center #1108, SK Techno-Park, #190-1, Sangdaewon-Dong, Jungwon-Gu",
        "address_2": "Seongnam  Gyeonggi-Do  462-807",
        "country": "KR"
    },
    "785C28": {
        "oui_hex": "78-5C-28",
        "organization": "Prime Motion Inc.",
        "address_1": "Akaho 1134-12",
        "address_2": "Komagane  Nagano  399-4117",
        "country": "JP"
    },
    "8C5BF0": {
        "oui_hex": "8C-5B-F0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1890D8": {
        "oui_hex": "18-90-D8",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "88835D": {
        "oui_hex": "88-83-5D",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "No.8, Litong Road, Liuyang Economic & Technical Development Zone",
        "address_2": "ChangSha  Hu Nan  410300",
        "country": "CN"
    },
    "EC9F0D": {
        "oui_hex": "EC-9F-0D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E078A3": {
        "oui_hex": "E0-78-A3",
        "organization": "Shanghai Winner Information Technology Co.,Inc",
        "address_1": "Lujiazui Software Park,No.190,Lane 91,Eshan Road,Pudong New Area",
        "address_2": "Shanghai  Shanghai  200127",
        "country": "CN"
    },
    "0005A7": {
        "oui_hex": "00-05-A7",
        "organization": "HYPERCHIP Inc.",
        "address_1": "180 Peel Street - Ste. #333",
        "address_2": "123    H3C 2G7",
        "country": "CA"
    },
    "088466": {
        "oui_hex": "08-84-66",
        "organization": "Novartis Pharma AG",
        "address_1": "Lichtstrasse 35",
        "address_2": "Basel    4056",
        "country": "CH"
    },
    "309FFB": {
        "oui_hex": "30-9F-FB",
        "organization": "Ardomus Networks Corporation",
        "address_1": "4F,No. 6 Innovation Road II, Hsinchu Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "282373": {
        "oui_hex": "28-23-73",
        "organization": "Digita",
        "address_1": "Jämsänkatu 2",
        "address_2": "Helsinki  Uusimaa  00520",
        "country": "FI"
    },
    "649A08": {
        "oui_hex": "64-9A-08",
        "organization": "Shenzhen SuperElectron Technology Co.,LTD",
        "address_1": "Layer 13,Haosheng Business Center,Dongbin Road,Nanshan District",
        "address_2": "Shenzhen  guangdong  518052",
        "country": "CN"
    },
    "68A682": {
        "oui_hex": "68-A6-82",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "587A62": {
        "oui_hex": "58-7A-62",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "547A52": {
        "oui_hex": "54-7A-52",
        "organization": "CTE International srl",
        "address_1": "Via Sevardi 7",
        "address_2": "Reggio Emilia    42124",
        "country": "IT"
    },
    "F06E0B": {
        "oui_hex": "F0-6E-0B",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND    98052",
        "country": "US"
    },
    "346FED": {
        "oui_hex": "34-6F-ED",
        "organization": "Enovation Controls",
        "address_1": "5311 S. 122nd E. Ave.",
        "address_2": "Tulsa  OK  74146",
        "country": "US"
    },
    "5433CB": {
        "oui_hex": "54-33-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3408BC": {
        "oui_hex": "34-08-BC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1C36BB": {
        "oui_hex": "1C-36-BB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C2EFF": {
        "oui_hex": "3C-2E-FF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00E025": {
        "oui_hex": "00-E0-25",
        "organization": "dit Co., Ltd.",
        "address_1": "Premier Toyocho Building",
        "address_2": "Koto-ku  Tokyo  135-0056",
        "country": "JP"
    },
    "AC84C6": {
        "oui_hex": "AC-84-C6",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001530": {
        "oui_hex": "00-15-30",
        "organization": "Dell EMC",
        "address_1": "176 South Street",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "0CB2B7": {
        "oui_hex": "0C-B2-B7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "24F677": {
        "oui_hex": "24-F6-77",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B0CA68": {
        "oui_hex": "B0-CA-68",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C83C85": {
        "oui_hex": "C8-3C-85",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78870D": {
        "oui_hex": "78-87-0D",
        "organization": "Unifiedgateways India Private Limited",
        "address_1": "25 1st Floor 4th Cross KR Road Jayanagar 7th Block West",
        "address_2": "Bangalore  Karnataka  560082",
        "country": "IN"
    },
    "A88200": {
        "oui_hex": "A8-82-00",
        "organization": "Hisense Electric Co.,Ltd",
        "address_1": "Qianwangang Roard 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "3820A8": {
        "oui_hex": "38-20-A8",
        "organization": "ColorTokens, Inc.",
        "address_1": "2101 Tasman Dr. Suite 200A",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "705896": {
        "oui_hex": "70-58-96",
        "organization": "InShow Technology",
        "address_1": "Jinqi Zhigu Building, Chongwen Garden, Liuxian Avenue, Nanshan District",
        "address_2": "shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "000589": {
        "oui_hex": "00-05-89",
        "organization": "National Datacomputer",
        "address_1": "900 Middlesex Tpk.",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "3CA616": {
        "oui_hex": "3C-A6-16",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "9CE063": {
        "oui_hex": "9C-E0-63",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D03169": {
        "oui_hex": "D0-31-69",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "24F27F": {
        "oui_hex": "24-F2-7F",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "BC0543": {
        "oui_hex": "BC-05-43",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "00B69F": {
        "oui_hex": "00-B6-9F",
        "organization": "Latch",
        "address_1": "450 W 33rd  St",
        "address_2": "New York  NY  10001",
        "country": "US"
    },
    "842C80": {
        "oui_hex": "84-2C-80",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "3CC079": {
        "oui_hex": "3C-C0-79",
        "organization": "Shenzhen One-Nine Intelligent Electronic Science and Technology Co., Ltd",
        "address_1": "Office 3015, Chuangxingda Business Building, No.36. Liuxian 3 Road, Baoan District",
        "address_2": "Shenzhen  Guangdong  518133",
        "country": "CN"
    },
    "98C5DB": {
        "oui_hex": "98-C5-DB",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "149F3C": {
        "oui_hex": "14-9F-3C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCEEE6": {
        "oui_hex": "FC-EE-E6",
        "organization": "FORMIKE ELECTRONIC CO., LTD",
        "address_1": "Flats 401-403, Block B, iPARK Building, 26 Dengliang Rd., NanShan Distric",
        "address_2": "Shenzhen  Guang Dong  518054",
        "country": "CN"
    },
    "84E327": {
        "oui_hex": "84-E3-27",
        "organization": "TAILYN TECHNOLOGIES INC",
        "address_1": "NO 10 RUNG-AN ROAD, LU-ZHU DISTRICT",
        "address_2": "TAOYUAN CITY  TAIWAN ROC  33852",
        "country": "TW"
    },
    "0021B8": {
        "oui_hex": "00-21-B8",
        "organization": "Inphi Corporation",
        "address_1": "112 S. Lakeview Canyon Rd., Suite 100",
        "address_2": "Westlake Village  CA  91362",
        "country": "US"
    },
    "0C9160": {
        "oui_hex": "0C-91-60",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "D8ED1C": {
        "oui_hex": "D8-ED-1C",
        "organization": "Magna Technology SL",
        "address_1": "C/Principe de Vergara, 55. 3ª planta",
        "address_2": "Madrid    28006",
        "country": "ES"
    },
    "D83134": {
        "oui_hex": "D8-31-34",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "408BF6": {
        "oui_hex": "40-8B-F6",
        "organization": "Shenzhen TCL New Technology Co., Ltd",
        "address_1": "TCL Building, #5 Central Nanhai Road, Nanshan District,",
        "address_2": "Shenzhen,  Guangdong,   518067",
        "country": "CN"
    },
    "00006B": {
        "oui_hex": "00-00-6B",
        "organization": "Silicon Graphics",
        "address_1": "2011 NORTH SHORELINE BLVD.",
        "address_2": "MOUNTAIN VIEW  CA  94039-7311",
        "country": "US"
    },
    "74373B": {
        "oui_hex": "74-37-3B",
        "organization": "UNINET Co.,Ltd.",
        "address_1": "#1803, Daerung Techno Town15, 401, Simin-daero, Dongan-gu",
        "address_2": "Anyang-si  Gyunggi-do  14057",
        "country": "KR"
    },
    "7C6456": {
        "oui_hex": "7C-64-56",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "F46E24": {
        "oui_hex": "F4-6E-24",
        "organization": "NEC Personal Computers, Ltd.",
        "address_1": "Akihabara UDX,14-1, Sotokanda 4-Chome",
        "address_2": "Chiyoda-ku  Tokyo  101-0021",
        "country": "JP"
    },
    "888279": {
        "oui_hex": "88-82-79",
        "organization": "Shenzhen RB-LINK Intelligent Technology Co.Ltd",
        "address_1": "Second floor, No 22, Wanfeng the third industry area, Shajing , BaoAn district",
        "address_2": "Shenzhen City    518125",
        "country": "CN"
    },
    "68C63A": {
        "oui_hex": "68-C6-3A",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "A0648F": {
        "oui_hex": "A0-64-8F",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "C850E9": {
        "oui_hex": "C8-50-E9",
        "organization": "Raisecom Technology CO., LTD",
        "address_1": "No. 11, East Area, No. 10 Block, East Xibeiwang Road",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "10F163": {
        "oui_hex": "10-F1-63",
        "organization": "TNK CO.,LTD",
        "address_1": "1 Kasugayama.Iitoyo",
        "address_2": "Tenei-village.Iwase-country  Fukushima-prefecture  962-0512",
        "country": "JP"
    },
    "88DA1A": {
        "oui_hex": "88-DA-1A",
        "organization": "Redpine Signals, Inc.",
        "address_1": "2107, N. First St",
        "address_2": "San Jose  CA  95131-2019",
        "country": "US"
    },
    "98EF9B": {
        "oui_hex": "98-EF-9B",
        "organization": "OHSUNG",
        "address_1": "335-4,SANHODAERO,GUMI,GYEONG BUK,KOREA",
        "address_2": "GUMI  GYEONG BUK  730-030",
        "country": "KR"
    },
    "14CF8D": {
        "oui_hex": "14-CF-8D",
        "organization": "OHSUNG",
        "address_1": "181",
        "address_2": "GUMI  KYUNGBUK  730-030",
        "country": "KR"
    },
    "104400": {
        "oui_hex": "10-44-00",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B0E17E": {
        "oui_hex": "B0-E1-7E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E4A7C5": {
        "oui_hex": "E4-A7-C5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5C8D2D": {
        "oui_hex": "5C-8D-2D",
        "organization": "Shanghai Wellpay Information Technology Co., Ltd",
        "address_1": " Loushanguan Road 523, Jin Hongqiao International Center Building, 1501",
        "address_2": "Shanghai    200000",
        "country": "CN"
    },
    "90FD9F": {
        "oui_hex": "90-FD-9F",
        "organization": "Silicon Laboratories",
        "address_1": "400 W. Cesar Chavez St.",
        "address_2": "Austin  TX  78701",
        "country": "US"
    },
    "B430C0": {
        "oui_hex": "B4-30-C0",
        "organization": "York Instruments Ltd",
        "address_1": "The Biocentre, York Science Park",
        "address_2": "York  North Yorkshire  YO10 5NY",
        "country": "GB"
    },
    "E81DA8": {
        "oui_hex": "E8-1D-A8",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F03D03": {
        "oui_hex": "F0-3D-03",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "DCF090": {
        "oui_hex": "DC-F0-90",
        "organization": "Nubia Technology Co.,Ltd.",
        "address_1": "6/F-8/F 10/F-11/F A Tower,6/F B Tower,6/F-10/F C Tower Dazu Innovation Mansion, North Ring Rd,No.9018,High-Tech Park Nanshan District",
        "address_2": "Shenzhen  Guandong  518057",
        "country": "CN"
    },
    "A0FE61": {
        "oui_hex": "A0-FE-61",
        "organization": "Vivint Wireless Inc.",
        "address_1": "4931 N 300 W",
        "address_2": "Provo  UT  84604",
        "country": "US"
    },
    "5C2BF5": {
        "oui_hex": "5C-2B-F5",
        "organization": "Vivint Wireless Inc.",
        "address_1": "4931 N 300 W",
        "address_2": "Provo  UT  84604",
        "country": "US"
    },
    "CC5A53": {
        "oui_hex": "CC-5A-53",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "006088": {
        "oui_hex": "00-60-88",
        "organization": "Analog Devices, Inc.",
        "address_1": "410 AMHERST STREET-STE #325",
        "address_2": "NASHUA  NH  03063",
        "country": "US"
    },
    "084ACF": {
        "oui_hex": "08-4A-CF",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "2C279E": {
        "oui_hex": "2C-27-9E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8C5F48": {
        "oui_hex": "8C-5F-48",
        "organization": "Continental Intelligent Transportation Systems LLC",
        "address_1": "3901 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "947EB9": {
        "oui_hex": "94-7E-B9",
        "organization": "National Narrowband Network Communications Pty Ltd",
        "address_1": "Unit 10, 1 Talavera Road",
        "address_2": "Macquarie Park  New South Wales  2113",
        "country": "AU"
    },
    "646E69": {
        "oui_hex": "64-6E-69",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "706BB9": {
        "oui_hex": "70-6B-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D4389C": {
        "oui_hex": "D4-38-9C",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "00C0EE": {
        "oui_hex": "00-C0-EE",
        "organization": "KYOCERA Display Corporation",
        "address_1": "2-14-9 TAMAGAWADAI",
        "address_2": "tokyo  158  0000",
        "country": "JP"
    },
    "245FDF": {
        "oui_hex": "24-5F-DF",
        "organization": "KYOCERA CORPORATION",
        "address_1": "2-1-1,Kagahara,",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "9C63ED": {
        "oui_hex": "9C-63-ED",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "74F661": {
        "oui_hex": "74-F6-61",
        "organization": "Schneider Electric Fire & Security Oy",
        "address_1": "Sokerilinnantie 11 C",
        "address_2": "Espoo    02650",
        "country": "FI"
    },
    "B8634D": {
        "oui_hex": "B8-63-4D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24C42F": {
        "oui_hex": "24-C4-2F",
        "organization": "Philips Lifeline",
        "address_1": "111 Lawrence st",
        "address_2": "Framingham  MA  01702",
        "country": "US"
    },
    "2CB21A": {
        "oui_hex": "2C-B2-1A",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "A4E975": {
        "oui_hex": "A4-E9-75",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3035AD": {
        "oui_hex": "30-35-AD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "844167": {
        "oui_hex": "84-41-67",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9800C6": {
        "oui_hex": "98-00-C6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC1F74": {
        "oui_hex": "AC-1F-74",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A85C2C": {
        "oui_hex": "A8-5C-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00DB70": {
        "oui_hex": "00-DB-70",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCE557": {
        "oui_hex": "FC-E5-57",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "48C58D": {
        "oui_hex": "48-C5-8D",
        "organization": "Lear Corporation GmbH",
        "address_1": "Industriestrasse 48",
        "address_2": "Kronach  Bavaria  96317",
        "country": "DE"
    },
    "00289F": {
        "oui_hex": "00-28-9F",
        "organization": "Semptian Co., Ltd.",
        "address_1": "Block 5D, 8/F, Software Industry Park, No.14, Haitian 2nd Road, GaoxinSouth, Nanshan District, Shenzhen, China",
        "address_2": "Shen Zhen  GuangDong  518061",
        "country": "CN"
    },
    "9C305B": {
        "oui_hex": "9C-30-5B",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "104E89": {
        "oui_hex": "10-4E-89",
        "organization": "Garmin International",
        "address_1": "1200 E. 151st St",
        "address_2": "Olathe  KS  66062",
        "country": "US"
    },
    "D8C497": {
        "oui_hex": "D8-C4-97",
        "organization": "Quanta Computer Inc.",
        "address_1": "No. 211, Wen-Hwa 2nd Rd.,Kuei-Shan Dist.",
        "address_2": "Taoyuan City  Taiwan  33377",
        "country": "TW"
    },
    "BCC342": {
        "oui_hex": "BC-C3-42",
        "organization": "Panasonic Communications Co., Ltd.",
        "address_1": "4-1-62 Minoshima Hakata-ku",
        "address_2": "Fukuoka city  Fukuoka  812-8531",
        "country": "JP"
    },
    "001BD3": {
        "oui_hex": "00-1B-D3",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma  Osaka  571-8504",
        "country": "JP"
    },
    "CC7EE7": {
        "oui_hex": "CC-7E-E7",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma City  Osaka  571-8504",
        "country": "JP"
    },
    "20C6EB": {
        "oui_hex": "20-C6-EB",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma  Osaka  571-8504",
        "country": "JP"
    },
    "64B5C6": {
        "oui_hex": "64-B5-C6",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "2830AC": {
        "oui_hex": "28-30-AC",
        "organization": "Frontiir Co. Ltd.",
        "address_1": "5 Bayint Naung Road, Hlaing Township",
        "address_2": "Yangon    11052",
        "country": "MM"
    },
    "D4D2E5": {
        "oui_hex": "D4-D2-E5",
        "organization": "BKAV Corporation",
        "address_1": "2nd floor - HH1 Building - Yen Hoa Urban Area, Yen Hoa Ward, Cau Giay District",
        "address_2": "HaNoi    100000",
        "country": "VN"
    },
    "0050B5": {
        "oui_hex": "00-50-B5",
        "organization": "FICHET SECURITE ELECTRONIQUE",
        "address_1": "15-17 AVE. MORANE-SAULNIER",
        "address_2": "",
        "country": "FR"
    },
    "001439": {
        "oui_hex": "00-14-39",
        "organization": "Blonder Tongue Laboratories, Inc",
        "address_1": "One Jake Brown Road",
        "address_2": "Old Bridge    08857",
        "country": "US"
    },
    "20A6CD": {
        "oui_hex": "20-A6-CD",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "84802D": {
        "oui_hex": "84-80-2D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001987": {
        "oui_hex": "00-19-87",
        "organization": "Panasonic Mobile Communications Co.,Ltd.",
        "address_1": "600 Saedo-cho, Tsuzuki-ku,",
        "address_2": "Yokohama City  Kanagawa Prefecture  224-8539",
        "country": "JP"
    },
    "741C27": {
        "oui_hex": "74-1C-27",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "00A0AC": {
        "oui_hex": "00-A0-AC",
        "organization": "GILAT SATELLITE NETWORKS, LTD.",
        "address_1": "24A HABARZEL STREET",
        "address_2": "",
        "country": "IL"
    },
    "002609": {
        "oui_hex": "00-26-09",
        "organization": "Phyllis Co., Ltd.",
        "address_1": "9th Fl., Room 3/4, No. 52, Sec. 2, Chung Shan North Road,",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "28F537": {
        "oui_hex": "28-F5-37",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "94D9B3": {
        "oui_hex": "94-D9-B3",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C84029": {
        "oui_hex": "C8-40-29",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "F86EEE": {
        "oui_hex": "F8-6E-EE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7802B1": {
        "oui_hex": "78-02-B1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B40F3B": {
        "oui_hex": "B4-0F-3B",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "00188D": {
        "oui_hex": "00-18-8D",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    1790",
        "country": "DK"
    },
    "0015AB": {
        "oui_hex": "00-15-AB",
        "organization": "PRO CO SOUND INC",
        "address_1": "225 PARSONS STREET",
        "address_2": "KALAMAZOO  MICHIGAN  49008",
        "country": "US"
    },
    "5876C5": {
        "oui_hex": "58-76-C5",
        "organization": "DIGI I'S LTD",
        "address_1": "31, Takahata, Maesawa",
        "address_2": "Oshu  Iwate  029-4204",
        "country": "JP"
    },
    "A8B2DA": {
        "oui_hex": "A8-B2-DA",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "001354": {
        "oui_hex": "00-13-54",
        "organization": "Zcomax Technologies, Inc.",
        "address_1": "98 Ford Road",
        "address_2": "Denville  NJ  07834",
        "country": "US"
    },
    "78D800": {
        "oui_hex": "78-D8-00",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0835B2": {
        "oui_hex": "08-35-B2",
        "organization": "CoreEdge Networks Co., Ltd",
        "address_1": "#806 G Plus Tower, 123, Digital-ro 26gil, Guro-gu",
        "address_2": "Seoul    08390",
        "country": "KR"
    },
    "4C49E3": {
        "oui_hex": "4C-49-E3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "245880": {
        "oui_hex": "24-58-80",
        "organization": "VIZEO",
        "address_1": "13 rue Emile Decorps",
        "address_2": "Villeurbanne    69100",
        "country": "FR"
    },
    "54666C": {
        "oui_hex": "54-66-6C",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "A89675": {
        "oui_hex": "A8-96-75",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "389AF6": {
        "oui_hex": "38-9A-F6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E0AA96": {
        "oui_hex": "E0-AA-96",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "507705": {
        "oui_hex": "50-77-05",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "28D436": {
        "oui_hex": "28-D4-36",
        "organization": "Jiangsu dewosi electric co., LTD",
        "address_1": "Dantu district fengjingchengbang  xibanya 503, building 6",
        "address_2": "Zhenjiang  Jiangsu  212028",
        "country": "CN"
    },
    "D4B27A": {
        "oui_hex": "D4-B2-7A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "44EA4B": {
        "oui_hex": "44-EA-4B",
        "organization": "Actlas Inc.",
        "address_1": "2-2-32, Asahikawa,",
        "address_2": "Yokote  Akita  013-0033",
        "country": "JP"
    },
    "C4CB6B": {
        "oui_hex": "C4-CB-6B",
        "organization": "Airista Flow, Inc.",
        "address_1": "913 Ridgebrook Road Suite 110",
        "address_2": "Sparks  MD  21152",
        "country": "US"
    },
    "188090": {
        "oui_hex": "18-80-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "786256": {
        "oui_hex": "78-62-56",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B05508": {
        "oui_hex": "B0-55-08",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B875C0": {
        "oui_hex": "B8-75-C0",
        "organization": "PayPal, Inc.",
        "address_1": "2211 North 1st Street",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "001C71": {
        "oui_hex": "00-1C-71",
        "organization": "Emergent Electronics",
        "address_1": "Bldg 2 Level 3 Suite 305",
        "address_2": "Sewickley  PA  15143",
        "country": "US"
    },
    "001A93": {
        "oui_hex": "00-1A-93",
        "organization": "ERCO Leuchten GmbH",
        "address_1": "Brockhauser Weg 80-82",
        "address_2": "Lüdenscheid  NRW  D-58507",
        "country": "DE"
    },
    "94F665": {
        "oui_hex": "94-F6-65",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B090D4": {
        "oui_hex": "B0-90-D4",
        "organization": "Shenzhen Hoin Internet Technology Co., Ltd",
        "address_1": "Xusheng Building, No. 4004, Bao’an, Room 1616 Bao’an District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C0BAE6": {
        "oui_hex": "C0-BA-E6",
        "organization": "Application Solutions (Electronics and Vision) Ltd",
        "address_1": "The Riverside Centre",
        "address_2": "Lewes  East Sussex  BN7 2AQ",
        "country": "GB"
    },
    "8C9F3B": {
        "oui_hex": "8C-9F-3B",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "0014B8": {
        "oui_hex": "00-14-B8",
        "organization": "Hill-Rom",
        "address_1": "1125 E. Pearl Street",
        "address_2": "Batesville  IN  47006",
        "country": "US"
    },
    "ACED5C": {
        "oui_hex": "AC-ED-5C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "842096": {
        "oui_hex": "84-20-96",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B4C170": {
        "oui_hex": "B4-C1-70",
        "organization": "Yi chip Microelectronics (Hangzhou) Co., Ltd",
        "address_1": "Suite 401, Building #13, No. 498 Guoshoujing Rd., Pudong",
        "address_2": "Shanghai    201210",
        "country": "CN"
    },
    "AC6706": {
        "oui_hex": "AC-67-06",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "044FAA": {
        "oui_hex": "04-4F-AA",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "589396": {
        "oui_hex": "58-93-96",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001F41": {
        "oui_hex": "00-1F-41",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C4108A": {
        "oui_hex": "C4-10-8A",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F0B052": {
        "oui_hex": "F0-B0-52",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "70DF2F": {
        "oui_hex": "70-DF-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3894E0": {
        "oui_hex": "38-94-E0",
        "organization": "Syrotech Networks. Ltd.",
        "address_1": "UNIT NO.-5 20F, KIN WING INDUSTERIAL BUILDING,33 KIN WING STREET",
        "address_2": "TUEN MUN    999077",
        "country": "HK"
    },
    "34F64B": {
        "oui_hex": "34-F6-4B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F46BEF": {
        "oui_hex": "F4-6B-EF",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "10CDB6": {
        "oui_hex": "10-CD-B6",
        "organization": "Essential Products, Inc.",
        "address_1": "380 Portage Avenue",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "A4F3E7": {
        "oui_hex": "A4-F3-E7",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "E43A6E": {
        "oui_hex": "E4-3A-6E",
        "organization": "Shenzhen Zeroone Technology CO.,LTD",
        "address_1": "9/F.,Building B Tianan Cyber Park ,North Huangge Road,Longgang District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "7CE2CA": {
        "oui_hex": "7C-E2-CA",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "9061AE": {
        "oui_hex": "90-61-AE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6CF9D2": {
        "oui_hex": "6C-F9-D2",
        "organization": "CHENGDU POVODO ELECTRONIC TECHNOLOGY CO., LTD",
        "address_1": "High - West West West Center Road on the 4th",
        "address_2": " Chengdu   Sichuan  611731",
        "country": "CN"
    },
    "30B62D": {
        "oui_hex": "30-B6-2D",
        "organization": " Mojo Networks, Inc.",
        "address_1": "339 N.Bernardo Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "50184C": {
        "oui_hex": "50-18-4C",
        "organization": "Platina Systems Inc.",
        "address_1": "3180 De La Cruz Blvd. Ste# 110",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "F4B7B3": {
        "oui_hex": "F4-B7-B3",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "CC03D9": {
        "oui_hex": "CC-03-D9",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "FCA667": {
        "oui_hex": "FC-A6-67",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "C81FEA": {
        "oui_hex": "C8-1F-EA",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "0027E3": {
        "oui_hex": "00-27-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0018AE": {
        "oui_hex": "00-18-AE",
        "organization": "TVT CO.,LTD",
        "address_1": "5/F,North Block,CE Lighting House",
        "address_2": "shenzhen  guangdong  518026",
        "country": "CN"
    },
    "8891DD": {
        "oui_hex": "88-91-DD",
        "organization": "Racktivity",
        "address_1": "Hertstokweg 5",
        "address_2": "Ternat  Flanders  1741",
        "country": "BE"
    },
    "1C4593": {
        "oui_hex": "1C-45-93",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "90EC50": {
        "oui_hex": "90-EC-50",
        "organization": "C.O.B.O. SPA",
        "address_1": "via Tito Speri, 10",
        "address_2": "Leno  Brescia  25024",
        "country": "IT"
    },
    "E0D848": {
        "oui_hex": "E0-D8-48",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "60271C": {
        "oui_hex": "60-27-1C",
        "organization": "VIDEOR E. Hartig GmbH",
        "address_1": "Carl-Zeiss-Straße 8",
        "address_2": "Rödermark  Hessen  63322",
        "country": "DE"
    },
    "00EC0A": {
        "oui_hex": "00-EC-0A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C8D7B0": {
        "oui_hex": "C8-D7-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "6C60EB": {
        "oui_hex": "6C-60-EB",
        "organization": "ZHI YUAN ELECTRONICS CO., LIMITED",
        "address_1": "UNIT 2508A 25/F BANK OF AMERICA TOWER， 12 HARCOURT RD CENTRAL",
        "address_2": "HONGKONG    999077",
        "country": "HK"
    },
    "74DADA": {
        "oui_hex": "74-DA-DA",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "D8F1F0": {
        "oui_hex": "D8-F1-F0",
        "organization": "Pepxim International Limited",
        "address_1": "A5, 5/F, HK Spinners Industrial Building, Phase 6",
        "address_2": "Cheung Sha Wan  Hong Kong  0",
        "country": "HK"
    },
    "DCC8F5": {
        "oui_hex": "DC-C8-F5",
        "organization": "Shanghai UMEinfo CO.,LTD.",
        "address_1": "16/F,Building B ,NO.15 Changyi Road ,Baoshan District,",
        "address_2": "Shanghai    200441",
        "country": "CN"
    },
    "88D7F6": {
        "oui_hex": "88-D7-F6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "9097F3": {
        "oui_hex": "90-97-F3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C1C68": {
        "oui_hex": "7C-1C-68",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C087EB": {
        "oui_hex": "C0-87-EB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "04714B": {
        "oui_hex": "04-71-4B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2C41A1": {
        "oui_hex": "2C-41-A1",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "4C38D8": {
        "oui_hex": "4C-38-D8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "447BBB": {
        "oui_hex": "44-7B-BB",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "9C7BD2": {
        "oui_hex": "9C-7B-D2",
        "organization": "NEOLAB Convergence",
        "address_1": "4F Yujung bldg.,",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "D0F88C": {
        "oui_hex": "D0-F8-8C",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "2CB115": {
        "oui_hex": "2C-B1-15",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "10D07A": {
        "oui_hex": "10-D0-7A",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "D4C1C8": {
        "oui_hex": "D4-C1-C8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "88D274": {
        "oui_hex": "88-D2-74",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "002449": {
        "oui_hex": "00-24-49",
        "organization": "Shen Zhen Lite Star Electronics Technology Co., Ltd",
        "address_1": "Xinghong Science Park,1st Ind.Area,",
        "address_2": "ShenZhen  GuangDong  518102",
        "country": "CN"
    },
    "00E18C": {
        "oui_hex": "00-E1-8C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "847933": {
        "oui_hex": "84-79-33",
        "organization": "profichip GmbH",
        "address_1": "Einsteinstrasse 6",
        "address_2": "Herzogenaurach    91074",
        "country": "DE"
    },
    "881544": {
        "oui_hex": "88-15-44",
        "organization": "Cisco Meraki",
        "address_1": "660 Alabama St",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "C4ABB2": {
        "oui_hex": "C4-AB-B2",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "80B234": {
        "oui_hex": "80-B2-34",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "44B412": {
        "oui_hex": "44-B4-12",
        "organization": "SIUS AG",
        "address_1": "Im Langhag 1",
        "address_2": "Effretikon    8307",
        "country": "CH"
    },
    "0CB912": {
        "oui_hex": "0C-B9-12",
        "organization": "JM-DATA GmbH",
        "address_1": "Hackl-Str. 1",
        "address_2": "Traun  Upper Austria  4050",
        "country": "AT"
    },
    "3CA308": {
        "oui_hex": "3C-A3-08",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F43E61": {
        "oui_hex": "F4-3E-61",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "2F Baiying Building",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "B4417A": {
        "oui_hex": "B4-41-7A",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "4F,Baiying Building, No.1019,Nanhai RD,Shekou",
        "address_2": "ShenZhen  GuangDong  518067",
        "country": "CN"
    },
    "185207": {
        "oui_hex": "18-52-07",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "000062": {
        "oui_hex": "00-00-62",
        "organization": "BULL HN INFORMATION SYSTEMS",
        "address_1": "300 CONCORD ROAD M/S 864A",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "E8C1D7": {
        "oui_hex": "E8-C1-D7",
        "organization": "Philips",
        "address_1": "TussenDiepen 4",
        "address_2": "Drachten  Friesland  9206 AD",
        "country": "NL"
    },
    "4C8120": {
        "oui_hex": "4C-81-20",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "28A6DB": {
        "oui_hex": "28-A6-DB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "14A0F8": {
        "oui_hex": "14-A0-F8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C8F86D": {
        "oui_hex": "C8-F8-6D",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "6045CB": {
        "oui_hex": "60-45-CB",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "00118B": {
        "oui_hex": "00-11-8B",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "00E0B1": {
        "oui_hex": "00-E0-B1",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "00E0DA": {
        "oui_hex": "00-E0-DA",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "CALABASAS  CA  91301",
        "country": "US"
    },
    "F8BE0D": {
        "oui_hex": "F8-BE-0D",
        "organization": "A2UICT Co.,Ltd.",
        "address_1": "1202, OWNER'S TOWER, 28,",
        "address_2": "Hwangsaeul-ro 200 beon-gil, Bundang-gu,  Seongnam-si, Gyeonggi-do  13595",
        "country": "KR"
    },
    "E442A6": {
        "oui_hex": "E4-42-A6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3C678C": {
        "oui_hex": "3C-67-8C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D4503F": {
        "oui_hex": "D4-50-3F",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "388C50": {
        "oui_hex": "38-8C-50",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "DC0856": {
        "oui_hex": "DC-08-56",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Rd",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "1CDA27": {
        "oui_hex": "1C-DA-27",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "90F305": {
        "oui_hex": "90-F3-05",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "4095BD": {
        "oui_hex": "40-95-BD",
        "organization": "NTmore.Co.,Ltd",
        "address_1": "38, Heungan-daero 427 beon-gil, Dongan-gu",
        "address_2": "Anyang  Gyeonggi  431-801",
        "country": "KR"
    },
    "98AAFC": {
        "oui_hex": "98-AA-FC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "00143F": {
        "oui_hex": "00-14-3F",
        "organization": "Hotway Technology Corporation",
        "address_1": "3F.-4, No.81, Sec. 1, Xintai 5th Rd.",
        "address_2": "Xizhi Dist.  New Taipei City  22101",
        "country": "TW"
    },
    "D055B2": {
        "oui_hex": "D0-55-B2",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "144FD7": {
        "oui_hex": "14-4F-D7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B85510": {
        "oui_hex": "B8-55-10",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "A1&A2 Building,Lantian Technology Park, Xinyu Road, Xingqiao Henggang Block, Shajing Street,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "049573": {
        "oui_hex": "04-95-73",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F0D7AA": {
        "oui_hex": "F0-D7-AA",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "F8FF0B": {
        "oui_hex": "F8-FF-0B",
        "organization": "Electronic Technology Inc.",
        "address_1": "511 Lyons Ave",
        "address_2": "Irvington  NJ  07111",
        "country": "US"
    },
    "7C6BF7": {
        "oui_hex": "7C-6B-F7",
        "organization": "NTI co., ltd.",
        "address_1": "5th floor takei building 2-19-6",
        "address_2": "taito  taito-ku , Tokyo  1100016",
        "country": "JP"
    },
    "00D318": {
        "oui_hex": "00-D3-18",
        "organization": "SPG Controls",
        "address_1": "Blue gates business park Stortford road",
        "address_2": "Dunmow  Essex  CM61SN",
        "country": "GB"
    },
    "3096FB": {
        "oui_hex": "30-96-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4827EA": {
        "oui_hex": "48-27-EA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C787E": {
        "oui_hex": "7C-78-7E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "245BA7": {
        "oui_hex": "24-5B-A7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70F087": {
        "oui_hex": "70-F0-87",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0C63C": {
        "oui_hex": "E0-C6-3C",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "000C46": {
        "oui_hex": "00-0C-46",
        "organization": "Allied Telesyn Inc.",
        "address_1": "960 Stewart Drive, Suite B",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "001F72": {
        "oui_hex": "00-1F-72",
        "organization": "QingDao Hiphone Technology Co,.Ltd",
        "address_1": "NO.106,JiangXi Road",
        "address_2": "QingDao  ShanDong  266071",
        "country": "CN"
    },
    "002365": {
        "oui_hex": "00-23-65",
        "organization": "Insta Elektro GmbH",
        "address_1": "Hohe Steinert 10",
        "address_2": "Luedenscheid  NRW  58509",
        "country": "DE"
    },
    "6091F3": {
        "oui_hex": "60-91-F3",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "28395E": {
        "oui_hex": "28-39-5E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "38295A": {
        "oui_hex": "38-29-5A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "88E628": {
        "oui_hex": "88-E6-28",
        "organization": "Shenzhen Kezhonglong Optoelectronic Technology Co.,Ltd",
        "address_1": "Floor 3, Bldg. 5, Area B, Xinfu Industrial Park, Chongqing Rd., Baoan Dist,Shenzhen,Guangdong, China",
        "address_2": "Shenzhen   Guangdong  518103",
        "country": "CN"
    },
    "58238C": {
        "oui_hex": "58-23-8C",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "CC82EB": {
        "oui_hex": "CC-82-EB",
        "organization": "KYOCERA CORPORATION",
        "address_1": " 2-1-1,Kagahara, Tsuzuki-ku,",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "14987D": {
        "oui_hex": "14-98-7D",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "D4CF37": {
        "oui_hex": "D4-CF-37",
        "organization": "Symbolic IO",
        "address_1": "101 Crawfords Corner Rd.",
        "address_2": "Holmdel  NJ  07733",
        "country": "US"
    },
    "D47DFC": {
        "oui_hex": "D4-7D-FC",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "409F38": {
        "oui_hex": "40-9F-38",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "BC2F3D": {
        "oui_hex": "BC-2F-3D",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "40FA7F": {
        "oui_hex": "40-FA-7F",
        "organization": "Preh Car Connect GmbH",
        "address_1": "Gewerbepark 5",
        "address_2": "Dresden    01156",
        "country": "DE"
    },
    "000DBB": {
        "oui_hex": "00-0D-BB",
        "organization": "Nippon Dentsu Co.,Ltd.",
        "address_1": "2-21-1,Isoji",
        "address_2": "Osaka    552-0003",
        "country": "JP"
    },
    "2C7E81": {
        "oui_hex": "2C-7E-81",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "407D0F": {
        "oui_hex": "40-7D-0F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "68CC6E": {
        "oui_hex": "68-CC-6E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3034D2": {
        "oui_hex": "30-34-D2",
        "organization": "Availink, Inc.",
        "address_1": "Scotia Centre P.O. Box 268GT,Grand Cayman, Cayman Islands",
        "address_2": "Grand Cayman  Grand Cayman  999159",
        "country": "KY"
    },
    "504061": {
        "oui_hex": "50-40-61",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "00108E": {
        "oui_hex": "00-10-8E",
        "organization": "HUGH SYMONS CONCEPT Technologies Ltd.",
        "address_1": "Alder Hills Park",
        "address_2": "Poole, Dorset BM12 4AR",
        "country": "GB"
    },
    "E05163": {
        "oui_hex": "E0-51-63",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "54E3F6": {
        "oui_hex": "54-E3-F6",
        "organization": "Alcatel-Lucent",
        "address_1": "777 East Middlefield Road",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "40B034": {
        "oui_hex": "40-B0-34",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "B816DB": {
        "oui_hex": "B8-16-DB",
        "organization": "CHANT SINCERE CO.,LTD",
        "address_1": "7F-2,NO.188,SEC.3,TA TUNG ROAD",
        "address_2": "XIZHI DISTRICT, NEW TAIPEI CITY  TAIWAN,ROC  22103",
        "country": "TW"
    },
    "40B4CD": {
        "oui_hex": "40-B4-CD",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "D481D7": {
        "oui_hex": "D4-81-D7",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "F42B48": {
        "oui_hex": "F4-2B-48",
        "organization": "Ubiqam",
        "address_1": "15 Gonen",
        "address_2": "Petah Tiqva    4925915",
        "country": "IL"
    },
    "50F14A": {
        "oui_hex": "50-F1-4A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "04DEF2": {
        "oui_hex": "04-DE-F2",
        "organization": "Shenzhen ECOM Technology Co. Ltd",
        "address_1": "Longhua Street Qinghu Community Longhu Junhui Fashion Apartment",
        "address_2": " Longhua New District, Shenzhen  Guangdong  518012",
        "country": "CN"
    },
    "78C1A7": {
        "oui_hex": "78-C1-A7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4C7872": {
        "oui_hex": "4C-78-72",
        "organization": "Cav. Uff. Giacomo Cimberio S.p.A.",
        "address_1": "Via Torchio, 57",
        "address_2": "San Maurizio d'Opaglio  (Novara)  28017",
        "country": "IT"
    },
    "8CF5A3": {
        "oui_hex": "8C-F5-A3",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "8CC8F4": {
        "oui_hex": "8C-C8-F4",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F483E1": {
        "oui_hex": "F4-83-E1",
        "organization": "Shanghai Clouder Semiconductor Co.,Ltd",
        "address_1": "Room515,No.8,Wuzhong Rd,Xuhui District",
        "address_2": "Shanghai  Shanghai  200336",
        "country": "CN"
    },
    "083E5D": {
        "oui_hex": "08-3E-5D",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "3CBD3E": {
        "oui_hex": "3C-BD-3E",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "641A22": {
        "oui_hex": "64-1A-22",
        "organization": "Heliospectra AB",
        "address_1": "Frans Perssons väg 6",
        "address_2": "",
        "country": "SE"
    },
    "A084CB": {
        "oui_hex": "A0-84-CB",
        "organization": "SonicSensory,Inc.",
        "address_1": "1161 Logan St",
        "address_2": "Los Angeles  CA  90026",
        "country": "US"
    },
    "D47AE2": {
        "oui_hex": "D4-7A-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "6854FD": {
        "oui_hex": "68-54-FD",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0003BC": {
        "oui_hex": "00-03-BC",
        "organization": "COT GmbH",
        "address_1": "Güterstraße 5",
        "address_2": "",
        "country": "DE"
    },
    "D4B169": {
        "oui_hex": "D4-B1-69",
        "organization": "Le Shi Zhi Xin Electronic Technology (Tianjin) Limited",
        "address_1": ",Le Shi Building, No.105 Yaojiayuan Road,Chaoyang District,Beijing,China",
        "address_2": "beijing  beijing  100025",
        "country": "CN"
    },
    "E44790": {
        "oui_hex": "E4-47-90",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "38454C": {
        "oui_hex": "38-45-4C",
        "organization": "Light Labs, Inc.",
        "address_1": "636 Ramona St.",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "000A49": {
        "oui_hex": "00-0A-49",
        "organization": "F5 Networks, Inc.",
        "address_1": "401 Elliott Ave. W.",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "00A0C8": {
        "oui_hex": "00-A0-C8",
        "organization": "Adtran Inc",
        "address_1": "901 EXPLORER BLVD.",
        "address_2": "HUNTSVILLE  AL  35806-2807",
        "country": "US"
    },
    "F49651": {
        "oui_hex": "F4-96-51",
        "organization": "NAKAYO Inc",
        "address_1": "1-3-2, Soja-machi",
        "address_2": "Maebashi-shi  Gunma  371-0853",
        "country": "JP"
    },
    "446246": {
        "oui_hex": "44-62-46",
        "organization": "Comat AG",
        "address_1": "Bernstrasse 4",
        "address_2": "Worb    3076",
        "country": "CH"
    },
    "34FCB9": {
        "oui_hex": "34-FC-B9",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "70918F": {
        "oui_hex": "70-91-8F",
        "organization": "Weber-Stephen Products LLC",
        "address_1": "1415 S. Roselle Rd",
        "address_2": "Palatine  IL  60067",
        "country": "US"
    },
    "D8E0E1": {
        "oui_hex": "D8-E0-E1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "7C1015": {
        "oui_hex": "7C-10-15",
        "organization": "Brilliant Home Technology, Inc.",
        "address_1": "762 Judith Ct",
        "address_2": "Incline Village  NV  89451",
        "country": "US"
    },
    "D8C771": {
        "oui_hex": "D8-C7-71",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E02A82": {
        "oui_hex": "E0-2A-82",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "B0F963": {
        "oui_hex": "B0-F9-63",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "D490E0": {
        "oui_hex": "D4-90-E0",
        "organization": "Topcon Electronics GmbH & Co. KG",
        "address_1": "Industriestraße 7",
        "address_2": "Geisenheim    65366",
        "country": "DE"
    },
    "A84041": {
        "oui_hex": "A8-40-41",
        "organization": "Dragino Technology Co., Limited",
        "address_1": "303, Block B, No 8; 349, Jian'An 1 Road,Bao'An",
        "address_2": "Shenzhen  GuangDong  518101",
        "country": "CN"
    },
    "E02202": {
        "oui_hex": "E0-22-02",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D825B0": {
        "oui_hex": "D8-25-B0",
        "organization": "Rockeetech Systems Co.,Ltd.",
        "address_1": "Unit 201, #6 Lane 51, Shuicheng S Rd.",
        "address_2": "Shanghai    201103",
        "country": "CN"
    },
    "74614B": {
        "oui_hex": "74-61-4B",
        "organization": "Chongqing Huijiatong Information Technology Co., Ltd.",
        "address_1": "Yubei District Longxi Street Hongjin Road No. 498, building  Jialeziguang No.1 12-12, 12-13, 12-13, 12-14, 12-15",
        "address_2": "Chongqing  Chongqing City  401120",
        "country": "CN"
    },
    "98D293": {
        "oui_hex": "98-D2-93",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "CCB8A8": {
        "oui_hex": "CC-B8-A8",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "1077B0": {
        "oui_hex": "10-77-B0",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "F01DBC": {
        "oui_hex": "F0-1D-BC",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "34049E": {
        "oui_hex": "34-04-9E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "94FB29": {
        "oui_hex": "94-FB-29",
        "organization": "Zebra Technologies Inc.",
        "address_1": "ONE ZEBRA PLAZA",
        "address_2": "HOLTSVILLE  NY  11742",
        "country": "US"
    },
    "B0702D": {
        "oui_hex": "B0-70-2D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C19C0": {
        "oui_hex": "6C-19-C0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00204F": {
        "oui_hex": "00-20-4F",
        "organization": "DEUTSCHE AEROSPACE AG",
        "address_1": "GESCHAEFTSFELD",
        "address_2": "  BUNDESREPUBLIK  DEUTSCHLAND",
        "country": "DE"
    },
    "00DBDF": {
        "oui_hex": "00-DB-DF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "94A04E": {
        "oui_hex": "94-A0-4E",
        "organization": "Bostex Technology Co., LTD",
        "address_1": "NO.148 West MinZhou Road",
        "address_2": "Cixi City  Zhejiang Province  315301",
        "country": "CN"
    },
    "8CE117": {
        "oui_hex": "8C-E1-17",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "688AF0": {
        "oui_hex": "68-8A-F0",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C0210D": {
        "oui_hex": "C0-21-0D",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4CE2F1": {
        "oui_hex": "4C-E2-F1",
        "organization": "sclak srl",
        "address_1": "via borgonuovo 7",
        "address_2": "milano  mi  20121",
        "country": "IT"
    },
    "504B5B": {
        "oui_hex": "50-4B-5B",
        "organization": "CONTROLtronic GmbH",
        "address_1": "Schragenhofstr. 35",
        "address_2": "Munich    80992",
        "country": "DE"
    },
    "B47447": {
        "oui_hex": "B4-74-47",
        "organization": "CoreOS",
        "address_1": "PO Box 7775 #55097",
        "address_2": "San Francisco  CA  94120-7775",
        "country": "US"
    },
    "80D4A5": {
        "oui_hex": "80-D4-A5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "04B0E7": {
        "oui_hex": "04-B0-E7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "446A2E": {
        "oui_hex": "44-6A-2E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0C8DDB": {
        "oui_hex": "0C-8D-DB",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "B0EE7B": {
        "oui_hex": "B0-EE-7B",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "AC587B": {
        "oui_hex": "AC-58-7B",
        "organization": "JCT Healthcare",
        "address_1": "1/25 London Road",
        "address_2": "Mile End South  South Australia  5031",
        "country": "AU"
    },
    "1062EB": {
        "oui_hex": "10-62-EB",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "000894": {
        "oui_hex": "00-08-94",
        "organization": "InnoVISION Multimedia Ltd.",
        "address_1": "Rm 608, 6/F Tins Enterprises Centre,",
        "address_2": "Kowloon,",
        "country": "HK"
    },
    "480033": {
        "oui_hex": "48-00-33",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "A06FAA": {
        "oui_hex": "A0-6F-AA",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "0026AB": {
        "oui_hex": "00-26-AB",
        "organization": "Seiko Epson Corporation",
        "address_1": "3-3-5 OWA",
        "address_2": "SUWA-SHI  NAGANO-KEN  392-8502",
        "country": "JP"
    },
    "FC10C6": {
        "oui_hex": "FC-10-C6",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "2C6FC9": {
        "oui_hex": "2C-6F-C9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "58EF68": {
        "oui_hex": "58-EF-68",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  null  90094",
        "country": "US"
    },
    "000B4F": {
        "oui_hex": "00-0B-4F",
        "organization": "Verifone",
        "address_1": "2099 Gateway Place",
        "address_2": "San Jose    95110",
        "country": "US"
    },
    "60C798": {
        "oui_hex": "60-C7-98",
        "organization": "Verifone",
        "address_1": "2455 Augustine Drive",
        "address_2": "Santa Clara  California  95054",
        "country": ""
    },
    "C8662C": {
        "oui_hex": "C8-66-2C",
        "organization": "Beijing Haitai Fangyuan High Technology Co,.Ltd.",
        "address_1": "B1st&2nd  floor,Unit E，NO.9 Building,Zhongguancun Software Park,Dongbeiwang West Road 8.Haidian District,Beijing",
        "address_2": "Bei Jing    100094",
        "country": "CN"
    },
    "8096CA": {
        "oui_hex": "80-96-CA",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "186571": {
        "oui_hex": "18-65-71",
        "organization": "Top Victory Electronics (Taiwan) Co., Ltd.",
        "address_1": "14F,No.166,Jian 1st Rd",
        "address_2": "New Taipei City  Taiwan  23511",
        "country": "TW"
    },
    "F83F51": {
        "oui_hex": "F8-3F-51",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "50D753": {
        "oui_hex": "50-D7-53",
        "organization": "CONELCOM GmbH",
        "address_1": "Trientlgasse 18c",
        "address_2": "Innsbruck    6020",
        "country": "AT"
    },
    "0CC47A": {
        "oui_hex": "0C-C4-7A",
        "organization": "Super Micro Computer, Inc.",
        "address_1": "980 Rock Avenue",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "34D270": {
        "oui_hex": "34-D2-70",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "50795B": {
        "oui_hex": "50-79-5B",
        "organization": "Interexport Telecomunicaciones S.A.",
        "address_1": "Cerro Colorado 5240 piso 14",
        "address_2": "Santiago  Region Metropolitana  8320000",
        "country": "US"
    },
    "0016D9": {
        "oui_hex": "00-16-D9",
        "organization": "NINGBO BIRD CO.,LTD.",
        "address_1": "No.999 Dacheng East Road",
        "address_2": "Fenghua  Zhejiang  315500",
        "country": "CN"
    },
    "6CA7FA": {
        "oui_hex": "6C-A7-FA",
        "organization": "YOUNGBO ENGINEERING INC.",
        "address_1": "132, Haewian-gil, Dunpo-myeon",
        "address_2": "Asan-si  Chungcheongnam-do  336-873",
        "country": "KR"
    },
    "8C7EB3": {
        "oui_hex": "8C-7E-B3",
        "organization": "Lytro, Inc.",
        "address_1": "1300  Terra Bella Avenue",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "B4B384": {
        "oui_hex": "B4-B3-84",
        "organization": "ShenZhen Figigantic Electronic Co.,Ltd",
        "address_1": "5F NO.1 Bld East,Guole Industrial Zone,Lirong Road,Longhua New",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "7828CA": {
        "oui_hex": "78-28-CA",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "00C003": {
        "oui_hex": "00-C0-03",
        "organization": "GLOBALNET COMMUNICATIONS",
        "address_1": "912, PLACE TRANS CANADA",
        "address_2": "CANADA  J4G  2M1",
        "country": "CA"
    },
    "00234A": {
        "oui_hex": "00-23-4A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "2C402B": {
        "oui_hex": "2C-40-2B",
        "organization": "Smart iBlue Technology Limited",
        "address_1": "Unit 12, 10/F., Hong Man Industrial Centre,2 Hong Man Street, Chai Wan, Hong Kong",
        "address_2": "Hong Kong    000",
        "country": "HK"
    },
    "5C6B4F": {
        "oui_hex": "5C-6B-4F",
        "organization": "Hello Inc.",
        "address_1": "438 Shotwell Street",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "2C9924": {
        "oui_hex": "2C-99-24",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D058A8": {
        "oui_hex": "D0-58-A8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D071C4": {
        "oui_hex": "D0-71-C4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A0CC2B": {
        "oui_hex": "A0-CC-2B",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "5001D9": {
        "oui_hex": "50-01-D9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00271C": {
        "oui_hex": "00-27-1C",
        "organization": "MERCURY CORPORATION",
        "address_1": "90, Gajaeul-ro, Seo-gu",
        "address_2": "INCHEON    22830",
        "country": "KR"
    },
    "E0D9E3": {
        "oui_hex": "E0-D9-E3",
        "organization": "Eltex Enterprise Ltd.",
        "address_1": "Okruzhnaya st. 29v",
        "address_2": "Novosibirsk    630020",
        "country": "RU"
    },
    "805EC0": {
        "oui_hex": "80-5E-C0",
        "organization": "YEALINK(XIAMEN) NETWORK TECHNOLOGY CO.,LTD.",
        "address_1": "309, 3th Floor, No.16, Yun Ding North Road, Huli District",
        "address_2": "xiamen  Fujian  361015",
        "country": "CN"
    },
    "007B18": {
        "oui_hex": "00-7B-18",
        "organization": "SENTRY Co., LTD.",
        "address_1": "792,Pyeongcheon-ro,Wonmi-gu",
        "address_2": "Bucheon-si, Gyeonggi-do    420-805",
        "country": "KR"
    },
    "144D67": {
        "oui_hex": "14-4D-67",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "A1&A2 Building,Lantian Technology Park, Xinyu Road, Xingqiao Henggang Block, Shajing Street, Baoan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4CE173": {
        "oui_hex": "4C-E1-73",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0CD86C": {
        "oui_hex": "0C-D8-6C",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "049790": {
        "oui_hex": "04-97-90",
        "organization": "Lartech telecom LLC",
        "address_1": "Bolshoi Sampsonievski 68, lit. N, office 237",
        "address_2": "Saint-Petersburg    194100",
        "country": "RU"
    },
    "28EED3": {
        "oui_hex": "28-EE-D3",
        "organization": "Shenzhen Super D Technology Co., Ltd",
        "address_1": "Room 201 , Building A former Qianhai Shenzhen-Hong Kong cooperation zone Shenzhen Bay all the way to No. 1 ( settled in Shenzhen Qianhai Business Secretary , Ltd. )",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "24C44A": {
        "oui_hex": "24-C4-4A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "98541B": {
        "oui_hex": "98-54-1B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1C40E8": {
        "oui_hex": "1C-40-E8",
        "organization": "SHENZHEN PROGRESS&WIN TECHNOLOGY CO.,LTD",
        "address_1": "9F, K1 Mall, Xinsha street, Shajing District, Baoan",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0023D2": {
        "oui_hex": "00-23-D2",
        "organization": "Inhand Electronics, Inc.",
        "address_1": "30 West Gude Drive",
        "address_2": "Rockville  Maryland  20850",
        "country": "US"
    },
    "DC0B34": {
        "oui_hex": "DC-0B-34",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "404E36": {
        "oui_hex": "40-4E-36",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "A8E705": {
        "oui_hex": "A8-E7-05",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "9840BB": {
        "oui_hex": "98-40-BB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "0060D6": {
        "oui_hex": "00-60-D6",
        "organization": "NovAtel Inc.",
        "address_1": "SUITE 200, 6715-8TH STREET NE",
        "address_2": "CALGARY, ALBERTA T2E 8M4    0000",
        "country": "CA"
    },
    "503AA0": {
        "oui_hex": "50-3A-A0",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B0958E": {
        "oui_hex": "B0-95-8E",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C025E9": {
        "oui_hex": "C0-25-E9",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "802AA8": {
        "oui_hex": "80-2A-A8",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "F09FC2": {
        "oui_hex": "F0-9F-C2",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "188B15": {
        "oui_hex": "18-8B-15",
        "organization": "ShenZhen ZhongRuiJing Technology co.,LTD",
        "address_1": "4th Floor,Building 3,Meng Liyuan Industrial Park, Yousong Road, Longhua New District,Shenzhen,Guangdong Province,China",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "788A20": {
        "oui_hex": "78-8A-20",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "886B0F": {
        "oui_hex": "88-6B-0F",
        "organization": "Bluegiga Technologies OY",
        "address_1": "P.O. BOX 120",
        "address_2": "FIN-02631  Espoo",
        "country": "FI"
    },
    "AC84C9": {
        "oui_hex": "AC-84-C9",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "245CBF": {
        "oui_hex": "24-5C-BF",
        "organization": "NCSE",
        "address_1": "Future of China Electronics Science & Technology",
        "address_2": "Beijing  Changping District  102200",
        "country": "CN"
    },
    "2C3361": {
        "oui_hex": "2C-33-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60A4D0": {
        "oui_hex": "60-A4-D0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "008701": {
        "oui_hex": "00-87-01",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5C9960": {
        "oui_hex": "5C-99-60",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C62AB": {
        "oui_hex": "9C-62-AB",
        "organization": "Sumavision Technologies Co.,Ltd",
        "address_1": "6F, Block A2, Power Creative Building,No.1 Shangdi East Road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "C8F946": {
        "oui_hex": "C8-F9-46",
        "organization": "LOCOSYS Technology Inc.",
        "address_1": "20F.-13, No. 79, Sec. 1, Xintai 5th Rd, Xizhi Dist.",
        "address_2": "New Taipei City  Taiwan  22101",
        "country": "TW"
    },
    "487B6B": {
        "oui_hex": "48-7B-6B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "883FD3": {
        "oui_hex": "88-3F-D3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "240D65": {
        "oui_hex": "24-0D-65",
        "organization": "Shenzhen Vsun Communication Technology Co., Ltd.",
        "address_1": "3/F., 19 Block, Wisdomland Business Park, No.2 Nantou Gateway Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "000B14": {
        "oui_hex": "00-0B-14",
        "organization": "ViewSonic Corporation",
        "address_1": "381 Brea Canyon Road",
        "address_2": "Walnut  California  91789",
        "country": "US"
    },
    "C8028F": {
        "oui_hex": "C8-02-8F",
        "organization": "Nova Electronics (Shanghai) Co., Ltd.",
        "address_1": "Room B706, 7th Floor, MET Plaza, No.268 Tongxie Road",
        "address_2": "Shanghai  Changning District  200335",
        "country": "CN"
    },
    "A46011": {
        "oui_hex": "A4-60-11",
        "organization": "Verifone",
        "address_1": "2099 Gateway Place",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "5CA933": {
        "oui_hex": "5C-A9-33",
        "organization": "Luma Home",
        "address_1": "75 5th St",
        "address_2": "Atlanta  GA  30308",
        "country": "US"
    },
    "00137E": {
        "oui_hex": "00-13-7E",
        "organization": "CorEdge Networks, Inc.",
        "address_1": "7600 Boone Ave N",
        "address_2": "Brooklyn Park  MN  55428",
        "country": "US"
    },
    "D814D6": {
        "oui_hex": "D8-14-D6",
        "organization": "SURE SYSTEM Co Ltd",
        "address_1": "Bakurou-machi 4-7-5",
        "address_2": "Cyuou-ku  Osaka  541-0059",
        "country": "JP"
    },
    "6CEFC6": {
        "oui_hex": "6C-EF-C6",
        "organization": "SHENZHEN TWOWING TECHNOLOGIES CO.,LTD.",
        "address_1": "Nangang Industrial Building, Tangtou Industrial Park, Shiyan, Baoan",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "101DC0": {
        "oui_hex": "10-1D-C0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002341": {
        "oui_hex": "00-23-41",
        "organization": "Vanderbilt International (SWE) AB",
        "address_1": "Englundavaegen 7",
        "address_2": "Solna    SE-171 41",
        "country": "SE"
    },
    "407C7D": {
        "oui_hex": "40-7C-7D",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "24590B": {
        "oui_hex": "24-59-0B",
        "organization": "White Sky Inc. Limited",
        "address_1": "Floor 5, Building 1, No. 6, Lane 365, Xinhua Road",
        "address_2": "Shanghai    200052",
        "country": "CN"
    },
    "68EBAE": {
        "oui_hex": "68-EB-AE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "444E1A": {
        "oui_hex": "44-4E-1A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "143365": {
        "oui_hex": "14-33-65",
        "organization": "TEM Mobile Limited",
        "address_1": "RM1703, North Block, Cangsong Building, Tairan 6 road, Futian District, Shenzhen.",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "801844": {
        "oui_hex": "80-18-44",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "78471D": {
        "oui_hex": "78-47-1D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A07591": {
        "oui_hex": "A0-75-91",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CDFA4": {
        "oui_hex": "0C-DF-A4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B072BF": {
        "oui_hex": "B0-72-BF",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "701DC4": {
        "oui_hex": "70-1D-C4",
        "organization": "NorthStar Battery Company, LLC",
        "address_1": "4000 Continental Way",
        "address_2": "Springfield  MO  65803",
        "country": "US"
    },
    "64DAA0": {
        "oui_hex": "64-DA-A0",
        "organization": "Robert Bosch Smart Home GmbH",
        "address_1": "Schockenriedstraße 17",
        "address_2": "Stuttgart    70565",
        "country": "DE"
    },
    "14B837": {
        "oui_hex": "14-B8-37",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "5C8613": {
        "oui_hex": "5C-86-13",
        "organization": "Beijing Zhoenet Technology Co., Ltd",
        "address_1": "Room B16,No. 8 WenHua East Road,Changping District",
        "address_2": "Beijing  Beijing  102208",
        "country": "CN"
    },
    "CC7314": {
        "oui_hex": "CC-73-14",
        "organization": "HONG KONG WHEATEK TECHNOLOGY LIMITED",
        "address_1": "Building 20，No.2277, ZuChongZhi Road, PuDong District, Shanghai",
        "address_2": "shanghai    201203",
        "country": "CN"
    },
    "B8EE65": {
        "oui_hex": "B8-EE-65",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "985BB0": {
        "oui_hex": "98-5B-B0",
        "organization": "KMDATA INC.",
        "address_1": "505-2, Daeryung Techno Town 1cha, 18, Gasan Digital 2-ro, Geumcheon-gu",
        "address_2": "Seoul    153771",
        "country": "KR"
    },
    "E006E6": {
        "oui_hex": "E0-06-E6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "BC8556": {
        "oui_hex": "BC-85-56",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "342387": {
        "oui_hex": "34-23-87",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "002637": {
        "oui_hex": "00-26-37",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Metan dong",
        "address_2": "Suwon  Kyung-ki do  443-743",
        "country": "KR"
    },
    "002119": {
        "oui_hex": "00-21-19",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Metan 3 dong",
        "address_2": "Suwon  Kyung-gi do  443-743",
        "country": "KR"
    },
    "F4D9FB": {
        "oui_hex": "F4-D9-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu,",
        "address_2": "Suwon  Gyeonggi-do  443-742",
        "country": "KR"
    },
    "3C6200": {
        "oui_hex": "3C-62-00",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu,",
        "address_2": "Suwon-City  Gyeonggi-do  443-742",
        "country": "KR"
    },
    "C417FE": {
        "oui_hex": "C4-17-FE",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "9439E5": {
        "oui_hex": "94-39-E5",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "642737": {
        "oui_hex": "64-27-37",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A41731": {
        "oui_hex": "A4-17-31",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "5CA39D": {
        "oui_hex": "5C-A3-9D",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon    443-743",
        "country": "US"
    },
    "90187C": {
        "oui_hex": "90-18-7C",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon  KYUNGGI-DO  443-743",
        "country": "KR"
    },
    "50CCF8": {
        "oui_hex": "50-CC-F8",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "Metan Dong 314, Youngtong Gu",
        "address_2": "Suwon  Kyung-gi Do.  443-743",
        "country": "KR"
    },
    "00223B": {
        "oui_hex": "00-22-3B",
        "organization": "Communication Networks, LLC",
        "address_1": "3 Corporate Drive",
        "address_2": "Danbury  CT  06810",
        "country": "US"
    },
    "C0F8DA": {
        "oui_hex": "C0-F8-DA",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0011FF": {
        "oui_hex": "00-11-FF",
        "organization": "Digitro Tecnologia Ltda",
        "address_1": "Rua: Professora Sofia Quint de Souza, 167",
        "address_2": "Florianópolis  Santa Catarina  88085-040",
        "country": "BR"
    },
    "001B94": {
        "oui_hex": "00-1B-94",
        "organization": "T.E.M.A. S.p.A.",
        "address_1": "via della Scienza 21 A/C",
        "address_2": "Castelnuovo Rangone  Modena  41051",
        "country": "IT"
    },
    "F0F002": {
        "oui_hex": "F0-F0-02",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C0CB38": {
        "oui_hex": "C0-CB-38",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "F07BCB": {
        "oui_hex": "F0-7B-CB",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "50B7C3": {
        "oui_hex": "50-B7-C3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi  443742",
        "country": "KR"
    },
    "1C5A3E": {
        "oui_hex": "1C-5A-3E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3dong, Yeongtong-Gu",
        "address_2": "Suwon    443742",
        "country": "US"
    },
    "A02195": {
        "oui_hex": "A0-21-95",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#416, Maetan 3-dong",
        "address_2": "Suwon-si  Gyeonggi-do  443-742",
        "country": "KR"
    },
    "B07870": {
        "oui_hex": "B0-78-70",
        "organization": "Wi-NEXT, Inc.",
        "address_1": "530 Lytton Avenue",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "E47CF9": {
        "oui_hex": "E4-7C-F9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-do  443742",
        "country": "KR"
    },
    "4844F7": {
        "oui_hex": "48-44-F7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-do  443742",
        "country": "KR"
    },
    "001377": {
        "oui_hex": "00-13-77",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi  443742",
        "country": "KR"
    },
    "002454": {
        "oui_hex": "00-24-54",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi  443742",
        "country": "KR"
    },
    "E81132": {
        "oui_hex": "E8-11-32",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi  443742",
        "country": "KR"
    },
    "C06599": {
        "oui_hex": "C0-65-99",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC79AD": {
        "oui_hex": "BC-79-AD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4C3C16": {
        "oui_hex": "4C-3C-16",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0073E0": {
        "oui_hex": "00-73-E0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0017D5": {
        "oui_hex": "00-17-D5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "001E7D": {
        "oui_hex": "00-1E-7D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001DF6": {
        "oui_hex": "00-1D-F6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F008F1": {
        "oui_hex": "F0-08-F1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "58C38B": {
        "oui_hex": "58-C3-8B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00E3B2": {
        "oui_hex": "00-E3-B2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "301966": {
        "oui_hex": "30-19-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F0E77E": {
        "oui_hex": "F0-E7-7E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "94350A": {
        "oui_hex": "94-35-0A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001D25": {
        "oui_hex": "00-1D-25",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E4C1F1": {
        "oui_hex": "E4-C1-F1",
        "organization": "SHENZHEN SPOTMAU INFORMATION TECHNOLIGY CO., Ltd",
        "address_1": "10F, Block D, 5th Building, Shenzhen Software Industrial Base, Haitian 2nd Rd,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "240AC4": {
        "oui_hex": "24-0A-C4",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "343111": {
        "oui_hex": "34-31-11",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "08FD0E": {
        "oui_hex": "08-FD-0E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "041BBA": {
        "oui_hex": "04-1B-BA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "889B39": {
        "oui_hex": "88-9B-39",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E432CB": {
        "oui_hex": "E4-32-CB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC8CCD": {
        "oui_hex": "BC-8C-CD",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "D022BE": {
        "oui_hex": "D0-22-BE",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "EC9BF3": {
        "oui_hex": "EC-9B-F3",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "F409D8": {
        "oui_hex": "F4-09-D8",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "10D542": {
        "oui_hex": "10-D5-42",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A0821F": {
        "oui_hex": "A0-82-1F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F06BCA": {
        "oui_hex": "F0-6B-CA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "AC3613": {
        "oui_hex": "AC-36-13",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002611": {
        "oui_hex": "00-26-11",
        "organization": "Licera AB",
        "address_1": "Teknikringen 1C",
        "address_2": "Linköping    58330",
        "country": "SE"
    },
    "005094": {
        "oui_hex": "00-50-94",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E0B7B1": {
        "oui_hex": "E0-B7-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D82522": {
        "oui_hex": "D8-25-22",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F0038C": {
        "oui_hex": "F0-03-8C",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "18D276": {
        "oui_hex": "18-D2-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "005218": {
        "oui_hex": "00-52-18",
        "organization": "Wuxi Keboda Electron Co.Ltd",
        "address_1": "No.155 Chunhui Road, Xishan District,",
        "address_2": "Wuxi  Jiangsu  214101",
        "country": "CN"
    },
    "001E81": {
        "oui_hex": "00-1E-81",
        "organization": "CNB Technology Inc.",
        "address_1": "#701 Star Valley, 60-11 Gasan-Dong,",
        "address_2": "Seoul    153777",
        "country": "KR"
    },
    "7CA97D": {
        "oui_hex": "7C-A9-7D",
        "organization": "Objenious",
        "address_1": "20 rue de Troyon",
        "address_2": "SEVRES    92310",
        "country": "FR"
    },
    "A8A648": {
        "oui_hex": "A8-A6-48",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Jiangxi Road",
        "address_2": "Qingdao  Shandong  266071",
        "country": "CN"
    },
    "985DAD": {
        "oui_hex": "98-5D-AD",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D43639": {
        "oui_hex": "D4-36-39",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "BC282C": {
        "oui_hex": "BC-28-2C",
        "organization": "e-Smart Systems Pvt. Ltd",
        "address_1": "483 FIE, , Patparganj Industrial Area",
        "address_2": "Delhi  Delhi  110092",
        "country": "IN"
    },
    "A40DBC": {
        "oui_hex": "A4-0D-BC",
        "organization": "Xiamen Intretech Inc.",
        "address_1": " FL 7 NO 588 JIAHE RD TORCH CARDEN HIGH-TECH ZONE",
        "address_2": "Xiamen  FUJIAN  361006",
        "country": "CN"
    },
    "84EF18": {
        "oui_hex": "84-EF-18",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "84C1C1": {
        "oui_hex": "84-C1-C1",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "A81B6A": {
        "oui_hex": "A8-1B-6A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "343DC4": {
        "oui_hex": "34-3D-C4",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "B0F893": {
        "oui_hex": "B0-F8-93",
        "organization": "Shanghai MXCHIP Information Technology Co., Ltd.",
        "address_1": "9th Floor, No. 5 Building, 2145 Jinshajiang Rd., Putuo District",
        "address_2": "Shanghai    200333",
        "country": "CN"
    },
    "C411E0": {
        "oui_hex": "C4-11-E0",
        "organization": "Bull Group Co., Ltd",
        "address_1": "No.32 Sanhai Road,East Guanhaiwei Industrial Zone, Cixi City, Zhejiang, P.R.China",
        "address_2": "Cixi  Zhejiang  315314",
        "country": "CN"
    },
    "28C87A": {
        "oui_hex": "28-C8-7A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "48FD8E": {
        "oui_hex": "48-FD-8E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C0623": {
        "oui_hex": "7C-06-23",
        "organization": "Ultra Electronics Sonar System Division",
        "address_1": "419 Bridport Road",
        "address_2": "Greenford  Middlesex  UB6 8UA",
        "country": "GB"
    },
    "28AC67": {
        "oui_hex": "28-AC-67",
        "organization": "Mach Power, Rappresentanze Internazionali s.r.l.",
        "address_1": "CUPA S.ANIELLO, 112",
        "address_2": "NAPOLI  Napoli  80146",
        "country": "IT"
    },
    "14825B": {
        "oui_hex": "14-82-5B",
        "organization": "Hefei Radio Communication Technology Co., Ltd",
        "address_1": "No.108, YinXing Road, High-tech Development Zone, Hefei, Anhui Province, China",
        "address_2": "Hefei  Anhui Province  230088",
        "country": "CN"
    },
    "641269": {
        "oui_hex": "64-12-69",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0002C9": {
        "oui_hex": "00-02-C9",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "080051": {
        "oui_hex": "08-00-51",
        "organization": "ExperData",
        "address_1": "88, RUE BRILLAT SAVARIN",
        "address_2": "0000    0000",
        "country": "FR"
    },
    "00126C": {
        "oui_hex": "00-12-6C",
        "organization": "Visonic Technologies 1993 Ltd.",
        "address_1": "24 Habarzel St.",
        "address_2": "Tel Aviv    69710",
        "country": "IL"
    },
    "AC6175": {
        "oui_hex": "AC-61-75",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "244427": {
        "oui_hex": "24-44-27",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0080C7": {
        "oui_hex": "00-80-C7",
        "organization": "XIRCOM",
        "address_1": "26025 MUREAU ROAD",
        "address_2": "CALABASAS  CA  91302",
        "country": "US"
    },
    "000138": {
        "oui_hex": "00-01-38",
        "organization": "XAVi Technologies Corp.",
        "address_1": "9F, No. 129, Hsing Te Rd,",
        "address_2": "241 TAIWAN  241 TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00166D": {
        "oui_hex": "00-16-6D",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "8/F.high Tech Plaza,TianAn Cyberpark,Chegongmiao",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "3C9157": {
        "oui_hex": "3C-91-57",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "5F Building 2,No.56,Liuhe Road,Xihu District",
        "address_2": "Hangzhou  Zhejiang  310023",
        "country": "CN"
    },
    "0000D8": {
        "oui_hex": "00-00-D8",
        "organization": "Novell, Inc.",
        "address_1": "122 EAST 1700 SOUTH M/S:E-12-1",
        "address_2": "PROVO  UT  84601",
        "country": "US"
    },
    "001F46": {
        "oui_hex": "00-1F-46",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson    75082",
        "country": "US"
    },
    "003093": {
        "oui_hex": "00-30-93",
        "organization": "Sonnet Technologies, Inc",
        "address_1": "8 Autry",
        "address_2": "Irvine,  CA  92618",
        "country": "US"
    },
    "00034B": {
        "oui_hex": "00-03-4B",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "002561": {
        "oui_hex": "00-25-61",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "008058": {
        "oui_hex": "00-80-58",
        "organization": "PRINTER SYSTEMS CORP.",
        "address_1": "207 PARRY PARKWAY",
        "address_2": "GAITHERSBURG  MD  20877",
        "country": "US"
    },
    "00157D": {
        "oui_hex": "00-15-7D",
        "organization": "POSDATA",
        "address_1": "276-2,Seohyeon-dong,Bundang-gu,",
        "address_2": "Seongnam-City  Kyeonggi-Do  463-775",
        "country": "KR"
    },
    "4849C7": {
        "oui_hex": "48-49-C7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "849866": {
        "oui_hex": "84-98-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001C9C": {
        "oui_hex": "00-1C-9C",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001B25": {
        "oui_hex": "00-1B-25",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0019E1": {
        "oui_hex": "00-19-E1",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001D42": {
        "oui_hex": "00-1D-42",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "00140D": {
        "oui_hex": "00-14-0D",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000E40": {
        "oui_hex": "00-0E-40",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "FCB0C4": {
        "oui_hex": "FC-B0-C4",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F Info-Tech Building",
        "address_2": "Shanghai  Shanghai  200092",
        "country": "CN"
    },
    "A89DD2": {
        "oui_hex": "A8-9D-D2",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F Info-Tech Building",
        "address_2": "Shanghai  Shanghai  200092",
        "country": "CN"
    },
    "00E00F": {
        "oui_hex": "00-E0-0F",
        "organization": "Shanghai Baud Data Communication Co.,Ltd.",
        "address_1": "COMMUNICATION DEVELOPMENT CORP",
        "address_2": "SHANGHAI    0000",
        "country": "CN"
    },
    "28BE03": {
        "oui_hex": "28-BE-03",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "903AE6": {
        "oui_hex": "90-3A-E6",
        "organization": "PARROT SA",
        "address_1": "174 Quai de Jemmapes",
        "address_2": "Paris    75010",
        "country": "FR"
    },
    "A098ED": {
        "oui_hex": "A0-98-ED",
        "organization": "Shandong Intelligent Optical Communication Development Co., Ltd.",
        "address_1": "No.149 Yingcui Road,Torch Town,Advanced Technique Development Area",
        "address_2": "Jining  Shandong  272023",
        "country": "CN"
    },
    "000EF4": {
        "oui_hex": "00-0E-F4",
        "organization": "Kasda Networks Inc",
        "address_1": "B-31 Building, Tanglang Industry Zone",
        "address_2": "Shenzhen  Guangdong Province  518055",
        "country": "CN"
    },
    "00167A": {
        "oui_hex": "00-16-7A",
        "organization": "Skyworth Overseas Development Ltd.",
        "address_1": "Room 1505-06,Westlands Centre",
        "address_2": "0000    0000",
        "country": "HK"
    },
    "A42940": {
        "oui_hex": "A4-29-40",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "E4A387": {
        "oui_hex": "E4-A3-87",
        "organization": "Control Solutions LLC",
        "address_1": "2520 Diehl Rd",
        "address_2": "Aurora  IL  60502",
        "country": "US"
    },
    "1880F5": {
        "oui_hex": "18-80-F5",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "10E878": {
        "oui_hex": "10-E8-78",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "10F96F": {
        "oui_hex": "10-F9-6F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "C4438F": {
        "oui_hex": "C4-43-8F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "A09169": {
        "oui_hex": "A0-91-69",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "286C07": {
        "oui_hex": "28-6C-07",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "002280": {
        "oui_hex": "00-22-80",
        "organization": "A2B Electronics AB",
        "address_1": "Box 14",
        "address_2": "Motala    S-591 21",
        "country": "SE"
    },
    "404AD4": {
        "oui_hex": "40-4A-D4",
        "organization": "Widex A/S",
        "address_1": "Nymoellevej 6",
        "address_2": "Lynge  Alleroed  DK3540",
        "country": "DK"
    },
    "9893CC": {
        "oui_hex": "98-93-CC",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1, Cheongho-ri, Jinwi-myeon",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "3CCD93": {
        "oui_hex": "3C-CD-93",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1, CHEONGHO-RI, JINWI-MYEON",
        "address_2": "PYEONGTAEK  GYEONGGI-DO  451-713",
        "country": "KR"
    },
    "2021A5": {
        "oui_hex": "20-21-A5",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "6CD68A": {
        "oui_hex": "6C-D6-8A",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "CC79CF": {
        "oui_hex": "CC-79-CF",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,Shenzhen,P.R.C",
        "address_2": "ShenZhen  Guangdong  518000",
        "country": "CN"
    },
    "001925": {
        "oui_hex": "00-19-25",
        "organization": "Intelicis Corporation",
        "address_1": "4633 Old Ironsides Drive, Suite 150",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "9476B7": {
        "oui_hex": "94-76-B7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2C54CF": {
        "oui_hex": "2C-54-CF",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "485929": {
        "oui_hex": "48-59-29",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "58A2B5": {
        "oui_hex": "58-A2-B5",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "002483": {
        "oui_hex": "00-24-83",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "001FE3": {
        "oui_hex": "00-1F-E3",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F0421C": {
        "oui_hex": "F0-42-1C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "000F62": {
        "oui_hex": "00-0F-62",
        "organization": "Alcatel Bell Space N.V.",
        "address_1": "Berkenrodelei 33",
        "address_2": "Hoboken  Antwerpen  B-2660",
        "country": "BE"
    },
    "001CD8": {
        "oui_hex": "00-1C-D8",
        "organization": "BlueAnt Wireless",
        "address_1": "245 St.Kilda Rd, St Kilda",
        "address_2": "Melbourne  Victoria  3182",
        "country": "AU"
    },
    "0019AB": {
        "oui_hex": "00-19-AB",
        "organization": "Raycom CO ., LTD",
        "address_1": "A,3-4/FL, Building 1,27 Chuangxin Road,",
        "address_2": "Beijing    102200",
        "country": "CN"
    },
    "4C334E": {
        "oui_hex": "4C-33-4E",
        "organization": "HIGHTECH",
        "address_1": "No202.gsif, 4 Gyeonggang-ro 2326 beon-gil",
        "address_2": "Gangneung-si  Gangwon-do  25570",
        "country": "KR"
    },
    "7C70BC": {
        "oui_hex": "7C-70-BC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E81863": {
        "oui_hex": "E8-18-63",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2CD141": {
        "oui_hex": "2C-D1-41",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "3C39E7": {
        "oui_hex": "3C-39-E7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "BC6641": {
        "oui_hex": "BC-66-41",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "80E4DA": {
        "oui_hex": "80-E4-DA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "885D90": {
        "oui_hex": "88-5D-90",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C88ED1": {
        "oui_hex": "C8-8E-D1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B01F81": {
        "oui_hex": "B0-1F-81",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "549A11": {
        "oui_hex": "54-9A-11",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B8D812": {
        "oui_hex": "B8-D8-12",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "1C21D1": {
        "oui_hex": "1C-21-D1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "283638": {
        "oui_hex": "28-36-38",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F485C6": {
        "oui_hex": "F4-85-C6",
        "organization": "FDT Technologies",
        "address_1": "14027 Memorial Drive #132",
        "address_2": "Houston  TX  77024",
        "country": "US"
    },
    "D404FF": {
        "oui_hex": "D4-04-FF",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C8755B": {
        "oui_hex": "C8-75-5B",
        "organization": "Quantify Technology Pty. Ltd.",
        "address_1": "Suite 1, 4 Sarich Way",
        "address_2": "Bentley  Western Australia  6102",
        "country": "AU"
    },
    "88124E": {
        "oui_hex": "88-12-4E",
        "organization": "Qualcomm Inc.",
        "address_1": "1700 Technology Drive",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "001428": {
        "oui_hex": "00-14-28",
        "organization": "Vocollect Inc",
        "address_1": "703 Rodi Road",
        "address_2": "Pittsburgh  PA  15235",
        "country": "US"
    },
    "006B9E": {
        "oui_hex": "00-6B-9E",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "4C6641": {
        "oui_hex": "4C-66-41",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "5CA86A": {
        "oui_hex": "5C-A8-6A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "001B32": {
        "oui_hex": "00-1B-32",
        "organization": "QLogic Corporation",
        "address_1": "26650 Aliso Viejo Parkway",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "0017CA": {
        "oui_hex": "00-17-CA",
        "organization": "Qisda Corporation",
        "address_1": "157 Shan Ying Road,",
        "address_2": "GueiShan  Taoyuan,  333",
        "country": "TW"
    },
    "70F395": {
        "oui_hex": "70-F3-95",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "48F7C0": {
        "oui_hex": "48-F7-C0",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "0015B7": {
        "oui_hex": "00-15-B7",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome    1988710",
        "country": "JP"
    },
    "E89D87": {
        "oui_hex": "E8-9D-87",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "E09579": {
        "oui_hex": "E0-95-79",
        "organization": "ORTHOsoft inc, d/b/a Zimmer CAS",
        "address_1": "75 Queen Street, Suite 3300",
        "address_2": "Montreal  Quebec  H3C 2N6",
        "country": "CA"
    },
    "A0ADA1": {
        "oui_hex": "A0-AD-A1",
        "organization": "JMR Electronics, Inc",
        "address_1": "8968 Fullbright Avenue",
        "address_2": "Chatsworth  California  91311",
        "country": "US"
    },
    "BCC00F": {
        "oui_hex": "BC-C0-0F",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "9CA5C0": {
        "oui_hex": "9C-A5-C0",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong  523860",
        "country": "CN"
    },
    "80C6AB": {
        "oui_hex": "80-C6-AB",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "90A4DE": {
        "oui_hex": "90-A4-DE",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsinchu Science Park,",
        "address_2": "Hsinchu     308",
        "country": "TW"
    },
    "70E284": {
        "oui_hex": "70-E2-84",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "No.38,East Keji Road,Zhongshan Torch Development Zone,Zhongshan City,Guangdong,China",
        "address_2": "Zhongshan  Guangdong  528437",
        "country": "CN"
    },
    "A854B2": {
        "oui_hex": "A8-54-B2",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsin Science Park, Hsinchu 308, Taiwan",
        "address_2": "HsinChu  Taiwan  308",
        "country": "TW"
    },
    "3044A1": {
        "oui_hex": "30-44-A1",
        "organization": "Shanghai Nanchao Information Technology",
        "address_1": "Floor 1th, building 13, No.368 Zhangjiang Road, Pudong New District, Shanghai",
        "address_2": "shanghai    200000",
        "country": "CN"
    },
    "CC03FA": {
        "oui_hex": "CC-03-FA",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "E0ACF1": {
        "oui_hex": "E0-AC-F1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00015B": {
        "oui_hex": "00-01-5B",
        "organization": "ITALTEL S.p.A/RF-UP-I",
        "address_1": "20019 Cast.Settimo M.se (MI)",
        "address_2": "",
        "country": "IT"
    },
    "00A0A8": {
        "oui_hex": "00-A0-A8",
        "organization": "RENEX CORPORATION",
        "address_1": "2750 KILLARNEY DRIVE",
        "address_2": "WOODBRIDGE  VA  22192",
        "country": "US"
    },
    "00C0AB": {
        "oui_hex": "00-C0-AB",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield  MA  02048",
        "country": "US"
    },
    "0023F8": {
        "oui_hex": "00-23-F8",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "0019CB": {
        "oui_hex": "00-19-CB",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "2C094D": {
        "oui_hex": "2C-09-4D",
        "organization": "Raptor Engineering, LLC",
        "address_1": "2556 Anderson Dr.",
        "address_2": "Belvidere  IL  61008",
        "country": "US"
    },
    "AC3743": {
        "oui_hex": "AC-37-43",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "001D7E": {
        "oui_hex": "00-1D-7E",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "E4FB8F": {
        "oui_hex": "E4-FB-8F",
        "organization": "MOBIWIRE MOBILES (NINGBO) CO.,LTD",
        "address_1": "No.999,Dacheng East Road,Fenghua City,Zhejiang Province,China.",
        "address_2": "Fenghua  Zhejiang  315500",
        "country": "CN"
    },
    "10BD55": {
        "oui_hex": "10-BD-55",
        "organization": "Q-Lab Corporation",
        "address_1": "800 Canterbury Rd",
        "address_2": "Westlake  OH  44145",
        "country": "US"
    },
    "C449BB": {
        "oui_hex": "C4-49-BB",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "FC2D5E": {
        "oui_hex": "FC-2D-5E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B40418": {
        "oui_hex": "B4-04-18",
        "organization": "Smartchip Integrated Inc.",
        "address_1": "9B,Science Plaza,1355 JinJiHu Avenue,Suzhou Industrial Park",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "90CF7D": {
        "oui_hex": "90-CF-7D",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "F40A4A": {
        "oui_hex": "F4-0A-4A",
        "organization": "INDUSNET Communication Technology Co.,LTD",
        "address_1": "3th floor A block,No11 Gaopeng st,Wuhou district",
        "address_2": "chengdu  sichuan  610041",
        "country": "CN"
    },
    "F85A00": {
        "oui_hex": "F8-5A-00",
        "organization": "Sanford LP",
        "address_1": "6655 Peachtree Dunwoody Road",
        "address_2": "Atlanta  GA  30228",
        "country": "US"
    },
    "FC55DC": {
        "oui_hex": "FC-55-DC",
        "organization": "Baltic Latvian Universal Electronics LLC",
        "address_1": "5706 Corsa Avenue Suite 102",
        "address_2": "Westlake Village  CA  91362",
        "country": "US"
    },
    "08010F": {
        "oui_hex": "08-01-0F",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "941882": {
        "oui_hex": "94-18-82",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "6038E0": {
        "oui_hex": "60-38-E0",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "8850DD": {
        "oui_hex": "88-50-DD",
        "organization": "Infiniband Trade Association",
        "address_1": "3855 SW 153rd Drive",
        "address_2": "Beaverton  OR  97003",
        "country": "US"
    },
    "002550": {
        "oui_hex": "00-25-50",
        "organization": "Riverbed Technology, Inc.",
        "address_1": "125 Cambridge Park Drive",
        "address_2": "Cambridge  MA  02140",
        "country": "US"
    },
    "D0B2C4": {
        "oui_hex": "D0-B2-C4",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "50AB3E": {
        "oui_hex": "50-AB-3E",
        "organization": "Qibixx AG",
        "address_1": "Bahnhofstrasse 2",
        "address_2": "Buchs  SG  9471",
        "country": "CH"
    },
    "3876CA": {
        "oui_hex": "38-76-CA",
        "organization": "Shenzhen Smart Intelligent Technology Co.Ltd",
        "address_1": "Gaoxin South 4th Road Hi-Tech Industry Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "042758": {
        "oui_hex": "04-27-58",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9CE374": {
        "oui_hex": "9C-E3-74",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8CD2E9": {
        "oui_hex": "8C-D2-E9",
        "organization": "YOKOTE SEIKO CO., LTD.",
        "address_1": "10-18 Minami-Gosyono Yasumoto",
        "address_2": "Yokote-City  Akita  013-0811",
        "country": "JP"
    },
    "B8BBAF": {
        "oui_hex": "B8-BB-AF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "60C5AD": {
        "oui_hex": "60-C5-AD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "442C05": {
        "oui_hex": "44-2C-05",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "8C897A": {
        "oui_hex": "8C-89-7A",
        "organization": "AUGTEK",
        "address_1": "Tuanjie Road No.100, Building C, Room 521",
        "address_2": "Nanjing  Jiangsu  211899",
        "country": "CN"
    },
    "F845AD": {
        "oui_hex": "F8-45-AD",
        "organization": "Konka Group Co., Ltd.",
        "address_1": "Shenzhen Konka R & D Building, 28th floor 15-24",
        "address_2": "Nanshan District  Guangdong  00000",
        "country": "CN"
    },
    "000FE2": {
        "oui_hex": "00-0F-E2",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "Oriental Electronic Bld., NO.2,Chuangye Road",
        "address_2": "Hai-Dian District  Beijing  100085",
        "country": "CN"
    },
    "80F62E": {
        "oui_hex": "80-F6-2E",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "608D17": {
        "oui_hex": "60-8D-17",
        "organization": "Sentrus Government Systems Division, Inc",
        "address_1": "141 Chesterfield Industrial Blvd",
        "address_2": "Chesterfield  MO  63005-1219",
        "country": "US"
    },
    "ECADB8": {
        "oui_hex": "EC-AD-B8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9801A7": {
        "oui_hex": "98-01-A7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6879ED": {
        "oui_hex": "68-79-ED",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "002382": {
        "oui_hex": "00-23-82",
        "organization": "Lih Rong electronic Enterprise Co., Ltd.",
        "address_1": "No. 2, Lane 387, Hsin Shu Rd.",
        "address_2": "Hsin Chuang City,  Taipei  242",
        "country": "TW"
    },
    "24F094": {
        "oui_hex": "24-F0-94",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "086D41": {
        "oui_hex": "08-6D-41",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B4D5BD": {
        "oui_hex": "B4-D5-BD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "98AA3C": {
        "oui_hex": "98-AA-3C",
        "organization": "Will i-tech Co., Ltd.",
        "address_1": "34, Deokcheon-ro, Manan-gu, Anyang-si, Gyeonggi-do, Korea",
        "address_2": "Anyang    14088",
        "country": "KR"
    },
    "BCAD28": {
        "oui_hex": "BC-AD-28",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "F4911E": {
        "oui_hex": "F4-91-1E",
        "organization": "ZHUHAI EWPE INFORMATION TECHNOLOGY INC",
        "address_1": "Room 409,NO.10,Technology 1st Road, Gangwan Av.,Tangjia Bay Town,Zhuhai,Guangdong,China",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "002552": {
        "oui_hex": "00-25-52",
        "organization": "VXi Corporation",
        "address_1": "271 Locust Street",
        "address_2": "Dover  NH  03820",
        "country": "US"
    },
    "6CE983": {
        "oui_hex": "6C-E9-83",
        "organization": "Gastron Co., LTD.",
        "address_1": "#75-10, Palgok2-dong, Sangnok-gu,",
        "address_2": "Ansan-city  Kyunggi-do  426-190",
        "country": "KR"
    },
    "28E31F": {
        "oui_hex": "28-E3-1F",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "989096": {
        "oui_hex": "98-90-96",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "DC3752": {
        "oui_hex": "DC-37-52",
        "organization": "GE",
        "address_1": "650 Markland Street",
        "address_2": "Markham  Ontario  L6C 0M1",
        "country": "CA"
    },
    "DCD916": {
        "oui_hex": "DC-D9-16",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00022E": {
        "oui_hex": "00-02-2E",
        "organization": "TEAC Corp. R& D",
        "address_1": "857 Koyata, Iruma",
        "address_2": "",
        "country": "JP"
    },
    "0060B0": {
        "oui_hex": "00-60-B0",
        "organization": "Hewlett Packard",
        "address_1": "MS 42LE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "7C738B": {
        "oui_hex": "7C-73-8B",
        "organization": "Cocoon Alarm Ltd",
        "address_1": "46 The Calls",
        "address_2": "Leeds  West Yorkshire  LS2 7EY",
        "country": "GB"
    },
    "F80F84": {
        "oui_hex": "F8-0F-84",
        "organization": "Natural Security SAS",
        "address_1": "165 Avenue de Bretagne",
        "address_2": "Lille    59000",
        "country": "FR"
    },
    "44A42D": {
        "oui_hex": "44-A4-2D",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "70F96D": {
        "oui_hex": "70-F9-6D",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "BC6A44": {
        "oui_hex": "BC-6A-44",
        "organization": "Commend International GmbH",
        "address_1": "Saalachstrasse 51",
        "address_2": "Salzburg  Salzburg  A-5020",
        "country": "AT"
    },
    "F0EE58": {
        "oui_hex": "F0-EE-58",
        "organization": "PACE Telematics GmbH",
        "address_1": "Haid-und-Neu-Str. 18",
        "address_2": "Karlsruhe    76131",
        "country": "DE"
    },
    "083FBC": {
        "oui_hex": "08-3F-BC",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00C0F0": {
        "oui_hex": "00-C0-F0",
        "organization": "Kingston Technology Company, Inc.",
        "address_1": "17600 NEWHOPE STREET",
        "address_2": "FOUNTAIN VALLEY  CA  92708",
        "country": "US"
    },
    "943BB1": {
        "oui_hex": "94-3B-B1",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "KAONMEDIA Building 513-4",
        "address_2": "Sungnam-City  Kyonggi-Do  463-839, KOREA",
        "country": "KR"
    },
    "0018D7": {
        "oui_hex": "00-18-D7",
        "organization": "JAVAD GNSS, Inc.",
        "address_1": "1731 Technology Drive, Suite 680",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "001F09": {
        "oui_hex": "00-1F-09",
        "organization": "Jastec",
        "address_1": "Jastec B/D 2F, 92-7 Kumgok-dong,",
        "address_2": "Boondang-gu,    463-804",
        "country": "KR"
    },
    "AC620D": {
        "oui_hex": "AC-62-0D",
        "organization": "Jabil Circuit(Wuxi) Co.,Ltd",
        "address_1": "Lot J9, J10 Export Processing Zone",
        "address_2": "Wuxi City  Jiangsu  214028",
        "country": "CN"
    },
    "08000D": {
        "oui_hex": "08-00-0D",
        "organization": "International Computers, Ltd",
        "address_1": "WENLOCK WAY",
        "address_2": "na  UNITED  KINGDOM",
        "country": "GB"
    },
    "1C7370": {
        "oui_hex": "1C-73-70",
        "organization": "Neotech",
        "address_1": "104, 37 Yaeun-ro",
        "address_2": "Gumi-si  Gyoungsangbuk-do  730-711",
        "country": "KR"
    },
    "30E37A": {
        "oui_hex": "30-E3-7A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0000C9": {
        "oui_hex": "00-00-C9",
        "organization": "Emulex Corporation",
        "address_1": "3333 Susan Street",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "0040AA": {
        "oui_hex": "00-40-AA",
        "organization": "Valmet Automation",
        "address_1": "Lentokentänkatu 11, P.O.Box 237",
        "address_2": "Tampere    FIN-3310",
        "country": "FI"
    },
    "D0B0CD": {
        "oui_hex": "D0-B0-CD",
        "organization": "Moen",
        "address_1": "25300 Al Moen Dr",
        "address_2": "North Olmstead  OH  44070-8022",
        "country": "US"
    },
    "7050AF": {
        "oui_hex": "70-50-AF",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "F4EF9E": {
        "oui_hex": "F4-EF-9E",
        "organization": "SGSG SCIENCE & TECHNOLOGY CO. LTD",
        "address_1": "3RD Fl, Bldg A3, No.1 software Park Rd",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "1C740D": {
        "oui_hex": "1C-74-0D",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "603ECA": {
        "oui_hex": "60-3E-CA",
        "organization": "Cambridge Medical Robotics Ltd",
        "address_1": "Unit 2, Crome Lea Business Park",
        "address_2": "Madingley Road  Cambridgeshire  CB23 7PH",
        "country": "GB"
    },
    "001F1F": {
        "oui_hex": "00-1F-1F",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "00020E": {
        "oui_hex": "00-02-0E",
        "organization": "ECI Telecom Ltd.",
        "address_1": "30 Hasivim St",
        "address_2": "Petach-Tikva 49133    49133",
        "country": "IL"
    },
    "200A5E": {
        "oui_hex": "20-0A-5E",
        "organization": "Xiangshan Giant Eagle Technology Developing Co., Ltd.",
        "address_1": "Juexi Road no.9 Juexi street",
        "address_2": "Ningbo  Zhejiang  315708",
        "country": "CN"
    },
    "9C741A": {
        "oui_hex": "9C-74-1A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E4A8B6": {
        "oui_hex": "E4-A8-B6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "244C07": {
        "oui_hex": "24-4C-07",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "746FF7": {
        "oui_hex": "74-6F-F7",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "B8AEED": {
        "oui_hex": "B8-AE-ED",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No. 239, Sec. 2, Ti Ding Blvd.,",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "000DB0": {
        "oui_hex": "00-0D-B0",
        "organization": "Olym-tech Co.,Ltd.",
        "address_1": "Room 401/402,No.1,Songling Road,Hi-tech",
        "address_2": "Shenzhen  Guangdong  518031",
        "country": "CN"
    },
    "30F6B9": {
        "oui_hex": "30-F6-B9",
        "organization": "Ecocentric Energy",
        "address_1": "E3 The Innovation Centre, 9 De Laeter Way, Technology Park",
        "address_2": "Bentley  Western Australia  6102",
        "country": "AU"
    },
    "847BEB": {
        "oui_hex": "84-7B-EB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "54511B": {
        "oui_hex": "54-51-1B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "68536C": {
        "oui_hex": "68-53-6C",
        "organization": "SPnS Co.,Ltd",
        "address_1": "#315, Woolim Lions Valley 2nd, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    08591",
        "country": "KR"
    },
    "1CEA1B": {
        "oui_hex": "1C-EA-1B",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "D4612E": {
        "oui_hex": "D4-61-2E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B0E2E5": {
        "oui_hex": "B0-E2-E5",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "001FA7": {
        "oui_hex": "00-1F-A7",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "9046A2": {
        "oui_hex": "90-46-A2",
        "organization": "Tedipay UK Ltd",
        "address_1": "Level 39, One Canada Square",
        "address_2": "London    E14 5AB",
        "country": "GB"
    },
    "6479A7": {
        "oui_hex": "64-79-A7",
        "organization": "Phison Electronics Corp.",
        "address_1": "No.1, Qun Yi Rd., Jhunan,",
        "address_2": "Miaoli    350",
        "country": "TW"
    },
    "CCB11A": {
        "oui_hex": "CC-B1-1A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "703C03": {
        "oui_hex": "70-3C-03",
        "organization": "RadiAnt Co.,Ltd",
        "address_1": "102-610, 36, Bucheon-ro 198beon-gil, Wonmi-gu",
        "address_2": "Bucheon-si  Gyeonggi-do  14557",
        "country": "KR"
    },
    "00C164": {
        "oui_hex": "00-C1-64",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DC2DCB": {
        "oui_hex": "DC-2D-CB",
        "organization": "Beijing Unis HengYue Technology Co., Ltd.",
        "address_1": "Room 402, No. 2 Block, No. 1 yard, Zhongguancun east road, Haidian District",
        "address_2": "Beijing    100190",
        "country": "CN"
    },
    "2C9662": {
        "oui_hex": "2C-96-62",
        "organization": "Invenit BV",
        "address_1": "Lange Broekstraat 3",
        "address_2": "Raamsdonk  Noord-Brabant  4944 XH",
        "country": "NL"
    },
    "CCD3E2": {
        "oui_hex": "CC-D3-E2",
        "organization": "Jiangsu Yinhe  Electronics Co.,Ltd.",
        "address_1": "No.188 Nanhuan Road, TangQiao Town",
        "address_2": "Zhangjiagang   Jiangsu   215611",
        "country": "CN"
    },
    "E4FAED": {
        "oui_hex": "E4-FA-ED",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "288335": {
        "oui_hex": "28-83-35",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DCCF96": {
        "oui_hex": "DC-CF-96",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "AC44F2": {
        "oui_hex": "AC-44-F2",
        "organization": "YAMAHA CORPORATION",
        "address_1": "10-1 Nakazawa-cho, Naka-ku",
        "address_2": "Hamamatsu  Shizuoka  430-8650",
        "country": "JP"
    },
    "1C5F2B": {
        "oui_hex": "1C-5F-2B",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "1C98EC": {
        "oui_hex": "1C-98-EC",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "70661B": {
        "oui_hex": "70-66-1B",
        "organization": "Sonova AG",
        "address_1": "Laubisruetistrasse 28",
        "address_2": "Staefa    8712",
        "country": "CH"
    },
    "B07FB9": {
        "oui_hex": "B0-7F-B9",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "047E4A": {
        "oui_hex": "04-7E-4A",
        "organization": "moobox CO., Ltd.",
        "address_1": "No 801, Yanchang Zhong Road",
        "address_2": "Shanghai  Shanghai  200072",
        "country": "CN"
    },
    "0080E5": {
        "oui_hex": "00-80-E5",
        "organization": "NetApp",
        "address_1": "1395 Crossman Ave",
        "address_2": "Sunnyvale,  CA  94089",
        "country": "US"
    },
    "9C5C8E": {
        "oui_hex": "9C-5C-8E",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "C88722": {
        "oui_hex": "C8-87-22",
        "organization": "Lumenpulse",
        "address_1": "1751 Richardson, suite 1505",
        "address_2": "Montreal  Quebec  H3K 1G6",
        "country": "CA"
    },
    "84683E": {
        "oui_hex": "84-68-3E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E0CDFD": {
        "oui_hex": "E0-CD-FD",
        "organization": "Beijing E3Control Technology Co, LTD",
        "address_1": "1 Shangdi East Rd, Building A, Rm 205",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "000895": {
        "oui_hex": "00-08-95",
        "organization": "DIRC Technologie GmbH & Co.KG",
        "address_1": "Borsigstraße 13",
        "address_2": "Ratingen  NRW  40880",
        "country": "DE"
    },
    "60ACC8": {
        "oui_hex": "60-AC-C8",
        "organization": "KunTeng Inc.",
        "address_1": "Room302, 3rd Floor, Building1 ,No.8 NongDa South street",
        "address_2": "HaiDian District  BeiJing  100084",
        "country": "CN"
    },
    "CCB3AB": {
        "oui_hex": "CC-B3-AB",
        "organization": "shenzhen Biocare Bio-Medical Equipment Co.,Ltd.",
        "address_1": "#A735, 7/F, Block A, Shenzhen Mingyou Industrial Products Exhibition & Procurement  Center, Baoyuan Road, Xixiang Sub-district, Bao'an District, 518102 Shenzhen, P.R. China",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "E4B318": {
        "oui_hex": "E4-B3-18",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "743E2B": {
        "oui_hex": "74-3E-2B",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E0C767": {
        "oui_hex": "E0-C7-67",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80ED2C": {
        "oui_hex": "80-ED-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F03404": {
        "oui_hex": "F0-34-04",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "80D160": {
        "oui_hex": "80-D1-60",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "30785C": {
        "oui_hex": "30-78-5C",
        "organization": "Partow Tamas Novin (Parman)",
        "address_1": "UNIT 32 NO.31 26TH WEST AVE ,ALLAMEH TABATABAIE ST.SAADAT ABAD",
        "address_2": "Tehran  Tehran  1997968413",
        "country": "IR"
    },
    "246968": {
        "oui_hex": "24-69-68",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "8CA2FD": {
        "oui_hex": "8C-A2-FD",
        "organization": "Starry, Inc.",
        "address_1": "PO Box 52226",
        "address_2": "Boston  MA  02205",
        "country": "US"
    },
    "84BA3B": {
        "oui_hex": "84-BA-3B",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "000585": {
        "oui_hex": "00-05-85",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "204E71": {
        "oui_hex": "20-4E-71",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00194F": {
        "oui_hex": "00-19-4F",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "00BD3A": {
        "oui_hex": "00-BD-3A",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "80501B": {
        "oui_hex": "80-50-1B",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "A04E04": {
        "oui_hex": "A0-4E-04",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "001262": {
        "oui_hex": "00-12-62",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0014A7": {
        "oui_hex": "00-14-A7",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0015A0": {
        "oui_hex": "00-15-A0",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0016BC": {
        "oui_hex": "00-16-BC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "00174B": {
        "oui_hex": "00-17-4B",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002669": {
        "oui_hex": "00-26-69",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "AC61EA": {
        "oui_hex": "AC-61-EA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38B54D": {
        "oui_hex": "38-B5-4D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1C5CF2": {
        "oui_hex": "1C-5C-F2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A87E33": {
        "oui_hex": "A8-7E-33",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002403": {
        "oui_hex": "00-24-03",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002404": {
        "oui_hex": "00-24-04",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0019B7": {
        "oui_hex": "00-19-B7",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0017B0": {
        "oui_hex": "00-17-B0",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002109": {
        "oui_hex": "00-21-09",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002108": {
        "oui_hex": "00-21-08",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001B33": {
        "oui_hex": "00-1B-33",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0015DE": {
        "oui_hex": "00-15-DE",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0002EE": {
        "oui_hex": "00-02-EE",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj, Copenhagen V",
        "address_2": "copenhagen    12345",
        "country": "DK"
    },
    "D8F710": {
        "oui_hex": "D8-F7-10",
        "organization": "Libre Wireless Technologies Inc.",
        "address_1": "5405 Alton Parkway",
        "address_2": "Irvine, CA  CA  92604",
        "country": "US"
    },
    "3C591E": {
        "oui_hex": "3C-59-1E",
        "organization": "TCL King Electrical Appliances (Huizhou) Co., Ltd",
        "address_1": "7/FTCL Multimedia Building, TCL International E City, No.1001 Zhongshanyuan Road, Nanshan",
        "address_2": "Shenzhen   Guangdong    518052",
        "country": "CN"
    },
    "C43655": {
        "oui_hex": "C4-36-55",
        "organization": "Shenzhen Fenglian Technology Co., Ltd.",
        "address_1": "Room 302, 3F, Block 2, Oriental Cyberport, No. 2, Xinxi Road",
        "address_2": "Shenzhen   Guangdong  518057",
        "country": "CN"
    },
    "E0B9E5": {
        "oui_hex": "E0-B9-E5",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "0030DA": {
        "oui_hex": "00-30-DA",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "64680C": {
        "oui_hex": "64-68-0C",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "3872C0": {
        "oui_hex": "38-72-C0",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "A80600": {
        "oui_hex": "A8-06-00",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002682": {
        "oui_hex": "00-26-82",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No.1 Jen Ai Road, Hsinchu Industrial Park,",
        "address_2": "Hukou,  Hsinchu  303",
        "country": "TW"
    },
    "0009E1": {
        "oui_hex": "00-09-E1",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No.1 Jen Ai Road",
        "address_2": "Hukou  Hsinchu  303",
        "country": "TW"
    },
    "14C126": {
        "oui_hex": "14-C1-26",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "600194": {
        "oui_hex": "60-01-94",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F05A09": {
        "oui_hex": "F0-5A-09",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "503275": {
        "oui_hex": "50-32-75",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "08FC88": {
        "oui_hex": "08-FC-88",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0270B3": {
        "oui_hex": "02-70-B3",
        "organization": "DATA RECALL LTD.",
        "address_1": "SONDES PLACE",
        "address_2": "12345  UNITED  KINGDOM",
        "country": "GB"
    },
    "000136": {
        "oui_hex": "00-01-36",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99, Park Avenue III",
        "address_2": "Hsinchu    12345",
        "country": "TW"
    },
    "D04D2C": {
        "oui_hex": "D0-4D-2C",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "B0A737": {
        "oui_hex": "B0-A7-37",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "140C76": {
        "oui_hex": "14-0C-76",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS    75008",
        "country": "FR"
    },
    "001BE9": {
        "oui_hex": "00-1B-E9",
        "organization": "Broadcom",
        "address_1": "16215 Alton Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0019C7": {
        "oui_hex": "00-19-C7",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "Room 309,333 Hong Qiao Road",
        "address_2": "Shanghai    200030",
        "country": "CN"
    },
    "70D931": {
        "oui_hex": "70-D9-31",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22Floor,Qilai Tower;889Yishan Road",
        "address_2": "shanghai    200233",
        "country": "CN"
    },
    "029D8E": {
        "oui_hex": "02-9D-8E",
        "organization": "CARDIAC RECORDERS, INC.",
        "address_1": "34 SCARBORO RD",
        "address_2": "UK  UNITED  KINGDOM",
        "country": "GB"
    },
    "00402A": {
        "oui_hex": "00-40-2A",
        "organization": "Canoga Perkins Corporation",
        "address_1": "21012 LASSEN STREET",
        "address_2": "CHATSWORTH  CA  91311-4241",
        "country": "US"
    },
    "A4C7DE": {
        "oui_hex": "A4-C7-DE",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22 Floor,Qilai Tower;889 Yishan Road",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "D8B8F6": {
        "oui_hex": "D8-B8-F6",
        "organization": "Nantworks",
        "address_1": "12230 El Camino Real, Suite 400",
        "address_2": "San Diego  CA  92130",
        "country": "US"
    },
    "008077": {
        "oui_hex": "00-80-77",
        "organization": "Brother industries, LTD.",
        "address_1": "RESEARCH LABORATORY",
        "address_2": "piscatawa    12345",
        "country": "JP"
    },
    "24F5AA": {
        "oui_hex": "24-F5-AA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "988389": {
        "oui_hex": "98-83-89",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "84A466": {
        "oui_hex": "84-A4-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "C4576E": {
        "oui_hex": "C4-57-6E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "508569": {
        "oui_hex": "50-85-69",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "0060BB": {
        "oui_hex": "00-60-BB",
        "organization": "Cabletron Systems, Inc.",
        "address_1": "35 INDUSTRIAL WAY",
        "address_2": "ROCHESTER  NH  03866-5005",
        "country": "US"
    },
    "F8D0BD": {
        "oui_hex": "F8-D0-BD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "78595E": {
        "oui_hex": "78-59-5E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0C1420": {
        "oui_hex": "0C-14-20",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "94B10A": {
        "oui_hex": "94-B1-0A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3CBBFD": {
        "oui_hex": "3C-BB-FD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A48431": {
        "oui_hex": "A4-84-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A0B4A5": {
        "oui_hex": "A0-B4-A5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E4F8EF": {
        "oui_hex": "E4-F8-EF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DC446D": {
        "oui_hex": "DC-44-6D",
        "organization": "Allwinner Technology Co., Ltd",
        "address_1": "No.9 Technology Road 2, High-Tech Zone",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "745AAA": {
        "oui_hex": "74-5A-AA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "04FE8D": {
        "oui_hex": "04-FE-8D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "001333": {
        "oui_hex": "00-13-33",
        "organization": "BaudTec Corporation",
        "address_1": "12F, NO.181, Sec.  1. Tatung Rd.,",
        "address_2": "Hsichih  Taipei Hsien  221",
        "country": "TW"
    },
    "58671A": {
        "oui_hex": "58-67-1A",
        "organization": "Barnes&Noble",
        "address_1": "400 HAMILTON AVENUE",
        "address_2": "PALO ALTO  CA  94301",
        "country": "US"
    },
    "002675": {
        "oui_hex": "00-26-75",
        "organization": "Aztech Electronics Pte Ltd",
        "address_1": "31 Ubi Road 1",
        "address_2": "Singapore    408694",
        "country": "SG"
    },
    "0024FE": {
        "oui_hex": "00-24-FE",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "C02506": {
        "oui_hex": "C0-25-06",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "405D82": {
        "oui_hex": "40-5D-82",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "DCEF09": {
        "oui_hex": "DC-EF-09",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "DC64B8": {
        "oui_hex": "DC-64-B8",
        "organization": "Shenzhen JingHanDa Electronics Co.Ltd",
        "address_1": "5th Floor,No 4 ,Road 1,ShangXue Technology industrial Park,LongGang district,ShenZhen,GuangDong,China",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "000D92": {
        "oui_hex": "00-0D-92",
        "organization": "ARIMA Communications Corp.",
        "address_1": "16, lane 658, Ying-Tao Road",
        "address_2": "Yingko  Taipei County  23943",
        "country": "TW"
    },
    "002163": {
        "oui_hex": "00-21-63",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119.CHIENKANG RD,CHUNG-HO,",
        "address_2": "taipei  TAIPEI  235",
        "country": "TW"
    },
    "A8D3F7": {
        "oui_hex": "A8-D3-F7",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.,",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "4C60DE": {
        "oui_hex": "4C-60-DE",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C43DC7": {
        "oui_hex": "C4-3D-C7",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "489D24": {
        "oui_hex": "48-9D-24",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "08BD43": {
        "oui_hex": "08-BD-43",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "44EE02": {
        "oui_hex": "44-EE-02",
        "organization": "MTI Ltd.",
        "address_1": "Nishi-shinjuku Tokyo Opera City Tower 3-20-2 35F",
        "address_2": "Shinjuku-ku  Tokyo  163-1435",
        "country": "JP"
    },
    "5856E8": {
        "oui_hex": "58-56-E8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F80BBE": {
        "oui_hex": "F8-0B-BE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "DC4517": {
        "oui_hex": "DC-45-17",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C8AA21": {
        "oui_hex": "C8-AA-21",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0017EE": {
        "oui_hex": "00-17-EE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00111A": {
        "oui_hex": "00-11-1A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000F9F": {
        "oui_hex": "00-0F-9F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0004BD": {
        "oui_hex": "00-04-BD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002642": {
        "oui_hex": "00-26-42",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0024A1": {
        "oui_hex": "00-24-A1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002210": {
        "oui_hex": "00-22-10",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0022B4": {
        "oui_hex": "00-22-B4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00149A": {
        "oui_hex": "00-14-9A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0014E8": {
        "oui_hex": "00-14-E8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0019C0": {
        "oui_hex": "00-19-C0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00E06F": {
        "oui_hex": "00-E0-6F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8096B1": {
        "oui_hex": "80-96-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "707E43": {
        "oui_hex": "70-7E-43",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00152F": {
        "oui_hex": "00-15-2F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001FC4": {
        "oui_hex": "00-1F-C4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001CFB": {
        "oui_hex": "00-1C-FB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002395": {
        "oui_hex": "00-23-95",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0023AF": {
        "oui_hex": "00-23-AF",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F87B7A": {
        "oui_hex": "F8-7B-7A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0000F4": {
        "oui_hex": "00-00-F4",
        "organization": "Allied Telesis, Inc.",
        "address_1": "CORPORATION",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "001577": {
        "oui_hex": "00-15-77",
        "organization": "Allied Telesis, Inc.",
        "address_1": "3200 North First Street",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "001AEB": {
        "oui_hex": "00-1A-EB",
        "organization": "Allied Telesis R&D Center K.K.",
        "address_1": "No.2 TOC Bldg.",
        "address_2": "Shinagawa-ku  Tokyo  141-0031",
        "country": "JP"
    },
    "703C39": {
        "oui_hex": "70-3C-39",
        "organization": "SEAWING Kft",
        "address_1": "Palánkai utca 5.",
        "address_2": "Székesfehérvár  Fejér  8000",
        "country": "HU"
    },
    "9097D5": {
        "oui_hex": "90-97-D5",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "ACD074": {
        "oui_hex": "AC-D0-74",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "38E3C5": {
        "oui_hex": "38-E3-C5",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "0015CE": {
        "oui_hex": "00-15-CE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015A2": {
        "oui_hex": "00-15-A2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015A3": {
        "oui_hex": "00-15-A3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015A4": {
        "oui_hex": "00-15-A4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0000CA": {
        "oui_hex": "00-00-CA",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "709E29": {
        "oui_hex": "70-9E-29",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "A4DB30": {
        "oui_hex": "A4-DB-30",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "40F02F": {
        "oui_hex": "40-F0-2F",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "74C246": {
        "oui_hex": "74-C2-46",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "000FA3": {
        "oui_hex": "00-0F-A3",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing 7th Rd.,Science-based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001D6A": {
        "oui_hex": "00-1D-6A",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing Seventh Road,Science-based",
        "address_2": "Hsinchu    300",
        "country": "US"
    },
    "002345": {
        "oui_hex": "00-23-45",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "6C0E0D": {
        "oui_hex": "6C-0E-0D",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "6C23B9": {
        "oui_hex": "6C-23-B9",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "3017C8": {
        "oui_hex": "30-17-C8",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0012EE": {
        "oui_hex": "00-12-EE",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001620": {
        "oui_hex": "00-16-20",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001963": {
        "oui_hex": "00-19-63",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001FE4": {
        "oui_hex": "00-1F-E4",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "205476": {
        "oui_hex": "20-54-76",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001A80": {
        "oui_hex": "00-1A-80",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec, 5-1-2 Kitashinagawa",
        "address_2": "Tokyo    141-0001",
        "country": "JP"
    },
    "8841FC": {
        "oui_hex": "88-41-FC",
        "organization": "AirTies Wireless Networks",
        "address_1": "Gulbahar Mahallesi, Avni Diligil Sokak",
        "address_2": "ISTANBUL  ISTANBUL  34394",
        "country": "TR"
    },
    "0030D3": {
        "oui_hex": "00-30-D3",
        "organization": "Agilent Technologies, Inc.",
        "address_1": "1501 Page Mill Road",
        "address_2": "Palo Alto  CA  94304-1126",
        "country": "US"
    },
    "00A02F": {
        "oui_hex": "00-A0-2F",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "20126 MILAN    12345",
        "country": "IT"
    },
    "98743D": {
        "oui_hex": "98-74-3D",
        "organization": "Shenzhen Jun Kai Hengye Technology Co. Ltd",
        "address_1": "5th floor,Yahua Building,#1Hongwan Gonghegongye RD,Xixiang Gushu Community,Baoan District,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A0F459": {
        "oui_hex": "A0-F4-59",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "5th Floor, A Building, Haoye Logistics Park, Shugang Channel, Bao'an District,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "586356": {
        "oui_hex": "58-63-56",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "5th Floor, A Building, Haoye Logistics Park, Shugang Channel, Bao'an District,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "8CB864": {
        "oui_hex": "8C-B8-64",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F., No.22, Dalin Rd.,",
        "address_2": "Taoyuan City    330",
        "country": "TW"
    },
    "5CE2F4": {
        "oui_hex": "5C-E2-F4",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F., No.22, Dalin Rd.",
        "address_2": "Taoyuan  Taoyuan County  33067",
        "country": "TW"
    },
    "B8616F": {
        "oui_hex": "B8-61-6F",
        "organization": "Accton Technology Corp",
        "address_1": "No.1 Creation Rd III, Science-based Industrial Park",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "0012CF": {
        "oui_hex": "00-12-CF",
        "organization": "Accton Technology Corp",
        "address_1": "No. 1 Creation Rd. III, Science-based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0030F1": {
        "oui_hex": "00-30-F1",
        "organization": "Accton Technology Corp",
        "address_1": "No. 1, Creation Rd. IV",
        "address_2": "Hsinchu    12345",
        "country": "TW"
    },
    "705A0F": {
        "oui_hex": "70-5A-0F",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "4495FA": {
        "oui_hex": "44-95-FA",
        "organization": "Qingdao Santong Digital Technology Co.Ltd",
        "address_1": "Room701, No.1£¬Fu Ying Building,No.443East Changjiang Road,Qingdao Economic and Technological Development District",
        "address_2": "Qingdao  Shandong  266555",
        "country": "CN"
    },
    "0025D3": {
        "oui_hex": "00-25-D3",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F ., No.94, Baozhong Rd.",
        "address_2": "Xindian City    231",
        "country": "TW"
    },
    "1C4BD6": {
        "oui_hex": "1C-4B-D6",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baoshong Rd.",
        "address_2": "Xindian City, Taipei County    231",
        "country": "TW"
    },
    "08A95A": {
        "oui_hex": "08-A9-5A",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baoshong Rd.",
        "address_2": "Xindian City, Taipei County    231",
        "country": "TW"
    },
    "94DBC9": {
        "oui_hex": "94-DB-C9",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F No94 Baozhong Rd",
        "address_2": "XindianDistrict, New Taipei City    231",
        "country": "TW"
    },
    "240A64": {
        "oui_hex": "24-0A-64",
        "organization": "AzureWave Technology Inc.",
        "address_1": "9F.,No.92,Baozhong Rd",
        "address_2": "Xindian  NewTaipeiCity  231",
        "country": "TW"
    },
    "40E230": {
        "oui_hex": "40-E2-30",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "80D21D": {
        "oui_hex": "80-D2-1D",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "D4D184": {
        "oui_hex": "D4-D1-84",
        "organization": "ADB Broadband Italia",
        "address_1": "via Sarca 222",
        "address_2": "Milano    20126",
        "country": "IT"
    },
    "A04FD4": {
        "oui_hex": "A0-4F-D4",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "D00ED9": {
        "oui_hex": "D0-0E-D9",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD, Lu Du",
        "address_2": "Taicang  Jiangsu  215412",
        "country": "CN"
    },
    "541473": {
        "oui_hex": "54-14-73",
        "organization": " Wingtech Group (HongKong）Limited",
        "address_1": "FLAT/RM 1903 19/F PODIUM PLAZA 5HANOI ROAD TSIM SHA TSUI",
        "address_2": "HongKong    999077",
        "country": "HK"
    },
    "8086F2": {
        "oui_hex": "80-86-F2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E09467": {
        "oui_hex": "E0-94-67",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "08D40C": {
        "oui_hex": "08-D4-0C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6C8814": {
        "oui_hex": "6C-88-14",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "303A64": {
        "oui_hex": "30-3A-64",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "ACFDCE": {
        "oui_hex": "AC-FD-CE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7CCCB8": {
        "oui_hex": "7C-CC-B8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F40669": {
        "oui_hex": "F4-06-69",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001DE1": {
        "oui_hex": "00-1D-E1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "90E2BA": {
        "oui_hex": "90-E2-BA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0026C7": {
        "oui_hex": "00-26-C7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0026C6": {
        "oui_hex": "00-26-C6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0CCC26": {
        "oui_hex": "0C-CC-26",
        "organization": "Airenetworks",
        "address_1": "Ramon y Cajal 11",
        "address_2": "Elche  Alicante  03203",
        "country": "ES"
    },
    "E09D31": {
        "oui_hex": "E0-9D-31",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "88532E": {
        "oui_hex": "88-53-2E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "74C99A": {
        "oui_hex": "74-C9-9A",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "5CC213": {
        "oui_hex": "5C-C2-13",
        "organization": "Fr. Sauter AG",
        "address_1": "Im Surinam 55",
        "address_2": "Basel  BS  CH4016",
        "country": "CH"
    },
    "28101B": {
        "oui_hex": "28-10-1B",
        "organization": "MagnaCom",
        "address_1": "9 Bareket Street",
        "address_2": "Petah Tikva    4951777",
        "country": "IL"
    },
    "001676": {
        "oui_hex": "00-16-76",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0016EA": {
        "oui_hex": "00-16-EA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001B77": {
        "oui_hex": "00-1B-77",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001CC0": {
        "oui_hex": "00-1C-C0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "104A7D": {
        "oui_hex": "10-4A-7D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001AA0": {
        "oui_hex": "00-1A-A0",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "0019B9": {
        "oui_hex": "00-19-B9",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00B0D0": {
        "oui_hex": "00-B0-D0",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00C04F": {
        "oui_hex": "00-C0-4F",
        "organization": "Dell Inc.",
        "address_1": "1807 WEST BRAKER LANE-BLDG.",
        "address_2": "AUSTIN  TX  78758-3610",
        "country": "US"
    },
    "B07994": {
        "oui_hex": "B0-79-94",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Hwy 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "A470D6": {
        "oui_hex": "A4-70-D6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "74867A": {
        "oui_hex": "74-86-7A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "180373": {
        "oui_hex": "18-03-73",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "14FEB5": {
        "oui_hex": "14-FE-B5",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "782BCB": {
        "oui_hex": "78-2B-CB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001F3B": {
        "oui_hex": "00-1F-3B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00215D": {
        "oui_hex": "00-21-5D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00216A": {
        "oui_hex": "00-21-6A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001C23": {
        "oui_hex": "00-1C-23",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "A4BADB": {
        "oui_hex": "A4-BA-DB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "002564": {
        "oui_hex": "00-25-64",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "A41F72": {
        "oui_hex": "A4-1F-72",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock     78682",
        "country": "US"
    },
    "C46699": {
        "oui_hex": "C4-66-99",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "C8F230": {
        "oui_hex": "C8-F2-30",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "8C0EE3": {
        "oui_hex": "8C-0E-E3",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "C8CD72": {
        "oui_hex": "C8-CD-72",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "F82C18": {
        "oui_hex": "F8-2C-18",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "18017D": {
        "oui_hex": "18-01-7D",
        "organization": "Harbin Arteor technology co., LTD",
        "address_1": "Yushan Road 49-2",
        "address_2": "Harbin  Heilongjiang  150090",
        "country": "CN"
    },
    "001556": {
        "oui_hex": "00-15-56",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "C0D044": {
        "oui_hex": "C0-D0-44",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, Route de l'Empereur",
        "address_2": "RUEIL-MALMAISON    92500",
        "country": "FR"
    },
    "A01B29": {
        "oui_hex": "A0-1B-29",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "74E14A": {
        "oui_hex": "74-E1-4A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0CEFAF": {
        "oui_hex": "0C-EF-AF",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F80278": {
        "oui_hex": "F8-02-78",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A0BB3E": {
        "oui_hex": "A0-BB-3E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "884AEA": {
        "oui_hex": "88-4A-EA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0022A4": {
        "oui_hex": "00-22-A4",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "982CBE": {
        "oui_hex": "98-2C-BE",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "640F28": {
        "oui_hex": "64-0F-28",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose   CA  95131",
        "country": "US"
    },
    "00123F": {
        "oui_hex": "00-12-3F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "000BDB": {
        "oui_hex": "00-0B-DB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "204747": {
        "oui_hex": "20-47-47",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001495": {
        "oui_hex": "00-14-95",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "348AAE": {
        "oui_hex": "34-8A-AE",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "7C03D8": {
        "oui_hex": "7C-03-D8",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "C0AC54": {
        "oui_hex": "C0-AC-54",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "2C3996": {
        "oui_hex": "2C-39-96",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "F08261": {
        "oui_hex": "F0-82-61",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "0030C5": {
        "oui_hex": "00-30-C5",
        "organization": "CADENCE DESIGN SYSTEMS, INC.",
        "address_1": "555 RIVER OAKS PARKWAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "D08CB5": {
        "oui_hex": "D0-8C-B5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "00182F": {
        "oui_hex": "00-18-2F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017EA": {
        "oui_hex": "00-17-EA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0021BA": {
        "oui_hex": "00-21-BA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "BC0DA5": {
        "oui_hex": "BC-0D-A5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "CC8CE3": {
        "oui_hex": "CC-8C-E3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E0D7BA": {
        "oui_hex": "E0-D7-BA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "1CE2CC": {
        "oui_hex": "1C-E2-CC",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "985945": {
        "oui_hex": "98-59-45",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "944452": {
        "oui_hex": "94-44-52",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "B0B448": {
        "oui_hex": "B0-B4-48",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D494A1": {
        "oui_hex": "D4-94-A1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0014BF": {
        "oui_hex": "00-14-BF",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "CCB255": {
        "oui_hex": "CC-B2-55",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "28107B": {
        "oui_hex": "28-10-7B",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "FC7516": {
        "oui_hex": "FC-75-16",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "84C9B2": {
        "oui_hex": "84-C9-B2",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "C8D3A3": {
        "oui_hex": "C8-D3-A3",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12. The Synergy Singapore",
        "address_2": "Singapore    609917",
        "country": "US"
    },
    "3CBB73": {
        "oui_hex": "3C-BB-73",
        "organization": "Shenzhen Xinguodu Technology Co., Ltd.",
        "address_1": "F17A, JinSong Building, Tairan Industrial & Trade Park, Chegongmiao, Shennan Road，Futian District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "0C47C9": {
        "oui_hex": "0C-47-C9",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0050BA": {
        "oui_hex": "00-50-BA",
        "organization": "D-Link Corporation",
        "address_1": "2F, NO. 233L-2, PAO-CHIAO RD.",
        "address_2": "TAIPEI    0000",
        "country": "TW"
    },
    "00179A": {
        "oui_hex": "00-17-9A",
        "organization": "D-Link Corporation",
        "address_1": "No. 289, Sinhu 3rd Rd., Neihu District,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001CF0": {
        "oui_hex": "00-1C-F0",
        "organization": "D-Link Corporation",
        "address_1": "NO.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "001E58": {
        "oui_hex": "00-1E-58",
        "organization": "D-Link Corporation",
        "address_1": "NO.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "0022B0": {
        "oui_hex": "00-22-B0",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd RD.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "002401": {
        "oui_hex": "00-24-01",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd RD.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "1CAFF7": {
        "oui_hex": "1C-AF-F7",
        "organization": "D-Link International",
        "address_1": "1 INTERNATIONAL  BUSINESS  PARK,",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "14D64D": {
        "oui_hex": "14-D6-4D",
        "organization": "D-Link International",
        "address_1": "1 INTERNATIONAL BUSINESS PARK",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "9094E4": {
        "oui_hex": "90-94-E4",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "B499BA": {
        "oui_hex": "B4-99-BA",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "047863": {
        "oui_hex": "04-78-63",
        "organization": "Shanghai MXCHIP Information Technology Co., Ltd.",
        "address_1": "9th Floor, No. 5 Building, 2145 Jinshajiang Rd., Putuo District",
        "address_2": "Shanghai    200333",
        "country": "CN"
    },
    "409F87": {
        "oui_hex": "40-9F-87",
        "organization": "Jide Technology (Hong Kong) Limited",
        "address_1": "jiahua Mansion 3F, 133 North 4th Ring Road East, Chaoyang District",
        "address_2": "Beijing    100101",
        "country": "CN"
    },
    "0CF9C0": {
        "oui_hex": "0C-F9-C0",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "4CFF12": {
        "oui_hex": "4C-FF-12",
        "organization": "Fuze Entertainment Co., ltd",
        "address_1": "3rd Floor Harbour Centre",
        "address_2": "George Town  George Town  P.O. Box 613GT",
        "country": "KY"
    },
    "AC9A22": {
        "oui_hex": "AC-9A-22",
        "organization": "NXP Semiconductors",
        "address_1": "411 E. Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "287CDB": {
        "oui_hex": "28-7C-DB",
        "organization": "Hefei  Toycloud Technology Co.,ltd",
        "address_1": "FLOOR 13,XUNFEI BUILDING,NO.666 WANGJIANG ROAD,HIGH & NEW TECHNOLOGY DEVELOPMENT ZONE.HEFEI.",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "806AB0": {
        "oui_hex": "80-6A-B0",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park",
        "address_2": "Nanshan District, Shenzhen  GUANGDONG  518053",
        "country": "CN"
    },
    "48AD08": {
        "oui_hex": "48-AD-08",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4CFB45": {
        "oui_hex": "4C-FB-45",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "009ACD": {
        "oui_hex": "00-9A-CD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3C5AB4": {
        "oui_hex": "3C-5A-B4",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View    94043",
        "country": "US"
    },
    "F4F5E8": {
        "oui_hex": "F4-F5-E8",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View    94043",
        "country": "US"
    },
    "94EB2C": {
        "oui_hex": "94-EB-2C",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View    94043",
        "country": "US"
    },
    "0CC731": {
        "oui_hex": "0C-C7-31",
        "organization": "Currant, Inc.",
        "address_1": "927 Industrial Ave",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "70B3D5": {
        "oui_hex": "70-B3-D5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "28ED6A": {
        "oui_hex": "28-ED-6A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C056E3": {
        "oui_hex": "C0-56-E3",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "EC3EF7": {
        "oui_hex": "EC-3E-F7",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0CF893": {
        "oui_hex": "0C-F8-93",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3CDFA9": {
        "oui_hex": "3C-DF-A9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8461A0": {
        "oui_hex": "84-61-A0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015D1": {
        "oui_hex": "00-15-D1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DD0": {
        "oui_hex": "00-1D-D0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DD3": {
        "oui_hex": "00-1D-D3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "ACB313": {
        "oui_hex": "AC-B3-13",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "38F23E": {
        "oui_hex": "38-F2-3E",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "E4F89C": {
        "oui_hex": "E4-F8-9C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6CA100": {
        "oui_hex": "6C-A1-00",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2C4138": {
        "oui_hex": "2C-41-38",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "441EA1": {
        "oui_hex": "44-1E-A1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "78E7D1": {
        "oui_hex": "78-E7-D1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "5C8FE0": {
        "oui_hex": "5C-8F-E0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "90C792": {
        "oui_hex": "90-C7-92",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "BCCAB5": {
        "oui_hex": "BC-CA-B5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D039B3": {
        "oui_hex": "D0-39-B3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000FCC": {
        "oui_hex": "00-0F-CC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0012F0": {
        "oui_hex": "00-12-F0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "000740": {
        "oui_hex": "00-07-40",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "0024A5": {
        "oui_hex": "00-24-A5",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "CCE1D5": {
        "oui_hex": "CC-E1-D5",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg.,30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref  460-8315",
        "country": "JP"
    },
    "A402B9": {
        "oui_hex": "A4-02-B9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DC5360": {
        "oui_hex": "DC-53-60",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001CC4": {
        "oui_hex": "00-1C-C4",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001E0B": {
        "oui_hex": "00-1E-0B",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "002264": {
        "oui_hex": "00-22-64",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0025B3": {
        "oui_hex": "00-25-B3",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000CF1": {
        "oui_hex": "00-0C-F1",
        "organization": "Intel Corporation",
        "address_1": "MS: JF3-420",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "784859": {
        "oui_hex": "78-48-59",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "58DC6D": {
        "oui_hex": "58-DC-6D",
        "organization": "Exceptional Innovation, Inc.",
        "address_1": "480 Olde Worthington Rd, Suite 350",
        "address_2": "Westerville  OH  43082",
        "country": "US"
    },
    "902155": {
        "oui_hex": "90-21-55",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "643150": {
        "oui_hex": "64-31-50",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "7CB15D": {
        "oui_hex": "7C-B1-5D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "00265E": {
        "oui_hex": "00-26-5E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00242C": {
        "oui_hex": "00-24-2C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D8B377": {
        "oui_hex": "D8-B3-77",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd.,",
        "address_2": "Taoyuan City    330",
        "country": "TW"
    },
    "B0F1A3": {
        "oui_hex": "B0-F1-A3",
        "organization": "Fengfan (BeiJing) Technology Co., Ltd.",
        "address_1": "Room518,Dianzichengdasha Town,No12,Jiuxianqiao Road",
        "address_2": "Beijing  Chaoyang District  100016",
        "country": "CN"
    },
    "3464A9": {
        "oui_hex": "34-64-A9",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "3863BB": {
        "oui_hex": "38-63-BB",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "5CB901": {
        "oui_hex": "5C-B9-01",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "DC4A3E": {
        "oui_hex": "DC-4A-3E",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "B05ADA": {
        "oui_hex": "B0-5A-DA",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "001083": {
        "oui_hex": "00-10-83",
        "organization": "Hewlett Packard",
        "address_1": "MAIL STOP 42LE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "A0B3CC": {
        "oui_hex": "A0-B3-CC",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "ECB1D7": {
        "oui_hex": "EC-B1-D7",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "9CB654": {
        "oui_hex": "9C-B6-54",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "6C3BE5": {
        "oui_hex": "6C-3B-E5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "B0AA36": {
        "oui_hex": "B0-AA-36",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "784B87": {
        "oui_hex": "78-4B-87",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1,Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "E4CE02": {
        "oui_hex": "E4-CE-02",
        "organization": "WyreStorm Technologies Ltd",
        "address_1": "Tech Valley Park, 23 Wood Road",
        "address_2": "Round Lake  New York  12151",
        "country": "GB"
    },
    "40F308": {
        "oui_hex": "40-F3-08",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "808917": {
        "oui_hex": "80-89-17",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "A09347": {
        "oui_hex": "A0-93-47",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN,DONGGUAN,GUANGDONG,CHINA",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "E8BBA8": {
        "oui_hex": "E8-BB-A8",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN,DONGGUAN,GUANGDONG,CHINA",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "942CB3": {
        "oui_hex": "94-2C-B3",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "002719": {
        "oui_hex": "00-27-19",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "40169F": {
        "oui_hex": "40-16-9F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F4EC38": {
        "oui_hex": "F4-EC-38",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "140467": {
        "oui_hex": "14-04-67",
        "organization": "SNK Technologies Co.,Ltd.",
        "address_1": "#1001, Byuksan Sunyoung Technopia, A-dong, 13",
        "address_2": "Ojeongongeop-gil, Uiwang-si,  Gyeonggi-do  16072",
        "country": "KR"
    },
    "8030DC": {
        "oui_hex": "80-30-DC",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A4D578": {
        "oui_hex": "A4-D5-78",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "14CF92": {
        "oui_hex": "14-CF-92",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "20DCE6": {
        "oui_hex": "20-DC-E6",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "14CC20": {
        "oui_hex": "14-CC-20",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "246081": {
        "oui_hex": "24-60-81",
        "organization": "razberi technologies",
        "address_1": "13755 Hutton Drive Suite 500",
        "address_2": "Farmers Branch  TX  75234",
        "country": "US"
    },
    "A4D18C": {
        "oui_hex": "A4-D1-8C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90F652": {
        "oui_hex": "90-F6-52",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan,",
        "address_2": "Shenzhen  Guangdong Province,  518057",
        "country": "CN"
    },
    "241EEB": {
        "oui_hex": "24-1E-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC25EF": {
        "oui_hex": "CC-25-EF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88CF98": {
        "oui_hex": "88-CF-98",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F80D43": {
        "oui_hex": "F8-0D-43",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "38F889": {
        "oui_hex": "38-F8-89",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D07AB5": {
        "oui_hex": "D0-7A-B5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0019C6": {
        "oui_hex": "00-19-C6",
        "organization": "zte corporation",
        "address_1": "Technology Management Department,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001DD9": {
        "oui_hex": "00-1D-D9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00197D": {
        "oui_hex": "00-19-7D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "7C4CA5": {
        "oui_hex": "7C-4C-A5",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "0014A4": {
        "oui_hex": "00-14-A4",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "78DD08": {
        "oui_hex": "78-DD-08",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "9CD21E": {
        "oui_hex": "9C-D2-1E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B43052": {
        "oui_hex": "B4-30-52",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "80D09B": {
        "oui_hex": "80-D0-9B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C8E5C": {
        "oui_hex": "1C-8E-5C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "84742A": {
        "oui_hex": "84-74-2A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "9CD24B": {
        "oui_hex": "9C-D2-4B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C87B5B": {
        "oui_hex": "C8-7B-5B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0007D8": {
        "oui_hex": "00-07-D8",
        "organization": "Hitron Technologies. Inc",
        "address_1": "135-220 Hitron B/D 726-5",
        "address_2": "Seoul    13456",
        "country": "KR"
    },
    "C03E0F": {
        "oui_hex": "C0-3E-0F",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "904E2B": {
        "oui_hex": "90-4E-2B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2008ED": {
        "oui_hex": "20-08-ED",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0034FE": {
        "oui_hex": "00-34-FE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C85195": {
        "oui_hex": "C8-51-95",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "40CBA8": {
        "oui_hex": "40-CB-A8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "D46E5C": {
        "oui_hex": "D4-6E-5C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "8853D4": {
        "oui_hex": "88-53-D4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "04C06F": {
        "oui_hex": "04-C0-6F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "202BC1": {
        "oui_hex": "20-2B-C1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "54A51B": {
        "oui_hex": "54-A5-1B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "002568": {
        "oui_hex": "00-25-68",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "781DBA": {
        "oui_hex": "78-1D-BA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "HUAWEI Industrial Base Bantian,Longgang",
        "address_2": "Shenzhen  guangdong  518129",
        "country": "CN"
    },
    "00259E": {
        "oui_hex": "00-25-9E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "B1-7,Huawei Base,Bantian, Longgang District,ShenZhen,GuangDong,CHINA",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "006B8E": {
        "oui_hex": "00-6B-8E",
        "organization": "Shanghai Feixun Communication Co.,Ltd.",
        "address_1": "Building 90,No,4855,Guangfulin Road",
        "address_2": "shanghai  Shanghai  201616",
        "country": "CN"
    },
    "D46AA8": {
        "oui_hex": "D4-6A-A8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen    518129",
        "country": "CN"
    },
    "BCADAB": {
        "oui_hex": "BC-AD-AB",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "FCA841": {
        "oui_hex": "FC-A8-41",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "3CB15B": {
        "oui_hex": "3C-B1-5B",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "3475C7": {
        "oui_hex": "34-75-C7",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "B0ADAA": {
        "oui_hex": "B0-AD-AA",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "B4475E": {
        "oui_hex": "B4-47-5E",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "B8BC1B": {
        "oui_hex": "B8-BC-1B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "582AF7": {
        "oui_hex": "58-2A-F7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "24D921": {
        "oui_hex": "24-D9-21",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "848371": {
        "oui_hex": "84-83-71",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "001B4F": {
        "oui_hex": "00-1B-4F",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "4C8BEF": {
        "oui_hex": "4C-8B-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5006AB": {
        "oui_hex": "50-06-AB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "FC48EF": {
        "oui_hex": "FC-48-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "707BE8": {
        "oui_hex": "70-7B-E8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "4C1FCC": {
        "oui_hex": "4C-1F-CC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "00906D": {
        "oui_hex": "00-90-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0090AB": {
        "oui_hex": "00-90-AB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "005054": {
        "oui_hex": "00-50-54",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00500B": {
        "oui_hex": "00-50-0B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0003DD": {
        "oui_hex": "00-03-DD",
        "organization": "Comark Interactive Solutions",
        "address_1": "93 West St.",
        "address_2": "Medfield  MA  02052",
        "country": "US"
    },
    "005053": {
        "oui_hex": "00-50-53",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "005050": {
        "oui_hex": "00-50-50",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D4B110": {
        "oui_hex": "D4-B1-10",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "E468A3": {
        "oui_hex": "E4-68-A3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "247189": {
        "oui_hex": "24-71-89",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "987BF3": {
        "oui_hex": "98-7B-F3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "A0F6FD": {
        "oui_hex": "A0-F6-FD",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "D0B5C2": {
        "oui_hex": "D0-B5-C2",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "78A504": {
        "oui_hex": "78-A5-04",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "6CECEB": {
        "oui_hex": "6C-EC-EB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "3400A3": {
        "oui_hex": "34-00-A3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "00902B": {
        "oui_hex": "00-90-2B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E08F": {
        "oui_hex": "00-E0-8F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001868": {
        "oui_hex": "00-18-68",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "887556": {
        "oui_hex": "88-75-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "FC9947": {
        "oui_hex": "FC-99-47",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "6C2056": {
        "oui_hex": "6C-20-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0015F2": {
        "oui_hex": "00-15-F2",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "No.5 Shing Yeh Street,Kwei Shan Hsiang,Taoyuan",
        "address_2": "Taipei    333",
        "country": "TW"
    },
    "90E6BA": {
        "oui_hex": "90-E6-BA",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "002618": {
        "oui_hex": "00-26-18",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "F46D04": {
        "oui_hex": "F4-6D-04",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "00E018": {
        "oui_hex": "00-E0-18",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "150 LI-TE RD.",
        "address_2": "PEITOU, TAIPEI    77777",
        "country": "TW"
    },
    "000C6E": {
        "oui_hex": "00-0C-6E",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "150, Li-Te Rd., PeiTou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "000EA6": {
        "oui_hex": "00-0E-A6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "150, Li-Te Rd., PeiTou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "001D60": {
        "oui_hex": "00-1D-60",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "6C416A": {
        "oui_hex": "6C-41-6A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "ECE1A9": {
        "oui_hex": "EC-E1-A9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C067AF": {
        "oui_hex": "C0-67-AF",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "ACF2C5": {
        "oui_hex": "AC-F2-C5",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "2401C7": {
        "oui_hex": "24-01-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "6886A7": {
        "oui_hex": "68-86-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C0255C": {
        "oui_hex": "C0-25-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3C0E23": {
        "oui_hex": "3C-0E-23",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "08CC68": {
        "oui_hex": "08-CC-68",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0C2724": {
        "oui_hex": "0C-27-24",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "6CFA89": {
        "oui_hex": "6C-FA-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00E0A3": {
        "oui_hex": "00-E0-A3",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "602AD0": {
        "oui_hex": "60-2A-D0",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "745E1C": {
        "oui_hex": "74-5E-1C",
        "organization": "PIONEER CORPORATION",
        "address_1": "1-1 Shin-ogura",
        "address_2": "Kawasaki-shi  Kanagawa Prefecture  2120031",
        "country": "JP"
    },
    "046273": {
        "oui_hex": "04-62-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "D8B190": {
        "oui_hex": "D8-B1-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "80E86F": {
        "oui_hex": "80-E8-6F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "AC7E8A": {
        "oui_hex": "AC-7E-8A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1CE85D": {
        "oui_hex": "1C-E8-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A89D21": {
        "oui_hex": "A8-9D-21",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "689CE2": {
        "oui_hex": "68-9C-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0023BE": {
        "oui_hex": "00-23-BE",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "185933": {
        "oui_hex": "18-59-33",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "445829": {
        "oui_hex": "44-58-29",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "F44E05": {
        "oui_hex": "F4-4E-05",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "881DFC": {
        "oui_hex": "88-1D-FC",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001011": {
        "oui_hex": "00-10-11",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00000C": {
        "oui_hex": "00-00-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "28CFE9": {
        "oui_hex": "28-CF-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00A040": {
        "oui_hex": "00-A0-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0F849": {
        "oui_hex": "A0-F8-49",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3CD0F8": {
        "oui_hex": "3C-D0-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "680927": {
        "oui_hex": "68-09-27",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6CC26B": {
        "oui_hex": "6C-C2-6B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "44D884": {
        "oui_hex": "44-D8-84",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002608": {
        "oui_hex": "00-26-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0026B0": {
        "oui_hex": "00-26-B0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0026BB": {
        "oui_hex": "00-26-BB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D49A20": {
        "oui_hex": "D4-9A-20",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F81EDF": {
        "oui_hex": "F8-1E-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C82A14": {
        "oui_hex": "C8-2A-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C0754": {
        "oui_hex": "3C-07-54",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A4B197": {
        "oui_hex": "A4-B1-97",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0B479": {
        "oui_hex": "F0-B4-79",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1093E9": {
        "oui_hex": "10-93-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "442A60": {
        "oui_hex": "44-2A-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A4D1D2": {
        "oui_hex": "A4-D1-D2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28CFDA": {
        "oui_hex": "28-CF-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "003065": {
        "oui_hex": "00-30-65",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001451": {
        "oui_hex": "00-14-51",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001E52": {
        "oui_hex": "00-1E-52",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0021E9": {
        "oui_hex": "00-21-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC08E0": {
        "oui_hex": "CC-08-E0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "045453": {
        "oui_hex": "04-54-53",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F4F951": {
        "oui_hex": "F4-F9-51",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C06394": {
        "oui_hex": "C0-63-94",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18AF8F": {
        "oui_hex": "18-AF-8F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8B5B7": {
        "oui_hex": "C8-B5-B7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90B21F": {
        "oui_hex": "90-B2-1F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "30F7C5": {
        "oui_hex": "30-F7-C5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "40B395": {
        "oui_hex": "40-B3-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "44FB42": {
        "oui_hex": "44-FB-42",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E88D28": {
        "oui_hex": "E8-8D-28",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "949426": {
        "oui_hex": "94-94-26",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "207D74": {
        "oui_hex": "20-7D-74",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F4F15A": {
        "oui_hex": "F4-F1-5A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C86F1D": {
        "oui_hex": "C8-6F-1D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3090AB": {
        "oui_hex": "30-90-AB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C2DAA": {
        "oui_hex": "8C-2D-AA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "848506": {
        "oui_hex": "84-85-06",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98FE94": {
        "oui_hex": "98-FE-94",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D8004D": {
        "oui_hex": "D8-00-4D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64200C": {
        "oui_hex": "64-20-0C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8334B": {
        "oui_hex": "C8-33-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64E682": {
        "oui_hex": "64-E6-82",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8E856": {
        "oui_hex": "B8-E8-56",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D89695": {
        "oui_hex": "D8-96-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1499E2": {
        "oui_hex": "14-99-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B418D1": {
        "oui_hex": "B4-18-D1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C207B": {
        "oui_hex": "9C-20-7B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B065BD": {
        "oui_hex": "B0-65-BD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "542696": {
        "oui_hex": "54-26-96",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64A3CB": {
        "oui_hex": "64-A3-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "903C92": {
        "oui_hex": "90-3C-92",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D81D72": {
        "oui_hex": "D8-1D-72",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "341298": {
        "oui_hex": "34-12-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70E72C": {
        "oui_hex": "70-E7-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70ECE4": {
        "oui_hex": "70-EC-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68AE20": {
        "oui_hex": "68-AE-20",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC87A3": {
        "oui_hex": "AC-87-A3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D8BB2C": {
        "oui_hex": "D8-BB-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D04F7E": {
        "oui_hex": "D0-4F-7E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2078F0": {
        "oui_hex": "20-78-F0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0ACCB": {
        "oui_hex": "E0-AC-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0999B": {
        "oui_hex": "A0-99-9B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24240E": {
        "oui_hex": "24-24-0E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0DBF8": {
        "oui_hex": "F0-DB-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48746E": {
        "oui_hex": "48-74-6E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "54AE27": {
        "oui_hex": "54-AE-27",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCE998": {
        "oui_hex": "FC-E9-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0CBC9F": {
        "oui_hex": "0C-BC-9F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34363B": {
        "oui_hex": "34-36-3B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0A637": {
        "oui_hex": "D0-A6-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "789F70": {
        "oui_hex": "78-9F-70",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9CF387": {
        "oui_hex": "9C-F3-87",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A85B78": {
        "oui_hex": "A8-5B-78",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8F650": {
        "oui_hex": "C8-F6-50",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A88E24": {
        "oui_hex": "A8-8E-24",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C4A39": {
        "oui_hex": "6C-4A-39",
        "organization": "BITA",
        "address_1": "6/F, New Century Hotel Office Tower",
        "address_2": "  BEI JING  100044",
        "country": "CN"
    },
    "847D50": {
        "oui_hex": "84-7D-50",
        "organization": "Holley Metering Limited",
        "address_1": "181 Wuchang Avenue",
        "address_2": "Hangzhou  Zhejiang  310023",
        "country": "CN"
    },
    "50D59C": {
        "oui_hex": "50-D5-9C",
        "organization": "Thai Habel Industrial Co., Ltd.",
        "address_1": "3/1 - 3/3 RAMA 3 RD,",
        "address_2": "ฺBangkholaem  Bangkok  10120",
        "country": "TH"
    },
    "20896F": {
        "oui_hex": "20-89-6F",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "3052CB": {
        "oui_hex": "30-52-CB",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "049645": {
        "oui_hex": "04-96-45",
        "organization": "WUXI SKY CHIP INTERCONNECTION TECHNOLOGY CO.,LTD.",
        "address_1": "Building F12, China Sensor Network International Innovation park,200# Linghu Avenue,Wuxi.",
        "address_2": "WUXI  Jiangsu  214135",
        "country": "CN"
    },
    "1CCDE5": {
        "oui_hex": "1C-CD-E5",
        "organization": "Shanghai Wind Technologies Co.,Ltd",
        "address_1": "Room 208,Section A, Building 3#, No.7 GuiQing Road, Xuhui District, Shanghai, China(Headquarter)",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "681401": {
        "oui_hex": "68-14-01",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "50A9DE": {
        "oui_hex": "50-A9-DE",
        "organization": "Smartcom - Bulgaria AD",
        "address_1": "BIC IZOT, Building 1, Floor 3, Office 317",
        "address_2": "Sofia  Sofia  1784",
        "country": "BG"
    },
    "AC1FD7": {
        "oui_hex": "AC-1F-D7",
        "organization": "Real Vision Technology Co.,Ltd.",
        "address_1": "A-805, 537, Dunchon-daero, Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13216",
        "country": "KR"
    },
    "88C242": {
        "oui_hex": "88-C2-42",
        "organization": "Poynt Co.",
        "address_1": "490 S. California Avenue",
        "address_2": "Palo Alto  California  94306",
        "country": "US"
    },
    "1402EC": {
        "oui_hex": "14-02-EC",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "E034E4": {
        "oui_hex": "E0-34-E4",
        "organization": "Feit Electric Company, Inc.",
        "address_1": "4901 Gregg Road",
        "address_2": "Pico Rivera  CA  90660",
        "country": "US"
    },
    "34C9F0": {
        "oui_hex": "34-C9-F0",
        "organization": "LM Technologies Ltd",
        "address_1": "Unit 19 Spectrum House",
        "address_2": "London  England  NW5 1LP",
        "country": "GB"
    },
    "68A828": {
        "oui_hex": "68-A8-28",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CC20E8": {
        "oui_hex": "CC-20-E8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48BF74": {
        "oui_hex": "48-BF-74",
        "organization": "Baicells Technologies Co.,LTD",
        "address_1": "10F,Dinghao Electronics Plaza-B,No.3 Haidian St.,Haidian Dist.,Beijing,China",
        "address_2": "Beijing  Beijing  10080",
        "country": "CN"
    },
    "6C9354": {
        "oui_hex": "6C-93-54",
        "organization": "Yaojin Technology (Shenzhen) Co., LTD.",
        "address_1": " No.18,Zhulong Tian Road,Shuitian No.4 Industrial Area,Shiyan Street, Baoan District,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "DCDC07": {
        "oui_hex": "DC-DC-07",
        "organization": "TRP Systems BV",
        "address_1": "Televisieweg 159 1322 BH  Almere",
        "address_2": "Almere  -  -",
        "country": "NL"
    },
    "3891D5": {
        "oui_hex": "38-91-D5",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "8CE2DA": {
        "oui_hex": "8C-E2-DA",
        "organization": "Circle Media Inc",
        "address_1": "1319 SE Martin Luther King Jr. Blvd.",
        "address_2": "Portland  Oregon  97214",
        "country": "US"
    },
    "382187": {
        "oui_hex": "38-21-87",
        "organization": "Midea Group Co., Ltd.",
        "address_1": "No. 6 Midea Avenue,",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "78D6B2": {
        "oui_hex": "78-D6-B2",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "E8DED6": {
        "oui_hex": "E8-DE-D6",
        "organization": "Intrising Networks, Inc.",
        "address_1": "8F., No.67, Shitan Rd., Neihu Dist., Taipei City 11469",
        "address_2": "Taipei",
        "country": "TW"
    },
    "DC82F6": {
        "oui_hex": "DC-82-F6",
        "organization": "iPort",
        "address_1": "236 Calle Pintoresco",
        "address_2": "San Clemente  CA  92672",
        "country": "US"
    },
    "70480F": {
        "oui_hex": "70-48-0F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CB72B": {
        "oui_hex": "3C-B7-2B",
        "organization": "PLUMgrid Inc",
        "address_1": "5155 OLD IRONSIDES DR",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "489A42": {
        "oui_hex": "48-9A-42",
        "organization": "Technomate Ltd",
        "address_1": "Unit 11 Nobel Road",
        "address_2": "London    N18 3BH",
        "country": "GB"
    },
    "20D160": {
        "oui_hex": "20-D1-60",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "BC9C31": {
        "oui_hex": "BC-9C-31",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D88B4C": {
        "oui_hex": "D8-8B-4C",
        "organization": "KingTing Tech.",
        "address_1": "8 Holly St",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "384C90": {
        "oui_hex": "38-4C-90",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F0B0E7": {
        "oui_hex": "F0-B0-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "381C23": {
        "oui_hex": "38-1C-23",
        "organization": "Hilan Technology CO.,LTD",
        "address_1": "604,Block 1,Kai Da Er Building,No.168 TongSha Road,XiLi Town,Nanshan,Shenzhen,P.R.C",
        "address_2": "Shenzhen  Guandong  518055",
        "country": "CN"
    },
    "649A12": {
        "oui_hex": "64-9A-12",
        "organization": "P2 Mobile Technologies Limited",
        "address_1": "Unit 708, 7/F, Bio-Informatics Centre, No.2 Science Park West Avenue,",
        "address_2": "Hong Kong  Hong Kong  00000",
        "country": "HK"
    },
    "AC8995": {
        "oui_hex": "AC-89-95",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "0469F8": {
        "oui_hex": "04-69-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3029BE": {
        "oui_hex": "30-29-BE",
        "organization": "Shanghai MRDcom Co.,Ltd",
        "address_1": "NO.123 JULI RD",
        "address_2": "SHANGHAI  PUDONG ZHANGJIANG HIGH-TECH PARK  201203",
        "country": "CN"
    },
    "20C3A4": {
        "oui_hex": "20-C3-A4",
        "organization": "RetailNext",
        "address_1": "60 S. Market St, 10th Floor",
        "address_2": "San Jose  CA  95113",
        "country": "US"
    },
    "E4C2D1": {
        "oui_hex": "E4-C2-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D4F4BE": {
        "oui_hex": "D4-F4-BE",
        "organization": "Palo Alto Networks",
        "address_1": "4401 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "48B620": {
        "oui_hex": "48-B6-20",
        "organization": "ROLI Ltd.",
        "address_1": "2 Glebe Road",
        "address_2": "London    E8 4BD",
        "country": "GB"
    },
    "D888CE": {
        "oui_hex": "D8-88-CE",
        "organization": "RF Technology Pty Ltd",
        "address_1": "46/7 Sefton Rd",
        "address_2": "Thornleigh  NSW  2120",
        "country": "AU"
    },
    "307CB2": {
        "oui_hex": "30-7C-B2",
        "organization": "ANOV FRANCE",
        "address_1": "100 CHEMIN DE BAILLOT",
        "address_2": "MONTAUBAN  TARN ET GARONNE  82000",
        "country": "FR"
    },
    "847973": {
        "oui_hex": "84-79-73",
        "organization": "Shanghai Baud Data Communication Co.,Ltd.",
        "address_1": "NO.123 JULI RD",
        "address_2": "PUDONG ZHANGJIANG HIGH-TECH PARK  SHANGHAI  201203",
        "country": "CN"
    },
    "E8B4C8": {
        "oui_hex": "E8-B4-C8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D087E2": {
        "oui_hex": "D0-87-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F05B7B": {
        "oui_hex": "F0-5B-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B047BF": {
        "oui_hex": "B0-47-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C0BC6": {
        "oui_hex": "7C-0B-C6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7CFE90": {
        "oui_hex": "7C-FE-90",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "845B12": {
        "oui_hex": "84-5B-12",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "205531": {
        "oui_hex": "20-55-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "10868C": {
        "oui_hex": "10-86-8C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "44FDA3": {
        "oui_hex": "44-FD-A3",
        "organization": "Everysight LTD.",
        "address_1": "Advanced Technology Center P.O.B 539",
        "address_2": "Haifa  Haifa  31053",
        "country": "IL"
    },
    "A8A795": {
        "oui_hex": "A8-A7-95",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "906FA9": {
        "oui_hex": "90-6F-A9",
        "organization": "NANJING PUTIAN TELECOMMUNICATIONS TECHNOLOGY CO.,LTD.",
        "address_1": "No.1 Putian Road,Yuhuamenwai,Nanjing",
        "address_2": "Nan Jing  Jiang Su  210022",
        "country": "CN"
    },
    "60FD56": {
        "oui_hex": "60-FD-56",
        "organization": "WOORISYSTEMS CO., Ltd",
        "address_1": "357-4, Neungpyeong-ri, Opo-eup",
        "address_2": "Gwangjiu-si  Gyeonggi-do  464-921",
        "country": "KR"
    },
    "9870E8": {
        "oui_hex": "98-70-E8",
        "organization": "INNATECH SDN BHD",
        "address_1": "2, JALAN TIARA 3, TIARA SQUARE",
        "address_2": "SUBANG JAYA  SELANGOR  47600",
        "country": "MY"
    },
    "44656A": {
        "oui_hex": "44-65-6A",
        "organization": "Mega Video Electronic(HK) Industry Co., Ltd",
        "address_1": "Room 503, No.43 Fushun Street, Huanghai West Road,",
        "address_2": "Dalian  Liaoning  116600",
        "country": "CN"
    },
    "78EB39": {
        "oui_hex": "78-EB-39",
        "organization": "Instituto Nacional de Tecnología Industrial",
        "address_1": "Av. Gral. Paz 5445",
        "address_2": "San Martín  Buenos Aires  1650",
        "country": "AR"
    },
    "0C756C": {
        "oui_hex": "0C-75-6C",
        "organization": "Anaren Microwave, Inc.",
        "address_1": "6635 Kirkville Road",
        "address_2": "East Syracuse  NY  13057",
        "country": "US"
    },
    "D47BB0": {
        "oui_hex": "D4-7B-B0",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "F0224E": {
        "oui_hex": "F0-22-4E",
        "organization": "Esan electronic co.",
        "address_1": "D&I Building 2nd floor",
        "address_2": "Gun-Po  Kyunggido  435-862",
        "country": "KR"
    },
    "CC5FBF": {
        "oui_hex": "CC-5F-BF",
        "organization": "Topwise 3G Communication Co., Ltd.",
        "address_1": "6 Floor, A8 Music Building, Keyuan Road, High-Tech Park, Nanshan District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C8F9C8": {
        "oui_hex": "C8-F9-C8",
        "organization": "NewSharp Technology(SuZhou)Co,Ltd",
        "address_1": "1st/f.building 7th No.328 XingHu street SuZhou City",
        "address_2": "SuZhou City  JiangSu Province  215123",
        "country": "CN"
    },
    "80C5E6": {
        "oui_hex": "80-C5-E6",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "10DF8B": {
        "oui_hex": "10-DF-8B",
        "organization": "Shenzhen CareDear Communication Technology Co.,Ltd",
        "address_1": "No.605,6th floor, 1st Section, 25th Building, Science and Technology Park Industrial Zone, median space, High-tech Zone",
        "address_2": "ShenZhen  Guangdong  518000",
        "country": "CN"
    },
    "C412F5": {
        "oui_hex": "C4-12-F5",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "5C4527": {
        "oui_hex": "5C-45-27",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E02CB2": {
        "oui_hex": "E0-2C-B2",
        "organization": "Lenovo Mobile Communication (Wuhan) Company Limited",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan, China  430205",
        "address_2": "Wuhan  Hubei  430205",
        "country": "CN"
    },
    "606DC7": {
        "oui_hex": "60-6D-C7",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "68EDA4": {
        "oui_hex": "68-ED-A4",
        "organization": "Shenzhen Seavo Technology Co.,Ltd",
        "address_1": "5H,West Building,NO.210,Terra Hi-Tech Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "2CC5D3": {
        "oui_hex": "2C-C5-D3",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F4573E": {
        "oui_hex": "F4-57-3E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D0431E": {
        "oui_hex": "D0-43-1E",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "54CD10": {
        "oui_hex": "54-CD-10",
        "organization": "Panasonic Mobile Communications Co.,Ltd.",
        "address_1": "600 Saedo-cho Tsuzuki-ku",
        "address_2": "Yokohama City  Kanagawa  224-8539",
        "country": "JP"
    },
    "408D5C": {
        "oui_hex": "40-8D-5C",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "FCE1FB": {
        "oui_hex": "FC-E1-FB",
        "organization": "Array Networks",
        "address_1": "1371 McCarthy Blvd",
        "address_2": "Milpitas  California  95035",
        "country": "US"
    },
    "E89120": {
        "oui_hex": "E8-91-20",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "D4F9A1": {
        "oui_hex": "D4-F9-A1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5440AD": {
        "oui_hex": "54-40-AD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A424DD": {
        "oui_hex": "A4-24-DD",
        "organization": "Cambrionix Ltd",
        "address_1": "St Johns Innovation Centre",
        "address_2": "Cambridge  Cambridgeshire  CB4 0WS",
        "country": "GB"
    },
    "145A83": {
        "oui_hex": "14-5A-83",
        "organization": "Logi-D inc",
        "address_1": "5550 Des Rossignol Blvd",
        "address_2": "Laval  Quebec  H7L 5W6",
        "country": "CA"
    },
    "804E81": {
        "oui_hex": "80-4E-81",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C09A71": {
        "oui_hex": "C0-9A-71",
        "organization": "XIAMEN MEITU MOBILE TECHNOLOGY CO.LTD",
        "address_1": "1-3F, Block2, No.6 Wanghai Rd,Siming District, Xiamen, Fujian, China (”MEITU”)",
        "address_2": "Xiamen  Fujian  361008",
        "country": "CN"
    },
    "64167F": {
        "oui_hex": "64-16-7F",
        "organization": "Polycom",
        "address_1": "6001 America Center Drive",
        "address_2": "San Jose  CA  95002",
        "country": "US"
    },
    "340B40": {
        "oui_hex": "34-0B-40",
        "organization": "MIOS ELETTRONICA SRL",
        "address_1": "VIA ARCHIMEDE, 10",
        "address_2": "SAN MARTINO B.A. (VR)  VERONA  37036",
        "country": "IT"
    },
    "48066A": {
        "oui_hex": "48-06-6A",
        "organization": "Tempered Networks, Inc.",
        "address_1": "100 West Harrison St",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "BCF811": {
        "oui_hex": "BC-F8-11",
        "organization": "Xiamen DNAKE Technology Co.,Ltd",
        "address_1": "5F,Xingtel Building,Chuangxin Rd.",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "900A39": {
        "oui_hex": "90-0A-39",
        "organization": "Wiio, Inc.",
        "address_1": "99 S. Almaden Boulevard",
        "address_2": "San Jose  California  95113",
        "country": "US"
    },
    "D0C0BF": {
        "oui_hex": "D0-C0-BF",
        "organization": "Actions Microelectronics Co., Ltd",
        "address_1": "201, No 9 Building, Software Park,Kejizhonger Rd.,",
        "address_2": "Shenzhen  Gangdong  518057",
        "country": "CN"
    },
    "E861BE": {
        "oui_hex": "E8-61-BE",
        "organization": "Melec Inc.",
        "address_1": "516-10 Higashiasakawamachi",
        "address_2": "Hachioji  Tokyo  193-0834",
        "country": "JP"
    },
    "5870C6": {
        "oui_hex": "58-70-C6",
        "organization": "Shanghai Xiaoyi Technology Co., Ltd.",
        "address_1": "Shanghai Zhangjiang hi-tech park of Pudong New Area",
        "address_2": "Shanghai  Shanghai  201120",
        "country": "CN"
    },
    "FC8F90": {
        "oui_hex": "FC-8F-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "74042B": {
        "oui_hex": "74-04-2B",
        "organization": "Lenovo Mobile Communication (Wuhan) Company Limited",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan, China  430205",
        "address_2": "Wuhan  Hubei  430205",
        "country": "CN"
    },
    "F87AEF": {
        "oui_hex": "F8-7A-EF",
        "organization": "Rosonix Technology, Inc.",
        "address_1": "10F, No.235, Sec. 4, Chengde Rd.,",
        "address_2": "Taipei  Taiwan  11167",
        "country": "TW"
    },
    "2028BC": {
        "oui_hex": "20-28-BC",
        "organization": "Visionscape Co,. Ltd.",
        "address_1": "503, 145, Gasan Digital 1-ro, Geumcheon-gu,",
        "address_2": "Seoul  Korea  153-787",
        "country": "KR"
    },
    "241C04": {
        "oui_hex": "24-1C-04",
        "organization": "SHENZHEN JEHE TECHNOLOGY DEVELOPMENT CO., LTD.",
        "address_1": "2/F, Block A, Tsinghua Information Harbor, North Section",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D05C7A": {
        "oui_hex": "D0-5C-7A",
        "organization": "Sartura d.o.o.",
        "address_1": "Kuniscak 28",
        "address_2": "  Zagreb  10000",
        "country": "HR"
    },
    "BC5C4C": {
        "oui_hex": "BC-5C-4C",
        "organization": "ELECOM CO.,LTD.",
        "address_1": "11F Tokyubancho Bldg. 6-2,",
        "address_2": "Chiyoda-ku  Tokyo  102-0081",
        "country": "JP"
    },
    "887033": {
        "oui_hex": "88-70-33",
        "organization": "Hangzhou Silan Microelectronic Inc",
        "address_1": "No.4 HuangGuShan Road",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "DC56E6": {
        "oui_hex": "DC-56-E6",
        "organization": "Shenzhen Bococom Technology Co.,LTD",
        "address_1": "303, Dongjiang Environmental Build, LangShan Road.",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "CC9635": {
        "oui_hex": "CC-96-35",
        "organization": "LVS Co.,Ltd.",
        "address_1": "SmartValley B # 801",
        "address_2": "Incheon    406-840",
        "country": "KR"
    },
    "4480EB": {
        "oui_hex": "44-80-EB",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "402814": {
        "oui_hex": "40-28-14",
        "organization": "RFI Engineering",
        "address_1": "Markerkant 13-76",
        "address_2": "Almere  Flevoland  1314AN",
        "country": "NL"
    },
    "144146": {
        "oui_hex": "14-41-46",
        "organization": "Honeywell (China) Co., LTD",
        "address_1": "No. 100, Zunyi Road, Changning District",
        "address_2": "Shanghai  Shanghai  200051",
        "country": "CN"
    },
    "94F19E": {
        "oui_hex": "94-F1-9E",
        "organization": "HUIZHOU MAORONG INTELLIGENT TECHNOLOGY CO.,LTD",
        "address_1": "China Guangdong Huizhou",
        "address_2": "Huizhou  Guangdong  516000",
        "country": "CN"
    },
    "B856BD": {
        "oui_hex": "B8-56-BD",
        "organization": "ITT LLC",
        "address_1": "1-ya Brestkaya St, building 35",
        "address_2": "  Moscow  125047",
        "country": "RU"
    },
    "40A5EF": {
        "oui_hex": "40-A5-EF",
        "organization": "Shenzhen Four Seas Global Link Network Technology Co., Ltd.",
        "address_1": "Room 607-610, Block B, TAOJINDI Electronic Business Incubation Base",
        "address_2": "Tenglong Road, Longhua District,   Shenzhen Guangdong  518000",
        "country": "CN"
    },
    "C4924C": {
        "oui_hex": "C4-92-4C",
        "organization": "KEISOKUKI CENTER CO.,LTD.",
        "address_1": "2-6-7 SAKANE",
        "address_2": "KAWANISHI-CITY  HYOGO  666-0021",
        "country": "JP"
    },
    "749CE3": {
        "oui_hex": "74-9C-E3",
        "organization": "KodaCloud Canada, Inc",
        "address_1": "Suite 310",
        "address_2": "Ottawa  Ontario  K2K3G4",
        "country": "CA"
    },
    "D45556": {
        "oui_hex": "D4-55-56",
        "organization": "Fiber Mountain Inc.",
        "address_1": "700 W Johnson Ave",
        "address_2": "Cheshire  CT  06410",
        "country": "US"
    },
    "50502A": {
        "oui_hex": "50-50-2A",
        "organization": "Egardia",
        "address_1": "Kleine Landtong 19",
        "address_2": "Gorinchem  Zuid Holland  4201 HL",
        "country": "NL"
    },
    "749637": {
        "oui_hex": "74-96-37",
        "organization": "Todaair Electronic Co., Ltd",
        "address_1": "F.6 Electronic Building, No.1 Shuinan Guangdeli Road，Peng’Jiang District, Jiangmen, Guangdong, China",
        "address_2": "JiangMen  Guangdong  529000",
        "country": "CN"
    },
    "88E603": {
        "oui_hex": "88-E6-03",
        "organization": "Avotek corporation",
        "address_1": "9-17, Dongil-ro 174-gil, Nowon-gu, Seoul",
        "address_2": "Seoul  Seoul  139-808",
        "country": "KR"
    },
    "2CAD13": {
        "oui_hex": "2C-AD-13",
        "organization": "SHENZHEN ZHILU TECHNOLOGY CO.,LTD",
        "address_1": "B2-402 Kexin Science Park, Keyuan Road, Hi-tech Park, Nanshan District, Shenzhen",
        "address_2": "shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "78ACBF": {
        "oui_hex": "78-AC-BF",
        "organization": "Igneous Systems",
        "address_1": "2401 4th Ave",
        "address_2": "Seattle  WA  98121",
        "country": "US"
    },
    "C48E8F": {
        "oui_hex": "C4-8E-8F",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C4366C": {
        "oui_hex": "C4-36-6C",
        "organization": "LG Innotek",
        "address_1": "Jangduk-dong 978-1",
        "address_2": "Gwang-ju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "54369B": {
        "oui_hex": "54-36-9B",
        "organization": "1Verge Internet Technology (Beijing) Co., Ltd.",
        "address_1": "5th Floor, Sinosteel International Plaza",
        "address_2": "Haidian District  Beijing",
        "country": "CN"
    },
    "40D28A": {
        "oui_hex": "40-D2-8A",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "4062B6": {
        "oui_hex": "40-62-B6",
        "organization": "Tele system communication",
        "address_1": "5F, No.437, Tao Ying Rd",
        "address_2": "Taoyuan    33068",
        "country": "TW"
    },
    "60128B": {
        "oui_hex": "60-12-8B",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "84C3E8": {
        "oui_hex": "84-C3-E8",
        "organization": "Vaillant GmbH",
        "address_1": "Berghauser Straße 40",
        "address_2": "Remscheid  NRW  D-42859",
        "country": "DE"
    },
    "9CD35B": {
        "oui_hex": "9C-D3-5B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A89FBA": {
        "oui_hex": "A8-9F-BA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B88EC6": {
        "oui_hex": "B8-8E-C6",
        "organization": "Stateless Networks",
        "address_1": "388 Market Street",
        "address_2": "San Francisco  CA  94111",
        "country": "US"
    },
    "BCD165": {
        "oui_hex": "BC-D1-65",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "28E476": {
        "oui_hex": "28-E4-76",
        "organization": "Pi-Coral",
        "address_1": "2130 Gold Street, Ste. 200",
        "address_2": "San Jose  CA - California  95002",
        "country": "US"
    },
    "4CA515": {
        "oui_hex": "4C-A5-15",
        "organization": "Baikal Electronics JSC",
        "address_1": "Highway Baltic 26 km, BC 'RigaLand, Block B, 3-rd entrance, 2-nd floor.",
        "address_2": "Krasnogorsk district  Moscow region  143421",
        "country": "RU"
    },
    "7C3CB6": {
        "oui_hex": "7C-3C-B6",
        "organization": "Shenzhen Homecare Technology Co.,Ltd.",
        "address_1": "Homecare Industrial Zone,NO.30,Langdong road,Yangchuan,Songgang Town,Bao'an Distric ,",
        "address_2": "Shenzhen  Guangdong  5108105",
        "country": "CN"
    },
    "1C7D22": {
        "oui_hex": "1C-7D-22",
        "organization": "Fuji Xerox Co., Ltd.",
        "address_1": "6-1 Minatomirai, Nishi-ku",
        "address_2": "Yokohama  Kanagawa  220-8668",
        "country": "JP"
    },
    "20C06D": {
        "oui_hex": "20-C0-6D",
        "organization": "SHENZHEN SPACETEK TECHNOLOGY CO.,LTD",
        "address_1": "3F, NO.2, ChaXiSanWei Industrial Park, Gushu Community, XiXiang Street, BaoAn District",
        "address_2": "ShenZhen  GuangDong  518100",
        "country": ""
    },
    "4886E8": {
        "oui_hex": "48-86-E8",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "74A34A": {
        "oui_hex": "74-A3-4A",
        "organization": "ZIMI CORPORATION",
        "address_1": "Room A913, 159 Chengjiang Road, Jiangyin City, Jiangsu Province, P, R.China",
        "address_2": "    214400",
        "country": "CN"
    },
    "A86405": {
        "oui_hex": "A8-64-05",
        "organization": "nimbus 9, Inc",
        "address_1": "29 W. Cimarron St.",
        "address_2": "Colorado Springs  CO  80903",
        "country": "US"
    },
    "30D587": {
        "oui_hex": "30-D5-87",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#416, Maetan 3-dong",
        "address_2": "Suwon-si  Gyeonggi-do  443-742",
        "country": "KR"
    },
    "6828F6": {
        "oui_hex": "68-28-F6",
        "organization": "Vubiq Networks, Inc.",
        "address_1": "9231 Irvine Blvd.",
        "address_2": "Irvine  California  92618",
        "country": "US"
    },
    "DC60A1": {
        "oui_hex": "DC-60-A1",
        "organization": "Teledyne DALSA Professional Imaging",
        "address_1": "High Tech Campus 27",
        "address_2": "Eindhoven  NB  5656 AE",
        "country": "NL"
    },
    "10A659": {
        "oui_hex": "10-A6-59",
        "organization": "Mobile Create Co.,Ltd.",
        "address_1": "Kakukita 2-20-8",
        "address_2": "Oita    870-0848",
        "country": "JP"
    },
    "58856E": {
        "oui_hex": "58-85-6E",
        "organization": "QSC AG",
        "address_1": "Mathias-Brueggen-Str. 55",
        "address_2": "Köln    50829",
        "country": "DE"
    },
    "8C9109": {
        "oui_hex": "8C-91-09",
        "organization": "Toyoshima Electric Technoeogy(Suzhou) Co.,Ltd.",
        "address_1": "No.399,Baisheng Road,Jinxi Town",
        "address_2": "Kunshan  Jiangsu  215324",
        "country": "CN"
    },
    "54098D": {
        "oui_hex": "54-09-8D",
        "organization": "deister electronic GmbH",
        "address_1": "Hermann-Bahlsen-Str. 11",
        "address_2": "Barsinghausen  Niedersachsen  30890",
        "country": "DE"
    },
    "D05BA8": {
        "oui_hex": "D0-5B-A8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E4BAD9": {
        "oui_hex": "E4-BA-D9",
        "organization": "360 Fly Inc.",
        "address_1": "1000 Town Center Blvd",
        "address_2": "Canonsburg  PA  15317",
        "country": "US"
    },
    "EC59E7": {
        "oui_hex": "EC-59-E7",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "C035C5": {
        "oui_hex": "C0-35-C5",
        "organization": "Prosoft Systems LTD",
        "address_1": "Volgogradskaya 194-a",
        "address_2": "Ekaterinburg  Sverdlovskay  620102",
        "country": "RU"
    },
    "A0A3E2": {
        "oui_hex": "A0-A3-E2",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "74547D": {
        "oui_hex": "74-54-7D",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "00E6E8": {
        "oui_hex": "00-E6-E8",
        "organization": "Netzin Technology Corporation,.Ltd.",
        "address_1": "4F-17, No. 26, Lane 321, Yang-Kuang St.,Neihu District, Taipei, Taiwan,",
        "address_2": "Taiwan Taipei  Taiwan Taipei  11491",
        "country": "TW"
    },
    "50F43C": {
        "oui_hex": "50-F4-3C",
        "organization": "Leeo Inc",
        "address_1": "989 Comercial St",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "E887A3": {
        "oui_hex": "E8-87-A3",
        "organization": "Loxley Public Company Limited",
        "address_1": "102 Na Ranong Road, Klongtoey,",
        "address_2": "  Bangkok  10110",
        "country": "TH"
    },
    "10C67E": {
        "oui_hex": "10-C6-7E",
        "organization": "SHENZHEN JUCHIN TECHNOLOGY CO., LTD",
        "address_1": "Unit 423 4/B NO.1, Central Business District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "08A5C8": {
        "oui_hex": "08-A5-C8",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "F88479": {
        "oui_hex": "F8-84-79",
        "organization": "Yaojin Technology(Shenzhen)Co.,Ltd",
        "address_1": "Yaojin Park, Shui Tian No.4 Industrial Area ShiYan Tow,",
        "address_2": "SHENZHEN  GUANGDONG  518108",
        "country": "CN"
    },
    "2C2997": {
        "oui_hex": "2C-29-97",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "D46132": {
        "oui_hex": "D4-61-32",
        "organization": "Pro Concept Manufacturer Co.,Ltd.",
        "address_1": "88/1 Moo12 Soi Phetkasem120",
        "address_2": "Kratumbaen  Samutsakorn  74130",
        "country": "TH"
    },
    "54A050": {
        "oui_hex": "54-A0-50",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "4C2C83": {
        "oui_hex": "4C-2C-83",
        "organization": "Zhejiang KaNong Network Technology Co.,Ltd.",
        "address_1": "Room 633, Building B, ShunFan Technology Park,JingChang Road No.768, YuHang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "908C09": {
        "oui_hex": "90-8C-09",
        "organization": "Total Phase",
        "address_1": "735 Palomar Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "DC2F03": {
        "oui_hex": "DC-2F-03",
        "organization": "Step forward Group Co., Ltd.",
        "address_1": "1/3 Park Village Rama2 Floor 2   C2-2",
        "address_2": "Bangkok  Bangkok  10150",
        "country": "TH"
    },
    "380E7B": {
        "oui_hex": "38-0E-7B",
        "organization": "V.P.S. Thai Co., Ltd",
        "address_1": "279-281 Mangkorn Rd., Pomprab District",
        "address_2": "Bangkok  Bangkok  10100",
        "country": "TH"
    },
    "2C3796": {
        "oui_hex": "2C-37-96",
        "organization": "CYBO CO.,LTD.",
        "address_1": "218 MOO 3 LAEM CHA BANG",
        "address_2": "SRIRACHA  CHONBURI  20230",
        "country": "TH"
    },
    "587FB7": {
        "oui_hex": "58-7F-B7",
        "organization": "SONAR INDUSTRIAL CO., LTD.",
        "address_1": "29, 29/1, 29/2, MOO.3, THATALAD,",
        "address_2": "SAMPRAN  NAKORN PATHOM  73110",
        "country": "TH"
    },
    "08EB29": {
        "oui_hex": "08-EB-29",
        "organization": "Jiangsu Huitong Group Co.,Ltd.",
        "address_1": "No. 24, Block 2, Taohuawu New District",
        "address_2": "Zhenjiang  Jiangsu  212003",
        "country": "CN"
    },
    "409B0D": {
        "oui_hex": "40-9B-0D",
        "organization": "Shenzhen Yourf Kwan Industrial Co., Ltd",
        "address_1": "MCN Edifice 5D, R1 Building, No.21 4th Hi-tech Road South, High-tech Industrial Park(south)",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D8CB8A": {
        "oui_hex": "D8-CB-8A",
        "organization": "Micro-Star INTL CO., LTD.",
        "address_1": "No.69, Lide St.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "70FC8C": {
        "oui_hex": "70-FC-8C",
        "organization": "OneAccess SA",
        "address_1": "381 avenue du général de Gaulle",
        "address_2": "CLAMART   France  92140",
        "country": "FR"
    },
    "58108C": {
        "oui_hex": "58-10-8C",
        "organization": "Intelbras",
        "address_1": "BR 101, km 210, S/N°",
        "address_2": "São José  Santa Catarina  88104800",
        "country": "BR"
    },
    "4C7403": {
        "oui_hex": "4C-74-03",
        "organization": "BQ",
        "address_1": "c Sofía 10. Polígono Európolis",
        "address_2": "Las Rozas de Madrid  Madrid  28230",
        "country": "ES"
    },
    "8C5D60": {
        "oui_hex": "8C-5D-60",
        "organization": "UCI Corporation Co.,Ltd.",
        "address_1": "299/195-7, Chaengwattana Road,",
        "address_2": "Bangkok  Bangkok  10210",
        "country": "TH"
    },
    "BC6B4D": {
        "oui_hex": "BC-6B-4D",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "C8D019": {
        "oui_hex": "C8-D0-19",
        "organization": "Shanghai Tigercel Communication Technology Co.,Ltd",
        "address_1": "Room 805, building 1",
        "address_2": "  Shanghai  200235",
        "country": "CN"
    },
    "902181": {
        "oui_hex": "90-21-81",
        "organization": "Shanghai Huaqin Telecom Technology Co.,Ltd",
        "address_1": "No.1 Building,399 Keyuan Road, Zhangjian Hi-Tech Park,",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "849681": {
        "oui_hex": "84-96-81",
        "organization": "Cathay Communication Co.,Ltd",
        "address_1": "Tsinghua Institude A319 of Hi-tech Park,Nanshan district,Shenzhen China",
        "address_2": "Shenzhen  Canton  0755",
        "country": "CN"
    },
    "2CA30E": {
        "oui_hex": "2C-A3-0E",
        "organization": "POWER DRAGON DEVELOPMENT LIMITED",
        "address_1": "Room D, 10/F Tower A, Billion Centre, 1 Wang Kwong Road, Kowloon Bay",
        "address_2": "HONG KONG  HONG KONG  999077",
        "country": "CN"
    },
    "8486F3": {
        "oui_hex": "84-86-F3",
        "organization": "Greenvity Communications",
        "address_1": "673 S. Milpitas Blvd Suite 204",
        "address_2": "Milpitas  California  95035",
        "country": "US"
    },
    "1C5216": {
        "oui_hex": "1C-52-16",
        "organization": "DONGGUAN HELE ELECTRONICS CO., LTD",
        "address_1": "Lijiangwei Group,",
        "address_2": "Dongguan City  Guangdong  86",
        "country": "CN"
    },
    "6099D1": {
        "oui_hex": "60-99-D1",
        "organization": "Vuzix / Lenovo",
        "address_1": "2166 Brighton Henrietta Town Line Road",
        "address_2": "Rochester  NY  14623",
        "country": "US"
    },
    "B04515": {
        "oui_hex": "B0-45-15",
        "organization": "mira fitness,LLC.",
        "address_1": "1925 West Field Court Suite100",
        "address_2": "Lake Forest  IL  60045",
        "country": "US"
    },
    "14488B": {
        "oui_hex": "14-48-8B",
        "organization": "Shenzhen Doov Technology Co.,Ltd",
        "address_1": "11st Floor,East,2nd Phase",
        "address_2": " Futian District, Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "2012D5": {
        "oui_hex": "20-12-D5",
        "organization": "Scientech Materials Corporation",
        "address_1": "No.7, Hejiang 2nd Rd., Chungli , Taoyuan Hsien 320, Taiwan",
        "address_2": "Taoyuan Hsien  Chungli  320",
        "country": "TW"
    },
    "6C6EFE": {
        "oui_hex": "6C-6E-FE",
        "organization": "Core Logic Inc.",
        "address_1": "11th Fl., 1-B U-SPACE Bldg.",
        "address_2": "Seongnam  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "3808FD": {
        "oui_hex": "38-08-FD",
        "organization": "Silca Spa",
        "address_1": "Via Podgora, 20 (Z.I.)",
        "address_2": "Vittorio Veneto  TV  31029",
        "country": "IT"
    },
    "784561": {
        "oui_hex": "78-45-61",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "94CE31": {
        "oui_hex": "94-CE-31",
        "organization": "CTS Limited",
        "address_1": "1st district, 23D, 21",
        "address_2": "Moscow  -  142784",
        "country": "RU"
    },
    "80F8EB": {
        "oui_hex": "80-F8-EB",
        "organization": "RayTight",
        "address_1": "Room 1-216, Building 25, No 9, Anningzhuang West Road",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "D437D7": {
        "oui_hex": "D4-37-D7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "2C010B": {
        "oui_hex": "2C-01-0B",
        "organization": "NASCENT Technology, LLC - RemKon",
        "address_1": "2744 Yorkmont Road",
        "address_2": "Charlotte  NC  28208",
        "country": ""
    },
    "04DEDB": {
        "oui_hex": "04-DE-DB",
        "organization": "Rockport Networks Inc",
        "address_1": "515 Legget Dr., Suite 600",
        "address_2": "Kanata  ON  K2K 3G4",
        "country": "CA"
    },
    "1C4840": {
        "oui_hex": "1C-48-40",
        "organization": "IMS Messsysteme GmbH",
        "address_1": "Dieselstr. 55",
        "address_2": "Heiligenhaus  NRW  D-42579",
        "country": "DE"
    },
    "6050C1": {
        "oui_hex": "60-50-C1",
        "organization": "Kinetek Sports",
        "address_1": "16885 Via Del Campo Ct.",
        "address_2": "San Diego  Ca  92127",
        "country": "US"
    },
    "2C1A31": {
        "oui_hex": "2C-1A-31",
        "organization": "Electronics Company Limited",
        "address_1": "Units 12,15&16,8/F,Metro Centre 2",
        "address_2": "Kowloon Bay  HongKong  852",
        "country": "CN"
    },
    "90B686": {
        "oui_hex": "90-B6-86",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "ECD9D1": {
        "oui_hex": "EC-D9-D1",
        "organization": "Shenzhen TG-NET Botone Technology Co.,Ltd.",
        "address_1": "East F/3,No.38 Huarong Second Industry Zone",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "6C0273": {
        "oui_hex": "6C-02-73",
        "organization": "Shenzhen Jin Yun Video Equipment Co., Ltd.",
        "address_1": "4th floor, 78th, Matou Road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "54DF00": {
        "oui_hex": "54-DF-00",
        "organization": "Ulterius Technologies, LLC",
        "address_1": "1625 N. Waterfront Parkway",
        "address_2": "Wichita  KS  67206",
        "country": "US"
    },
    "20ED74": {
        "oui_hex": "20-ED-74",
        "organization": "Ability enterprise co.,Ltd.",
        "address_1": "4F., No.8, Ln.7, Wuquan Rd, Wugu Dist, New Taipei City 24886, Taiwan(R.O.C)",
        "address_2": "Taipei  Taipei  24886",
        "country": "TW"
    },
    "A056B2": {
        "oui_hex": "A0-56-B2",
        "organization": "Harman/Becker Automotive Systems GmbH",
        "address_1": "Becker-Göring-Straße 16",
        "address_2": "Karlsbad  Baden-Württemberg  76307",
        "country": "DE"
    },
    "44666E": {
        "oui_hex": "44-66-6E",
        "organization": "IP-LINE",
        "address_1": "#204, Gangseo B/D",
        "address_2": "Guro-gu  Seoul  152-826",
        "country": "KR"
    },
    "244F1D": {
        "oui_hex": "24-4F-1D",
        "organization": "iRule LLC",
        "address_1": "1555 Broadway St",
        "address_2": "Detroit  MI  48226",
        "country": "US"
    },
    "94AEE3": {
        "oui_hex": "94-AE-E3",
        "organization": "Belden Hirschmann Industries (Suzhou) Ltd.",
        "address_1": "333 Yanhu Road, Huaqiao Town",
        "address_2": "Kunshan  Jiangsu  215332",
        "country": "CN"
    },
    "5CB6CC": {
        "oui_hex": "5C-B6-CC",
        "organization": "NovaComm Technologies Inc.",
        "address_1": "902A, #560 Shengxia Rd., ZJ Inno Park",
        "address_2": "  Shanghai  201203",
        "country": "CN"
    },
    "705B2E": {
        "oui_hex": "70-5B-2E",
        "organization": "M2Communication Inc.",
        "address_1": "Room 12, 18F., No.65, Gaotie 7th Road",
        "address_2": "Zhubei City  Hsinchu County  302",
        "country": "TW"
    },
    "5C1515": {
        "oui_hex": "5C-15-15",
        "organization": "ADVAN",
        "address_1": "Wisma SMR.JL.Yos Sudarso Kav 89,Lt8.Suite 804,Jakarta Utara 10730",
        "address_2": "Jakarta  Jakarta Utara  １４３５０",
        "country": "ID"
    },
    "D059E4": {
        "oui_hex": "D0-59-E4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "14A364": {
        "oui_hex": "14-A3-64",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B40AC6": {
        "oui_hex": "B4-0A-C6",
        "organization": "DEXON Systems Ltd.",
        "address_1": "Baross u. 165",
        "address_2": "Budaors  Pest  H-2040",
        "country": "HU"
    },
    "D866EE": {
        "oui_hex": "D8-66-EE",
        "organization": "BOXIN COMMUNICATION CO.,LTD.",
        "address_1": "Room 309，Block A，New materials business building",
        "address_2": "Haidian District  Beijing  100094",
        "country": "CN"
    },
    "2829CC": {
        "oui_hex": "28-29-CC",
        "organization": "Corsa Technology Incorporated",
        "address_1": "505 March Road",
        "address_2": "Ottawa  Ontario  K2K 3A4",
        "country": "CA"
    },
    "184A6F": {
        "oui_hex": "18-4A-6F",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "10C37B": {
        "oui_hex": "10-C3-7B",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "E85D6B": {
        "oui_hex": "E8-5D-6B",
        "organization": "Luminate Wireless",
        "address_1": "20823 Stevens Creek Blvd, Suite 300",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B40B44": {
        "oui_hex": "B4-0B-44",
        "organization": "Smartisan Technology Co., Ltd.",
        "address_1": "7/F, Motorola Bldg., 1st Wangjing East Rd,",
        "address_2": "Beijing    100102",
        "country": "CN"
    },
    "3431C4": {
        "oui_hex": "34-31-C4",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "50FEF2": {
        "oui_hex": "50-FE-F2",
        "organization": "Sify Technologies Ltd",
        "address_1": "II floor, TIDEL Park,",
        "address_2": "chennai  Tamilnadu  600113",
        "country": "IN"
    },
    "34C5D0": {
        "oui_hex": "34-C5-D0",
        "organization": "Hagleitner Hygiene International GmbH",
        "address_1": "Lunastrasse 5",
        "address_2": "Zell am See  Salzburg  5700",
        "country": "AT"
    },
    "A012DB": {
        "oui_hex": "A0-12-DB",
        "organization": "TABUCHI ELECTRIC CO.,LTD",
        "address_1": "4-2-21",
        "address_2": "  OSAKA  532-0003",
        "country": "JP"
    },
    "481A84": {
        "oui_hex": "48-1A-84",
        "organization": "Pointer Telocation Ltd",
        "address_1": "14 Hamelacha Street,",
        "address_2": "Rosh Ha’ayin  Israel  48091",
        "country": "IL"
    },
    "DC663A": {
        "oui_hex": "DC-66-3A",
        "organization": "Apacer Technology Inc.",
        "address_1": "1F., No.32, Zhongcheng Rd., Tucheng Dist.,",
        "address_2": "New Taipei City  Taiwan R.O.C.  236",
        "country": "TW"
    },
    "08DF1F": {
        "oui_hex": "08-DF-1F",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "581F67": {
        "oui_hex": "58-1F-67",
        "organization": "Open-m technology limited",
        "address_1": "logan century buildding ,No.23 of Hai xiu road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4826E8": {
        "oui_hex": "48-26-E8",
        "organization": "Tek-Air Systems, Inc.",
        "address_1": "41 Eagle Road",
        "address_2": "Danbury  CT  06810",
        "country": "US"
    },
    "D05AF1": {
        "oui_hex": "D0-5A-F1",
        "organization": "Shenzhen Pulier Tech CO.,Ltd",
        "address_1": "3rd Floor, NO. B Buliding, District A, Shajing minzhu jiujiu industrial park , Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "FCE186": {
        "oui_hex": "FC-E1-86",
        "organization": "A3M Co., LTD",
        "address_1": "KeumJeong Highview 2F #205,",
        "address_2": "Gunpo  Gyeonggi  435-845",
        "country": "KR"
    },
    "54EF92": {
        "oui_hex": "54-EF-92",
        "organization": "Shenzhen Elink Technology Co., LTD",
        "address_1": "A531, Famous, No 168 Bao Yuan Road,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "ECE512": {
        "oui_hex": "EC-E5-12",
        "organization": "tado GmbH",
        "address_1": "Lindwurmstr. 76",
        "address_2": "Munich  Bavaria  80337",
        "country": "DE"
    },
    "30918F": {
        "oui_hex": "30-91-8F",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "5CF4AB": {
        "oui_hex": "5C-F4-AB",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "08B2A3": {
        "oui_hex": "08-B2-A3",
        "organization": "Cynny Italia S.r.L.",
        "address_1": "Via delle Mantellate, 8",
        "address_2": "Firenze  FI  59021",
        "country": "IT"
    },
    "70305D": {
        "oui_hex": "70-30-5D",
        "organization": "Ubiquoss Inc",
        "address_1": "8F Ubiquoss B/D, 68, Pangyo-ro 255beon-gil, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "488244": {
        "oui_hex": "48-82-44",
        "organization": "Life Fitness / Div. of Brunswick",
        "address_1": "10601 W. Belmont Ave",
        "address_2": "Franklin Park  IL  60131",
        "country": "US"
    },
    "C83168": {
        "oui_hex": "C8-31-68",
        "organization": "eZEX corporation",
        "address_1": "Rm 508, Ssangyong IT Twin-Tower II, 442-5",
        "address_2": "Seongnam-si  Gyeonggi-do  462-120",
        "country": "KR"
    },
    "40B3CD": {
        "oui_hex": "40-B3-CD",
        "organization": "Chiyoda Electronics Co.,Ltd.",
        "address_1": "1-3-11 Nishiki-cho",
        "address_2": "Warabi  Saitama",
        "country": "JP"
    },
    "24336C": {
        "oui_hex": "24-33-6C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "202564": {
        "oui_hex": "20-25-64",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "C8D590": {
        "oui_hex": "C8-D5-90",
        "organization": "FLIGHT DATA SYSTEMS",
        "address_1": "31 MCGREGORS DRIVE",
        "address_2": "KEILOR PARK  VICTORIA  3042",
        "country": "AU"
    },
    "7CFF62": {
        "oui_hex": "7C-FF-62",
        "organization": "Huizhou Super Electron Technology Co.,Ltd.",
        "address_1": "10F,Financial Tower,No.23,Xiapu Road",
        "address_2": "Huizhou City  Guangdong Province  516001",
        "country": "CN"
    },
    "84B59C": {
        "oui_hex": "84-B5-9C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C09D26": {
        "oui_hex": "C0-9D-26",
        "organization": "Topicon HK Lmd.",
        "address_1": "302, 3F, Lee Loong Building",
        "address_2": "Central  Hong Kong  0000",
        "country": "US"
    },
    "442938": {
        "oui_hex": "44-29-38",
        "organization": "NietZsche enterprise Co.Ltd.",
        "address_1": "4F. No.560 Sec2 Chung Shan Rd.",
        "address_2": "New Taipei City Taiwan R.O.C  Taipei ( 臺 北 縣 / 市 )  220",
        "country": "TW"
    },
    "A0DA92": {
        "oui_hex": "A0-DA-92",
        "organization": "Nanjing Glarun Atten Technology Co. Ltd.",
        "address_1": "Dinghuai men No. 1, Gulou District",
        "address_2": "",
        "country": "CN"
    },
    "ECF72B": {
        "oui_hex": "EC-F7-2B",
        "organization": "HD DIGITAL TECH CO., LTD.",
        "address_1": "Room 602, Baoyuan road, Banan District",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "US"
    },
    "4CF45B": {
        "oui_hex": "4C-F4-5B",
        "organization": "Blue Clover Devices",
        "address_1": "1001 Bayhill Dr",
        "address_2": "San Bruno  CA  94066",
        "country": "US"
    },
    "B06971": {
        "oui_hex": "B0-69-71",
        "organization": "DEI Sales, Inc.",
        "address_1": "1 Viper Way",
        "address_2": "Vista  CA  92081",
        "country": "US"
    },
    "1889DF": {
        "oui_hex": "18-89-DF",
        "organization": "CerebrEX Inc.",
        "address_1": "Central Shin-Osaka Building 10F",
        "address_2": "Osaka  Osaka  532-0003",
        "country": "JP"
    },
    "54C80F": {
        "oui_hex": "54-C8-0F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E4D332": {
        "oui_hex": "E4-D3-32",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0C2026": {
        "oui_hex": "0C-20-26",
        "organization": "noax Technologies AG",
        "address_1": "Am Forst 6",
        "address_2": "Ebersberg    85560",
        "country": "DE"
    },
    "283B96": {
        "oui_hex": "28-3B-96",
        "organization": "Cool Control LTD",
        "address_1": "Mivtahim 2",
        "address_2": "Petah Tikva  Israel  4951774",
        "country": "IL"
    },
    "648D9E": {
        "oui_hex": "64-8D-9E",
        "organization": "IVT Electronic Co.,Ltd",
        "address_1": "F building Dongxing Insdustrial Area",
        "address_2": "Dongguan City  Guangdong provice  523457",
        "country": "CN"
    },
    "CC95D7": {
        "oui_hex": "CC-95-D7",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "FC09F6": {
        "oui_hex": "FC-09-F6",
        "organization": "GUANGDONG TONZE ELECTRIC CO.,LTD",
        "address_1": "No.12-12 Block,Jinyuan Industrical City,Chaoshan Road,Shantou,Guangdong,china",
        "address_2": "Shantou  Guangdong  515021",
        "country": "CN"
    },
    "BCF61C": {
        "oui_hex": "BC-F6-1C",
        "organization": "Geomodeling Wuxi Technology Co. Ltd.",
        "address_1": "Room1708, 17/F, North Star Times Tower, No.8 BeiChen East Road",
        "address_2": "  Beijing  100101",
        "country": "CN"
    },
    "FC923B": {
        "oui_hex": "FC-92-3B",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "E03F49": {
        "oui_hex": "E0-3F-49",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "88A73C": {
        "oui_hex": "88-A7-3C",
        "organization": "Ragentek Technology Group",
        "address_1": "D10/D11, No.3188, Xiupu Road",
        "address_2": "  Shanghai  201315",
        "country": "CN"
    },
    "88D962": {
        "oui_hex": "88-D9-62",
        "organization": "Canopus Systems US LLC",
        "address_1": "Nasa Ames Research Park",
        "address_2": "Moffett Field  CALIFORNIA  94035",
        "country": "US"
    },
    "D09C30": {
        "oui_hex": "D0-9C-30",
        "organization": "Foster Electric Company, Limited",
        "address_1": "1-1-109, Tsutsujigaoka",
        "address_2": "Akishima  Tokyo  196-8550",
        "country": "JP"
    },
    "949F3F": {
        "oui_hex": "94-9F-3F",
        "organization": "Optek Digital Technology company limited",
        "address_1": "Room508 Build A, Shennan Garden, Shenzhen Science and Industry Park, Nanshan",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "E817FC": {
        "oui_hex": "E8-17-FC",
        "organization": "Fujitsu Cloud Technologies Limited",
        "address_1": "Shinjuku Front Tower 21-1",
        "address_2": " Kita-shinjuku 2-chome   Shinjuku-ku, Tokyo   169-0074",
        "country": "JP"
    },
    "78FEE2": {
        "oui_hex": "78-FE-E2",
        "organization": "Shanghai Diveo Technology Co., Ltd",
        "address_1": "No.8,Lane 777,LongWu Rd",
        "address_2": "  Shanghai  200232",
        "country": "CN"
    },
    "086DF2": {
        "oui_hex": "08-6D-F2",
        "organization": "Shenzhen MIMOWAVE Technology Co.,Ltd",
        "address_1": "",
        "address_2": "Shenzhen  Guangdong  518172",
        "country": "CN"
    },
    "687848": {
        "oui_hex": "68-78-48",
        "organization": "Westunitis Co., Ltd.",
        "address_1": "North Building 7F, 3-1 Ofuka-cho, Kita-ku",
        "address_2": "Osaka-city  Osaka-pref  5300011",
        "country": "JP"
    },
    "48D0CF": {
        "oui_hex": "48-D0-CF",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "9C3EAA": {
        "oui_hex": "9C-3E-AA",
        "organization": "EnvyLogic Co.,Ltd.",
        "address_1": "#605,Gwanyang Doosan Ven Digm B/D",
        "address_2": "Anyang-si  Gyeonggi-do  431-810",
        "country": "KR"
    },
    "1CFCBB": {
        "oui_hex": "1C-FC-BB",
        "organization": "Realfiction ApS",
        "address_1": "Oester Alle 42, 5",
        "address_2": "Copenhagen  OE  2100",
        "country": "DK"
    },
    "F8F005": {
        "oui_hex": "F8-F0-05",
        "organization": "Newport Media Inc.",
        "address_1": "1 Spectrum Pointe Drive Suite 225",
        "address_2": "Lake Forest  CA  92630",
        "country": "US"
    },
    "28656B": {
        "oui_hex": "28-65-6B",
        "organization": "Keystone Microtech Corporation",
        "address_1": "9F., No.255, Dong Sec. 1,",
        "address_2": "Jhubei City, Hsinchu County    302",
        "country": "TW"
    },
    "CC9F35": {
        "oui_hex": "CC-9F-35",
        "organization": "Transbit Sp. z o.o.",
        "address_1": "Przyczolkowa 109A",
        "address_2": "Warsaw     02-968",
        "country": "PL"
    },
    "DCC793": {
        "oui_hex": "DC-C7-93",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "444891": {
        "oui_hex": "44-48-91",
        "organization": "HDMI Licensing, LLC",
        "address_1": "1140 East Arques, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "5C254C": {
        "oui_hex": "5C-25-4C",
        "organization": "Avire Global Pte Ltd",
        "address_1": "8 Admiralty Street",
        "address_2": "Singapore    757438",
        "country": "SG"
    },
    "D42F23": {
        "oui_hex": "D4-2F-23",
        "organization": "Akenori PTE Ltd",
        "address_1": "176 Joo Chiat Road, #02-02",
        "address_2": "Singapore    427447",
        "country": "SG"
    },
    "98C0EB": {
        "oui_hex": "98-C0-EB",
        "organization": "Global Regency Ltd",
        "address_1": "20F, Phase A, Wenjin Plaza,",
        "address_2": "Shen Zhen  Guangdong  518000",
        "country": "CN"
    },
    "F03FF8": {
        "oui_hex": "F0-3F-F8",
        "organization": "R L Drake",
        "address_1": "1 Jake Brown Road",
        "address_2": "Old Bridge  NJ  08857",
        "country": "US"
    },
    "B0C554": {
        "oui_hex": "B0-C5-54",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "48EE86": {
        "oui_hex": "48-EE-86",
        "organization": "UTStarcom (China) Co.,Ltd",
        "address_1": "25 Floor,A Block,1#Building,TianZuo International Center,",
        "address_2": "Haidian District  BeiJing  100081",
        "country": "CN"
    },
    "888914": {
        "oui_hex": "88-89-14",
        "organization": "All Components Incorporated",
        "address_1": "828 New Meister Lane",
        "address_2": "Pflugerville  TX  78660",
        "country": "US"
    },
    "F0321A": {
        "oui_hex": "F0-32-1A",
        "organization": "Mita-Teknik A/S",
        "address_1": "Aktieselskabet af 12.12.2006",
        "address_2": "Roedkaersbro    8840",
        "country": "DK"
    },
    "A881F1": {
        "oui_hex": "A8-81-F1",
        "organization": "BMEYE B.V.",
        "address_1": "Hoogoorddreef 60",
        "address_2": "Amsterdam    1101BE",
        "country": "NL"
    },
    "C4E984": {
        "oui_hex": "C4-E9-84",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D069D0": {
        "oui_hex": "D0-69-D0",
        "organization": "Verto Medical Solutions, LLC",
        "address_1": "900 Spruce St., Suite 550",
        "address_2": "St. Louis  Missouri  63012",
        "country": "US"
    },
    "FC1349": {
        "oui_hex": "FC-13-49",
        "organization": "Global Apps Corp.",
        "address_1": "12F., No 225, Sec. 5 Nanjing E. Rd",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "848433": {
        "oui_hex": "84-84-33",
        "organization": "Paradox Engineering SA",
        "address_1": "Via Passeggiata, 7",
        "address_2": "Novazzano  Ticino  6883",
        "country": "CH"
    },
    "44C306": {
        "oui_hex": "44-C3-06",
        "organization": "SIFROM Inc.",
        "address_1": "1201 N. Orange St., Ste 700 #7112",
        "address_2": "Wilmington  DE  19801-1186",
        "country": "US"
    },
    "602103": {
        "oui_hex": "60-21-03",
        "organization": "I4VINE, INC",
        "address_1": "TLI Building 6th floor, 195",
        "address_2": "Seongnam-si  Gyeonggi-do  462-100",
        "country": "KR"
    },
    "FC07A0": {
        "oui_hex": "FC-07-A0",
        "organization": "LRE Medical GmbH",
        "address_1": "Hofer Strasse 5",
        "address_2": "Noerdlingen  Bavaria  86720",
        "country": "DE"
    },
    "1CEEE8": {
        "oui_hex": "1C-EE-E8",
        "organization": "Ilshin Elecom",
        "address_1": "2973, Hagun-ri, Yangchon-eup",
        "address_2": "Gimpo-si  Gyeonggi-do  415-843",
        "country": "KR"
    },
    "9031CD": {
        "oui_hex": "90-31-CD",
        "organization": "Onyx Healthcare Inc.",
        "address_1": "2F ,No135, Lane235,",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "E48184": {
        "oui_hex": "E4-81-84",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "14C089": {
        "oui_hex": "14-C0-89",
        "organization": "DUNE HD LTD",
        "address_1": "2F., No.297, Sec. 2, Tiding Blvd.,",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "F4B6E5": {
        "oui_hex": "F4-B6-E5",
        "organization": "TerraSem Co.,Ltd",
        "address_1": "9,Gwahaksaneop 5-ro",
        "address_2": "Cheongwon-Gu  ChungBuk  363-885",
        "country": "KR"
    },
    "60FFDD": {
        "oui_hex": "60-FF-DD",
        "organization": "C.E. ELECTRONICS, INC",
        "address_1": "2107 INDUSTRIAL DR",
        "address_2": "BRYAN  OHIO  43506",
        "country": "US"
    },
    "24050F": {
        "oui_hex": "24-05-0F",
        "organization": "MTN Electronic Co. Ltd",
        "address_1": "MTN Industrial Park,No 3, Fuhua Road,",
        "address_2": "Shenzhen  Guangdong Province  518117",
        "country": "CN"
    },
    "AC2DA3": {
        "oui_hex": "AC-2D-A3",
        "organization": "TXTR GmbH",
        "address_1": "Rosenthaler Str. 13",
        "address_2": "Berlin    10119",
        "country": "DE"
    },
    "889CA6": {
        "oui_hex": "88-9C-A6",
        "organization": "BTB Korea INC",
        "address_1": "#1001, Suntech City 1st",
        "address_2": "Sungnam  Kyunggido  462-725",
        "country": "KR"
    },
    "90837A": {
        "oui_hex": "90-83-7A",
        "organization": "General Electric Water & Process Technologies",
        "address_1": "6060 Spine Road",
        "address_2": "Boulder  Colorado  80301-3687",
        "country": "US"
    },
    "80BAE6": {
        "oui_hex": "80-BA-E6",
        "organization": "Neets",
        "address_1": "Langballe 4",
        "address_2": "Horsens  Jylland  8700",
        "country": "DK"
    },
    "F8A2B4": {
        "oui_hex": "F8-A2-B4",
        "organization": "RHEWA-WAAGENFABRIK August Freudewald GmbH &amp;Co. KG",
        "address_1": "Feldstr. 17",
        "address_2": "Mettmann    40822",
        "country": "DE"
    },
    "E056F4": {
        "oui_hex": "E0-56-F4",
        "organization": "AxesNetwork Solutions inc.",
        "address_1": "410 pepin",
        "address_2": "Sherbrooke  qc  j1l2y8",
        "country": "CA"
    },
    "84569C": {
        "oui_hex": "84-56-9C",
        "organization": "Coho Data, Inc.,",
        "address_1": "1230 Midas Way, Suite 110",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "78AE0C": {
        "oui_hex": "78-AE-0C",
        "organization": "Far South Networks",
        "address_1": "49 Bell Crescent",
        "address_2": "Westlake  Western Cape  7945",
        "country": "ZA"
    },
    "B024F3": {
        "oui_hex": "B0-24-F3",
        "organization": "Progeny Systems",
        "address_1": "9500 Innovation Drive",
        "address_2": "Manassas  VA  20110",
        "country": "US"
    },
    "0C54A5": {
        "oui_hex": "0C-54-A5",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "8C4DB9": {
        "oui_hex": "8C-4D-B9",
        "organization": "Unmonday Ltd",
        "address_1": "Laivakatu 3",
        "address_2": "Helsinki  Uusimaa  00150",
        "country": "FI"
    },
    "78CA5E": {
        "oui_hex": "78-CA-5E",
        "organization": "ELNO",
        "address_1": "43 rue Michel Carré",
        "address_2": "Argenteuil  -  F95102",
        "country": "US"
    },
    "2C5A05": {
        "oui_hex": "2C-5A-05",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "D481CA": {
        "oui_hex": "D4-81-CA",
        "organization": "iDevices, LLC",
        "address_1": "136 Simsbury, Rd",
        "address_2": "Avon  CT  06001",
        "country": "US"
    },
    "D858D7": {
        "oui_hex": "D8-58-D7",
        "organization": "CZ.NIC, z.s.p.o.",
        "address_1": "Americka 23",
        "address_2": "  Prague  12000",
        "country": "CZ"
    },
    "B0D7C5": {
        "oui_hex": "B0-D7-C5",
        "organization": "Logipix Ltd",
        "address_1": "Kesmark utca 11-13",
        "address_2": "Budapest  -  1158",
        "country": "HU"
    },
    "A43A69": {
        "oui_hex": "A4-3A-69",
        "organization": "Vers Inc",
        "address_1": "PO Box 5265",
        "address_2": "Wayland  MA  01778",
        "country": "US"
    },
    "9C44A6": {
        "oui_hex": "9C-44-A6",
        "organization": "SwiftTest, Inc.",
        "address_1": "3255 Scott Blvd.",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "4CD9C4": {
        "oui_hex": "4C-D9-C4",
        "organization": "Magneti Marelli Automotive Electronics (Guangzhou) Co. Ltd",
        "address_1": "Building B10, No.8 Jinghu Road",
        "address_2": "Guangzhou  Guangdong  510800",
        "country": "CN"
    },
    "50E0C7": {
        "oui_hex": "50-E0-C7",
        "organization": "TurControlSystme AG",
        "address_1": "Geschwister-Scholl-Strasse 7",
        "address_2": "Genthin  Sachsen-Anhalt  39307",
        "country": "DE"
    },
    "B4827B": {
        "oui_hex": "B4-82-7B",
        "organization": "AKG Acoustics GmbH",
        "address_1": "Lemboeckgasse 21-25",
        "address_2": "  Vienna  1230",
        "country": "AT"
    },
    "DC5E36": {
        "oui_hex": "DC-5E-36",
        "organization": "Paterson Technology",
        "address_1": "23490 SE 51st Pl",
        "address_2": "Issaquah  WA  98029",
        "country": "US"
    },
    "DCAD9E": {
        "oui_hex": "DC-AD-9E",
        "organization": "GreenPriz",
        "address_1": "549, boulevard Pierre Sauvaigo",
        "address_2": "La Colle sur Loup    06480",
        "country": "FR"
    },
    "B8DF6B": {
        "oui_hex": "B8-DF-6B",
        "organization": "SpotCam Co., Ltd.",
        "address_1": "12F.-1, No.125, Jianguo Rd.",
        "address_2": "New Taipei City    239",
        "country": "TW"
    },
    "9C8888": {
        "oui_hex": "9C-88-88",
        "organization": "Simac Techniek NV",
        "address_1": "De Run 1101",
        "address_2": "Veldhoven  NB  5503LB",
        "country": "NL"
    },
    "10B26B": {
        "oui_hex": "10-B2-6B",
        "organization": "base Co.,Ltd.",
        "address_1": "F1 92 building taoyuancun longzhu road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4CF02E": {
        "oui_hex": "4C-F0-2E",
        "organization": "Vifa Denmark A/S",
        "address_1": "Mariendalsvej 2A",
        "address_2": "Viborg    DK-8800",
        "country": "US"
    },
    "288A1C": {
        "oui_hex": "28-8A-1C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "DCCEBC": {
        "oui_hex": "DC-CE-BC",
        "organization": "Shenzhen JSR Technology Co.,Ltd.",
        "address_1": "2-3F,E building,Yu Jianfeng science and industry park",
        "address_2": "Shenzhen City  Guangdong  518109",
        "country": "CN"
    },
    "18C8E7": {
        "oui_hex": "18-C8-E7",
        "organization": "Shenzhen Hualistone Technology Co.,Ltd",
        "address_1": "1708RM,Huafeng HQ Economic Building,",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "A03B1B": {
        "oui_hex": "A0-3B-1B",
        "organization": "Inspire Tech",
        "address_1": "No.588-10,Zhongzheng Rd.,Xinzhuang Dist",
        "address_2": "New Taipei  Taiwan  24255",
        "country": "TW"
    },
    "7CCD3C": {
        "oui_hex": "7C-CD-3C",
        "organization": "Guangzhou Juzing Technology Co., Ltd",
        "address_1": "Building C Rm 1906-1909",
        "address_2": "Guangzhou  Guangdong  510630",
        "country": "US"
    },
    "9843DA": {
        "oui_hex": "98-43-DA",
        "organization": "INTERTECH",
        "address_1": "3F. 14-9 Sarihyun-Ro. Ilsandong-Gu",
        "address_2": "Goyang-Si  Gyeonggi-Do  410-821",
        "country": "KR"
    },
    "08CA45": {
        "oui_hex": "08-CA-45",
        "organization": "Toyou Feiji Electronics Co., Ltd.",
        "address_1": "No.2 Building No.9 Yard, Dijin Road,",
        "address_2": "  Beijing  100095",
        "country": "CN"
    },
    "3CCA87": {
        "oui_hex": "3C-CA-87",
        "organization": "Iders Incorporated",
        "address_1": "27047 Oakwood Rd",
        "address_2": "Oakbank  Manitoba  R0E 1J2",
        "country": "CA"
    },
    "7C6AB3": {
        "oui_hex": "7C-6A-B3",
        "organization": "IBC TECHNOLOGIES INC.",
        "address_1": "1445 CHARLES STREET",
        "address_2": "Vancouver  British Columbia  V5L2S7",
        "country": "CA"
    },
    "181BEB": {
        "oui_hex": "18-1B-EB",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "84A783": {
        "oui_hex": "84-A7-83",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "041A04": {
        "oui_hex": "04-1A-04",
        "organization": "WaveIP",
        "address_1": "1 Sky street",
        "address_2": "Misgav    20179",
        "country": "IL"
    },
    "68764F": {
        "oui_hex": "68-76-4F",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "34A5E1": {
        "oui_hex": "34-A5-E1",
        "organization": "Sensorist ApS",
        "address_1": "Nyhavn 16",
        "address_2": "Copenhagen K  Sjaelland  1051",
        "country": "DK"
    },
    "8079AE": {
        "oui_hex": "80-79-AE",
        "organization": "ShanDong Tecsunrise  Co.,Ltd",
        "address_1": "B316,F-2,QiLu Soft Park,",
        "address_2": "JiNan  ShanDong  250101",
        "country": "CN"
    },
    "7CBD06": {
        "oui_hex": "7C-BD-06",
        "organization": "AE REFUsol",
        "address_1": "Uracher Str. 91",
        "address_2": "Metzingen  Baden-Württemberg  72555",
        "country": "DE"
    },
    "94BA56": {
        "oui_hex": "94-BA-56",
        "organization": "Shenzhen Coship Electronics Co., Ltd.",
        "address_1": "Rainbow Bldg., North, Hi-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "38DBBB": {
        "oui_hex": "38-DB-BB",
        "organization": "Sunbow Telecom Co., Ltd.",
        "address_1": "3F, 501-21, Chung Cheng Rd., Hsin Tien Dist.",
        "address_2": "New Taipei City    23148",
        "country": "TW"
    },
    "448A5B": {
        "oui_hex": "44-8A-5B",
        "organization": "Micro-Star INT'L CO., LTD.",
        "address_1": "No69, LIde St.",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "6C4B7F": {
        "oui_hex": "6C-4B-7F",
        "organization": "Vossloh-Schwabe Deutschland GmbH",
        "address_1": "Wasenstrasse 25",
        "address_2": "Urbach    73660",
        "country": "DE"
    },
    "908C44": {
        "oui_hex": "90-8C-44",
        "organization": "H.K ZONGMU TECHNOLOGY CO., LTD.",
        "address_1": "ROOM 604, BUILDING B, 977 SHANGFENG RD",
        "address_2": "  SHANGHAI  201201",
        "country": "CN"
    },
    "688AB5": {
        "oui_hex": "68-8A-B5",
        "organization": "EDP Servicos",
        "address_1": "Rua Castilho, número 165, 5º andar",
        "address_2": "Lisboa    1070-050",
        "country": "PT"
    },
    "2493CA": {
        "oui_hex": "24-93-CA",
        "organization": "Voxtronic Austria",
        "address_1": "Modecenterstrasse 17  Objekt 1",
        "address_2": "Vienna    1110",
        "country": "AT"
    },
    "0CCB8D": {
        "oui_hex": "0C-CB-8D",
        "organization": "ASCO Numatics GmbH",
        "address_1": "Otto-Hahn-Str. 7-11",
        "address_2": "Oelbronn-Duerrn    75248",
        "country": "DE"
    },
    "907990": {
        "oui_hex": "90-79-90",
        "organization": "Benchmark Electronics Romania SRL",
        "address_1": "Aeroportului no 6 Ghimbav",
        "address_2": "Brasov    507075",
        "country": "US"
    },
    "740EDB": {
        "oui_hex": "74-0E-DB",
        "organization": "Optowiz Co., Ltd",
        "address_1": "D-901 Bundang Techno Park",
        "address_2": "Seongnam-si  Kyeonggi-do  463-760",
        "country": "KR"
    },
    "6C8366": {
        "oui_hex": "6C-83-66",
        "organization": "Nanjing SAC Power Grid Automation Co., Ltd.",
        "address_1": "No.11 Phoenix Road",
        "address_2": "Nanjing  Jiangsu Provience  211100",
        "country": "CN"
    },
    "F83D4E": {
        "oui_hex": "F8-3D-4E",
        "organization": "Softlink Automation System Co., Ltd",
        "address_1": "No.12, Hi-tech South 7th Rd.,",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "74D435": {
        "oui_hex": "74-D4-35",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "78D99F": {
        "oui_hex": "78-D9-9F",
        "organization": "NuCom HK Ltd.",
        "address_1": "Unit B 11/F, Eton Bldg, 288 Des Voeux Rd. Central",
        "address_2": "Hong Kong  Hong Kong  00852",
        "country": "CN"
    },
    "142BD2": {
        "oui_hex": "14-2B-D2",
        "organization": "Armtel Ltd.",
        "address_1": " 33A Smolenskaya str.",
        "address_2": "St.  Petersburg    196084",
        "country": "RU"
    },
    "9CA10A": {
        "oui_hex": "9C-A1-0A",
        "organization": "SCLE SFE",
        "address_1": "Parc des Aygalades – Bât 10",
        "address_2": "MARSEILLE  PACA  13014",
        "country": "FR"
    },
    "88789C": {
        "oui_hex": "88-78-9C",
        "organization": "Game Technologies SA",
        "address_1": "Plac W. Andersa 3",
        "address_2": "Poznan    61894",
        "country": "PL"
    },
    "A4895B": {
        "oui_hex": "A4-89-5B",
        "organization": "ARK INFOSOLUTIONS PVT LTD",
        "address_1": "4428, GANESH BAZAR CLOTH MARKET",
        "address_2": "  DELHI  110006",
        "country": "IN"
    },
    "D09D0A": {
        "oui_hex": "D0-9D-0A",
        "organization": "LINKCOM",
        "address_1": "11 Rue du Soleil Levant",
        "address_2": "Clamart    92140",
        "country": "FR"
    },
    "EC219F": {
        "oui_hex": "EC-21-9F",
        "organization": "VidaBox LLC",
        "address_1": "240 Madison Ave",
        "address_2": "Garden City Park  NEW YORK  11040",
        "country": "US"
    },
    "A8CCC5": {
        "oui_hex": "A8-CC-C5",
        "organization": "Saab AB (publ)",
        "address_1": "Nobymalmsvagen",
        "address_2": "Linkoping    SE-581 82",
        "country": "SE"
    },
    "58468F": {
        "oui_hex": "58-46-8F",
        "organization": "Koncar Electronics and Informatics",
        "address_1": "Fallerovo setaliste 22",
        "address_2": "Zagreb  Drvinje  10000",
        "country": "HR"
    },
    "985D46": {
        "oui_hex": "98-5D-46",
        "organization": "PeopleNet Communication",
        "address_1": "4400 Baker Road",
        "address_2": "Minnetonka  Minnesota  55343",
        "country": "US"
    },
    "F89FB8": {
        "oui_hex": "F8-9F-B8",
        "organization": "YAZAKI Energy System Corporation",
        "address_1": "1-7-1 YOKOI",
        "address_2": "Shimada -shi,Shizuoka    427-8555",
        "country": "JP"
    },
    "F0F5AE": {
        "oui_hex": "F0-F5-AE",
        "organization": "Adaptrum Inc.",
        "address_1": "25 E Trimble Rd.",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "FC3FAB": {
        "oui_hex": "FC-3F-AB",
        "organization": "Henan Lanxin Technology Co., Ltd",
        "address_1": "4/F-B, Building No.1, 863 Central China Software Park, No.6 Cuizhu Street, High &amp; New Technology Industries Development Zone",
        "address_2": "Zhengzhou  Henan  450001",
        "country": "CN"
    },
    "988E4A": {
        "oui_hex": "98-8E-4A",
        "organization": "NOXUS(BEIJING) TECHNOLOGY CO.,LTD",
        "address_1": "02-1205,11/F, No.2 Building,No.8,Worker’s Stadium North Road Chaoyang District",
        "address_2": "  Beijing  100027",
        "country": "CN"
    },
    "EC2AF0": {
        "oui_hex": "EC-2A-F0",
        "organization": "Ypsomed AG",
        "address_1": "Brunnmattstrasse 6",
        "address_2": "Burgdorf  BE  3400",
        "country": "CH"
    },
    "F854AF": {
        "oui_hex": "F8-54-AF",
        "organization": "ECI Telecom Ltd.",
        "address_1": "30 Hasivim St.",
        "address_2": "Petah Tikva    49133",
        "country": "IL"
    },
    "54BEF7": {
        "oui_hex": "54-BE-F7",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "50B888": {
        "oui_hex": "50-B8-88",
        "organization": "wi2be Tecnologia S/A",
        "address_1": "Rua Manoel Valdomiro de Macedo, 2285",
        "address_2": "Curitiba  Parana  81170-150",
        "country": "BR"
    },
    "7C8306": {
        "oui_hex": "7C-83-06",
        "organization": "Glen Dimplex Nordic as",
        "address_1": "Postboks 16",
        "address_2": "Stjoerdal  N-T  7501",
        "country": "NO"
    },
    "442AFF": {
        "oui_hex": "44-2A-FF",
        "organization": "E3 Technology, Inc.",
        "address_1": "Martell-house 2F, 2-28-3 Sekimachi-Kita,",
        "address_2": "Nerima-ku  Tokyo  177-0051",
        "country": "JP"
    },
    "140D4F": {
        "oui_hex": "14-0D-4F",
        "organization": "Flextronics International",
        "address_1": "Stretton Green Distribution Centre Langford Way",
        "address_2": "Warrington  Cheshire  WA4 4TQ",
        "country": "GB"
    },
    "446755": {
        "oui_hex": "44-67-55",
        "organization": "Orbit Irrigation",
        "address_1": "P.O. Box 328",
        "address_2": "Bountiful  Utah  84011",
        "country": "US"
    },
    "E0FAEC": {
        "oui_hex": "E0-FA-EC",
        "organization": "Platan sp. z o.o. sp. k.",
        "address_1": "ul.Platanowa 2",
        "address_2": "Sopot  pomorskie  81-855",
        "country": "PL"
    },
    "7CE56B": {
        "oui_hex": "7C-E5-6B",
        "organization": "ESEN Optoelectronics Technology Co.,Ltd.",
        "address_1": "Houcheng Yuanjiaqiao ,Jingang Town",
        "address_2": "Zhangjiagang  Jiangsu  215631",
        "country": "CN"
    },
    "D44C9C": {
        "oui_hex": "D4-4C-9C",
        "organization": "Shenzhen YOOBAO Technology Co.Ltd",
        "address_1": "F3,A5,Hua Tong Yuan Logistics Center,Minzhi Street,Longhua Town,Bao’an District,Shenzhen City,China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "20CEC4": {
        "oui_hex": "20-CE-C4",
        "organization": "Peraso Technologies",
        "address_1": "144 Front St. West, Suite 685",
        "address_2": "Toronto  ON  M5J 2L7",
        "country": "CA"
    },
    "CC4703": {
        "oui_hex": "CC-47-03",
        "organization": "Intercon Systems Co., Ltd.",
        "address_1": "#915 Hanlim Human Tower,1-40 Geumjeong-dong",
        "address_2": "Gunpo-si  Gyeonggi-do  435-824",
        "country": "KR"
    },
    "ACCA8E": {
        "oui_hex": "AC-CA-8E",
        "organization": "ODA Technologies",
        "address_1": "607-A Woorim Lions Valley, #425",
        "address_2": "Incheon    KSXX0009",
        "country": "KR"
    },
    "088E4F": {
        "oui_hex": "08-8E-4F",
        "organization": "SF Software Solutions",
        "address_1": "Buchenweg 32",
        "address_2": "Großbettlingen  Baden-Württemberg  72663",
        "country": "US"
    },
    "540536": {
        "oui_hex": "54-05-36",
        "organization": "Vivago Oy",
        "address_1": "Itsehallintokuja 6",
        "address_2": "  Espoo  FI-02600",
        "country": "FI"
    },
    "6C90B1": {
        "oui_hex": "6C-90-B1",
        "organization": "SanLogic Inc",
        "address_1": "2350 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "CC7B35": {
        "oui_hex": "CC-7B-35",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "04D437": {
        "oui_hex": "04-D4-37",
        "organization": "ZNV",
        "address_1": "4/F, W1-A, Bldg, Gaoxin S, 1st Ave., Hi-tech Park, Nanshan District, Shenzhen, P.R.C",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "US"
    },
    "CCF407": {
        "oui_hex": "CC-F4-07",
        "organization": "EUKREA ELECTROMATIQUE SARL",
        "address_1": "74 AVENUE JEAN JAURES",
        "address_2": "PESSAC  GIRONDE  33600",
        "country": "FR"
    },
    "DC1792": {
        "oui_hex": "DC-17-92",
        "organization": "Captivate Network",
        "address_1": "2 Executive Drive Suite 301",
        "address_2": "Chelmsford  Massachusetts  01824",
        "country": "US"
    },
    "28A241": {
        "oui_hex": "28-A2-41",
        "organization": "exlar corp",
        "address_1": "18400 west 77th street",
        "address_2": "chanhassen  mn  55317",
        "country": "US"
    },
    "509871": {
        "oui_hex": "50-98-71",
        "organization": "Inventum Technologies Private Limited",
        "address_1": "C-70, Phase 2 Extension",
        "address_2": "NOIDA  Uttar Pradesh  201305",
        "country": "IN"
    },
    "048C03": {
        "oui_hex": "04-8C-03",
        "organization": "ThinPAD Technology (Shenzhen)CO.,LTD",
        "address_1": "Room 2305, Xingji Building, Xinsha Road",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "88462A": {
        "oui_hex": "88-46-2A",
        "organization": "Telechips Inc.",
        "address_1": "Luther Building,7-20, Sincheon-dong,Songpa-gu,",
        "address_2": "Seoul  Seoul  138-240",
        "country": "KR"
    },
    "C80258": {
        "oui_hex": "C8-02-58",
        "organization": "ITW GSE ApS",
        "address_1": "Smedebakken 31-33",
        "address_2": "Odense N    5270",
        "country": "DK"
    },
    "30786B": {
        "oui_hex": "30-78-6B",
        "organization": "TIANJIN Golden Pentagon Electronics Co., Ltd.",
        "address_1": "No. 196 Rixin Road, Binhai Science Park,",
        "address_2": "  Tianjin  300457",
        "country": "CN"
    },
    "20DF3F": {
        "oui_hex": "20-DF-3F",
        "organization": "Nanjing SAC Power Grid Automation Co., Ltd.",
        "address_1": "No.11 Phoenix Road",
        "address_2": "Nanjing  Jiangsu  211106",
        "country": "CN"
    },
    "F8516D": {
        "oui_hex": "F8-51-6D",
        "organization": "Denwa Technology Corp.",
        "address_1": "1931 NW 150 TH AVE",
        "address_2": "Penbroke Pines  Florida  33028",
        "country": "US"
    },
    "444A65": {
        "oui_hex": "44-4A-65",
        "organization": "Silverflare Ltd.",
        "address_1": "2 Bakers Yard",
        "address_2": "Uxbridge  Greater London  UB8 1JZ",
        "country": "GB"
    },
    "744BE9": {
        "oui_hex": "74-4B-E9",
        "organization": "EXPLORER HYPERTECH CO.,LTD",
        "address_1": "7F.-9,NO.112,Xinmin St",
        "address_2": "New Taipei City    235",
        "country": "TW"
    },
    "FC6018": {
        "oui_hex": "FC-60-18",
        "organization": "Zhejiang Kangtai Electric Co., Ltd.",
        "address_1": "No.5, Kangtai Rd",
        "address_2": "Yueqing  Zhejiang  325605",
        "country": "CN"
    },
    "F42012": {
        "oui_hex": "F4-20-12",
        "organization": "Cuciniale GmbH",
        "address_1": "Heuriedweg 65",
        "address_2": "Lindau    88131",
        "country": "DE"
    },
    "98B039": {
        "oui_hex": "98-B0-39",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "B830A8": {
        "oui_hex": "B8-30-A8",
        "organization": "Road-Track Telematics Development",
        "address_1": "15th Keren Hayesod St.",
        "address_2": "Tirat Hacarmel  Israel  15223",
        "country": "IL"
    },
    "4CD637": {
        "oui_hex": "4C-D6-37",
        "organization": "Qsono Electronics Co., Ltd",
        "address_1": "2nd Floor,Dingxin Industry park,jiayuan Road,East Lake Development Zone",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "9436E0": {
        "oui_hex": "94-36-E0",
        "organization": "Sichuan Bihong Broadcast &amp; Television New Technologies Co.,Ltd",
        "address_1": "Guanghan City, Sichuan province Zhongshan road south three period of 36",
        "address_2": "Deyang Guanghan  Sichuan Province  618300",
        "country": "CN"
    },
    "5422F8": {
        "oui_hex": "54-22-F8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "486E73": {
        "oui_hex": "48-6E-73",
        "organization": "Pica8, Inc.",
        "address_1": "1032 Elwell Court, Suite 105",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "6405BE": {
        "oui_hex": "64-05-BE",
        "organization": "NEW LIGHT LED",
        "address_1": "No.50, Siyuan Rd",
        "address_2": "New Taipei    24251",
        "country": "TW"
    },
    "646EEA": {
        "oui_hex": "64-6E-EA",
        "organization": "Iskratel d.o.o.",
        "address_1": "Ljubljanska cesta 24a",
        "address_2": "Kranj    4000",
        "country": "SI"
    },
    "D0737F": {
        "oui_hex": "D0-73-7F",
        "organization": "Mini-Circuits",
        "address_1": "50 Yosef Levi Street",
        "address_2": "Kiryat Bialik Industrial Zone    27000",
        "country": "US"
    },
    "E8BB3D": {
        "oui_hex": "E8-BB-3D",
        "organization": "Sino Prime-Tech Limited",
        "address_1": "Room 418, Building 1, Hua Mei Ju (D),",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "28285D": {
        "oui_hex": "28-28-5D",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "0CF019": {
        "oui_hex": "0C-F0-19",
        "organization": "Malgn Technology Co., Ltd.",
        "address_1": "Star Tower #305, 223-25",
        "address_2": "Seongnam-Si  Kyounggi-Do  462-738",
        "country": "KR"
    },
    "949FB4": {
        "oui_hex": "94-9F-B4",
        "organization": "ChengDu JiaFaAnTai Technology Co.,Ltd",
        "address_1": "8th Floor, Building No.2, Zone A of Wisdom Valley",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "406826": {
        "oui_hex": "40-68-26",
        "organization": "Thales UK Limited",
        "address_1": "1 Linthouse Road",
        "address_2": "Glasgow  Scotland  G51 4BZ",
        "country": "GB"
    },
    "F82BC8": {
        "oui_hex": "F8-2B-C8",
        "organization": "Jiangsu Switter Co., Ltd",
        "address_1": "Room 512, Buliding 8, 118 Nanyuanbei Road",
        "address_2": "Suzhou City  Jiangsu Province  215006",
        "country": "CN"
    },
    "60C397": {
        "oui_hex": "60-C3-97",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "E07F88": {
        "oui_hex": "E0-7F-88",
        "organization": "EVIDENCE Network SIA",
        "address_1": "Zilupes 4A",
        "address_2": "  Rīga  LV-1019",
        "country": "LV"
    },
    "1C7CC7": {
        "oui_hex": "1C-7C-C7",
        "organization": "Coriant GmbH",
        "address_1": "St.-Martin-Str. 76",
        "address_2": "Munich  Germany  81541",
        "country": "DE"
    },
    "341B22": {
        "oui_hex": "34-1B-22",
        "organization": "Grandbeing Technology Co., Ltd",
        "address_1": "B-301,Science and Technology Building Phase II",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "40560C": {
        "oui_hex": "40-56-0C",
        "organization": "In Home Displays Ltd",
        "address_1": "Waterside House",
        "address_2": "Edinburgh  Lothian  EH6 6QU",
        "country": "GB"
    },
    "58E02C": {
        "oui_hex": "58-E0-2C",
        "organization": "Micro Technic A/S",
        "address_1": "Smedevaenget 5",
        "address_2": "Aarup    5560",
        "country": "DK"
    },
    "78B3CE": {
        "oui_hex": "78-B3-CE",
        "organization": "Elo touch solutions",
        "address_1": "1033 McCarthy Boulevard",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "88142B": {
        "oui_hex": "88-14-2B",
        "organization": "Protonic Holland",
        "address_1": "Factorij 36",
        "address_2": "Zwaag NH  Netherlands  1689 AL",
        "country": "NL"
    },
    "A4FCCE": {
        "oui_hex": "A4-FC-CE",
        "organization": "Security Expert Ltd.",
        "address_1": "75, Ekaterininskaya Street, of. 105",
        "address_2": "Perm  Perm region  614000",
        "country": "RU"
    },
    "34A68C": {
        "oui_hex": "34-A6-8C",
        "organization": "Shine Profit Development Limited",
        "address_1": "Unit 1401B Telecom Tower",
        "address_2": "Kwun Tong  Kowloon  000001",
        "country": "HK"
    },
    "341A4C": {
        "oui_hex": "34-1A-4C",
        "organization": "SHENZHEN WEIBU ELECTRONICS CO.,LTD.",
        "address_1": "3/F, Block 132,Jindi Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518048",
        "country": "CN"
    },
    "0488E2": {
        "oui_hex": "04-88-E2",
        "organization": "Beats Electronics LLC",
        "address_1": "1601 Cloverfield Blvd.",
        "address_2": "Santa Monica  California  90404",
        "country": "US"
    },
    "A47ACF": {
        "oui_hex": "A4-7A-CF",
        "organization": "VIBICOM COMMUNICATIONS INC.",
        "address_1": "900 CORPORATE DRIVE",
        "address_2": "MAHWAH  NEW JERSEY  074030",
        "country": "US"
    },
    "BC261D": {
        "oui_hex": "BC-26-1D",
        "organization": "HONG KONG TECON TECHNOLOGY",
        "address_1": "ROOM 2802,BLOCK A,SHEN FANG OLAZA",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "E8CE06": {
        "oui_hex": "E8-CE-06",
        "organization": "SkyHawke Technologies, LLC.",
        "address_1": "274 Commerce Park Drive",
        "address_2": "Ridgeland  MS  39157",
        "country": "US"
    },
    "C8F386": {
        "oui_hex": "C8-F3-86",
        "organization": "Shenzhen Xiaoniao Technology Co.,Ltd",
        "address_1": "Floor 13 C-D Yunsong Buliding",
        "address_2": "Futian District, Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "E0DCA0": {
        "oui_hex": "E0-DC-A0",
        "organization": "Siemens Industrial Automation Products Ltd Chengdu",
        "address_1": "Tianyuan Road 99",
        "address_2": "Cheng Du  Si Chuan  611731",
        "country": "CN"
    },
    "842F75": {
        "oui_hex": "84-2F-75",
        "organization": "Innokas Group",
        "address_1": "Tarjusojantie 12",
        "address_2": "Kempele  Oulu  90440",
        "country": "FI"
    },
    "CC3C3F": {
        "oui_hex": "CC-3C-3F",
        "organization": "SA.S.S. Datentechnik AG",
        "address_1": "Talhofstr. 32",
        "address_2": "Gilching  Bayern  82205",
        "country": "DE"
    },
    "2C69BA": {
        "oui_hex": "2C-69-BA",
        "organization": "RF Controls, LLC",
        "address_1": "622 Bates Street",
        "address_2": "Saint Louis  Missouri  63111",
        "country": "US"
    },
    "D4BF7F": {
        "oui_hex": "D4-BF-7F",
        "organization": "UPVEL",
        "address_1": "13139 Ramona Blvd. #F",
        "address_2": "Irwindale  CA  91706",
        "country": "US"
    },
    "2C72C3": {
        "oui_hex": "2C-72-C3",
        "organization": "Soundmatters",
        "address_1": "8060 Double R Blvd Suite 100",
        "address_2": "Reno  NV  89511",
        "country": "US"
    },
    "C44838": {
        "oui_hex": "C4-48-38",
        "organization": "Satcom Direct, Inc.",
        "address_1": "1901 Hwy A1A",
        "address_2": "Satellite Beach  FL  32937",
        "country": "US"
    },
    "C8DDC9": {
        "oui_hex": "C8-DD-C9",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,",
        "address_2": "Xiamen   Fujian  361006",
        "country": "US"
    },
    "6C8686": {
        "oui_hex": "6C-86-86",
        "organization": "Technonia",
        "address_1": "#1101, Hanshin IT Tower 235",
        "address_2": "  Seoul  152-768",
        "country": "KR"
    },
    "D4AC4E": {
        "oui_hex": "D4-AC-4E",
        "organization": "BODi rS, LLC",
        "address_1": "7622 Rickenbacker Drive",
        "address_2": "Gaithersburg  MD  20879",
        "country": "US"
    },
    "204C6D": {
        "oui_hex": "20-4C-6D",
        "organization": "Hugo Brennenstuhl Gmbh & Co. KG.",
        "address_1": "Seestr. 1-3",
        "address_2": "Tuebingen  Baden-Wuerttemberg  72074",
        "country": "DE"
    },
    "40C4D6": {
        "oui_hex": "40-C4-D6",
        "organization": "ChongQing Camyu Technology Development Co.,Ltd.",
        "address_1": "4th Floor,Tower of Venus Technology Building ,NO 60 Xing Guang Road",
        "address_2": "  Chong Qing  401121",
        "country": "CN"
    },
    "A8294C": {
        "oui_hex": "A8-29-4C",
        "organization": "Precision Optical Transceivers, Inc.",
        "address_1": "2328 Innovation Way",
        "address_2": "Rochester  NY  14624",
        "country": "US"
    },
    "70C6AC": {
        "oui_hex": "70-C6-AC",
        "organization": "Bosch Automotive Aftermarket",
        "address_1": "Franz Oechsle Str. 4",
        "address_2": "Plochingen    D-73201",
        "country": "DE"
    },
    "7C0507": {
        "oui_hex": "7C-05-07",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "880905": {
        "oui_hex": "88-09-05",
        "organization": "MTMCommunications",
        "address_1": "2-3-10 Honmachi",
        "address_2": "Ichinomiya-shi  Aichi-ken  491-0853",
        "country": "US"
    },
    "30D46A": {
        "oui_hex": "30-D4-6A",
        "organization": "Autosales Incorporated",
        "address_1": "1200 Souteat Avenue",
        "address_2": "Tallmadge  Ohio  44278",
        "country": "US"
    },
    "282CB2": {
        "oui_hex": "28-2C-B2",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "64E599": {
        "oui_hex": "64-E5-99",
        "organization": "EFM Networks",
        "address_1": "6F, Benposra II 1197-1 Bojeong Giheung Gu",
        "address_2": "Yong In  Kyunggi do  446913",
        "country": "KR"
    },
    "308999": {
        "oui_hex": "30-89-99",
        "organization": "Guangdong East Power Co.,",
        "address_1": "No.6 Northern Industry Road,Songshan lake SCI&TECH Industry Park",
        "address_2": "DongGuan  GuangDong  523808",
        "country": "CN"
    },
    "C89346": {
        "oui_hex": "C8-93-46",
        "organization": "MXCHIP Company Limited",
        "address_1": "Room 811,Tongpu Building,",
        "address_2": "Shanghai  Shanghai  200333",
        "country": "CN"
    },
    "F4B381": {
        "oui_hex": "F4-B3-81",
        "organization": "WindowMaster A/S",
        "address_1": "Skelstedet 13",
        "address_2": "Vedbaek    2950",
        "country": "DK"
    },
    "74F102": {
        "oui_hex": "74-F1-02",
        "organization": "Beijing HCHCOM Technology Co., Ltd",
        "address_1": "Patton Building 8 floor,11# Wan liu zhong lu,Haidian District,Beijing,China",
        "address_2": "Beijing  China  100089",
        "country": "CN"
    },
    "A0861D": {
        "oui_hex": "A0-86-1D",
        "organization": "Chengdu Fuhuaxin Technology co.,Ltd",
        "address_1": "Room 1608,Building G1,No.1800 of Yizhou Ave",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "508D6F": {
        "oui_hex": "50-8D-6F",
        "organization": "CHAHOO Limited",
        "address_1": "B-4thFloor, 631",
        "address_2": "Sungnam  Gyeonggi  463-400",
        "country": "KR"
    },
    "E8DE27": {
        "oui_hex": "E8-DE-27",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "94ACCA": {
        "oui_hex": "94-AC-CA",
        "organization": "trivum technologies GmbH",
        "address_1": "Heusteigstraße 37",
        "address_2": "Stuttgart    70108",
        "country": "DE"
    },
    "9C9726": {
        "oui_hex": "9C-97-26",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "908260": {
        "oui_hex": "90-82-60",
        "organization": "IEEE 1904.1 Working Group",
        "address_1": "1351 Redwood Way,",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "D4EE07": {
        "oui_hex": "D4-EE-07",
        "organization": "HIWIFI Co., Ltd.",
        "address_1": "Room 1002, Zhongguancun e-Plaza A,",
        "address_2": "Haidian District  Beijing  100080",
        "country": "CN"
    },
    "FCAD0F": {
        "oui_hex": "FC-AD-0F",
        "organization": "QTS NETWORKS",
        "address_1": "Jinyanlong Plaza, Huilongguan,",
        "address_2": "  Beijing  100092",
        "country": "CN"
    },
    "984C04": {
        "oui_hex": "98-4C-04",
        "organization": "Zhangzhou Keneng Electrical Equipment Co Ltd",
        "address_1": "Keneng Technology Park,No.12 Wuqiao Zhong Rd",
        "address_2": "Zhangzhou  Fujian  363005",
        "country": "CN"
    },
    "A4E991": {
        "oui_hex": "A4-E9-91",
        "organization": "SISTEMAS AUDIOVISUALES ITELSIS S.L.",
        "address_1": "POL.IND. DEL TAMBRE",
        "address_2": "SANTIAGO COMPOSTELA  A CORUÑA  15890",
        "country": "ES"
    },
    "3C86A8": {
        "oui_hex": "3C-86-A8",
        "organization": "Sangshin elecom .co,, LTD",
        "address_1": "614-1 Wolhari Suhmyon",
        "address_2": "  Choongnam  339-814",
        "country": "KR"
    },
    "84F493": {
        "oui_hex": "84-F4-93",
        "organization": "OMS spol. s.r.o.",
        "address_1": "Dojc 419",
        "address_2": "Dojc  Slovakia  90602",
        "country": "SK"
    },
    "BCD177": {
        "oui_hex": "BC-D1-77",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "ACDBDA": {
        "oui_hex": "AC-DB-DA",
        "organization": "Shenzhen Geniatech Inc, Ltd",
        "address_1": "18th F, GDC Building,No.9 ,Gaoxin Central Avenue 3rd",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "D42751": {
        "oui_hex": "D4-27-51",
        "organization": "Infopia Co., Ltd",
        "address_1": "891, Hogye-dong, Dongan-gu",
        "address_2": "Anyang  Gyeonggi  431-080",
        "country": "KR"
    },
    "103DEA": {
        "oui_hex": "10-3D-EA",
        "organization": "HFC Technology (Beijing) Ltd. Co.",
        "address_1": "Building #3, Room 1214",
        "address_2": "Beijing  AP (Area Pacific)  100193",
        "country": "CN"
    },
    "F05DC8": {
        "oui_hex": "F0-5D-C8",
        "organization": "Duracell Powermat",
        "address_1": "230 Park Ave, suit 910",
        "address_2": "new york  NY  10169",
        "country": "US"
    },
    "CC5D57": {
        "oui_hex": "CC-5D-57",
        "organization": "Information  System Research Institute,Inc.",
        "address_1": "Metro city minamiikebukuro-bldg.5F",
        "address_2": "Toshima-ku  Tokyo  171-0022",
        "country": "JP"
    },
    "64C667": {
        "oui_hex": "64-C6-67",
        "organization": "Barnes&Noble",
        "address_1": "400 Hamilton Avenue",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "F0F260": {
        "oui_hex": "F0-F2-60",
        "organization": "Mobitec AB",
        "address_1": "Box 97",
        "address_2": "Herrljunga  VG  52421",
        "country": "SE"
    },
    "044CEF": {
        "oui_hex": "04-4C-EF",
        "organization": "Fujian Sanao Technology Co.,Ltd",
        "address_1": "Fuzhou shibei bicyclic road no. 117",
        "address_2": "Fuzhou  Fujian  350000",
        "country": "CN"
    },
    "4C804F": {
        "oui_hex": "4C-80-4F",
        "organization": "Armstrong Monitoring Corp",
        "address_1": "215 Colonnade Rd",
        "address_2": "Nepean  Ontario  K2E 7K3",
        "country": "CA"
    },
    "7CD762": {
        "oui_hex": "7C-D7-62",
        "organization": "Freestyle Technology Pty Ltd",
        "address_1": "1A 24 Ricketts Road",
        "address_2": "Mount Waverley  Victoria  3149",
        "country": "AU"
    },
    "901D27": {
        "oui_hex": "90-1D-27",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "9C3178": {
        "oui_hex": "9C-31-78",
        "organization": "Foshan Huadian Intelligent Communications Teachnologies Co.,Ltd",
        "address_1": "Building B,No.8 of Shishan Industrial Avenue",
        "address_2": "Foshan  Guangdong  528225",
        "country": "CN"
    },
    "B0C95B": {
        "oui_hex": "B0-C9-5B",
        "organization": "Beijing Symtech CO.,LTD",
        "address_1": "Technology Park Building 2-1,The Hung Fu Pioneer Park",
        "address_2": "  Beijing  102209",
        "country": "CN"
    },
    "4CCA53": {
        "oui_hex": "4C-CA-53",
        "organization": "Skyera, Inc.",
        "address_1": "1704 Automation Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "90FF79": {
        "oui_hex": "90-FF-79",
        "organization": "Metro Ethernet Forum",
        "address_1": "6033 W. Century Boulevard",
        "address_2": "Los Angeles  California  90045",
        "country": "US"
    },
    "B01408": {
        "oui_hex": "B0-14-08",
        "organization": "LIGHTSPEED INTERNATIONAL CO.",
        "address_1": "No.20, LANE 526 NIUPU East RD.",
        "address_2": "Hsinchu  Not US/Canada  30091",
        "country": "TW"
    },
    "081DFB": {
        "oui_hex": "08-1D-FB",
        "organization": "Shanghai Mexon Communication Technology Co.,Ltd",
        "address_1": "Floor4-5, Unit B, Building 5 ,Lane 128, Jiujing Road",
        "address_2": "Shanghai  Shanghai  201615",
        "country": "CN"
    },
    "983F9F": {
        "oui_hex": "98-3F-9F",
        "organization": "China SSJ (Suzhou) Network Technology Inc.",
        "address_1": "399 Linquan St., Dongnan Building 411",
        "address_2": "Suzhou  Jiangsu  215123",
        "country": "CN"
    },
    "B838CA": {
        "oui_hex": "B8-38-CA",
        "organization": "Kyokko Tsushin System CO.,LTD",
        "address_1": "2-25-7 sakado,Takatsu-ku",
        "address_2": "Kawasaki  Kanagawa  213-0012",
        "country": "JP"
    },
    "C44EAC": {
        "oui_hex": "C4-4E-AC",
        "organization": "Shenzhen Shiningworth Technology Co., Ltd.",
        "address_1": "Room 610, Block B, Huameiju Business Center,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A80180": {
        "oui_hex": "A8-01-80",
        "organization": "IMAGO Technologies GmbH",
        "address_1": "Strassheimer Str. 45",
        "address_2": "Friedberg  Hessen  61169",
        "country": "DE"
    },
    "0C5521": {
        "oui_hex": "0C-55-21",
        "organization": "Axiros GmbH",
        "address_1": "Altlaufstrasse 34",
        "address_2": "Munich Hoehenkirchen  Bavaria  85635",
        "country": "DE"
    },
    "68A40E": {
        "oui_hex": "68-A4-0E",
        "organization": "BSH Hausgeräte GmbH",
        "address_1": "Im Gewerbepark B35",
        "address_2": "Regensburg  Bayern  93059",
        "country": "DE"
    },
    "F4C6D7": {
        "oui_hex": "F4-C6-D7",
        "organization": "blackned GmbH",
        "address_1": "Am Hartholz 21",
        "address_2": "Alling  Bavaria  82239",
        "country": "DE"
    },
    "D4CA6E": {
        "oui_hex": "D4-CA-6E",
        "organization": "u-blox AG",
        "address_1": "Zuercherstrasse 68",
        "address_2": "Thalwil    8800",
        "country": "CH"
    },
    "5C43D2": {
        "oui_hex": "5C-43-D2",
        "organization": "HAZEMEYER",
        "address_1": "ZI Route de Grugies",
        "address_2": "GAUCHY  FRANCE  02430",
        "country": "FR"
    },
    "D809C3": {
        "oui_hex": "D8-09-C3",
        "organization": "Cercacor Labs",
        "address_1": "189 Technology Dr",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "E0C2B7": {
        "oui_hex": "E0-C2-B7",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "A01917": {
        "oui_hex": "A0-19-17",
        "organization": "Bertel S.p.a.",
        "address_1": "Frazione Rimale, Via Emilia Ovest 61",
        "address_2": "Fidenza  Parma  43036",
        "country": "IT"
    },
    "68B8D9": {
        "oui_hex": "68-B8-D9",
        "organization": "Act KDE, Inc.",
        "address_1": "196-14, Bangi-dong, Songpa-gu",
        "address_2": "Seoul    138-834",
        "country": "KR"
    },
    "90CC24": {
        "oui_hex": "90-CC-24",
        "organization": "Synaptics, Inc",
        "address_1": "1251 McKay Drive",
        "address_2": "San Jose  CA   95131-1709",
        "country": "US"
    },
    "2CE871": {
        "oui_hex": "2C-E8-71",
        "organization": "Alert Metalguard ApS",
        "address_1": "Vester Voldgade 104, st, th",
        "address_2": "Copenhagen V    1552",
        "country": "DK"
    },
    "F87B62": {
        "oui_hex": "F8-7B-62",
        "organization": "FASTWEL INTERNATIONAL CO., LTD. Taiwan Branch",
        "address_1": "6F., No.118, Ln. 235, Baociao Rd., Sindian City, Taipei County 231, Taiwan  R.O.C.",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "40270B": {
        "oui_hex": "40-27-0B",
        "organization": "Mobileeco Co., Ltd",
        "address_1": "#2126, IT Tower B, Keumkang Penterium Bldg, 810",
        "address_2": "Anyang City  Kyunggi-Do  431810",
        "country": "KR"
    },
    "74FE48": {
        "oui_hex": "74-FE-48",
        "organization": "ADVANTECH CO., LTD.",
        "address_1": "NO.1, Alley 20, Lane 26",
        "address_2": "  TAIPEI  231",
        "country": "TW"
    },
    "80B95C": {
        "oui_hex": "80-B9-5C",
        "organization": "ELFTECH Co., Ltd.",
        "address_1": "174, Daehyeon Techno World 6F 609,",
        "address_2": "Uiwang-Si  Gyeonggi-Do  437-753",
        "country": "KR"
    },
    "38B5BD": {
        "oui_hex": "38-B5-BD",
        "organization": "E.G.O. Elektro-Ger",
        "address_1": "Einkauf",
        "address_2": "Oberderdingen    75038",
        "country": "DE"
    },
    "20918A": {
        "oui_hex": "20-91-8A",
        "organization": "PROFALUX",
        "address_1": "377 rue des Cypr",
        "address_2": "THYEZ  Haute Savoie  74300",
        "country": "FR"
    },
    "E4EEFD": {
        "oui_hex": "E4-EE-FD",
        "organization": "MR&D Manufacturing",
        "address_1": "Viale dell'Unione Europea, 8",
        "address_2": "Gallarate  Varese  21013",
        "country": "US"
    },
    "105CBF": {
        "oui_hex": "10-5C-BF",
        "organization": "DuroByte Inc",
        "address_1": "875 Foster Ave, Unit 101",
        "address_2": "Windsor  Ontario  N8X4W3",
        "country": "CA"
    },
    "A46E79": {
        "oui_hex": "A4-6E-79",
        "organization": "DFT System Co.Ltd",
        "address_1": "Room 6B XINHAOFANG Building",
        "address_2": "SHENZHEN  GUANGDONG  518052",
        "country": "CN"
    },
    "C88A83": {
        "oui_hex": "C8-8A-83",
        "organization": "Dongguan HuaHong Electronics Co.,Ltd",
        "address_1": "NO.25,Xing Er Road,Chen Wu Industrial Zone,Wusha Village,Chang£§an Town",
        "address_2": "Dongguan City  China/Guangdong  523858",
        "country": "CN"
    },
    "8CC5E1": {
        "oui_hex": "8C-C5-E1",
        "organization": "ShenZhen Konka Telecommunication Technology Co.,Ltd",
        "address_1": "No.9008 Shennan Road",
        "address_2": "ShenZhen  GuangDong  518053",
        "country": "CN"
    },
    "64A341": {
        "oui_hex": "64-A3-41",
        "organization": "Wonderlan (Beijing) Technology Co., Ltd.",
        "address_1": "Room 04D, Building D, KeShi Plaza",
        "address_2": " Haidian District  Beijing  100085",
        "country": "CN"
    },
    "7898FD": {
        "oui_hex": "78-98-FD",
        "organization": "Q9 Networks Inc.",
        "address_1": "Suite 4400, PO Box 235",
        "address_2": "Toronto  ON  M5K 1J3",
        "country": "CA"
    },
    "D063B4": {
        "oui_hex": "D0-63-B4",
        "organization": "SolidRun Ltd.",
        "address_1": "P.O Box 50782",
        "address_2": "Nazareth  ISRAEL  16165",
        "country": "IL"
    },
    "9C541C": {
        "oui_hex": "9C-54-1C",
        "organization": "Shenzhen My-power Technology Co.,Ltd",
        "address_1": "202¬Building 3¬Shenzhen Software Park",
        "address_2": "Shenzhen  Nanshan  518000",
        "country": "CN"
    },
    "8C3330": {
        "oui_hex": "8C-33-30",
        "organization": "EmFirst Co., Ltd.",
        "address_1": "701 Suwon Venture Center",
        "address_2": "Suwon  Gyeonggi-do  442-833",
        "country": "KR"
    },
    "087BAA": {
        "oui_hex": "08-7B-AA",
        "organization": "SVYAZKOMPLEKTSERVICE, LLC",
        "address_1": "Lenskaya 2-21",
        "address_2": "Moscow    129327",
        "country": "US"
    },
    "24F2DD": {
        "oui_hex": "24-F2-DD",
        "organization": "Radiant Zemax LLC",
        "address_1": "22908 NE Alder Crest Dr NE Ste 100",
        "address_2": "Redmond  WA  98053",
        "country": "US"
    },
    "20B5C6": {
        "oui_hex": "20-B5-C6",
        "organization": "Mimosa Networks",
        "address_1": "656 N. Santa Cruz. Ave., Suite B",
        "address_2": "Los Gatos  CA  95030",
        "country": "US"
    },
    "E4E409": {
        "oui_hex": "E4-E4-09",
        "organization": "LEIFHEIT AG",
        "address_1": "Leifhheitstreet",
        "address_2": "Nassau  Rheinland-Pfalz  56377",
        "country": "DE"
    },
    "B877C3": {
        "oui_hex": "B8-77-C3",
        "organization": "METER Group",
        "address_1": "2365 NE Hopkins Court",
        "address_2": "Pullman  WA  99163",
        "country": "US"
    },
    "004D32": {
        "oui_hex": "00-4D-32",
        "organization": "Andon Health Co.,Ltd.",
        "address_1": "NO.3Jin PIng Road Ya An Street",
        "address_2": "Tianjin    300190",
        "country": "CN"
    },
    "FCA9B0": {
        "oui_hex": "FC-A9-B0",
        "organization": "MIARTECH (SHANGHAI),INC.",
        "address_1": "3F,Building 4,No 290 Zhangheng Road Zhangjiang Hi-Tech Park,Pudong New District Shanghai,P.R.China",
        "address_2": "SHANGHAI  SHANGHAI  201204",
        "country": "CN"
    },
    "94DE80": {
        "oui_hex": "94-DE-80",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "2C441B": {
        "oui_hex": "2C-44-1B",
        "organization": "Spectrum Medical Limited",
        "address_1": "Harrier 4, Meteor Business Park",
        "address_2": "Gloucester    GL2 9QL",
        "country": "US"
    },
    "EC4993": {
        "oui_hex": "EC-49-93",
        "organization": "Qihan Technology Co., Ltd",
        "address_1": "20th Floor,Times Technology BuildingNo.7028,Shennan Road,Futian,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "B0ACFA": {
        "oui_hex": "B0-AC-FA",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "8CE081": {
        "oui_hex": "8C-E0-81",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A44E2D": {
        "oui_hex": "A4-4E-2D",
        "organization": "Adaptive Wireless Solutions, LLC",
        "address_1": "577 Main Street",
        "address_2": "Hudson  MA  01749",
        "country": "US"
    },
    "0CCDFB": {
        "oui_hex": "0C-CD-FB",
        "organization": "EDIC Systems Inc.",
        "address_1": "1-3-7 Nakamachidai",
        "address_2": "Yokohama  Kanagawa  224-0041",
        "country": "JP"
    },
    "9C8D1A": {
        "oui_hex": "9C-8D-1A",
        "organization": "INTEG process group inc",
        "address_1": "2919 E Hardies Rd, First Floor",
        "address_2": "Gibsonia  PA  15044",
        "country": "US"
    },
    "480362": {
        "oui_hex": "48-03-62",
        "organization": "DESAY ELECTRONICS(HUIZHOU)CO.,LTD",
        "address_1": "BuildingA,No.3 Desay Industrial Zone",
        "address_2": "Huizhou  Guangdong  516029",
        "country": "CN"
    },
    "18673F": {
        "oui_hex": "18-67-3F",
        "organization": "Hanover Displays Limited",
        "address_1": "Unit 24",
        "address_2": "Lewes  East Sussex  BN8 6JL",
        "country": "GB"
    },
    "7C0A50": {
        "oui_hex": "7C-0A-50",
        "organization": "J-MEX Inc.",
        "address_1": "B2, 3F, No.1, Li-Hsin 1st Road,",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "5011EB": {
        "oui_hex": "50-11-EB",
        "organization": "SilverNet Ltd",
        "address_1": "16 Cocran Close",
        "address_2": "Milton Keynes  Bucks  MK8 0AJ",
        "country": "GB"
    },
    "54DF63": {
        "oui_hex": "54-DF-63",
        "organization": "Intrakey technologies GmbH",
        "address_1": "Wiener Strasse 114-116",
        "address_2": "Dresden  Saxony  01219",
        "country": "DE"
    },
    "40F2E9": {
        "oui_hex": "40-F2-E9",
        "organization": "IBM",
        "address_1": "3039 E Cornwallis Rd",
        "address_2": "Research Triangle Park  NC  27709",
        "country": "US"
    },
    "744D79": {
        "oui_hex": "74-4D-79",
        "organization": "Arrive Systems Inc.",
        "address_1": "1404 Franklin Street, # 350",
        "address_2": "Oakland  CA  94612",
        "country": "US"
    },
    "9C0473": {
        "oui_hex": "9C-04-73",
        "organization": "Tecmobile (International) Ltd.",
        "address_1": "Unit L, Braintree Industrial Estate,",
        "address_2": "    HA4 0EJ",
        "country": "GB"
    },
    "B4DFFA": {
        "oui_hex": "B4-DF-FA",
        "organization": "Litemax Electronics Inc.",
        "address_1": "8F, No.137,Lane 235",
        "address_2": "Shin-dian-Dist  New Taipei  23145",
        "country": "TW"
    },
    "681CA2": {
        "oui_hex": "68-1C-A2",
        "organization": "Rosewill Inc.",
        "address_1": "17708 Rowland St.,",
        "address_2": "City of Industry  CA  91748",
        "country": "US"
    },
    "604616": {
        "oui_hex": "60-46-16",
        "organization": "XIAMEN VANN INTELLIGENT CO., LTD",
        "address_1": "UNIT 101£¬NO.28 GUANRI RD., SOFTWARE PARK ¢ò",
        "address_2": "XIAMEN  FUJIAN  361009",
        "country": "CN"
    },
    "E45614": {
        "oui_hex": "E4-56-14",
        "organization": "Suttle Apparatus",
        "address_1": "1001 East Highway 212",
        "address_2": "Hector  MN  55342",
        "country": "US"
    },
    "3C83B5": {
        "oui_hex": "3C-83-B5",
        "organization": "Advance Vision Electronics Co. Ltd.",
        "address_1": "6F, No. 199, Lide St. Jhonghe Dist",
        "address_2": "New Taipei City, Jhonghe Dist    23556",
        "country": "TW"
    },
    "28A192": {
        "oui_hex": "28-A1-92",
        "organization": "GERP Solution",
        "address_1": "Rua Costa Aguiar, 1710",
        "address_2": "São Paulo  SP  04204002",
        "country": "BR"
    },
    "106FEF": {
        "oui_hex": "10-6F-EF",
        "organization": "Ad-Sol Nissin Corp",
        "address_1": "Rivage Shinagawa, 4-1-8 Kounan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "6C40C6": {
        "oui_hex": "6C-40-C6",
        "organization": "Nimbus Data, Inc.",
        "address_1": "5151 California Ave, Ste 100",
        "address_2": "Irvine  CA  92617",
        "country": "US"
    },
    "1048B1": {
        "oui_hex": "10-48-B1",
        "organization": "Beijing Duokan Technology Limited",
        "address_1": "Room 1105, Changxin Building, No.39 Anding Road",
        "address_2": "Chaoyang District  Beijing  100029",
        "country": "CN"
    },
    "D493A0": {
        "oui_hex": "D4-93-A0",
        "organization": "Fidelix Oy",
        "address_1": "Martinkyläntie 41",
        "address_2": "VANTAA  International  01720",
        "country": "FI"
    },
    "08EBED": {
        "oui_hex": "08-EB-ED",
        "organization": "World Elite Technology Co.,LTD",
        "address_1": "6/F Liyuan floor ,Dragon City North Road on the 3rd",
        "address_2": "ShenZhen  GuangDong  518100",
        "country": "CN"
    },
    "DC9FA4": {
        "oui_hex": "DC-9F-A4",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "44C39B": {
        "oui_hex": "44-C3-9B",
        "organization": "OOO RUBEZH NPO",
        "address_1": "Pionerskaya 11a",
        "address_2": "Bratsk  Irkutsk  665717",
        "country": "RU"
    },
    "C44567": {
        "oui_hex": "C4-45-67",
        "organization": "SAMBON PRECISON and ELECTRONICS",
        "address_1": "204, Samjeong-dong, Ojeong-gu",
        "address_2": "Bucheon-city   Kyeonggi-do  421-810",
        "country": "KR"
    },
    "48F8B3": {
        "oui_hex": "48-F8-B3",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "D8D27C": {
        "oui_hex": "D8-D2-7C",
        "organization": "JEMA ENERGY, SA",
        "address_1": "Pº Circuito nº10",
        "address_2": "Lasarte-Oria  Guipuzcoa  20160",
        "country": "ES"
    },
    "B01203": {
        "oui_hex": "B0-12-03",
        "organization": "Dynamics Hong Kong Limited",
        "address_1": "Room A4, 3/F, Friend's House , No.6A Carnarvon Road,",
        "address_2": "    999077",
        "country": "HK"
    },
    "9886B1": {
        "oui_hex": "98-86-B1",
        "organization": "Flyaudio corporation (China)",
        "address_1": "No.16 Mingzhu RD Economic&Technology",
        "address_2": "Guangzhou  Guangdong Province  510730",
        "country": "CN"
    },
    "7093F8": {
        "oui_hex": "70-93-F8",
        "organization": "Space Monkey, Inc.",
        "address_1": "7707 south main street",
        "address_2": "Midvale  Utah  84047",
        "country": "US"
    },
    "28B3AB": {
        "oui_hex": "28-B3-AB",
        "organization": "Genmark Automation",
        "address_1": "1201 Cadillac Ct",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "C4E7BE": {
        "oui_hex": "C4-E7-BE",
        "organization": "SCSpro Co.,Ltd",
        "address_1": "#1203, KCC welltz valley 470-8",
        "address_2": "Seoul  Korea  153-710",
        "country": "KR"
    },
    "58874C": {
        "oui_hex": "58-87-4C",
        "organization": "LITE-ON CLEAN ENERGY TECHNOLOGY CORP.",
        "address_1": "3F, 392, Ruey Kuang Road, Neihu,",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "2891D0": {
        "oui_hex": "28-91-D0",
        "organization": "Stage Tec Entwicklungsgesellschaft für professionelle Audiotechnik mbH",
        "address_1": "Tabbertstraße 10",
        "address_2": "Berlin    12459",
        "country": "DE"
    },
    "C0BD42": {
        "oui_hex": "C0-BD-42",
        "organization": "ZPA Smart Energy a.s.",
        "address_1": "Komenskeho 821",
        "address_2": "Trutnov    54101",
        "country": "CZ"
    },
    "FC52CE": {
        "oui_hex": "FC-52-CE",
        "organization": "Control iD",
        "address_1": "Rua Hungria, 574",
        "address_2": "São Paulo  SP  01455-000",
        "country": "BR"
    },
    "5C4A26": {
        "oui_hex": "5C-4A-26",
        "organization": "Enguity Technology Corp",
        "address_1": "2020 Pennsylvania Ave., NW",
        "address_2": "Washington  DC  20006",
        "country": "US"
    },
    "60F2EF": {
        "oui_hex": "60-F2-EF",
        "organization": "VisionVera International Co., Ltd.",
        "address_1": "A1103 Gehua Building",
        "address_2": "  Beijing  100007",
        "country": "CN"
    },
    "C03F2A": {
        "oui_hex": "C0-3F-2A",
        "organization": "Biscotti, Inc.",
        "address_1": "5900 South Lake Forest Drive",
        "address_2": "McKinney  TX  75070",
        "country": "US"
    },
    "381C4A": {
        "oui_hex": "38-1C-4A",
        "organization": "SIMCom Wireless Solutions Co.,Ltd.",
        "address_1": "Building A,SIM Technology Building,No.633,Jinzhong Road,",
        "address_2": "  Shanghai  200335",
        "country": "CN"
    },
    "D8C691": {
        "oui_hex": "D8-C6-91",
        "organization": "Hichan Technology Corp.",
        "address_1": "12F., No.2, Jian 8th Rd., Zhonghe Dist",
        "address_2": "New Taipei City    23511",
        "country": "TW"
    },
    "E43FA2": {
        "oui_hex": "E4-3F-A2",
        "organization": "Wuxi DSP Technologies Inc.",
        "address_1": "Rm A801,530Mansion,International High-Tech Park,Qingyuan Road",
        "address_2": "Wuxi  Jiangsu  214000",
        "country": "US"
    },
    "F4B72A": {
        "oui_hex": "F4-B7-2A",
        "organization": "TIME INTERCONNECT LTD",
        "address_1": "6/F, Photonics Centre",
        "address_2": "",
        "country": "HK"
    },
    "749975": {
        "oui_hex": "74-99-75",
        "organization": "IBM Corporation",
        "address_1": "4400 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "2C625A": {
        "oui_hex": "2C-62-5A",
        "organization": "Finest Security Systems Co., Ltd",
        "address_1": "12F, No.103, Sec3, Nan King E. RD",
        "address_2": "Taipei    104",
        "country": "US"
    },
    "2074CF": {
        "oui_hex": "20-74-CF",
        "organization": "Shenzhen Voxtech Co.,Ltd",
        "address_1": "4/F East, Building 4, Minqi Science&Technology Park, Pingshan,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "E0F5CA": {
        "oui_hex": "E0-F5-CA",
        "organization": "CHENG UEI PRECISION INDUSTRY CO.,LTD.",
        "address_1": "No. 18, ZhongShan Rd., TuCheng Dist.,",
        "address_2": "New Taipei City  Taiwan  23680",
        "country": "TW"
    },
    "A8EF26": {
        "oui_hex": "A8-EF-26",
        "organization": "Tritonwave",
        "address_1": "795 Lakeshore Dr, Suite 307",
        "address_2": "  Quebec  H9S 0A8",
        "country": "CA"
    },
    "20DC93": {
        "oui_hex": "20-DC-93",
        "organization": "Cheetah Hi-Tech, Inc.",
        "address_1": "Rm 804, No. 5, Sec. 2, Anhe Rd.",
        "address_2": "Taipei  Taiwan  10680",
        "country": "TW"
    },
    "4423AA": {
        "oui_hex": "44-23-AA",
        "organization": "Farmage Co., Ltd.",
        "address_1": "166-8 Kanazawa Toubetsu",
        "address_2": "  Hokkaido  061-0212",
        "country": "JP"
    },
    "7CFE28": {
        "oui_hex": "7C-FE-28",
        "organization": "Salutron Inc.",
        "address_1": "40979 Encyclopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "E8102E": {
        "oui_hex": "E8-10-2E",
        "organization": "Really Simple Software, Inc",
        "address_1": "P.O. Box 1086",
        "address_2": "Tiburon  California  94920",
        "country": "US"
    },
    "0C565C": {
        "oui_hex": "0C-56-5C",
        "organization": "HyBroad Vision (Hong Kong) Technology Co Ltd",
        "address_1": "Unit 1808 18/F Tower 3 Enterprise Square",
        "address_2": "Kowloon Bay",
        "country": "HK"
    },
    "8C6AE4": {
        "oui_hex": "8C-6A-E4",
        "organization": "Viogem Limited",
        "address_1": "Paddock House",
        "address_2": "Orlingbury  Northamptonshire  NN141JH",
        "country": "GB"
    },
    "543968": {
        "oui_hex": "54-39-68",
        "organization": "Edgewater Networks Inc",
        "address_1": "2895 Northwestern Parkway",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "440CFD": {
        "oui_hex": "44-0C-FD",
        "organization": "NetMan Co., Ltd.",
        "address_1": "Rm 406, DIP, 2139, Daemyeong-dong,",
        "address_2": "Daegu    705-701",
        "country": "KR"
    },
    "8CD3A2": {
        "oui_hex": "8C-D3-A2",
        "organization": "VisSim AS",
        "address_1": "Vollveien 5",
        "address_2": "Horten  Vestfold  3183",
        "country": "NO"
    },
    "D82DE1": {
        "oui_hex": "D8-2D-E1",
        "organization": "Tricascade Inc.",
        "address_1": "5020 Campus Drv.",
        "address_2": "Newport Beach  CA  92660",
        "country": "US"
    },
    "14358B": {
        "oui_hex": "14-35-8B",
        "organization": "Mediabridge Products, LLC.",
        "address_1": "1951 Old Cuthbert Rd",
        "address_2": "Cherry Hill  New Jersey  08034",
        "country": "US"
    },
    "00F403": {
        "oui_hex": "00-F4-03",
        "organization": "Orbis Systems Oy",
        "address_1": "Taivaltie 5",
        "address_2": "Vantaa    01610",
        "country": "FI"
    },
    "547398": {
        "oui_hex": "54-73-98",
        "organization": "Toyo Electronics Corporation",
        "address_1": "1860-38, Simoakasaka",
        "address_2": "Kawagoe  Saitama  3501155",
        "country": "JP"
    },
    "E0A30F": {
        "oui_hex": "E0-A3-0F",
        "organization": "Pevco",
        "address_1": "1401 Tangier Drive",
        "address_2": "Baltimore  MD  21220",
        "country": "US"
    },
    "88DC96": {
        "oui_hex": "88-DC-96",
        "organization": "SENAO Networks, Inc.",
        "address_1": "No. 500, Fusing 3rd Rd., Hwa-Ya Technology Park",
        "address_2": "Kuei-Shan Hsiang  TaoYuan County  333",
        "country": "TW"
    },
    "20443A": {
        "oui_hex": "20-44-3A",
        "organization": "Schneider Electric Asia Pacific Ltd",
        "address_1": "13F East Wing, Warwick House, Taikoo Place",
        "address_2": "Quarry Bay",
        "country": "HK"
    },
    "C4393A": {
        "oui_hex": "C4-39-3A",
        "organization": "SMC Networks Inc",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "5C2479": {
        "oui_hex": "5C-24-79",
        "organization": "Baltech AG",
        "address_1": "Lilienthalstrasse 27",
        "address_2": "Hallbergmoos    85399",
        "country": "DE"
    },
    "EC9327": {
        "oui_hex": "EC-93-27",
        "organization": "MEMMERT GmbH + Co. KG",
        "address_1": "Aeussere Rittersbacher Strasse 38",
        "address_2": "Schwabach  Bavaria  91126",
        "country": "DE"
    },
    "A0EF84": {
        "oui_hex": "A0-EF-84",
        "organization": "Seine Image Int'l Co., Ltd",
        "address_1": "6F,4Building, NO.63,Mingz North Road",
        "address_2": "ZhuHai    519075",
        "country": "CN"
    },
    "64517E": {
        "oui_hex": "64-51-7E",
        "organization": "LONG BEN (DONGGUAN) ELECTRONIC TECHNOLOGY CO.,LTD.",
        "address_1": "NO.19.Jian she Road,Shi ma Village,Tang xia  Town,Dong guan,Guang dong,China",
        "address_2": "Dong guan  Guang dong  523731",
        "country": "CN"
    },
    "D43D7E": {
        "oui_hex": "D4-3D-7E",
        "organization": "Micro-Star Int'l Co, Ltd",
        "address_1": "No.69, Lide St., Jhonghe City",
        "address_2": "Taipei County    235",
        "country": "US"
    },
    "ACD9D6": {
        "oui_hex": "AC-D9-D6",
        "organization": "tci GmbH",
        "address_1": "Ludwig-Rinn-Straße 10-14",
        "address_2": "Heuchelheim  Hessen  35452",
        "country": "US"
    },
    "48282F": {
        "oui_hex": "48-28-2F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "60CBFB": {
        "oui_hex": "60-CB-FB",
        "organization": "AirScape Inc.",
        "address_1": "625 Charles Way",
        "address_2": "Medford  OR  97501",
        "country": "US"
    },
    "7C160D": {
        "oui_hex": "7C-16-0D",
        "organization": "Saia-Burgess Controls AG",
        "address_1": "Bahnhofstrasse 18",
        "address_2": "Murten  FR  3280",
        "country": "CH"
    },
    "A497BB": {
        "oui_hex": "A4-97-BB",
        "organization": "Hitachi Industrial Equipment Systems Co.,Ltd",
        "address_1": "3, Kanda Neribei-cho",
        "address_2": "Chiyoda-ku  Tokyo  101-0022",
        "country": "US"
    },
    "4C5427": {
        "oui_hex": "4C-54-27",
        "organization": "Linepro Sp. z o.o.",
        "address_1": "ul. Miedziana 11",
        "address_2": "Warszawa  mazowieckie  00-835",
        "country": "PL"
    },
    "80D18B": {
        "oui_hex": "80-D1-8B",
        "organization": "Hangzhou I'converge Technology Co.,Ltd",
        "address_1": "No.618 Xixi Road,",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "4088E0": {
        "oui_hex": "40-88-E0",
        "organization": "Beijing Ereneben Information Technology Limited Shenzhen Branch",
        "address_1": "Room 14A, Building A, Honglong Central Plaza, No.3001,Heping Road, Luohu District, Shenzhen City",
        "address_2": "Shenzhen  Guangdong  518001",
        "country": "CN"
    },
    "E85484": {
        "oui_hex": "E8-54-84",
        "organization": "NEO Information Systems Co., Ltd.",
        "address_1": "609, Junganginduspia, #517-13, Sangdaeweon-Dong, Jungweon-Gu",
        "address_2": "Seongnam  Gyunggi-Do  462-713",
        "country": "KR"
    },
    "74AE76": {
        "oui_hex": "74-AE-76",
        "organization": "iNovo Broadband, Inc.",
        "address_1": "3475 Corporate Way",
        "address_2": "Duluth  Georgia  30096",
        "country": "US"
    },
    "EC1A59": {
        "oui_hex": "EC-1A-59",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  Ca.   90094",
        "country": "US"
    },
    "881036": {
        "oui_hex": "88-10-36",
        "organization": "Panodic(ShenZhen) Electronics Limted",
        "address_1": "Floor 12, Grentech Building, Keji.C. Road",
        "address_2": "ShenZhen  GuangDong   518052",
        "country": "CN"
    },
    "68B6FC": {
        "oui_hex": "68-B6-FC",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "ECA29B": {
        "oui_hex": "EC-A2-9B",
        "organization": "Kemppi Oy",
        "address_1": "Kempinkatu 1",
        "address_2": "Lahti  Lahti  15810",
        "country": "FI"
    },
    "04CE14": {
        "oui_hex": "04-CE-14",
        "organization": "Wilocity LTD.",
        "address_1": "21 Bareket St.",
        "address_2": "Caesarea  Israel  38900",
        "country": "US"
    },
    "C4BA99": {
        "oui_hex": "C4-BA-99",
        "organization": "I+ME Actia Informatik und Mikro-Elektronik GmbH",
        "address_1": "Dresdenstrasse 17/18",
        "address_2": "Braunschweig  Niedersachsen  38690",
        "country": "DE"
    },
    "A4934C": {
        "oui_hex": "A4-93-4C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D0D212": {
        "oui_hex": "D0-D2-12",
        "organization": "K2NET Co.,Ltd.",
        "address_1": "K2Net Building",
        "address_2": "  Seoul  158-092",
        "country": "KR"
    },
    "B0435D": {
        "oui_hex": "B0-43-5D",
        "organization": "NuLEDs, Inc.",
        "address_1": "1497 Poinsettia Ave.",
        "address_2": "Vista  CA  92081",
        "country": "US"
    },
    "0808EA": {
        "oui_hex": "08-08-EA",
        "organization": "AMSC",
        "address_1": "15775 W Schaefer Court",
        "address_2": "New Berlin  WI  53151",
        "country": "US"
    },
    "E8D483": {
        "oui_hex": "E8-D4-83",
        "organization": "ULTIMATE Europe Transportation Equipment GmbH",
        "address_1": "Industriestraße 3",
        "address_2": "3300  Niederösterreich  3300",
        "country": "AT"
    },
    "1C8464": {
        "oui_hex": "1C-84-64",
        "organization": "FORMOSA WIRELESS COMMUNICATION CORP.",
        "address_1": "11F., No.3-2, Yuanqu St., Nangang Dist.,",
        "address_2": "  Taipei City  115",
        "country": "TW"
    },
    "346E8A": {
        "oui_hex": "34-6E-8A",
        "organization": "Ecosense",
        "address_1": "1414 Kolon science vallet-II., #811",
        "address_2": "Seoul  Guro-gu  152-878",
        "country": "KR"
    },
    "64F242": {
        "oui_hex": "64-F2-42",
        "organization": "Gerdes Aktiengesellschaft",
        "address_1": "Bergerwiesenstraße 9",
        "address_2": "Meckenheim  NRW  53340",
        "country": "DE"
    },
    "60F281": {
        "oui_hex": "60-F2-81",
        "organization": "TRANWO TECHNOLOGY CO., LTD.",
        "address_1": "No.236, Sec.3, Huanbei Rd.",
        "address_2": "Jubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "942197": {
        "oui_hex": "94-21-97",
        "organization": "Stalmart Technology Limited",
        "address_1": "Rm1106-1107E, Building F, Xihaimingzhu, No.1, Taoyuan Road",
        "address_2": "Shenzhen  Gunagdong  518052",
        "country": "CN"
    },
    "A0C3DE": {
        "oui_hex": "A0-C3-DE",
        "organization": "Triton Electronic Systems Ltd.",
        "address_1": "620063, Ekaterinburg, P/O box 522",
        "address_2": "Ekaterinburg  Sverdlovskaya obl.  620063",
        "country": "RU"
    },
    "D0699E": {
        "oui_hex": "D0-69-9E",
        "organization": "LUMINEX Lighting Control Equipment",
        "address_1": "Berkenlaan 8 A",
        "address_2": "Hechtel - Eksel  Limburg  3940",
        "country": "BE"
    },
    "0CC0C0": {
        "oui_hex": "0C-C0-C0",
        "organization": "MAGNETI MARELLI SISTEMAS ELECTRONICOS MEXICO",
        "address_1": "AV. INDUSTRIA 20/21",
        "address_2": "TEPOTZOTLAN  MEXICO  54600",
        "country": "MX"
    },
    "08379C": {
        "oui_hex": "08-37-9C",
        "organization": "Topaz Co. LTD.",
        "address_1": "B305-22, Acrotower, 1591 Gwanyang-dong",
        "address_2": "Anyang-si  Gyeonggi-Do  431-060",
        "country": "KR"
    },
    "D80DE3": {
        "oui_hex": "D8-0D-E3",
        "organization": "FXI TECHNOLOGIES AS",
        "address_1": "Postboks 609",
        "address_2": "TRONDHEIM  Norge  7406",
        "country": "NO"
    },
    "B0D2F5": {
        "oui_hex": "B0-D2-F5",
        "organization": "Vello Systems, Inc.",
        "address_1": "1530 O'Brien Drive",
        "address_2": "Menlo Park  California  94025",
        "country": "US"
    },
    "709A0B": {
        "oui_hex": "70-9A-0B",
        "organization": "Italian Institute of Technology",
        "address_1": "Via Morego 30",
        "address_2": "Genova  GE  16163",
        "country": "IT"
    },
    "F0FDA0": {
        "oui_hex": "F0-FD-A0",
        "organization": "Acurix Networks Pty Ltd",
        "address_1": "Unit 5, 348 Victoria Road,",
        "address_2": "Malaga, Perth  Western Austraila  6090",
        "country": "NZ"
    },
    "B45570": {
        "oui_hex": "B4-55-70",
        "organization": "Borea",
        "address_1": "Mlaka 1b",
        "address_2": "Begunje    SI-4275",
        "country": "SI"
    },
    "100D2F": {
        "oui_hex": "10-0D-2F",
        "organization": "Online Security Pty. Ltd.",
        "address_1": "5/21-25 Redland Drive",
        "address_2": "Mitcham  VIC  3132",
        "country": "AU"
    },
    "142DF5": {
        "oui_hex": "14-2D-F5",
        "organization": "Amphitech",
        "address_1": "1, rue Robert & Sonia DELAUNAY",
        "address_2": "Paris    75011",
        "country": "FR"
    },
    "5057A8": {
        "oui_hex": "50-57-A8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00DEFB": {
        "oui_hex": "00-DE-FB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3CA315": {
        "oui_hex": "3C-A3-15",
        "organization": "Bless Information & Communications Co., Ltd",
        "address_1": "#64-1, Wonhyoro 3-ga, Yongsan-gu,",
        "address_2": "Seoul    140-848",
        "country": "KR"
    },
    "F83094": {
        "oui_hex": "F8-30-94",
        "organization": "Alcatel-Lucent Telecom Limited",
        "address_1": "The Quadrant, Stonehill Green",
        "address_2": "SWINDON    SN5 7DJ",
        "country": "GB"
    },
    "10A932": {
        "oui_hex": "10-A9-32",
        "organization": "Beijing Cyber Cloud Technology Co. ,Ltd.",
        "address_1": "2/F, Tower B, Jingmeng High-tech Building. No. 5 Shangdi East Road, Haidian District.",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "34FC6F": {
        "oui_hex": "34-FC-6F",
        "organization": "ALCEA",
        "address_1": "3 Rue Joly de Bammeville",
        "address_2": "91460  Marcoussis",
        "country": "FR"
    },
    "C0B357": {
        "oui_hex": "C0-B3-57",
        "organization": "Yoshiki Electronics Industry Ltd.",
        "address_1": "Ooicyoyo Building 7f",
        "address_2": "Shinagawa-ku  Tokyo  140-0011",
        "country": "JP"
    },
    "3C98BF": {
        "oui_hex": "3C-98-BF",
        "organization": "Quest Controls, Inc.",
        "address_1": "208 9th Street Dr. West",
        "address_2": "Palmetto  FL  34221",
        "country": "US"
    },
    "D0AEEC": {
        "oui_hex": "D0-AE-EC",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing 7th Rd., Science-based Industrial Park, Hsinchu, Taiwan, R.O.C",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "E81324": {
        "oui_hex": "E8-13-24",
        "organization": "GuangZhou Bonsoninfo System CO.,LTD",
        "address_1": "4/F,NO.1029/31,GaoPu Road,GaoTang New Building District",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "E477D4": {
        "oui_hex": "E4-77-D4",
        "organization": "Minrray Industry Co.,Ltd",
        "address_1": "C5, Building 2, ZhongHaiXin  ,Science&Technology Park, Ganli Rd, LiLang Blvd., Buji",
        "address_2": "Shenzhen  GuangDong  518112",
        "country": "CN"
    },
    "38E08E": {
        "oui_hex": "38-E0-8E",
        "organization": "Mitsubishi Electric Corporation",
        "address_1": "2-7-3 Marunouchi Chiyoda-ku",
        "address_2": "Tokyo    100-8310",
        "country": "JP"
    },
    "E4C806": {
        "oui_hex": "E4-C8-06",
        "organization": "Ceiec Electric Technology Inc.",
        "address_1": "8/F West Side, Building 201, Terra Industrial & Tradepark, Che Gong Miao,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "E0F9BE": {
        "oui_hex": "E0-F9-BE",
        "organization": "Cloudena Corp.",
        "address_1": "6F., No. 5, Alley 22, Lane 513",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "B88F14": {
        "oui_hex": "B8-8F-14",
        "organization": "Analytica GmbH",
        "address_1": "Vorholzstraße 36",
        "address_2": "Karlsruhe  Baden-Württemberg  76137",
        "country": "DE"
    },
    "7C94B2": {
        "oui_hex": "7C-94-B2",
        "organization": "Philips Healthcare PCCI",
        "address_1": "2271 Cosmos Ct",
        "address_2": "Carlsbad  CA  92011",
        "country": "US"
    },
    "442B03": {
        "oui_hex": "44-2B-03",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F473CA": {
        "oui_hex": "F4-73-CA",
        "organization": "Conversion Sound Inc.",
        "address_1": "960 N. Northwest Hwy",
        "address_2": "Park Ridge  IL  60068",
        "country": "US"
    },
    "F8F7FF": {
        "oui_hex": "F8-F7-FF",
        "organization": "SYN-TECH SYSTEMS INC",
        "address_1": "100 FOUR POINTS WAY",
        "address_2": "TALLAHASSEE  FL  32305",
        "country": "US"
    },
    "A81758": {
        "oui_hex": "A8-17-58",
        "organization": "Elektronik System i Umeå AB",
        "address_1": "Box 7978",
        "address_2": "Umeå  Västerbotten  907 19",
        "country": "SE"
    },
    "882012": {
        "oui_hex": "88-20-12",
        "organization": "LMI Technologies",
        "address_1": "1673 Cliveden Avenue",
        "address_2": "Delta  British Columbia  V3M 6V5",
        "country": "CA"
    },
    "60E956": {
        "oui_hex": "60-E9-56",
        "organization": "Ayla Networks, Inc",
        "address_1": "218 Morgan Lane",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "EC1120": {
        "oui_hex": "EC-11-20",
        "organization": "FloDesign Wind Turbine Corporation",
        "address_1": "Papirfabrikken 28",
        "address_2": "Silkeborg    8600",
        "country": "DK"
    },
    "F897CF": {
        "oui_hex": "F8-97-CF",
        "organization": "DAESHIN-INFORMATION TECHNOLOGY CO., LTD.",
        "address_1": "6F, Chungwon Bldg., 828-5 Yuksam-Dong,Kangnam-Gu,",
        "address_2": "Seoul    135935",
        "country": "KR"
    },
    "08B4CF": {
        "oui_hex": "08-B4-CF",
        "organization": "Abicom International",
        "address_1": "The Old Grammar School",
        "address_2": "Market Drayton  Shropshire  TF9 1JR",
        "country": "GB"
    },
    "C495A2": {
        "oui_hex": "C4-95-A2",
        "organization": "SHENZHEN WEIJIU INDUSTRY AND TRADE DEVELOPMENT CO., LTD",
        "address_1": "ROOM 1713,BAOHUA BUILDING, HUAQIANG NORTH ROAD, FUTIAN DISTRICT,",
        "address_2": "SHENZHEN  GUANGDONG  518031",
        "country": "CN"
    },
    "8C6878": {
        "oui_hex": "8C-68-78",
        "organization": "Nortek-AS",
        "address_1": "Vangkroken 2",
        "address_2": "  Akreshus  1351 RUD",
        "country": "NO"
    },
    "202598": {
        "oui_hex": "20-25-98",
        "organization": "Teleview",
        "address_1": "#401 Sehwa, 355-1",
        "address_2": "Sungnam  Gyeonggi  463-828",
        "country": "KR"
    },
    "38F8B7": {
        "oui_hex": "38-F8-B7",
        "organization": "V2COM PARTICIPACOES S.A.",
        "address_1": "Rua Cunha Gago, 700",
        "address_2": "São Paulo    05421001",
        "country": "BR"
    },
    "F8D462": {
        "oui_hex": "F8-D4-62",
        "organization": "Pumatronix Equipamentos Eletronicos Ltda.",
        "address_1": "Rua Bartolomeu Lourenco de Gusmao 2021",
        "address_2": "Curitiba  PR  81650050",
        "country": "BR"
    },
    "A0DC04": {
        "oui_hex": "A0-DC-04",
        "organization": "Becker-Antriebe GmbH",
        "address_1": "Friedrich-Ebert-Straße 2 - 4",
        "address_2": "35764 Sinn  Hessen  DE811177977",
        "country": "DE"
    },
    "40605A": {
        "oui_hex": "40-60-5A",
        "organization": "Hawkeye Tech Co. Ltd",
        "address_1": "13F-5, No. 736 Chung Cheng Road, Chung He",
        "address_2": "New Taipei    23511",
        "country": "TW"
    },
    "A04CC1": {
        "oui_hex": "A0-4C-C1",
        "organization": "Helixtech Corp.",
        "address_1": "6F Lions bldg., 160-2 Gangnam-daero,",
        "address_2": "Seoul    137-888",
        "country": "KR"
    },
    "34A7BA": {
        "oui_hex": "34-A7-BA",
        "organization": "Fischer International Systems Corporation",
        "address_1": "5801 Pelican Bay Boulevard #300",
        "address_2": "Naples  Florida  34108",
        "country": "US"
    },
    "0463E0": {
        "oui_hex": "04-63-E0",
        "organization": "Nome Oy",
        "address_1": "Lunkintie 9",
        "address_2": "Oulunsalo  Oulun lللni  90460",
        "country": "FI"
    },
    "B49EE6": {
        "oui_hex": "B4-9E-E6",
        "organization": "SHENZHEN TECHNOLOGY CO LTD",
        "address_1": "NO34 SHILONG RD",
        "address_2": "SHENZHEN  GUANGDONG  91732",
        "country": "CN"
    },
    "BC4B79": {
        "oui_hex": "BC-4B-79",
        "organization": "SensingTek",
        "address_1": "2F, No.6-2,Dusing Rd.,Hsinchu Science Park,",
        "address_2": "Hsinchu    30078",
        "country": "TW"
    },
    "A49005": {
        "oui_hex": "A4-90-05",
        "organization": "CHINA GREATWALL COMPUTER SHENZHEN CO.,LTD",
        "address_1": "409,2#,Greatwall Bldg,No.3 Kefa Road,Science & Industry Park,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  51807",
        "country": "CN"
    },
    "C40ACB": {
        "oui_hex": "C4-0A-CB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E86D6E": {
        "oui_hex": "E8-6D-6E",
        "organization": "voestalpine SIGNALING Fareham Ltd.",
        "address_1": "Unit 1, Fulcrum 4, Solent Way",
        "address_2": "Whiteley  Hampshire  PO15 7FT",
        "country": "GB"
    },
    "681605": {
        "oui_hex": "68-16-05",
        "organization": "Systems And Electronic Development FZCO",
        "address_1": "Roundabout no. 8",
        "address_2": "Jebel Ali free Zone  Dubai  P.O.Box 61129",
        "country": "AE"
    },
    "D4A02A": {
        "oui_hex": "D4-A0-2A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3C4E47": {
        "oui_hex": "3C-4E-47",
        "organization": "Etronic A/S",
        "address_1": "Rødeledsvej 95",
        "address_2": "Svendborg  South Denmark  5700",
        "country": "DK"
    },
    "F48771": {
        "oui_hex": "F4-87-71",
        "organization": "Infoblox",
        "address_1": "4750 Patrick Henry Drive",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "5453ED": {
        "oui_hex": "54-53-ED",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec 5-1-2",
        "address_2": "Tokyo  Shinagawa-ku  141-0001",
        "country": "JP"
    },
    "00376D": {
        "oui_hex": "00-37-6D",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "50008C": {
        "oui_hex": "50-00-8C",
        "organization": "Hong Kong Telecommunications (HKT) Limited",
        "address_1": "41/F, PCCW Tower, Taikoo Place,",
        "address_2": "",
        "country": "HK"
    },
    "902B34": {
        "oui_hex": "90-2B-34",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City,",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "88C36E": {
        "oui_hex": "88-C3-6E",
        "organization": "Beijing Ereneben lnformation Technology Limited",
        "address_1": "Room 14F,Building F,Honglong Central Plaza,NO,3001,Heping Road,LuoHu",
        "address_2": "ShenZhen  GuangDong  518110",
        "country": "CN"
    },
    "4C9E80": {
        "oui_hex": "4C-9E-80",
        "organization": "KYOKKO ELECTRIC Co., Ltd.",
        "address_1": "5-7-20, Motomachi-dori, Chuo-Ku",
        "address_2": "Kobe  Hyogo  6500022",
        "country": "JP"
    },
    "5CEB4E": {
        "oui_hex": "5C-EB-4E",
        "organization": "R. STAHL HMI Systems GmbH",
        "address_1": "Im Gewerbegebiet Pesch 14",
        "address_2": "Cologne    50767",
        "country": "DE"
    },
    "34AA99": {
        "oui_hex": "34-AA-99",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "645563": {
        "oui_hex": "64-55-63",
        "organization": "Intelight Inc.",
        "address_1": "3450 S Broadmont Drive  #126",
        "address_2": "Tucson  Arizona  85713",
        "country": "US"
    },
    "943AF0": {
        "oui_hex": "94-3A-F0",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "645422": {
        "oui_hex": "64-54-22",
        "organization": "Equinox Payments",
        "address_1": "8888 E. Raintree Dr., Suite 300",
        "address_2": "Scottsdale  Arizona  85260",
        "country": "US"
    },
    "080D84": {
        "oui_hex": "08-0D-84",
        "organization": "GECO, Inc.",
        "address_1": "1754 N. 48th St.",
        "address_2": "Mesa  AZ  85205",
        "country": "US"
    },
    "88E712": {
        "oui_hex": "88-E7-12",
        "organization": "Whirlpool Corporation",
        "address_1": "750 Monte Dr.",
        "address_2": "Benton Harbor  Michigan  49022",
        "country": "US"
    },
    "D412BB": {
        "oui_hex": "D4-12-BB",
        "organization": "Quadrant Components Inc. Ltd",
        "address_1": "Unit 5, 17/F, Metro Loft,",
        "address_2": "Kwai Chung,  New Territory",
        "country": "HK"
    },
    "24B88C": {
        "oui_hex": "24-B8-8C",
        "organization": "Crenus Co.,Ltd.",
        "address_1": "Mario Tower 814, 222-12",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "BCFE8C": {
        "oui_hex": "BC-FE-8C",
        "organization": "Altronic, LLC",
        "address_1": "712 Trumbull Ave",
        "address_2": "Girard  Ohio  44420",
        "country": "US"
    },
    "649EF3": {
        "oui_hex": "64-9E-F3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "24BBC1": {
        "oui_hex": "24-BB-C1",
        "organization": "Absolute Analysis",
        "address_1": "2393 Teller Road Ste #109",
        "address_2": "Newbury Park  California  91320",
        "country": "US"
    },
    "9CCAD9": {
        "oui_hex": "9C-CA-D9",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "046D42": {
        "oui_hex": "04-6D-42",
        "organization": "Bryston Ltd.",
        "address_1": "P.O. Box 2170",
        "address_2": "Peterborough  Ontario  K9J  7Y4",
        "country": "CA"
    },
    "D8E743": {
        "oui_hex": "D8-E7-43",
        "organization": "Wush, Inc",
        "address_1": "17F.No 268, Liancheng Rd., Zhonghe District",
        "address_2": "New  Taipei City     235",
        "country": "TW"
    },
    "644D70": {
        "oui_hex": "64-4D-70",
        "organization": "dSPACE GmbH",
        "address_1": "Rathenaustraße 26",
        "address_2": "Paderborn    33102",
        "country": "DE"
    },
    "DCC101": {
        "oui_hex": "DC-C1-01",
        "organization": "SOLiD Technologies, Inc.",
        "address_1": "9th Floor, SOLiD Space, Pangyoyeok-ro 220",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "3CE624": {
        "oui_hex": "3C-E6-24",
        "organization": "LG Display",
        "address_1": "9th, Fl., LG U+ building, 65-228, Hangangro, 3-ga, Yongsan-gu",
        "address_2": "Seoul    140-716",
        "country": "KR"
    },
    "D8F0F2": {
        "oui_hex": "D8-F0-F2",
        "organization": "Zeebo Inc",
        "address_1": "5405 Morehouse Drive",
        "address_2": "San Diego  California  92121",
        "country": "US"
    },
    "806007": {
        "oui_hex": "80-60-07",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "38A851": {
        "oui_hex": "38-A8-51",
        "organization": "Moog, Ing",
        "address_1": "3650 Woodhead Drive",
        "address_2": "Northbrook  IL  60062",
        "country": "US"
    },
    "94E0D0": {
        "oui_hex": "94-E0-D0",
        "organization": "HealthStream Taiwan Inc.",
        "address_1": "16-3, Zichiang 1st Road",
        "address_2": "Jhongli, Taoyuan county    32063",
        "country": "TW"
    },
    "D8052E": {
        "oui_hex": "D8-05-2E",
        "organization": "Skyviia Corporation",
        "address_1": "No. 10-1, Lixing 1st Rd., Science Park,",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "80946C": {
        "oui_hex": "80-94-6C",
        "organization": "TOKYO RADAR CORPORATION",
        "address_1": "15-7 Nishikubo-cho",
        "address_2": "Hodogaya-ku, Yokohama-shi  Kanagawa  240-0022",
        "country": "JP"
    },
    "D0CF5E": {
        "oui_hex": "D0-CF-5E",
        "organization": "Energy Micro AS",
        "address_1": "Sandakerveien 118",
        "address_2": "Oslo    N-0484",
        "country": "NO"
    },
    "1803FA": {
        "oui_hex": "18-03-FA",
        "organization": "IBT Interfaces",
        "address_1": "Im Taubhaus 19",
        "address_2": "Roedermark  Hessen  63322",
        "country": "DE"
    },
    "306E5C": {
        "oui_hex": "30-6E-5C",
        "organization": "Validus Technologies",
        "address_1": "420 North Main Street",
        "address_2": "East Peoria  Illinois  61611",
        "country": "US"
    },
    "C894D2": {
        "oui_hex": "C8-94-D2",
        "organization": "Jiangsu Datang  Electronic Products Co., Ltd",
        "address_1": "NO.20",
        "address_2": "Nanjing  Jiangsu  211800",
        "country": "CN"
    },
    "C8A620": {
        "oui_hex": "C8-A6-20",
        "organization": "Nebula, Inc",
        "address_1": "215 Castro St",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "EC6264": {
        "oui_hex": "EC-62-64",
        "organization": "Global411 Internet Services, LLC",
        "address_1": "10400 W Overland Rd #371",
        "address_2": "Boise  Idaho  83709",
        "country": "US"
    },
    "00F051": {
        "oui_hex": "00-F0-51",
        "organization": "KWB Gmbh",
        "address_1": "Industriestraße 235",
        "address_2": "St. Margarethen  Styria  8321",
        "country": "AT"
    },
    "FC946C": {
        "oui_hex": "FC-94-6C",
        "organization": "UBIVELOX",
        "address_1": "#1301 KOLONG Digital Villent 222-7 Guro-dong Guro-gu",
        "address_2": "SEOUL    152-777",
        "country": "KR"
    },
    "407B1B": {
        "oui_hex": "40-7B-1B",
        "organization": "Mettle Networks Inc.",
        "address_1": "111 N. Market St STE 300",
        "address_2": "San Jose   CA  95113",
        "country": "US"
    },
    "40D559": {
        "oui_hex": "40-D5-59",
        "organization": "MICRO S.E.R.I.",
        "address_1": "24, rue Henri FARMAN",
        "address_2": "TREMBLAY EN FRANCE  Ile de France  93290",
        "country": "FR"
    },
    "306CBE": {
        "oui_hex": "30-6C-BE",
        "organization": "Skymotion Technology (HK) Limited",
        "address_1": "Unit 2603, 26/F, Metropole Square,",
        "address_2": "    852",
        "country": "HK"
    },
    "183825": {
        "oui_hex": "18-38-25",
        "organization": "Wuhan Lingjiu High-tech Co.,Ltd.",
        "address_1": "No.718",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "7C4B78": {
        "oui_hex": "7C-4B-78",
        "organization": "Red Sun Synthesis Pte Ltd",
        "address_1": "639, #11-544",
        "address_2": "    510539",
        "country": "SG"
    },
    "64A0E7": {
        "oui_hex": "64-A0-E7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DCF858": {
        "oui_hex": "DC-F8-58",
        "organization": "Lorent Networks, Inc.",
        "address_1": "Third Floor, Technology Complex, HAO Science Park",
        "address_2": "Foshan  Guangdong Province  528200",
        "country": "CN"
    },
    "940B2D": {
        "oui_hex": "94-0B-2D",
        "organization": "NetView Technologies(Shenzhen) Co., Ltd",
        "address_1": "RM2902,East Tower, Nanshan Software Park",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "803F5D": {
        "oui_hex": "80-3F-5D",
        "organization": "Winstars Technology Ltd",
        "address_1": "Block4,Taisong Industrial Park, DaLang Street, LongHua Town , Bao'an District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "40BF17": {
        "oui_hex": "40-BF-17",
        "organization": "Digistar Telecom. SA",
        "address_1": "Av. Theodomiro Porto da Fonseca, 3101",
        "address_2": "Sao Leopoldo  RS  9302080",
        "country": "BR"
    },
    "780738": {
        "oui_hex": "78-07-38",
        "organization": "Z.U.K. Elzab S.A.",
        "address_1": "ul. Kruczkowskiego 39",
        "address_2": "Zabrze    41-813",
        "country": "PL"
    },
    "2037BC": {
        "oui_hex": "20-37-BC",
        "organization": "Kuipers Electronic Engineering BV",
        "address_1": "Houtkopersstraat 6",
        "address_2": "Zwijndrecht  Zuid-Holland  3334 KD",
        "country": "NL"
    },
    "94319B": {
        "oui_hex": "94-31-9B",
        "organization": "Alphatronics BV",
        "address_1": "Watergoorweg 71",
        "address_2": "NIJKERK  Gld  3861 MA",
        "country": "NL"
    },
    "00E175": {
        "oui_hex": "00-E1-75",
        "organization": "AK-Systems Ltd",
        "address_1": "off 62, 27/29 Pavlovskaya str.",
        "address_2": "Moscow    115093",
        "country": "RU"
    },
    "CC501C": {
        "oui_hex": "CC-50-1C",
        "organization": "KVH Industries, Inc.",
        "address_1": "50 Enterprise Center",
        "address_2": "Middletown  RI  02842-5279",
        "country": "US"
    },
    "04D783": {
        "oui_hex": "04-D7-83",
        "organization": "Y&H E&C Co.,LTD.",
        "address_1": "1501 Daerung Technotown 224-5",
        "address_2": "Anyang-city  Gyeonggi-do  431-062",
        "country": "KR"
    },
    "54A9D4": {
        "oui_hex": "54-A9-D4",
        "organization": "Minibar Systems",
        "address_1": "7340 Westmore Road",
        "address_2": "Rockville  MD  20850",
        "country": "US"
    },
    "B0E50E": {
        "oui_hex": "B0-E5-0E",
        "organization": "NRG SYSTEMS INC",
        "address_1": "PO BOX 0509",
        "address_2": "Hinesburg  VT  054610509",
        "country": "US"
    },
    "64808B": {
        "oui_hex": "64-80-8B",
        "organization": "VG Controls, Inc.",
        "address_1": "11 Butternut Drive",
        "address_2": "Vernon  NJ  07462",
        "country": "US"
    },
    "48C1AC": {
        "oui_hex": "48-C1-AC",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "98588A": {
        "oui_hex": "98-58-8A",
        "organization": "SYSGRATION Ltd.",
        "address_1": "10Fl.NO.868-3.Chung Cheng Rd.",
        "address_2": "NewTaipei City    235",
        "country": "TW"
    },
    "2437EF": {
        "oui_hex": "24-37-EF",
        "organization": "EMC Electronic Media Communication SA",
        "address_1": "Via Cantonale 4",
        "address_2": "S. Antonino  Ticino  6592",
        "country": "CH"
    },
    "28B0CC": {
        "oui_hex": "28-B0-CC",
        "organization": "Xenya d.o.o.",
        "address_1": "Celovska cesta 172",
        "address_2": "Ljubljana    1000",
        "country": "SI"
    },
    "205B5E": {
        "oui_hex": "20-5B-5E",
        "organization": "Shenzhen Wonhe Technology Co., Ltd",
        "address_1": "South Block 10th floor, Yuanxing Building, No. 1",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C058A7": {
        "oui_hex": "C0-58-A7",
        "organization": "Pico Systems Co., Ltd.",
        "address_1": "332-7 Kouya",
        "address_2": "Matsudo  Chiba pref.  270-0017",
        "country": "JP"
    },
    "EC3F05": {
        "oui_hex": "EC-3F-05",
        "organization": "Institute 706, The Second Academy China Aerospace Science & Industry Corp",
        "address_1": "YongDing Road ,HaiDian District.BeiJing ,No.51",
        "address_2": "BeiJing    100854",
        "country": "CN"
    },
    "489BE2": {
        "oui_hex": "48-9B-E2",
        "organization": "SCI Innovations Ltd",
        "address_1": "16C Hurst End",
        "address_2": "Newport Pagnell  Buckinghamshire  MK16 9HS",
        "country": "GB"
    },
    "80FFA8": {
        "oui_hex": "80-FF-A8",
        "organization": "UNIDIS",
        "address_1": "4 floors(401), 144-4, Gumi-dong",
        "address_2": "Sungnam-si  Gyeonggi-do  463-810",
        "country": "KR"
    },
    "E435FB": {
        "oui_hex": "E4-35-FB",
        "organization": "Sabre Technology (Hull) Ltd",
        "address_1": "3a Newlands Science Park",
        "address_2": "Hull  East Yorkshire  HU6 7TQ",
        "country": "GB"
    },
    "C83B45": {
        "oui_hex": "C8-3B-45",
        "organization": "JRI",
        "address_1": "16 rue louis rameau",
        "address_2": "Bezons Cedex    95872",
        "country": "FR"
    },
    "E878A1": {
        "oui_hex": "E8-78-A1",
        "organization": "BEOVIEW INTERCOM DOO",
        "address_1": "TRESNJINOG CVETA 5/17",
        "address_2": "BELGRADE    11070",
        "country": "RS"
    },
    "CCEF48": {
        "oui_hex": "CC-EF-48",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F04B6A": {
        "oui_hex": "F0-4B-6A",
        "organization": "Scientific Production Association Siberian Arsenal, Ltd.",
        "address_1": "Bld.8A, Gorskiy Microdistrict",
        "address_2": "Novosibirsk    630073",
        "country": "RU"
    },
    "64AE0C": {
        "oui_hex": "64-AE-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E8DA96": {
        "oui_hex": "E8-DA-96",
        "organization": "Zhuhai Tianrui Electrical Power Tech. Co., Ltd.",
        "address_1": "Minying Technology Zone, 10# Keji 1 Road, Gangwan Main Road, Tangjia",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "B4D8DE": {
        "oui_hex": "B4-D8-DE",
        "organization": "iota Computing, Inc.",
        "address_1": "2275 East Bayshore Road",
        "address_2": "Palo Alto  CA  94303-3222",
        "country": "US"
    },
    "C8903E": {
        "oui_hex": "C8-90-3E",
        "organization": "Pakton Technologies",
        "address_1": "1 Helium St",
        "address_2": "Narangba  QLD  4504",
        "country": "AU"
    },
    "54CDA7": {
        "oui_hex": "54-CD-A7",
        "organization": "Fujian Shenzhou Electronic Co.,Ltd",
        "address_1": "Quanzhou Economical&Technological Development Zone,Quanzhou,Fujian,China",
        "address_2": "QUANZHOU  FUJIAN  362005",
        "country": "CN"
    },
    "886B76": {
        "oui_hex": "88-6B-76",
        "organization": "CHINA HOPEFUL GROUP HOPEFUL ELECTRIC CO.,LTD",
        "address_1": "Shunde District of Foshan City, Guangdong Province, Guangxi Rong Ronggui Town Road, No. 148",
        "address_2": "Foshan  GuangDong  528305",
        "country": "CN"
    },
    "78F7D0": {
        "oui_hex": "78-F7-D0",
        "organization": "Silverbrook Research",
        "address_1": "3 Montague Street",
        "address_2": "Balmain  New South Wales  2041",
        "country": "AU"
    },
    "207600": {
        "oui_hex": "20-76-00",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "F013C3": {
        "oui_hex": "F0-13-C3",
        "organization": "SHENZHEN FENDA TECHNOLOGY CO., LTD",
        "address_1": "Fenda Hi-Tech Park, Zhoushi Road, Shiyan, Baoan",
        "address_2": "ShenZhen  GuangDong  518108",
        "country": "CN"
    },
    "04A82A": {
        "oui_hex": "04-A8-2A",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "E44E18": {
        "oui_hex": "E4-4E-18",
        "organization": "Gardasoft VisionLimited",
        "address_1": "Units 1 and 2, Castle Acres",
        "address_2": "Cambridge    CB23 4JQ",
        "country": "GB"
    },
    "2046A1": {
        "oui_hex": "20-46-A1",
        "organization": "VECOW Co., Ltd",
        "address_1": "7F., No.105, Zhongcheng Rd., Tucheng Dist.,",
        "address_2": "New Taipei City     23674",
        "country": "TW"
    },
    "FC01CD": {
        "oui_hex": "FC-01-CD",
        "organization": "FUNDACION TEKNIKER",
        "address_1": "Avenida Otaola, 20",
        "address_2": "Eibar  Gipuzkoa  20600",
        "country": "ES"
    },
    "9C8BF1": {
        "oui_hex": "9C-8B-F1",
        "organization": "The Warehouse Limited",
        "address_1": "Suite 601, City Point, 1600 Zhonghua Road, Huangpu District",
        "address_2": "Shanghai    200010",
        "country": "CN"
    },
    "DC2E6A": {
        "oui_hex": "DC-2E-6A",
        "organization": "HCT. Co., Ltd.",
        "address_1": "105-1, Jangam-ri, Majang-myen",
        "address_2": "Icheon-si  Gyeonggi-do  467-811",
        "country": "KR"
    },
    "148A70": {
        "oui_hex": "14-8A-70",
        "organization": "ADS GmbH",
        "address_1": "Im Rohnweiher 39",
        "address_2": "Lohmar  Germany  D-53797",
        "country": "DE"
    },
    "00B338": {
        "oui_hex": "00-B3-38",
        "organization": "Kontron Asia Pacific Design Sdn. Bhd",
        "address_1": "Plot 554, Lorong Perusahaan 4",
        "address_2": "Prai Free Trade Zone  Prai, Penang  13600",
        "country": "MY"
    },
    "84248D": {
        "oui_hex": "84-24-8D",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "FCE892": {
        "oui_hex": "FC-E8-92",
        "organization": "Hangzhou Lancable Technology Co.,Ltd",
        "address_1": "Zone A,Floor 16,Zhongcai Building,68#,Tonghe Road,Binjiang District,",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "1071F9": {
        "oui_hex": "10-71-F9",
        "organization": "Cloud Telecomputers, LLC",
        "address_1": "1032 Elwell Court",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "B8621F": {
        "oui_hex": "B8-62-1F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F0022B": {
        "oui_hex": "F0-02-2B",
        "organization": "Chrontel",
        "address_1": "2210 OToole Ave., Suite 100",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "D453AF": {
        "oui_hex": "D4-53-AF",
        "organization": "VIGO System S.A.",
        "address_1": "129/133 Poznanska str",
        "address_2": "Ozarow Mazowiecki  Mazowieckie  05-850",
        "country": "PL"
    },
    "18AD4D": {
        "oui_hex": "18-AD-4D",
        "organization": "Polostar Technology Corporation",
        "address_1": "2F, No.351, Yangguang St.",
        "address_2": "Taipei    11491",
        "country": "TW"
    },
    "94C6EB": {
        "oui_hex": "94-C6-EB",
        "organization": "NOVA electronics, Inc.",
        "address_1": "Grand Axe Bldg. 3F.",
        "address_2": "Shibuya-ku  Tokyo  151-0064",
        "country": "JP"
    },
    "843F4E": {
        "oui_hex": "84-3F-4E",
        "organization": "Tri-Tech Manufacturing, Inc.",
        "address_1": "333 Turbine Drive",
        "address_2": "Rapid City  SD  57703",
        "country": "US"
    },
    "C83232": {
        "oui_hex": "C8-32-32",
        "organization": "Hunting Innova",
        "address_1": "8383 N Sam Houston Pkwy West",
        "address_2": "Houston  Texas  77064",
        "country": "US"
    },
    "549478": {
        "oui_hex": "54-94-78",
        "organization": "Silvershore Technology Partners",
        "address_1": "800 High Street",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "A06E50": {
        "oui_hex": "A0-6E-50",
        "organization": "Nanotek Elektronik Sistemler Ltd. Sti.",
        "address_1": "Ivedik Organize Sanayi",
        "address_2": "Ankara    06370",
        "country": "TR"
    },
    "4C774F": {
        "oui_hex": "4C-77-4F",
        "organization": "Embedded Wireless Labs",
        "address_1": "702 Level 7 Uptown 2 No.2",
        "address_2": "Petaling Jaya  Selangor  47400",
        "country": "MY"
    },
    "D0C282": {
        "oui_hex": "D0-C2-82",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "147DB3": {
        "oui_hex": "14-7D-B3",
        "organization": "JOA TELECOM.CO.,LTD",
        "address_1": "1007,Sicox tower,513-14,Sangdaewon-dong,Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  462-806",
        "country": "KR"
    },
    "ECBD09": {
        "oui_hex": "EC-BD-09",
        "organization": "FUSION Electronics Ltd",
        "address_1": "PO Box 137 - 142",
        "address_2": "Auckland    1151",
        "country": "NZ"
    },
    "944696": {
        "oui_hex": "94-46-96",
        "organization": "BaudTec Corporation",
        "address_1": "12F, No.181, Sec.1.Tatung Rd.",
        "address_2": "Hsi-chih  Taipei  221",
        "country": "TW"
    },
    "54847B": {
        "oui_hex": "54-84-7B",
        "organization": "Digital Devices GmbH",
        "address_1": "Moewestr 45 A",
        "address_2": "Muenchen    81827",
        "country": "DE"
    },
    "3C2763": {
        "oui_hex": "3C-27-63",
        "organization": "SLE quality engineering GmbH & Co. KG",
        "address_1": "Josef-Buchinger-Str. 9",
        "address_2": "Grafenau  Bavaria  94481",
        "country": "DE"
    },
    "B0F1BC": {
        "oui_hex": "B0-F1-BC",
        "organization": "Dhemax Ingenieros Ltda",
        "address_1": "Siete Oriente 1234",
        "address_2": "Vina del Mar  Region de Valparaiso  2530954",
        "country": "CL"
    },
    "B8288B": {
        "oui_hex": "B8-28-8B",
        "organization": "Parker Hannifin Manufacturing (UK) Ltd",
        "address_1": "Condition Monitoring Centre",
        "address_2": "Thetford  Norfolk  IP24 1HP",
        "country": "GB"
    },
    "90D11B": {
        "oui_hex": "90-D1-1B",
        "organization": "Palomar Medical Technologies",
        "address_1": "15 Network Drive",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "34A55D": {
        "oui_hex": "34-A5-5D",
        "organization": "TECHNOSOFT INTERNATIONAL SRL",
        "address_1": "RO6640904",
        "address_2": "  Bucuresti - Sector 6  061992",
        "country": "RO"
    },
    "802E14": {
        "oui_hex": "80-2E-14",
        "organization": "azeti Networks AG",
        "address_1": "Am Brambusch 1a",
        "address_2": "Luenen  NRW  44536",
        "country": "DE"
    },
    "D4C1FC": {
        "oui_hex": "D4-C1-FC",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "34BCA6": {
        "oui_hex": "34-BC-A6",
        "organization": "Beijing Ding Qing Technology, Ltd.",
        "address_1": "218 Han Tai Hua Office Building, 13 Huan Yuan Lu,",
        "address_2": "Haidian District  Beijing  100083",
        "country": "CN"
    },
    "5835D9": {
        "oui_hex": "58-35-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "64D912": {
        "oui_hex": "64-D9-12",
        "organization": "Solidica, Inc.",
        "address_1": "5840 Interface Drive",
        "address_2": "Ann Arbor  Michigan  48103",
        "country": "US"
    },
    "C47B2F": {
        "oui_hex": "C4-7B-2F",
        "organization": "Beijing JoinHope Image Technology Ltd.",
        "address_1": "624 Room .Automation Building.95# Zhong Guancun East Road.Haidian District",
        "address_2": "Beijing    100190",
        "country": "CN"
    },
    "508ACB": {
        "oui_hex": "50-8A-CB",
        "organization": "SHENZHEN MAXMADE TECHNOLOGY CO., LTD.",
        "address_1": "Building 3,No.5 Fuqiao Industrial Estate,",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "3CD16E": {
        "oui_hex": "3C-D1-6E",
        "organization": "Telepower Communication Co., Ltd",
        "address_1": "5/F,Zonghe Building, Hantian Technology Town,Guiping RD,Nanhai District,F",
        "address_2": "Foshan City  Guangdong  528251",
        "country": "CN"
    },
    "FC2E2D": {
        "oui_hex": "FC-2E-2D",
        "organization": "Lorom Industrial Co.LTD.",
        "address_1": "F1.13,Rm.2,No.78,Sec.2,An-HoRd.",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "40040C": {
        "oui_hex": "40-04-0C",
        "organization": "A&T",
        "address_1": "#411, Will Town, 402-3",
        "address_2": "Bucheon-Si  Gyeonggi-Do  420-814",
        "country": "KR"
    },
    "DC3C84": {
        "oui_hex": "DC-3C-84",
        "organization": "Ticom Geomatics, Inc.",
        "address_1": "9130 Jollyville Rd. Ste. 300",
        "address_2": "Austin  Texas  78759",
        "country": "US"
    },
    "D0131E": {
        "oui_hex": "D0-13-1E",
        "organization": "Sunrex Technology Corp",
        "address_1": "No. 188-1,Chung Cheng Road.,Ta Ya Shiang",
        "address_2": "Taichung    428",
        "country": "TW"
    },
    "00FC70": {
        "oui_hex": "00-FC-70",
        "organization": "Intrepid Control Systems, Inc.",
        "address_1": "31601 Research Park Dr.",
        "address_2": "Madison Heights  MI  48071",
        "country": "US"
    },
    "703AD8": {
        "oui_hex": "70-3A-D8",
        "organization": "Shenzhen Afoundry Electronic Co., Ltd",
        "address_1": "201, A Building, Bole Industrial Zone, Bantian, Longgang District",
        "address_2": "Shenzhen   Guangdong  518129",
        "country": "CN"
    },
    "704AAE": {
        "oui_hex": "70-4A-AE",
        "organization": "Xstream Flow (Pty) Ltd",
        "address_1": "Room 123, Building 16, CSIR campus",
        "address_2": "Pretoria  Gauteng  0184",
        "country": "ZA"
    },
    "40B3FC": {
        "oui_hex": "40-B3-FC",
        "organization": "Logital Co. Limited",
        "address_1": "Rm 901-902, 9/F, Nathan Centre,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "A4134E": {
        "oui_hex": "A4-13-4E",
        "organization": "Luxul",
        "address_1": "14203 Minuteman Drive",
        "address_2": "Draper  UT  84020",
        "country": "US"
    },
    "B09928": {
        "oui_hex": "B0-99-28",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "04E1C8": {
        "oui_hex": "04-E1-C8",
        "organization": "IMS Soluções em Energia Ltda.",
        "address_1": "Av. Bernardino Silveira Pastoriza, 720",
        "address_2": "Porto Alegre  RS  91160-310",
        "country": "BR"
    },
    "948FEE": {
        "oui_hex": "94-8F-EE",
        "organization": "Verizon Telematics",
        "address_1": "2002 Summit Blvd",
        "address_2": "Atlanta  GA  30319",
        "country": "US"
    },
    "50D6D7": {
        "oui_hex": "50-D6-D7",
        "organization": "Takahata Precision",
        "address_1": "4-17-1 Suniyoshi",
        "address_2": "Kofu    400-0851",
        "country": "JP"
    },
    "88F077": {
        "oui_hex": "88-F0-77",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "587521": {
        "oui_hex": "58-75-21",
        "organization": "CJSC RTSoft",
        "address_1": "Nikitinskaya str., 3",
        "address_2": "Moscow    105037",
        "country": "RU"
    },
    "C40F09": {
        "oui_hex": "C4-0F-09",
        "organization": "Hermes electronic GmbH",
        "address_1": "Am Handwerkerpark 1",
        "address_2": "Essen  NRW  45309",
        "country": "DE"
    },
    "48F47D": {
        "oui_hex": "48-F4-7D",
        "organization": "TechVision Holding  Internation Limited",
        "address_1": "Offshore Incorporations Centre",
        "address_2": "Road Town  Tortola  VG1110",
        "country": "VG"
    },
    "F081AF": {
        "oui_hex": "F0-81-AF",
        "organization": "IRZ AUTOMATION TECHNOLOGIES LTD",
        "address_1": "Unit 9-10 27/F Seapower Tower",
        "address_2": "  Kowloon",
        "country": "HK"
    },
    "701404": {
        "oui_hex": "70-14-04",
        "organization": "Limited Liability Company",
        "address_1": "I.Yakovleva St., 1",
        "address_2": "Cheboksary Chuvash Republic    428003",
        "country": "RU"
    },
    "B435F7": {
        "oui_hex": "B4-35-F7",
        "organization": "Zhejiang Pearmain Electronics Co.ltd.",
        "address_1": "4F Yitai Mansion, 76 Gucui Road,",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "9866EA": {
        "oui_hex": "98-66-EA",
        "organization": "Industrial Control Communications, Inc.",
        "address_1": "1600 Aspen Commons",
        "address_2": "Middleton  WI  53562",
        "country": "US"
    },
    "983000": {
        "oui_hex": "98-30-00",
        "organization": "Beijing KEMACOM Technologies Co., Ltd.",
        "address_1": "Room 208, Building 6, No.50, Xi San Huan Bei Road",
        "address_2": "Beijing    100044",
        "country": "CN"
    },
    "90CF15": {
        "oui_hex": "90-CF-15",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "948B03": {
        "oui_hex": "94-8B-03",
        "organization": "EAGET Innovation and Technology Co., Ltd.",
        "address_1": "3/F, Building 4, Lianchuang Technology Park,Buji Town,",
        "address_2": "Shenzhen  Guangdong  518112",
        "country": "CN"
    },
    "2C0033": {
        "oui_hex": "2C-00-33",
        "organization": "EControls, LLC",
        "address_1": "5757 Farinon Dr",
        "address_2": "San Antonio  TX  78249",
        "country": "US"
    },
    "AC199F": {
        "oui_hex": "AC-19-9F",
        "organization": "SUNGROW POWER SUPPLY CO.,LTD.",
        "address_1": "NO.2 Tianhu Road, New and High Technology Industrial Development Zone",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "7C4A82": {
        "oui_hex": "7C-4A-82",
        "organization": "Portsmith LLC",
        "address_1": "850 E. Franklin Road",
        "address_2": "Meridian  ID  83642",
        "country": "US"
    },
    "94E848": {
        "oui_hex": "94-E8-48",
        "organization": "FYLDE MICRO LTD",
        "address_1": "8 AVROE CRESCENT",
        "address_2": "BLACKPOOL  LANCASHIRE  FY4 2DP",
        "country": "GB"
    },
    "AC5E8C": {
        "oui_hex": "AC-5E-8C",
        "organization": "Utillink",
        "address_1": "817 Woolim Lions Valley 1, 311-3 Sangdaewon-dong Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  462160",
        "country": "KR"
    },
    "18E288": {
        "oui_hex": "18-E2-88",
        "organization": "STT Condigi",
        "address_1": "Agnesfridsvagen 113 A",
        "address_2": "Malmö  Skåne  21237",
        "country": "SE"
    },
    "1C35F1": {
        "oui_hex": "1C-35-F1",
        "organization": "NEW Lift Neue Elektronische Wege Steuerungsbau GmbH",
        "address_1": "Lochhamer Schlag 8",
        "address_2": "Graefelfing  Bavaria  82166",
        "country": "DE"
    },
    "803457": {
        "oui_hex": "80-34-57",
        "organization": "OT Systems Limited",
        "address_1": "Unit 1023, 10/F., Landmark North,",
        "address_2": "Sheung Shui, N. T.",
        "country": "HK"
    },
    "5C0CBB": {
        "oui_hex": "5C-0C-BB",
        "organization": "CELIZION Inc.",
        "address_1": "#206 Lordland EZ Tower, GuMi-Dong 153 BunDang-Gu",
        "address_2": "SeongNam-Si   GyeongGi-Do  463-870",
        "country": "KR"
    },
    "C4242E": {
        "oui_hex": "C4-24-2E",
        "organization": "Galvanic Applied Sciences Inc",
        "address_1": "7000 Fisher Road SE",
        "address_2": "Calgary  Alberta  T2H 0W3",
        "country": "CA"
    },
    "24C86E": {
        "oui_hex": "24-C8-6E",
        "organization": "Chaney Instrument Co.",
        "address_1": "965 Wells Street",
        "address_2": "Lake Geneva  WI  53147",
        "country": "US"
    },
    "F0AE51": {
        "oui_hex": "F0-AE-51",
        "organization": "Xi3 Corp",
        "address_1": "299 S. Main St.",
        "address_2": "Salt Lake City  UT  84111",
        "country": "US"
    },
    "B80B9D": {
        "oui_hex": "B8-0B-9D",
        "organization": "ROPEX Industrie-Elektronik GmbH",
        "address_1": "Adolf-Heim-Str. 4",
        "address_2": "Bietigheim-Bissingen  Baden Wuerttemberg  74321",
        "country": "DE"
    },
    "306118": {
        "oui_hex": "30-61-18",
        "organization": "Paradom Inc.",
        "address_1": "8F, N0. 178, Sec-2, Gongdaowu Rd.",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "4C7367": {
        "oui_hex": "4C-73-67",
        "organization": "Genius Bytes Software Solutions GmbH",
        "address_1": "Merianstraße 30",
        "address_2": "Bochum  NRW  44801",
        "country": "DE"
    },
    "90EA60": {
        "oui_hex": "90-EA-60",
        "organization": "SPI Lasers Ltd",
        "address_1": "6 wellington Park",
        "address_2": "Southampton  Hampshire  S0302QU",
        "country": "GB"
    },
    "5070E5": {
        "oui_hex": "50-70-E5",
        "organization": "He Shan World Fair Electronics Technology Limited",
        "address_1": "New Material Base, Gonghe Town",
        "address_2": "Jiangmen  Guangdong  529728",
        "country": "CN"
    },
    "802275": {
        "oui_hex": "80-22-75",
        "organization": "Beijing Beny Wave Technology Co Ltd",
        "address_1": "No.55, Jiachuang Road",
        "address_2": "Tongzhou District  Beijing  101111",
        "country": "CN"
    },
    "CCF3A5": {
        "oui_hex": "CC-F3-A5",
        "organization": "Chi Mei Communication Systems, Inc",
        "address_1": "No.4",
        "address_2": "Tucheng City  Taipei County   23678",
        "country": "TW"
    },
    "14A9E3": {
        "oui_hex": "14-A9-E3",
        "organization": "MST CORPORATION",
        "address_1": "4th Floor Lawford House",
        "address_2": "London  England  N3 1 RL",
        "country": "GB"
    },
    "F8EA0A": {
        "oui_hex": "F8-EA-0A",
        "organization": "Dipl.-Math. Michael Rauch",
        "address_1": "Kapellenstraße 31",
        "address_2": "Bretten  BaWü  75015",
        "country": "DE"
    },
    "3831AC": {
        "oui_hex": "38-31-AC",
        "organization": "WEG",
        "address_1": "Av. Pref. Waldemar Grubba, 3000",
        "address_2": "Jaraguá do Sul  Santa Catarina  89256-900",
        "country": "BR"
    },
    "584C19": {
        "oui_hex": "58-4C-19",
        "organization": "Chongqing Guohong Technology Development Company Limited",
        "address_1": "Rongzhi Building, Science & Technology Venture Center,",
        "address_2": "Chongqing    401336",
        "country": "CN"
    },
    "6469BC": {
        "oui_hex": "64-69-BC",
        "organization": "Hytera Communications Co .,ltd",
        "address_1": "HYT Tower ,Hi-Tech Industrial Park North,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B4F323": {
        "oui_hex": "B4-F3-23",
        "organization": "PETATEL INC.",
        "address_1": "#322 THE O VILLE 720-25, YEOKSAM-DONG",
        "address_2": "GANGNAM-GU  SEOUL  135080",
        "country": "KR"
    },
    "285132": {
        "oui_hex": "28-51-32",
        "organization": "Shenzhen Prayfly Technology Co.,Ltd",
        "address_1": "16F B International Chamber of Commerce Building",
        "address_2": "Shenzhen  Guangdong Province   518048",
        "country": "CN"
    },
    "E42FF6": {
        "oui_hex": "E4-2F-F6",
        "organization": "Unicore communication Inc.",
        "address_1": "Rm.312 Building 2 IRICO, No.11St.4,Shangdi, Haidian District,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "84D9C8": {
        "oui_hex": "84-D9-C8",
        "organization": "Unipattern Co.,",
        "address_1": "16F., No.30., Beiping E. Rd., Zhongzheng Dist.,",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "94AAB8": {
        "oui_hex": "94-AA-B8",
        "organization": "Joview(Beijing) Technology Co. Ltd.",
        "address_1": "Room 302, South Building",
        "address_2": "Beijing    100081",
        "country": "CN"
    },
    "28F358": {
        "oui_hex": "28-F3-58",
        "organization": "2C - Trifonov & Co",
        "address_1": "133, Tsarigradsko Shose Blvd, BIZ IZOT,",
        "address_2": "Sofia    1784",
        "country": "BG"
    },
    "14C21D": {
        "oui_hex": "14-C2-1D",
        "organization": "Sabtech Industries",
        "address_1": "23231 La Palma Ave",
        "address_2": "Yorba Linda  Ca.  92887-4788",
        "country": "US"
    },
    "C88439": {
        "oui_hex": "C8-84-39",
        "organization": "Sunrise Technologies",
        "address_1": "54 Commercial Street",
        "address_2": "Raynham  MA  02767",
        "country": "US"
    },
    "F0BF97": {
        "oui_hex": "F0-BF-97",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec 5-1-2",
        "address_2": "Tokyo  Shinagawa-ku  141-0001",
        "country": "JP"
    },
    "C44AD0": {
        "oui_hex": "C4-4A-D0",
        "organization": "FIREFLIES SYSTEMS",
        "address_1": "3 CHEMIN DU PRE CARRE",
        "address_2": "MEYLAN    38240",
        "country": "FR"
    },
    "EC7D9D": {
        "oui_hex": "EC-7D-9D",
        "organization": "CPI",
        "address_1": "3222 Phoenixville Pike Suite 200",
        "address_2": "Malvern  PA  19355",
        "country": "US"
    },
    "C81E8E": {
        "oui_hex": "C8-1E-8E",
        "organization": "ADV Security (S) Pte Ltd",
        "address_1": "56 Dunlop Street",
        "address_2": "    209386",
        "country": "SG"
    },
    "A88792": {
        "oui_hex": "A8-87-92",
        "organization": "Broadband Antenna Tracking Systems",
        "address_1": "8902 Vincennes Circle, Suite D-2",
        "address_2": "Indianapolis  IN  46268",
        "country": "US"
    },
    "14F0C5": {
        "oui_hex": "14-F0-C5",
        "organization": "Xtremio Ltd.",
        "address_1": "POB 5246",
        "address_2": "Herzelyia    46152",
        "country": "IL"
    },
    "E8C229": {
        "oui_hex": "E8-C2-29",
        "organization": "H-Displays (MSC) Bhd",
        "address_1": "No. 31 & 32, Jalan Gangsa Dua",
        "address_2": "Johor Bahru    81700",
        "country": "MY"
    },
    "3CA72B": {
        "oui_hex": "3C-A7-2B",
        "organization": "MRV Communications (Networks) LTD",
        "address_1": "P.O Box 614",
        "address_2": "Yokneam     20692",
        "country": "IL"
    },
    "301A28": {
        "oui_hex": "30-1A-28",
        "organization": "Mako Networks Ltd",
        "address_1": "1/62 Paul Matthews Rd",
        "address_2": "Auckland    0632",
        "country": "NZ"
    },
    "04E662": {
        "oui_hex": "04-E6-62",
        "organization": "Acroname Inc.",
        "address_1": "4822 Sterling Drive",
        "address_2": "Boulder  CO  80301-2350",
        "country": "US"
    },
    "F87B8C": {
        "oui_hex": "F8-7B-8C",
        "organization": "Amped Wireless",
        "address_1": "13089 Peyton Dr. #C307",
        "address_2": "Chino Hills  CA  91709",
        "country": "US"
    },
    "283410": {
        "oui_hex": "28-34-10",
        "organization": "Enigma Diagnostics Limited",
        "address_1": "Building 224",
        "address_2": "DSTL Porton Down  Salisbury  SP4 0JQ",
        "country": "GB"
    },
    "0CE82F": {
        "oui_hex": "0C-E8-2F",
        "organization": "Bonfiglioli Vectron GmbH",
        "address_1": "Europark Fichtenhain B6",
        "address_2": "Krefeld  NRW  47807",
        "country": "DE"
    },
    "40F4EC": {
        "oui_hex": "40-F4-EC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "14B73D": {
        "oui_hex": "14-B7-3D",
        "organization": "ARCHEAN Technologies",
        "address_1": "1899 avenue d'Italie",
        "address_2": "MONTAUBAN    82000",
        "country": "FR"
    },
    "948D50": {
        "oui_hex": "94-8D-50",
        "organization": "Beamex Oy Ab",
        "address_1": "Ristisuonraitti 10",
        "address_2": "Pietarsaari    FI-68600",
        "country": "FI"
    },
    "A433D1": {
        "oui_hex": "A4-33-D1",
        "organization": "Fibrlink Communications Co.,Ltd.",
        "address_1": "28F Ages Wealth World, No.1 Hangfeng Road",
        "address_2": "Beijing    100070",
        "country": "CN"
    },
    "5CBD9E": {
        "oui_hex": "5C-BD-9E",
        "organization": "HONGKONG MIRACLE EAGLE TECHNOLOGY(GROUP) LIMITED",
        "address_1": "FLAT RM 2103,  EASEY COMMERCIAL BLDG,253-261 HENNESSY RD,",
        "address_2": "  WANCHAI  999077",
        "country": "HK"
    },
    "08E672": {
        "oui_hex": "08-E6-72",
        "organization": "JEBSEE ELECTRONICS CO.,LTD.",
        "address_1": "24-3, SIN LE ROAD,",
        "address_2": "TAINAN    70268",
        "country": "TW"
    },
    "B8E589": {
        "oui_hex": "B8-E5-89",
        "organization": "Payter BV",
        "address_1": "Rozenlaan 115",
        "address_2": "Rotterdam  Zuid-Holland  3051 LP",
        "country": "NL"
    },
    "88E0A0": {
        "oui_hex": "88-E0-A0",
        "organization": "Shenzhen VisionSTOR Technologies Co., Ltd",
        "address_1": "12/F, East Tower,Nanshan Software Park",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "FC10BD": {
        "oui_hex": "FC-10-BD",
        "organization": "Control Sistematizado S.A.",
        "address_1": "Cra 43 N 31 52",
        "address_2": "Medellin  Antioquia  10101",
        "country": "CO"
    },
    "F0C27C": {
        "oui_hex": "F0-C2-7C",
        "organization": "Mianyang Netop Telecom Equipment Co.,Ltd.",
        "address_1": "No.111,East section of Puming South Road,",
        "address_2": "Mianyang City  Sichuan Province,   621000",
        "country": "CN"
    },
    "241A8C": {
        "oui_hex": "24-1A-8C",
        "organization": "Squarehead Technology AS",
        "address_1": "PO Box 13 Nydalen",
        "address_2": "Oslo    NO-0410",
        "country": "NO"
    },
    "D44F80": {
        "oui_hex": "D4-4F-80",
        "organization": "Kemper Digital GmbH",
        "address_1": "Koenigswall 16-18",
        "address_2": "Recklinghausen  North-Rhine-Westphalia  45657",
        "country": "DE"
    },
    "A41BC0": {
        "oui_hex": "A4-1B-C0",
        "organization": "Fastec Imaging Corporation",
        "address_1": "17150 Via Del Campo",
        "address_2": "San Diego  California  92127",
        "country": "US"
    },
    "205B2A": {
        "oui_hex": "20-5B-2A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "F40321": {
        "oui_hex": "F4-03-21",
        "organization": "BeNeXt B.V.",
        "address_1": "Ter Gouwstraat 3",
        "address_2": "Amsterdam  NH  1093JX",
        "country": "NL"
    },
    "A071A9": {
        "oui_hex": "A0-71-A9",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "A4E32E": {
        "oui_hex": "A4-E3-2E",
        "organization": "Silicon & Software Systems Ltd.",
        "address_1": "South County Business Park",
        "address_2": "Leopardstown  Dublin  18",
        "country": "IE"
    },
    "C8C126": {
        "oui_hex": "C8-C1-26",
        "organization": "ZPM Industria e Comercio Ltda",
        "address_1": "Rua Araguaia, 175",
        "address_2": "Canoas  RS  92410-000",
        "country": "BR"
    },
    "64DE1C": {
        "oui_hex": "64-DE-1C",
        "organization": "Kingnetic Pte Ltd",
        "address_1": "47 Kaki Bukit Place",
        "address_2": "    416225",
        "country": "SG"
    },
    "A862A2": {
        "oui_hex": "A8-62-A2",
        "organization": "JIWUMEDIA CO., LTD.",
        "address_1": "#902, Daerug Techno Town 13'th, 664",
        "address_2": "Geumcheon-gu  Seoul  153-803",
        "country": "KR"
    },
    "984E97": {
        "oui_hex": "98-4E-97",
        "organization": "Starlight Marketing (H. K.) Ltd.",
        "address_1": "5/F., Shing Dao Industrial Building,",
        "address_2": "",
        "country": "HK"
    },
    "64DC01": {
        "oui_hex": "64-DC-01",
        "organization": "Static Systems Group PLC",
        "address_1": "Heathmill Road",
        "address_2": "Wolverhampton  West Midlands  WV5 8AN",
        "country": "GB"
    },
    "FC1FC0": {
        "oui_hex": "FC-1F-C0",
        "organization": "EURECAM",
        "address_1": "BAT 9 - Miniparc",
        "address_2": "LES ULIS    91940",
        "country": "FR"
    },
    "BC6784": {
        "oui_hex": "BC-67-84",
        "organization": "Environics Oy",
        "address_1": "Graanintie 5",
        "address_2": "Mikkeli    50190",
        "country": "FI"
    },
    "68DCE8": {
        "oui_hex": "68-DC-E8",
        "organization": "PacketStorm Communications",
        "address_1": "20 Meridian Rd",
        "address_2": "Eatontown  NJ  07724",
        "country": "US"
    },
    "488E42": {
        "oui_hex": "48-8E-42",
        "organization": "DIGALOG GmbH",
        "address_1": "Wattstraße 11-13",
        "address_2": "Berlin    D-13355",
        "country": "DE"
    },
    "607688": {
        "oui_hex": "60-76-88",
        "organization": "Velodyne",
        "address_1": "345 Digital Drive",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "78CD8E": {
        "oui_hex": "78-CD-8E",
        "organization": "SMC Networks Inc",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "2C8065": {
        "oui_hex": "2C-80-65",
        "organization": "HARTING Inc. of North America",
        "address_1": "1370 Bowes Road",
        "address_2": "Elgin  Illinois  60123",
        "country": "US"
    },
    "3CC0C6": {
        "oui_hex": "3C-C0-C6",
        "organization": "d&b audiotechnik GmbH",
        "address_1": "Eugen Adolff Str 134",
        "address_2": "Backnang  Baden Wuerttemberg  71522",
        "country": "DE"
    },
    "4468AB": {
        "oui_hex": "44-68-AB",
        "organization": "JUIN COMPANY, LIMITED",
        "address_1": "2FL, 1075-1, Wonpyeong-Dong",
        "address_2": "Gumi City  Gyeongsangbuk-Do  730-010",
        "country": "KR"
    },
    "F81037": {
        "oui_hex": "F8-10-37",
        "organization": "Atopia Systems, LP",
        "address_1": "681 N. Plano Road",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "78A683": {
        "oui_hex": "78-A6-83",
        "organization": "Precidata",
        "address_1": "CP 672",
        "address_2": "2002  NE  2002",
        "country": "CH"
    },
    "F02572": {
        "oui_hex": "F0-25-72",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "04FF51": {
        "oui_hex": "04-FF-51",
        "organization": "NOVAMEDIA INNOVISION SP. Z O.O.",
        "address_1": "WODNA 7",
        "address_2": "KALISZ  WIELKOPOLSKA  62-800",
        "country": "PL"
    },
    "4CB4EA": {
        "oui_hex": "4C-B4-EA",
        "organization": "HRD (S) PTE., LTD.",
        "address_1": "Lot 7, Block 9, Phase 1, Cavite Eco-Zone,",
        "address_2": "Rosario  Cavite  4106",
        "country": "PH"
    },
    "D44C24": {
        "oui_hex": "D4-4C-24",
        "organization": "Vuppalamritha Magnetic Components LTD",
        "address_1": "3rd Floor, 307 ,My Home Ashoka Chambers,S.P Road,",
        "address_2": "Secunderabad  AndhraPradesh  500003",
        "country": "IN"
    },
    "F8C678": {
        "oui_hex": "F8-C6-78",
        "organization": "Carefusion",
        "address_1": "10020 Pacific Mesa Blvd",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6CAB4D": {
        "oui_hex": "6C-AB-4D",
        "organization": "Digital Payment Technologies",
        "address_1": "4105 Grandview Hwy",
        "address_2": "Burnaby  BC  V5C 6B4",
        "country": "CA"
    },
    "2CB0DF": {
        "oui_hex": "2C-B0-DF",
        "organization": "Soliton Technologies Pvt Ltd",
        "address_1": "# 683, 15th Cross",
        "address_2": "Bangalore  Karnataka  560 078",
        "country": "IN"
    },
    "ECE555": {
        "oui_hex": "EC-E5-55",
        "organization": "Hirschmann Automation",
        "address_1": "Stuttgarter Straße 45-51",
        "address_2": "Neckartenzlingen  Baden-Württemberg  72654",
        "country": "DE"
    },
    "58F98E": {
        "oui_hex": "58-F9-8E",
        "organization": "SECUDOS GmbH",
        "address_1": "Rhenus-Platz 2",
        "address_2": "Holzwickede  NRW  59439",
        "country": "DE"
    },
    "B4C44E": {
        "oui_hex": "B4-C4-4E",
        "organization": "VXL eTech Pvt Ltd",
        "address_1": "#91, 11th Main, Begur Main Road",
        "address_2": "Bangalore  Karnataka  560068",
        "country": "IN"
    },
    "707EDE": {
        "oui_hex": "70-7E-DE",
        "organization": "NASTEC LTD.",
        "address_1": "111-D, Krasnorechenskaya str.",
        "address_2": "Khabarovsk    680006",
        "country": "RU"
    },
    "C07E40": {
        "oui_hex": "C0-7E-40",
        "organization": "SHENZHEN XDK COMMUNICATION EQUIPMENT CO.,LTD",
        "address_1": "XDK BUILDING,NO.1 INDUSTRIAL AREA,BANTIAN,LONGGANG DISTRICT",
        "address_2": "SHENZHEN  GUANGDONG  518129",
        "country": "CN"
    },
    "E44F29": {
        "oui_hex": "E4-4F-29",
        "organization": "MA Lighting Technology GmbH",
        "address_1": "Dachdeckerstraße16",
        "address_2": "Waldbüttelbrunn  Bavaria  97297",
        "country": "DE"
    },
    "B4749F": {
        "oui_hex": "B4-74-9F",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "7C4AA8": {
        "oui_hex": "7C-4A-A8",
        "organization": "MindTree Wireless PVT Ltd",
        "address_1": "LGF, Phase III, Mindtree West Campus,",
        "address_2": "Bangalore  Karnataka  560 059",
        "country": "IN"
    },
    "8091C0": {
        "oui_hex": "80-91-C0",
        "organization": "AgileMesh, Inc.",
        "address_1": "1671 International Pkwy",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "E05FB9": {
        "oui_hex": "E0-5F-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0143E": {
        "oui_hex": "E0-14-3E",
        "organization": "Modoosis Inc.",
        "address_1": "#302, Samil Bldg., 656-282",
        "address_2": "Seoul    133-110",
        "country": "KR"
    },
    "90D852": {
        "oui_hex": "90-D8-52",
        "organization": "Comtec Co., Ltd.",
        "address_1": " 3F., No.81, Jiankang Rd.,",
        "address_2": "Zhonghe City  Taipei County  23586",
        "country": "TW"
    },
    "380197": {
        "oui_hex": "38-01-97",
        "organization": "TSST Global,Inc",
        "address_1": "14 Floor, Bldg. No. 102, Digital Empire2, 486, Sin-dong, Yeongtong-gu, Suwon-si,",
        "address_2": "Su-won  Gyeonggi  443-734",
        "country": "KR"
    },
    "AC02CF": {
        "oui_hex": "AC-02-CF",
        "organization": "RW Tecnologia Industria e Comercio Ltda",
        "address_1": "Centro Empresarial Paulo Frederico de Toledo, 80 A",
        "address_2": "Santa Rita do Sapucai  Minas Gerais   37540000",
        "country": "BR"
    },
    "D41296": {
        "oui_hex": "D4-12-96",
        "organization": "Anobit Technologies Ltd.",
        "address_1": "8 Hasadnaot St.",
        "address_2": "Herzeliya Pituach     46728",
        "country": "IL"
    },
    "48174C": {
        "oui_hex": "48-17-4C",
        "organization": "MicroPower technologies",
        "address_1": "4225 Executive Sq.",
        "address_2": "La Jolla  California  92037",
        "country": "US"
    },
    "349A0D": {
        "oui_hex": "34-9A-0D",
        "organization": "ZBD Displays Ltd",
        "address_1": "Orchard Lea",
        "address_2": "Windsor  Berkshire  SL4 4RU",
        "country": "GB"
    },
    "90507B": {
        "oui_hex": "90-50-7B",
        "organization": "Advanced PANMOBIL Systems GmbH & Co. KG",
        "address_1": "Hansestraße 91",
        "address_2": "Cologne  NRW  51149",
        "country": "DE"
    },
    "0876FF": {
        "oui_hex": "08-76-FF",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "1C7C11": {
        "oui_hex": "1C-7C-11",
        "organization": "EID",
        "address_1": "Rua Quinta dos Medronheiros",
        "address_2": "Charneca da Caparica     2820-486",
        "country": "PT"
    },
    "20AA25": {
        "oui_hex": "20-AA-25",
        "organization": "IP-NET LLC",
        "address_1": "10256 N.W. 47th St.",
        "address_2": "Sunrise  FL  33351",
        "country": "US"
    },
    "C4EEF5": {
        "oui_hex": "C4-EE-F5",
        "organization": "II-VI Incorporated",
        "address_1": "Network Solutions,343 Daniel Zenker Dr., Suite 102",
        "address_2": "Horseheads  NY  14845",
        "country": "US"
    },
    "E0CF2D": {
        "oui_hex": "E0-CF-2D",
        "organization": "Gemintek Corporation",
        "address_1": "5F-1, No.8, Alley 30, Lane 358, Rueiguang Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "D491AF": {
        "oui_hex": "D4-91-AF",
        "organization": "Electroacustica General Iberica, S.A.",
        "address_1": "Avda. Almozara, 79",
        "address_2": "Zaragoza    50003",
        "country": "ES"
    },
    "C4B512": {
        "oui_hex": "C4-B5-12",
        "organization": "General Electric Digital Energy",
        "address_1": "4200 Wildwood Pkwy",
        "address_2": "Atlanta  GA  30339",
        "country": "US"
    },
    "0034F1": {
        "oui_hex": "00-34-F1",
        "organization": "Radicom Research, Inc.",
        "address_1": "2148 Bering Drive",
        "address_2": "San Jose  Ca  95131",
        "country": "US"
    },
    "9433DD": {
        "oui_hex": "94-33-DD",
        "organization": "Taco Inc",
        "address_1": "1160 Cranston Street",
        "address_2": "Cranston  RI  02920",
        "country": "US"
    },
    "E02538": {
        "oui_hex": "E0-25-38",
        "organization": "Titan Pet Products",
        "address_1": "6521 Creedmoor Rd. Suite 101",
        "address_2": "Raleigh  NC  27613",
        "country": "US"
    },
    "CC7A30": {
        "oui_hex": "CC-7A-30",
        "organization": "CMAX Wireless Co., Ltd.",
        "address_1": "KT Bongduk B/D 9F, 627-15, Bongduk-dong",
        "address_2": "Namgu  Daegu  705710",
        "country": "KR"
    },
    "B88E3A": {
        "oui_hex": "B8-8E-3A",
        "organization": "Infinite Technologies JLT",
        "address_1": "Office 3203, Level 32",
        "address_2": "Jumeirah Lake Towers  Dubai",
        "country": "AE"
    },
    "588D09": {
        "oui_hex": "58-8D-09",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C0C1C0": {
        "oui_hex": "C0-C1-C0",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "6015C7": {
        "oui_hex": "60-15-C7",
        "organization": "IdaTech",
        "address_1": "63065 NE 18th St.",
        "address_2": "Bend  OR  97701",
        "country": "US"
    },
    "DC2008": {
        "oui_hex": "DC-20-08",
        "organization": "ASD Electronics Ltd",
        "address_1": "DEDE INDUSTRIAL PARK,JIAN'AN ROAD,HIGH-TECH",
        "address_2": "Shenzhen   Guang Dong  518103",
        "country": "CN"
    },
    "1C83B0": {
        "oui_hex": "1C-83-B0",
        "organization": "Linked IP GmbH",
        "address_1": "Kirchenstrasse 9",
        "address_2": "Anif / Niederalm  SBG  5081",
        "country": "AT"
    },
    "A4D1D1": {
        "oui_hex": "A4-D1-D1",
        "organization": "ECOtality North America",
        "address_1": "430 S 2nd Avenue",
        "address_2": "Phoenix  AZ  85003",
        "country": "US"
    },
    "C49313": {
        "oui_hex": "C4-93-13",
        "organization": "100fio networks technology llc",
        "address_1": "2534 crescent st. apt 3F",
        "address_2": "Astoria  New york  11102",
        "country": "US"
    },
    "7C3920": {
        "oui_hex": "7C-39-20",
        "organization": "SSOMA SECURITY",
        "address_1": "Unit 703, Daeryung Technotown 13th,",
        "address_2": "Geumcheongu  Seoul  153754",
        "country": "KR"
    },
    "28C0DA": {
        "oui_hex": "28-C0-DA",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "9C77AA": {
        "oui_hex": "9C-77-AA",
        "organization": "NADASNV",
        "address_1": "2203, T-dong, Poonglim I-won Plus",
        "address_2": "Seongnam-si  Gyeonggi-do  463-862",
        "country": "KR"
    },
    "10E8EE": {
        "oui_hex": "10-E8-EE",
        "organization": "PhaseSpace",
        "address_1": "1933 Davis St Suite 312",
        "address_2": "San Leandro  CA  94577",
        "country": "US"
    },
    "A47C1F": {
        "oui_hex": "A4-7C-1F",
        "organization": "Cobham plc",
        "address_1": "3985 Gateway Centre Blvd",
        "address_2": "Pinellas Park  FL  33782",
        "country": "US"
    },
    "D46CDA": {
        "oui_hex": "D4-6C-DA",
        "organization": "CSM GmbH",
        "address_1": "Raiffeisenstraße 34",
        "address_2": "Filderstadt  Baden-Württemberg  70794",
        "country": "DE"
    },
    "5CD998": {
        "oui_hex": "5C-D9-98",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd Rd., Neihu District,",
        "address_2": "Taipei City     114",
        "country": "TW"
    },
    "68597F": {
        "oui_hex": "68-59-7F",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "F065DD": {
        "oui_hex": "F0-65-DD",
        "organization": "Primax Electronics Ltd.",
        "address_1": "669, Ruey Kuang Road, Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "706582": {
        "oui_hex": "70-65-82",
        "organization": "Suzhou Hanming Technologies Co., Ltd.",
        "address_1": "Suite 407, No. 166, Ren Ai Road",
        "address_2": "Suzhou  Jiangsu  215123",
        "country": "CN"
    },
    "34D2C4": {
        "oui_hex": "34-D2-C4",
        "organization": "RENA GmbH Print Systeme",
        "address_1": "Hienlohestrasse 24",
        "address_2": "Otterfing  Bavaria  83624",
        "country": "DE"
    },
    "D4CBAF": {
        "oui_hex": "D4-CB-AF",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "045D56": {
        "oui_hex": "04-5D-56",
        "organization": "camtron industrial inc.",
        "address_1": "5F, Kuem-Ah B/D, 31-3, Karak-dong, Songpa-gu",
        "address_2": "Seoul    138-801",
        "country": "KR"
    },
    "68234B": {
        "oui_hex": "68-23-4B",
        "organization": "Nihon Dengyo Kousaku",
        "address_1": "shinmachi 21-1",
        "address_2": "kawagoe-shi  saitama  350-1107",
        "country": "JP"
    },
    "1C3DE7": {
        "oui_hex": "1C-3D-E7",
        "organization": "Sigma Koki Co.,Ltd.",
        "address_1": "1-19-9 Midori",
        "address_2": "Sumida-ku  Tokyo  130-0021",
        "country": "JP"
    },
    "58BC27": {
        "oui_hex": "58-BC-27",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "20D607": {
        "oui_hex": "20-D6-07",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "6CE0B0": {
        "oui_hex": "6C-E0-B0",
        "organization": "SOUND4",
        "address_1": "11 quai Joseph Gillet",
        "address_2": "LYON    69004",
        "country": "FR"
    },
    "9CFFBE": {
        "oui_hex": "9C-FF-BE",
        "organization": "OTSL Inc.",
        "address_1": "HANROKU Bldg. 2F, 2-1-2",
        "address_2": "Shinjuku-ku  Tokyo  160-0021",
        "country": "JP"
    },
    "00F860": {
        "oui_hex": "00-F8-60",
        "organization": "PT. Panggung Electric Citrabuana",
        "address_1": "Jl. Raya Waru no. 1",
        "address_2": "Sidoarjo  Jawa Timur  61256",
        "country": "ID"
    },
    "B8BA72": {
        "oui_hex": "B8-BA-72",
        "organization": "Cynove",
        "address_1": "10 cite rougemont",
        "address_2": "Paris    75009",
        "country": "FR"
    },
    "443D21": {
        "oui_hex": "44-3D-21",
        "organization": "Nuvolt",
        "address_1": "8087 Boul. de la Rive Sud",
        "address_2": "Levis  Quebec  G6V 9G9",
        "country": "CA"
    },
    "30493B": {
        "oui_hex": "30-49-3B",
        "organization": "Nanjing Z-Com Wireless Co.,Ltd",
        "address_1": "Z-Com Building,NO.30 Jiangsu Software Park,NO.699-22 Xuanwu Avenue,",
        "address_2": "Nanjing  Jiangsu  210042",
        "country": "CN"
    },
    "A45C27": {
        "oui_hex": "A4-5C-27",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "6C0460": {
        "oui_hex": "6C-04-60",
        "organization": "RBH Access Technologies Inc.",
        "address_1": "2 Automatic Road",
        "address_2": "Brampton  Ontario  L6S 6K8",
        "country": "CA"
    },
    "706417": {
        "oui_hex": "70-64-17",
        "organization": "ORBIS TECNOLOGIA ELECTRICA S.A.",
        "address_1": "Lerida, 61",
        "address_2": "Madrid  Madrid  E28020",
        "country": "US"
    },
    "18EF63": {
        "oui_hex": "18-EF-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "206FEC": {
        "oui_hex": "20-6F-EC",
        "organization": "Braemac CA LLC",
        "address_1": "43134 Osgood Road",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "100D32": {
        "oui_hex": "10-0D-32",
        "organization": "Embedian, Inc.",
        "address_1": "10F., 95, Nanjing E. Rd. Sec. 4,",
        "address_2": "Taipei    10580",
        "country": "TW"
    },
    "88ACC1": {
        "oui_hex": "88-AC-C1",
        "organization": "Generiton Co., Ltd.",
        "address_1": "8F-1, No. 81, Shuili Rd.,",
        "address_2": "Hsinchu City,     30059",
        "country": "TW"
    },
    "8818AE": {
        "oui_hex": "88-18-AE",
        "organization": "Tamron Co., Ltd",
        "address_1": "1385,Hasunuma, Minuma-ku",
        "address_2": "Saitama-shi  Saitama  337-8556",
        "country": "JP"
    },
    "7CED8D": {
        "oui_hex": "7C-ED-8D",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "A4BE61": {
        "oui_hex": "A4-BE-61",
        "organization": "EutroVision System, Inc.",
        "address_1": "Rm 403,Building33,No.680 GuipingRd,Xuhui,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "D07DE5": {
        "oui_hex": "D0-7D-E5",
        "organization": "Forward Pay Systems, Inc.",
        "address_1": "9531 West 78th St., #245",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "04DD4C": {
        "oui_hex": "04-DD-4C",
        "organization": "Velocytech",
        "address_1": "Poppelgårdvej 11",
        "address_2": "Søborg  DK  2860",
        "country": "DK"
    },
    "A40CC3": {
        "oui_hex": "A4-0C-C3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4CBAA3": {
        "oui_hex": "4C-BA-A3",
        "organization": "Bison Electronics Inc.",
        "address_1": "3F., No.28, Lane 583, Rueiguang Rd., Neihu District",
        "address_2": "Taipei City    11492",
        "country": "TW"
    },
    "A8B1D4": {
        "oui_hex": "A8-B1-D4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "EC7C74": {
        "oui_hex": "EC-7C-74",
        "organization": "Justone Technologies Co., Ltd.",
        "address_1": "Tongguang Building F19, 12# South Agriculture Exhibition Center Road,",
        "address_2": "Beijing    100125",
        "country": "CN"
    },
    "CCFCB1": {
        "oui_hex": "CC-FC-B1",
        "organization": "Wireless Technology, Inc.",
        "address_1": "2064 Eastman Ave. #113",
        "address_2": "Ventura  CA  93003-7787",
        "country": "US"
    },
    "3C1A79": {
        "oui_hex": "3C-1A-79",
        "organization": "Huayuan Technology CO.,LTD",
        "address_1": "R308 Block Jingmeng High-Tech Building,NO.5-1 Shangdi East Road,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "7CF098": {
        "oui_hex": "7C-F0-98",
        "organization": "Bee Beans Technologies, Inc.",
        "address_1": "TCI B5",
        "address_2": "Tsukuba City  Ibaraki  305-0047",
        "country": "JP"
    },
    "EC66D1": {
        "oui_hex": "EC-66-D1",
        "organization": "B&W Group LTD",
        "address_1": "Dale Road",
        "address_2": "Worthing  Sussex  BN11 2BH",
        "country": "GB"
    },
    "385FC3": {
        "oui_hex": "38-5F-C3",
        "organization": "Yu Jeong System, Co.Ltd",
        "address_1": "#503, Dong il B/D, 826, Guro-3dong,",
        "address_2": "Seoul    152-879",
        "country": "KR"
    },
    "888B5D": {
        "oui_hex": "88-8B-5D",
        "organization": "Storage Appliance Corporation",
        "address_1": "29 Su Zhou Jie, Haidian Dist.",
        "address_2": "Beijing     100080",
        "country": "CN"
    },
    "78C6BB": {
        "oui_hex": "78-C6-BB",
        "organization": "Innovasic, Inc.",
        "address_1": "5635 Jefferson St. NE, Suite A",
        "address_2": "Albuquerque  NM  87109",
        "country": "US"
    },
    "84A991": {
        "oui_hex": "84-A9-91",
        "organization": "Cyber Trans Japan Co.,Ltd.",
        "address_1": "",
        "address_2": "Setagaya-ku  Tokyo  155-0031",
        "country": "JP"
    },
    "68784C": {
        "oui_hex": "68-78-4C",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "F8D756": {
        "oui_hex": "F8-D7-56",
        "organization": "Simm Tronic Limited",
        "address_1": "Unit 3, Waterside",
        "address_2": "Hoddesdon  Hertfordshire  EN11 0QR",
        "country": "GB"
    },
    "04A3F3": {
        "oui_hex": "04-A3-F3",
        "organization": "Emicon",
        "address_1": "shelkovskoe shosse, 77",
        "address_2": "Moscow    107241",
        "country": "RU"
    },
    "1C17D3": {
        "oui_hex": "1C-17-D3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7CE044": {
        "oui_hex": "7C-E0-44",
        "organization": "NEON Inc",
        "address_1": "5340 Airport Boulevard",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "284C53": {
        "oui_hex": "28-4C-53",
        "organization": "Intune Networks",
        "address_1": "9B Beckett Way",
        "address_2": "Dublin     12",
        "country": "IE"
    },
    "64D02D": {
        "oui_hex": "64-D0-2D",
        "organization": "Next Generation Integration (NGI)",
        "address_1": "137 rue de Versailles",
        "address_2": "Le Chesnay    78150",
        "country": "FR"
    },
    "90513F": {
        "oui_hex": "90-51-3F",
        "organization": "Elettronica Santerno SpA",
        "address_1": "Via della Concia 7",
        "address_2": "Castel Guelfo (BO)    40026",
        "country": "IT"
    },
    "8841C1": {
        "oui_hex": "88-41-C1",
        "organization": "ORBISAT DA AMAZONIA IND E AEROL SA",
        "address_1": "AV SHISHIMA HIFUMI, 2911",
        "address_2": "SAO JOSE DOS CAMPOS  São Paulo  12244-000",
        "country": "BR"
    },
    "9C7514": {
        "oui_hex": "9C-75-14",
        "organization": "Wildix srl",
        "address_1": "loc. Le Basse, 3",
        "address_2": "Trento  TN  38100",
        "country": "IT"
    },
    "4CF737": {
        "oui_hex": "4C-F7-37",
        "organization": "SamJi Electronics Co., Ltd",
        "address_1": "459-21, Gasan-dong, Gumchun-ku",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "F0D767": {
        "oui_hex": "F0-D7-67",
        "organization": "Axema Passagekontroll AB",
        "address_1": "Box 90 215",
        "address_2": "Stockholm    120 23",
        "country": "SE"
    },
    "C84C75": {
        "oui_hex": "C8-4C-75",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C802A6": {
        "oui_hex": "C8-02-A6",
        "organization": "Beijing Newmine Technology",
        "address_1": "10 floor,Keshi Plaza",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "4C8B55": {
        "oui_hex": "4C-8B-55",
        "organization": "Grupo Digicon",
        "address_1": "Rua Nissin Castiel, 640",
        "address_2": "Gravataí  Rio Grande do Sul  94045420",
        "country": "BR"
    },
    "6C5CDE": {
        "oui_hex": "6C-5C-DE",
        "organization": "SunReports, Inc.",
        "address_1": "1406 Cedarwood Dr.",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "34F39B": {
        "oui_hex": "34-F3-9B",
        "organization": "WizLAN Ltd.",
        "address_1": "P.O.Box 7948",
        "address_2": "Haifa    31078",
        "country": "IL"
    },
    "E86CDA": {
        "oui_hex": "E8-6C-DA",
        "organization": "Supercomputers and Neurocomputers Research Center",
        "address_1": "2, Chekhov st",
        "address_2": "Taganrog   Rostov-on-Don region   347922",
        "country": "RU"
    },
    "240B2A": {
        "oui_hex": "24-0B-2A",
        "organization": "Viettel Group",
        "address_1": "Center for Research and Development",
        "address_2": "Hanoi    1111",
        "country": "VN"
    },
    "00B5D6": {
        "oui_hex": "00-B5-D6",
        "organization": "Omnibit Inc.",
        "address_1": "2-7-9, Soto-Kanda",
        "address_2": "Chiyoda-ku  Tokyo  101-0021",
        "country": "JP"
    },
    "548922": {
        "oui_hex": "54-89-22",
        "organization": "Zelfy Inc",
        "address_1": "4655 Old Ironsides Dr, Suite#200",
        "address_2": "Santa Clara  Ca  95054",
        "country": "US"
    },
    "50C58D": {
        "oui_hex": "50-C5-8D",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "24A42C": {
        "oui_hex": "24-A4-2C",
        "organization": "KOUKAAM a.s.",
        "address_1": "U vinnych sklepu 7",
        "address_2": "Prague    190 00",
        "country": "CZ"
    },
    "4C3089": {
        "oui_hex": "4C-30-89",
        "organization": "Thales Transportation Systems GmbH",
        "address_1": "Bierweg 2",
        "address_2": "Arnstadt  Thuringia  99310",
        "country": "DE"
    },
    "481249": {
        "oui_hex": "48-12-49",
        "organization": "Luxcom Technologies Inc.",
        "address_1": "102 Walgreen Road",
        "address_2": "Ottawa  Ontario  K0A 1L0",
        "country": "CA"
    },
    "24A937": {
        "oui_hex": "24-A9-37",
        "organization": "PURE Storage",
        "address_1": "650 Castro Street",
        "address_2": "Mt. View  CA  94041",
        "country": "US"
    },
    "348302": {
        "oui_hex": "34-83-02",
        "organization": "iFORCOM Co., Ltd",
        "address_1": "1326",
        "address_2": "Sagamihara  Kanagawa  252-0157",
        "country": "JP"
    },
    "B43DB2": {
        "oui_hex": "B4-3D-B2",
        "organization": "Degreane Horizon",
        "address_1": "730 Rue de l'Initiative",
        "address_2": "Cuers  Var  83390",
        "country": "FR"
    },
    "84F64C": {
        "oui_hex": "84-F6-4C",
        "organization": "Cross Point BV",
        "address_1": "Postbus 2112",
        "address_2": "Emmen  Drenthe  7801 CC",
        "country": "NL"
    },
    "C08B6F": {
        "oui_hex": "C0-8B-6F",
        "organization": "S I Sistemas Inteligentes Eletrônicos Ltda",
        "address_1": "Rua Amadeu Piotto 161",
        "address_2": "Curitiba  Paraná  81280020",
        "country": "BR"
    },
    "F86ECF": {
        "oui_hex": "F8-6E-CF",
        "organization": "Arcx Inc",
        "address_1": "151 Amber St, Unit 1",
        "address_2": "Markham  ON  L3R 3B3",
        "country": "CA"
    },
    "8C8401": {
        "oui_hex": "8C-84-01",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "408493": {
        "oui_hex": "40-84-93",
        "organization": "Clavister AB",
        "address_1": "Sjogatan 6J",
        "address_2": "Ornskoldsvik    89160",
        "country": "SE"
    },
    "78A6BD": {
        "oui_hex": "78-A6-BD",
        "organization": "DAEYEON Control&Instrument Co,.Ltd",
        "address_1": "ACETECHNOTOWER 2-108, 197-7, Guro3-Dong, Guro-Gu,",
        "address_2": "Seoul    152-766",
        "country": "KR"
    },
    "3C1915": {
        "oui_hex": "3C-19-15",
        "organization": "GFI Chrono Time",
        "address_1": "121 rue des Guillees",
        "address_2": "CHAURAY    79180",
        "country": "FR"
    },
    "ECB106": {
        "oui_hex": "EC-B1-06",
        "organization": "Acuro Networks, Inc",
        "address_1": "42808 Christy St., Suite 100",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "C835B8": {
        "oui_hex": "C8-35-B8",
        "organization": "Ericsson, EAB/RWI/K",
        "address_1": "Skolgången 17",
        "address_2": "    SE-800 06",
        "country": "SE"
    },
    "F89D0D": {
        "oui_hex": "F8-9D-0D",
        "organization": "Control Technology Inc.",
        "address_1": "7608 North Hudson Ave",
        "address_2": "Oklahoma City  OK  73116",
        "country": "US"
    },
    "2C3F3E": {
        "oui_hex": "2C-3F-3E",
        "organization": "Alge-Timing GmbH",
        "address_1": "Rotkreuzstrasse 39",
        "address_2": "Lustenau    6890",
        "country": "AT"
    },
    "089F97": {
        "oui_hex": "08-9F-97",
        "organization": "LEROY AUTOMATION",
        "address_1": "35, Boulevard du Libre Echange",
        "address_2": "Saint Orens de Gameville    31650",
        "country": "FR"
    },
    "34BA51": {
        "oui_hex": "34-BA-51",
        "organization": "Se-Kure Controls, Inc.",
        "address_1": "3714 Runge Street",
        "address_2": "Franklin Park  IL  60131",
        "country": "US"
    },
    "6C7039": {
        "oui_hex": "6C-70-39",
        "organization": "Novar GmbH",
        "address_1": "Johannes-Mauthe-Str. 14",
        "address_2": "Albstadt  Baden-Württemberg  72458",
        "country": "DE"
    },
    "982D56": {
        "oui_hex": "98-2D-56",
        "organization": "Resolution Audio",
        "address_1": "88 Hoff Street #106",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "147373": {
        "oui_hex": "14-73-73",
        "organization": "TUBITAK UEKAE",
        "address_1": "ANIBAL ST.",
        "address_2": "KOCAELI    41470",
        "country": "TR"
    },
    "FCCF62": {
        "oui_hex": "FC-CF-62",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "084E1C": {
        "oui_hex": "08-4E-1C",
        "organization": "H2A Systems, LLC",
        "address_1": "7545 Irvine Center Drive",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "88B627": {
        "oui_hex": "88-B6-27",
        "organization": "Gembird Europe BV",
        "address_1": "Wittevrouwen 56",
        "address_2": "Almere  Flevoland  1358CD",
        "country": "NL"
    },
    "F06853": {
        "oui_hex": "F0-68-53",
        "organization": "Integrated Corporation",
        "address_1": "3/F, Shun On Commercial Bldg.,",
        "address_2": "Cetnral,",
        "country": "HK"
    },
    "A4ADB8": {
        "oui_hex": "A4-AD-B8",
        "organization": "Vitec Group, Camera Dynamics Ltd",
        "address_1": "William Vinten Building",
        "address_2": "Bury St Edmunds  Suffolk  IP33 3TB",
        "country": "GB"
    },
    "A4B121": {
        "oui_hex": "A4-B1-21",
        "organization": "Arantia 2010 S.L.",
        "address_1": "Volta do Castro s/n",
        "address_2": "Santiago de Compostela  A Coruña  15706",
        "country": "ES"
    },
    "E02636": {
        "oui_hex": "E0-26-36",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "5C57C8": {
        "oui_hex": "5C-57-C8",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "D46CBF": {
        "oui_hex": "D4-6C-BF",
        "organization": "Goodrich ISR",
        "address_1": "6600 Gulton Crt",
        "address_2": "Albuquerque  NM  87109",
        "country": "US"
    },
    "E02630": {
        "oui_hex": "E0-26-30",
        "organization": "Intrigue Technologies, Inc.",
        "address_1": "800 Old Pond Road",
        "address_2": "Bridgeville  PA  15017",
        "country": "US"
    },
    "ECC882": {
        "oui_hex": "EC-C8-82",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6CFDB9": {
        "oui_hex": "6C-FD-B9",
        "organization": "Proware Technologies Co Ltd.",
        "address_1": "2nd F1 East Wing,South Section,Factory Building 24,Science&Technology Park",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "10189E": {
        "oui_hex": "10-18-9E",
        "organization": "Elmo Motion Control",
        "address_1": "64 Gisin St.",
        "address_2": "Petach Tikva    49103",
        "country": "IL"
    },
    "8C56C5": {
        "oui_hex": "8C-56-C5",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "CCB888": {
        "oui_hex": "CC-B8-88",
        "organization": "AnB Securite s.a.",
        "address_1": "Rue de Joie,38-40",
        "address_2": "Liege    4000",
        "country": "BE"
    },
    "6C5E7A": {
        "oui_hex": "6C-5E-7A",
        "organization": "Ubiquitous Internet Telecom Co., Ltd",
        "address_1": "#512, 5th Floor, Kolon Digital Valley,Guro 3(sam)-dong, Guro-gu",
        "address_2": "Seoul    152-777",
        "country": "KR"
    },
    "B42CBE": {
        "oui_hex": "B4-2C-BE",
        "organization": "Direct Payment Solutions Limited",
        "address_1": "98 Anzac Avenue",
        "address_2": "Auckland    1035",
        "country": "NZ"
    },
    "CC2218": {
        "oui_hex": "CC-22-18",
        "organization": "InnoDigital Co., Ltd.",
        "address_1": "No.310 3F Kofomo Tower",
        "address_2": "Sungnam-city  Kyunggi-do  463-825",
        "country": "KR"
    },
    "C86C1E": {
        "oui_hex": "C8-6C-1E",
        "organization": "Display Systems Ltd",
        "address_1": "16-Parkovaja Street 26",
        "address_2": "Moscow    105484",
        "country": "RU"
    },
    "A01859": {
        "oui_hex": "A0-18-59",
        "organization": "Shenzhen Yidashi Electronics Co Ltd",
        "address_1": "Building A10, Fukang Industrial Zone",
        "address_2": "Shenzhen   Guangdong   518110",
        "country": "CN"
    },
    "E8056D": {
        "oui_hex": "E8-05-6D",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "C45976": {
        "oui_hex": "C4-59-76",
        "organization": "Fugoo Coorporation",
        "address_1": "8001 Irvine Center Drive",
        "address_2": "Irvine  CA  62618",
        "country": "US"
    },
    "90A7C1": {
        "oui_hex": "90-A7-C1",
        "organization": "Pakedge Device and Software Inc.",
        "address_1": "1011 Edwards Road",
        "address_2": "Burlingame  CA  94010",
        "country": "US"
    },
    "80BAAC": {
        "oui_hex": "80-BA-AC",
        "organization": "TeleAdapt Ltd",
        "address_1": "Axis 5",
        "address_2": "Watford  Hertfordshire  WD244YW",
        "country": "GB"
    },
    "502DF4": {
        "oui_hex": "50-2D-F4",
        "organization": "Phytec Messtechnik GmbH",
        "address_1": "Robert-Koch-Straße 39",
        "address_2": "Mainz  Rheinland-Pfalz  55129",
        "country": "DE"
    },
    "2CCD27": {
        "oui_hex": "2C-CD-27",
        "organization": "Precor Inc",
        "address_1": "20031 142nd Avenue NE",
        "address_2": "Woodinville  WA  98072",
        "country": "US"
    },
    "104369": {
        "oui_hex": "10-43-69",
        "organization": "Soundmax Electronic Limited",
        "address_1": "Room#1505, Oriental plaza, #1072 JianShe Road",
        "address_2": "SHENZHEN   Guangdong  518001",
        "country": "CN"
    },
    "C06C0F": {
        "oui_hex": "C0-6C-0F",
        "organization": "Dobbs Stanford",
        "address_1": "2715 Electronic Lane",
        "address_2": "Dallas  Texas  75220",
        "country": "US"
    },
    "C86CB6": {
        "oui_hex": "C8-6C-B6",
        "organization": "Optcom Co., Ltd.",
        "address_1": "792-3 Tomigaoka",
        "address_2": "Iwata  Shizuoka  438-0803",
        "country": "JP"
    },
    "5849BA": {
        "oui_hex": "58-49-BA",
        "organization": "Chitai Electronic Corp.",
        "address_1": "5F., No. 1 Lane 123, Pao-Chung Rd., Hsin-Tien City",
        "address_2": "Taiepi    23144",
        "country": "TW"
    },
    "00D11C": {
        "oui_hex": "00-D1-1C",
        "organization": "ACETEL",
        "address_1": "#1006, World Merdian 2-cha, 426-5,",
        "address_2": "Seoul    153-759",
        "country": "KR"
    },
    "601D0F": {
        "oui_hex": "60-1D-0F",
        "organization": "Midnite Solar",
        "address_1": "17722 67th Ave NE #C",
        "address_2": "Arlington  WA  98223",
        "country": "US"
    },
    "A8F94B": {
        "oui_hex": "A8-F9-4B",
        "organization": "Eltex Enterprise Ltd.",
        "address_1": "Okruzhnaya st. 29v",
        "address_2": "Novosibirsk    630020",
        "country": "RU"
    },
    "0C8230": {
        "oui_hex": "0C-82-30",
        "organization": "SHENZHEN MAGNUS TECHNOLOGIES CO.,LTD",
        "address_1": "c-504,Skyworth Building,No.8 Road,High-tech south,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "746B82": {
        "oui_hex": "74-6B-82",
        "organization": "MOVEK",
        "address_1": "6517 Navaho Trail",
        "address_2": "Edina  Minnesota  55439",
        "country": "US"
    },
    "9CC077": {
        "oui_hex": "9C-C0-77",
        "organization": "PrintCounts, LLC",
        "address_1": "5109 W Lemon St",
        "address_2": "Tampa  FL  33609",
        "country": "US"
    },
    "3CB17F": {
        "oui_hex": "3C-B1-7F",
        "organization": "Wattwatchers Pty Ld",
        "address_1": "22 Woodbury Rd St. Ives",
        "address_2": "Sydney  NSW  2075",
        "country": "AU"
    },
    "CC5459": {
        "oui_hex": "CC-54-59",
        "organization": "OnTime Networks AS",
        "address_1": "Gladsvei 20",
        "address_2": "Oslo    0489",
        "country": "NO"
    },
    "F8DC7A": {
        "oui_hex": "F8-DC-7A",
        "organization": "Variscite LTD",
        "address_1": "60 Medinat Hayehudim st.",
        "address_2": "Hertzelia    46722",
        "country": "IL"
    },
    "D4F143": {
        "oui_hex": "D4-F1-43",
        "organization": "IPROAD.,Inc",
        "address_1": "#505 Byuksan digital valley 7, 170-13,",
        "address_2": "Seoul    152-847",
        "country": "KR"
    },
    "B8F732": {
        "oui_hex": "B8-F7-32",
        "organization": "Aryaka Networks Inc",
        "address_1": "691 S. Milpitas Blvd.,",
        "address_2": "Milpitas   CA  95035",
        "country": "US"
    },
    "E8DFF2": {
        "oui_hex": "E8-DF-F2",
        "organization": "PRF Co., Ltd.",
        "address_1": "#510, Leaders B/D, Yatop-dong",
        "address_2": "Seongnam-city  Gyeonggi-do  463-828",
        "country": "KR"
    },
    "B4ED54": {
        "oui_hex": "B4-ED-54",
        "organization": "Wohler Technologies",
        "address_1": "31055 Huntwood Avenue",
        "address_2": "Hayward  CA  94544",
        "country": "US"
    },
    "006440": {
        "oui_hex": "00-64-40",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "94C4E9": {
        "oui_hex": "94-C4-E9",
        "organization": "PowerLayer Microsystems HongKong Limited",
        "address_1": "23 Zhichun Rd,Liangziyinzuo Rm1009",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "8843E1": {
        "oui_hex": "88-43-E1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "34862A": {
        "oui_hex": "34-86-2A",
        "organization": "Heinz Lackmann GmbH & Co KG",
        "address_1": "Harkortstraße 15",
        "address_2": "Münster  NRW  48163",
        "country": "DE"
    },
    "ACE348": {
        "oui_hex": "AC-E3-48",
        "organization": "MadgeTech, Inc",
        "address_1": "879 Maple St",
        "address_2": "Contoocook  NH  03229",
        "country": "US"
    },
    "549A16": {
        "oui_hex": "54-9A-16",
        "organization": "Uzushio Electric Co.,Ltd.",
        "address_1": "105",
        "address_2": "Imabari-city  Ehime pref.  7948582",
        "country": "JP"
    },
    "9018AE": {
        "oui_hex": "90-18-AE",
        "organization": "Shanghai Meridian Technologies, Co. Ltd.",
        "address_1": "Suite 6A Tongsheng Tower",
        "address_2": "Pudong  shanghai  200122",
        "country": "CN"
    },
    "0494A1": {
        "oui_hex": "04-94-A1",
        "organization": "CATCH THE WIND INC",
        "address_1": "10781 JAMES PAYNE COURT",
        "address_2": "MANASSAS  VA  20110",
        "country": "US"
    },
    "003A99": {
        "oui_hex": "00-3A-99",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003A9A": {
        "oui_hex": "00-3A-9A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003A98": {
        "oui_hex": "00-3A-98",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "50A6E3": {
        "oui_hex": "50-A6-E3",
        "organization": "David Clark Company",
        "address_1": "360 Franklin St.",
        "address_2": "Worcester  MA  01615",
        "country": "US"
    },
    "50934F": {
        "oui_hex": "50-93-4F",
        "organization": "Gradual Tecnologia Ltda.",
        "address_1": "Rua Attilio Giaretta, 110",
        "address_2": "Itatiba  SP  13257-584",
        "country": "BR"
    },
    "B8B1C7": {
        "oui_hex": "B8-B1-C7",
        "organization": "BT&COM CO.,LTD",
        "address_1": "#1103, E&C Venture Dream Tower II",
        "address_2": "Seoul    152-719",
        "country": "KR"
    },
    "DC2C26": {
        "oui_hex": "DC-2C-26",
        "organization": "Iton Technology Limited",
        "address_1": "Room 10E, JingFeng Building,",
        "address_2": "ShenZhen  GuangDong  518034",
        "country": "CN"
    },
    "D411D6": {
        "oui_hex": "D4-11-D6",
        "organization": "ShotSpotter, Inc.",
        "address_1": "1060 Terra Bella Ave.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "9CAFCA": {
        "oui_hex": "9C-AF-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "1C0FCF": {
        "oui_hex": "1C-0F-CF",
        "organization": "Sypro Optics GmbH",
        "address_1": "Carl-Zeiss-Promenade 10",
        "address_2": "Jena  Thuringia  07745",
        "country": "DE"
    },
    "9C4E8E": {
        "oui_hex": "9C-4E-8E",
        "organization": "ALT Systems Ltd",
        "address_1": "PoBox 17",
        "address_2": "Helsinki    00761",
        "country": "FI"
    },
    "7072CF": {
        "oui_hex": "70-72-CF",
        "organization": "EdgeCore Networks",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "ECD00E": {
        "oui_hex": "EC-D0-0E",
        "organization": "MiraeRecognition Co., Ltd.",
        "address_1": "PrimeBank Bldg. Annex-3F, #278-3",
        "address_2": "Seoul    135-833",
        "country": "KR"
    },
    "A4AD00": {
        "oui_hex": "A4-AD-00",
        "organization": "Ragsdale Technology",
        "address_1": "505 Echo Lane",
        "address_2": "Big Bear Lake  CA  92315",
        "country": "US"
    },
    "4C9EE4": {
        "oui_hex": "4C-9E-E4",
        "organization": "Hanyang Navicom Co.,Ltd.",
        "address_1": "713, Gwanpyeong-dong, Yusung-gu",
        "address_2": "Daejeon    305-509",
        "country": "KR"
    },
    "C87248": {
        "oui_hex": "C8-72-48",
        "organization": "Aplicom Oy",
        "address_1": "Rautatienkatu 56",
        "address_2": "Äänekoski  Länsi-Suomi  44101",
        "country": "FI"
    },
    "C47D4F": {
        "oui_hex": "C4-7D-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3CDF1E": {
        "oui_hex": "3C-DF-1E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "986DC8": {
        "oui_hex": "98-6D-C8",
        "organization": "TOSHIBA MITSUBISHI-ELECTRIC INDUSTRIAL SYSTEMS CORPORATION",
        "address_1": " TOKYO SQUARE GARDEN",
        "address_2": " 3-1-1 Kyobashi, CHUO-KU  Tokyo  104-0031",
        "country": "JP"
    },
    "6CAC60": {
        "oui_hex": "6C-AC-60",
        "organization": "Venetex Corp",
        "address_1": "8-3-9,Shin-machi",
        "address_2": "Ome-shi,  Tokyo  198-0024",
        "country": "JP"
    },
    "F04BF2": {
        "oui_hex": "F0-4B-F2",
        "organization": "JTECH Communications, Inc.",
        "address_1": "6413 Congress Ave.",
        "address_2": "Boca Raton  FL  33487",
        "country": "US"
    },
    "042BBB": {
        "oui_hex": "04-2B-BB",
        "organization": "PicoCELA, Inc.",
        "address_1": "3-8-33, Momochihama",
        "address_2": "Fukuoka-city  Fukuoka  814-0001",
        "country": "JP"
    },
    "FC0877": {
        "oui_hex": "FC-08-77",
        "organization": "Prentke Romich Company",
        "address_1": "1022 Heyl Rd",
        "address_2": "Wooster  OH  44691",
        "country": "US"
    },
    "64F970": {
        "oui_hex": "64-F9-70",
        "organization": "Kenade Electronics Technology Co.,LTD.",
        "address_1": "F/G room,11/F,Hangdu building,Huafu Rd, Futian district,",
        "address_2": "ShenZhen  GuangDong  518028",
        "country": "CN"
    },
    "C82E94": {
        "oui_hex": "C8-2E-94",
        "organization": "Halfa Enterprise Co., Ltd.",
        "address_1": "5F, No.102, Ming Chuan Road",
        "address_2": "Hsin Tien  Taipei County  23141",
        "country": "TW"
    },
    "80177D": {
        "oui_hex": "80-17-7D",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "7C7BE4": {
        "oui_hex": "7C-7B-E4",
        "organization": "Z'SEDAI KENKYUSHO CORPORATION",
        "address_1": "Meikai sannomiya 2nd Bldg. 11th/fl.",
        "address_2": "Kobe  Hyogo  650-0034",
        "country": "JP"
    },
    "F0DE71": {
        "oui_hex": "F0-DE-71",
        "organization": "Shanghai EDO Technologies Co.,Ltd.",
        "address_1": "Unit 12302, Building 12,498 Guoshoujing Road, Pudong New Area",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "60D30A": {
        "oui_hex": "60-D3-0A",
        "organization": "Quatius Limited",
        "address_1": "Units 05-07, 16/F, Greenfield Tower, Concordia Plaza,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "24CF21": {
        "oui_hex": "24-CF-21",
        "organization": "Shenzhen State Micro Technology Co., Ltd",
        "address_1": "SSMEC Building2/F, Gao Xin Nan First Avenue, Hi-Tech Park South, Nanshan",
        "address_2": "Shenzhen City  Guangdong Province  518057",
        "country": "CN"
    },
    "10BAA5": {
        "oui_hex": "10-BA-A5",
        "organization": "GANA I&C CO., LTD",
        "address_1": "154-17 kyoungdong B/D 3F karak-dong songpa-gu",
        "address_2": "Seoul  Korea  138-160",
        "country": "KR"
    },
    "BC9DA5": {
        "oui_hex": "BC-9D-A5",
        "organization": "DASCOM Europe GmbH",
        "address_1": "Heuweg 3",
        "address_2": "Ulm  Baden-Württemberg  89079",
        "country": "DE"
    },
    "28FBD3": {
        "oui_hex": "28-FB-D3",
        "organization": "Ragentek Technology Group",
        "address_1": "D10/D11，No.3188, Xiupu Road, PuDong District, Shanghai",
        "address_2": "Shanghai    201703",
        "country": "CN"
    },
    "586ED6": {
        "oui_hex": "58-6E-D6",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "EC3091": {
        "oui_hex": "EC-30-91",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "64BC11": {
        "oui_hex": "64-BC-11",
        "organization": "CombiQ AB",
        "address_1": "Science Park",
        "address_2": "Jonkoping    553 18",
        "country": "SE"
    },
    "C8C13C": {
        "oui_hex": "C8-C1-3C",
        "organization": "RuggedTek Hangzhou Co., Ltd",
        "address_1": "Zhejiang University National Science Park",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "F4ACC1": {
        "oui_hex": "F4-AC-C1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4097D1": {
        "oui_hex": "40-97-D1",
        "organization": "BK Electronics cc",
        "address_1": "150 Swaardlelie Ave",
        "address_2": "Pretoria  Gauteng  0184",
        "country": "ZA"
    },
    "0CE936": {
        "oui_hex": "0C-E9-36",
        "organization": "ELIMOS srl",
        "address_1": "Area Science Park - Padriciano 99",
        "address_2": "TRIESTE    34149",
        "country": "IT"
    },
    "A02EF3": {
        "oui_hex": "A0-2E-F3",
        "organization": "United Integrated Services Co., Led.",
        "address_1": "5F No 3 Lane 7 Packao Road Hsintien",
        "address_2": "Taipei Hsien    23144",
        "country": "TW"
    },
    "A09805": {
        "oui_hex": "A0-98-05",
        "organization": "OpenVox Communication Co Ltd",
        "address_1": "F2,Building No.14,Shangsha Science &",
        "address_2": "ShenZhen  GuangDong  518031",
        "country": "CN"
    },
    "60391F": {
        "oui_hex": "60-39-1F",
        "organization": "ABB Ltd",
        "address_1": "Distribution Automation",
        "address_2": "Vadodara  Gujarat  390013",
        "country": "IN"
    },
    "E8A4C1": {
        "oui_hex": "E8-A4-C1",
        "organization": "Deep Sea Electronics Ltd",
        "address_1": "Highfield House",
        "address_2": "Hunmanby  North Yorkshire  YO14 0PH",
        "country": "GB"
    },
    "C8D2C1": {
        "oui_hex": "C8-D2-C1",
        "organization": "Jetlun (Shenzhen) Corporation",
        "address_1": "1008A Skyworth Building, Gao-xin Rd South",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "E09153": {
        "oui_hex": "E0-91-53",
        "organization": "XAVi Technologies Corp.",
        "address_1": "9F., No129, Xingde RD.,Sanchong Dist.,",
        "address_2": "New Taipei  Taiwan  24158",
        "country": "TW"
    },
    "88A5BD": {
        "oui_hex": "88-A5-BD",
        "organization": "QPCOM INC.",
        "address_1": "6030 NW 99 AVE",
        "address_2": "DORAL  FLORIDA  33178",
        "country": "US"
    },
    "D4C766": {
        "oui_hex": "D4-C7-66",
        "organization": "Acentic GmbH",
        "address_1": "Venloer Strasse 151-153",
        "address_2": "Cologne    50672",
        "country": "DE"
    },
    "002712": {
        "oui_hex": "00-27-12",
        "organization": "MaxVision LLC",
        "address_1": "495 Production Ave",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "00271F": {
        "oui_hex": "00-27-1F",
        "organization": "MIPRO Electronics Co., Ltd",
        "address_1": "814,Peikang Road",
        "address_2": "Chiayi    60096",
        "country": "TW"
    },
    "00270C": {
        "oui_hex": "00-27-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0026CF": {
        "oui_hex": "00-26-CF",
        "organization": "DEKA R&D",
        "address_1": "340 Commercial Street",
        "address_2": "Manchester  NH  03101",
        "country": "US"
    },
    "0026E7": {
        "oui_hex": "00-26-E7",
        "organization": "Shanghai ONLAN Communication Tech. Co., Ltd.",
        "address_1": "3F, 6C, No. 1658, Gumei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "0026E0": {
        "oui_hex": "00-26-E0",
        "organization": "ASITEQ",
        "address_1": "5F, DONGYOUNG Bldg,382-6,Yatap dong",
        "address_2": "Sung Nam si  Kyounggi-do  463-827",
        "country": "KR"
    },
    "002703": {
        "oui_hex": "00-27-03",
        "organization": "Testech Electronics Pte Ltd",
        "address_1": "Block 118, #05-110,",
        "address_2": "Singapore    380118",
        "country": "SG"
    },
    "0026F3": {
        "oui_hex": "00-26-F3",
        "organization": "SMC Networks",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0026A5": {
        "oui_hex": "00-26-A5",
        "organization": "MICROROBOT.CO.,LTD",
        "address_1": "167-3 Gungpyeong-ri",
        "address_2": "Gwangju-si  Gyeonggi-Do  464-881",
        "country": "KR"
    },
    "0026A3": {
        "oui_hex": "00-26-A3",
        "organization": "FQ Ingenieria Electronica S.A.",
        "address_1": "Avda. Roquetes 9",
        "address_2": "Sant Pere de Ribes  Barcelona  08812",
        "country": "ES"
    },
    "00269D": {
        "oui_hex": "00-26-9D",
        "organization": "M2Mnet Co., Ltd.",
        "address_1": "607 Downtown Bld. 1043-1 Hogye-Dong Dongan-Gu",
        "address_2": "Anyang-City  Kyunggi-Do  431-080",
        "country": "KR"
    },
    "002697": {
        "oui_hex": "00-26-97",
        "organization": "Alpha  Technologies Inc.",
        "address_1": "3767 Alpha Way",
        "address_2": "Bellingham  WA  98226",
        "country": "US"
    },
    "00268A": {
        "oui_hex": "00-26-8A",
        "organization": "Terrier SC Ltd",
        "address_1": "Strettit Farm",
        "address_2": "East Peckham  Kent  TN12 5EE",
        "country": "GB"
    },
    "002689": {
        "oui_hex": "00-26-89",
        "organization": "General Dynamics Robotic Systems",
        "address_1": "1231 Tech Court",
        "address_2": "Westminster  MD  21157",
        "country": "US"
    },
    "0026C5": {
        "oui_hex": "00-26-C5",
        "organization": "Guangdong Gosun Telecommunications Co.,Ltd",
        "address_1": "Guangdong software park D, No.11, CaiPing road , Guangzhou science city",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "0026C4": {
        "oui_hex": "00-26-C4",
        "organization": "Cadmos microsystems S.r.l.",
        "address_1": "Via Pietro Frattini, 255",
        "address_2": "Roma    00149",
        "country": "IT"
    },
    "0026C8": {
        "oui_hex": "00-26-C8",
        "organization": "System Sensor",
        "address_1": "3825 Ohio Avenue",
        "address_2": "Saint Charles  IL  60174",
        "country": "US"
    },
    "00267A": {
        "oui_hex": "00-26-7A",
        "organization": "wuhan hongxin telecommunication technologies co.,ltd",
        "address_1": "No.5 Donxin Road,Wuhan East Lake High-Tech Development Zone",
        "address_2": "Wuhan  Hubei  430073",
        "country": "CN"
    },
    "0026C2": {
        "oui_hex": "00-26-C2",
        "organization": "SCDI Co. LTD",
        "address_1": "#451, Hagal-Dong, Giheung-Gu,",
        "address_2": "Yongin-Si  Gyeonggi-Do  446-930",
        "country": "KR"
    },
    "002685": {
        "oui_hex": "00-26-85",
        "organization": "Digital Innovation",
        "address_1": "Travbaneveien 6",
        "address_2": "Trondheim    7044",
        "country": "NO"
    },
    "0026A9": {
        "oui_hex": "00-26-A9",
        "organization": "Strong Technologies Pty Ltd",
        "address_1": "60 Wedgewood Road",
        "address_2": "Hallam  Victoria  3803",
        "country": "AU"
    },
    "002672": {
        "oui_hex": "00-26-72",
        "organization": "AAMP of America",
        "address_1": "13190 56th Court",
        "address_2": "Clearwater  Florida  33760",
        "country": "US"
    },
    "0025FD": {
        "oui_hex": "00-25-FD",
        "organization": "OBR Centrum Techniki Morskiej S.A.",
        "address_1": "Dickmana 62",
        "address_2": "Gdynia    81-109",
        "country": "US"
    },
    "002600": {
        "oui_hex": "00-26-00",
        "organization": "TEAC Australia Pty Ltd.",
        "address_1": "75 Northgate Drive",
        "address_2": "Thomastown  Victoria  3074",
        "country": "AU"
    },
    "0025FF": {
        "oui_hex": "00-25-FF",
        "organization": "CreNova Multimedia Co., Ltd",
        "address_1": "7/F, Hana EZ Tower, Gumi-Dong 10, Sungnam Rd 43,",
        "address_2": "Sungnam-Si  Kyunggi-Do  463-870",
        "country": "KR"
    },
    "002604": {
        "oui_hex": "00-26-04",
        "organization": "Audio Processing Technology Ltd",
        "address_1": "Whiterock Business Park",
        "address_2": "Belfast    BT12 7FP",
        "country": "GB"
    },
    "002659": {
        "oui_hex": "00-26-59",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002651": {
        "oui_hex": "00-26-51",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002612": {
        "oui_hex": "00-26-12",
        "organization": "Space Exploration Technologies",
        "address_1": "1 Rocket Road",
        "address_2": "Hawthorne  CA  90250",
        "country": "US"
    },
    "002616": {
        "oui_hex": "00-26-16",
        "organization": "Rosemount Inc.",
        "address_1": "8200 Market Boulevard",
        "address_2": "Chanhassen  MN  55317",
        "country": "US"
    },
    "00260B": {
        "oui_hex": "00-26-0B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002623": {
        "oui_hex": "00-26-23",
        "organization": "JRD Communication Inc",
        "address_1": "16/F, TCL Tower, Gaoxin Nanyi Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002627": {
        "oui_hex": "00-26-27",
        "organization": "Truesell",
        "address_1": "301 Sungyun Bldg, 89-2",
        "address_2": "Seocho-gu,  Seoul  137-130",
        "country": "KR"
    },
    "00264E": {
        "oui_hex": "00-26-4E",
        "organization": "Rail & Road Protec GmbH",
        "address_1": "Norderhofenden 12-13",
        "address_2": "Flensburg    24937",
        "country": "DE"
    },
    "00264F": {
        "oui_hex": "00-26-4F",
        "organization": "Krüger &Gothe GmbH",
        "address_1": "Atzendorfer Straße 19",
        "address_2": "Staßfurt  Sachsen Anhalt  39418",
        "country": "DE"
    },
    "002621": {
        "oui_hex": "00-26-21",
        "organization": "InteliCloud Technology Inc.",
        "address_1": "895 Dove St.",
        "address_2": "Newport Beach  CA  92660",
        "country": "US"
    },
    "00261C": {
        "oui_hex": "00-26-1C",
        "organization": "NEOVIA INC.",
        "address_1": "503 LOTTE IT CASTLE 1DONG,550-1",
        "address_2": "SEOUL    153-768",
        "country": "KR"
    },
    "002664": {
        "oui_hex": "00-26-64",
        "organization": "Core System Japan",
        "address_1": "Bunshu Bldg,2-27-6,Myojin",
        "address_2": "Hachioji  Tokyo  1920046",
        "country": "JP"
    },
    "002639": {
        "oui_hex": "00-26-39",
        "organization": "T.M. Electronics, Inc.",
        "address_1": "45 Main St",
        "address_2": "Boylston  MA  01505",
        "country": "US"
    },
    "0025C6": {
        "oui_hex": "00-25-C6",
        "organization": "kasercorp, ltd",
        "address_1": "South 20,Gaobu Road,Gaobu Town",
        "address_2": "Dongwan  Guangdong  523000",
        "country": "CN"
    },
    "0025C5": {
        "oui_hex": "00-25-C5",
        "organization": "Star Link Communication Pvt. Ltd.",
        "address_1": "HR114/6 & Hr132/6, Pulprehladpur,",
        "address_2": "New Delhi    110044",
        "country": "IN"
    },
    "0025C7": {
        "oui_hex": "00-25-C7",
        "organization": "altek Corporation",
        "address_1": "3F, No. 10, Li-Hsin Road, Science-Based Industrial Park,",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "0025E6": {
        "oui_hex": "00-25-E6",
        "organization": "Belgian Monitoring Systems bvba",
        "address_1": "Th. Sevenslaan 106",
        "address_2": "Kortrijk  WVL  8500",
        "country": "BE"
    },
    "0025E0": {
        "oui_hex": "00-25-E0",
        "organization": "CeedTec Sdn Bhd",
        "address_1": "303-4-5, Krystal Point Business Center",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "0025DE": {
        "oui_hex": "00-25-DE",
        "organization": "Probits Co., LTD.",
        "address_1": "#1502, Kolon Science Valley II, 811",
        "address_2": "Seoul    152-878",
        "country": "KR"
    },
    "0025B0": {
        "oui_hex": "00-25-B0",
        "organization": "Schmartz Inc",
        "address_1": "2307 Valerian Trl",
        "address_2": "Round Rock  TX  78665",
        "country": "US"
    },
    "0025AD": {
        "oui_hex": "00-25-AD",
        "organization": "Manufacturing Resources International",
        "address_1": "6415 Shiloh Road East",
        "address_2": "Alpharetta  GA  30005",
        "country": "US"
    },
    "0025AC": {
        "oui_hex": "00-25-AC",
        "organization": "I-Tech corporation",
        "address_1": "1-15 Shin-ogawa machi",
        "address_2": "Shinjyuku-ku  Tokyo  162-0814",
        "country": "JP"
    },
    "0025AB": {
        "oui_hex": "00-25-AB",
        "organization": "AIO LCD PC BU / TPV",
        "address_1": "10F., No., 230, Liancheng Rd.",
        "address_2": "Zhonghe City  Taipei Taiwan  23553",
        "country": "TW"
    },
    "0025EC": {
        "oui_hex": "00-25-EC",
        "organization": "Humanware",
        "address_1": "445 rue du Parc Industriel",
        "address_2": "Longueuil  Québec  J4H 3V7",
        "country": "CA"
    },
    "0025ED": {
        "oui_hex": "00-25-ED",
        "organization": "NuVo Technologies LLC",
        "address_1": "3015 Kustom Drive",
        "address_2": "Hebron  KY  41048",
        "country": "US"
    },
    "0025E9": {
        "oui_hex": "00-25-E9",
        "organization": "i-mate Development, Inc.",
        "address_1": "8383 158th Ave. N.E., Suite 300, Redmond,",
        "address_2": "Washington  WA  98052-3871",
        "country": "US"
    },
    "0025BA": {
        "oui_hex": "00-25-BA",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0025BB": {
        "oui_hex": "00-25-BB",
        "organization": "INNERINT Co., Ltd.",
        "address_1": "Dongyoung CentralTower #202, Geumjung-dong,",
        "address_2": "Gunpo-si  Kyunggi-do  430050",
        "country": "KR"
    },
    "0025B8": {
        "oui_hex": "00-25-B8",
        "organization": "Agile Communications, Inc.",
        "address_1": "810 Lawrence Dr",
        "address_2": "Thousand Oaks  California  91320",
        "country": "US"
    },
    "0025B1": {
        "oui_hex": "00-25-B1",
        "organization": "Maya-Creation Corporation",
        "address_1": "3F, Building M-10, Centre od Hi-Tech Ind. Dist.",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "0025A1": {
        "oui_hex": "00-25-A1",
        "organization": "Enalasys",
        "address_1": "250 Avenida Campillo",
        "address_2": "Calexico  California  92231",
        "country": "US"
    },
    "0025F3": {
        "oui_hex": "00-25-F3",
        "organization": "Nordwestdeutsche Zählerrevision",
        "address_1": "Ing. Aug. Knemeyer GmbH & Co. KG",
        "address_2": "Bad Laer  Niedersachsen  49196",
        "country": "DE"
    },
    "0025DD": {
        "oui_hex": "00-25-DD",
        "organization": "SUNNYTEK INFORMATION CO., LTD.",
        "address_1": "12F, NO. 88, HSIN-TE ROAD",
        "address_2": "TAIPEI HSIEN    241",
        "country": "TW"
    },
    "0025CE": {
        "oui_hex": "00-25-CE",
        "organization": "InnerSpace",
        "address_1": "PO Box 2186",
        "address_2": "Grand Rapids  MI  49501",
        "country": "US"
    },
    "002549": {
        "oui_hex": "00-25-49",
        "organization": "Jeorich Tech. Co.,Ltd.",
        "address_1": "4F., No.6, Ln. 70, Sec. 2, Academia Rd., Nangang District, Taipei City 115, Taiwan (R.O.C.)",
        "address_2": "Taipei  Taiwan  110",
        "country": "TW"
    },
    "002539": {
        "oui_hex": "00-25-39",
        "organization": "IfTA GmbH",
        "address_1": "Industriestraße 33",
        "address_2": "Groebenzell  Bavaria  82194",
        "country": "DE"
    },
    "002537": {
        "oui_hex": "00-25-37",
        "organization": "Runcom Technologies Ltd.",
        "address_1": "11 Moshe Levi Str. 11th Flr.",
        "address_2": "Rishon Le Zion    75658",
        "country": "IL"
    },
    "002538": {
        "oui_hex": "00-25-38",
        "organization": "Samsung Electronics Co., Ltd., Memory Division",
        "address_1": "San #16 Banwol-Dong, Taean-Gu",
        "address_2": "Hwasung City  Gyeonggi Do  445-701",
        "country": "KR"
    },
    "002544": {
        "oui_hex": "00-25-44",
        "organization": "LoJack Corporation",
        "address_1": "780 Dedham Street",
        "address_2": "Canton  MA  02021",
        "country": "US"
    },
    "002532": {
        "oui_hex": "00-25-32",
        "organization": "Digital Recorders",
        "address_1": "4018 Patriot Drive",
        "address_2": "Durham  NC  27709",
        "country": "US"
    },
    "00255D": {
        "oui_hex": "00-25-5D",
        "organization": "Morningstar Corporation",
        "address_1": "10611 Iron Bridge Road",
        "address_2": "Jessup  MD  20794",
        "country": "US"
    },
    "002558": {
        "oui_hex": "00-25-58",
        "organization": "MPEDIA",
        "address_1": "Shinyoung Tower 12F 246-2",
        "address_2": "Seongnam  Gyeonggi-do  463-824",
        "country": "KR"
    },
    "00254A": {
        "oui_hex": "00-25-4A",
        "organization": "RingCube Technologies, Inc.",
        "address_1": "100 West Evelyn Ave, Suite 210",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "00254F": {
        "oui_hex": "00-25-4F",
        "organization": "ELETTROLAB Srl",
        "address_1": "Via Dell'Industria 25",
        "address_2": "San Vendemiano  Treviso  31020",
        "country": "IT"
    },
    "002583": {
        "oui_hex": "00-25-83",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002591": {
        "oui_hex": "00-25-91",
        "organization": "NEXTEK, Inc.",
        "address_1": "410 Douglass Street",
        "address_2": "Reading  PA  19601",
        "country": "US"
    },
    "00258D": {
        "oui_hex": "00-25-8D",
        "organization": "Haier",
        "address_1": "No.1,Haier Road",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "002571": {
        "oui_hex": "00-25-71",
        "organization": "Zhejiang Tianle Digital Electric Co.,Ltd",
        "address_1": "No.8 Tianle Rd,Economic Development Zone",
        "address_2": "Shengzhou  Zhejiang  312400",
        "country": "CN"
    },
    "00259A": {
        "oui_hex": "00-25-9A",
        "organization": "CEStronics GmbH",
        "address_1": "Friedrichstraße 243",
        "address_2": "Velbert    42551",
        "country": "DE"
    },
    "002502": {
        "oui_hex": "00-25-02",
        "organization": "NaturalPoint",
        "address_1": "PO Box 2317",
        "address_2": "Corvallis  OR  97339",
        "country": "US"
    },
    "0024F8": {
        "oui_hex": "00-24-F8",
        "organization": "Technical Solutions Company Ltd.",
        "address_1": "Box 31750",
        "address_2": "Whitehorse  Yukon  Y1A 6L3",
        "country": "CA"
    },
    "0024F9": {
        "oui_hex": "00-24-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0024F2": {
        "oui_hex": "00-24-F2",
        "organization": "Uniphone Telecommunication Co., Ltd.",
        "address_1": "No. 25, Chu-Kung 3rd Lane, Chu-Hou Tsung, Jen-Wu Hsiang,",
        "address_2": "Kaohsiung Hsien    81448",
        "country": "TW"
    },
    "002514": {
        "oui_hex": "00-25-14",
        "organization": "PC Worth Int'l Co., Ltd.",
        "address_1": "18F, No.100, Sec. 1, Xintai 5th Rd., Xizhi Dist.,",
        "address_2": "New Taipei City  Taipei  22102",
        "country": "TW"
    },
    "00250B": {
        "oui_hex": "00-25-0B",
        "organization": "CENTROFACTOR  INC",
        "address_1": "Road Town, Tortola, P.O.Box 3161,",
        "address_2": "Tortola    194295",
        "country": "VG"
    },
    "002506": {
        "oui_hex": "00-25-06",
        "organization": "A.I. ANTITACCHEGGIO ITALIA SRL",
        "address_1": "VICOLO DELLE DAME 4",
        "address_2": "BOLOGNA    40124",
        "country": "IT"
    },
    "00251C": {
        "oui_hex": "00-25-1C",
        "organization": "EDT",
        "address_1": "1400 SW Compton",
        "address_2": "Beaverton  OR  97008",
        "country": "US"
    },
    "00251A": {
        "oui_hex": "00-25-1A",
        "organization": "Psiber Data Systems Inc.",
        "address_1": "7075-K Mission Gorge Rd",
        "address_2": "San Diego  CA  92120",
        "country": "US"
    },
    "0024E1": {
        "oui_hex": "00-24-E1",
        "organization": "Convey Computer Corp.",
        "address_1": "1302 E. Collins Blvd.",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0024EE": {
        "oui_hex": "00-24-EE",
        "organization": "Wynmax Inc.",
        "address_1": "18F., No. 75, Sec. 1, XinTai 5th  Rd.,",
        "address_2": "Xizhi  City,  Taipei County  221",
        "country": "TW"
    },
    "0024E3": {
        "oui_hex": "00-24-E3",
        "organization": "CAO Group",
        "address_1": "4628 West Skyhawk Drive",
        "address_2": "West Jordan  UT  84084",
        "country": "US"
    },
    "002507": {
        "oui_hex": "00-25-07",
        "organization": "ASTAK Inc.",
        "address_1": "1911 Hartog Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0024D9": {
        "oui_hex": "00-24-D9",
        "organization": "BICOM, Inc.",
        "address_1": "755 Main Street",
        "address_2": "Monroe  CT  06468",
        "country": "US"
    },
    "00248E": {
        "oui_hex": "00-24-8E",
        "organization": "Infoware ZRt.",
        "address_1": "Huseg u. 10/a",
        "address_2": "Budapest    1223",
        "country": "HU"
    },
    "002494": {
        "oui_hex": "00-24-94",
        "organization": "Shenzhen Baoxin Tech CO., Ltd.",
        "address_1": "6F Huale BLDG., Zhonghangbei Rd.,",
        "address_2": "Shenzhen  GuangDong  518028",
        "country": "CN"
    },
    "002489": {
        "oui_hex": "00-24-89",
        "organization": "Vodafone Omnitel N.V.",
        "address_1": "Via Jervis 13",
        "address_2": "10015  Ivrea  Torino",
        "country": "IT"
    },
    "00246F": {
        "oui_hex": "00-24-6F",
        "organization": "Onda Communication spa",
        "address_1": "via del lavoro 9",
        "address_2": "pordenone    33170",
        "country": "IT"
    },
    "002469": {
        "oui_hex": "00-24-69",
        "organization": "Smart Doorphones",
        "address_1": "Klipsenstraat 18A",
        "address_2": "Lokeren    9160",
        "country": "BE"
    },
    "00247F": {
        "oui_hex": "00-24-7F",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002475": {
        "oui_hex": "00-24-75",
        "organization": "Compass System(Embedded Dept.)",
        "address_1": "1403 ACE TechnoTower 8th",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "0024C3": {
        "oui_hex": "00-24-C3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0024B5": {
        "oui_hex": "00-24-B5",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0024B0": {
        "oui_hex": "00-24-B0",
        "organization": "ESAB AB",
        "address_1": "Box 8004",
        "address_2": "Göteborg    SE-402 77",
        "country": "SE"
    },
    "0024C4": {
        "oui_hex": "00-24-C4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00249D": {
        "oui_hex": "00-24-9D",
        "organization": "NES Technology Inc.",
        "address_1": "#205 ACE Technotower 10, 470-5 Gasan-dong",
        "address_2": "Seoul    153-789",
        "country": "KR"
    },
    "002464": {
        "oui_hex": "00-24-64",
        "organization": "Bridge Technologies Co AS",
        "address_1": "Mølleparken 4",
        "address_2": "Oslo    0459",
        "country": "NO"
    },
    "002462": {
        "oui_hex": "00-24-62",
        "organization": "Rayzone Corporation",
        "address_1": "#2008, B-Dong, Samho BLDG",
        "address_2": "Seoul    137-941",
        "country": "KR"
    },
    "002420": {
        "oui_hex": "00-24-20",
        "organization": "NetUP Inc.",
        "address_1": "Olof Palme st., 1, sect. 7",
        "address_2": "Moscow    119311",
        "country": "RU"
    },
    "00241E": {
        "oui_hex": "00-24-1E",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "00241F": {
        "oui_hex": "00-24-1F",
        "organization": "DCT-Delta GmbH",
        "address_1": "Bodanrückstraße 1",
        "address_2": "Bodman - Ludwigshafen  Baden-Württemberg  78351",
        "country": "DE"
    },
    "00240E": {
        "oui_hex": "00-24-0E",
        "organization": "Inventec Besta Co., Ltd.",
        "address_1": "10FL, No.36, Lane 513, Rui Guang Road, Nei Hu Dist.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "002460": {
        "oui_hex": "00-24-60",
        "organization": "Giaval Science Development Co. Ltd.",
        "address_1": "58 Bei Si Huan Xi Rd",
        "address_2": "  Beijing  100080",
        "country": "CN"
    },
    "00245C": {
        "oui_hex": "00-24-5C",
        "organization": "Design-Com Technologies Pty. Ltd.",
        "address_1": "14 Redland Drive",
        "address_2": "Mitcham  Victoria  3132",
        "country": "AU"
    },
    "00243D": {
        "oui_hex": "00-24-3D",
        "organization": "Emerson Appliance Motors and Controls",
        "address_1": "1901 South St.",
        "address_2": "Elgin  IL  60123",
        "country": "US"
    },
    "002437": {
        "oui_hex": "00-24-37",
        "organization": "Motorola - BSG",
        "address_1": "1101 Marina Village Pkwy",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "002444": {
        "oui_hex": "00-24-44",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002413": {
        "oui_hex": "00-24-13",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00244F": {
        "oui_hex": "00-24-4F",
        "organization": "Asantron Technologies Ltd.",
        "address_1": "3F-1, No.30 Jihe Rd., 111",
        "address_2": "Taipei    11166",
        "country": "TW"
    },
    "0023DD": {
        "oui_hex": "00-23-DD",
        "organization": "ELGIN S.A.",
        "address_1": "RUA BARAO DE CAMPINAS, 305",
        "address_2": "São Paulo    01201-901",
        "country": "BR"
    },
    "0023DE": {
        "oui_hex": "00-23-DE",
        "organization": "Ansync Inc.",
        "address_1": "4970 Robert J Matthews Pky",
        "address_2": "El Dorado Hills  CA  95762",
        "country": "US"
    },
    "0023D9": {
        "oui_hex": "00-23-D9",
        "organization": "Banner Engineering",
        "address_1": "9714 10th Ave. N.",
        "address_2": "Plymouth  MN  55441",
        "country": "US"
    },
    "0023DA": {
        "oui_hex": "00-23-DA",
        "organization": "Industrial Computer Source (Deutschland)GmbH",
        "address_1": "Marie-Curie-Straße 9",
        "address_2": "Pulheim  NRW  50259",
        "country": "DE"
    },
    "002405": {
        "oui_hex": "00-24-05",
        "organization": "Dilog Nordic AB",
        "address_1": "Faktorvägen 9",
        "address_2": "Kungsbacka  Halland  439 34",
        "country": "SE"
    },
    "0023E8": {
        "oui_hex": "00-23-E8",
        "organization": "Demco Corp.",
        "address_1": "#919, Doosan Venturedigm, 126-1",
        "address_2": "Anyang-Si  Kyungki-Do  431-070",
        "country": "US"
    },
    "0023E3": {
        "oui_hex": "00-23-E3",
        "organization": "Microtronic AG",
        "address_1": "Duennernstrasse 32",
        "address_2": "Oensingen  Solothurn  4702",
        "country": "CH"
    },
    "0023B7": {
        "oui_hex": "00-23-B7",
        "organization": "Q-Light Co., Ltd.",
        "address_1": "178-1 Woogye-Ri, Sangdong-Myun,",
        "address_2": "Gimhae-Si  GyungsangNam-Do  621-812",
        "country": "KR"
    },
    "0023FD": {
        "oui_hex": "00-23-FD",
        "organization": "AFT Atlas Fahrzeugtechnik GmbH",
        "address_1": "Gewerbestraße 14",
        "address_2": "Werdohl    58791",
        "country": "DE"
    },
    "0023EF": {
        "oui_hex": "00-23-EF",
        "organization": "Zuend Systemtechnik AG",
        "address_1": "Industriestrasse 8",
        "address_2": "Altstaetten  SG  9450",
        "country": "CH"
    },
    "0023AC": {
        "oui_hex": "00-23-AC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0023D8": {
        "oui_hex": "00-23-D8",
        "organization": "Ball-It Oy",
        "address_1": "Uusikatu 24 G 76",
        "address_2": "Oulu    90100",
        "country": "FI"
    },
    "00239F": {
        "oui_hex": "00-23-9F",
        "organization": "Institut für Prüftechnik",
        "address_1": "Schulstraße 3",
        "address_2": "Todtenweis  Bayern  86447",
        "country": "DE"
    },
    "00239D": {
        "oui_hex": "00-23-9D",
        "organization": "Mapower Electronics Co., Ltd",
        "address_1": "No. 50 Minquan Road",
        "address_2": "Taoyuan County    33846",
        "country": "TW"
    },
    "00239C": {
        "oui_hex": "00-23-9C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "002398": {
        "oui_hex": "00-23-98",
        "organization": "Vutlan sro",
        "address_1": "ul. Svornosti 43",
        "address_2": "Bratislava  BA  82 106",
        "country": "SK"
    },
    "00235B": {
        "oui_hex": "00-23-5B",
        "organization": "Gulfstream",
        "address_1": "32 Lummus Drive",
        "address_2": "Savannah  GA  31407",
        "country": "US"
    },
    "002359": {
        "oui_hex": "00-23-59",
        "organization": "Benchmark Electronics ( Thailand ) Public Company Limited",
        "address_1": "94 Moo 1, Hi-Tech Industrial Estate",
        "address_2": "Bang Pa-in  Ayudhaya  13160",
        "country": "TH"
    },
    "002357": {
        "oui_hex": "00-23-57",
        "organization": "Pitronot Technologies and Engineering P.T.E. Ltd.",
        "address_1": "8 Hatut st",
        "address_2": "Pardesiya    42815",
        "country": "IL"
    },
    "002355": {
        "oui_hex": "00-23-55",
        "organization": "Kinco Automation(Shanghai) Ltd.",
        "address_1": "Bldg1, No.1387, Zhangdong Road,",
        "address_2": "  Shanghai  201203",
        "country": "CN"
    },
    "002373": {
        "oui_hex": "00-23-73",
        "organization": "GridIron Systems, Inc.",
        "address_1": "726 Palomar Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "002367": {
        "oui_hex": "00-23-67",
        "organization": "UniControls a.s.",
        "address_1": "Krenicka 2257",
        "address_2": "Prague 10    100 00",
        "country": "CZ"
    },
    "002368": {
        "oui_hex": "00-23-68",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "00236E": {
        "oui_hex": "00-23-6E",
        "organization": "Burster GmbH & Co KG",
        "address_1": "Talstraße 1-5",
        "address_2": "Gernsbach  Baden-Württemberg  76593",
        "country": "DE"
    },
    "002366": {
        "oui_hex": "00-23-66",
        "organization": "Beijing Siasun Electronic System Co.,Ltd.",
        "address_1": "Rm.1018 Huatian Bldg, No.6 Bei Xiaomachang",
        "address_2": "Beijing    100038",
        "country": "CN"
    },
    "00238F": {
        "oui_hex": "00-23-8F",
        "organization": "NIDEC COPAL CORPORATION",
        "address_1": "2-18-10,SHIMURA",
        "address_2": "ITABASHI-KU  TOKYO  174-8550",
        "country": "JP"
    },
    "002380": {
        "oui_hex": "00-23-80",
        "organization": "Nanoteq",
        "address_1": " PO Box 7991",
        "address_2": "Centurion  Gauteng  0046",
        "country": "ZA"
    },
    "00233D": {
        "oui_hex": "00-23-3D",
        "organization": "Laird Technologies",
        "address_1": "Meesmannstrasse 103",
        "address_2": "Bochum    44807",
        "country": "DE"
    },
    "00233F": {
        "oui_hex": "00-23-3F",
        "organization": "Purechoice Inc",
        "address_1": "11481 Rupp Drive",
        "address_2": "Burnsville  MN  55337",
        "country": "US"
    },
    "00231B": {
        "oui_hex": "00-23-1B",
        "organization": "Danaher Motion - Kollmorgen",
        "address_1": "201 W. Rock Road",
        "address_2": "Radford  VA  24141",
        "country": "US"
    },
    "00231E": {
        "oui_hex": "00-23-1E",
        "organization": "Cezzer Multimedia Technologies",
        "address_1": "Pépinière d'entreprises CREATIC",
        "address_2": "Plouzané    29280",
        "country": "FR"
    },
    "00231F": {
        "oui_hex": "00-23-1F",
        "organization": "Guangda Electronic & Telecommunication Technology Development Co., Ltd.",
        "address_1": "#8 Gaopengdong Road, Gaoxin District",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "002270": {
        "oui_hex": "00-22-70",
        "organization": "ABK North America, LLC",
        "address_1": "440 North Wolfe Rd.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "002313": {
        "oui_hex": "00-23-13",
        "organization": "Qool Technologies Ltd.",
        "address_1": "Gotanda Chuo Bldg 8f, 2-3-5",
        "address_2": "Shinagawa-ku  Tokyo  141-0022",
        "country": "JP"
    },
    "002310": {
        "oui_hex": "00-23-10",
        "organization": "LNC Technology Co., Ltd.",
        "address_1": "19F, No. 78-2, Sec. 3, Taichung Kang Rd.",
        "address_2": "Taichung    40764",
        "country": "TW"
    },
    "0022CD": {
        "oui_hex": "00-22-CD",
        "organization": "Ared Technology Co., Ltd.",
        "address_1": "6F-8 No.83 Sec.1, Nankan Rd. Luzhu Shiang",
        "address_2": "Taoyuan County  Taiwan  33859",
        "country": "TW"
    },
    "0022CC": {
        "oui_hex": "00-22-CC",
        "organization": "SciLog, Inc.",
        "address_1": "8845 South Greenview Drive",
        "address_2": "Middleton  Wisconsin  53562",
        "country": "US"
    },
    "0022CB": {
        "oui_hex": "00-22-CB",
        "organization": "IONODES Inc.",
        "address_1": "4001 boulevard Industriel",
        "address_2": "Laval  Quebec  H7L4S3",
        "country": "CA"
    },
    "0022C6": {
        "oui_hex": "00-22-C6",
        "organization": "Sutus Inc",
        "address_1": "301-3999 Henning Drive",
        "address_2": "Burnaby  British Columbia  V5C 6P9",
        "country": "CA"
    },
    "0022E8": {
        "oui_hex": "00-22-E8",
        "organization": "Applition Co., Ltd.",
        "address_1": "509-1, Bundang Techno Park D-dong,",
        "address_2": "SeongNam  Kyunggi-do  463-760",
        "country": "KR"
    },
    "0022E9": {
        "oui_hex": "00-22-E9",
        "organization": "ProVision Communications",
        "address_1": "1 Portland Square",
        "address_2": "Bristol    BS2 8RR",
        "country": "GB"
    },
    "0022E6": {
        "oui_hex": "00-22-E6",
        "organization": "Intelligent Data",
        "address_1": "Edf. Inverinnova – Avda. Punto Mobi, 4. Parque Científico Tecnológico",
        "address_2": "Alcalá de Henares  Madrid  28805",
        "country": "ES"
    },
    "0022E3": {
        "oui_hex": "00-22-E3",
        "organization": "Amerigon",
        "address_1": "21680 Haggerty Road",
        "address_2": "Northville  Michigan  48167",
        "country": "US"
    },
    "0022EB": {
        "oui_hex": "00-22-EB",
        "organization": "Data Respons A/S",
        "address_1": "Ellekær 6",
        "address_2": "Herlev    2730",
        "country": "DK"
    },
    "0022EF": {
        "oui_hex": "00-22-EF",
        "organization": "iWDL Technologies",
        "address_1": "10522 Meinert Rd",
        "address_2": "Wexford  PA  15090",
        "country": "US"
    },
    "0022F2": {
        "oui_hex": "00-22-F2",
        "organization": "SunPower Corp",
        "address_1": "1414 Harbour Way South",
        "address_2": "Richmond  CA  94804",
        "country": "US"
    },
    "0022E2": {
        "oui_hex": "00-22-E2",
        "organization": "WABTEC Transit Division",
        "address_1": "130 Ridgeview Circle",
        "address_2": "Duncan  SC  29334",
        "country": "US"
    },
    "002301": {
        "oui_hex": "00-23-01",
        "organization": "Witron Technology Limited",
        "address_1": "6/F, Xin Rui Building, 32 Tao Hua Road, Futian Free Trade Zone,",
        "address_2": "  Shenzhen  86",
        "country": "CN"
    },
    "0022F7": {
        "oui_hex": "00-22-F7",
        "organization": "Conceptronic",
        "address_1": "Databankweg 7",
        "address_2": "AMERSFOORT  utrecht  3821 AL",
        "country": "NL"
    },
    "00230C": {
        "oui_hex": "00-23-0C",
        "organization": "CLOVER ELECTRONICS CO.,LTD.",
        "address_1": "AKENO 306-1",
        "address_2": "ISE City  MIE Prefecture  519-0501",
        "country": "JP"
    },
    "002334": {
        "oui_hex": "00-23-34",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0022C8": {
        "oui_hex": "00-22-C8",
        "organization": "Applied Instruments B.V.",
        "address_1": "Dynamoweg 3",
        "address_2": "Vlissingen  Zeeland  NL-4382WZ",
        "country": "NL"
    },
    "0022C0": {
        "oui_hex": "00-22-C0",
        "organization": "Shenzhen Forcelink Electronic Co, Ltd",
        "address_1": "2nd and 3rd floor, Hasse manufacture building, Hasee industrial park",
        "address_2": "Shenzhen  Guangdong  518112",
        "country": "CN"
    },
    "0022A6": {
        "oui_hex": "00-22-A6",
        "organization": "Sony Computer Entertainment America",
        "address_1": "919 East Hillsdale Blvd",
        "address_2": "Foster City  California  94404-2175",
        "country": "US"
    },
    "0022A7": {
        "oui_hex": "00-22-A7",
        "organization": "Tyco Electronics AMP GmbH",
        "address_1": "Amperestraße 12-14",
        "address_2": "Bensheim  Hessen  64625",
        "country": "DE"
    },
    "0022A1": {
        "oui_hex": "00-22-A1",
        "organization": "Huawei Symantec Technologies Co.,Ltd.",
        "address_1": "Building 1,The West Zone Science Park of UESTC,No.88,Tianchen Road",
        "address_2": "Chengdu  Sichuan  611731",
        "country": "CN"
    },
    "00229D": {
        "oui_hex": "00-22-9D",
        "organization": "PYUNG-HWA IND.CO.,LTD",
        "address_1": "230-1",
        "address_2": "HWASUNG-SI  KYUNGGI-DO  445-912",
        "country": "KR"
    },
    "002296": {
        "oui_hex": "00-22-96",
        "organization": "LinoWave Corporation",
        "address_1": "1001-101 Champlain Avenue",
        "address_2": "Burlington  Ontario  L7L 5Z4",
        "country": "CA"
    },
    "002244": {
        "oui_hex": "00-22-44",
        "organization": "Chengdu Linkon Communications Device Co., Ltd",
        "address_1": "5f-02, Juntong Building, No. 53,Shuangfeng Road, Wuhou District,",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "002250": {
        "oui_hex": "00-22-50",
        "organization": "Point Six Wireless, LLC",
        "address_1": "2333 Alumni Park Plaza",
        "address_2": "Lexington  KY  40517",
        "country": "US"
    },
    "00226F": {
        "oui_hex": "00-22-6F",
        "organization": "3onedata Technology Co. Ltd.",
        "address_1": "3/F, B/2, Jiuxiangling Industrial District, Xili Town, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "002278": {
        "oui_hex": "00-22-78",
        "organization": "Shenzhen  Tongfang Multimedia  Technology Co.,Ltd.",
        "address_1": "2f Sector D of TongFang Information Harbor",
        "address_2": "Nanshan District, Shenzhen  GuangDong  518058",
        "country": "CN"
    },
    "00227A": {
        "oui_hex": "00-22-7A",
        "organization": "Telecom Design",
        "address_1": "Za Remora",
        "address_2": "33170  Gradignan",
        "country": "FR"
    },
    "002260": {
        "oui_hex": "00-22-60",
        "organization": "AFREEY Inc.",
        "address_1": "6F, No.249, Chien I Road",
        "address_2": "Chung Ho City  Taipei County  235",
        "country": "TW"
    },
    "0021EF": {
        "oui_hex": "00-21-EF",
        "organization": "Kapsys",
        "address_1": "790 Av du Docteur Maurice Donat",
        "address_2": "06250 Mougins  Sophia Antipolis",
        "country": "FR"
    },
    "0021ED": {
        "oui_hex": "00-21-ED",
        "organization": "Telegesis",
        "address_1": "84 Station Road",
        "address_2": "Marlow  Bucks  SL7 1NX",
        "country": "GB"
    },
    "0021EB": {
        "oui_hex": "00-21-EB",
        "organization": "ESP SYSTEMS, LLC",
        "address_1": "1422 East Fourth Street",
        "address_2": "Charlotte  NC  28204",
        "country": "US"
    },
    "002237": {
        "oui_hex": "00-22-37",
        "organization": "Shinhint Group",
        "address_1": "Unit 1506, 15/F, Nanyang Plaza,, 57 Hung To Road,",
        "address_2": "",
        "country": "HK"
    },
    "00222F": {
        "oui_hex": "00-22-2F",
        "organization": "Open Grid Computing, Inc.",
        "address_1": "4030-1 West Braker Lane STE130",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0021F6": {
        "oui_hex": "00-21-F6",
        "organization": "Oracle Corporation",
        "address_1": "900 Chelmsford Street",
        "address_2": "Lowell  MA  01851",
        "country": "US"
    },
    "002206": {
        "oui_hex": "00-22-06",
        "organization": "Cyberdyne Inc.",
        "address_1": "504 @C49-2",
        "address_2": "Tsukuba-shi  Ibaraki-ken  305-0817",
        "country": "JP"
    },
    "002202": {
        "oui_hex": "00-22-02",
        "organization": "Excito Elektronik i Skåne AB",
        "address_1": "Box 126",
        "address_2": "Löddeköpinge    246 22",
        "country": "SE"
    },
    "002227": {
        "oui_hex": "00-22-27",
        "organization": "uv-electronic GmbH",
        "address_1": "Grosswiesenstraße 20",
        "address_2": "Durchhausen  Baden-Württemberg  78591",
        "country": "DE"
    },
    "00221E": {
        "oui_hex": "00-22-1E",
        "organization": "Media Devices Co., Ltd.",
        "address_1": "Rm1002 Ace TechnoTower(9th) 345-30",
        "address_2": "Seoul    153-802",
        "country": "KR"
    },
    "002225": {
        "oui_hex": "00-22-25",
        "organization": "Thales Avionics Ltd",
        "address_1": "86 Bushey Road",
        "address_2": "London    SW20 0JW",
        "country": "GB"
    },
    "002220": {
        "oui_hex": "00-22-20",
        "organization": "Mitac Technology Corp",
        "address_1": "9th Fl., #75, Min-sheng E. Road, Sec. 3,",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "00220E": {
        "oui_hex": "00-22-0E",
        "organization": "Indigo Security Co., Ltd.",
        "address_1": "2nd Floor, 277-169 Sungsoo2-Ga, Sungdong-Gu",
        "address_2": "Seoul    133-832",
        "country": "KR"
    },
    "002207": {
        "oui_hex": "00-22-07",
        "organization": "Inteno Broadband Technology AB",
        "address_1": "Stensätravägen 13",
        "address_2": "Skärholmen  SE  127 39",
        "country": "SE"
    },
    "00223E": {
        "oui_hex": "00-22-3E",
        "organization": "IRTrans GmbH",
        "address_1": "Einsteinstrasse 14",
        "address_2": "Unterschleissheim  BAYERN  85716",
        "country": "DE"
    },
    "0021CE": {
        "oui_hex": "00-21-CE",
        "organization": "NTC-Metrotek",
        "address_1": "9, Nevzorovoy street",
        "address_2": "Saint-Petersburg    192148",
        "country": "RU"
    },
    "0021CA": {
        "oui_hex": "00-21-CA",
        "organization": "ART System Co., Ltd.",
        "address_1": "Mobile Techno Bldg Room 910",
        "address_2": "Dae-Gu    702-020",
        "country": "KR"
    },
    "0021CB": {
        "oui_hex": "00-21-CB",
        "organization": "SMS TECNOLOGIA ELETRONICA LTDA",
        "address_1": "Av. Pirâmide, 661",
        "address_2": "DIADEMA  São Paulo  09970330",
        "country": "BR"
    },
    "0021C8": {
        "oui_hex": "00-21-C8",
        "organization": "LOHUIS Networks",
        "address_1": "2681 TV Monster",
        "address_2": "Votlaan 408  Votlaan  31",
        "country": "NL"
    },
    "0021DB": {
        "oui_hex": "00-21-DB",
        "organization": "Santachi Video Technology (Shenzhen) Co., Ltd.",
        "address_1": "Santachi Building,#14 Kaifeng Road,Meilin,",
        "address_2": "Shenzhen  Guangdong  518049",
        "country": "CN"
    },
    "0021BF": {
        "oui_hex": "00-21-BF",
        "organization": "Hitachi High-Tech Control Systems Corporation",
        "address_1": "500,Miyu-cho",
        "address_2": "Mito-shi  Ibaraki-ken  319-0316",
        "country": "JP"
    },
    "0021BC": {
        "oui_hex": "00-21-BC",
        "organization": "ZALA COMPUTER",
        "address_1": "EL BOUNI",
        "address_2": "ANNABA    23000",
        "country": "DZ"
    },
    "0021B4": {
        "oui_hex": "00-21-B4",
        "organization": "APRO MEDIA CO., LTD",
        "address_1": "#13-5,Dodang-Dong,Wonmi-Gu,",
        "address_2": "Bucheon-City  Kyunggi-Do  420-801",
        "country": "KR"
    },
    "0021A8": {
        "oui_hex": "00-21-A8",
        "organization": "Telephonics Corporation",
        "address_1": "815 Broad Hollow Road",
        "address_2": "Farmingdale  New York  11790",
        "country": "US"
    },
    "0021A9": {
        "oui_hex": "00-21-A9",
        "organization": "Mobilink Telecom Co.,Ltd",
        "address_1": "292-3 Sindang-ri, Sandong-myun",
        "address_2": "Gumi  Gyeongbuk  730-853",
        "country": "KR"
    },
    "00218D": {
        "oui_hex": "00-21-8D",
        "organization": "AP Router Ind. Eletronica LTDA",
        "address_1": "Av. Lomanto Junior, 1000",
        "address_2": "Ilheus  Bahia  45654-000",
        "country": "BR"
    },
    "002190": {
        "oui_hex": "00-21-90",
        "organization": "Goliath Solutions",
        "address_1": "3082 Sterling Circle",
        "address_2": "Boulder  Colorado  80301",
        "country": "US"
    },
    "002185": {
        "oui_hex": "00-21-85",
        "organization": "MICRO-STAR INT'L CO.,LTD.",
        "address_1": "No.69,Li-De St,Jung-Ho City",
        "address_2": "Taipei Hsien    235",
        "country": "TW"
    },
    "00219F": {
        "oui_hex": "00-21-9F",
        "organization": "SATEL OY",
        "address_1": "Meriniitynkatu 17",
        "address_2": "SALO  Lansi-Suomen Laani  24100",
        "country": "FI"
    },
    "002196": {
        "oui_hex": "00-21-96",
        "organization": "Telsey  S.p.A.",
        "address_1": "Viale dell'Industria, 1",
        "address_2": "Quinto  DiTreviso  31055",
        "country": "IT"
    },
    "002182": {
        "oui_hex": "00-21-82",
        "organization": "SandLinks Systems, Ltd.",
        "address_1": "P.O.Box 4629",
        "address_2": "Petah-Tiqwa  Israel  49277",
        "country": "IL"
    },
    "002183": {
        "oui_hex": "00-21-83",
        "organization": "ANDRITZ HYDRO GmbH",
        "address_1": "Eibesbrunnergasse 20",
        "address_2": "Vienna    1120",
        "country": "AT"
    },
    "0021DF": {
        "oui_hex": "00-21-DF",
        "organization": "Martin Christ GmbH",
        "address_1": "An der Unteren Soese 50",
        "address_2": "Osterode  Niedersachsen  37520",
        "country": "DE"
    },
    "0021D4": {
        "oui_hex": "00-21-D4",
        "organization": "Vollmer Werke GmbH",
        "address_1": "Maschinenfabrik",
        "address_2": "Biberach  Baden-Württemberg  88400",
        "country": "DE"
    },
    "0021D6": {
        "oui_hex": "00-21-D6",
        "organization": "LXI Consortium",
        "address_1": "P.O. Box 1016",
        "address_2": "Niwot  CO  80544-1016",
        "country": "US"
    },
    "0021A6": {
        "oui_hex": "00-21-A6",
        "organization": "Videotec Spa",
        "address_1": "Via Friuli,6",
        "address_2": "Schio  Vicenza  36015",
        "country": "IT"
    },
    "002159": {
        "oui_hex": "00-21-59",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "002155": {
        "oui_hex": "00-21-55",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002157": {
        "oui_hex": "00-21-57",
        "organization": "National Datacast, Inc.",
        "address_1": "2100 Crystal Drive, Suite 750",
        "address_2": "Arlington  VA  22202",
        "country": "US"
    },
    "00213B": {
        "oui_hex": "00-21-3B",
        "organization": "Berkshire Products, Inc",
        "address_1": "PO Box 2819",
        "address_2": "Cumming  GA  30028",
        "country": "US"
    },
    "002137": {
        "oui_hex": "00-21-37",
        "organization": "Bay Controls, LLC",
        "address_1": "6528 Weatherfield Ct",
        "address_2": "Maumee  OH  43537",
        "country": "US"
    },
    "002139": {
        "oui_hex": "00-21-39",
        "organization": "Escherlogic Inc.",
        "address_1": "1481 Rosebank Rd.",
        "address_2": "Pickering  Ontario  L1V 1P3",
        "country": "CA"
    },
    "00212C": {
        "oui_hex": "00-21-2C",
        "organization": "SemIndia System Private Limited",
        "address_1": "No. 1106/9, A.M Industrial Estate, Garvebhavipalya",
        "address_2": "Bangalore  Karnataka  560 068",
        "country": "IN"
    },
    "00212B": {
        "oui_hex": "00-21-2B",
        "organization": "MSA Auer",
        "address_1": "Thiemannstraße 1",
        "address_2": "Berlin    12059",
        "country": "DE"
    },
    "002174": {
        "oui_hex": "00-21-74",
        "organization": "AvaLAN Wireless",
        "address_1": "958 San Leandro Ave, Suite 900",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "002179": {
        "oui_hex": "00-21-79",
        "organization": "IOGEAR, Inc.",
        "address_1": "23 Hubble",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "002168": {
        "oui_hex": "00-21-68",
        "organization": "iVeia, LLC",
        "address_1": "51 Franklin Street",
        "address_2": "Annapolis  MD  21401",
        "country": "US"
    },
    "002150": {
        "oui_hex": "00-21-50",
        "organization": "EYEVIEW ELECTRONICS",
        "address_1": "3 Floor, No. 86, Kung Yeh 32 Road",
        "address_2": "TAICHUNG    407",
        "country": "TW"
    },
    "00214D": {
        "oui_hex": "00-21-4D",
        "organization": "Guangzhou Skytone Transmission Technology Com. Ltd.",
        "address_1": "3/F West, Block 4, Huangzhou",
        "address_2": "Guangzhou  Guangdong  510660",
        "country": "CN"
    },
    "00212A": {
        "oui_hex": "00-21-2A",
        "organization": "Audiovox Corporation",
        "address_1": "150 Marcus Blvd",
        "address_2": "Hauppauge  NY  11788",
        "country": "US"
    },
    "00215E": {
        "oui_hex": "00-21-5E",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "001FF6": {
        "oui_hex": "00-1F-F6",
        "organization": "PS Audio International",
        "address_1": "4826 Sterling Drive",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "002110": {
        "oui_hex": "00-21-10",
        "organization": "Clearbox Systems",
        "address_1": "Suite 2, Level 2",
        "address_2": "Macquarie Park  NSW  2113",
        "country": "AU"
    },
    "00210C": {
        "oui_hex": "00-21-0C",
        "organization": "Cymtec Systems, Inc.",
        "address_1": "10845 Olive Bouleveard",
        "address_2": "St Louis  MO  63141",
        "country": "US"
    },
    "00210B": {
        "oui_hex": "00-21-0B",
        "organization": "GEMINI TRAZE RFID PVT. LTD.",
        "address_1": "1, DR. RANGA ROAD",
        "address_2": "CHENNAI  TAMILNADU  600018",
        "country": "IN"
    },
    "001FDD": {
        "oui_hex": "00-1F-DD",
        "organization": "GDI LLC",
        "address_1": "One MidAmerica Plaza",
        "address_2": "Oakbrook Terrace  IL  60181",
        "country": "US"
    },
    "001FDA": {
        "oui_hex": "00-1F-DA",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002104": {
        "oui_hex": "00-21-04",
        "organization": "Gigaset Communications GmbH",
        "address_1": "Frankenstrasse 2",
        "address_2": "46395  Bocholt",
        "country": "DE"
    },
    "001FFB": {
        "oui_hex": "00-1F-FB",
        "organization": "Green Packet Bhd",
        "address_1": "Lot 1-4, Incubator 2, Technology Park Malaysia",
        "address_2": "Kuala Lumpur  Wilayah Persekutuan  57000",
        "country": "MY"
    },
    "001FE9": {
        "oui_hex": "00-1F-E9",
        "organization": "Printrex, Inc.",
        "address_1": "276 East Gish Road",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "001FF0": {
        "oui_hex": "00-1F-F0",
        "organization": "Audio Partnership",
        "address_1": "Gallery Court",
        "address_2": "London    SE1 4BB",
        "country": "GB"
    },
    "001FEA": {
        "oui_hex": "00-1F-EA",
        "organization": "Applied Media Technologies Corporation",
        "address_1": "4091 AMTC Center Drive",
        "address_2": "Clearwater  FL  33764",
        "country": "US"
    },
    "001FD9": {
        "oui_hex": "00-1F-D9",
        "organization": "RSD Communications Ltd",
        "address_1": "8 Borrowmeadow Road",
        "address_2": "Stirling  Scotland  FK7 7UW",
        "country": "GB"
    },
    "001FCE": {
        "oui_hex": "00-1F-CE",
        "organization": "QTECH LLC",
        "address_1": "Novozavodskaya st. 18 build. 1",
        "address_2": "Moscow  Moscow region  121309",
        "country": "RU"
    },
    "001F8B": {
        "oui_hex": "00-1F-8B",
        "organization": "Cache IQ",
        "address_1": "8834 North Capital of Texas Hwy",
        "address_2": "Austin  Texas  78759",
        "country": "US"
    },
    "001F85": {
        "oui_hex": "00-1F-85",
        "organization": "Apriva ISS, LLC",
        "address_1": "6900 E Camelback Rd",
        "address_2": "Scottsdale  AZ  85251",
        "country": "US"
    },
    "001F87": {
        "oui_hex": "00-1F-87",
        "organization": "Skydigital Inc.",
        "address_1": "#28-9 Wonhyoro1-ga, Yongsan-gu,",
        "address_2": "Seoul    140-846",
        "country": "KR"
    },
    "001F88": {
        "oui_hex": "00-1F-88",
        "organization": "FMS Force Measuring Systems AG",
        "address_1": "Aspstrasse 6",
        "address_2": "Oberglatt  Zurich  8154",
        "country": "CH"
    },
    "001F86": {
        "oui_hex": "00-1F-86",
        "organization": "digEcor",
        "address_1": "1625 N. 1100 W.",
        "address_2": "Springville  UT  84663",
        "country": "US"
    },
    "001FA1": {
        "oui_hex": "00-1F-A1",
        "organization": "Gtran Inc",
        "address_1": "2651 Lavery Court",
        "address_2": "Newbury Park  CA  91320",
        "country": "US"
    },
    "001F9F": {
        "oui_hex": "00-1F-9F",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "001F99": {
        "oui_hex": "00-1F-99",
        "organization": "SERONICS co.ltd",
        "address_1": "#401 Technopolis,",
        "address_2": "Daegu  Gyeong-buk  704-230",
        "country": "KR"
    },
    "001F80": {
        "oui_hex": "00-1F-80",
        "organization": "Lucas Holding bv",
        "address_1": "Domein 28",
        "address_2": "Gemert  NB  5421AR",
        "country": "NL"
    },
    "001B58": {
        "oui_hex": "00-1B-58",
        "organization": "ACE CAD Enterprise Co., Ltd.",
        "address_1": "2F, No. 94, Bao Chung Road,",
        "address_2": "Hsin Tien City,  Taipei Hsien  23144",
        "country": "TW"
    },
    "001FB0": {
        "oui_hex": "00-1F-B0",
        "organization": "TimeIPS, Inc.",
        "address_1": "3522 N Comotara St",
        "address_2": "Wichita  KS  67226",
        "country": "US"
    },
    "001FAE": {
        "oui_hex": "00-1F-AE",
        "organization": "Blick South Africa (Pty) Ltd",
        "address_1": "PO Box 1908",
        "address_2": "Johannesburg  Gauteng  2108",
        "country": "ZA"
    },
    "001F79": {
        "oui_hex": "00-1F-79",
        "organization": "Lodam Electronics A/S",
        "address_1": "Kærvej 77",
        "address_2": "Sønderborg  Als  DK-6400",
        "country": "DK"
    },
    "001F71": {
        "oui_hex": "00-1F-71",
        "organization": "xG Technology, Inc.",
        "address_1": "240 S. Pineapple Avenue",
        "address_2": "Sarasota  FL  34236",
        "country": "US"
    },
    "001FA5": {
        "oui_hex": "00-1F-A5",
        "organization": "Blue-White Industries",
        "address_1": "5300 Business Drive",
        "address_2": "Huntington Beach  CA  92649",
        "country": "US"
    },
    "001F9D": {
        "oui_hex": "00-1F-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F96": {
        "oui_hex": "00-1F-96",
        "organization": "APROTECH CO.LTD",
        "address_1": "KOLONDIGITAL TOWER ASTON 201, 505-14",
        "address_2": "SEOUL    KSXX 0022",
        "country": "KR"
    },
    "001F6C": {
        "oui_hex": "00-1F-6C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F6F": {
        "oui_hex": "00-1F-6F",
        "organization": "Fujian Sunnada Communication Co.,Ltd.",
        "address_1": "7/F Main Building,Fujian Torch Hi-Tech Innovation Park No.611 Industrial Road,Fuzhou Fuzhou Fujian China  350002",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "001F60": {
        "oui_hex": "00-1F-60",
        "organization": "COMPASS SYSTEMS CORP.",
        "address_1": "6F, No. 413, Sec. 2, Ti-Ding Blvd.,",
        "address_2": "Taipei  NeihuDist  114",
        "country": "TW"
    },
    "001F6A": {
        "oui_hex": "00-1F-6A",
        "organization": "PacketFlux Technologies, Inc.",
        "address_1": "50 11th Avenue",
        "address_2": "Helena  MT  59601",
        "country": "US"
    },
    "001F65": {
        "oui_hex": "00-1F-65",
        "organization": "KOREA ELECTRIC TERMINAL CO., LTD.",
        "address_1": "#7-38 SONGDO-DONG",
        "address_2": "YEONSU-GU  INCHEON  406-840",
        "country": "KR"
    },
    "001F17": {
        "oui_hex": "00-1F-17",
        "organization": "IDX Company, Ltd.",
        "address_1": "6-28-11 Shukugawara, Tana-ku",
        "address_2": "Kawasaki-Shi  Kanagawa-Ken  2140021",
        "country": "JP"
    },
    "001F1B": {
        "oui_hex": "00-1F-1B",
        "organization": "RoyalTek Company Ltd.",
        "address_1": "Suite 9F-1, No. 1071, Chung Cheng Rd.",
        "address_2": "Taoyuan Shien  Taoyuan  330",
        "country": "TW"
    },
    "001F5E": {
        "oui_hex": "00-1F-5E",
        "organization": "Dyna Technology Co.,Ltd.",
        "address_1": "HaoHai Building 1F,No.7,5th Street,Shangdi,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001F55": {
        "oui_hex": "00-1F-55",
        "organization": "Honeywell Security (China) Co., Ltd.",
        "address_1": "Block 28, Section 2, Huai  De Cui Gang Industrial  Estate, Fu Yong, Bao An, ShenZhen, P.R. China",
        "address_2": "ShenZhen  GuangDong  518103",
        "country": "CN"
    },
    "001F54": {
        "oui_hex": "00-1F-54",
        "organization": "Lorex Technology Inc.",
        "address_1": "250 Royal Crest Court",
        "address_2": "Markham  Ontario  L3R3S1",
        "country": "CA"
    },
    "001F2E": {
        "oui_hex": "00-1F-2E",
        "organization": "Triangle Research Int'l Pte Ltd",
        "address_1": "10 Ubi Crescent #05-83",
        "address_2": "Ubi Techpark  SG  408664",
        "country": "SG"
    },
    "001F4B": {
        "oui_hex": "00-1F-4B",
        "organization": "Lineage Power",
        "address_1": "3000 Skyline Dr.",
        "address_2": "Mesquite  TX  75149",
        "country": "US"
    },
    "001F0D": {
        "oui_hex": "00-1F-0D",
        "organization": "L3 Communications - Telemetry West",
        "address_1": "9020 Balboa Ave",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "001EFC": {
        "oui_hex": "00-1E-FC",
        "organization": "JSC MASSA-K",
        "address_1": "15, A, Pirogovskaya nab.",
        "address_2": "Saint-Petersburg  Leningradskiy reg.  194044",
        "country": "RU"
    },
    "001F23": {
        "oui_hex": "00-1F-23",
        "organization": "Interacoustics",
        "address_1": "Drejervaenget 8",
        "address_2": "Assens  DK  5610",
        "country": "DK"
    },
    "001F06": {
        "oui_hex": "00-1F-06",
        "organization": "Integrated Dispatch Solutions",
        "address_1": "645 Mountain Ave",
        "address_2": "Wyckoff  NJ  07481",
        "country": "US"
    },
    "001EBA": {
        "oui_hex": "00-1E-BA",
        "organization": "High Density Devices AS",
        "address_1": "Vestre Strandgate 26",
        "address_2": "Kristiansand    4611",
        "country": "NO"
    },
    "001EB8": {
        "oui_hex": "00-1E-B8",
        "organization": "Aloys, Inc",
        "address_1": "#3F HANWHA TECHWIN R&D BLDG. 4-5, YANGHYEON-RO 405 BEON-GIL,",
        "address_2": "JUNGWON-GU, SEONGNAM-SI  GYEONGGI-DO  13438",
        "country": "KR"
    },
    "001EB4": {
        "oui_hex": "00-1E-B4",
        "organization": "UNIFAT TECHNOLOGY LTD.",
        "address_1": "7/FLOOR, SUI HONG IND. BLDG.,",
        "address_2": "KWAI CHUNG  N.T.",
        "country": "HK"
    },
    "001EDA": {
        "oui_hex": "00-1E-DA",
        "organization": "Wesemann Elektrotechniek B.V.",
        "address_1": "Droogbloem 31",
        "address_2": "Rotterdam  Zuid-Holland  3068 AW",
        "country": "NL"
    },
    "001ED7": {
        "oui_hex": "00-1E-D7",
        "organization": "H-Stream Wireless, Inc.",
        "address_1": "2595 East Bayshore Road",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "001ED5": {
        "oui_hex": "00-1E-D5",
        "organization": "Tekon-Automatics",
        "address_1": "Zelenograd, 512-29",
        "address_2": "Moscow    124482",
        "country": "RU"
    },
    "001EE8": {
        "oui_hex": "00-1E-E8",
        "organization": "Mytek",
        "address_1": "151 Lafayette Str 3 Fl",
        "address_2": "New York  NY  10013",
        "country": "US"
    },
    "001EEE": {
        "oui_hex": "00-1E-EE",
        "organization": "ETL Systems Ltd",
        "address_1": "Coldwell Radio Station",
        "address_2": "Hereford  Herefordshire  HR2 9NE",
        "country": "GB"
    },
    "001EFA": {
        "oui_hex": "00-1E-FA",
        "organization": "PROTEI Ltd.",
        "address_1": "60A B.Sampsonievsky,  Business Center",
        "address_2": "St.Petersburg  RU  194044",
        "country": "RU"
    },
    "001EFB": {
        "oui_hex": "00-1E-FB",
        "organization": "Trio Motion Technology Ltd",
        "address_1": "Shannon Way",
        "address_2": "Tewkesbury  Gloucestershire  GL20 8ND",
        "country": "GB"
    },
    "001EF8": {
        "oui_hex": "00-1E-F8",
        "organization": "Emfinity Inc.",
        "address_1": "1305 Kelly Lake Road",
        "address_2": "Sudbury  Ontario  P3E5P5",
        "country": "CA"
    },
    "001ECB": {
        "oui_hex": "00-1E-CB",
        "organization": "RPC Energoautomatika Ltd",
        "address_1": "Krasnokazarmennaya st., 13/1",
        "address_2": "Moscow    111250",
        "country": "RU"
    },
    "001EA8": {
        "oui_hex": "00-1E-A8",
        "organization": "Datang Mobile Communications Equipment CO.,LTD",
        "address_1": "No.29,Xueyuan Rd.",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "001EAB": {
        "oui_hex": "00-1E-AB",
        "organization": "TeleWell Oy",
        "address_1": "Alahotie 14 b",
        "address_2": "Jarvenpaa  Uusimaa  04430",
        "country": "FI"
    },
    "001E9F": {
        "oui_hex": "00-1E-9F",
        "organization": "Visioneering Systems, Inc.",
        "address_1": "5931 Sea Lion Place",
        "address_2": "Carlsbad  California  92010",
        "country": "US"
    },
    "001E6B": {
        "oui_hex": "00-1E-6B",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001E70": {
        "oui_hex": "00-1E-70",
        "organization": "Cobham Antenna Systems",
        "address_1": "Cobham Centre, Fourth Avenue",
        "address_2": "Marlow  Buckinghamshire  SL7 1TF",
        "country": "GB"
    },
    "001E61": {
        "oui_hex": "00-1E-61",
        "organization": "ITEC GmbH",
        "address_1": "Lassnitzthal 300",
        "address_2": "  A-8200   Gleisdorf",
        "country": "AT"
    },
    "001E3E": {
        "oui_hex": "00-1E-3E",
        "organization": "KMW Inc.",
        "address_1": "65 Youngchun-ri, Dongtan-myun",
        "address_2": "Hwasung-si  Kyungki-do  445-813",
        "country": "KR"
    },
    "001E38": {
        "oui_hex": "00-1E-38",
        "organization": "Bluecard Software Technology Co., Ltd.",
        "address_1": "D-801 Shangdi Science Building",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001E47": {
        "oui_hex": "00-1E-47",
        "organization": "PT. Hariff Daya Tunggal Engineering",
        "address_1": "Jl. Soekarno Hatta No. 450",
        "address_2": "Bandung  Jawa Barat  40266",
        "country": "ID"
    },
    "001E48": {
        "oui_hex": "00-1E-48",
        "organization": "Wi-Links",
        "address_1": "332 Ayiou street",
        "address_2": "Limassol    3725",
        "country": "CY"
    },
    "001E8A": {
        "oui_hex": "00-1E-8A",
        "organization": "eCopy, Inc",
        "address_1": "1 Oracle Dr",
        "address_2": "Nashua  NH  03062",
        "country": "US"
    },
    "001E9B": {
        "oui_hex": "00-1E-9B",
        "organization": "San-Eisha, Ltd.",
        "address_1": "2-1 Ebara 5-chome",
        "address_2": "Shinagawa-ku  Tokyo  142-8611",
        "country": "JP"
    },
    "001E96": {
        "oui_hex": "00-1E-96",
        "organization": "Sepura Plc",
        "address_1": "Radio House",
        "address_2": "Cambridge  CAMBRIDGESHIRE  CB4 1GR",
        "country": "GB"
    },
    "001E59": {
        "oui_hex": "00-1E-59",
        "organization": "Silicon Turnkey Express, LLC",
        "address_1": "749 Miner Road",
        "address_2": "Highland Heights  Ohio  44143",
        "country": "US"
    },
    "001E51": {
        "oui_hex": "00-1E-51",
        "organization": "Converter Industry Srl",
        "address_1": "Via Euclide, 12",
        "address_2": "Forli'  FC  47100",
        "country": "IT"
    },
    "001E71": {
        "oui_hex": "00-1E-71",
        "organization": "MIrcom Group of Companies",
        "address_1": "25 Interchange Way",
        "address_2": "  Vaughan, Ontario  l4K 5W3",
        "country": "CA"
    },
    "001DC4": {
        "oui_hex": "00-1D-C4",
        "organization": "AIOI Systems Co., Ltd.",
        "address_1": "KDX Omori, Bldg 8F",
        "address_2": "Tokyo    140-0016",
        "country": "JP"
    },
    "001DC0": {
        "oui_hex": "00-1D-C0",
        "organization": "Enphase Energy",
        "address_1": "201 1st Street, Suite 111",
        "address_2": "Petaluma  CA  94952",
        "country": "US"
    },
    "001DBD": {
        "oui_hex": "00-1D-BD",
        "organization": "Versamed Inc.",
        "address_1": "2 Blue Hill Plaza",
        "address_2": "Pearl River  NY  10965",
        "country": "US"
    },
    "001DF8": {
        "oui_hex": "00-1D-F8",
        "organization": "Webpro Vision Technology Corporation",
        "address_1": "4F., No.573, Cingping Rd.",
        "address_2": "Anping District    708",
        "country": "TW"
    },
    "001DF9": {
        "oui_hex": "00-1D-F9",
        "organization": "Cybiotronics (Far East) Limited",
        "address_1": "Unit 1906, Eastern Centre,",
        "address_2": "Quarry Bay",
        "country": "HK"
    },
    "001DF7": {
        "oui_hex": "00-1D-F7",
        "organization": "R. STAHL Schaltgeräte GmbH",
        "address_1": "am Bahnhof 30",
        "address_2": "Waldenburg  Baden-Württemberg  74638",
        "country": "DE"
    },
    "001E05": {
        "oui_hex": "00-1E-05",
        "organization": "Xseed Technologies & Computing",
        "address_1": "Topaz House, MATAM",
        "address_2": "Haifa    39100",
        "country": "IL"
    },
    "001E07": {
        "oui_hex": "00-1E-07",
        "organization": "Winy Technology Co., Ltd.",
        "address_1": "305-303, Bucheon Techno-park, #365",
        "address_2": "Bucheon  Gyeonggi-do  421-741",
        "country": "KR"
    },
    "001E0A": {
        "oui_hex": "00-1E-0A",
        "organization": "Syba Tech Limited",
        "address_1": "RM1301, Vanta Industrial Centre,",
        "address_2": "Kwai Chung",
        "country": "HK"
    },
    "001E03": {
        "oui_hex": "00-1E-03",
        "organization": "LiComm Co., Ltd.",
        "address_1": "908-1 SEO-RI, IDONG-MYEON",
        "address_2": "YONGIN-SI  GYEONGGI-DO  449-834",
        "country": "KR"
    },
    "001E1B": {
        "oui_hex": "00-1E-1B",
        "organization": "Digital Stream Technology, Inc.",
        "address_1": "4,5,6th Fl., TaeChang B/D, 451-1",
        "address_2": "Seoul    134-030",
        "country": "KR"
    },
    "001E17": {
        "oui_hex": "00-1E-17",
        "organization": "STN BV",
        "address_1": "Amerikaweg 4",
        "address_2": "Hulst  Zeeland  4561 PB",
        "country": "NL"
    },
    "001E18": {
        "oui_hex": "00-1E-18",
        "organization": "Radio Activity srl",
        "address_1": "Via De Notaris 50",
        "address_2": "Milano  MI  20128",
        "country": "IT"
    },
    "001E15": {
        "oui_hex": "00-1E-15",
        "organization": "Beech Hill Electronics",
        "address_1": "Beechcroft, Beech Hill Road",
        "address_2": "Reading  Berkshire  RG7 2AU",
        "country": "GB"
    },
    "001E30": {
        "oui_hex": "00-1E-30",
        "organization": "Shireen Inc",
        "address_1": "8531 Ziggy Lane",
        "address_2": "Gaithersburg  MD  20877",
        "country": "US"
    },
    "001E2E": {
        "oui_hex": "00-1E-2E",
        "organization": "SIRTI S.p.A.",
        "address_1": "Via Bombrini 11/3",
        "address_2": "GENOA    16149",
        "country": "IT"
    },
    "001DDC": {
        "oui_hex": "00-1D-DC",
        "organization": "HangZhou DeChangLong Tech&Info Co.,Ltd",
        "address_1": "Room 1102,KeJi Mansion,",
        "address_2": "HangZhou  ZheJiang  310012",
        "country": "CN"
    },
    "001DEB": {
        "oui_hex": "00-1D-EB",
        "organization": "DINEC International",
        "address_1": "Rue de la Gare, 30",
        "address_2": "BRAINE L'ALLEUD  BRABANT WALLON  1420",
        "country": "BE"
    },
    "001D9A": {
        "oui_hex": "00-1D-9A",
        "organization": "GODEX INTERNATIONAL CO., LTD",
        "address_1": "4F. NO.168, Lian-Cheng Road Chung-Ho City,",
        "address_2": "Taipei  Hsien  235",
        "country": "US"
    },
    "001D97": {
        "oui_hex": "00-1D-97",
        "organization": "Alertus Technologies LLC",
        "address_1": "11785 Beltsville Drive",
        "address_2": "Beltsville  MD  20705",
        "country": "US"
    },
    "001D91": {
        "oui_hex": "00-1D-91",
        "organization": "Digitize, Inc",
        "address_1": "158 Edison Road",
        "address_2": "Lake Hopatcong  New Jersey  07849",
        "country": "US"
    },
    "001D95": {
        "oui_hex": "00-1D-95",
        "organization": "Flash, Inc.",
        "address_1": "3703 N. 200th St.",
        "address_2": "Elkhorn  NE  68022-2922",
        "country": "US"
    },
    "001D9D": {
        "oui_hex": "00-1D-9D",
        "organization": "ARTJOY INTERNATIONAL LIMITED",
        "address_1": "Room 1601,No.239 ZhongXing Road,LuoHu District",
        "address_2": "Shenzhen  Guangdong  518001",
        "country": "CN"
    },
    "001D9E": {
        "oui_hex": "00-1D-9E",
        "organization": "AXION TECHNOLOGIES",
        "address_1": "151 RUE PARC INNOVATION",
        "address_2": "LA POCATIERE  QUEBEC  G0R1Z0",
        "country": "US"
    },
    "001D70": {
        "oui_hex": "00-1D-70",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D78": {
        "oui_hex": "00-1D-78",
        "organization": "Invengo Information Technology Co.,Ltd",
        "address_1": "3/F,No.T2-B,High-Tech Industrial Park South",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001D6F": {
        "oui_hex": "00-1D-6F",
        "organization": "Chainzone Technology Co., Ltd",
        "address_1": "Chainzone Tech. Ind Park, Nanxin 1st Rd.",
        "address_2": "Foshan  Guangdong  528200",
        "country": "CN"
    },
    "001D7F": {
        "oui_hex": "00-1D-7F",
        "organization": "Tekron International Ltd",
        "address_1": "409 Cuba Street, Alicetown",
        "address_2": "Lower Hutt  Wellington  5010",
        "country": "NZ"
    },
    "001D79": {
        "oui_hex": "00-1D-79",
        "organization": "SIGNAMAX LLC",
        "address_1": "1090 Vermont Avenue",
        "address_2": "Washington  Washington D.C.  20005",
        "country": "US"
    },
    "001DAE": {
        "oui_hex": "00-1D-AE",
        "organization": "CHANG TSENG TECHNOLOGY CO., LTD",
        "address_1": "2F NO.160 BACK BUILDING, LEN CHENG RD., CHUNG HO CITY",
        "address_2": "TAIPEI  HSIEN  235",
        "country": "TW"
    },
    "001DA6": {
        "oui_hex": "00-1D-A6",
        "organization": "Media Numerics Limited",
        "address_1": "Rodenbacher Chaussee 6",
        "address_2": "Hanau  Hessen  63457",
        "country": "DE"
    },
    "001D62": {
        "oui_hex": "00-1D-62",
        "organization": "InPhase Technologies",
        "address_1": "2000 Pike Road",
        "address_2": "Longmont  Colorado  80501",
        "country": "US"
    },
    "001D63": {
        "oui_hex": "00-1D-63",
        "organization": "Miele & Cie. KG",
        "address_1": "Carl-Miele-Straße 29",
        "address_2": "Gütersloh    33332",
        "country": "DE"
    },
    "001DB7": {
        "oui_hex": "00-1D-B7",
        "organization": "Tendril Networks, Inc.",
        "address_1": "5700-D Flatiron Parkway",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "001D8D": {
        "oui_hex": "00-1D-8D",
        "organization": "Fluke Process Instruments GmbH",
        "address_1": "Blankenburger Str. 135",
        "address_2": "Berlin    13127",
        "country": "DE"
    },
    "001D1F": {
        "oui_hex": "00-1D-1F",
        "organization": "Siauliu Tauro Televizoriai, JSC",
        "address_1": "Pramones,15",
        "address_2": "Siauliai    LT-57318",
        "country": "LT"
    },
    "001D43": {
        "oui_hex": "00-1D-43",
        "organization": "Shenzhen G-link Digital Technology Co., Ltd.",
        "address_1": "4F, E Building,Huachuang Da Technology Zone ,Hangcheng Highway,Gushu,Xixiang ,",
        "address_2": "shenzhen  GuangDong  518126",
        "country": "CN"
    },
    "001D3F": {
        "oui_hex": "00-1D-3F",
        "organization": "Mitron Pty Ltd",
        "address_1": "Unit 11",
        "address_2": "Artarmon  NSW  2065",
        "country": "AU"
    },
    "001D39": {
        "oui_hex": "00-1D-39",
        "organization": "MOOHADIGITAL CO., LTD",
        "address_1": "Seoul Hightech Venture Center C-307 647-26",
        "address_2": "SEOUL    157-030",
        "country": "KR"
    },
    "001D37": {
        "oui_hex": "00-1D-37",
        "organization": "Thales-Panda Transportation System",
        "address_1": "6th floor, HUIJIE Plaza, 268 Zhongshan Rd.",
        "address_2": "nanjing  jiangsu  210008",
        "country": "CN"
    },
    "001D13": {
        "oui_hex": "00-1D-13",
        "organization": "NextGTV",
        "address_1": "13F Byucksan/Kyungin Digital Valley ll",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "001D14": {
        "oui_hex": "00-1D-14",
        "organization": "SPERADTONE INFORMATION TECHNOLOGY LIMITED",
        "address_1": "Room 1001 NO.418 Gui Ping Road,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "001D10": {
        "oui_hex": "00-1D-10",
        "organization": "LightHaus Logic, Inc.",
        "address_1": "126-1020 Mainland Street",
        "address_2": "Vancouver  BC  V6B 2T4",
        "country": "CA"
    },
    "001D04": {
        "oui_hex": "00-1D-04",
        "organization": "Zipit Wireless, Inc.",
        "address_1": "49 Salters Road.",
        "address_2": "Greenville  SC  29607",
        "country": "US"
    },
    "001CF2": {
        "oui_hex": "00-1C-F2",
        "organization": "Tenlon Technology Co.,Ltd.",
        "address_1": "4/F.,Shenhua Bldg,No.3155,Binhe Road,Futian District",
        "address_2": "Shenzhen  Guangdong  518033",
        "country": "CN"
    },
    "001D30": {
        "oui_hex": "00-1D-30",
        "organization": "YX Wireless S.A.",
        "address_1": "Av. Vicuña Mackenna #4860",
        "address_2": "Santiago    8580710",
        "country": "US"
    },
    "001CB2": {
        "oui_hex": "00-1C-B2",
        "organization": "BPT SPA",
        "address_1": "Via Stazione,48",
        "address_2": "Sesto al Reghena  Pordenone  33079",
        "country": "IT"
    },
    "001CB5": {
        "oui_hex": "00-1C-B5",
        "organization": "Neihua Network Technology Co.,LTD.(NHN)",
        "address_1": "Plot Xinmei Road 102-Q,New District",
        "address_2": "WuXi  Jiangsu  214028",
        "country": "CN"
    },
    "001CB4": {
        "oui_hex": "00-1C-B4",
        "organization": "Iridium Satellite LLC",
        "address_1": "8440 S. River Parkway",
        "address_2": "Tempe  AZ  85284",
        "country": "US"
    },
    "001CB6": {
        "oui_hex": "00-1C-B6",
        "organization": "Duzon CNT Co., Ltd.",
        "address_1": "14th Floor, IRE building 2",
        "address_2": "Seoul    150-967",
        "country": "KR"
    },
    "001CC7": {
        "oui_hex": "00-1C-C7",
        "organization": "Rembrandt Technologies, LLC d/b/a REMSTREAM",
        "address_1": "140 South Beverly Drive",
        "address_2": "Beverly Hills  CA  90212",
        "country": "US"
    },
    "001CBB": {
        "oui_hex": "00-1C-BB",
        "organization": "MusicianLink",
        "address_1": "2401 Cory Ave.",
        "address_2": "San Jose  CA  95128",
        "country": "US"
    },
    "001C8D": {
        "oui_hex": "00-1C-8D",
        "organization": "Mesa Imaging",
        "address_1": "Badenerstrasse 569",
        "address_2": "Zürich  ZH  8048",
        "country": "CH"
    },
    "001C89": {
        "oui_hex": "00-1C-89",
        "organization": "Force Communications, Inc.",
        "address_1": "3810 Arbordale Lane",
        "address_2": "Sachse  TX  75048",
        "country": "US"
    },
    "001C87": {
        "oui_hex": "00-1C-87",
        "organization": "Uriver Inc.",
        "address_1": "3rd., Fl., Bogwang Bldg., Poi-dong, 238-7 Gangnam-gu,",
        "address_2": "Seoul    135-964",
        "country": "KR"
    },
    "001CCD": {
        "oui_hex": "00-1C-CD",
        "organization": "Alektrona Corporation",
        "address_1": "95 Hathaway Street, Suite 10",
        "address_2": "Providence  RI  02907",
        "country": "US"
    },
    "001CEC": {
        "oui_hex": "00-1C-EC",
        "organization": "Mobilesoft (Aust.) Pty Ltd",
        "address_1": "Suite 2, 27-35 Grosvenor Street",
        "address_2": "Sydney  NSW  2089",
        "country": "AU"
    },
    "001CE8": {
        "oui_hex": "00-1C-E8",
        "organization": "Cummins Inc",
        "address_1": "1400 73rd Ave NE",
        "address_2": "Fridley  MN  55432",
        "country": "US"
    },
    "001CD0": {
        "oui_hex": "00-1C-D0",
        "organization": "Circleone Co.,Ltd.",
        "address_1": "860-1,Noda",
        "address_2": "Beppu-shi  Ooita-ken  874-0016",
        "country": "JP"
    },
    "001C9F": {
        "oui_hex": "00-1C-9F",
        "organization": "Razorstream, LLC",
        "address_1": "2381-C Renaissance Drive",
        "address_2": "Las Vegas  NV  89119",
        "country": "US"
    },
    "001C7D": {
        "oui_hex": "00-1C-7D",
        "organization": "Excelpoint Manufacturing Pte Ltd",
        "address_1": "15, Changi Business Park",
        "address_2": "    486057",
        "country": "SG"
    },
    "001C5C": {
        "oui_hex": "00-1C-5C",
        "organization": "Integrated Medical Systems, Inc.",
        "address_1": "1984 Obispo Avenue",
        "address_2": "Signal Hill  CA  90755",
        "country": "US"
    },
    "001C52": {
        "oui_hex": "00-1C-52",
        "organization": "VISIONEE SRL",
        "address_1": "VIALE DELLA REPUBBLICA, 22",
        "address_2": "VILLORBA  TREVISO  31050",
        "country": "IT"
    },
    "001C47": {
        "oui_hex": "00-1C-47",
        "organization": "Hangzhou Hollysys Automation Co., Ltd",
        "address_1": "No.10 Middle Road, Jiancaicheng, Haidian District,",
        "address_2": "Beijing    100096",
        "country": "CN"
    },
    "001C16": {
        "oui_hex": "00-1C-16",
        "organization": "ThyssenKrupp Elevator",
        "address_1": "9280 Crestwyn Hills Drive",
        "address_2": "Memphis  TN  38125",
        "country": "US"
    },
    "001C19": {
        "oui_hex": "00-1C-19",
        "organization": "secunet Security Networks AG",
        "address_1": "Kronprinzenstraße 30",
        "address_2": "Essen  NRW  45128",
        "country": "DE"
    },
    "001C6C": {
        "oui_hex": "00-1C-6C",
        "organization": "30805",
        "address_1": "128, Jun Cheng Road,uangzhou Economic and Technological Development District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "001C61": {
        "oui_hex": "00-1C-61",
        "organization": "Galaxy  Microsystems LImited",
        "address_1": "Room 1101-03, 11/F Enterprise Square Two",
        "address_2": "Kowloon Bay  Kowloon",
        "country": "HK"
    },
    "001C3B": {
        "oui_hex": "00-1C-3B",
        "organization": "AmRoad Technology Inc.",
        "address_1": "18F-3 No. 150 , Chien I Rd",
        "address_2": "Chung Ho  Taipei Hsien  23511",
        "country": "TW"
    },
    "001C3F": {
        "oui_hex": "00-1C-3F",
        "organization": "International Police Technologies, Inc.",
        "address_1": "4150 S. 87th E. Avenue",
        "address_2": "Tulsa  OK  74145",
        "country": "US"
    },
    "001C28": {
        "oui_hex": "00-1C-28",
        "organization": "Sphairon Technologies GmbH",
        "address_1": "Philipp-Reis-Strasse 1",
        "address_2": "Bautzen  Saxony  02625",
        "country": "DE"
    },
    "001C1F": {
        "oui_hex": "00-1C-1F",
        "organization": "Quest Retail Technology Pty Ltd",
        "address_1": "37-39 Walsh Street",
        "address_2": "Thebarton  SA  5031",
        "country": "AU"
    },
    "001C32": {
        "oui_hex": "00-1C-32",
        "organization": "Telian Corporation",
        "address_1": "4FL. Namjeon Bldg. 53-3 Haandong",
        "address_2": "Kwangmyungsi  Kyoungkido  423060",
        "country": "KR"
    },
    "001C2B": {
        "oui_hex": "00-1C-2B",
        "organization": "Alertme.com Limited",
        "address_1": "30 Station Road",
        "address_2": "Cambridge  Cambridgeshire  CB1 2RE",
        "country": "GB"
    },
    "001C77": {
        "oui_hex": "00-1C-77",
        "organization": "Prodys",
        "address_1": "C/Trigo 54 Pol. Ind. Polvoranca",
        "address_2": "Leganes  MADRID  28914",
        "country": "ES"
    },
    "001C6F": {
        "oui_hex": "00-1C-6F",
        "organization": "Emfit Ltd",
        "address_1": "Konttisentie 8 B",
        "address_2": "Vaajakoski    40800",
        "country": "FI"
    },
    "001C49": {
        "oui_hex": "00-1C-49",
        "organization": "Zoltan Technology Inc.",
        "address_1": "4F, No.30, Wunsi St.",
        "address_2": "Jhubei  Hsinchu  302",
        "country": "TW"
    },
    "001C63": {
        "oui_hex": "00-1C-63",
        "organization": "TRUEN",
        "address_1": "4F SAMWON BLDG., 451-7",
        "address_2": "SEOUL    137-818",
        "country": "KR"
    },
    "001BDF": {
        "oui_hex": "00-1B-DF",
        "organization": "Iskra Sistemi d.d.",
        "address_1": "Stegne 21",
        "address_2": "Ljubljana  Slovenia  1000",
        "country": "SI"
    },
    "001BD9": {
        "oui_hex": "00-1B-D9",
        "organization": "Edgewater Wireless Systems Inc",
        "address_1": "50 HInes Road Suite 200",
        "address_2": "Ottawa  Ontario  K2K-2M5",
        "country": "CA"
    },
    "001BC7": {
        "oui_hex": "00-1B-C7",
        "organization": "StarVedia Technology Inc.",
        "address_1": "3F, No. 247, Done Sec. 1, Guangming 6th Rd.",
        "address_2": "Jhubei  Hsin-Chu County  302",
        "country": "TW"
    },
    "001BEC": {
        "oui_hex": "00-1B-EC",
        "organization": "Netio Technologies Co., Ltd",
        "address_1": "4F-1, No. 582, Rueiguang Rd., Neihu District",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "001C09": {
        "oui_hex": "00-1C-09",
        "organization": "SAE Electronic Co.,Ltd.",
        "address_1": "23/F,Ying Long Zhan Ye Building,",
        "address_2": "Shenzhen  Guang Dong  518040",
        "country": "CN"
    },
    "001C0C": {
        "oui_hex": "00-1C-0C",
        "organization": "TANITA Corporation",
        "address_1": "1-14-2,Maeno-cho",
        "address_2": "Tokyo    174-8630",
        "country": "JP"
    },
    "001BA6": {
        "oui_hex": "00-1B-A6",
        "organization": "intotech inc.",
        "address_1": " 13F DMC R&D Center E3-2 Building Land Development District Sangam-Dong",
        "address_2": "Mapogu  Seoul  121-270",
        "country": "KR"
    },
    "001BA4": {
        "oui_hex": "00-1B-A4",
        "organization": "S.A.E Afikim",
        "address_1": "Kibutz Afikim",
        "address_2": "Kibutz Afikim    15148",
        "country": "IL"
    },
    "001BB4": {
        "oui_hex": "00-1B-B4",
        "organization": "Airvod Limited",
        "address_1": "Heather House",
        "address_2": "Sandyford Ind Est  Dublin 18  D18",
        "country": "IE"
    },
    "001BB6": {
        "oui_hex": "00-1B-B6",
        "organization": "Bird Electronic Corp.",
        "address_1": "30303 Aurora Road",
        "address_2": "Solon  Ohio  44139",
        "country": "US"
    },
    "001BE8": {
        "oui_hex": "00-1B-E8",
        "organization": "Ultratronik GmbH",
        "address_1": "Dornierstr. 9",
        "address_2": "Gilching    822205",
        "country": "DE"
    },
    "001BE1": {
        "oui_hex": "00-1B-E1",
        "organization": "ViaLogy",
        "address_1": "2400 Lincoln Ave",
        "address_2": "Altadena  CA  91001",
        "country": "US"
    },
    "001B93": {
        "oui_hex": "00-1B-93",
        "organization": "JC Decaux SA DNT",
        "address_1": "21 rue claude Bernard",
        "address_2": "MAUREPAS    78310",
        "country": "FR"
    },
    "001B9B": {
        "oui_hex": "00-1B-9B",
        "organization": "Hose-McCann Communications",
        "address_1": "1241 West Newport Center Drive",
        "address_2": "Deerfield Beach  FL  33442",
        "country": "US"
    },
    "001B9C": {
        "oui_hex": "00-1B-9C",
        "organization": "SATEL sp. z o.o.",
        "address_1": "Schuberta 79",
        "address_2": "Gdansk  pomorskie  80-172",
        "country": "PL"
    },
    "001B92": {
        "oui_hex": "00-1B-92",
        "organization": "l-acoustics",
        "address_1": "parc de la fontaine de jouvence",
        "address_2": "marcoussis  essonne  91462",
        "country": "FR"
    },
    "001B8E": {
        "oui_hex": "00-1B-8E",
        "organization": "Hulu Sweden AB",
        "address_1": "Box 12328, 10228",
        "address_2": "Kista  Stockholm  164 40",
        "country": "SE"
    },
    "001B45": {
        "oui_hex": "00-1B-45",
        "organization": "ABB AS, Division Automation Products",
        "address_1": "Bergerveien 12",
        "address_2": "Billingstad    NO-1375",
        "country": "NO"
    },
    "001B3F": {
        "oui_hex": "00-1B-3F",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "    118502",
        "country": "SG"
    },
    "001B41": {
        "oui_hex": "00-1B-41",
        "organization": "General Infinity Co.,Ltd.",
        "address_1": "3F,No.169, Xing-ai Rd,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001B50": {
        "oui_hex": "00-1B-50",
        "organization": "Nizhny Novgorod Factory named after M.Frunze, FSUE (NZiF)",
        "address_1": "174, Gagarina Avenue",
        "address_2": "Nizhny Novgorod  Russia  603950",
        "country": "RU"
    },
    "001B47": {
        "oui_hex": "00-1B-47",
        "organization": "Futarque A/S",
        "address_1": "Aagade 15B",
        "address_2": "Aalborg    9000",
        "country": "DK"
    },
    "001B6C": {
        "oui_hex": "00-1B-6C",
        "organization": "LookX Digital Media BV",
        "address_1": "Roekenveldweg 1",
        "address_2": "Brunssum  Limburg  6446DK",
        "country": "NL"
    },
    "001B6B": {
        "oui_hex": "00-1B-6B",
        "organization": "Swyx Solutions AG",
        "address_1": "Joseph-von-Fraunhofer-straße 13a",
        "address_2": "Dortmund    44227",
        "country": "DE"
    },
    "001B69": {
        "oui_hex": "00-1B-69",
        "organization": "Equaline Corporation",
        "address_1": "9F, No. 234, Section 4, Cheng-De Road,",
        "address_2": "  Taipei Hsien  25162",
        "country": "TW"
    },
    "001B76": {
        "oui_hex": "00-1B-76",
        "organization": "Ripcode, Inc.",
        "address_1": "1130 E. Arapaho Road",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "001B70": {
        "oui_hex": "00-1B-70",
        "organization": "IRI Ubiteq, INC.",
        "address_1": "Shinjuku-Nomura Bldg. 47F,",
        "address_2": "Shinjuku-ku  Tokyo  163-0547",
        "country": "JP"
    },
    "001B68": {
        "oui_hex": "00-1B-68",
        "organization": "Modnnet Co., Ltd",
        "address_1": "2139 Daemyung-Dong DIP main B/D Room#505, Namgu",
        "address_2": "Daegu  Kyungsang Bookdo  705-701",
        "country": "KR"
    },
    "001B62": {
        "oui_hex": "00-1B-62",
        "organization": "JHT Optoelectronics Co.,Ltd.",
        "address_1": "Hetian Industrial Park 2rd,Houjie Town, Donguan,",
        "address_2": "Dongguan  Guangdong  523945",
        "country": "CN"
    },
    "001B8A": {
        "oui_hex": "00-1B-8A",
        "organization": "2M Electronic A/S",
        "address_1": "Malervej 10",
        "address_2": "Taastrup    2630",
        "country": "DK"
    },
    "001B80": {
        "oui_hex": "00-1B-80",
        "organization": "LORD Corporation",
        "address_1": "2000 West Grandview Blvd",
        "address_2": "Erie  Pa  16509",
        "country": "US"
    },
    "001B3E": {
        "oui_hex": "00-1B-3E",
        "organization": "Curtis, Inc.",
        "address_1": "2405 Annapolis Lane",
        "address_2": "Minneapolis  MN  55441",
        "country": "US"
    },
    "001B37": {
        "oui_hex": "00-1B-37",
        "organization": "Computec Oy",
        "address_1": "Juholankatu 8",
        "address_2": "Kouvola  Kymi  45200",
        "country": "FI"
    },
    "001B07": {
        "oui_hex": "00-1B-07",
        "organization": "Mendocino Software",
        "address_1": "47001 Benecia St.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "001B08": {
        "oui_hex": "00-1B-08",
        "organization": "Danfoss Drives A/S",
        "address_1": "Ulsnaes 1",
        "address_2": "Graasten  6300",
        "country": "DK"
    },
    "001B01": {
        "oui_hex": "00-1B-01",
        "organization": "Applied Radio Technologies",
        "address_1": "1124 South Service Road West",
        "address_2": "Oakville  Ontario  L6L 5T7",
        "country": "CA"
    },
    "001B02": {
        "oui_hex": "00-1B-02",
        "organization": "ED Co.Ltd",
        "address_1": "517-15 SangDaeWon-Dong",
        "address_2": "SeongNam-City  GyeongGi-Do  462-806",
        "country": "KR"
    },
    "001AFC": {
        "oui_hex": "00-1A-FC",
        "organization": "ModusLink Corporation",
        "address_1": "2905 Prestonwood Drive",
        "address_2": "Plano  Texas  75093",
        "country": "US"
    },
    "001B10": {
        "oui_hex": "00-1B-10",
        "organization": "ShenZhen Kang Hui Technology Co.,ltd",
        "address_1": "China  GuangDong",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "001B0B": {
        "oui_hex": "00-1B-0B",
        "organization": "Phidgets Inc.",
        "address_1": "2715A 16A Street N.W.",
        "address_2": "Calgary  Alberta  T2M 3R7",
        "country": "CA"
    },
    "001B0C": {
        "oui_hex": "00-1B-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001AE0": {
        "oui_hex": "00-1A-E0",
        "organization": "Mythology Tech Express Inc.",
        "address_1": "2F, No.10, Lane 235, Bao Chiao road,",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "001AE2": {
        "oui_hex": "00-1A-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001AD7": {
        "oui_hex": "00-1A-D7",
        "organization": "Christie Digital Systems, Inc.",
        "address_1": "809 Wellington Street North",
        "address_2": "Kitchener  Ontario  N2G 4Y7",
        "country": "CA"
    },
    "001B23": {
        "oui_hex": "00-1B-23",
        "organization": "SimpleComTools",
        "address_1": "598 Indian Trail Rd S.",
        "address_2": "Indian Trail  NC  28079",
        "country": "US"
    },
    "001AF6": {
        "oui_hex": "00-1A-F6",
        "organization": "Woven Systems, Inc.",
        "address_1": "2455 Augustine Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001AF9": {
        "oui_hex": "00-1A-F9",
        "organization": "AeroVIronment (AV Inc)",
        "address_1": "4685 Industrial St",
        "address_2": "Simi Valley  CA  93063",
        "country": "US"
    },
    "001B30": {
        "oui_hex": "00-1B-30",
        "organization": "Solitech Inc.",
        "address_1": "1838 Main Street",
        "address_2": "Stevensville  MD  21666",
        "country": "US"
    },
    "001B18": {
        "oui_hex": "00-1B-18",
        "organization": "Tsuken Electric Ind. Co.,Ltd",
        "address_1": "3-9 Akedouri Izumi-ku",
        "address_2": "Sendai City  Miyagi  981-3206",
        "country": "JP"
    },
    "001AE7": {
        "oui_hex": "00-1A-E7",
        "organization": "Aztek Networks, Inc.",
        "address_1": "2477 55th St. #202",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "001A95": {
        "oui_hex": "00-1A-95",
        "organization": "Hisense Mobile Communications Technoligy Co.,Ltd.",
        "address_1": "11,JiangXi Road,",
        "address_2": "QingDao  ShanDong  266071",
        "country": "CN"
    },
    "001A81": {
        "oui_hex": "00-1A-81",
        "organization": "Zelax",
        "address_1": "2nd buid., 1B, Zavodskaya st.,",
        "address_2": "Moscow    124681",
        "country": "RU"
    },
    "001A87": {
        "oui_hex": "00-1A-87",
        "organization": "Canhold International Limited",
        "address_1": "Flat 4, 13/F., Block 4, Tai Ping Industrial Centre",
        "address_2": "    00852",
        "country": "HK"
    },
    "001A88": {
        "oui_hex": "00-1A-88",
        "organization": "Venergy,Co,Ltd",
        "address_1": "West 6th Floor,M-8 Building Maqueling Zone,",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "001AC1": {
        "oui_hex": "00-1A-C1",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "001ABB": {
        "oui_hex": "00-1A-BB",
        "organization": "Fontal Technology Incorporation",
        "address_1": "Rm.522, Bldg. 52, 195, Sec. 4, ChungHsing Rd., Chutung",
        "address_2": "Hsinchu    310",
        "country": "TW"
    },
    "001ABD": {
        "oui_hex": "00-1A-BD",
        "organization": "Impatica Inc.",
        "address_1": "205-1725 St. Laurent Blvd.",
        "address_2": "Ottawa  ON  K1G 3V4",
        "country": "CA"
    },
    "001AAE": {
        "oui_hex": "00-1A-AE",
        "organization": "Savant Systems LLC",
        "address_1": "45 Perseverance Way",
        "address_2": "Hyannis  Massachusetts  02601",
        "country": "US"
    },
    "001ACD": {
        "oui_hex": "00-1A-CD",
        "organization": "Tidel Engineering LP",
        "address_1": "2025 W Belt Line Road Suite 114",
        "address_2": "Carrollton  TX  75019",
        "country": "US"
    },
    "001AC9": {
        "oui_hex": "00-1A-C9",
        "organization": "SUZUKEN CO.,LTD",
        "address_1": "SUZUKEN TOMEI BLDG.",
        "address_2": "NAGOYA-SI  AICHI-KEN  465-0045",
        "country": "JP"
    },
    "001A79": {
        "oui_hex": "00-1A-79",
        "organization": "TELECOMUNICATION TECHNOLOGIES LTD.",
        "address_1": "4D ZHUKOVA BLV.",
        "address_2": "ODESSA    65121",
        "country": "UA"
    },
    "001AAA": {
        "oui_hex": "00-1A-AA",
        "organization": "Analogic Corp.",
        "address_1": "8 Centennial Drive",
        "address_2": "Peabody  MA  01960",
        "country": "US"
    },
    "001A8B": {
        "oui_hex": "00-1A-8B",
        "organization": "CHUNIL ELECTRIC IND., CO.",
        "address_1": "308,ByuckSan Digital Valley,132-7,Gamjeon-Dong,Sasang-Gu",
        "address_2": "Busan  GyeongSangNamDo  617-800",
        "country": "KR"
    },
    "001A8D": {
        "oui_hex": "00-1A-8D",
        "organization": "AVECS Bergen GmbH",
        "address_1": "Billrothstraße 11 a",
        "address_2": "Bergen auf Rügen  M/V  18528",
        "country": "DE"
    },
    "001AB4": {
        "oui_hex": "00-1A-B4",
        "organization": "FFEI Ltd.",
        "address_1": "Graphics House",
        "address_2": "Hemel Hempstead  Hertfordshire  HP2 7SU",
        "country": "GB"
    },
    "001AB5": {
        "oui_hex": "00-1A-B5",
        "organization": "Home Network System",
        "address_1": "107, Hyundai I-Vally",
        "address_2": "Seongnam-si  Gyeonggi-do  462-714",
        "country": "KR"
    },
    "001AA4": {
        "oui_hex": "00-1A-A4",
        "organization": "Future University-Hakodate",
        "address_1": "116-2 Kamedanakano-cho",
        "address_2": "Hakodate  Hokkaido  041-8655",
        "country": "JP"
    },
    "001A9F": {
        "oui_hex": "00-1A-9F",
        "organization": "A-Link Ltd",
        "address_1": "Kylavainiontie 20",
        "address_2": "Espoo    FI-02760",
        "country": "FI"
    },
    "001A74": {
        "oui_hex": "00-1A-74",
        "organization": "Procare International Co",
        "address_1": "5F, No.88, Jhouzih Street, Neihu District",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001ABE": {
        "oui_hex": "00-1A-BE",
        "organization": "COMPUTER HI-TECH INC.",
        "address_1": "HigashiUeno3-18-7",
        "address_2": "Taitoku  Tokyo  110-0015",
        "country": "JP"
    },
    "001A19": {
        "oui_hex": "00-1A-19",
        "organization": "Computer Engineering Limited",
        "address_1": "PO Box 493",
        "address_2": "Auckland  AK  2340",
        "country": "NZ"
    },
    "001A18": {
        "oui_hex": "00-1A-18",
        "organization": "Advanced Simulation Technology inc.",
        "address_1": "500A Huntmar Park Drive",
        "address_2": "Herndon  VA  20170",
        "country": "US"
    },
    "001A58": {
        "oui_hex": "00-1A-58",
        "organization": "CCV Deutschland GmbH - Celectronic eHealth Div.",
        "address_1": "Gertraudenstrasse 18",
        "address_2": "Berlin    D-10178",
        "country": "DE"
    },
    "001A5E": {
        "oui_hex": "00-1A-5E",
        "organization": "Thincom Technology Co.,Ltd",
        "address_1": "17F-3, No.398, Huanbei Rd.,",
        "address_2": "Zhongli City  Taoyuan Contry  320",
        "country": "TW"
    },
    "001A5C": {
        "oui_hex": "00-1A-5C",
        "organization": "Euchner GmbH+Co. KG",
        "address_1": "Kohlhammerstraße 16",
        "address_2": "Leinfelden-Echterdingen  BW  70771",
        "country": "DE"
    },
    "001A5B": {
        "oui_hex": "00-1A-5B",
        "organization": "NetCare Service Co., Ltd.",
        "address_1": "5-13-16 Shimizu, Asahi-ku",
        "address_2": "Osaka    535-0021",
        "country": "JP"
    },
    "001A24": {
        "oui_hex": "00-1A-24",
        "organization": "Galaxy Telecom Technologies Ltd",
        "address_1": "No.25, The 1st Gaoxin Road",
        "address_2": "Xi'an City  Shannxi  710075",
        "country": "CN"
    },
    "001A20": {
        "oui_hex": "00-1A-20",
        "organization": "CMOTECH Co. Ltd.",
        "address_1": "5F Etronix Bldg. 17-10",
        "address_2": "Youngdungpo-Gu  Seoul  150-874",
        "country": "KR"
    },
    "001A4E": {
        "oui_hex": "00-1A-4E",
        "organization": "NTI AG / LinMot",
        "address_1": "Haerdlistrasse 15",
        "address_2": "Spreitenbach  AG  8957",
        "country": "CH"
    },
    "001A52": {
        "oui_hex": "00-1A-52",
        "organization": "Meshlinx Wireless Inc.",
        "address_1": "1410 G Avenue, Suite T",
        "address_2": "Plano  Texas  75074",
        "country": "US"
    },
    "001A13": {
        "oui_hex": "00-1A-13",
        "organization": "Wanlida Group Co., LTD",
        "address_1": "Jiahe Road No.618",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "001A0F": {
        "oui_hex": "00-1A-0F",
        "organization": "Sistemas Avanzados de Control, S.A.",
        "address_1": "calle Colquide 6",
        "address_2": "Las Rozas  Madrid  28230",
        "country": "ES"
    },
    "001A43": {
        "oui_hex": "00-1A-43",
        "organization": "Logical Link Communications",
        "address_1": "1909 Central Drive Suite 205",
        "address_2": "Bedford  TX  76021",
        "country": "US"
    },
    "001A47": {
        "oui_hex": "00-1A-47",
        "organization": "Agami Systems, Inc.",
        "address_1": "1269 Innsbruck Drive",
        "address_2": "Sunnyvale  California  94089",
        "country": "US"
    },
    "001A2D": {
        "oui_hex": "00-1A-2D",
        "organization": "The Navvo Group",
        "address_1": "4400 Baker Road",
        "address_2": "Minnetonka  MN  55343",
        "country": "US"
    },
    "001A2F": {
        "oui_hex": "00-1A-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019A9": {
        "oui_hex": "00-19-A9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019AE": {
        "oui_hex": "00-19-AE",
        "organization": "Hopling Technologies b.v.",
        "address_1": "Camerastraat 10",
        "address_2": "Almere  Flevoland  1322 BC",
        "country": "NL"
    },
    "0019AF": {
        "oui_hex": "00-19-AF",
        "organization": "Rigol Technologies, Inc.",
        "address_1": "No. 156 Cai He Village, Sha He Town",
        "address_2": "Beijing    102206",
        "country": "CN"
    },
    "0019DE": {
        "oui_hex": "00-19-DE",
        "organization": "MOBITEK",
        "address_1": "5F,No.60,Lane 321,Yang-Kwang Street",
        "address_2": "Taipei    114",
        "country": "US"
    },
    "0019E5": {
        "oui_hex": "00-19-E5",
        "organization": "Lynx Studio Technology, Inc.",
        "address_1": "1540 Barton Rd # 268",
        "address_2": "Redlands  CA  92373",
        "country": "US"
    },
    "0019DB": {
        "oui_hex": "00-19-DB",
        "organization": "MICRO-STAR INTERNATIONAL CO., LTD.",
        "address_1": "NO. 69, LI-DE ST.",
        "address_2": "JUNG-HE CITY  TAIPEI HSIEN  235",
        "country": "TW"
    },
    "001A03": {
        "oui_hex": "00-1A-03",
        "organization": "Angel Electronics Co., Ltd.",
        "address_1": "17, Lane 134, Shou Shan Road, Tai Shan,",
        "address_2": "Taipei    243",
        "country": "TW"
    },
    "0019F9": {
        "oui_hex": "00-19-F9",
        "organization": "TDK-Lambda",
        "address_1": "405 Essex Road",
        "address_2": "Neptune  NJ  07753",
        "country": "US"
    },
    "0019CE": {
        "oui_hex": "00-19-CE",
        "organization": "Progressive Gaming International",
        "address_1": "920 Pilot Road",
        "address_2": "Las Vegas  NV  89119",
        "country": "US"
    },
    "0019BD": {
        "oui_hex": "00-19-BD",
        "organization": "New Media Life",
        "address_1": "Hea Ju Bild, 5F, 837-7, Yeoksam-dong",
        "address_2": "Kangnam-gu  Seoul  135-080",
        "country": "KR"
    },
    "0019F2": {
        "oui_hex": "00-19-F2",
        "organization": "Teradyne K.K.",
        "address_1": "272-13, Heisei, Takaono",
        "address_2": "Kikuchi-gun  Kumamoto  869-1232",
        "country": "JP"
    },
    "0019A7": {
        "oui_hex": "00-19-A7",
        "organization": "ITU-T",
        "address_1": "Place des Nations",
        "address_2": "Geneva 20    CH-1211",
        "country": "CH"
    },
    "00199F": {
        "oui_hex": "00-19-9F",
        "organization": "DKT A/S",
        "address_1": "Fanoevej 6",
        "address_2": "Kr. Saaby    DK-4060",
        "country": "DK"
    },
    "00198D": {
        "oui_hex": "00-19-8D",
        "organization": "Ocean Optics, Inc.",
        "address_1": "830 Douglas Ave",
        "address_2": "Dunedin  FL  34698",
        "country": "US"
    },
    "001982": {
        "oui_hex": "00-19-82",
        "organization": "SmarDTV",
        "address_1": "Route de Genève 22",
        "address_2": "Cheseaux    CH-1033",
        "country": "CH"
    },
    "001985": {
        "oui_hex": "00-19-85",
        "organization": "IT Watchdogs, Inc",
        "address_1": "12885 Research, Suite 210B",
        "address_2": "Austin  TX  78750",
        "country": "US"
    },
    "001951": {
        "oui_hex": "00-19-51",
        "organization": "NETCONS, s.r.o.",
        "address_1": "Stara Vajnorska 37",
        "address_2": "Bratislava  Slovakia  831 04",
        "country": "SK"
    },
    "001957": {
        "oui_hex": "00-19-57",
        "organization": "Saafnet Canada Inc.",
        "address_1": "107-1089 East Kent Ave (N)",
        "address_2": "Vancouver  BC  V5X 4V9",
        "country": "CA"
    },
    "001958": {
        "oui_hex": "00-19-58",
        "organization": "Bluetooth SIG, Inc.",
        "address_1": "5209 Lake Washington Blvd NE",
        "address_2": "Kirkland  WA  98033",
        "country": "US"
    },
    "001956": {
        "oui_hex": "00-19-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00196B": {
        "oui_hex": "00-19-6B",
        "organization": "Danpex Corporation",
        "address_1": "2114 Ringwood Avenue",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "00193D": {
        "oui_hex": "00-19-3D",
        "organization": "GMC Guardian Mobility Corp.",
        "address_1": "Suite 200",
        "address_2": "Ottawa  ON  K2E 7Y8",
        "country": "CA"
    },
    "001986": {
        "oui_hex": "00-19-86",
        "organization": "Cheng Hongjian",
        "address_1": "Rm.2305B.Sege Plaza,Huaqiang North Rd.,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "US"
    },
    "00199E": {
        "oui_hex": "00-19-9E",
        "organization": "Nifty",
        "address_1": "miwa4-2-22-105",
        "address_2": "  Nagano  3800803",
        "country": "JP"
    },
    "00196A": {
        "oui_hex": "00-19-6A",
        "organization": "MikroM GmbH",
        "address_1": "Dovestraße 1",
        "address_2": "Berlin    10587",
        "country": "DE"
    },
    "0018FF": {
        "oui_hex": "00-18-FF",
        "organization": "PowerQuattro Co.",
        "address_1": "János u. 175.",
        "address_2": "Budapest    H-1161",
        "country": "HU"
    },
    "0018F4": {
        "oui_hex": "00-18-F4",
        "organization": "EO TECHNICS Co., Ltd.",
        "address_1": "91, Dongpyeon-ro",
        "address_2": "Anyang  Kyeonggi-Do  431-803",
        "country": "KR"
    },
    "0018FC": {
        "oui_hex": "00-18-FC",
        "organization": "Altec Electronic AG",
        "address_1": "Lenggenbachstrasse 3",
        "address_2": "Fahrweid  Zürich  CH-8951",
        "country": "CH"
    },
    "0018F6": {
        "oui_hex": "00-18-F6",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "0018F5": {
        "oui_hex": "00-18-F5",
        "organization": "Shenzhen Streaming Video Technology Company Limited",
        "address_1": "5/F, Block 3, Software Part No.1, Keji Middle 2 Road,",
        "address_2": "Shenzhen  GaungDong  518057",
        "country": "CN"
    },
    "0018F9": {
        "oui_hex": "00-18-F9",
        "organization": "VVOND, Inc.",
        "address_1": "3000 Bridge Parkway",
        "address_2": "Redwood City  CA  94065",
        "country": "US"
    },
    "00193B": {
        "oui_hex": "00-19-3B",
        "organization": "LigoWave",
        "address_1": "138 Mountain Brook Drive",
        "address_2": "Canton  GA  30115",
        "country": "US"
    },
    "001935": {
        "oui_hex": "00-19-35",
        "organization": "DUERR DENTAL AG",
        "address_1": "Hoepfigheimer Strasse 17",
        "address_2": "Bietigheim-Bissingen  Baden-Wuerttemberg  74321",
        "country": "DE"
    },
    "001910": {
        "oui_hex": "00-19-10",
        "organization": "Knick Elektronische Messgeraete GmbH & Co. KG",
        "address_1": "Beuckestraße 22",
        "address_2": "Berlin    14163",
        "country": "DE"
    },
    "001913": {
        "oui_hex": "00-19-13",
        "organization": "Chuang-Yi Network Equipment Co.Ltd.",
        "address_1": "238 TianMuShan Rd., West Lake district",
        "address_2": "HangZhou  ZheJiang  310000",
        "country": "CN"
    },
    "0018FA": {
        "oui_hex": "00-18-FA",
        "organization": "Yushin Precision Equipment Co.,Ltd.",
        "address_1": "11-260 KOGAHONMACHI",
        "address_2": "KYOTO    612-8492 JAP",
        "country": "JP"
    },
    "0018EA": {
        "oui_hex": "00-18-EA",
        "organization": "Alltec GmbH",
        "address_1": "An der Trave 27-31",
        "address_2": "Selmsdorf  Mecklenburg-Vorpommern  23923",
        "country": "DE"
    },
    "0018E8": {
        "oui_hex": "00-18-E8",
        "organization": "Hacetron Corporation",
        "address_1": "No. 542,",
        "address_2": "Yang-Mei,  Tao-Yuan,  326",
        "country": "TW"
    },
    "001914": {
        "oui_hex": "00-19-14",
        "organization": "Winix Co., Ltd",
        "address_1": "363 Angade Bldg., Yangjae-dong",
        "address_2": "Seoul    137-898",
        "country": "KR"
    },
    "001906": {
        "oui_hex": "00-19-06",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001901": {
        "oui_hex": "00-19-01",
        "organization": "F1MEDIA",
        "address_1": "610, Keumkang Hightech ¥±, 138-1 Sangdaewon-Dong, Jungwon-Gu",
        "address_2": "Seongnam-Si  Gyeonggi-Do  462-707",
        "country": "KR"
    },
    "001931": {
        "oui_hex": "00-19-31",
        "organization": "Balluff GmbH",
        "address_1": "Schurwaldstraße 9",
        "address_2": "Neuhausen  BW  73765",
        "country": "DE"
    },
    "0018E3": {
        "oui_hex": "00-18-E3",
        "organization": "Visualgate Systems, Inc.",
        "address_1": "64 Bakersfield Street",
        "address_2": "Toronto  Ontario  M3J 2W7",
        "country": "CA"
    },
    "00189F": {
        "oui_hex": "00-18-9F",
        "organization": "Lenntek Corporation",
        "address_1": "4F, 125 GuangMing 3rd. Road",
        "address_2": "Jhu Bei  Hsin Chu  302",
        "country": "TW"
    },
    "001899": {
        "oui_hex": "00-18-99",
        "organization": "ShenZhen jieshun Science&Technology Industry CO,LTD.",
        "address_1": "China GuangDong state Shenzhen City Futian section NO17. Meilin Road",
        "address_2": "Shenzhen  GuangDong  518049",
        "country": "CN"
    },
    "00186D": {
        "oui_hex": "00-18-6D",
        "organization": "Zhenjiang Sapphire Electronic Industry CO.",
        "address_1": "Wei San Road,Dingmao Develop Area",
        "address_2": "zhenjiang  jiangsu  212009",
        "country": "CN"
    },
    "00186F": {
        "oui_hex": "00-18-6F",
        "organization": "Setha Industria Eletronica LTDA",
        "address_1": "Rua Alvaro de Macedo 134",
        "address_2": "Rio de Janeiro  RJ  21.250-620",
        "country": "BR"
    },
    "001875": {
        "oui_hex": "00-18-75",
        "organization": "AnaCise Testnology Pte Ltd",
        "address_1": "3 Bishan Place #02-06",
        "address_2": "    579838",
        "country": "SG"
    },
    "0018C1": {
        "oui_hex": "00-18-C1",
        "organization": "Almitec Informática e Comércio",
        "address_1": "461, Francisco de Morais St.",
        "address_2": "São Paulo    04714-010",
        "country": "BR"
    },
    "0018C4": {
        "oui_hex": "00-18-C4",
        "organization": "Raba Technologies LLC",
        "address_1": "8830 Stanford Blvd Suite 205",
        "address_2": "Columbia  Maryland  21045",
        "country": "US"
    },
    "0018C9": {
        "oui_hex": "00-18-C9",
        "organization": "EOps Technology Limited",
        "address_1": "Room 2001, Fairmont House,",
        "address_2": "Hong Kong",
        "country": "HK"
    },
    "0018D8": {
        "oui_hex": "00-18-D8",
        "organization": "ARCH METER Corporation",
        "address_1": "4F, No.3-2, Industry E. Rd.",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "0018D9": {
        "oui_hex": "00-18-D9",
        "organization": "Santosha Internatonal, Inc",
        "address_1": "3843 S. Bristol St. #242",
        "address_2": "Santa Ana  CA  92704",
        "country": "US"
    },
    "0018CF": {
        "oui_hex": "00-18-CF",
        "organization": "Baldor Electric Company",
        "address_1": "600 S. Zero St.",
        "address_2": "Fort Smith  AR  72901",
        "country": "US"
    },
    "0018BC": {
        "oui_hex": "00-18-BC",
        "organization": "ZAO NVP Bolid",
        "address_1": "Pionerskaya str., 4",
        "address_2": "Korolyov  Moscow region  141070",
        "country": "RU"
    },
    "0018B7": {
        "oui_hex": "00-18-B7",
        "organization": "D3 LED, LLC",
        "address_1": "380 Mountain Rd",
        "address_2": "Union City  NJ  07087",
        "country": "US"
    },
    "001895": {
        "oui_hex": "00-18-95",
        "organization": "Hansun Technologies Inc.",
        "address_1": "Room 301, Building 103, Wangjingkejiyuan, Chaoyang District",
        "address_2": "Beijing    100102",
        "country": "CN"
    },
    "001883": {
        "oui_hex": "00-18-83",
        "organization": "FORMOSA21 INC.",
        "address_1": "8F-6, NO.351, CHUNG SHAN RD., SEC.2",
        "address_2": "TAIPEI    235",
        "country": "TW"
    },
    "00188E": {
        "oui_hex": "00-18-8E",
        "organization": "Ekahau, Inc.",
        "address_1": "Hiilikatu 3",
        "address_2": "HELSINKI  UUSIMAA  00180",
        "country": "FI"
    },
    "001814": {
        "oui_hex": "00-18-14",
        "organization": "Mitutoyo Corporation",
        "address_1": "20-1, Sakado 1-chome, Takatsu-ku,",
        "address_2": "Kawasaki-shi    213-8533",
        "country": "JP"
    },
    "001817": {
        "oui_hex": "00-18-17",
        "organization": "D. E. Shaw Research, LLC",
        "address_1": "120 W. 45th St., 33rd Floor",
        "address_2": "New York  NY  10036",
        "country": "US"
    },
    "001811": {
        "oui_hex": "00-18-11",
        "organization": "Neuros Technology International, LLC.",
        "address_1": "650 W Lake St",
        "address_2": "Chicago  IL  60661",
        "country": "US"
    },
    "0017DE": {
        "oui_hex": "00-17-DE",
        "organization": "Advantage Six Ltd",
        "address_1": "208 George St",
        "address_2": "OLDHAM  Lancs  OL2 8DR",
        "country": "GB"
    },
    "0017D7": {
        "oui_hex": "00-17-D7",
        "organization": "ION Geophysical Corporation Inc.",
        "address_1": "850 Dorothy",
        "address_2": "Richardson  Texas  75081",
        "country": "US"
    },
    "001837": {
        "oui_hex": "00-18-37",
        "organization": "Universal ABIT Co., Ltd.",
        "address_1": "7F, No. 323 Yangguang St.,",
        "address_2": "Neihu  Taipei  114",
        "country": "TW"
    },
    "001822": {
        "oui_hex": "00-18-22",
        "organization": "CEC TELECOM CO.,LTD.",
        "address_1": "10thFL.CEC Building,6 Zhongguancun South Street",
        "address_2": "Beijing    100086",
        "country": "CN"
    },
    "001820": {
        "oui_hex": "00-18-20",
        "organization": "w5networks",
        "address_1": "48389 Fremont Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00185D": {
        "oui_hex": "00-18-5D",
        "organization": "TAIGUEN TECHNOLOGY (SHEN-ZHEN) CO., LTD.",
        "address_1": "No. 23, The Third Industrial Park of Xia Village,",
        "address_2": "Shenzhen City,  Guangdong,  815106",
        "country": "CN"
    },
    "00185E": {
        "oui_hex": "00-18-5E",
        "organization": "Nexterm Inc.",
        "address_1": "1-12-3, Shibaura, Minato-ku,",
        "address_2": "Tokyo    105-0023",
        "country": "JP"
    },
    "001828": {
        "oui_hex": "00-18-28",
        "organization": "e2v technologies (UK) ltd.",
        "address_1": "106 Waterhouse Lane",
        "address_2": "Chelmsford  Essex  CM1 2QU",
        "country": "GB"
    },
    "001835": {
        "oui_hex": "00-18-35",
        "organization": "Thoratec / ITC",
        "address_1": "2656 Patton Road",
        "address_2": "Roseville  MN  55113",
        "country": "US"
    },
    "001801": {
        "oui_hex": "00-18-01",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0017F3": {
        "oui_hex": "00-17-F3",
        "organization": "Harris Corporation",
        "address_1": "1025 West NASA Blvd",
        "address_2": "Melbourne  FL  32919",
        "country": "US"
    },
    "00184A": {
        "oui_hex": "00-18-4A",
        "organization": "Catcher, Inc.",
        "address_1": "5864 Owens Ave.",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "00184B": {
        "oui_hex": "00-18-4B",
        "organization": "Las Vegas Gaming, Inc.",
        "address_1": "4000 West Ali Baba Lane, Suite D",
        "address_2": "Las Vegas  Nevada  89118",
        "country": "US"
    },
    "00180E": {
        "oui_hex": "00-18-0E",
        "organization": "Avega Systems",
        "address_1": "59 Victoria Street",
        "address_2": "McMahons Point  NSW  2060",
        "country": "AU"
    },
    "0017BC": {
        "oui_hex": "00-17-BC",
        "organization": "Touchtunes Music Corporation",
        "address_1": "3 Place du Commerce",
        "address_2": "Montréal  Québec  H3E 1H7",
        "country": "CA"
    },
    "0017C1": {
        "oui_hex": "00-17-C1",
        "organization": "CM Precision Technology LTD.",
        "address_1": "2 Fl, No. 177, Chien-E Road, Chung-Ho City",
        "address_2": "Taipei Hsien    235",
        "country": "TW"
    },
    "0017B2": {
        "oui_hex": "00-17-B2",
        "organization": "SK Telesys",
        "address_1": "4F, Kyungdong bldg, 4-4, Sunae-Dong, Pundang-Gu",
        "address_2": "Sungnam-City  Kunggi-Do  463-825",
        "country": "KR"
    },
    "0017B1": {
        "oui_hex": "00-17-B1",
        "organization": "ACIST Medical Systems, Inc.",
        "address_1": "7450 Flying Cloud Drive",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "0017A3": {
        "oui_hex": "00-17-A3",
        "organization": "MIX s.r.l.",
        "address_1": "Via Caldera, 21",
        "address_2": "Milan    I-20153",
        "country": "IT"
    },
    "0017A6": {
        "oui_hex": "00-17-A6",
        "organization": "YOSIN ELECTRONICS CO., LTD.",
        "address_1": "6F-2, No.17, Lan 174,Shin-Ming Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00179C": {
        "oui_hex": "00-17-9C",
        "organization": "DEPRAG SCHULZ GMBH u. CO.",
        "address_1": "Kurfürstenringg 12.18",
        "address_2": "Amberg  Bayern  92224",
        "country": "DE"
    },
    "001796": {
        "oui_hex": "00-17-96",
        "organization": "Rittmeyer AG",
        "address_1": "Inwilerriedstrasse 57",
        "address_2": "Baar  ZG  CH-6341",
        "country": "CH"
    },
    "0017E1": {
        "oui_hex": "00-17-E1",
        "organization": "DACOS Technologies Co., Ltd.",
        "address_1": "104 Daeryung-Technotown III 448",
        "address_2": "SEOUL  Keumcheon-Gu  153-772",
        "country": "KR"
    },
    "0017E0": {
        "oui_hex": "00-17-E0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0017D2": {
        "oui_hex": "00-17-D2",
        "organization": "THINLINX PTY LTD",
        "address_1": "31 Carwoola Crescent",
        "address_2": "Mooloolaba  Queensland  4557",
        "country": "AU"
    },
    "001785": {
        "oui_hex": "00-17-85",
        "organization": "Sparr Electronics Ltd",
        "address_1": "Sparr Electronics Ltd",
        "address_2": "Bangalore  Karnataka  560054",
        "country": "IN"
    },
    "001775": {
        "oui_hex": "00-17-75",
        "organization": "TTE Germany GmbH",
        "address_1": "Hermann-Schwer-Straße 3",
        "address_2": "Villingen-Schwenningen  Baden-Württemberg  78048",
        "country": "DE"
    },
    "0017B8": {
        "oui_hex": "00-17-B8",
        "organization": "NOVATRON CO., LTD.",
        "address_1": "#601 polaris bldg., 15-3 jeongja-dong, bundang-gu",
        "address_2": "Seong Nam  Gyeonggi Do  463-811",
        "country": "KR"
    },
    "0017BB": {
        "oui_hex": "00-17-BB",
        "organization": "Syrinx Industrial Electronics",
        "address_1": "De Factorij 13",
        "address_2": "Zwaag  Noord Holland  1689 AK",
        "country": "NL"
    },
    "00177C": {
        "oui_hex": "00-17-7C",
        "organization": "Smartlink Network Systems Limited",
        "address_1": "L-7, Verna Electronic city",
        "address_2": "Nagoa  Goa  403 722",
        "country": "IN"
    },
    "001781": {
        "oui_hex": "00-17-81",
        "organization": "Greystone Data System, Inc.",
        "address_1": "40800 Encycopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00178D": {
        "oui_hex": "00-17-8D",
        "organization": "Checkpoint Systems, Inc.",
        "address_1": "101 Wolf Drive",
        "address_2": "Thorofare  NJ  08086",
        "country": "US"
    },
    "00178E": {
        "oui_hex": "00-17-8E",
        "organization": "Gunnebo Cash Automation AB",
        "address_1": "Fabriksgatan 10",
        "address_2": "Göteborg    402 27",
        "country": "SE"
    },
    "0017C7": {
        "oui_hex": "00-17-C7",
        "organization": "MARA Systems Consulting AB",
        "address_1": "Instrumentvägen 45",
        "address_2": "Stockholm    126 53",
        "country": "SE"
    },
    "00175D": {
        "oui_hex": "00-17-5D",
        "organization": "Dongseo system.",
        "address_1": "974-21 Mansu-dong Namdong-gu",
        "address_2": "Incheon  In-Cheon  405-865",
        "country": "KR"
    },
    "001750": {
        "oui_hex": "00-17-50",
        "organization": "GSI Group, MicroE Systems",
        "address_1": "8 Erie Drive",
        "address_2": "Natick  MA  01760",
        "country": "US"
    },
    "001755": {
        "oui_hex": "00-17-55",
        "organization": "GE Security",
        "address_1": "12345 SW Leveton Drive",
        "address_2": "Tualatin  OR  97062",
        "country": "US"
    },
    "00171D": {
        "oui_hex": "00-17-1D",
        "organization": "DIGIT",
        "address_1": "Via Pasteur , 1/3",
        "address_2": "S.Pietro Mosezzo  NOVARA  28060",
        "country": "IT"
    },
    "001718": {
        "oui_hex": "00-17-18",
        "organization": "Vansco Electronics Oy",
        "address_1": "Tiilenlyojankatu 5",
        "address_2": "FORSSA    30101",
        "country": "FI"
    },
    "001719": {
        "oui_hex": "00-17-19",
        "organization": "Audiocodes USA, Inc",
        "address_1": "27 World's Fair Drive",
        "address_2": "Somerset  NJ  08873",
        "country": "US"
    },
    "001776": {
        "oui_hex": "00-17-76",
        "organization": "Meso Scale Diagnostics, LLC",
        "address_1": "9238 Gaither Rd.",
        "address_2": "Gaithersburg  MD  20877",
        "country": "US"
    },
    "001779": {
        "oui_hex": "00-17-79",
        "organization": "QuickTel",
        "address_1": "Cornishe El-Nile, Maasara",
        "address_2": "Cairo    11743",
        "country": "EG"
    },
    "001767": {
        "oui_hex": "00-17-67",
        "organization": "Earforce AS",
        "address_1": "P.O.Box 4",
        "address_2": "Bryne    4349",
        "country": "NO"
    },
    "001739": {
        "oui_hex": "00-17-39",
        "organization": "Bright Headphone Electronics Company",
        "address_1": "8F, 109, Li De Street",
        "address_2": "Chung Ho City  Taipei County  235",
        "country": "TW"
    },
    "00172C": {
        "oui_hex": "00-17-2C",
        "organization": "TAEJIN INFOTECH",
        "address_1": "6F Woolim e-Biz Center, 170-5",
        "address_2": "Seoul    152-769",
        "country": "KR"
    },
    "001751": {
        "oui_hex": "00-17-51",
        "organization": "Online Corporation",
        "address_1": "22F-3, No. 398, Huan Pei Road,",
        "address_2": "Chung Li  Taoyuan  320",
        "country": "TW"
    },
    "00174C": {
        "oui_hex": "00-17-4C",
        "organization": "Millipore",
        "address_1": "1, rue Jacques Monod",
        "address_2": "Guyancourt    78280",
        "country": "FR"
    },
    "001711": {
        "oui_hex": "00-17-11",
        "organization": "GE Healthcare Bio-Sciences AB",
        "address_1": "Björkgatan 30",
        "address_2": "Uppsala  SE  75184",
        "country": "SE"
    },
    "001745": {
        "oui_hex": "00-17-45",
        "organization": "INNOTZ CO., Ltd",
        "address_1": "14F, Prime Center 546-4 Guui-Dong Kwanggin-Gu",
        "address_2": "Seoul  Seoul",
        "country": "KR"
    },
    "001748": {
        "oui_hex": "00-17-48",
        "organization": "Neokoros Brasil Ltda",
        "address_1": "Rua 86, numero 501, Setor Sul",
        "address_2": "Goiania  Goias  74083-330",
        "country": "BR"
    },
    "001763": {
        "oui_hex": "00-17-63",
        "organization": "Essentia S.p.A.",
        "address_1": "Via G.B. Vico, 29",
        "address_2": "Cella (RE)  Reggio Emilia  42040",
        "country": "IT"
    },
    "001701": {
        "oui_hex": "00-17-01",
        "organization": "KDE, Inc.",
        "address_1": "KDE TOWN, 42-7, Mangwol-dong",
        "address_2": "Hanam  Gyeonggi-do  465-150",
        "country": "KR"
    },
    "0016F6": {
        "oui_hex": "00-16-F6",
        "organization": "Video Products Group",
        "address_1": "1600 Emerson Avenue",
        "address_2": "Oxnard  California  93033",
        "country": "US"
    },
    "0016EE": {
        "oui_hex": "00-16-EE",
        "organization": "Royaldigital Inc.",
        "address_1": "8F., No.308, Sec.1, Neihu Rd.",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "0016DE": {
        "oui_hex": "00-16-DE",
        "organization": "FAST Inc",
        "address_1": "905 Honeyspot Rd",
        "address_2": "Stratford  CT  06615",
        "country": "US"
    },
    "0016DA": {
        "oui_hex": "00-16-DA",
        "organization": "Futronic Technology Co. Ltd.",
        "address_1": "Room 1016A, 10/F., Profit Ind. Bldg.,",
        "address_2": "Kwai Chung    00000",
        "country": "HK"
    },
    "0016D4": {
        "oui_hex": "00-16-D4",
        "organization": "Compal Communications, Inc.",
        "address_1": "7th, FL, No. 319, Sec. 4, Pa-Teh rd.",
        "address_2": "Taipei    886",
        "country": "TW"
    },
    "0016D7": {
        "oui_hex": "00-16-D7",
        "organization": "Sunways AG",
        "address_1": "Macairestraße 3-5",
        "address_2": "Konstanz  Baden-Württemberg  78467",
        "country": "DE"
    },
    "0016FF": {
        "oui_hex": "00-16-FF",
        "organization": "Wamin Optocomm Mfg Corp",
        "address_1": "No. 239 Qiaohe Road",
        "address_2": "Zhonghe City  Taipei County  235",
        "country": "TW"
    },
    "0016D1": {
        "oui_hex": "00-16-D1",
        "organization": "ZAT a.s.",
        "address_1": "K Podlesi 541",
        "address_2": "Pribram VI    26180",
        "country": "CZ"
    },
    "0016C5": {
        "oui_hex": "00-16-C5",
        "organization": "Shenzhen Xing Feng Industry Co.,Ltd",
        "address_1": "Floor 1 - 4, Block 25, Hongtian Jinyuan Industrial,",
        "address_2": "Shenzhen  GuangDong  86",
        "country": "CN"
    },
    "0016CC": {
        "oui_hex": "00-16-CC",
        "organization": "Xcute Mobile Corp.",
        "address_1": "3F. No.25, Ally15, Lane 120, Sec.1, Neihu Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001717": {
        "oui_hex": "00-17-17",
        "organization": "Leica Geosystems AG",
        "address_1": "Heinrich Wild Strasse",
        "address_2": "Heerbrugg  St. Gallen  CH-9435",
        "country": "CH"
    },
    "001715": {
        "oui_hex": "00-17-15",
        "organization": "Qstik",
        "address_1": "Cartel Business Estate",
        "address_2": "Harlow  Essex  CM20 2TT",
        "country": "GB"
    },
    "00170E": {
        "oui_hex": "00-17-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001705": {
        "oui_hex": "00-17-05",
        "organization": "Methode Electronics",
        "address_1": "7401 W. Wilson",
        "address_2": "Chicago  IL  60706",
        "country": "US"
    },
    "0016AA": {
        "oui_hex": "00-16-AA",
        "organization": "Kei Communication Technology Inc.",
        "address_1": "8-BAN CHUOU",
        "address_2": "KOBE  HYOGO  650-0024",
        "country": "JP"
    },
    "0016A8": {
        "oui_hex": "00-16-A8",
        "organization": "CWT CO., LTD.",
        "address_1": "10F No. 74 Sec. 1 Chung-Hua Rd.",
        "address_2": "Taipei    108",
        "country": "TW"
    },
    "0016A6": {
        "oui_hex": "00-16-A6",
        "organization": "Dovado FZ-LLC",
        "address_1": "Al-Thuraya Tower 1, office 504",
        "address_2": "Dubai",
        "country": "AE"
    },
    "0016ED": {
        "oui_hex": "00-16-ED",
        "organization": "Utility, Inc",
        "address_1": "250 E Ponce de Leon Ave Suite 700",
        "address_2": "Decatur  GA  30030",
        "country": "US"
    },
    "0016C7": {
        "oui_hex": "00-16-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001671": {
        "oui_hex": "00-16-71",
        "organization": "Symphox Information Co.",
        "address_1": "15F, No. 51, Sec. 3, Minsheng E. Road",
        "address_2": "Taipei City    104",
        "country": "TW"
    },
    "001669": {
        "oui_hex": "00-16-69",
        "organization": "MRV Communication (Networks) LTD",
        "address_1": "P.O Box 614",
        "address_2": "Yokneam    20692",
        "country": "US"
    },
    "001668": {
        "oui_hex": "00-16-68",
        "organization": "Eishin Electronics",
        "address_1": "Nishiku Miyashita 1-19",
        "address_2": "Kobe City  Hyogo Prefecture  651-2146",
        "country": "JP"
    },
    "001640": {
        "oui_hex": "00-16-40",
        "organization": "Asmobile Communication Inc.",
        "address_1": "No.11 Lane 120, Li-Te Rd., Peitou 112, Taipei, Taiwan, R.O.C",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "00163C": {
        "oui_hex": "00-16-3C",
        "organization": "Rebox B.V.",
        "address_1": "Hendrik Figeeweg 1X",
        "address_2": "Haarlem  Noord-Holland  2031 BJ",
        "country": "NL"
    },
    "00167D": {
        "oui_hex": "00-16-7D",
        "organization": "Sky-Line Information Co., Ltd.",
        "address_1": "8F.,No.38,Sihyuan Rd.,",
        "address_2": "Sinihuang  Taipei  242",
        "country": "TW"
    },
    "001677": {
        "oui_hex": "00-16-77",
        "organization": "Bihl + Wiedemann GmbH",
        "address_1": "Flosswoerthstr 41",
        "address_2": "Mannheim    68199",
        "country": "DE"
    },
    "001655": {
        "oui_hex": "00-16-55",
        "organization": "FUHO TECHNOLOGY Co., LTD",
        "address_1": "No. 30, Lane 726, Jinma Rd, Sec. 3",
        "address_2": "Chang Hua    500",
        "country": "TW"
    },
    "001646": {
        "oui_hex": "00-16-46",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001648": {
        "oui_hex": "00-16-48",
        "organization": "SSD Company Limited",
        "address_1": "3-3-4 Higashiyagura",
        "address_2": "Kusatsu-city  Shiga  525-0054",
        "country": "JP"
    },
    "001672": {
        "oui_hex": "00-16-72",
        "organization": "Zenway enterprise ltd",
        "address_1": "6F., No.20, Lane 150, Jhongsing Rd., Sijhih City",
        "address_2": "Taipei    886",
        "country": "TW"
    },
    "00165A": {
        "oui_hex": "00-16-5A",
        "organization": "Harman Specialty Group",
        "address_1": "3 Oak Park Drive",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "001659": {
        "oui_hex": "00-16-59",
        "organization": "Z.M.P. RADWAG",
        "address_1": "Bracka 28 street",
        "address_2": "RADOM  Mazowieckie  26-600",
        "country": "PL"
    },
    "0016A2": {
        "oui_hex": "00-16-A2",
        "organization": "CentraLite Systems, Inc.",
        "address_1": "6420 Wall Street",
        "address_2": "Mobile  AL  36695",
        "country": "US"
    },
    "001695": {
        "oui_hex": "00-16-95",
        "organization": "AVC Technology (International) Limited",
        "address_1": "6/F Enterprise Square III",
        "address_2": "Kowloon Bay",
        "country": "HK"
    },
    "0015D8": {
        "oui_hex": "00-15-D8",
        "organization": "Interlink Electronics",
        "address_1": "546 Flynn Road",
        "address_2": "Camarillo  CA  93012",
        "country": "US"
    },
    "0015D4": {
        "oui_hex": "00-15-D4",
        "organization": "Emitor AB",
        "address_1": "Sjöviksbacken 14",
        "address_2": "Stockholm    117 43",
        "country": "SE"
    },
    "0015D5": {
        "oui_hex": "00-15-D5",
        "organization": "NICEVT",
        "address_1": "Warshawskoe shosse 125",
        "address_2": "Moscow    117405",
        "country": "RU"
    },
    "00160C": {
        "oui_hex": "00-16-0C",
        "organization": "LPL  DEVELOPMENT S.A. DE C.V",
        "address_1": "LAGO GINEBRA 380 P3",
        "address_2": "  D.F.  11480",
        "country": "MX"
    },
    "001612": {
        "oui_hex": "00-16-12",
        "organization": "Otsuka Electronics Co., Ltd.",
        "address_1": "1-10 Sasagaoka, Minakuchi",
        "address_2": "kouka  shiga  528-0061",
        "country": "US"
    },
    "00160B": {
        "oui_hex": "00-16-0B",
        "organization": "TVWorks LLC",
        "address_1": "Two Belvedere Place, #200",
        "address_2": "Mill Valley  CA  94941",
        "country": "US"
    },
    "001603": {
        "oui_hex": "00-16-03",
        "organization": "COOLKSKY Co., LTD",
        "address_1": "Shingsung offcetel A511, 1588-1 Secho",
        "address_2": "  Seoul  137-070",
        "country": "KR"
    },
    "0015EA": {
        "oui_hex": "00-15-EA",
        "organization": "Tellumat (Pty) Ltd",
        "address_1": "64/74 White Road",
        "address_2": "Cape Town  Western Province  7945",
        "country": "ZA"
    },
    "0015E2": {
        "oui_hex": "00-15-E2",
        "organization": "Dr.Ing. Herbert Knauer GmbH",
        "address_1": "Hegauer Weg 38",
        "address_2": "Berlin    14163",
        "country": "DE"
    },
    "0015E1": {
        "oui_hex": "00-15-E1",
        "organization": "Picochip Ltd",
        "address_1": "Upper Borough Court",
        "address_2": "Bath    BA1 1RG",
        "country": "GB"
    },
    "0015DF": {
        "oui_hex": "00-15-DF",
        "organization": "Clivet S.p.A.",
        "address_1": "via Camp Lonc 25",
        "address_2": "Feltre  Belluno  32030",
        "country": "IT"
    },
    "00161D": {
        "oui_hex": "00-16-1D",
        "organization": "Innovative Wireless Technologies, Inc.",
        "address_1": "1047 Vista Park Dr.",
        "address_2": "Forest  VA  24551",
        "country": "US"
    },
    "001611": {
        "oui_hex": "00-16-11",
        "organization": "Altecon Srl",
        "address_1": "Via F.lli Cairoli, 17",
        "address_2": "Lissone  Milano  20035",
        "country": "IT"
    },
    "001609": {
        "oui_hex": "00-16-09",
        "organization": "Unitech electronics co., ltd.",
        "address_1": "5F,No.136,Lane 235 ,Pao-chiao Rd.,",
        "address_2": "Hsin-Tien city  Taipei Hsien  231",
        "country": "TW"
    },
    "0015F5": {
        "oui_hex": "00-15-F5",
        "organization": "Sustainable Energy Systems",
        "address_1": "#500, 609 14th Street NW",
        "address_2": "Calgary  Ab  T2T 1P3",
        "country": "CA"
    },
    "0015F1": {
        "oui_hex": "00-15-F1",
        "organization": "KYLINK Communications Corp.",
        "address_1": "8F-8, No. 351, Sec. 2, Zhongshan Rd., Zhonghe City",
        "address_2": "    23504",
        "country": "TW"
    },
    "001623": {
        "oui_hex": "00-16-23",
        "organization": "Interval Media",
        "address_1": "3200 Ash Street",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "001619": {
        "oui_hex": "00-16-19",
        "organization": "Lancelan Technologies S.L.",
        "address_1": "C/Angel Guimera 208 bis",
        "address_2": "Terrassa  Barcelona  08223",
        "country": "ES"
    },
    "001625": {
        "oui_hex": "00-16-25",
        "organization": "Impinj, Inc.",
        "address_1": "400 Fairview Ave N, Suite 1200",
        "address_2": "Seattle  WA  98109",
        "country": "US"
    },
    "001586": {
        "oui_hex": "00-15-86",
        "organization": "Xiamen Overseas Chinese Electronic Co., Ltd.",
        "address_1": "No. 22, Huli Street,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "00157E": {
        "oui_hex": "00-15-7E",
        "organization": "Weidmüller Interface GmbH & Co. KG",
        "address_1": "Klingenbergstraße 16",
        "address_2": "Detmold    32758",
        "country": "DE"
    },
    "001580": {
        "oui_hex": "00-15-80",
        "organization": "U-WAY CORPORATION",
        "address_1": "3F-2, NO. 125, LANE 235, PAO-CHIAO",
        "address_2": "HSINTIEN CITY  TAIPEI HSIEN  231",
        "country": "TW"
    },
    "00157C": {
        "oui_hex": "00-15-7C",
        "organization": "Dave Networks, Inc.",
        "address_1": "2151 O'tool Avenue",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00157F": {
        "oui_hex": "00-15-7F",
        "organization": "ChuanG International Holding CO.,LTD.",
        "address_1": "1F, NO.12, Alley 1, Lane 125, Guolian Street 4Lirn, Wuhan Village",
        "address_2": "Taoyuan  Longtan  325",
        "country": "US"
    },
    "0015B3": {
        "oui_hex": "00-15-B3",
        "organization": "Caretech AB",
        "address_1": "Nyborgsvägen 197",
        "address_2": "Kalix    95291",
        "country": "SE"
    },
    "0015AA": {
        "oui_hex": "00-15-AA",
        "organization": "Rextechnik International Co.,",
        "address_1": "Room 5-3, No.51, Section 2, Keelung Road",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "0015A6": {
        "oui_hex": "00-15-A6",
        "organization": "Digital Electronics Products Ltd.",
        "address_1": "Room 301, 3 rd Floor, Tsun Yip Centre",
        "address_2": "Kwun Tong    852",
        "country": "HK"
    },
    "00159D": {
        "oui_hex": "00-15-9D",
        "organization": "Tripp Lite",
        "address_1": "1111 W 35th Street",
        "address_2": "Chicago  IL  60609",
        "country": "US"
    },
    "0015D6": {
        "oui_hex": "00-15-D6",
        "organization": "OSLiNK Sp. z o.o.",
        "address_1": "ul. Marsa 27",
        "address_2": "Gdansk    80299",
        "country": "PL"
    },
    "001592": {
        "oui_hex": "00-15-92",
        "organization": "Facom UK Ltd (Melksham)",
        "address_1": "Lancaster House",
        "address_2": "Melksham  Wiltshire  SN104FB",
        "country": "US"
    },
    "00158B": {
        "oui_hex": "00-15-8B",
        "organization": "Park Air Systems Ltd",
        "address_1": "Northfields",
        "address_2": "Peterborough    PE6 8UE",
        "country": "GB"
    },
    "001576": {
        "oui_hex": "00-15-76",
        "organization": "LABiTec - Labor Biomedical Technologies GmbH",
        "address_1": "An der Strusbek 6",
        "address_2": "",
        "country": "DE"
    },
    "0015BE": {
        "oui_hex": "00-15-BE",
        "organization": "Iqua Ltd.",
        "address_1": "Hyvoninkatu 1",
        "address_2": "Salo  Varsinais-Suomi  24240",
        "country": "US"
    },
    "0015C7": {
        "oui_hex": "00-15-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00155E": {
        "oui_hex": "00-15-5E",
        "organization": "Morgan Stanley",
        "address_1": "750 7th Avenue",
        "address_2": "New York  NY  10019",
        "country": "US"
    },
    "00150B": {
        "oui_hex": "00-15-0B",
        "organization": "SAGE INFOTECH LTD.",
        "address_1": "3F, No30, INDUSTRY E. 9TH RD.,SCIENCE-BASED",
        "address_2": "HSIN-CHU  TAIWAN  300",
        "country": "TW"
    },
    "001507": {
        "oui_hex": "00-15-07",
        "organization": "Renaissance Learning Inc",
        "address_1": "2911 Peach Street",
        "address_2": "Wisconsin Rapids  Wisconsin  54494",
        "country": "US"
    },
    "001508": {
        "oui_hex": "00-15-08",
        "organization": "Global Target Enterprise Inc",
        "address_1": "5F, No. 186, Sec. 2, Chung-Hsing Rd.,",
        "address_2": "Hsin Tien,  Taipei county  231",
        "country": "TW"
    },
    "001502": {
        "oui_hex": "00-15-02",
        "organization": "BETA tech",
        "address_1": "15 rue d'apollo",
        "address_2": "L'UNION    31240",
        "country": "FR"
    },
    "0014FD": {
        "oui_hex": "00-14-FD",
        "organization": "Thecus Technology Corp.",
        "address_1": "15F.,No. 79,Sec. 1,Sintai 5th RD.,",
        "address_2": "Sijhih City  Taipei County  221",
        "country": "TW"
    },
    "0014FC": {
        "oui_hex": "00-14-FC",
        "organization": "Extandon, Inc.",
        "address_1": "39350 Civic Center Drive Ste. 160",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0014F8": {
        "oui_hex": "00-14-F8",
        "organization": "Scientific Atlanta",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  Ga  30042",
        "country": "US"
    },
    "0014F7": {
        "oui_hex": "00-14-F7",
        "organization": "CREVIS Co., LTD",
        "address_1": "157-1, Hagal-Dong",
        "address_2": "Youngin  Kyungki  446930",
        "country": "KR"
    },
    "001515": {
        "oui_hex": "00-15-15",
        "organization": "Leipold+Co.GmbH",
        "address_1": "Kreuzwiese 12",
        "address_2": "Rockenhausen  RLP  D-67806",
        "country": "DE"
    },
    "00150F": {
        "oui_hex": "00-15-0F",
        "organization": "mingjong",
        "address_1": "8F,NO.1,LANE 16,SZE CHUAN ROAD,SEC.2,PANCHIAO CITY.",
        "address_2": "TAIPEI    220",
        "country": "TW"
    },
    "00155C": {
        "oui_hex": "00-15-5C",
        "organization": "Dresser Wayne",
        "address_1": "3814 Jarrett Way",
        "address_2": "Austin  Texas  78728",
        "country": "US"
    },
    "001559": {
        "oui_hex": "00-15-59",
        "organization": "Securaplane Technologies, Inc.",
        "address_1": "10800 N. Mavinee Dr.",
        "address_2": "Tucson  AZ  85737",
        "country": "US"
    },
    "001557": {
        "oui_hex": "00-15-57",
        "organization": "Olivetti",
        "address_1": "Via Jervis 77",
        "address_2": "Ivrea  Torino  10015",
        "country": "IT"
    },
    "001554": {
        "oui_hex": "00-15-54",
        "organization": "Atalum Wireless S.A.",
        "address_1": "C/ Orellana 5, 1º I",
        "address_2": "Madrid    28004",
        "country": "ES"
    },
    "00153B": {
        "oui_hex": "00-15-3B",
        "organization": "EMH metering GmbH & Co. KG",
        "address_1": "Neu- Galliner Weg 1",
        "address_2": "  Mecklenburg-Vorpommern",
        "country": "DE"
    },
    "001537": {
        "oui_hex": "00-15-37",
        "organization": "Ventus Networks",
        "address_1": "800 Connecticut Ave",
        "address_2": "Norwalk  CT  06854",
        "country": "US"
    },
    "001533": {
        "oui_hex": "00-15-33",
        "organization": "NADAM.CO.,LTD",
        "address_1": "#91-3 Wangrim-Li",
        "address_2": "Hwaseong  Gyeonggi  445-895",
        "country": "KR"
    },
    "001534": {
        "oui_hex": "00-15-34",
        "organization": "A Beltrónica-Companhia de Comunicações, Lda",
        "address_1": "Rua Dr. José Baptista de Sousa, 27",
        "address_2": "Lisbon    1549-002 Lis",
        "country": "PT"
    },
    "00153F": {
        "oui_hex": "00-15-3F",
        "organization": "Alcatel Alenia Space Italia",
        "address_1": "Strada Padana Superiore 290",
        "address_2": "Vimodrone  MI  20090",
        "country": "IT"
    },
    "001518": {
        "oui_hex": "00-15-18",
        "organization": "Shenzhen 10MOONS Technology Development CO.,Ltd",
        "address_1": "Add:3F,Huaxing building, QiaoXiang road,",
        "address_2": "shenzhen  guangdong  518053",
        "country": "CN"
    },
    "001526": {
        "oui_hex": "00-15-26",
        "organization": "Remote Technologies Inc",
        "address_1": " 5775 12th Ave E, Suite 180",
        "address_2": "Shakopee  MN  55379",
        "country": "US"
    },
    "0014F1": {
        "oui_hex": "00-14-F1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0014EA": {
        "oui_hex": "00-14-EA",
        "organization": "S Digm Inc. (Safe Paradigm Inc.)",
        "address_1": "5F, Shin-an Bldg. 89-8,",
        "address_2": "Songpa-Gu  Seoul  138-201",
        "country": "KR"
    },
    "0014E5": {
        "oui_hex": "00-14-E5",
        "organization": "Alticast",
        "address_1": "16th floor, Nara Bldg, 1328-3",
        "address_2": "  Seoul  137-070",
        "country": "KR"
    },
    "00149F": {
        "oui_hex": "00-14-9F",
        "organization": "System and Chips, Inc.",
        "address_1": "4F,No. 1, Lane 50, NanKang Road, Section 3,",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "0014B3": {
        "oui_hex": "00-14-B3",
        "organization": "CoreStar International Corp",
        "address_1": "1044 Sandy Hill Rd",
        "address_2": "Irwin  PA  15642",
        "country": "US"
    },
    "0014B1": {
        "oui_hex": "00-14-B1",
        "organization": "Axell Wireless Limited",
        "address_1": "Aerial HOuse",
        "address_2": "Chesham  Buckinghamshire  HP5 2QD",
        "country": "GB"
    },
    "0014E0": {
        "oui_hex": "00-14-E0",
        "organization": "LET'S Corporation",
        "address_1": "Bancho Bldg. 4F, 2-18-20 Marunouchi, Naka",
        "address_2": "Nagoya  Aichi  460-0002",
        "country": "JP"
    },
    "0014E2": {
        "oui_hex": "00-14-E2",
        "organization": "datacom systems inc.",
        "address_1": "9 adler drive",
        "address_2": "east syracuse  n.y.  13057",
        "country": "US"
    },
    "0014E4": {
        "oui_hex": "00-14-E4",
        "organization": "infinias, LLC",
        "address_1": "857 West Carmel Drive",
        "address_2": "Carmel  IN  46032",
        "country": "US"
    },
    "0014CC": {
        "oui_hex": "00-14-CC",
        "organization": "Zetec, Inc.",
        "address_1": "8226 Bracken Place SE",
        "address_2": "Snoqualmie  WA  98065",
        "country": "US"
    },
    "0014CB": {
        "oui_hex": "00-14-CB",
        "organization": "LifeSync Corporation",
        "address_1": "1 E Broward Boulevard, Suite 1701",
        "address_2": "Fort Lauderdale  Florida  33301",
        "country": "US"
    },
    "0014C6": {
        "oui_hex": "00-14-C6",
        "organization": "Quixant Ltd",
        "address_1": "61A Mount Pleasant",
        "address_2": "England  Kent  TN16 3TP",
        "country": "GB"
    },
    "001498": {
        "oui_hex": "00-14-98",
        "organization": "Viking Design Technology",
        "address_1": "2F, No.2, Lane 42,",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "001496": {
        "oui_hex": "00-14-96",
        "organization": "Phonic Corp.",
        "address_1": "12thFl, 59 Tung Hsing Rd",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001493": {
        "oui_hex": "00-14-93",
        "organization": "Systimax Solutions",
        "address_1": "1300 E Lookout Drive",
        "address_2": "Richardson  Texas  75082",
        "country": "US"
    },
    "0014DB": {
        "oui_hex": "00-14-DB",
        "organization": "Elma Trenew Electronic GmbH",
        "address_1": "Stuttgarter Straße 11",
        "address_2": "Pforzheim    75179",
        "country": "DE"
    },
    "00143A": {
        "oui_hex": "00-14-3A",
        "organization": "RAYTALK INTERNATIONAL SRL",
        "address_1": "St. Marecchia 79",
        "address_2": "  Verucchio (RN)  47826",
        "country": "IT"
    },
    "001436": {
        "oui_hex": "00-14-36",
        "organization": "Qwerty Elektronik AB",
        "address_1": "Gryt 44",
        "address_2": "Ösmo    610 60",
        "country": "SE"
    },
    "00146B": {
        "oui_hex": "00-14-6B",
        "organization": "Anagran, Inc.",
        "address_1": "580 North Pastoria Av",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "001461": {
        "oui_hex": "00-14-61",
        "organization": "CORONA CORPORATION",
        "address_1": "7-7, HIGASHI-SHINBO",
        "address_2": "SANJO-SHI  NIIGATA  955-8510",
        "country": "JP"
    },
    "001462": {
        "oui_hex": "00-14-62",
        "organization": "Digiwell Technology, inc",
        "address_1": "4F, No.1, Prosperity 1st Road",
        "address_2": "  Hsinchu Science Park  300",
        "country": "TW"
    },
    "001463": {
        "oui_hex": "00-14-63",
        "organization": "IDCS N.V.",
        "address_1": "Hellebeemden 9",
        "address_2": "Hasselt  Limburg  3500",
        "country": "BE"
    },
    "001465": {
        "oui_hex": "00-14-65",
        "organization": "Novo Nordisk A/S",
        "address_1": "Novo Alle",
        "address_2": "Bagsvaerd    2880",
        "country": "DK"
    },
    "001474": {
        "oui_hex": "00-14-74",
        "organization": "K40 Electronics",
        "address_1": "600 Tollgate Rd. Unit A",
        "address_2": "Elgin  IL  60123",
        "country": "US"
    },
    "00146F": {
        "oui_hex": "00-14-6F",
        "organization": "Kohler Co",
        "address_1": "444 Highland Drive",
        "address_2": "Kohler  WI  53044",
        "country": "US"
    },
    "001466": {
        "oui_hex": "00-14-66",
        "organization": "Kleinhenz Elektronik GmbH",
        "address_1": "Greinerberg 14",
        "address_2": "Munich    81371",
        "country": "DE"
    },
    "00147F": {
        "oui_hex": "00-14-7F",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "001475": {
        "oui_hex": "00-14-75",
        "organization": "Wiline Networks, Inc.",
        "address_1": "741 Alexander Rd",
        "address_2": "Princeton  NJ  08540",
        "country": "US"
    },
    "001486": {
        "oui_hex": "00-14-86",
        "organization": "Echo Digital Audio Corporation",
        "address_1": "402 E Carrillo St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "001482": {
        "oui_hex": "00-14-82",
        "organization": "Aurora Networks",
        "address_1": "5400 Betsy Ross Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001455": {
        "oui_hex": "00-14-55",
        "organization": "Coder Electronics Corporation",
        "address_1": "Takeda Bldg, 1-30-6 Shirasagi,",
        "address_2": "Nakano-ku  Tokyo  165-0035",
        "country": "JP"
    },
    "00144E": {
        "oui_hex": "00-14-4E",
        "organization": "SRISA",
        "address_1": "36/1, Nakhimovskiy pr-t",
        "address_2": "  Moscow  117218",
        "country": "RU"
    },
    "00148D": {
        "oui_hex": "00-14-8D",
        "organization": "Cubic Defense Simulation Systems",
        "address_1": "2001 W. Oakridge Road",
        "address_2": "Orlando  FL  32809",
        "country": "US"
    },
    "00143D": {
        "oui_hex": "00-14-3D",
        "organization": "Aevoe Inc.",
        "address_1": "11F, No 23, Keelung Road",
        "address_2": "Taipei  HsinYi District  110",
        "country": "TW"
    },
    "001415": {
        "oui_hex": "00-14-15",
        "organization": "Intec Automation inc.",
        "address_1": "2751 Arbutus Rd.",
        "address_2": "Victoria  British Columbia  V8N 5X7",
        "country": "CA"
    },
    "001410": {
        "oui_hex": "00-14-10",
        "organization": "Suzhou Keda Technology CO.,Ltd",
        "address_1": "131,Jinshan Road",
        "address_2": "Suzhou  JiangSu  215011",
        "country": "CN"
    },
    "001417": {
        "oui_hex": "00-14-17",
        "organization": "RSE Informations Technologie GmbH",
        "address_1": "Silberbergstrasse 9",
        "address_2": "Wolfsberg  Kärnten  9400",
        "country": "AT"
    },
    "001433": {
        "oui_hex": "00-14-33",
        "organization": "Empower Technologies(Canada) Inc.",
        "address_1": "Unit 405 - 5600 Parkwood Way,",
        "address_2": "Richmond  British Columbia  V6V 2M2",
        "country": "CA"
    },
    "001434": {
        "oui_hex": "00-14-34",
        "organization": "Keri Systems, Inc",
        "address_1": "2305 Bering Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0013DE": {
        "oui_hex": "00-13-DE",
        "organization": "Adapt4, LLC",
        "address_1": "1050 W Nasa Blvd,",
        "address_2": "Melbourne  FL  32901",
        "country": "US"
    },
    "0013DD": {
        "oui_hex": "00-13-DD",
        "organization": "Abbott Diagnostics",
        "address_1": "5440 Patrick Henry Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0013D7": {
        "oui_hex": "00-13-D7",
        "organization": "SPIDCOM Technologies SA",
        "address_1": "137 avenue du General LECLERC",
        "address_2": "BOURG LA REINE    92340",
        "country": "FR"
    },
    "0013C7": {
        "oui_hex": "00-13-C7",
        "organization": "IONOS Co.,Ltd.",
        "address_1": "1-36-18 Miyasaka",
        "address_2": "Setagaya-ku  Tokyo  156-0051",
        "country": "JP"
    },
    "001423": {
        "oui_hex": "00-14-23",
        "organization": "J-S Co. NEUROCOM",
        "address_1": "Energeticheskii proezd, 6",
        "address_2": "Moscow    111250",
        "country": "RU"
    },
    "001425": {
        "oui_hex": "00-14-25",
        "organization": "Galactic Computing Corp.",
        "address_1": "1/F",
        "address_2": "Chai Wan District",
        "country": "HK"
    },
    "001419": {
        "oui_hex": "00-14-19",
        "organization": "SIDSA",
        "address_1": "PTM - TORRES QUEVEDO 1",
        "address_2": "TRES CANTOS  MADRID  28760",
        "country": "ES"
    },
    "0013EE": {
        "oui_hex": "00-13-EE",
        "organization": "JBX Designs Inc.",
        "address_1": "PO Box 970158",
        "address_2": "Boca Raton  FL  33497",
        "country": "US"
    },
    "0013E5": {
        "oui_hex": "00-13-E5",
        "organization": "TENOSYS, INC.",
        "address_1": "Seojin B/D, 1564-1, Seocho-dong,",
        "address_2": "  Seoul  137-070",
        "country": "KR"
    },
    "0013E2": {
        "oui_hex": "00-13-E2",
        "organization": "GeoVision Inc.",
        "address_1": "9F.,No.246,Sec.1,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001402": {
        "oui_hex": "00-14-02",
        "organization": "kk-electronic a/s",
        "address_1": "Cypresvej 6",
        "address_2": "Herning    7400",
        "country": "DK"
    },
    "0013FF": {
        "oui_hex": "00-13-FF",
        "organization": "Dage-MTI of MC, Inc.",
        "address_1": "701 N. Roeske Ave.",
        "address_2": "Michigan City  IN  46360",
        "country": "US"
    },
    "0013BC": {
        "oui_hex": "00-13-BC",
        "organization": "Artimi Ltd",
        "address_1": "Betjeman House",
        "address_2": "Cambridge  Cambridgeshire  CB2 1LQ",
        "country": "GB"
    },
    "001408": {
        "oui_hex": "00-14-08",
        "organization": "Eka Systems Inc.",
        "address_1": "20251 Century Blvd",
        "address_2": "Germantown  MD  20874",
        "country": "US"
    },
    "0013A7": {
        "oui_hex": "00-13-A7",
        "organization": "BATTELLE MEMORIAL INSTITUTE",
        "address_1": "505 KING AVE",
        "address_2": "COLUMBUS  OHIO  43201",
        "country": "US"
    },
    "0013A6": {
        "oui_hex": "00-13-A6",
        "organization": "Extricom Ltd",
        "address_1": "Glil Yam",
        "address_2": "Herzlia    46905",
        "country": "IL"
    },
    "0013A2": {
        "oui_hex": "00-13-A2",
        "organization": "MaxStream, Inc",
        "address_1": "355 South 520 West Suite 180",
        "address_2": "Lindon  Ut  84042",
        "country": "US"
    },
    "00139F": {
        "oui_hex": "00-13-9F",
        "organization": "Electronics Design Services, Co., Ltd.",
        "address_1": "5-10-20 Tokumaru",
        "address_2": "Itabashi-ku  Tokyo  175-0083",
        "country": "JP"
    },
    "0013A0": {
        "oui_hex": "00-13-A0",
        "organization": "ALGOSYSTEM Co., Ltd.",
        "address_1": "656 kobirao mihara-cho",
        "address_2": "sakai  osaka  587-0021",
        "country": "JP"
    },
    "001398": {
        "oui_hex": "00-13-98",
        "organization": "TrafficSim Co.,Ltd",
        "address_1": "23-9 Mita-biru 2F, Chiyoda 3-chome",
        "address_2": "Aichi  Non  460-0012",
        "country": "JP"
    },
    "00139B": {
        "oui_hex": "00-13-9B",
        "organization": "ioIMAGE Ltd.",
        "address_1": "3 Maskit Street",
        "address_2": "Herzliya Pituach  IL  46733",
        "country": "IL"
    },
    "001396": {
        "oui_hex": "00-13-96",
        "organization": "Acbel Polytech Inc.",
        "address_1": "No.159,Sec.3, Tam-King Rd.,",
        "address_2": "Tamsui  Taipei  251",
        "country": "TW"
    },
    "001393": {
        "oui_hex": "00-13-93",
        "organization": "Panta Systems, Inc.",
        "address_1": "20450 Stevens Creek Blvd.",
        "address_2": "Cupertino  California  95014",
        "country": "US"
    },
    "00138B": {
        "oui_hex": "00-13-8B",
        "organization": "Phantom Technologies LLC",
        "address_1": "7825 Fay Avenue, Suite 200",
        "address_2": "La Jolla  CA  92037",
        "country": "US"
    },
    "001388": {
        "oui_hex": "00-13-88",
        "organization": "WiMedia Alliance",
        "address_1": "2400 Camino Ramon",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "00136E": {
        "oui_hex": "00-13-6E",
        "organization": "Techmetro Corp.",
        "address_1": "4F. Dongam B/D., 264-5, YangJae-Dong",
        "address_2": "Seoul    137-130",
        "country": "KR"
    },
    "00136D": {
        "oui_hex": "00-13-6D",
        "organization": "Tentaculus AB",
        "address_1": "Studiegangen 3",
        "address_2": "Ostersund  Jamtland  SE - 831 40",
        "country": "SE"
    },
    "00136A": {
        "oui_hex": "00-13-6A",
        "organization": "Hach Lange Sarl",
        "address_1": "6, route de Compois",
        "address_2": "VESENAZ  GENEVA  1222",
        "country": "CH"
    },
    "0013B2": {
        "oui_hex": "00-13-B2",
        "organization": "Carallon Limited",
        "address_1": "Studio G20 Shepherds Building",
        "address_2": "  London  W14 0DA",
        "country": "GB"
    },
    "0013AD": {
        "oui_hex": "00-13-AD",
        "organization": "Sendo Ltd",
        "address_1": "Hatchford Brook",
        "address_2": "Birmingham  West Midlands  B26 3RZ",
        "country": "GB"
    },
    "0013AA": {
        "oui_hex": "00-13-AA",
        "organization": "ALS  & TEC Ltd.",
        "address_1": "6 B. Kazachya str.",
        "address_2": "Saratov  Saratov region  410600",
        "country": "RU"
    },
    "0013A4": {
        "oui_hex": "00-13-A4",
        "organization": "KeyEye Communications",
        "address_1": "9785 Goethe",
        "address_2": "Sacramento  CA  95827",
        "country": "US"
    },
    "00134D": {
        "oui_hex": "00-13-4D",
        "organization": "Inepro BV",
        "address_1": "Pondweg 7",
        "address_2": "  Nieuw- Vennep",
        "country": "NL"
    },
    "00134B": {
        "oui_hex": "00-13-4B",
        "organization": "ToGoldenNet Technology Inc.",
        "address_1": "5F-1 No.25,Pu-ding.,",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "001384": {
        "oui_hex": "00-13-84",
        "organization": "Advanced Motion Controls",
        "address_1": "3805 Calle Tecate",
        "address_2": "Camarillo  California  93012",
        "country": "US"
    },
    "00137B": {
        "oui_hex": "00-13-7B",
        "organization": "Movon Corporation",
        "address_1": "5th, Hyunjuk B/D",
        "address_2": "Seoul    135-092",
        "country": "KR"
    },
    "001353": {
        "oui_hex": "00-13-53",
        "organization": "HYDAC Filtertechnik GMBH",
        "address_1": "Industriegebiet",
        "address_2": "Sulzbach/Saar  Saarland  66280",
        "country": "DE"
    },
    "001363": {
        "oui_hex": "00-13-63",
        "organization": "Verascape, Inc.",
        "address_1": "1101 31st St., Suite #190",
        "address_2": "Downers Grove  IL  60515",
        "country": "US"
    },
    "001303": {
        "oui_hex": "00-13-03",
        "organization": "GateConnect",
        "address_1": "Eisenhutweg 69",
        "address_2": "12487 Berlin    12487",
        "country": "DE"
    },
    "001304": {
        "oui_hex": "00-13-04",
        "organization": "Flaircomm Technologies Co. LTD",
        "address_1": "2088 Huashan Road",
        "address_2": "Shanghai    200030",
        "country": "CN"
    },
    "0012F9": {
        "oui_hex": "00-12-F9",
        "organization": "URYU SEISAKU, LTD.",
        "address_1": "1-2-11",
        "address_2": "HIGASHINARI-KU  OSAKA  537-0002",
        "country": "JP"
    },
    "0012F3": {
        "oui_hex": "00-12-F3",
        "organization": "connectBlue AB",
        "address_1": "Norra Vallgatan 64",
        "address_2": "Malmoe    SE-211 22",
        "country": "SE"
    },
    "001337": {
        "oui_hex": "00-13-37",
        "organization": "Orient Power Home Network Ltd.",
        "address_1": "307 Harbour Centre, Tower 1,",
        "address_2": "",
        "country": "HK"
    },
    "001334": {
        "oui_hex": "00-13-34",
        "organization": "Arkados, Inc.",
        "address_1": "948 US HWY 22",
        "address_2": "North Plainfield  NJ  07060",
        "country": "US"
    },
    "001332": {
        "oui_hex": "00-13-32",
        "organization": "Beijing Topsec Network Security Technology Co., Ltd.",
        "address_1": "Huakong Tower",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "00131F": {
        "oui_hex": "00-13-1F",
        "organization": "NxtPhase T&D, Corp.",
        "address_1": "3040 E. Broadway",
        "address_2": "Vancouver  BC  V5M 1Z4",
        "country": "CA"
    },
    "0012DC": {
        "oui_hex": "00-12-DC",
        "organization": "SunCorp Industrial Limited",
        "address_1": "No.68 Guowei Road,",
        "address_2": "Liantang Industrial District,  Shenzhen,",
        "country": "CN"
    },
    "0012FF": {
        "oui_hex": "00-12-FF",
        "organization": "Lely Industries N.V.",
        "address_1": "Weverskade 110",
        "address_2": "Maassluis  Zuid-Holland  3147PA",
        "country": "NL"
    },
    "00133A": {
        "oui_hex": "00-13-3A",
        "organization": "VadaTech Inc.",
        "address_1": "11540 S. Eastern Avenue",
        "address_2": "Henderson  Nevada  89052",
        "country": "US"
    },
    "00132A": {
        "oui_hex": "00-13-2A",
        "organization": "Sitronics Telecom Solutions",
        "address_1": "Michelska 60",
        "address_2": "Prague  Prague 4 - Michle  140 00",
        "country": "CZ"
    },
    "0012E5": {
        "oui_hex": "00-12-E5",
        "organization": "Time America, Inc.",
        "address_1": "51 W. 3rd Street #310",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "00130E": {
        "oui_hex": "00-13-0E",
        "organization": "Focusrite Audio Engineering Limited",
        "address_1": "19 Lincoln Road",
        "address_2": "High Wycombe  Bucks  HP12 3FX",
        "country": "GB"
    },
    "001309": {
        "oui_hex": "00-13-09",
        "organization": "Ocean Broadband Networks",
        "address_1": "2078 Walsh Ave, Suite B",
        "address_2": "Santa Clara  California  95050",
        "country": "US"
    },
    "001319": {
        "oui_hex": "00-13-19",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00131C": {
        "oui_hex": "00-13-1C",
        "organization": "LiteTouch, Inc.",
        "address_1": "3400 South West Temple",
        "address_2": "Salt Lake City  UT  84115",
        "country": "US"
    },
    "00134A": {
        "oui_hex": "00-13-4A",
        "organization": "Engim, Inc.",
        "address_1": "40 Nagog Park",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "0012D7": {
        "oui_hex": "00-12-D7",
        "organization": "Invento Networks, Inc.",
        "address_1": "377 Simarano Drive",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "0012C4": {
        "oui_hex": "00-12-C4",
        "organization": "Viseon, Inc.",
        "address_1": "8445 Freeport Parkway",
        "address_2": "Irving  Texas  75063",
        "country": "US"
    },
    "001293": {
        "oui_hex": "00-12-93",
        "organization": "GE Energy",
        "address_1": "1501 Roanoke Blvd.",
        "address_2": "Salem  VA  24153",
        "country": "US"
    },
    "001294": {
        "oui_hex": "00-12-94",
        "organization": "SUMITOMO ELECTRIC DEVICE INNOVATIONS, INC",
        "address_1": "1000 Kamisukiawara,Showa-cho",
        "address_2": "Nakakoma-gun  Yamanashi  409-3883",
        "country": "JP"
    },
    "001296": {
        "oui_hex": "00-12-96",
        "organization": "Addlogix",
        "address_1": "459 Wald",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0012B3": {
        "oui_hex": "00-12-B3",
        "organization": "Advance Wireless Technology Corp.",
        "address_1": "12F No. 27-6, Sec. 2, Chung Cheng East Road",
        "address_2": "Tamshui    251",
        "country": "TW"
    },
    "0012B0": {
        "oui_hex": "00-12-B0",
        "organization": "Efore Oyj   (Plc)",
        "address_1": "Quartetto Business Park",
        "address_2": "Espoo    FI - 02600",
        "country": "FI"
    },
    "00127F": {
        "oui_hex": "00-12-7F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0012A6": {
        "oui_hex": "00-12-A6",
        "organization": "Dolby Australia",
        "address_1": "Level 6",
        "address_2": "Surry Hills  NSW  2010",
        "country": "AU"
    },
    "0012A4": {
        "oui_hex": "00-12-A4",
        "organization": "ThingMagic, LLC",
        "address_1": "One Broadway",
        "address_2": "Cambridge  MA  02142",
        "country": "US"
    },
    "0012A9": {
        "oui_hex": "00-12-A9",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "0012D0": {
        "oui_hex": "00-12-D0",
        "organization": "Gossen-Metrawatt-GmbH",
        "address_1": "Thomas-Mann-Straße 16-20",
        "address_2": "Nürnberg  Bavaria  90471",
        "country": "DE"
    },
    "001299": {
        "oui_hex": "00-12-99",
        "organization": "Ktech Telecommunications Inc",
        "address_1": "21540 Prairie Street Unit B",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "00128C": {
        "oui_hex": "00-12-8C",
        "organization": "Woodward Governor",
        "address_1": "1000 E. Drake Road",
        "address_2": "Ft. Collins  CO  80525",
        "country": "US"
    },
    "0012B8": {
        "oui_hex": "00-12-B8",
        "organization": "G2 Microsystems",
        "address_1": "408 Euclid Ave",
        "address_2": "Oakland  CA  94610",
        "country": "US"
    },
    "00127B": {
        "oui_hex": "00-12-7B",
        "organization": "VIA Networking Technologies, Inc.",
        "address_1": "8F,533, Chung-Cheng Road, Hsin-Tien",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "001280": {
        "oui_hex": "00-12-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001275": {
        "oui_hex": "00-12-75",
        "organization": "Sentilla Corporation",
        "address_1": "201 Marshall Street",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "001276": {
        "oui_hex": "00-12-76",
        "organization": "CG Power Systems Ireland Limited",
        "address_1": "Herbert House., Harmony Row,",
        "address_2": "Dublin    D2",
        "country": "IE"
    },
    "001271": {
        "oui_hex": "00-12-71",
        "organization": "Measurement Computing Corp",
        "address_1": "10 Commerce Way",
        "address_2": "Norton  MA  02766",
        "country": "US"
    },
    "001273": {
        "oui_hex": "00-12-73",
        "organization": "Stoke Inc",
        "address_1": "2189 Leghorn Street",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001269": {
        "oui_hex": "00-12-69",
        "organization": "Value Electronics",
        "address_1": "Dong-kwan B/D, 5F, 1566-2",
        "address_2": "seoul    137-874",
        "country": "KR"
    },
    "001250": {
        "oui_hex": "00-12-50",
        "organization": "Tokyo Aircaft Instrument Co., Ltd.",
        "address_1": "1-35-1, Izumi-Honcho",
        "address_2": "Komae-Shi  Tokyo  201-8555",
        "country": "JP"
    },
    "001252": {
        "oui_hex": "00-12-52",
        "organization": "Citronix, LLC",
        "address_1": "2214 South Watson Road",
        "address_2": "Arlington  Texas  76010",
        "country": "US"
    },
    "001240": {
        "oui_hex": "00-12-40",
        "organization": "AMOI ELECTRONICS CO.,LTD",
        "address_1": "295 Lane,Zuchongzhi Road,Zhang jiang,",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "00122E": {
        "oui_hex": "00-12-2E",
        "organization": "Signal Technology - AISD",
        "address_1": "1820 Preston Park Blvd.",
        "address_2": "Plano  TX  75093",
        "country": "US"
    },
    "001264": {
        "oui_hex": "00-12-64",
        "organization": "daum electronic gmbh",
        "address_1": "flugplatzstraße 100",
        "address_2": "FÃƒÂ¼rth  Bavaria  90768",
        "country": "DE"
    },
    "001261": {
        "oui_hex": "00-12-61",
        "organization": "Adaptix, Inc",
        "address_1": "1407 116th Ave. NE",
        "address_2": "Bellevue  WA  98004",
        "country": "US"
    },
    "001260": {
        "oui_hex": "00-12-60",
        "organization": "Stanton Magnetics,inc.",
        "address_1": "3000 SW 42nd Street",
        "address_2": "Hollywood  FL  33312",
        "country": "US"
    },
    "001231": {
        "oui_hex": "00-12-31",
        "organization": "Motion Control Systems, Inc.",
        "address_1": "PO Box 115",
        "address_2": "New River  VA  24129",
        "country": "US"
    },
    "00124B": {
        "oui_hex": "00-12-4B",
        "organization": "Texas Instruments",
        "address_1": "Gaustadalleen 21",
        "address_2": "Oslo    N-0349",
        "country": "NO"
    },
    "00124A": {
        "oui_hex": "00-12-4A",
        "organization": "Dedicated Devices, Inc.",
        "address_1": "5680 E. Franklin Road",
        "address_2": "Nampa  Idaho  83687",
        "country": "US"
    },
    "001243": {
        "oui_hex": "00-12-43",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0011D9": {
        "oui_hex": "00-11-D9",
        "organization": "TiVo",
        "address_1": "2160 Gold Ave",
        "address_2": "Alviso  CA  95002-2160",
        "country": "US"
    },
    "0011D2": {
        "oui_hex": "00-11-D2",
        "organization": "Perception Digital Ltd",
        "address_1": "Flat A, 8/F, Shaw House",
        "address_2": "Clear Water Bay  NT",
        "country": "HK"
    },
    "0011CF": {
        "oui_hex": "00-11-CF",
        "organization": "Thrane & Thrane A/S",
        "address_1": "Lundtoftegårdsvej 93D",
        "address_2": "Lyngby  København  2800",
        "country": "DK"
    },
    "0011D4": {
        "oui_hex": "00-11-D4",
        "organization": "NetEnrich, Inc",
        "address_1": "890 Hillview Ct.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0011D5": {
        "oui_hex": "00-11-D5",
        "organization": "Hangzhou Sunyard System Engineering Co.,Ltd.",
        "address_1": "Sunyard Science & Technology Building Hi-Tech Software Park(Second Land Consolidation)",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "0011F8": {
        "oui_hex": "00-11-F8",
        "organization": "AIRAYA Corp",
        "address_1": "637 Adair Court",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "0011F4": {
        "oui_hex": "00-11-F4",
        "organization": "woori-net",
        "address_1": "#508, Hankook Moolyu, 853-1 Dongchun-Dong",
        "address_2": "Yongin-Si  Kyungki-Do  449-843",
        "country": "KR"
    },
    "0011F6": {
        "oui_hex": "00-11-F6",
        "organization": "Asia Pacific Microsystems , Inc.",
        "address_1": "No.2,R&D Road 6 ,Science-Based Industrial Park,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0011F0": {
        "oui_hex": "00-11-F0",
        "organization": "Wideful Limited",
        "address_1": "F5, 3/F., Phase II, Superluck Industrial Centre,",
        "address_2": "",
        "country": "HK"
    },
    "0011F1": {
        "oui_hex": "00-11-F1",
        "organization": "QinetiQ Ltd",
        "address_1": "Room E601",
        "address_2": "Malvern  Worcestershire  WR14 3PS",
        "country": "GB"
    },
    "0011ED": {
        "oui_hex": "00-11-ED",
        "organization": "802 Global",
        "address_1": "Studio 11,Intec 2,Wade Road",
        "address_2": "Hampshire    RG24 BNE",
        "country": "GB"
    },
    "001211": {
        "oui_hex": "00-12-11",
        "organization": "Protechna Herbst GmbH & Co. KG",
        "address_1": "Otto Hahn Str. 26",
        "address_2": "Ottobrunn  Germany/Bavaria  85521",
        "country": "DE"
    },
    "001219": {
        "oui_hex": "00-12-19",
        "organization": "General Datacomm LLC",
        "address_1": "353 Christian Street, Suite 4",
        "address_2": "Oxford  CT  06478",
        "country": "US"
    },
    "001216": {
        "oui_hex": "00-12-16",
        "organization": "ICP Internet Communication Payment AG",
        "address_1": "Wilhelm-Stein-Weg 24",
        "address_2": "Hamburg    D-22339",
        "country": "DE"
    },
    "001215": {
        "oui_hex": "00-12-15",
        "organization": "iStor Networks, Inc.",
        "address_1": "7585 Irvine Center Drive",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "001203": {
        "oui_hex": "00-12-03",
        "organization": "ActivNetworks",
        "address_1": "BAT L - 1 rue de Terre Neuve",
        "address_2": "COURTABOEUF    91944",
        "country": "FR"
    },
    "0011CC": {
        "oui_hex": "00-11-CC",
        "organization": "Guangzhou Jinpeng Group Co.,Ltd.",
        "address_1": "No.9 Shenzhou Road,Guangzhou Science City",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "0011C7": {
        "oui_hex": "00-11-C7",
        "organization": "Raymarine UK Ltd",
        "address_1": "Marine House",
        "address_2": "Fareham  Hampshire  PO15 5RJ",
        "country": "GB"
    },
    "0011C9": {
        "oui_hex": "00-11-C9",
        "organization": "MTT Corporation",
        "address_1": "2-7-12",
        "address_2": "Nishi-ku  Kobe  651-2241",
        "country": "JP"
    },
    "0011DB": {
        "oui_hex": "00-11-DB",
        "organization": "Land-Cellular Corporation",
        "address_1": "12054 Miramar Parkway",
        "address_2": "Miramar  FL  33025",
        "country": "US"
    },
    "001224": {
        "oui_hex": "00-12-24",
        "organization": "NexQL Corporation",
        "address_1": "12250 Inwood Road #6",
        "address_2": "Dallas  TX  75244",
        "country": "US"
    },
    "0011BD": {
        "oui_hex": "00-11-BD",
        "organization": "Bombardier Transportation",
        "address_1": "1501 Lebanon Church Road",
        "address_2": "Pittsburgh  PA  15236",
        "country": "US"
    },
    "0011AA": {
        "oui_hex": "00-11-AA",
        "organization": "Uniclass Technology, Co., LTD",
        "address_1": "4F, No. 98, Ming chuan Rd",
        "address_2": "Hsintien City  Taipei Hsien  231",
        "country": "TW"
    },
    "001179": {
        "oui_hex": "00-11-79",
        "organization": "Singular Technology Co. Ltd.",
        "address_1": "21F, No.37, Sec.2, San Min Rd.,",
        "address_2": "Taipei    220",
        "country": "TW"
    },
    "00118A": {
        "oui_hex": "00-11-8A",
        "organization": "Viewtran Technology Limited",
        "address_1": "3/F, R2-A builiding, High Tech Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001184": {
        "oui_hex": "00-11-84",
        "organization": "Humo Laboratory,Ltd.",
        "address_1": "Nishiogi-Kita 5-19-11",
        "address_2": "Suginami-ku  Tokyo  167-0042",
        "country": "JP"
    },
    "0011B1": {
        "oui_hex": "00-11-B1",
        "organization": "BlueExpert Technology Corp.",
        "address_1": "8F,No.16,Lane 77,Xing-Ai Rd,Nei-Hu District",
        "address_2": "Taipei    11494",
        "country": "TW"
    },
    "0011A6": {
        "oui_hex": "00-11-A6",
        "organization": "Sypixx Networks",
        "address_1": "108 Bank Street",
        "address_2": "Waterbury  CT  06702",
        "country": "US"
    },
    "0011B5": {
        "oui_hex": "00-11-B5",
        "organization": "Shenzhen Powercom Co.,Ltd",
        "address_1": "Floor 16,Tower B,Zhongyin Building,North Caitian Road,Futian District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong province  518028",
        "country": "CN"
    },
    "0011BB": {
        "oui_hex": "00-11-BB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001166": {
        "oui_hex": "00-11-66",
        "organization": "Taelim Electronics Co., Ltd.",
        "address_1": "196-5, ANYANG7-DONG MANAN-GU",
        "address_2": "ANYANG-SI  KYUGGI-DO  430-817",
        "country": "KR"
    },
    "001164": {
        "oui_hex": "00-11-64",
        "organization": "ACARD Technology Corp.",
        "address_1": "6F No.78 Sec1 Kwang Fu Road, Sanchung,",
        "address_2": "Taipei Hsien    241",
        "country": "TW"
    },
    "0011A2": {
        "oui_hex": "00-11-A2",
        "organization": "Manufacturing Technology Inc",
        "address_1": "70 Ready Ave NW",
        "address_2": "Fort Walton Beach  FL  32548",
        "country": "US"
    },
    "00119E": {
        "oui_hex": "00-11-9E",
        "organization": "Solectron Brazil",
        "address_1": "Rod. Campinas Mogi Mirim",
        "address_2": "Jaguariuna  SP  13820-000",
        "country": "BR"
    },
    "001173": {
        "oui_hex": "00-11-73",
        "organization": "SMART Storage Systems",
        "address_1": "2600 W Geronimo Place",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "001125": {
        "oui_hex": "00-11-25",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "00111C": {
        "oui_hex": "00-11-1C",
        "organization": "Pleora Technologies Inc.",
        "address_1": "359 Terry Fox Drive, Suite 230",
        "address_2": "Kanata  ON  K2K 2E7",
        "country": "CA"
    },
    "00111F": {
        "oui_hex": "00-11-1F",
        "organization": "Doremi Labs, Inc.",
        "address_1": "306 E. Alameda Ave.",
        "address_2": "Burbank  CA  91502",
        "country": "US"
    },
    "00111D": {
        "oui_hex": "00-11-1D",
        "organization": "Hectrix Limited",
        "address_1": "Unit 906-911, 9/F, Stanhope Hosue,",
        "address_2": "North Point  Hong Kong",
        "country": "CN"
    },
    "001119": {
        "oui_hex": "00-11-19",
        "organization": "Solteras, Inc.",
        "address_1": "900 W. Santa Anita Street",
        "address_2": "San Gabriel  CA  91776",
        "country": "US"
    },
    "001150": {
        "oui_hex": "00-11-50",
        "organization": "Belkin Corporation",
        "address_1": "501 West Walnut Street",
        "address_2": "Compton  CA  90220-5221",
        "country": "US"
    },
    "001146": {
        "oui_hex": "00-11-46",
        "organization": "Telecard-Pribor Ltd",
        "address_1": "Lustdorfskaya doroga, 162",
        "address_2": "Odessa    65115",
        "country": "UA"
    },
    "00110D": {
        "oui_hex": "00-11-0D",
        "organization": "SANBlaze Technology, Inc.",
        "address_1": "2 Clock Tower Place",
        "address_2": "Maynard  MA  01748",
        "country": "US"
    },
    "001106": {
        "oui_hex": "00-11-06",
        "organization": "Siemens NV (Belgium)",
        "address_1": "Atealaan 34",
        "address_2": "Herentals  Antwerp  2200",
        "country": "BE"
    },
    "000FF4": {
        "oui_hex": "00-0F-F4",
        "organization": "Guntermann & Drunck GmbH",
        "address_1": "Obere Leimbach 9",
        "address_2": "Siegen  NRW  57074",
        "country": "DE"
    },
    "000FF8": {
        "oui_hex": "00-0F-F8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00112C": {
        "oui_hex": "00-11-2C",
        "organization": "IZT GmbH",
        "address_1": "Am Weichselgarten 5",
        "address_2": "Erlangen  Bavaria  91058",
        "country": "DE"
    },
    "001114": {
        "oui_hex": "00-11-14",
        "organization": "EverFocus Electronics Corp.",
        "address_1": "12F, No. 79, Sec. 1, Shin-Tai Wu Rd.",
        "address_2": "Hsi-Chi  Taipei Hsien  221",
        "country": "TW"
    },
    "00110E": {
        "oui_hex": "00-11-0E",
        "organization": "Tsurusaki Sealand Transportation Co. Ltd.",
        "address_1": "1000 Misa",
        "address_2": "Oita    8700196",
        "country": "JP"
    },
    "00114C": {
        "oui_hex": "00-11-4C",
        "organization": "caffeina applied research ltd.",
        "address_1": "125 baird ave",
        "address_2": "cochrane  alberta  t4c 1c7",
        "country": "CA"
    },
    "001141": {
        "oui_hex": "00-11-41",
        "organization": "GoodMan Corporation",
        "address_1": "2F, No.572, Sec.1, Ming-Sheng N Road, Kwei-Shan Hsiang",
        "address_2": "Taoyuan Hsien    33300",
        "country": "TW"
    },
    "001155": {
        "oui_hex": "00-11-55",
        "organization": "Sevis Systems",
        "address_1": "2805 N Dallas Parkway, STE 530",
        "address_2": "Plano  Texas  75093",
        "country": "US"
    },
    "001152": {
        "oui_hex": "00-11-52",
        "organization": "Eidsvoll Electronics AS",
        "address_1": "Nedre Vilberg vei 8",
        "address_2": "Eidsvoll    N-2080",
        "country": "NO"
    },
    "000FCF": {
        "oui_hex": "00-0F-CF",
        "organization": "DataWind Research",
        "address_1": "555 Rene-Levesque West",
        "address_2": "Montreal  Quebec  H2Z 1B1",
        "country": "CA"
    },
    "000FD2": {
        "oui_hex": "00-0F-D2",
        "organization": "EWA Technologies, Inc.",
        "address_1": "13873 Park Center Road",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "000FCE": {
        "oui_hex": "00-0F-CE",
        "organization": "Kikusui Electronics Corp.",
        "address_1": "1-1-3,Higashi yamata",
        "address_2": "Yokohama  Kanagawa  224-0023",
        "country": "JP"
    },
    "000FEB": {
        "oui_hex": "00-0F-EB",
        "organization": "Cylon Controls",
        "address_1": "Clonshaugh Industrial Estate",
        "address_2": "Dublin 17",
        "country": "IE"
    },
    "000FDC": {
        "oui_hex": "00-0F-DC",
        "organization": "Ueda Japan  Radio Co., Ltd.",
        "address_1": "Fumiiri 2-10-19",
        "address_2": "Ueda city  Nagano prefecture  386-8608",
        "country": "JP"
    },
    "000F8E": {
        "oui_hex": "00-0F-8E",
        "organization": "DONGYANG TELECOM CO.,LTD.",
        "address_1": "642-7, DEUNGCHON-DONG, KANGSEO-GU",
        "address_2": "SEOUL  KANGSE-GU  157-841",
        "country": "KR"
    },
    "000F91": {
        "oui_hex": "00-0F-91",
        "organization": "Aerotelecom Co.,Ltd.",
        "address_1": "195-58 Anyang 7 Dong",
        "address_2": "Anyang  Kyunggi  430-817",
        "country": "US"
    },
    "000F87": {
        "oui_hex": "00-0F-87",
        "organization": "Maxcess International",
        "address_1": "222 W. Memorial Road",
        "address_2": "Oklahoma City  OK  73114",
        "country": "US"
    },
    "000FA1": {
        "oui_hex": "00-0F-A1",
        "organization": "Gigabit Systems Inc.",
        "address_1": "Fuyoh Video Building 3F",
        "address_2": "Yokohama  Kanagawa  241-0826",
        "country": "JP"
    },
    "000F99": {
        "oui_hex": "00-0F-99",
        "organization": "APAC opto Electronics Inc.",
        "address_1": "3 Tzu Chiang Road, Hsinchu Industrial Park",
        "address_2": "Hukow, Hsinchu Hsien    303",
        "country": "TW"
    },
    "000FF5": {
        "oui_hex": "00-0F-F5",
        "organization": "GN&S company",
        "address_1": "301 Ansan S/W center, 643-7 wongok-dong",
        "address_2": "Ansan city  Gyeonggi-do  425-130",
        "country": "KR"
    },
    "000FE8": {
        "oui_hex": "00-0F-E8",
        "organization": "Lobos, Inc.",
        "address_1": "U&T Bldg 3F, 1-2-3 Sarugaku-cho, Chiyoda-ku,",
        "address_2": "Tokyo    101-0064",
        "country": "JP"
    },
    "000FB2": {
        "oui_hex": "00-0F-B2",
        "organization": "Broadband Pacenet (India) Pvt. Ltd.",
        "address_1": "7-B, Shah Industrial Estate, Off Veera Desai Road",
        "address_2": "Mumbai  Maharashtra  400 053",
        "country": "IN"
    },
    "000FD7": {
        "oui_hex": "00-0F-D7",
        "organization": "Harman Music Group",
        "address_1": "8760 Sandy Parkway",
        "address_2": "Sandy  Utah  84070",
        "country": "US"
    },
    "000FD4": {
        "oui_hex": "00-0F-D4",
        "organization": "Soundcraft",
        "address_1": "Cranborne House",
        "address_2": "Potters Bar  Hertfordshire  EN6 3JN",
        "country": "GB"
    },
    "000FAF": {
        "oui_hex": "00-0F-AF",
        "organization": "Dialog Inc.",
        "address_1": "1-47-9",
        "address_2": "Toshima-ku  Tokyo  1700013",
        "country": "JP"
    },
    "000FA5": {
        "oui_hex": "00-0F-A5",
        "organization": "BWA Technology GmbH",
        "address_1": "Johann-Krane-Weg 21",
        "address_2": "Muenster    48149",
        "country": "DE"
    },
    "000F80": {
        "oui_hex": "00-0F-80",
        "organization": "Trinity Security Systems,Inc.",
        "address_1": "Alte Building Higashi Kanda 8F",
        "address_2": "Chiyoda-ku  Tokyo  101-0031",
        "country": "JP"
    },
    "000F32": {
        "oui_hex": "00-0F-32",
        "organization": "Lootom Telcovideo Network Wuxi Co Ltd",
        "address_1": "5F, 9Building,",
        "address_2": "WuXi  JiangSu  214072",
        "country": "CN"
    },
    "000F2A": {
        "oui_hex": "00-0F-2A",
        "organization": "Cableware Electronics",
        "address_1": "1702 Western Ave.",
        "address_2": "Las Vegas  Nevada  89102",
        "country": "US"
    },
    "000F29": {
        "oui_hex": "00-0F-29",
        "organization": "Augmentix Corporation",
        "address_1": "4030 W Braker Ln",
        "address_2": "Austin  Texas  78759",
        "country": "US"
    },
    "000F27": {
        "oui_hex": "00-0F-27",
        "organization": "TEAL Electronics, Inc.",
        "address_1": "10350 Sorrento Valley Road",
        "address_2": "San Diego  California  92121",
        "country": "US"
    },
    "000F43": {
        "oui_hex": "00-0F-43",
        "organization": "Wasabi Systems Inc.",
        "address_1": "500 E. Main Street",
        "address_2": "Norfolk  VA  23510",
        "country": "US"
    },
    "000F48": {
        "oui_hex": "00-0F-48",
        "organization": "Polypix Inc.",
        "address_1": "1Fl, Sungdo Venture Tower, 165-2 Samsung-Dong, Kangnam-Ku",
        "address_2": "Seoul    135-881",
        "country": "KR"
    },
    "000F50": {
        "oui_hex": "00-0F-50",
        "organization": "StreamScale Limited",
        "address_1": "The Court, Alexandra Park",
        "address_2": "St Helens    WA10 3TP",
        "country": "GB"
    },
    "000F4E": {
        "oui_hex": "00-0F-4E",
        "organization": "Cellink",
        "address_1": "Catherinalaan 37",
        "address_2": "Rotselaar  Vlaams Brabant  B-3110",
        "country": "BE"
    },
    "000F47": {
        "oui_hex": "00-0F-47",
        "organization": "ROBOX SPA",
        "address_1": "via Sempione 82",
        "address_2": "Castelletto S.Ticino  NO  28053",
        "country": "IT"
    },
    "000F18": {
        "oui_hex": "00-0F-18",
        "organization": "Industrial Control Systems",
        "address_1": "Houtschelf 1",
        "address_2": "Hardinxveld  Zuid-Holland  NL-3371 KB",
        "country": "NL"
    },
    "000F1D": {
        "oui_hex": "00-0F-1D",
        "organization": "Cosmo Techs Co., Ltd.",
        "address_1": "2-6-1, Matsue",
        "address_2": "Atsugi-shi  Kanagawa-ken  243-0005",
        "country": "JP"
    },
    "000F1B": {
        "oui_hex": "00-0F-1B",
        "organization": "Ego Systems Inc.",
        "address_1": "1206 Woolim e-Biz Center II",
        "address_2": "Seoul    150-834",
        "country": "KR"
    },
    "000F78": {
        "oui_hex": "00-0F-78",
        "organization": "Datacap Systems Inc",
        "address_1": "100 New Britain Blvd",
        "address_2": "Chalfont  PA  18914",
        "country": "US"
    },
    "000F70": {
        "oui_hex": "00-0F-70",
        "organization": "Wintec Industries, inc.",
        "address_1": "675 Sycamore Drive",
        "address_2": "Milpitas,  CA  95035",
        "country": "US"
    },
    "000F74": {
        "oui_hex": "00-0F-74",
        "organization": "Qamcom Technology AB",
        "address_1": "Gruvgatan 8",
        "address_2": "Vastra  Frolunda",
        "country": "SE"
    },
    "000F6D": {
        "oui_hex": "00-0F-6D",
        "organization": "Midas Engineering",
        "address_1": "Ace Techno-Tower V #906 197-22",
        "address_2": "Seoul    152-848",
        "country": "KR"
    },
    "000F5F": {
        "oui_hex": "00-0F-5F",
        "organization": "Nicety Technologies Inc. (NTS)",
        "address_1": "792-3 Tomioka Toyoda-cho",
        "address_2": "Iwata-gun  Shizuoka  438-0803",
        "country": "JP"
    },
    "000F5A": {
        "oui_hex": "00-0F-5A",
        "organization": "Peribit Networks",
        "address_1": "2855 Bowers Ave",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "000F31": {
        "oui_hex": "00-0F-31",
        "organization": "Allied Vision Technologies Canada Inc",
        "address_1": "101-3750 North Fraser Way",
        "address_2": "Burnaby  BC  V5J 5E9",
        "country": "CA"
    },
    "000F73": {
        "oui_hex": "00-0F-73",
        "organization": "RS Automation Co., Ltd",
        "address_1": "447-6, Gongse-Dong , Giheung-Gu",
        "address_2": "Youngin-City  Gyeonggi-Do  449-902",
        "country": "KR"
    },
    "000F3C": {
        "oui_hex": "00-0F-3C",
        "organization": "Endeleo Limited",
        "address_1": "78 Cannon Street",
        "address_2": "London  England  EC4N 6NQ",
        "country": "GB"
    },
    "000EAB": {
        "oui_hex": "00-0E-AB",
        "organization": "Cray Inc",
        "address_1": "901 Fifth Avenue",
        "address_2": "Seattle  WA  98104",
        "country": "US"
    },
    "000EAD": {
        "oui_hex": "00-0E-AD",
        "organization": "Metanoia Technologies, Inc.",
        "address_1": "5918 W. courtyard Dr.",
        "address_2": "Austin  TX  78730",
        "country": "US"
    },
    "000EAF": {
        "oui_hex": "00-0E-AF",
        "organization": "CASTEL",
        "address_1": "ZI Saint Lambert des Levées",
        "address_2": "SAUMUR  Maine et Loire  49412",
        "country": "FR"
    },
    "000EF8": {
        "oui_hex": "00-0E-F8",
        "organization": "SBC ASI",
        "address_1": "Network & Infrastructure Technical Support",
        "address_2": "San Antonio  Texas  78215",
        "country": "US"
    },
    "000EF9": {
        "oui_hex": "00-0E-F9",
        "organization": "REA Elektronik GmbH",
        "address_1": "Teichwiesenstraße 1",
        "address_2": "Muehltal  Hessen  64367",
        "country": "DE"
    },
    "000EE6": {
        "oui_hex": "00-0E-E6",
        "organization": "Adimos Systems LTD",
        "address_1": "17 Atirey-Yeda Street",
        "address_2": "Kfar-Saba    44643",
        "country": "IL"
    },
    "000EF6": {
        "oui_hex": "00-0E-F6",
        "organization": "E-TEN Information Systems Co., Ltd.",
        "address_1": "No. 256, Yangguang Street, Neihu Chiu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000EEA": {
        "oui_hex": "00-0E-EA",
        "organization": "Shadong Luneng Jicheng Electronics,Co.,Ltd",
        "address_1": "No.188,east,Huayuan Road",
        "address_2": "Jinan  Shandong  250100",
        "country": "CN"
    },
    "000F0F": {
        "oui_hex": "00-0F-0F",
        "organization": "Real ID Technology Co., Ltd.",
        "address_1": "9F Hanmi B/D 192-19",
        "address_2": "Gangnam-Gu  Seoul  135-010",
        "country": "KR"
    },
    "000F16": {
        "oui_hex": "00-0F-16",
        "organization": "JAY HOW TECHNOLOGY CO.,",
        "address_1": "NO.486,SEC. 1, WAN SHOU RD., KUEI",
        "address_2": "TAOYUAN HSIEN    333",
        "country": "TW"
    },
    "000EC6": {
        "oui_hex": "00-0E-C6",
        "organization": "ASIX ELECTRONICS CORP.",
        "address_1": "4F, NO.8, HSIN ANN RD.,",
        "address_2": "HSINCHU    300",
        "country": "TW"
    },
    "000EBF": {
        "oui_hex": "00-0E-BF",
        "organization": "Remsdaq Limited",
        "address_1": "Parkway",
        "address_2": "Deeside  Flintshire  CH5 2NL",
        "country": "GB"
    },
    "000EFF": {
        "oui_hex": "00-0E-FF",
        "organization": "Megasolution,Inc.",
        "address_1": "2-7-10 Shitaya",
        "address_2": "Taito  TOKYO  110-0004",
        "country": "JP"
    },
    "000EE0": {
        "oui_hex": "00-0E-E0",
        "organization": "Mcharge",
        "address_1": "Firstec Bldg,. 15-4 Youido-Dong",
        "address_2": "seoul  Youido  150-010",
        "country": "KR"
    },
    "000E9F": {
        "oui_hex": "00-0E-9F",
        "organization": "TEMIC SDS GmbH",
        "address_1": "Soeflinger Strasse 100",
        "address_2": "Ulm    89077",
        "country": "DE"
    },
    "000E96": {
        "oui_hex": "00-0E-96",
        "organization": "Cubic Defense Applications, Inc.",
        "address_1": "P.O. Box 85587",
        "address_2": "San Diego  CA  92186-5587",
        "country": "US"
    },
    "000E8E": {
        "oui_hex": "00-0E-8E",
        "organization": "SparkLAN Communications, Inc.",
        "address_1": "3Fl . , No. 246, Sec. 1, Neihu Road., Neihu Chiu,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000E91": {
        "oui_hex": "00-0E-91",
        "organization": "Navico Auckland Ltd",
        "address_1": "17-21 Kawana St",
        "address_2": "Northcote  Auckland",
        "country": "NZ"
    },
    "000E48": {
        "oui_hex": "00-0E-48",
        "organization": "Lipman TransAction Solutions",
        "address_1": "11 Haamal St.",
        "address_2": " Rosh-Haayin    48092",
        "country": "IL"
    },
    "000E3E": {
        "oui_hex": "00-0E-3E",
        "organization": "Sun Optronics Inc",
        "address_1": "4-38-4 Fuchinobe-honchou",
        "address_2": "Sagamihara  Kanagawa  229-0002",
        "country": "JP"
    },
    "000E33": {
        "oui_hex": "00-0E-33",
        "organization": "Shuko Electronics Co.,Ltd",
        "address_1": "TOHSHIN HIGASHI-IKEBUKURO Building 3F",
        "address_2": "TOKYO  KANTOH  170-0063",
        "country": "JP"
    },
    "000E75": {
        "oui_hex": "00-0E-75",
        "organization": "New York Air Brake Corp.",
        "address_1": "748 Starbuck Ave.",
        "address_2": "Watertown  NY  13601",
        "country": "US"
    },
    "000E7C": {
        "oui_hex": "00-0E-7C",
        "organization": "Televes S.A.",
        "address_1": "Rua Benefica Conxo 17",
        "address_2": "Santiago de Compostela  Coruña  15706",
        "country": "ES"
    },
    "000E66": {
        "oui_hex": "00-0E-66",
        "organization": "Hitachi Industry & Control Solutions, Ltd.",
        "address_1": "5-1-26, Omika-cho, Hitachi-shi, Ibaraki",
        "address_2": "    319-1221",
        "country": "JP"
    },
    "000E68": {
        "oui_hex": "00-0E-68",
        "organization": "E-TOP Network Technology Inc.",
        "address_1": "No. 7, Shin Shin Rd.,",
        "address_2": "Tainan    702",
        "country": "TW"
    },
    "000E5E": {
        "oui_hex": "00-0E-5E",
        "organization": "Raisecom Technology",
        "address_1": "2 Floor, South Building of Rainbow Plaza",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "000E56": {
        "oui_hex": "00-0E-56",
        "organization": "4G Systems GmbH & Co. KG",
        "address_1": "Jarrestrasse 2-6",
        "address_2": "22303  Hamburg",
        "country": "DE"
    },
    "000E55": {
        "oui_hex": "00-0E-55",
        "organization": "AUVITRAN",
        "address_1": "7c chemin des Prés",
        "address_2": "MEYLAN    38410",
        "country": "FR"
    },
    "000E73": {
        "oui_hex": "00-0E-73",
        "organization": "Tpack A/S",
        "address_1": "Lautrupbjerg 7 - 11",
        "address_2": "DK 2750  Ballerup    DK 2750",
        "country": "DK"
    },
    "000E72": {
        "oui_hex": "00-0E-72",
        "organization": "CTS electronics",
        "address_1": "Corso Vercelli 332",
        "address_2": "Ivrea  Torino  10015",
        "country": "IT"
    },
    "000E6E": {
        "oui_hex": "00-0E-6E",
        "organization": "MAT S.A. (Mircrelec Advanced Technology)",
        "address_1": "Mousounitsis 15",
        "address_2": "Peristeri  Athens",
        "country": "GR"
    },
    "000E84": {
        "oui_hex": "00-0E-84",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E87": {
        "oui_hex": "00-0E-87",
        "organization": "adp Gauselmann GmbH",
        "address_1": "Boschstraße 8",
        "address_2": "Luebbecke  NRW  32312",
        "country": "DE"
    },
    "000E92": {
        "oui_hex": "00-0E-92",
        "organization": "Open Telecom",
        "address_1": "803-804 Daeryung Techno-town II",
        "address_2": "Keuncheon-Ku  Seoul  153-771",
        "country": "KR"
    },
    "000E53": {
        "oui_hex": "00-0E-53",
        "organization": "AV TECH CORPORATION",
        "address_1": "10F,E Building,No.19-11 San Chung Rd.,NanKang",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "000DF9": {
        "oui_hex": "00-0D-F9",
        "organization": "NDS Limited",
        "address_1": "One Heathrow Boulevard",
        "address_2": "West Drayton  Middlesex  UB7 0DQ",
        "country": "GB"
    },
    "000DFD": {
        "oui_hex": "00-0D-FD",
        "organization": "Huges Hi-Tech Inc.,",
        "address_1": "7F, 188, Sec. 2, Chung Hsing Road.",
        "address_2": "Hsin Tien  Taipei Hsien  231",
        "country": "TW"
    },
    "000DFB": {
        "oui_hex": "00-0D-FB",
        "organization": "Komax AG",
        "address_1": "Industriestrasse 6",
        "address_2": "Dierikon  LU  6036",
        "country": "CH"
    },
    "000E00": {
        "oui_hex": "00-0E-00",
        "organization": "Atrie",
        "address_1": "10th Floor, 14, Lane 609, Sec. 5, Chung Hsin Rd., San Chung City,",
        "address_2": "Taipei Hsien  San Chung  241",
        "country": "TW"
    },
    "000DF4": {
        "oui_hex": "00-0D-F4",
        "organization": "Watertek Co.",
        "address_1": "Room 1006,Haitai building,north si Huan",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "000DFA": {
        "oui_hex": "00-0D-FA",
        "organization": "Micro Control Systems Ltd.",
        "address_1": "8-7 Sakurai",
        "address_2": "Saku-shi  Nagano  385-0056",
        "country": "JP"
    },
    "000DFC": {
        "oui_hex": "00-0D-FC",
        "organization": "ITFOR Inc.",
        "address_1": "Ichibancho Tokyu Bidg.,",
        "address_2": "  Tokyo  102-0082",
        "country": "JP"
    },
    "000DFE": {
        "oui_hex": "00-0D-FE",
        "organization": "Hauppauge Computer Works, Inc.",
        "address_1": "91 Cabot Court",
        "address_2": "Hauppauge  New York  11788",
        "country": "US"
    },
    "000DD6": {
        "oui_hex": "00-0D-D6",
        "organization": "ITI    LTD",
        "address_1": "R&D,ITI Bangalore Complex",
        "address_2": "Dooravani Nagar, Bangalore  Karnataka State  560016",
        "country": "IN"
    },
    "000DD5": {
        "oui_hex": "00-0D-D5",
        "organization": "O'RITE TECHNOLOGY CO.,LTD",
        "address_1": "4f-8,NO 80,GUANGFU RD.SEC 2,SANCHUNG",
        "address_2": "TAIPEI COUNTY    241",
        "country": "TW"
    },
    "000E0F": {
        "oui_hex": "00-0E-0F",
        "organization": "ERMME",
        "address_1": "9 rue Lavoisier",
        "address_2": "Vert-Le-Petit    91710",
        "country": "FR"
    },
    "000E10": {
        "oui_hex": "00-0E-10",
        "organization": "C-guys, Inc.",
        "address_1": "Izumi Garden Wing 1F, 1-6-3",
        "address_2": "Tokyo    106-0032",
        "country": "JP"
    },
    "000E0A": {
        "oui_hex": "00-0E-0A",
        "organization": "SAKUMA DESIGN OFFICE",
        "address_1": "674-11",
        "address_2": "KUKI-SHI  SAITAMA  346-0029",
        "country": "JP"
    },
    "000E0E": {
        "oui_hex": "00-0E-0E",
        "organization": "ESA elettronica S.P.A.",
        "address_1": "",
        "address_2": "Mariano Comense  CO  22066",
        "country": "IT"
    },
    "000E18": {
        "oui_hex": "00-0E-18",
        "organization": "MyA Technology",
        "address_1": "2100 Muirwood Way",
        "address_2": "San Jose  CA  95132",
        "country": "US"
    },
    "000E14": {
        "oui_hex": "00-0E-14",
        "organization": "Visionary Solutions, Inc.",
        "address_1": "4193 Carpinteria Ave",
        "address_2": "Carpinteria  CA  93013",
        "country": "US"
    },
    "000E1B": {
        "oui_hex": "00-0E-1B",
        "organization": "IAV GmbH",
        "address_1": "Carnotstraße 1",
        "address_2": "Berlin    10587",
        "country": "DE"
    },
    "000E13": {
        "oui_hex": "00-0E-13",
        "organization": "Accu-Sort Systems inc.",
        "address_1": "511 School House Road",
        "address_2": "Telford  PA  18969",
        "country": "US"
    },
    "000DDE": {
        "oui_hex": "00-0D-DE",
        "organization": "Joyteck Co., Ltd.",
        "address_1": "19F, No.4, Sec. 3, Min Chuan East Rd.",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "000DE2": {
        "oui_hex": "00-0D-E2",
        "organization": "CMZ Sistemi Elettronici",
        "address_1": "Via dell'Artiginato, 21",
        "address_2": "Vascon di Carbonera  Treviso  31050",
        "country": "IT"
    },
    "000DDA": {
        "oui_hex": "00-0D-DA",
        "organization": "ALLIED TELESIS K.K.",
        "address_1": "PIAZZA TIRANA N. 24/4 B",
        "address_2": "MILANO    20147",
        "country": "IT"
    },
    "000DCD": {
        "oui_hex": "00-0D-CD",
        "organization": "GROUPE TXCOM",
        "address_1": "ZI DU PETIT CLAMART",
        "address_2": "LE PLESSIS ROBINSON  HAUTS-DE-SEINE  92350",
        "country": "FR"
    },
    "000DCA": {
        "oui_hex": "00-0D-CA",
        "organization": "Tait Electronics",
        "address_1": "535 Wairakei Rd",
        "address_2": "Christchurch  Canterbury  8005",
        "country": "NZ"
    },
    "000DCF": {
        "oui_hex": "00-0D-CF",
        "organization": "Cidra Corp.",
        "address_1": "50 Barns Park North",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "000E3A": {
        "oui_hex": "00-0E-3A",
        "organization": "Cirrus Logic",
        "address_1": "2901 Via Fortuna",
        "address_2": "Austin  TX  78746",
        "country": "US"
    },
    "000E3B": {
        "oui_hex": "00-0E-3B",
        "organization": "Hawking Technologies, Inc.",
        "address_1": "15281A Barranca Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000DEC": {
        "oui_hex": "00-0D-EC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000DF2": {
        "oui_hex": "00-0D-F2",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000E27": {
        "oui_hex": "00-0E-27",
        "organization": "Crere Networks, Inc.",
        "address_1": "Room 110 ETRI TBI, 52 Eoeun-dong",
        "address_2": "Daejeon    305-333",
        "country": "KR"
    },
    "000DA0": {
        "oui_hex": "00-0D-A0",
        "organization": "NEDAP N.V.",
        "address_1": "P.O.Box 103",
        "address_2": "GROENLO  GLD  7141 AC",
        "country": "NL"
    },
    "000D8E": {
        "oui_hex": "00-0D-8E",
        "organization": "Koden Electronics Co., Ltd.",
        "address_1": "5278 Uenohara",
        "address_2": "  Yamanashi-Ken  409-0112",
        "country": "JP"
    },
    "000D8A": {
        "oui_hex": "00-0D-8A",
        "organization": "Winners Electronics Co., Ltd.",
        "address_1": "#340-5,Wonchun-Dong,Paldal-Gu",
        "address_2": "Suwon-City  Kyungki-Do  442-823",
        "country": "KR"
    },
    "000D7E": {
        "oui_hex": "00-0D-7E",
        "organization": "Axiowave Networks, Inc.",
        "address_1": "200 Nickerson Road",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "000D71": {
        "oui_hex": "00-0D-71",
        "organization": "boca systems",
        "address_1": "1065 s. rogers circle",
        "address_2": "boca raton  fl  33487",
        "country": "US"
    },
    "000D5A": {
        "oui_hex": "00-0D-5A",
        "organization": "Tiesse SpA",
        "address_1": "Via Asti",
        "address_2": "Ivrea  TO  10015",
        "country": "IT"
    },
    "000DB8": {
        "oui_hex": "00-0D-B8",
        "organization": "SCHILLER AG",
        "address_1": "Altgasse 68",
        "address_2": "Baar  Zug  6300",
        "country": "CH"
    },
    "000DC4": {
        "oui_hex": "00-0D-C4",
        "organization": "Emcore Corporation",
        "address_1": "1600 Eubank Blvd, SE",
        "address_2": "Albuquerque  New Mexico  87123",
        "country": "US"
    },
    "000D9B": {
        "oui_hex": "00-0D-9B",
        "organization": "Heraeus Electro-Nite International N.V.",
        "address_1": "Centrum Zuid 1105",
        "address_2": "Houthalen    3530",
        "country": "BE"
    },
    "000D7C": {
        "oui_hex": "00-0D-7C",
        "organization": "Codian Ltd",
        "address_1": "14 Waterside Drive",
        "address_2": "Langley  Slough  SL3 6EZ",
        "country": "GB"
    },
    "000D6B": {
        "oui_hex": "00-0D-6B",
        "organization": "Mita-Teknik A/S",
        "address_1": "Haandvaerkervej 1",
        "address_2": "Roedkaersbro    DK-8840",
        "country": "DK"
    },
    "000D43": {
        "oui_hex": "00-0D-43",
        "organization": "DRS Tactical Systems Inc.",
        "address_1": "3520 U.S. Highway 1",
        "address_2": "Palm Bay  FL  32905",
        "country": "US"
    },
    "000D44": {
        "oui_hex": "00-0D-44",
        "organization": "Audio BU - Logitech",
        "address_1": "1499 SE Tech Center Place",
        "address_2": "Vancouver  WA  98683",
        "country": "US"
    },
    "000D36": {
        "oui_hex": "00-0D-36",
        "organization": "Wu Han Routon Electronic Co., Ltd",
        "address_1": "Miao Shan District, East Lake Hi-Tech",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "000D3D": {
        "oui_hex": "00-0D-3D",
        "organization": "Hammerhead Systems, Inc.",
        "address_1": "640 Clyde Court",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "000D3E": {
        "oui_hex": "00-0D-3E",
        "organization": "APLUX Communications Ltd.",
        "address_1": "10F, No. 166, Dah-Yeh Rd., Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "000D0D": {
        "oui_hex": "00-0D-0D",
        "organization": "ITSupported, LLC",
        "address_1": "4989 Peachtree Parkway",
        "address_2": "Norcross  GA  30092",
        "country": "US"
    },
    "000D06": {
        "oui_hex": "00-0D-06",
        "organization": "Compulogic Limited",
        "address_1": "Unit W3, MK TWO Business Centre",
        "address_2": "Water Eaton  Milton Keynes  MK2 3HU",
        "country": "GB"
    },
    "000D4A": {
        "oui_hex": "00-0D-4A",
        "organization": "Steag ETA-Optik",
        "address_1": "Borsigstrasse 78.-80",
        "address_2": "Heinsberg    52525",
        "country": "DE"
    },
    "000D4F": {
        "oui_hex": "00-0D-4F",
        "organization": "Kenwood Corporation",
        "address_1": "2967-3, Ishikawa-machi",
        "address_2": "Hachioji-shi  Tokyo  192-8525",
        "country": "JP"
    },
    "000D47": {
        "oui_hex": "00-0D-47",
        "organization": "Collex",
        "address_1": "13F-3,No.142,Sec.1,Huamei W,St.,Shi Chiu",
        "address_2": "Taichung    403",
        "country": "TW"
    },
    "000D61": {
        "oui_hex": "00-0D-61",
        "organization": "Giga-Byte Technology Co., Ltd.",
        "address_1": "No 6, Bau Chiang Road, Hsin-Tien",
        "address_2": "Taipei Hsien    9999",
        "country": "TW"
    },
    "000D3B": {
        "oui_hex": "00-0D-3B",
        "organization": "Microelectronics Technology Inc.",
        "address_1": "No1, Innovation Road II",
        "address_2": "    300",
        "country": "TW"
    },
    "000D2D": {
        "oui_hex": "00-0D-2D",
        "organization": "NCT Deutschland GmbH",
        "address_1": "Wildenbruchstraße 15",
        "address_2": "Jena  Thüringen  07745",
        "country": "DE"
    },
    "000D1E": {
        "oui_hex": "00-0D-1E",
        "organization": "Control Techniques",
        "address_1": "The Gro",
        "address_2": "Newtown  Powys  SY16 3BE",
        "country": "GB"
    },
    "000D52": {
        "oui_hex": "00-0D-52",
        "organization": "Comart system",
        "address_1": "No. 211, Ace Techno Tower III, 197-48",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "000D1A": {
        "oui_hex": "00-0D-1A",
        "organization": "Mustek System Inc.",
        "address_1": "No. 25, R&D Road, Science-Based Industri",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "000CB8": {
        "oui_hex": "00-0C-B8",
        "organization": "MEDION AG",
        "address_1": "Am Zehnthof 77",
        "address_2": "Essen  NRW  45307",
        "country": "DE"
    },
    "000CBB": {
        "oui_hex": "00-0C-BB",
        "organization": "ISKRAEMECO",
        "address_1": "Savska loka 4",
        "address_2": "Kranj  Gorenjska  4000",
        "country": "SI"
    },
    "000CC0": {
        "oui_hex": "00-0C-C0",
        "organization": "Genera Oy",
        "address_1": "Niittylanpolku 16",
        "address_2": "Helsinki    00621",
        "country": "FI"
    },
    "000CA8": {
        "oui_hex": "00-0C-A8",
        "organization": "Garuda Networks Corporation",
        "address_1": "48499 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000D03": {
        "oui_hex": "00-0D-03",
        "organization": "Matrics, Inc.",
        "address_1": "8850 Stanford Blvd",
        "address_2": "Columbia  MD  21045",
        "country": "US"
    },
    "000CFF": {
        "oui_hex": "00-0C-FF",
        "organization": "MRO-TEK Realty Limited",
        "address_1": "#6, New BEL Road",
        "address_2": "Chikkamaranahalli  Bangalore  560 054",
        "country": "IN"
    },
    "000CFA": {
        "oui_hex": "00-0C-FA",
        "organization": "Digital Systems Corp",
        "address_1": "3 North Main Street",
        "address_2": "Walkersville  Maryland  21793",
        "country": "US"
    },
    "000CFD": {
        "oui_hex": "00-0C-FD",
        "organization": "Hyundai ImageQuest Co.,Ltd.",
        "address_1": "San 136-1, Ami-ri, Bubal-eub",
        "address_2": "Ichon-si  Kyoung ki-do  467-701",
        "country": "KR"
    },
    "000CD3": {
        "oui_hex": "00-0C-D3",
        "organization": "Prettl Elektronik Radeberg GmbH",
        "address_1": "Robert-Bosch-Str. 10",
        "address_2": "Radeberg  Saxony  D-01454",
        "country": "DE"
    },
    "000CD7": {
        "oui_hex": "00-0C-D7",
        "organization": "Nallatech Ltd",
        "address_1": "Boolean House",
        "address_2": "Glasgow  Scotland  G68 0BH",
        "country": "GB"
    },
    "000CD4": {
        "oui_hex": "00-0C-D4",
        "organization": "Positron Public Safety Systems inc.",
        "address_1": "5101 Buchan",
        "address_2": "Montreal  Quebec  H4P 2R9",
        "country": "CA"
    },
    "000CD6": {
        "oui_hex": "00-0C-D6",
        "organization": "PARTNER TECH",
        "address_1": "10F, NO.233-2,PAO CHIAO ROAD, SHIN TIEN",
        "address_2": "TAIPEI    231",
        "country": "TW"
    },
    "000CB9": {
        "oui_hex": "00-0C-B9",
        "organization": "LEA",
        "address_1": "Bat LA FAYETTE",
        "address_2": "Paris  RP  924051",
        "country": "FR"
    },
    "000CBD": {
        "oui_hex": "00-0C-BD",
        "organization": "Interface Masters, Inc",
        "address_1": "2381 Zanker Rd., Suite 130",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "000CB2": {
        "oui_hex": "00-0C-B2",
        "organization": "UNION co., ltd.",
        "address_1": "14Beon-Gil 17, UiChang-Gu,",
        "address_2": "GyeongSnagNam-Do    641-846",
        "country": "KR"
    },
    "000CEB": {
        "oui_hex": "00-0C-EB",
        "organization": "CNMP Networks, Inc.",
        "address_1": "1245 S. Winchester Blvd.",
        "address_2": "San Jose  CA  95128",
        "country": "US"
    },
    "000CCC": {
        "oui_hex": "00-0C-CC",
        "organization": "Aeroscout Ltd.",
        "address_1": "3 Pekeris St.",
        "address_2": "Rehovot    76701",
        "country": "IL"
    },
    "000CC7": {
        "oui_hex": "00-0C-C7",
        "organization": "Intelligent Computer Solutions Inc.",
        "address_1": "9350 Eton St.",
        "address_2": "Chatsworth  CA  91301",
        "country": "US"
    },
    "000CBE": {
        "oui_hex": "00-0C-BE",
        "organization": "Innominate Security Technologies AG",
        "address_1": "Rudower Chaussee 13",
        "address_2": "12489  Berlin",
        "country": "DE"
    },
    "000CA7": {
        "oui_hex": "00-0C-A7",
        "organization": "Metro (Suzhou) Technologies Co., Ltd.",
        "address_1": "No.221 Xinghai Street, Suzhou Industrial Park",
        "address_2": "Suzhou  Jiang Su Province  215021",
        "country": "CN"
    },
    "000CEF": {
        "oui_hex": "00-0C-EF",
        "organization": "Open Networks Engineering Ltd",
        "address_1": "Classic House",
        "address_2": "Bishop's Stortford  Hertfordshire  CM23 5PD",
        "country": "GB"
    },
    "000C64": {
        "oui_hex": "00-0C-64",
        "organization": "X2 MSA Group",
        "address_1": "Care of: Agilent Technologies",
        "address_2": "Ipswich,  Suffolk  IP1 5PB",
        "country": "GB"
    },
    "000CA0": {
        "oui_hex": "00-0C-A0",
        "organization": "StorCase Technology, Inc.",
        "address_1": "17600 Newhope St.",
        "address_2": "Fountain Valley  CA  92708",
        "country": "US"
    },
    "000C99": {
        "oui_hex": "00-0C-99",
        "organization": "HITEL LINK Co.,Ltd",
        "address_1": "Samsung Omni Tower 4th Fl., 395-62",
        "address_2": "Seoul    156-010",
        "country": "KR"
    },
    "000C5A": {
        "oui_hex": "00-0C-5A",
        "organization": "IBSmm Embedded Electronics Consulting",
        "address_1": "Teufelsgrabenweg 1",
        "address_2": "Valley  Bavaria  D-83626",
        "country": "DE"
    },
    "000C5E": {
        "oui_hex": "00-0C-5E",
        "organization": "Calypso Medical",
        "address_1": "2101 Fourth Avenue, Suite 1550",
        "address_2": "Seattle  WA  98121",
        "country": "US"
    },
    "000C61": {
        "oui_hex": "00-0C-61",
        "organization": "AC Tech corporation DBA Advanced Digital",
        "address_1": "1250-G Avenida Acaso",
        "address_2": "Camarillo  CA  93010",
        "country": "US"
    },
    "000C5F": {
        "oui_hex": "00-0C-5F",
        "organization": "Avtec, Inc.",
        "address_1": "4335 Augusta Hwy",
        "address_2": "Gilbert  SC  29054",
        "country": "US"
    },
    "000C4B": {
        "oui_hex": "00-0C-4B",
        "organization": "Cheops Elektronik",
        "address_1": "Jeschkenstrasse 32",
        "address_2": "Geretsried  Bayern  82538",
        "country": "DE"
    },
    "000C45": {
        "oui_hex": "00-0C-45",
        "organization": "Animation Technologies Inc.",
        "address_1": "8F,No.138,Lane 235,Paochiao Road,",
        "address_2": "Taipei Hsien    231",
        "country": "TW"
    },
    "000C3C": {
        "oui_hex": "00-0C-3C",
        "organization": "MediaChorus, Inc.",
        "address_1": "#205, ETRI TBI 2 Center",
        "address_2": "Daejon  DJ  305-333",
        "country": "KR"
    },
    "000C7C": {
        "oui_hex": "00-0C-7C",
        "organization": "Internet Information Image Inc.",
        "address_1": "Fl. 6, No. 1, Alley 20, Lane 26, Rueigua",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000C7B": {
        "oui_hex": "00-0C-7B",
        "organization": "ALPHA PROJECT Co.,Ltd.",
        "address_1": "834 Sekishi,Higashi-ku,Hamamatsu-city",
        "address_2": "Shizuoka    431-3114",
        "country": "JP"
    },
    "000C77": {
        "oui_hex": "00-0C-77",
        "organization": "Life Racing Ltd",
        "address_1": "Unit 6 Repton Close",
        "address_2": "Basildon  Essex  SS13 1LE",
        "country": "GB"
    },
    "000C69": {
        "oui_hex": "00-0C-69",
        "organization": "National Radio Astronomy Observatory",
        "address_1": "P.O. Box O",
        "address_2": "Socorro  NM  87801",
        "country": "US"
    },
    "000C66": {
        "oui_hex": "00-0C-66",
        "organization": "Pronto Networks Inc",
        "address_1": "4637 Chabot Dr",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "000C88": {
        "oui_hex": "00-0C-88",
        "organization": "Apache Micro Peripherals, Inc.",
        "address_1": "17526 Von Karman Ave",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "000C82": {
        "oui_hex": "00-0C-82",
        "organization": "NETWORK TECHNOLOGIES INC",
        "address_1": "1275 DANNER DRIVE",
        "address_2": "AURORA  OH  44202",
        "country": "US"
    },
    "000C8D": {
        "oui_hex": "00-0C-8D",
        "organization": "MATRIX VISION GmbH",
        "address_1": "Talstrasse 16",
        "address_2": "Oppenweiler  Baden-Württemberg  D-71570",
        "country": "DE"
    },
    "000C89": {
        "oui_hex": "00-0C-89",
        "organization": "AC Electric Vehicles, Ltd.",
        "address_1": "Markkinakuja 3",
        "address_2": "Jokela    05400",
        "country": "FI"
    },
    "000C4E": {
        "oui_hex": "00-0C-4E",
        "organization": "Winbest Technology CO,LT",
        "address_1": "7F-5No.736 Chung ChengRd.,ChungHo",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "000BFE": {
        "oui_hex": "00-0B-FE",
        "organization": "CASTEL Broadband Limited",
        "address_1": "9/F., Sui Ying Industrial Building.,",
        "address_2": "Tokwawan  Kowloon  150",
        "country": "HK"
    },
    "000BF5": {
        "oui_hex": "00-0B-F5",
        "organization": "Shanghai Sibo Telecom Technology Co.,Ltd",
        "address_1": "Floor 6 Building 18,300 Tianlin Rd.",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "000C27": {
        "oui_hex": "00-0C-27",
        "organization": "Sammy Corporation",
        "address_1": "SUN SHINE60 45F,3-1-1,HIGASHI-IKEBUKURO",
        "address_2": "TOSHIMA-KU  TOKYO  170-6045",
        "country": "JP"
    },
    "000C2A": {
        "oui_hex": "00-0C-2A",
        "organization": "OCTTEL Communication Co., Ltd.",
        "address_1": "7F-1, No.300, Daduen 10th St.",
        "address_2": "Taichung City    408",
        "country": "TW"
    },
    "000C1C": {
        "oui_hex": "00-0C-1C",
        "organization": "MicroWeb Co., Ltd.",
        "address_1": "403 T/S/S/C, 23-14 Jang-dong, Yusong-gu,",
        "address_2": "Daejeon  ChoongChungDo  305-343",
        "country": "KR"
    },
    "000BDF": {
        "oui_hex": "00-0B-DF",
        "organization": "Shenzhen RouterD Networks Limited",
        "address_1": "8/F, Building A, Tsinghua Hi-Tech Park",
        "address_2": "Shenzhen",
        "country": "CN"
    },
    "000BE6": {
        "oui_hex": "00-0B-E6",
        "organization": "Datel Electronics",
        "address_1": "Stafford Road",
        "address_2": "Stone  Staffordshire  ST15 0DG",
        "country": "GB"
    },
    "000BF2": {
        "oui_hex": "00-0B-F2",
        "organization": "Chih-Kan Technology Co., Ltd.",
        "address_1": "No. 24-1, Pei Shih Chou, Ming Ho Vill.",
        "address_2": "Shan Sun Hsiang  Tainan Hsien  180",
        "country": "TW"
    },
    "000BEB": {
        "oui_hex": "00-0B-EB",
        "organization": "Systegra AG",
        "address_1": "Burgunderstrasse 15",
        "address_2": "Bellach  SO  4512",
        "country": "CH"
    },
    "000BEF": {
        "oui_hex": "00-0B-EF",
        "organization": "Code Corporation",
        "address_1": "11814 S. Election Rd., Ste 200",
        "address_2": "Draper  Utah  84020",
        "country": "US"
    },
    "000C05": {
        "oui_hex": "00-0C-05",
        "organization": "RPA Reserch Co., Ltd.",
        "address_1": "4F, 90-7, Yangjae-Dong, Seocho-Ku",
        "address_2": "Seoul    137-130",
        "country": "US"
    },
    "000C22": {
        "oui_hex": "00-0C-22",
        "organization": "Double D Electronics Ltd",
        "address_1": "Unit 6, Robins Wharf",
        "address_2": "Northfleet  Kent  DA11 9AX",
        "country": "GB"
    },
    "000C0F": {
        "oui_hex": "00-0C-0F",
        "organization": "Techno-One Co., Ltd",
        "address_1": "9-17-1 Higashi Sonoda",
        "address_2": "Amagasaki  Hyogo  661-0953",
        "country": "JP"
    },
    "000C38": {
        "oui_hex": "00-0C-38",
        "organization": "TelcoBridges Inc.",
        "address_1": "586 Du Chenal",
        "address_2": "Repentigny  Quebec  J6A 7C5",
        "country": "CA"
    },
    "000BAF": {
        "oui_hex": "00-0B-AF",
        "organization": "WOOJU COMMUNICATIONS Co,.Ltd",
        "address_1": "B-713, SK Twin Tech Tower, 345-9, Ga-San",
        "address_2": "Seoul    153-802",
        "country": "KR"
    },
    "000BB6": {
        "oui_hex": "00-0B-B6",
        "organization": "Metalligence Technology Corp.",
        "address_1": "9, Park Avenue II, Science-Based Industr",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000BB3": {
        "oui_hex": "00-0B-B3",
        "organization": "RiT technologies Ltd.",
        "address_1": "24 Raoul Walenberg  St.",
        "address_2": "Tel Aviv    69719",
        "country": "IL"
    },
    "000BB7": {
        "oui_hex": "00-0B-B7",
        "organization": "Micro Systems Co.,Ltd.",
        "address_1": "2-15-34 Nishikubo",
        "address_2": "Musashino-City  Tokyo  180-0013",
        "country": "JP"
    },
    "000BBA": {
        "oui_hex": "00-0B-BA",
        "organization": "Harmonic, Inc",
        "address_1": "4300 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000B62": {
        "oui_hex": "00-0B-62",
        "organization": "ib-mohnen KG",
        "address_1": "Stich 30 e",
        "address_2": "52249  Eschweiler",
        "country": "DE"
    },
    "000B64": {
        "oui_hex": "00-0B-64",
        "organization": "Kieback & Peter GmbH & Co KG",
        "address_1": "Tempelhofer Weg 50",
        "address_2": "Berlin    12347",
        "country": "DE"
    },
    "000B67": {
        "oui_hex": "00-0B-67",
        "organization": "Topview Technology Corporation",
        "address_1": "No. 8,Wu-Chuan Road,Wu Ku Industrial Par",
        "address_2": "Wu Ku Hsiang,Taipei Hsien,    248",
        "country": "TW"
    },
    "000B7D": {
        "oui_hex": "00-0B-7D",
        "organization": "SOLOMON EXTREME INTERNATIONAL LTD.",
        "address_1": "3F, No.20, Lane 165, Duenhua N. Rd., Sun",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000B94": {
        "oui_hex": "00-0B-94",
        "organization": "Digital Monitoring Products, Inc.",
        "address_1": "2500 N. Partnership Boulevard",
        "address_2": "Springfield  Missouri  65803",
        "country": "US"
    },
    "000BAE": {
        "oui_hex": "00-0B-AE",
        "organization": "Vitals System Inc.",
        "address_1": "Jooheung B/D 4FL. 1005-1, Youngtong-Dong",
        "address_2": "Suwon City  Kyonggi-Do  442-813",
        "country": "KR"
    },
    "000BD9": {
        "oui_hex": "00-0B-D9",
        "organization": "General Hydrogen",
        "address_1": "13120 Vanier Place",
        "address_2": "Richmond  British Columbia  V6V 2J2",
        "country": "CA"
    },
    "000BAB": {
        "oui_hex": "00-0B-AB",
        "organization": "Advantech Technology (CHINA) Co., Ltd.",
        "address_1": "No.666, Han-Pu Rd. Yu-Shan",
        "address_2": "Kun-Shan  Jiang Su  215316",
        "country": "CN"
    },
    "000B6D": {
        "oui_hex": "00-0B-6D",
        "organization": "SOLECTRON JAPAN NAKANIIDA",
        "address_1": "325 GANBARA",
        "address_2": "KAMIGUN  MIYAGIKEN  981-4263",
        "country": "JP"
    },
    "000BC4": {
        "oui_hex": "00-0B-C4",
        "organization": "BIOTRONIK GmbH & Co",
        "address_1": "Woermannkehre 1",
        "address_2": "Berlin    12359",
        "country": "DE"
    },
    "000B57": {
        "oui_hex": "00-0B-57",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "000B51": {
        "oui_hex": "00-0B-51",
        "organization": "Micetek International Inc.",
        "address_1": "7F-1, #237, Sec. 1, wu Chuan W. Rd.",
        "address_2": "Taichung    403",
        "country": "TW"
    },
    "000B53": {
        "oui_hex": "00-0B-53",
        "organization": "INITIUM Co., Ltd.",
        "address_1": "8F. Gongduck Bldg. 272-6 Seohyun Bundang",
        "address_2": "Sungnam  Kyunggi  463-824",
        "country": "KR"
    },
    "000AFB": {
        "oui_hex": "00-0A-FB",
        "organization": "Ambri Limited",
        "address_1": "126 Greville Street",
        "address_2": "Chatswood  NSW  2067",
        "country": "AU"
    },
    "000AFF": {
        "oui_hex": "00-0A-FF",
        "organization": "Kilchherr Elektronik AG",
        "address_1": "Aeschistrasse 25",
        "address_2": "Muensingen  BE  3110",
        "country": "CH"
    },
    "000B4A": {
        "oui_hex": "00-0B-4A",
        "organization": "Visimetrics (UK) Ltd",
        "address_1": "Skye House",
        "address_2": "Prestwick  Ayrshire  KA9 2TA",
        "country": "GB"
    },
    "000B48": {
        "oui_hex": "00-0B-48",
        "organization": "sofrel",
        "address_1": "2 rue du plessis",
        "address_2": "vern sur seiche  ille et vilaine  35770",
        "country": "FR"
    },
    "000B1E": {
        "oui_hex": "00-0B-1E",
        "organization": "KAPPA opto-electronics GmbH",
        "address_1": "Kleines Feld 6",
        "address_2": "Gleichen  Niedersachsen",
        "country": "DE"
    },
    "000B1C": {
        "oui_hex": "00-0B-1C",
        "organization": "SIBCO bv",
        "address_1": "Schoonhout 46",
        "address_2": "Etten-Leur  NB  4872 ME",
        "country": "NL"
    },
    "000B37": {
        "oui_hex": "00-0B-37",
        "organization": "MANUFACTURE DES MONTRES ROLEX SA",
        "address_1": "LA HAUTE-ROUTE 82",
        "address_2": "BIEL-BIENNE  BE  2502",
        "country": "CH"
    },
    "000AF8": {
        "oui_hex": "00-0A-F8",
        "organization": "American Telecare Inc.",
        "address_1": "7640 Golden Triangle Drive",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "000B17": {
        "oui_hex": "00-0B-17",
        "organization": "MKS Instruments",
        "address_1": "651 Lowell Street",
        "address_2": "Methuen  MA  01844",
        "country": "US"
    },
    "000B2D": {
        "oui_hex": "00-0B-2D",
        "organization": "Danfoss Inc.",
        "address_1": "7941 Corporate Dr",
        "address_2": "Baltimore  MD  21236",
        "country": "US"
    },
    "000AA3": {
        "oui_hex": "00-0A-A3",
        "organization": "SHIMAFUJI ELECTRIC CO.,LTD.",
        "address_1": "Daihyaku-seimei Kamata Bldg.3F",
        "address_2": "  Tokyo  144-0051",
        "country": "JP"
    },
    "000AA7": {
        "oui_hex": "00-0A-A7",
        "organization": "FEI Electron Optics",
        "address_1": "Achtseweg Noord 5",
        "address_2": "Eindhoven    5651GG",
        "country": "NL"
    },
    "000AA6": {
        "oui_hex": "00-0A-A6",
        "organization": "Hochiki Corporation",
        "address_1": "246, TSURUMA",
        "address_2": "MACHIDA  TOKYO  194-8577",
        "country": "JP"
    },
    "000A9A": {
        "oui_hex": "00-0A-9A",
        "organization": "Aiptek International Inc",
        "address_1": "No 5-1 Innovation Rd 1",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "000A94": {
        "oui_hex": "00-0A-94",
        "organization": "ShangHai cellink CO., LTD",
        "address_1": "C3 MeiLong ZhongXin Industrial Park,No.1",
        "address_2": "ShangHai    200237",
        "country": "US"
    },
    "000A97": {
        "oui_hex": "00-0A-97",
        "organization": "SONICblue, Inc.",
        "address_1": "2841 Mission College Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000A92": {
        "oui_hex": "00-0A-92",
        "organization": "Presonus Corporation",
        "address_1": "7257 Florida Blvd.",
        "address_2": "Baton Rouge  Louisiana  70806",
        "country": "US"
    },
    "000A85": {
        "oui_hex": "00-0A-85",
        "organization": "PLAT'C2,Inc",
        "address_1": "2-3-6 SOTOKANDA",
        "address_2": "CHIYODA-KU  TOKYO  101-0021",
        "country": "JP"
    },
    "000AD0": {
        "oui_hex": "00-0A-D0",
        "organization": "Niigata Develoment Center,  F.I.T. Co., Ltd.",
        "address_1": "Akane-Niigata Building 2F",
        "address_2": "Niigata  Niigata Prefecture  950-0944",
        "country": "JP"
    },
    "000AD4": {
        "oui_hex": "00-0A-D4",
        "organization": "CoreBell Systems Inc.",
        "address_1": "HTVC 2317 KAIST",
        "address_2": "Yuseong-Gu  Daejeon  305-701",
        "country": "KR"
    },
    "000ACA": {
        "oui_hex": "00-0A-CA",
        "organization": "YOKOYAMA SHOKAI CO.,Ltd.",
        "address_1": "6-96 Matsumura",
        "address_2": "Kanazawa  Ishikawa  920-0348",
        "country": "JP"
    },
    "000ACE": {
        "oui_hex": "00-0A-CE",
        "organization": "RADIANTECH, INC.",
        "address_1": "2-1, INDUSTRY EAST RD. 1, SCIENCE-BASED",
        "address_2": "HSIN CHU    300",
        "country": "TW"
    },
    "000AC7": {
        "oui_hex": "00-0A-C7",
        "organization": "Unication Group",
        "address_1": "3F., No. 6, Wu-Kung 5Rd., Hsinchuang Cit",
        "address_2": "Taipei    242",
        "country": "TW"
    },
    "000ADE": {
        "oui_hex": "00-0A-DE",
        "organization": "Happy Communication Co., Ltd.",
        "address_1": "42-11 WonMi-Dong",
        "address_2": "Bucheon-City  KyungGi-Do  420-110",
        "country": "KR"
    },
    "000AE2": {
        "oui_hex": "00-0A-E2",
        "organization": "Binatone Electronics International, Ltd",
        "address_1": "Floor 23A, 9 Des Voeux Road West",
        "address_2": "Hong Kong  China",
        "country": "HK"
    },
    "000ADB": {
        "oui_hex": "00-0A-DB",
        "organization": "Trilliant",
        "address_1": "401 Harrison Oaks Blvd. Suite 300",
        "address_2": "Cary  NC  27513",
        "country": "US"
    },
    "000AB8": {
        "oui_hex": "00-0A-B8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000AAC": {
        "oui_hex": "00-0A-AC",
        "organization": "TerraTec Electronic GmbH",
        "address_1": "Herrenpfad 38",
        "address_2": "Nettetal    41334",
        "country": "DE"
    },
    "000ABF": {
        "oui_hex": "00-0A-BF",
        "organization": "HIROTA SS",
        "address_1": "Matukawa-Kougyoudanchi",
        "address_2": "Suzaka-shi  Nagano  382-0005",
        "country": "JP"
    },
    "000ABC": {
        "oui_hex": "00-0A-BC",
        "organization": "Seabridge Ltd.",
        "address_1": "3 Hanagar St.",
        "address_2": "Hod-Hasharon  Israel  45241",
        "country": "IL"
    },
    "000A50": {
        "oui_hex": "00-0A-50",
        "organization": "REMOTEK CORPORATION",
        "address_1": "6F-6, No 77, Sec 1, HSIN TAI WU ROAD,",
        "address_2": "HSI-CHIH  TAIPEI HSIEN  221",
        "country": "TW"
    },
    "000A58": {
        "oui_hex": "00-0A-58",
        "organization": "Freyer & Siegel Elektronik GmbH & Co. KG",
        "address_1": "Neuendorfstraße 18 b",
        "address_2": "Hennigsdorf  Brandenburg  16761",
        "country": "DE"
    },
    "000A4E": {
        "oui_hex": "00-0A-4E",
        "organization": "UNITEK Electronics INC.",
        "address_1": "1-18-4",
        "address_2": "Ohta-ku  Tokyo  143-0016",
        "country": "US"
    },
    "000A62": {
        "oui_hex": "00-0A-62",
        "organization": "Crinis Networks, Inc.",
        "address_1": "2099 N. Collins Blvd, Suite 200",
        "address_2": "Richardson  TX  75080",
        "country": "US"
    },
    "000A6A": {
        "oui_hex": "00-0A-6A",
        "organization": "SVM Microwaves s.r.o.",
        "address_1": "U Mrazovky 5",
        "address_2": "Praha 5    15000",
        "country": "CZ"
    },
    "000A66": {
        "oui_hex": "00-0A-66",
        "organization": "MITSUBISHI ELECTRIC SYSTEM & SERVICE CO.,LTD.",
        "address_1": "1-4-13 OOYODONAKA,KITA-KU",
        "address_2": "OSAKA    531-0076",
        "country": "JP"
    },
    "000A31": {
        "oui_hex": "00-0A-31",
        "organization": "HCV Consulting",
        "address_1": "P O Box 3692",
        "address_2": "Queensland     4212",
        "country": "AU"
    },
    "004252": {
        "oui_hex": "00-42-52",
        "organization": "RLX Technologies",
        "address_1": "25231 Grograns Mill Rd",
        "address_2": "The Woodlands  Tx  77380",
        "country": "US"
    },
    "000A70": {
        "oui_hex": "00-0A-70",
        "organization": "MPLS Forum",
        "address_1": "39355 California Street",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000A72": {
        "oui_hex": "00-0A-72",
        "organization": "STEC, INC.",
        "address_1": "3001 Daimler Street",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "000A3D": {
        "oui_hex": "00-0A-3D",
        "organization": "Elo Sistemas Eletronicos S.A.",
        "address_1": "Rua Edu Chaves, 547",
        "address_2": "Porto Alegre  RS  90.240-620",
        "country": "BR"
    },
    "000A46": {
        "oui_hex": "00-0A-46",
        "organization": "ARO WELDING TECHNOLOGIES SAS",
        "address_1": "1, avenue de Tours",
        "address_2": "Chateau du Loir  sarthe  72500",
        "country": "FR"
    },
    "000A71": {
        "oui_hex": "00-0A-71",
        "organization": "Avrio Technologies, Inc",
        "address_1": "2655 A Park Center Drive",
        "address_2": "Simi Valley  CA  91356",
        "country": "US"
    },
    "000A64": {
        "oui_hex": "00-0A-64",
        "organization": "Eracom Technologies",
        "address_1": "28 Greg Chappell Drive",
        "address_2": "Burleigh Heads  Qld  4220",
        "country": "AU"
    },
    "000A83": {
        "oui_hex": "00-0A-83",
        "organization": "SALTO SYSTEMS S.L.",
        "address_1": "Arkotz, 9",
        "address_2": "Polígonoo Lanbarren  Oiartzun  20180",
        "country": "ES"
    },
    "000A86": {
        "oui_hex": "00-0A-86",
        "organization": "Lenze",
        "address_1": "PO box 101352",
        "address_2": "Hameln  Lower Saxony  31763",
        "country": "DE"
    },
    "000A3F": {
        "oui_hex": "00-0A-3F",
        "organization": "Data East Corporation",
        "address_1": "4-41-10 Minami-Ogikubo",
        "address_2": "Suginami-ku  TOKYO  167-0052",
        "country": "JP"
    },
    "000A0C": {
        "oui_hex": "00-0A-0C",
        "organization": "Scientific Research Corporation",
        "address_1": "2300 Windy Ridge Parkway",
        "address_2": "Atlanta  GA  30339",
        "country": "US"
    },
    "0009F6": {
        "oui_hex": "00-09-F6",
        "organization": "Shenzhen Eastern Digital Tech Ltd.",
        "address_1": "Shenzhen Futian Chegongmiao Tairan",
        "address_2": "Shenzhen  Guangdong  518048",
        "country": "CN"
    },
    "000A20": {
        "oui_hex": "00-0A-20",
        "organization": "SVA Networks, Inc.",
        "address_1": "840 F Ave., Suite 104",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "000A24": {
        "oui_hex": "00-0A-24",
        "organization": "Octave Communications",
        "address_1": "85 Northwest Boulevard",
        "address_2": "Nashua  NH  03063",
        "country": "US"
    },
    "000A19": {
        "oui_hex": "00-0A-19",
        "organization": "Valere Power, Inc.",
        "address_1": "661 N. Plano Rd.",
        "address_2": "Richardson  Texas  75081",
        "country": "US"
    },
    "0009E5": {
        "oui_hex": "00-09-E5",
        "organization": "Hottinger Baldwin Messtechnik GmbH",
        "address_1": "Im Tiefen See 45",
        "address_2": "Darmstadt  Hessen  64293",
        "country": "DE"
    },
    "0009DE": {
        "oui_hex": "00-09-DE",
        "organization": "Samjin Information & Communications Co., Ltd.",
        "address_1": "MajangMyun DukPyungRi 235-2",
        "address_2": "Ichon  KyongGi  467-812",
        "country": "KR"
    },
    "0009E0": {
        "oui_hex": "00-09-E0",
        "organization": "XEMICS S.A.",
        "address_1": "Rue de la Maladiere 71",
        "address_2": "CH-2007 Neuchatel  Neuchatel  2007",
        "country": "CH"
    },
    "000A01": {
        "oui_hex": "00-0A-01",
        "organization": "SOHOware, Inc.",
        "address_1": "3050 Coronado Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0009EC": {
        "oui_hex": "00-09-EC",
        "organization": "Daktronics, Inc.",
        "address_1": "315 32nd Ave",
        "address_2": "Brookings  SD  57006",
        "country": "US"
    },
    "0009EE": {
        "oui_hex": "00-09-EE",
        "organization": "MEIKYO ELECTRIC CO.,LTD",
        "address_1": "4-27-2 Higashiogu",
        "address_2": "Arakawa-ku  Tokyo  116-0012",
        "country": "JP"
    },
    "0009CA": {
        "oui_hex": "00-09-CA",
        "organization": "iMaxNetworks(Shenzhen)Limited.",
        "address_1": "4/B,South Bldg of 29th,South District of",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "0009CF": {
        "oui_hex": "00-09-CF",
        "organization": "iAd GmbH",
        "address_1": "Unterschlauersbacher Hauptstraße 10",
        "address_2": "Grosshabersdorf  Bavaria  90613",
        "country": "DE"
    },
    "000A11": {
        "oui_hex": "00-0A-11",
        "organization": "ExPet Technologies, Inc",
        "address_1": "6F, Kyonggi Small Business Center",
        "address_2": "Suwon, Kyonggi-do, 442-270    442-770",
        "country": "KR"
    },
    "000A0F": {
        "oui_hex": "00-0A-0F",
        "organization": "Ilryung Telesys, Inc",
        "address_1": "Ilryung bldg, 34-2, Cheonho-dong",
        "address_2": "SEOUL    134-861",
        "country": "KR"
    },
    "0009E7": {
        "oui_hex": "00-09-E7",
        "organization": "ADC Techonology",
        "address_1": "Sakae Members Office Bld. 4-16-8, Sakae,",
        "address_2": "Nagoya  Aichi  4600008",
        "country": "JP"
    },
    "000993": {
        "oui_hex": "00-09-93",
        "organization": "Visteon Corporation",
        "address_1": "16630 Southfield Road",
        "address_2": "Allen Park  Michigan  48101",
        "country": "US"
    },
    "000999": {
        "oui_hex": "00-09-99",
        "organization": "CP GEORGES RENAULT",
        "address_1": "38 Rue Bobby Sands",
        "address_2": "44800  Saint Herblain",
        "country": "FR"
    },
    "000994": {
        "oui_hex": "00-09-94",
        "organization": "Cronyx Engineering",
        "address_1": "Marshala Sokolovskogo str. 4",
        "address_2": "Moscow    123063",
        "country": "RU"
    },
    "0009B9": {
        "oui_hex": "00-09-B9",
        "organization": "Action Imaging Solutions",
        "address_1": "Kings Hall, St Ives Business Park",
        "address_2": "Huntingdon  Cambridgeshire  PE27 4WY",
        "country": "GB"
    },
    "0009AC": {
        "oui_hex": "00-09-AC",
        "organization": "LANVOICE",
        "address_1": "1364-39 SeochoDong, #201 Jihun Bldg",
        "address_2": "Seoul    137-072",
        "country": "KR"
    },
    "0009B1": {
        "oui_hex": "00-09-B1",
        "organization": "Kanematsu Electronics, Ltd.",
        "address_1": "17-5, Kyobashi 2-chome",
        "address_2": "Chuo-ku  Tokyo  104-8338",
        "country": "JP"
    },
    "0009B0": {
        "oui_hex": "00-09-B0",
        "organization": "Onkyo Corporation",
        "address_1": "2-1 Nisshin-cho",
        "address_2": "Neyagawa  Osaka  5728540",
        "country": "JP"
    },
    "000979": {
        "oui_hex": "00-09-79",
        "organization": "Advanced Television Systems Committee, Inc.",
        "address_1": "1750 K Street NW",
        "address_2": "Washington  DC  20006",
        "country": "US"
    },
    "000963": {
        "oui_hex": "00-09-63",
        "organization": "Dominion Lasercom Inc.",
        "address_1": "1716 Briarcrest Dr. Ste. 210",
        "address_2": "Bryan  TX  77802",
        "country": "US"
    },
    "000966": {
        "oui_hex": "00-09-66",
        "organization": "TRIMBLE EUROPE BV",
        "address_1": "Meerheide 45",
        "address_2": "Eersel  DZ  5521",
        "country": "NL"
    },
    "0009C1": {
        "oui_hex": "00-09-C1",
        "organization": "PROCES-DATA A/S",
        "address_1": "Navervej 8",
        "address_2": "Silkeborg    DK-8600",
        "country": "DK"
    },
    "0009BB": {
        "oui_hex": "00-09-BB",
        "organization": "MathStar, Inc.",
        "address_1": "5900 Green Oak Drive",
        "address_2": "Minneapolis  MN  55343",
        "country": "US"
    },
    "000968": {
        "oui_hex": "00-09-68",
        "organization": "TECHNOVENTURE, INC.",
        "address_1": "P. O. Box 5641",
        "address_2": "Pasadena  Texas  77508-5641",
        "country": "US"
    },
    "000961": {
        "oui_hex": "00-09-61",
        "organization": "Switchgear and Instrumentation Ltd",
        "address_1": "Ripley Road",
        "address_2": "Bradford  West Yorkshire  BD4 7EH",
        "country": "GB"
    },
    "00097C": {
        "oui_hex": "00-09-7C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00097B": {
        "oui_hex": "00-09-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00099D": {
        "oui_hex": "00-09-9D",
        "organization": "Haliplex Communications",
        "address_1": "PO Box 147",
        "address_2": "Mooroolbark  Vic  3138",
        "country": "AU"
    },
    "00099E": {
        "oui_hex": "00-09-9E",
        "organization": "Testech, Inc.",
        "address_1": "Bundang-Technopark, C-Dong, 702-Ho, #145",
        "address_2": "Sungnam-City  Kyungki-Do  463-070",
        "country": "KR"
    },
    "000988": {
        "oui_hex": "00-09-88",
        "organization": "Nudian Electron Co., Ltd.",
        "address_1": "797-28 Bangbae-Dong, Seocho-Gu",
        "address_2": "Seoul    137-060",
        "country": "KR"
    },
    "00098E": {
        "oui_hex": "00-09-8E",
        "organization": "ipcas GmbH",
        "address_1": "Wetterkreuz 17",
        "address_2": "Erlangen  Bavaria  91058",
        "country": "DE"
    },
    "0009AB": {
        "oui_hex": "00-09-AB",
        "organization": "Netcontrol Oy",
        "address_1": "Karvaamokuja 3",
        "address_2": "Helsinki    FIN 00380",
        "country": "FI"
    },
    "000960": {
        "oui_hex": "00-09-60",
        "organization": "YOZAN Inc.",
        "address_1": "YOZAN Bld.,3-5-18, Kitazawa",
        "address_2": "Setagaya-ku  Tokyo  155-0031",
        "country": "JP"
    },
    "000956": {
        "oui_hex": "00-09-56",
        "organization": "Network Systems Group, Ltd. (NSG)",
        "address_1": "39 Kirpichnaya St., Suite 1302",
        "address_2": "Moscow    105187",
        "country": "RU"
    },
    "000900": {
        "oui_hex": "00-09-00",
        "organization": "TMT",
        "address_1": "11 Kiryat Mada, POB 45199",
        "address_2": "Jerusalem    91450",
        "country": "IL"
    },
    "000901": {
        "oui_hex": "00-09-01",
        "organization": "Shenzhen Shixuntong Information & Technoligy Co",
        "address_1": "Room 403,617 Bldg;Bagua 1 Road ,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518029",
        "country": "CN"
    },
    "000913": {
        "oui_hex": "00-09-13",
        "organization": "SystemK Corporation",
        "address_1": "238-9 Higashi 1, Kita 15, Higashi-ku",
        "address_2": "Sapporo  Hokkaido  065-0015",
        "country": "JP"
    },
    "00090E": {
        "oui_hex": "00-09-0E",
        "organization": "Helix Technology Inc.",
        "address_1": "5F, No. 6, Sec 1, Jung-Shing Rd., Wugu-S",
        "address_2": "Taipei    248",
        "country": "TW"
    },
    "00093C": {
        "oui_hex": "00-09-3C",
        "organization": "Jacques Technologies P/L",
        "address_1": "268 Montague Rd",
        "address_2": "West End  Queensland  4101",
        "country": "AU"
    },
    "000935": {
        "oui_hex": "00-09-35",
        "organization": "Sandvine Incorporated",
        "address_1": "170 Columbia St. W.",
        "address_2": "Waterloo  ON  N2L 3L3",
        "country": "CA"
    },
    "000936": {
        "oui_hex": "00-09-36",
        "organization": "Ipetronik GmbH & Co. KG",
        "address_1": "Im Rollfeld 28",
        "address_2": "Baden-Baden  Baden-Württemberg  76532",
        "country": "DE"
    },
    "000937": {
        "oui_hex": "00-09-37",
        "organization": "Inventec Appliance Corp",
        "address_1": "113, Wugung 1 RD., WuKu Industrial nPark",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000946": {
        "oui_hex": "00-09-46",
        "organization": "Cluster Labs GmbH",
        "address_1": "Dauerwaldweg 1",
        "address_2": "Berlin  Berlin  14055",
        "country": "DE"
    },
    "00093F": {
        "oui_hex": "00-09-3F",
        "organization": "Double-Win Enterpirse CO., LTD",
        "address_1": "NO.300, Sec 1, Chung Feng Rd.",
        "address_2": "Ping Chen City  Taoyuan Hsien  324",
        "country": "TW"
    },
    "000948": {
        "oui_hex": "00-09-48",
        "organization": "Vista Control Systems, Corp.",
        "address_1": "2001 West Melinda Lane",
        "address_2": "Phoenix  AZ  85027",
        "country": "US"
    },
    "000949": {
        "oui_hex": "00-09-49",
        "organization": "Glyph Technologies Inc.",
        "address_1": "735 W. Clinton Street",
        "address_2": "Ithaca  NY  14850",
        "country": "US"
    },
    "00092A": {
        "oui_hex": "00-09-2A",
        "organization": "MYTECS Co.,Ltd.",
        "address_1": "1-12-39, Taishidou",
        "address_2": "Setagaya-ku  Tokyo  154-0004",
        "country": "JP"
    },
    "000925": {
        "oui_hex": "00-09-25",
        "organization": "VSN Systemen BV",
        "address_1": "Keizersveld 83",
        "address_2": "Venray  Limburg  5803 AP",
        "country": "NL"
    },
    "0008E0": {
        "oui_hex": "00-08-E0",
        "organization": "ATO Technology Ltd.",
        "address_1": "Rm. 1314-1346, Block B1, Yau Tong Ind. C",
        "address_2": "Hong Kong",
        "country": "HK"
    },
    "0008E4": {
        "oui_hex": "00-08-E4",
        "organization": "Envenergy Inc",
        "address_1": "6307 Carpinteria Ave",
        "address_2": "Carpinteria  CA  93013",
        "country": "US"
    },
    "0008E3": {
        "oui_hex": "00-08-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0008E5": {
        "oui_hex": "00-08-E5",
        "organization": "IDK Corporation",
        "address_1": "6-7-10",
        "address_2": "Yamato  Kanagawa  242-0007",
        "country": "JP"
    },
    "0008D9": {
        "oui_hex": "00-08-D9",
        "organization": "Mitadenshi Co.,LTD",
        "address_1": "1-8-6 Furuichi Asaminamiku",
        "address_2": "Hiroshima    731-0123",
        "country": "JP"
    },
    "000891": {
        "oui_hex": "00-08-91",
        "organization": "Lyan Inc.",
        "address_1": "5F-1, NO.51, SEC.2, KEELUNG RD.",
        "address_2": "TAIPEI    110",
        "country": "TW"
    },
    "000892": {
        "oui_hex": "00-08-92",
        "organization": "EM Solutions",
        "address_1": "101 Hyde Rd",
        "address_2": "Yeronga  Brisbane, QLD  4104",
        "country": "AU"
    },
    "00088C": {
        "oui_hex": "00-08-8C",
        "organization": "Quanta Network Systems Inc.",
        "address_1": "13, 13F, Sec. 2, Pei-Tou Rd",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "00088A": {
        "oui_hex": "00-08-8A",
        "organization": "Minds@Work",
        "address_1": "15550 Rockfield Blvd. Suite C",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0008FD": {
        "oui_hex": "00-08-FD",
        "organization": "BlueKorea Co., Ltd.",
        "address_1": "3F, sejong Building, 379-15, Seokyo-Dong",
        "address_2": "Seoul    121-839",
        "country": "KR"
    },
    "0008F8": {
        "oui_hex": "00-08-F8",
        "organization": "UTC CCS",
        "address_1": "791 Commerce Blvd",
        "address_2": "Boca Raton  FL  33497",
        "country": "US"
    },
    "0008D5": {
        "oui_hex": "00-08-D5",
        "organization": "Vanguard Networks Solutions, LLC",
        "address_1": "25 Forbes Boulevard",
        "address_2": "Foxboro  MA  02035",
        "country": "US"
    },
    "0008CD": {
        "oui_hex": "00-08-CD",
        "organization": "With-Net Inc",
        "address_1": "4FL B&B B/D 1403-4",
        "address_2": "Anyang  Kyonggi  431-061",
        "country": "US"
    },
    "0008CC": {
        "oui_hex": "00-08-CC",
        "organization": "Remotec, Inc.",
        "address_1": "114 Union Valley Road",
        "address_2": "Oakridge  TN  37830",
        "country": "US"
    },
    "0008D1": {
        "oui_hex": "00-08-D1",
        "organization": "KAREL INC.",
        "address_1": "ORGANIZE SANAYI BOLGESI",
        "address_2": "ANKARA    06935",
        "country": "TR"
    },
    "0008A7": {
        "oui_hex": "00-08-A7",
        "organization": "iLogic Inc.",
        "address_1": "Rm#318, TechnoComplex Bldg., 126-16, 5-g",
        "address_2": "Seoul    136-701",
        "country": "KR"
    },
    "000899": {
        "oui_hex": "00-08-99",
        "organization": "Netbind, Inc.",
        "address_1": "5 Marine View Plaza",
        "address_2": "Hoboken  NJ  07030",
        "country": "US"
    },
    "0008A0": {
        "oui_hex": "00-08-A0",
        "organization": "Stotz Feinmesstechnik GmbH",
        "address_1": "Hermann-Dreher Str. 6",
        "address_2": "Gerlingen    70839",
        "country": "DE"
    },
    "0008BC": {
        "oui_hex": "00-08-BC",
        "organization": "Ilevo AB",
        "address_1": "Box 1561",
        "address_2": "Karlstad  Värmland  S-651 21",
        "country": "SE"
    },
    "0008BD": {
        "oui_hex": "00-08-BD",
        "organization": "TEPG-US",
        "address_1": "100 Simplex Drive",
        "address_2": "Westminster  MA  01441",
        "country": "US"
    },
    "0008AE": {
        "oui_hex": "00-08-AE",
        "organization": "PacketFront Network Products AB",
        "address_1": "PO 1217",
        "address_2": "Kistagangen 2, IV  Kista Stockholm SE -16428",
        "country": "SE"
    },
    "0008C3": {
        "oui_hex": "00-08-C3",
        "organization": "Contex A/S",
        "address_1": "Svanevang 2",
        "address_2": "Allerod  DK  3450",
        "country": "DK"
    },
    "0008F3": {
        "oui_hex": "00-08-F3",
        "organization": "WANY",
        "address_1": "CEEI Cap Alpha",
        "address_2": "Montpellier  Herault  34940",
        "country": "FR"
    },
    "0008DE": {
        "oui_hex": "00-08-DE",
        "organization": "3UP Systems",
        "address_1": "6 Results Way",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000822": {
        "oui_hex": "00-08-22",
        "organization": "InPro Comm",
        "address_1": "11F, No. 93 Shuei-Yuan Street",
        "address_2": "",
        "country": "TW"
    },
    "000823": {
        "oui_hex": "00-08-23",
        "organization": "Texa Corp.",
        "address_1": "Nara Bldg. 3F, 2-2-8 Shin-Yokohama,",
        "address_2": "    222-0033",
        "country": "JP"
    },
    "00081D": {
        "oui_hex": "00-08-1D",
        "organization": "Ipsil, Incorporated",
        "address_1": "7945 MacArthur Blvd.",
        "address_2": "Cabin John  MD  20818",
        "country": "US"
    },
    "00082D": {
        "oui_hex": "00-08-2D",
        "organization": "Indus Teqsite Private Limited",
        "address_1": "#7, Arya Gowder Road,",
        "address_2": "Tamil Nadu    600033",
        "country": "IN"
    },
    "000820": {
        "oui_hex": "00-08-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000828": {
        "oui_hex": "00-08-28",
        "organization": "Koei Engineering Ltd.",
        "address_1": "3-40, 5-Chome",
        "address_2": "Osaku    547-0026",
        "country": "JP"
    },
    "000824": {
        "oui_hex": "00-08-24",
        "organization": "Nuance Document Imaging",
        "address_1": "8390 Mayrand Street",
        "address_2": "Montreal   Quebec  H4P 2C9",
        "country": "CA"
    },
    "00086C": {
        "oui_hex": "00-08-6C",
        "organization": "Plasmon LMS",
        "address_1": "4425 ArrowsWest Drive",
        "address_2": "Colorado Springs  CO  80907",
        "country": "US"
    },
    "000868": {
        "oui_hex": "00-08-68",
        "organization": "PurOptix",
        "address_1": "1945 Camino Vida Roble",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "000869": {
        "oui_hex": "00-08-69",
        "organization": "Command-e Technology Co.,Ltd.",
        "address_1": "Suite 1108, Zhongsheng Mansion,",
        "address_2": "Beijing    100038",
        "country": "CN"
    },
    "000862": {
        "oui_hex": "00-08-62",
        "organization": "NEC Eluminant Technologies, Inc.",
        "address_1": "14700 Avion Parkway",
        "address_2": "Chantilly  VA  20151",
        "country": "US"
    },
    "000803": {
        "oui_hex": "00-08-03",
        "organization": "Cos Tron",
        "address_1": "4F Boolim B/D, 1431-22,",
        "address_2": "Anyang    431-061",
        "country": "KR"
    },
    "000805": {
        "oui_hex": "00-08-05",
        "organization": "Techno-Holon Corporation",
        "address_1": "3-19-2, Takamatsu-cho",
        "address_2": "Tokyo    190-0011",
        "country": "JP"
    },
    "000808": {
        "oui_hex": "00-08-08",
        "organization": "PPT Vision, Inc.",
        "address_1": "12988 Valley View Rd.",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "000814": {
        "oui_hex": "00-08-14",
        "organization": "TIL Technologies",
        "address_1": "Europark DePichaury, BAT 9",
        "address_2": "",
        "country": "FR"
    },
    "00085C": {
        "oui_hex": "00-08-5C",
        "organization": "Shanghai Dare Technologies Co. Ltd.",
        "address_1": "23F, China Merchants Tower,",
        "address_2": "Pudong New Area,  Shanghai",
        "country": "CN"
    },
    "00082C": {
        "oui_hex": "00-08-2C",
        "organization": "Homag AG",
        "address_1": "Abt. Ess-Mp., Homag Str. 3-5",
        "address_2": "",
        "country": "DE"
    },
    "000821": {
        "oui_hex": "00-08-21",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000887": {
        "oui_hex": "00-08-87",
        "organization": "Maschinenfabrik Reinhausen GmbH",
        "address_1": "Falkensteinstraße 8",
        "address_2": "Regensburg  Bavaria  93059",
        "country": "DE"
    },
    "000877": {
        "oui_hex": "00-08-77",
        "organization": "Liebert-Hiross Spa",
        "address_1": "Via Leonardo da Vinci 8",
        "address_2": "Piove di Sacco  Z.I. Tognana  35020",
        "country": "IT"
    },
    "00087B": {
        "oui_hex": "00-08-7B",
        "organization": "RTX Telecom A/S",
        "address_1": "Stroemmen 6",
        "address_2": "",
        "country": "DK"
    },
    "000861": {
        "oui_hex": "00-08-61",
        "organization": "SoftEnergy Co., Ltd.",
        "address_1": "346 Sangwangsipli-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "00084F": {
        "oui_hex": "00-08-4F",
        "organization": "Qualstar Corporation",
        "address_1": "3990B Heritage Oak Court",
        "address_2": "Simi Valley  CA  93063",
        "country": "US"
    },
    "000854": {
        "oui_hex": "00-08-54",
        "organization": "Netronix, Inc.",
        "address_1": "3F-1, No. 31, Hsin-Tai Road,",
        "address_2": "",
        "country": "TW"
    },
    "000876": {
        "oui_hex": "00-08-76",
        "organization": "SDSystem",
        "address_1": "613,Hyundai I Valley,223-12,",
        "address_2": "Seongnam  Gyeonggi-Do  462-807",
        "country": "KR"
    },
    "000870": {
        "oui_hex": "00-08-70",
        "organization": "Rasvia Systems, Inc.",
        "address_1": "3255-3 Scott Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00086E": {
        "oui_hex": "00-08-6E",
        "organization": "Hyglo AB",
        "address_1": "Vastberga alle 60",
        "address_2": "",
        "country": "SE"
    },
    "0007FD": {
        "oui_hex": "00-07-FD",
        "organization": "LANergy Ltd.",
        "address_1": "Rudloe Manor",
        "address_2": "",
        "country": "GB"
    },
    "0007FE": {
        "oui_hex": "00-07-FE",
        "organization": "Rigaku Corporation",
        "address_1": "3-9-12, Matsubara-cho",
        "address_2": "Tokyo    196-8666",
        "country": "JP"
    },
    "00047D": {
        "oui_hex": "00-04-7D",
        "organization": "Pelco",
        "address_1": "3500 Pelco Way",
        "address_2": "Clovis  CA  93612",
        "country": "US"
    },
    "0007BF": {
        "oui_hex": "00-07-BF",
        "organization": "Armillaire Technologies, Inc.",
        "address_1": "10411 Motor City Drive",
        "address_2": "Bethesda  MD  20817",
        "country": "US"
    },
    "0007BB": {
        "oui_hex": "00-07-BB",
        "organization": "Candera Inc.",
        "address_1": "673 South Milpitas Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0007BD": {
        "oui_hex": "00-07-BD",
        "organization": "Radionet Ltd.",
        "address_1": "Keilaranta 6",
        "address_2": "",
        "country": "FI"
    },
    "0007C4": {
        "oui_hex": "00-07-C4",
        "organization": "JEAN Co. Ltd.",
        "address_1": "7F, 2, Rei Kuang Road,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "0007B6": {
        "oui_hex": "00-07-B6",
        "organization": "Telecom Technology Ltd.",
        "address_1": "Docklands Innovation Park",
        "address_2": "Dublin 3",
        "country": "IE"
    },
    "0007B7": {
        "oui_hex": "00-07-B7",
        "organization": "Samurai Ind. Prods Eletronicos Ltda",
        "address_1": "R-Nebraska, 443 S/2 2o Andar",
        "address_2": "    04560-011",
        "country": "BR"
    },
    "0007B0": {
        "oui_hex": "00-07-B0",
        "organization": "Office Details, Inc.",
        "address_1": "25 Ottawa",
        "address_2": "Grand Rapids  MI  49503",
        "country": "US"
    },
    "0007D9": {
        "oui_hex": "00-07-D9",
        "organization": "Splicecom",
        "address_1": "Little Gillions, The Green",
        "address_2": "Herts    WD3 3HY",
        "country": "GB"
    },
    "0007DA": {
        "oui_hex": "00-07-DA",
        "organization": "Neuro Telecom Co., Ltd.",
        "address_1": "2F Misung B/D, 938-7",
        "address_2": "Kyunggi-do",
        "country": "KR"
    },
    "0007CD": {
        "oui_hex": "00-07-CD",
        "organization": "Kumoh Electronic Co, Ltd",
        "address_1": "154-2 Chunui-dong",
        "address_2": "Gyeonggi-do",
        "country": "KR"
    },
    "0007CF": {
        "oui_hex": "00-07-CF",
        "organization": "Anoto AB",
        "address_1": "Solvegatan 41",
        "address_2": "",
        "country": "SE"
    },
    "0007D2": {
        "oui_hex": "00-07-D2",
        "organization": "Logopak Systeme GmbH & Co. KG",
        "address_1": "Dorfstraße 40",
        "address_2": "",
        "country": "DE"
    },
    "0007C9": {
        "oui_hex": "00-07-C9",
        "organization": "Technol Seven Co., Ltd.",
        "address_1": "25-16 Tobehon-cho, Nisi-ku,",
        "address_2": "",
        "country": "JP"
    },
    "0007C7": {
        "oui_hex": "00-07-C7",
        "organization": "Synectics Systems Limited",
        "address_1": "3 Acorn Business Park",
        "address_2": "    S8 OTB",
        "country": "GB"
    },
    "0007C3": {
        "oui_hex": "00-07-C3",
        "organization": "Thomson",
        "address_1": "5-7, rue Salomon de Rothschild",
        "address_2": "    92150",
        "country": "FR"
    },
    "0007A5": {
        "oui_hex": "00-07-A5",
        "organization": "Y.D.K Co. Ltd.",
        "address_1": "1705, Oshitate, Inagi-City,",
        "address_2": "",
        "country": "JP"
    },
    "00079C": {
        "oui_hex": "00-07-9C",
        "organization": "Golden Electronics Technology Co., Ltd.",
        "address_1": "No. 29, 21st Road,",
        "address_2": "",
        "country": "TW"
    },
    "0007E4": {
        "oui_hex": "00-07-E4",
        "organization": "SoftRadio Co., Ltd.",
        "address_1": "2F, Dong-Bok B/D 645-18",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00078E": {
        "oui_hex": "00-07-8E",
        "organization": "Garz & Friche GmbH",
        "address_1": "Tempowerhving 4",
        "address_2": "",
        "country": "DE"
    },
    "000754": {
        "oui_hex": "00-07-54",
        "organization": "Xyterra Computing, Inc.",
        "address_1": "14505 Hayden Rd.,",
        "address_2": "Scottsdale  AZ  85260-6953",
        "country": "US"
    },
    "000757": {
        "oui_hex": "00-07-57",
        "organization": "Topcall International AG",
        "address_1": "Talpagasse 1",
        "address_2": "",
        "country": "AT"
    },
    "000753": {
        "oui_hex": "00-07-53",
        "organization": "Beijing Qxcomm Technology Co., Ltd.",
        "address_1": "4F Tower B, TongTai Building No. 33,",
        "address_2": "Beijing 100032",
        "country": "CN"
    },
    "00074C": {
        "oui_hex": "00-07-4C",
        "organization": "Beicom Inc.",
        "address_1": "114 King Street",
        "address_2": "Alexandria  VA  22314",
        "country": "US"
    },
    "00074D": {
        "oui_hex": "00-07-4D",
        "organization": "Zebra Technologies Corp.",
        "address_1": "333 Corporate Woods Parkway",
        "address_2": "Vernon Hills  IL  60061",
        "country": "US"
    },
    "000732": {
        "oui_hex": "00-07-32",
        "organization": "AAEON Technology Inc.",
        "address_1": "5F, #135, Lane 235, Pao Chiao Road",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000725": {
        "oui_hex": "00-07-25",
        "organization": "Bematech International Corp.",
        "address_1": "5895 Shiloh Road",
        "address_2": "Alpharetta  GA  30005",
        "country": "US"
    },
    "000723": {
        "oui_hex": "00-07-23",
        "organization": "ELCON Systemtechnik GmbH",
        "address_1": "Obere Hauptstraße10",
        "address_2": "",
        "country": "DE"
    },
    "00071D": {
        "oui_hex": "00-07-1D",
        "organization": "Satelsa Sistemas Y Aplicaciones De Telecomunicaciones, S.A.",
        "address_1": "c/, Alejandro Moran, 56",
        "address_2": "",
        "country": "ES"
    },
    "000720": {
        "oui_hex": "00-07-20",
        "organization": "Trutzschler GmbH & Co. KG",
        "address_1": "Duvenstraße 82-92",
        "address_2": "",
        "country": "DE"
    },
    "00076E": {
        "oui_hex": "00-07-6E",
        "organization": "Sinetica Corporation Limited",
        "address_1": "Willow House",
        "address_2": "Monmouthshire  Usk  NP15 1HY",
        "country": "GB"
    },
    "00076F": {
        "oui_hex": "00-07-6F",
        "organization": "Synoptics Limited",
        "address_1": "Beacon House, Nuffield Road,",
        "address_2": "",
        "country": "GB"
    },
    "000773": {
        "oui_hex": "00-07-73",
        "organization": "Ascom Powerline Communications Ltd.",
        "address_1": "Belpstr. 37",
        "address_2": "",
        "country": "CH"
    },
    "00076C": {
        "oui_hex": "00-07-6C",
        "organization": "Daehanet, Inc.",
        "address_1": "#8-2 Chung Jung Rd 2- Ga",
        "address_2": "Seoul    120-012",
        "country": "KR"
    },
    "00075D": {
        "oui_hex": "00-07-5D",
        "organization": "Celleritas Inc.",
        "address_1": "c/o Celeritas Ltd.",
        "address_2": "",
        "country": "IL"
    },
    "00073F": {
        "oui_hex": "00-07-3F",
        "organization": "Woojyun Systec Co., Ltd.",
        "address_1": "4F Han Yang B/D, Yoido-dong",
        "address_2": "Seoul    150-010",
        "country": "KR"
    },
    "000728": {
        "oui_hex": "00-07-28",
        "organization": "Neo Telecom",
        "address_1": "East Building 9F, 1T",
        "address_2": "Songpa-gu, Seoul",
        "country": "KR"
    },
    "00072C": {
        "oui_hex": "00-07-2C",
        "organization": "Fabricom",
        "address_1": "Rue Gatti De Gamond 254",
        "address_2": "",
        "country": "BE"
    },
    "00072D": {
        "oui_hex": "00-07-2D",
        "organization": "CNSystems",
        "address_1": "Baumkircherstrasse 1",
        "address_2": "",
        "country": "AT"
    },
    "00072F": {
        "oui_hex": "00-07-2F",
        "organization": "Intransa, Inc.",
        "address_1": "2670 Zanker",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000780": {
        "oui_hex": "00-07-80",
        "organization": "Bluegiga Technologies OY",
        "address_1": "P.O. BOX 120",
        "address_2": "FIN-02631  Espoo",
        "country": "FI"
    },
    "000777": {
        "oui_hex": "00-07-77",
        "organization": "Motah Ltd.",
        "address_1": "4-4-5 Koishikawa",
        "address_2": "    112-0002",
        "country": "JP"
    },
    "000724": {
        "oui_hex": "00-07-24",
        "organization": "Telemax Co., Ltd.",
        "address_1": "6th Fl. Sungwoo B/D, 1099-1",
        "address_2": "Kyungki-Do,    435-040",
        "country": "KR"
    },
    "00071B": {
        "oui_hex": "00-07-1B",
        "organization": "CDVI Americas Ltd",
        "address_1": "1637 Autoroute Laval West",
        "address_2": "Laval  Quebec  H7L 3W3",
        "country": "CA"
    },
    "000715": {
        "oui_hex": "00-07-15",
        "organization": "General Research of Electronics, Inc.",
        "address_1": "3-12-17, Mita, Minato-ku",
        "address_2": "Tokyo    108-0073",
        "country": "JP"
    },
    "000737": {
        "oui_hex": "00-07-37",
        "organization": "Soriya Co. Ltd.",
        "address_1": "2, 8th Floor Hanshin B/O, 136-1,",
        "address_2": "Seoul,",
        "country": "KR"
    },
    "000734": {
        "oui_hex": "00-07-34",
        "organization": "ONStor, Inc.",
        "address_1": "130-B Knowles Drive",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "000765": {
        "oui_hex": "00-07-65",
        "organization": "Jade Quantum Technologies, Inc.",
        "address_1": "5F, No. 116, Hsien Fu Rd.,",
        "address_2": "",
        "country": "TW"
    },
    "0005EA": {
        "oui_hex": "00-05-EA",
        "organization": "Rednix",
        "address_1": "502, Dong-A Resort Officetel",
        "address_2": "Taejon    305-709",
        "country": "KR"
    },
    "0006C9": {
        "oui_hex": "00-06-C9",
        "organization": "Technical Marketing Research, Inc.",
        "address_1": "Shin Nihon Gijutsu Bldg.",
        "address_2": "Tokyo 105-0012    105-0012",
        "country": "JP"
    },
    "0006C8": {
        "oui_hex": "00-06-C8",
        "organization": "Sumitomo Metal Micro Devices, Inc.",
        "address_1": "1, Higashimukojima Higashino-cho",
        "address_2": "",
        "country": "JP"
    },
    "0006F1": {
        "oui_hex": "00-06-F1",
        "organization": "Optillion",
        "address_1": "Kronborgsgr.9",
        "address_2": "",
        "country": "SE"
    },
    "0006A7": {
        "oui_hex": "00-06-A7",
        "organization": "Primarion",
        "address_1": "3450 Torrance Blvd.",
        "address_2": "Torrance  CA  90503",
        "country": "US"
    },
    "0006A9": {
        "oui_hex": "00-06-A9",
        "organization": "Universal Instruments Corp.",
        "address_1": "PO Box 825",
        "address_2": "Binghamton  NY  13902",
        "country": "US"
    },
    "00069E": {
        "oui_hex": "00-06-9E",
        "organization": "UNIQA, Inc.",
        "address_1": "477 Valley Way",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0006B1": {
        "oui_hex": "00-06-B1",
        "organization": "Sonicwall",
        "address_1": "1160 Bordeaux Dr.",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0006AD": {
        "oui_hex": "00-06-AD",
        "organization": "KB Electronics Ltd.",
        "address_1": "150 Bluewater Rd.",
        "address_2": "    B4B 1G9",
        "country": "CA"
    },
    "0006AF": {
        "oui_hex": "00-06-AF",
        "organization": "Xalted Networks",
        "address_1": "2901 Dallas Parkway",
        "address_2": "Plano  TX  75093",
        "country": "US"
    },
    "0006D7": {
        "oui_hex": "00-06-D7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0006D5": {
        "oui_hex": "00-06-D5",
        "organization": "Diamond Systems Corp.",
        "address_1": "8430-D Central Ave.",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "0006FD": {
        "oui_hex": "00-06-FD",
        "organization": "Comjet Information Systems Corp.",
        "address_1": "7Fl., No. 103, Fen Liao Street",
        "address_2": "",
        "country": "TW"
    },
    "0006F9": {
        "oui_hex": "00-06-F9",
        "organization": "Mitsui Zosen Systems Research Inc.",
        "address_1": "11-1, Uno 1-chome",
        "address_2": "    706-0011",
        "country": "JP"
    },
    "0006C0": {
        "oui_hex": "00-06-C0",
        "organization": "United Internetworks, Inc.",
        "address_1": "5072 North 300 West, Suite 2N",
        "address_2": "Provo  UT  84604",
        "country": "US"
    },
    "0006E0": {
        "oui_hex": "00-06-E0",
        "organization": "MAT Co., Ltd.",
        "address_1": "864-3 Kwanyang-dong",
        "address_2": "Kyunggi-do    431-060",
        "country": "KR"
    },
    "00D0B9": {
        "oui_hex": "00-D0-B9",
        "organization": "MICROTEK INTERNATIONAL, INC.",
        "address_1": "NO. 6 INDUSTRY EAST ROAD 3",
        "address_2": "TAIWAN 30077  TAIWAN 30077  R.O.C.",
        "country": "TW"
    },
    "00D05F": {
        "oui_hex": "00-D0-5F",
        "organization": "VALCOM, INC.",
        "address_1": "1111 INDUSTRY AVENUE",
        "address_2": "ROANOKE  VA  24013",
        "country": "US"
    },
    "000675": {
        "oui_hex": "00-06-75",
        "organization": "Banderacom, Inc.",
        "address_1": "9211 Waterford Centre Blvd.",
        "address_2": "Austin  TX  78758",
        "country": "US"
    },
    "000698": {
        "oui_hex": "00-06-98",
        "organization": "egnite GmbH",
        "address_1": "Erinstraße 9",
        "address_2": "Castrop-Rauxel    D-44575",
        "country": "DE"
    },
    "00069C": {
        "oui_hex": "00-06-9C",
        "organization": "Transmode Systems AB",
        "address_1": "Jakobsdalsvagen 17",
        "address_2": "  Hägersten  SE-126 53",
        "country": "SE"
    },
    "000643": {
        "oui_hex": "00-06-43",
        "organization": "SONO Computer Co., Ltd.",
        "address_1": "1F., No. 8, Alley 35, Lane 91,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000649": {
        "oui_hex": "00-06-49",
        "organization": "3M Deutschland GmbH",
        "address_1": "Carl-Schurz-Str. 1",
        "address_2": "Neuss    D-41453",
        "country": "DE"
    },
    "00063E": {
        "oui_hex": "00-06-3E",
        "organization": "Opthos Inc.",
        "address_1": "590 Taylor Way",
        "address_2": "San Carlos  CA  94070",
        "country": "US"
    },
    "00063B": {
        "oui_hex": "00-06-3B",
        "organization": "Arcturus Networks Inc.",
        "address_1": "701 Evans Ave. - Suite 300",
        "address_2": "Toronto  Ontario  M9C 1A3",
        "country": "CA"
    },
    "00067B": {
        "oui_hex": "00-06-7B",
        "organization": "Toplink C&C Corporation",
        "address_1": "6F-15, No. 12, Lane 609, Sec. 5",
        "address_2": "Taipei Hsien 241",
        "country": "TW"
    },
    "000670": {
        "oui_hex": "00-06-70",
        "organization": "Upponetti Oy",
        "address_1": "Tykistokatu 4D",
        "address_2": "",
        "country": "FI"
    },
    "00066F": {
        "oui_hex": "00-06-6F",
        "organization": "Korea Data Systems",
        "address_1": "170, Gongdan-Dong, Gumi-Si",
        "address_2": "Kyungbuk    730-030",
        "country": "KR"
    },
    "000668": {
        "oui_hex": "00-06-68",
        "organization": "Vicon Industries Inc.",
        "address_1": "89 Arkay Drive",
        "address_2": "Hauppauge  NY  11788",
        "country": "US"
    },
    "00066D": {
        "oui_hex": "00-06-6D",
        "organization": "Compuprint S.P.A.",
        "address_1": "Via Martiri D'Italia 26",
        "address_2": "",
        "country": "IT"
    },
    "000626": {
        "oui_hex": "00-06-26",
        "organization": "MWE GmbH",
        "address_1": "Olbrichtstraße 21",
        "address_2": "",
        "country": "DE"
    },
    "000620": {
        "oui_hex": "00-06-20",
        "organization": "Serial System Ltd.",
        "address_1": "76 Playfair Road",
        "address_2": "    367996",
        "country": "SG"
    },
    "000618": {
        "oui_hex": "00-06-18",
        "organization": "DigiPower Manufacturing Inc.",
        "address_1": "No. 114, Floor 13, Sec. 1,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000633": {
        "oui_hex": "00-06-33",
        "organization": "Cross Match Technologies GmbH",
        "address_1": "Unstrutweg 4",
        "address_2": "  Jena  07743",
        "country": "DE"
    },
    "000686": {
        "oui_hex": "00-06-86",
        "organization": "ZARDCOM Co., Ltd.",
        "address_1": "4F, 1548-1, Seocho Dong, Seocho-Gu",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000689": {
        "oui_hex": "00-06-89",
        "organization": "yLez Technologies Pte Ltd",
        "address_1": "No. 1, Tannery Road, Cencon 1,",
        "address_2": "",
        "country": "SG"
    },
    "000681": {
        "oui_hex": "00-06-81",
        "organization": "Goepel Electronic GmbH",
        "address_1": "Goeschwitzer Str. 58-60",
        "address_2": "",
        "country": "DE"
    },
    "000658": {
        "oui_hex": "00-06-58",
        "organization": "Helmut Fischer GmbH Institut für Elektronik und Messtechnik",
        "address_1": "Industriestraße 21",
        "address_2": "",
        "country": "DE"
    },
    "0005D3": {
        "oui_hex": "00-05-D3",
        "organization": "eProduction Solutions, Inc.",
        "address_1": "22001 North Park Drive",
        "address_2": "Kingwood  TX  77339-3804",
        "country": "US"
    },
    "000604": {
        "oui_hex": "00-06-04",
        "organization": "@Track Communications, Inc.",
        "address_1": "1155 Kas Dr.",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "000606": {
        "oui_hex": "00-06-06",
        "organization": "RapidWAN, Inc.",
        "address_1": "2085 Hamilton Ave.",
        "address_2": "San Jose  CA  95125",
        "country": "US"
    },
    "000603": {
        "oui_hex": "00-06-03",
        "organization": "Baker Hughes Inc.",
        "address_1": "2001 Rankin Rd.",
        "address_2": "Houston  TX  77073",
        "country": "US"
    },
    "000607": {
        "oui_hex": "00-06-07",
        "organization": "Omni Directional Control Technology Inc.",
        "address_1": "8F-2, No. 94, Pao-Chung Rd.",
        "address_2": "Taipei  Hsien,",
        "country": "TW"
    },
    "0005F7": {
        "oui_hex": "00-05-F7",
        "organization": "Analog Devices, Inc.",
        "address_1": "Three Technology Way",
        "address_2": "Norwood   MA  02062-2666",
        "country": "US"
    },
    "00059C": {
        "oui_hex": "00-05-9C",
        "organization": "Kleinknecht GmbH, Ing. Büro",
        "address_1": "Bachstraße 30",
        "address_2": "",
        "country": "DE"
    },
    "0005AE": {
        "oui_hex": "00-05-AE",
        "organization": "Mediaport USA",
        "address_1": "17151 Newhope Ave. #202",
        "address_2": "Fountain Valley  CA  92708",
        "country": "US"
    },
    "0005B0": {
        "oui_hex": "00-05-B0",
        "organization": "Korea Computer Technology Co., Ltd.",
        "address_1": "KCT Bldg, 111-3 Yangjae-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "0005B2": {
        "oui_hex": "00-05-B2",
        "organization": "Medison Co., Ltd.",
        "address_1": "997-4, Saechi-Dong,",
        "address_2": "    135-280",
        "country": "KR"
    },
    "000597": {
        "oui_hex": "00-05-97",
        "organization": "Eagle Traffic Control Systems",
        "address_1": "8004 Cameron Road",
        "address_2": "Austin  TX  78754",
        "country": "US"
    },
    "0005B5": {
        "oui_hex": "00-05-B5",
        "organization": "Broadcom Technologies",
        "address_1": "137-060",
        "address_2": "Secho-Gu  Seoul,",
        "country": "KR"
    },
    "0005CB": {
        "oui_hex": "00-05-CB",
        "organization": "ROIS Technologies, Inc.",
        "address_1": "6th F Changhyun B/D, 960-1",
        "address_2": "    431-080",
        "country": "KR"
    },
    "0005C8": {
        "oui_hex": "00-05-C8",
        "organization": "VERYTECH",
        "address_1": "#402, Jang Young Shil Kwan,",
        "address_2": "",
        "country": "KR"
    },
    "0005CD": {
        "oui_hex": "00-05-CD",
        "organization": "D&M Holdings Inc.",
        "address_1": "D&M Building, 2-1 Nisshin-cho",
        "address_2": "Kawasaki-shi  Kanagawa   210-8569",
        "country": "JP"
    },
    "0005A2": {
        "oui_hex": "00-05-A2",
        "organization": "CELOX Networks",
        "address_1": "940 West Port Plaza - Ste. #300",
        "address_2": "St. Louis  MO  63146",
        "country": "US"
    },
    "0005AA": {
        "oui_hex": "00-05-AA",
        "organization": "Moore Industries International Inc.",
        "address_1": "16650 Schoenborn St.",
        "address_2": "North Hills  CA  91343",
        "country": "US"
    },
    "0005E7": {
        "oui_hex": "00-05-E7",
        "organization": "Netrake an AudioCodes Company",
        "address_1": "3000 Technology Drive",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "0005F4": {
        "oui_hex": "00-05-F4",
        "organization": "System Base Co., Ltd.",
        "address_1": "475-22, BangBae 2 dong,",
        "address_2": "",
        "country": "KR"
    },
    "0005E1": {
        "oui_hex": "00-05-E1",
        "organization": "Trellis Photonics, Ltd.",
        "address_1": "P.O.B. 36",
        "address_2": "",
        "country": "IL"
    },
    "0005E2": {
        "oui_hex": "00-05-E2",
        "organization": "Creativ Network Technologies",
        "address_1": "1755 St. Regis Suite 240",
        "address_2": "  Quebec  H9B-2M9",
        "country": "CA"
    },
    "000613": {
        "oui_hex": "00-06-13",
        "organization": "Kawasaki Microelectronics Incorporated",
        "address_1": "MTG B-5, 1-3, Nakase,",
        "address_2": "Mihama-ku  Chiba  261-8501",
        "country": "JP"
    },
    "000617": {
        "oui_hex": "00-06-17",
        "organization": "Redswitch Inc.",
        "address_1": "1815 McCandless Drive",
        "address_2": "Milpitas  CA  95035-8046",
        "country": "US"
    },
    "000551": {
        "oui_hex": "00-05-51",
        "organization": "F & S Elektronik Systeme GmbH",
        "address_1": "Untere Waldplaetze 23",
        "address_2": "Stuttgart    70569",
        "country": "DE"
    },
    "00054D": {
        "oui_hex": "00-05-4D",
        "organization": "Brans Technologies, Inc.",
        "address_1": "501 Boramae Academy Tower",
        "address_2": "",
        "country": "KR"
    },
    "000547": {
        "oui_hex": "00-05-47",
        "organization": "Starent Networks",
        "address_1": "30 International Place",
        "address_2": "Tewksbury  MA  01876",
        "country": "US"
    },
    "00054E": {
        "oui_hex": "00-05-4E",
        "organization": "Philips",
        "address_1": "1000 West Maude Avenue",
        "address_2": "Sunnyvale  CA  94085-2810",
        "country": "US"
    },
    "000546": {
        "oui_hex": "00-05-46",
        "organization": "KDDI Network & Solultions Inc.",
        "address_1": "2-3-1, Nishishinjunku-ku,",
        "address_2": "  Tokyo  163-0907",
        "country": "JP"
    },
    "000540": {
        "oui_hex": "00-05-40",
        "organization": "FAST Corporation",
        "address_1": "2791-5 Shimo-Tsuruma",
        "address_2": "    242-0001",
        "country": "JP"
    },
    "00053C": {
        "oui_hex": "00-05-3C",
        "organization": "XIRCOM",
        "address_1": "2300 CORPORATE CENTER DR.",
        "address_2": "THOUSAND OAKS  CA  91320",
        "country": "US"
    },
    "000544": {
        "oui_hex": "00-05-44",
        "organization": "Valley Technologies, Inc.",
        "address_1": "1006 West College Ave.",
        "address_2": "State College  PA  16801",
        "country": "US"
    },
    "00052E": {
        "oui_hex": "00-05-2E",
        "organization": "Cinta Networks",
        "address_1": "3010 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00052F": {
        "oui_hex": "00-05-2F",
        "organization": "Leviton Network Solutions",
        "address_1": "2222 222nd Street S.E.",
        "address_2": "Bothell  WA  98021",
        "country": "US"
    },
    "00053B": {
        "oui_hex": "00-05-3B",
        "organization": "Harbour Networks Ltd., Co. Beijing",
        "address_1": "13/F, JiuLing Building, No. 21,",
        "address_2": "    100089",
        "country": "CN"
    },
    "000528": {
        "oui_hex": "00-05-28",
        "organization": "New Focus, Inc.",
        "address_1": "2630 Walsh Ave.",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "00056B": {
        "oui_hex": "00-05-6B",
        "organization": "C.P. Technology Co., Ltd.",
        "address_1": "12F, No. 86, Hsin Tai Wu Rd.,",
        "address_2": "    221",
        "country": "TW"
    },
    "000560": {
        "oui_hex": "00-05-60",
        "organization": "LEADER COMM.CO., LTD",
        "address_1": "234, Komae-ri, Kiheung-eup,",
        "address_2": "    449-900",
        "country": "KR"
    },
    "00055E": {
        "oui_hex": "00-05-5E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000596": {
        "oui_hex": "00-05-96",
        "organization": "Genotech Co., Ltd.",
        "address_1": "#308 Gunkook Bldg.,",
        "address_2": "Gumchon-Gu  Seoul",
        "country": "KR"
    },
    "000579": {
        "oui_hex": "00-05-79",
        "organization": "Universal Control Solution Corp.",
        "address_1": "12843 Foothill Blvd.",
        "address_2": "Sylmar  CA  91342",
        "country": "US"
    },
    "00057F": {
        "oui_hex": "00-05-7F",
        "organization": "Acqis Technology",
        "address_1": "1621 West El Camino Real",
        "address_2": "Mt. View  CA  94040",
        "country": "US"
    },
    "000573": {
        "oui_hex": "00-05-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000575": {
        "oui_hex": "00-05-75",
        "organization": "CDS-Electronics BV",
        "address_1": "Mozart laan 330",
        "address_2": "",
        "country": "NL"
    },
    "000556": {
        "oui_hex": "00-05-56",
        "organization": "360 Systems",
        "address_1": "31355 Agoura Road",
        "address_2": "Westlake Village  CA  91361",
        "country": "US"
    },
    "000559": {
        "oui_hex": "00-05-59",
        "organization": "Intracom S.A.",
        "address_1": "19 5 KM Markopoulou Ave.",
        "address_2": "Attika",
        "country": "GR"
    },
    "00058C": {
        "oui_hex": "00-05-8C",
        "organization": "Opentech Inc.",
        "address_1": "6F, DongWon Bldg., 275",
        "address_2": "Seoul    137-130",
        "country": "KR"
    },
    "0004C9": {
        "oui_hex": "00-04-C9",
        "organization": "Micro Electron Co., Ltd.",
        "address_1": "13-1-205 Aobaokakita",
        "address_2": "Suita-city  Osaka",
        "country": "JP"
    },
    "0004BE": {
        "oui_hex": "00-04-BE",
        "organization": "OptXCon, Inc.",
        "address_1": "P.O. Box 13449",
        "address_2": "Research Triangle Park  NC  27709-3449",
        "country": "US"
    },
    "0004C4": {
        "oui_hex": "00-04-C4",
        "organization": "Audiotonix Group Limited",
        "address_1": "Unit 10, Silverglade Business Park",
        "address_2": "Chessington  Surrey  KT9 2QL",
        "country": "GB"
    },
    "0004C1": {
        "oui_hex": "00-04-C1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0004D6": {
        "oui_hex": "00-04-D6",
        "organization": "Takagi Industrial Co., Ltd.",
        "address_1": "Electronic Instrument Div.",
        "address_2": "418-0103  418-0103",
        "country": "JP"
    },
    "0004D1": {
        "oui_hex": "00-04-D1",
        "organization": "Drew Technologies, Inc.",
        "address_1": "3915 Research Park Dr",
        "address_2": "Ann Arbor  MI  48108",
        "country": "US"
    },
    "0004D0": {
        "oui_hex": "00-04-D0",
        "organization": "Softlink s.r.o.",
        "address_1": "Tomkova 409",
        "address_2": "  Czech  Republic",
        "country": "CZ"
    },
    "008087": {
        "oui_hex": "00-80-87",
        "organization": "OKI ELECTRIC INDUSTRY CO., LTD",
        "address_1": "10-3 SHIBAURA 4-CHOME",
        "address_2": "",
        "country": "JP"
    },
    "0004D9": {
        "oui_hex": "00-04-D9",
        "organization": "Titan Electronics, Inc.",
        "address_1": "Rm 7, 11 Fl., No. 398,",
        "address_2": "Taoyuan  Taoyuan  TAIWAN",
        "country": "TW"
    },
    "0004D8": {
        "oui_hex": "00-04-D8",
        "organization": "IPWireless, Inc.",
        "address_1": "4 Landsowne Court",
        "address_2": "SN14  GRZ  UK",
        "country": "GB"
    },
    "000524": {
        "oui_hex": "00-05-24",
        "organization": "BTL System (HK) Limited",
        "address_1": "14/F., Blk. B, Vita Tower,",
        "address_2": "Aberdeen",
        "country": "HK"
    },
    "000522": {
        "oui_hex": "00-05-22",
        "organization": "LEA*D Corporation, Inc.",
        "address_1": "Advatech Bldg.",
        "address_2": "",
        "country": "IL"
    },
    "000520": {
        "oui_hex": "00-05-20",
        "organization": "Smartronix, Inc.",
        "address_1": "22685 Three Notch Rd.",
        "address_2": "California  MD  20619",
        "country": "US"
    },
    "0004EB": {
        "oui_hex": "00-04-EB",
        "organization": "Paxonet Communications, Inc.",
        "address_1": "4046 Clipper Court",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0004EF": {
        "oui_hex": "00-04-EF",
        "organization": "Polestar Corp.",
        "address_1": "RM #802 SeoGeon B/D, 1480,",
        "address_2": "  Korea  (ROK)",
        "country": "KR"
    },
    "000514": {
        "oui_hex": "00-05-14",
        "organization": "KDT Systems Co., Ltd.",
        "address_1": "102-6, Chobu-Li, Mohyun-Myun,",
        "address_2": "",
        "country": "KR"
    },
    "00050B": {
        "oui_hex": "00-05-0B",
        "organization": "SICOM Systems, Inc.",
        "address_1": "4140 Skyron Drive",
        "address_2": "Doylestown  PA  18901",
        "country": "US"
    },
    "000505": {
        "oui_hex": "00-05-05",
        "organization": "Systems Integration Solutions, Inc.",
        "address_1": "3922 Coconut Palm Drive,",
        "address_2": "Tampa  FL  33619",
        "country": "US"
    },
    "0004FE": {
        "oui_hex": "00-04-FE",
        "organization": "Pelago Networks",
        "address_1": "701 E. Plano Parkway - Ste. #205",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "000518": {
        "oui_hex": "00-05-18",
        "organization": "Jupiters Technology",
        "address_1": "PO Box 12693",
        "address_2": "",
        "country": "AU"
    },
    "0004B7": {
        "oui_hex": "00-04-B7",
        "organization": "AMB i.t. Holding",
        "address_1": "Zuiderhoutlaan 4",
        "address_2": "  PJ Haarlem  2012",
        "country": "NL"
    },
    "0004B9": {
        "oui_hex": "00-04-B9",
        "organization": "S.I. Soubou, Inc.",
        "address_1": "4-2586-8",
        "address_2": "Tokorozawa  Sitama  359-0047",
        "country": "JP"
    },
    "0004BB": {
        "oui_hex": "00-04-BB",
        "organization": "Bardac Corporation",
        "address_1": "40 Log Canoe Circle",
        "address_2": "Stevensville  MD  21666",
        "country": "US"
    },
    "0004BC": {
        "oui_hex": "00-04-BC",
        "organization": "Giantec, Inc.",
        "address_1": "4F, No. 3, Lane 123,",
        "address_2": "TAIWAN 231  TAIWAN 231  R.O.C.",
        "country": "TW"
    },
    "0004AF": {
        "oui_hex": "00-04-AF",
        "organization": "Digital Fountain, Inc.",
        "address_1": "600 Alabama St.",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "000456": {
        "oui_hex": "00-04-56",
        "organization": "Cambium Networks Limited",
        "address_1": "Unit B2, Linhay Business Park,",
        "address_2": "Ashburton  Devon  TQ13 7UP",
        "country": "GB"
    },
    "000458": {
        "oui_hex": "00-04-58",
        "organization": "Fusion X Co., Ltd.",
        "address_1": "#905 Hansol Techno Town",
        "address_2": "  Zip  435-030",
        "country": "KR"
    },
    "00044F": {
        "oui_hex": "00-04-4F",
        "organization": "Schubert System Elektronik Gmbh",
        "address_1": "Rudolf-Diesel-Str. 17",
        "address_2": "",
        "country": "DE"
    },
    "000446": {
        "oui_hex": "00-04-46",
        "organization": "CYZENTECH Co., Ltd.",
        "address_1": "601 Eunkyeong B/D 141-31,",
        "address_2": "  135-876  KOREA",
        "country": "KR"
    },
    "00044A": {
        "oui_hex": "00-04-4A",
        "organization": "iPolicy Networks, Inc.",
        "address_1": "47467 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000440": {
        "oui_hex": "00-04-40",
        "organization": "cyberPIXIE, Inc.",
        "address_1": "68 E. Wacker Place,",
        "address_2": "Chicago  IL  60601",
        "country": "US"
    },
    "00043C": {
        "oui_hex": "00-04-3C",
        "organization": "SONOS Co., Ltd.",
        "address_1": "#725 Pungsan Apt. Factory",
        "address_2": "Rep. of KOREA Zip  Code:  411-815",
        "country": "KR"
    },
    "0004B2": {
        "oui_hex": "00-04-B2",
        "organization": "ESSEGI SRL",
        "address_1": "Via Del Cavaratori, 17",
        "address_2": "",
        "country": "IT"
    },
    "0004B4": {
        "oui_hex": "00-04-B4",
        "organization": "CIAC",
        "address_1": "18 rue Joseph BARA",
        "address_2": "",
        "country": "FR"
    },
    "0004AD": {
        "oui_hex": "00-04-AD",
        "organization": "Malibu Networks",
        "address_1": "26637 Agoura Rd.",
        "address_2": "Calabasas  CA  91302",
        "country": "US"
    },
    "0004A9": {
        "oui_hex": "00-04-A9",
        "organization": "SandStream Technologies, Inc.",
        "address_1": "1955 Lakeway Dr.",
        "address_2": "Lewisville  TX  75057",
        "country": "US"
    },
    "000461": {
        "oui_hex": "00-04-61",
        "organization": "EPOX Computer Co., Ltd.",
        "address_1": "11F, #346, Chung San Rd.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000462": {
        "oui_hex": "00-04-62",
        "organization": "DAKOS Data & Communication Co., Ltd.",
        "address_1": "2nd Floor Bethel Building 324-1",
        "address_2": "Zip  code:  137-130",
        "country": "TW"
    },
    "00045F": {
        "oui_hex": "00-04-5F",
        "organization": "Avalue Technology, Inc.",
        "address_1": "7F, 228, Lian-Cheng Road",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00049C": {
        "oui_hex": "00-04-9C",
        "organization": "Surgient Networks, Inc.",
        "address_1": "3520 Executive Center Drive",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "00049D": {
        "oui_hex": "00-04-9D",
        "organization": "Ipanema Technologies",
        "address_1": "28, Rue De La Redoute",
        "address_2": "",
        "country": "FR"
    },
    "000460": {
        "oui_hex": "00-04-60",
        "organization": "Knilink Technology, Inc.",
        "address_1": "10F, #96, Hsin Tai Wu Rd.,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00048F": {
        "oui_hex": "00-04-8F",
        "organization": "TD Systems Corporation",
        "address_1": "100 Bearfoot Rd.",
        "address_2": "Hudson  MA  01749",
        "country": "US"
    },
    "000495": {
        "oui_hex": "00-04-95",
        "organization": "Tejas Networks India Limited",
        "address_1": "#58, 1st Main Road, J.P. Nagar,",
        "address_2": "Bangalore   560078",
        "country": "IN"
    },
    "00046F": {
        "oui_hex": "00-04-6F",
        "organization": "Digitel S/A Industria Eletronica",
        "address_1": "R. Doutor Joao Ignacio, 1165",
        "address_2": "  Zip:  90230.181",
        "country": "BR"
    },
    "000469": {
        "oui_hex": "00-04-69",
        "organization": "Innocom, Inc.",
        "address_1": "655-2 Naebalsan-Dong",
        "address_2": "157-280  157-280  KOREA",
        "country": "KR"
    },
    "000487": {
        "oui_hex": "00-04-87",
        "organization": "Cogency Semiconductor, Inc.",
        "address_1": "362 Terry Fox Drive, Suite 210",
        "address_2": "",
        "country": "CA"
    },
    "000468": {
        "oui_hex": "00-04-68",
        "organization": "Vivity, Inc.",
        "address_1": "3360 Mitchell Lane",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "0003E1": {
        "oui_hex": "00-03-E1",
        "organization": "Winmate Communication, Inc.",
        "address_1": "9F,No.111-6,Shing-De Rd",
        "address_2": "Taipei     241",
        "country": "TW"
    },
    "0003E4": {
        "oui_hex": "00-03-E4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0003DC": {
        "oui_hex": "00-03-DC",
        "organization": "Lexar Media, Inc.",
        "address_1": "47421 Bayside Parkway",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0003D8": {
        "oui_hex": "00-03-D8",
        "organization": "iMPath Networks, Inc.",
        "address_1": "1431 Merivale Rd.",
        "address_2": "CANADA  K2E  1B9",
        "country": "CA"
    },
    "0003D5": {
        "oui_hex": "00-03-D5",
        "organization": "Advanced Communications Co., Ltd.",
        "address_1": "2876-1 Ooka",
        "address_2": "Shizuoka  41-0022",
        "country": "JP"
    },
    "0003F7": {
        "oui_hex": "00-03-F7",
        "organization": "Plast-Control GmbH",
        "address_1": "Walter-Freitag-Str. 15",
        "address_2": "",
        "country": "DE"
    },
    "0003FC": {
        "oui_hex": "00-03-FC",
        "organization": "Intertex Data AB",
        "address_1": "Rissneleden 45",
        "address_2": "",
        "country": "SE"
    },
    "0003EF": {
        "oui_hex": "00-03-EF",
        "organization": "Oneline AG",
        "address_1": "Steinfeldstraße 3",
        "address_2": "",
        "country": "DE"
    },
    "0003F1": {
        "oui_hex": "00-03-F1",
        "organization": "Cicada Semiconductor, Inc.",
        "address_1": "811 Barton Springs Rd.",
        "address_2": "Austin  TX  78704",
        "country": "US"
    },
    "000430": {
        "oui_hex": "00-04-30",
        "organization": "Netgem",
        "address_1": "27 rue d'Orleans",
        "address_2": "",
        "country": "FR"
    },
    "00042C": {
        "oui_hex": "00-04-2C",
        "organization": "Minet, Inc.",
        "address_1": "3F Se-A Venture Tower",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00042A": {
        "oui_hex": "00-04-2A",
        "organization": "Wireless Networks, Inc.",
        "address_1": "2322 El Camino Real",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "00042B": {
        "oui_hex": "00-04-2B",
        "organization": "IT Access Co., Ltd.",
        "address_1": "3-17-6, Shinyokohama, Kouhoku-ku",
        "address_2": "Yokohama-shi  Kanagawa  222-8545",
        "country": "JP"
    },
    "0003D6": {
        "oui_hex": "00-03-D6",
        "organization": "RADVision, Ltd.",
        "address_1": "24 Raul Wallenberg St.",
        "address_2": "",
        "country": "IL"
    },
    "0003D4": {
        "oui_hex": "00-03-D4",
        "organization": "Alloptic, Inc.",
        "address_1": "6960 Koll Center Parkway",
        "address_2": "Pleasanton  CA  94566",
        "country": "US"
    },
    "0003CE": {
        "oui_hex": "00-03-CE",
        "organization": "ETEN Technologies, Inc.",
        "address_1": "2F, No. 9, Lane 235, Pao-Chiao Rd.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0003C8": {
        "oui_hex": "00-03-C8",
        "organization": "CML Emergency Services",
        "address_1": "75 Boulevard la Technologies",
        "address_2": "",
        "country": "CA"
    },
    "0003C3": {
        "oui_hex": "00-03-C3",
        "organization": "Micronik Multimedia",
        "address_1": "Brückenstraße 2",
        "address_2": "",
        "country": "DE"
    },
    "000419": {
        "oui_hex": "00-04-19",
        "organization": "Fibercycle Networks, Inc.",
        "address_1": "20 South Santa Cruz Ave.",
        "address_2": "Los Gatos  CA  95030",
        "country": "US"
    },
    "00041C": {
        "oui_hex": "00-04-1C",
        "organization": "ipDialog, Inc.",
        "address_1": "1762 Technology Drive",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "000418": {
        "oui_hex": "00-04-18",
        "organization": "Teltronic S.A.U.",
        "address_1": "Poligono de Malpica",
        "address_2": "",
        "country": "ES"
    },
    "000370": {
        "oui_hex": "00-03-70",
        "organization": "NXTV, Inc.",
        "address_1": "5955 De Soto Ave, #160",
        "address_2": "Woodland Hills  CA  91367",
        "country": "US"
    },
    "000402": {
        "oui_hex": "00-04-02",
        "organization": "Nexsan Technologies, Ltd.",
        "address_1": "Parker Centre",
        "address_2": "Derby    DE21 4SZ",
        "country": "GB"
    },
    "0003ED": {
        "oui_hex": "00-03-ED",
        "organization": "Shinkawa Electric Co., Ltd.",
        "address_1": "3-2-24 3 chome",
        "address_2": "",
        "country": "JP"
    },
    "0003BD": {
        "oui_hex": "00-03-BD",
        "organization": "OmniCluster Technologies, Inc.",
        "address_1": "4950 Blue Lake Drive",
        "address_2": "Boca Raton  FL  33431",
        "country": "US"
    },
    "0003C0": {
        "oui_hex": "00-03-C0",
        "organization": "RFTNC Co., Ltd.",
        "address_1": "3F, 1624-24, Bongchen-dong",
        "address_2": "  SOUTH  KOREA",
        "country": "KR"
    },
    "0003B8": {
        "oui_hex": "00-03-B8",
        "organization": "NetKit Solutions, LLC",
        "address_1": "26630 Agoura Road",
        "address_2": "Calabasas  CA  91302",
        "country": "US"
    },
    "0003B7": {
        "oui_hex": "00-03-B7",
        "organization": "ZACCESS Systems",
        "address_1": "275 Shoreline Drive, #110",
        "address_2": "Redwood City  CA  94065",
        "country": "US"
    },
    "0003A0": {
        "oui_hex": "00-03-A0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0003A2": {
        "oui_hex": "00-03-A2",
        "organization": "Catapult Communications",
        "address_1": "160 S. Whisman Rd.",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "00039C": {
        "oui_hex": "00-03-9C",
        "organization": "OptiMight Communications, Inc.",
        "address_1": "980 Linda Vista Avenue",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0003B0": {
        "oui_hex": "00-03-B0",
        "organization": "Xsense Technology Corp.",
        "address_1": "11 F, 232, Sec. 3, ChengTeh Rd.",
        "address_2": "Taipei  TAIWAN,  103",
        "country": "TW"
    },
    "0003AA": {
        "oui_hex": "00-03-AA",
        "organization": "Watlow",
        "address_1": "1241 Bundy Blvd.",
        "address_2": "Winona  MN  55987",
        "country": "US"
    },
    "0003A8": {
        "oui_hex": "00-03-A8",
        "organization": "IDOT Computers, Inc.",
        "address_1": "3F., No. 137, Lane 235",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000355": {
        "oui_hex": "00-03-55",
        "organization": "TeraBeam Internet Systems",
        "address_1": "14833 NE 87th St., Bldg. C",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "000369": {
        "oui_hex": "00-03-69",
        "organization": "Nippon Antenna Co., Ltd.",
        "address_1": "No. 49-8, Nishiogu,",
        "address_2": "Tokyo    116-8561",
        "country": "JP"
    },
    "000373": {
        "oui_hex": "00-03-73",
        "organization": "Aselsan A.S",
        "address_1": "Mehmet Akif Ersoy Mah.",
        "address_2": "",
        "country": "TR"
    },
    "000377": {
        "oui_hex": "00-03-77",
        "organization": "Gigabit Wireless",
        "address_1": "3099 N. First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000365": {
        "oui_hex": "00-03-65",
        "organization": "Kira Information & Communications, Ltd.",
        "address_1": "6th Fl. Anam Tower,",
        "address_2": "",
        "country": "KR"
    },
    "000385": {
        "oui_hex": "00-03-85",
        "organization": "Actelis Networks, Inc.",
        "address_1": "1 Bazel St., P.O.B. 10173",
        "address_2": "",
        "country": "IL"
    },
    "000354": {
        "oui_hex": "00-03-54",
        "organization": "Fiber Logic Communications",
        "address_1": "5F-3, No. 9, Prosperity Road One,",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "000350": {
        "oui_hex": "00-03-50",
        "organization": "BTICINO SPA",
        "address_1": "Via L. Manara, 4",
        "address_2": "",
        "country": "IT"
    },
    "000351": {
        "oui_hex": "00-03-51",
        "organization": "Diebold, Inc.",
        "address_1": "5995 Mayfair Road",
        "address_2": "North Canton  OH  44720",
        "country": "US"
    },
    "00034E": {
        "oui_hex": "00-03-4E",
        "organization": "Pos Data Company, Ltd.",
        "address_1": "276-2, Seo-Hyun Dong,",
        "address_2": "",
        "country": "KR"
    },
    "000348": {
        "oui_hex": "00-03-48",
        "organization": "Norscan Instruments, Ltd.",
        "address_1": "7 Terracon Place",
        "address_2": "    R2J 4B3",
        "country": "CA"
    },
    "000346": {
        "oui_hex": "00-03-46",
        "organization": "Hitachi Kokusai Electric, Inc.",
        "address_1": "1-6-10 Uchikanda",
        "address_2": "",
        "country": "JP"
    },
    "000344": {
        "oui_hex": "00-03-44",
        "organization": "Tietech.Co., Ltd.",
        "address_1": "2-13-1 Chikamatoori Minamiku",
        "address_2": "",
        "country": "JP"
    },
    "0002E6": {
        "oui_hex": "00-02-E6",
        "organization": "Gould Instrument Systems, Inc.",
        "address_1": "8333 Rockside Road",
        "address_2": "Valley View  OH  44125",
        "country": "US"
    },
    "0002E4": {
        "oui_hex": "00-02-E4",
        "organization": "JC HYUN Systems, Inc.",
        "address_1": "Shinbong Bldg, 736-6,",
        "address_2": "Seoul    (135-080)",
        "country": "KR"
    },
    "0002DE": {
        "oui_hex": "00-02-DE",
        "organization": "Astrodesign, Inc.",
        "address_1": "2-22-12 Kamikodana Ka",
        "address_2": "Kanagawa",
        "country": "JP"
    },
    "0002E2": {
        "oui_hex": "00-02-E2",
        "organization": "NDC Infared Engineering",
        "address_1": "5314 N. Irwindale Ave.",
        "address_2": "Irwindale  CA  91706",
        "country": "US"
    },
    "0002E1": {
        "oui_hex": "00-02-E1",
        "organization": "Integrated Network Corporation",
        "address_1": "757 Route 202/206",
        "address_2": "Bridgewater  NJ  08807",
        "country": "US"
    },
    "0002F7": {
        "oui_hex": "00-02-F7",
        "organization": "ARM",
        "address_1": "110, Fulbourn Road",
        "address_2": "    CB1 9NJ",
        "country": "GB"
    },
    "00D024": {
        "oui_hex": "00-D0-24",
        "organization": "Cognex Corporation",
        "address_1": "Modular Vision Systems Division",
        "address_2": "Portland  OR  97224",
        "country": "US"
    },
    "0002F1": {
        "oui_hex": "00-02-F1",
        "organization": "Pinetron Co., Ltd.",
        "address_1": "Bldg. #1599-11,",
        "address_2": "Seoul    137-073",
        "country": "KR"
    },
    "0002ED": {
        "oui_hex": "00-02-ED",
        "organization": "DXO Telecom Co., Ltd.",
        "address_1": "8F, 300-11, Yumgok-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "0002EC": {
        "oui_hex": "00-02-EC",
        "organization": "Maschoff Design Engineering",
        "address_1": "1325 Kenilworth Drive",
        "address_2": "Woodbury  MN  55125",
        "country": "US"
    },
    "000336": {
        "oui_hex": "00-03-36",
        "organization": "Zetes Technologies",
        "address_1": "3 Rue De Stras Bourg",
        "address_2": "",
        "country": "BE"
    },
    "000337": {
        "oui_hex": "00-03-37",
        "organization": "Vaone, Inc.",
        "address_1": "6F Kyemong Art Center,",
        "address_2": "    135-082",
        "country": "KR"
    },
    "00033B": {
        "oui_hex": "00-03-3B",
        "organization": "TAMI Tech Co., Ltd.",
        "address_1": "4F, Chungdo Bencher Town",
        "address_2": "Taejon",
        "country": "KR"
    },
    "00032D": {
        "oui_hex": "00-03-2D",
        "organization": "IBASE Technology, Inc.",
        "address_1": "5F, No. 221,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "00B052": {
        "oui_hex": "00-B0-52",
        "organization": "Atheros Communications",
        "address_1": "5955 T.G. Lee Blvd, Ste. 600",
        "address_2": "Ocala  FL  32822",
        "country": "US"
    },
    "000343": {
        "oui_hex": "00-03-43",
        "organization": "Martin Professional A/S",
        "address_1": "Olof Palmes Alle 18",
        "address_2": "",
        "country": "DK"
    },
    "000335": {
        "oui_hex": "00-03-35",
        "organization": "Mirae Technology",
        "address_1": "211-15, Hon Hyun-dong,",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0002F8": {
        "oui_hex": "00-02-F8",
        "organization": "SEAKR Engineering, Inc.",
        "address_1": "12847 E. Peakview Ave.",
        "address_2": "Englewood  CO  80111",
        "country": "US"
    },
    "000314": {
        "oui_hex": "00-03-14",
        "organization": "Teleware Network Systems",
        "address_1": "#7806 7th Dongil Technotown,",
        "address_2": "    431-062",
        "country": "KR"
    },
    "00032F": {
        "oui_hex": "00-03-2F",
        "organization": "Global Sun Technology, Inc.",
        "address_1": "No. 13, Tung Yuan Rd.,",
        "address_2": "",
        "country": "TW"
    },
    "0002DC": {
        "oui_hex": "00-02-DC",
        "organization": "Fujitsu General Limited",
        "address_1": "1116, Suenaga, Takatsu-Ku,",
        "address_2": "  213-8502",
        "country": "JP"
    },
    "0002D7": {
        "oui_hex": "00-02-D7",
        "organization": "EMPEG Ltd",
        "address_1": "1 Signet Court",
        "address_2": "    CB5 8LA",
        "country": "GB"
    },
    "0002D3": {
        "oui_hex": "00-02-D3",
        "organization": "NetBotz, Inc.",
        "address_1": "110044 Research Blvd.",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0002DA": {
        "oui_hex": "00-02-DA",
        "organization": "ExiO Communications, Inc.",
        "address_1": "2362 Qume Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0002D4": {
        "oui_hex": "00-02-D4",
        "organization": "PDA Peripherals, Inc.",
        "address_1": "205 Orange St.",
        "address_2": "New Haven  CT  06510",
        "country": "US"
    },
    "0002D6": {
        "oui_hex": "00-02-D6",
        "organization": "NICE Systems",
        "address_1": "8 Hapnina St., POB 690",
        "address_2": "",
        "country": "IL"
    },
    "00027D": {
        "oui_hex": "00-02-7D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00027C": {
        "oui_hex": "00-02-7C",
        "organization": "Trilithic, Inc.",
        "address_1": "9202 E. 33rd Street",
        "address_2": "Indianapolis  IN  46235",
        "country": "US"
    },
    "00028B": {
        "oui_hex": "00-02-8B",
        "organization": "VDSL Systems OY",
        "address_1": "Tekniikantie 12",
        "address_2": "",
        "country": "FI"
    },
    "00028C": {
        "oui_hex": "00-02-8C",
        "organization": "Micrel-Synergy Semiconductor",
        "address_1": "3250 Scott Boulevard",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00028D": {
        "oui_hex": "00-02-8D",
        "organization": "Movita Technologies, Inc.",
        "address_1": "No. 26 Wu-Chuan 7th Road,",
        "address_2": "Taipei  Taiwan,  R.O.C.",
        "country": "TW"
    },
    "000298": {
        "oui_hex": "00-02-98",
        "organization": "Broadframe Corporation",
        "address_1": "5828 Moonstone Ave.",
        "address_2": "Alta Loma  CA  91701",
        "country": "US"
    },
    "000297": {
        "oui_hex": "00-02-97",
        "organization": "C-COR.net",
        "address_1": "60 Decibel Road",
        "address_2": "State College  PA  16801",
        "country": "US"
    },
    "000291": {
        "oui_hex": "00-02-91",
        "organization": "Open Network Co., Ltd.",
        "address_1": "Seishin Bldg., 2-5-10 Shinjuku",
        "address_2": "  JAPAN  160-0022",
        "country": "JP"
    },
    "0002C1": {
        "oui_hex": "00-02-C1",
        "organization": "Innovative Electronic Designs, Inc.",
        "address_1": "9701 Taylorsville Rd.",
        "address_2": "Louisville  KY  40299",
        "country": "US"
    },
    "0002C0": {
        "oui_hex": "00-02-C0",
        "organization": "Bencent Tzeng Industry Co., Ltd.",
        "address_1": "3rd fl., No. 3 Ruey Kuang Rd.,",
        "address_2": "Taiwan  Taiwan  R.O.C.",
        "country": "TW"
    },
    "000299": {
        "oui_hex": "00-02-99",
        "organization": "Apex, Inc.",
        "address_1": "9911 Willows Rd. N.E.",
        "address_2": "Redmond  WA  95052",
        "country": "US"
    },
    "000275": {
        "oui_hex": "00-02-75",
        "organization": "SMART Technologies, Inc.",
        "address_1": "3636 Research  Road NW",
        "address_2": "Calgary, Alberta    T2L1Y1",
        "country": "CA"
    },
    "0002C6": {
        "oui_hex": "00-02-C6",
        "organization": "Data Track Technology PLC",
        "address_1": "153 Somerford Road",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0002A6": {
        "oui_hex": "00-02-A6",
        "organization": "Effinet Systems Co., Ltd.",
        "address_1": "Yugong Bldg. 502",
        "address_2": "    Korea",
        "country": "KR"
    },
    "00025F": {
        "oui_hex": "00-02-5F",
        "organization": "Nortel Networks",
        "address_1": "9300 trans-CANADA Highway",
        "address_2": "H4S  1KS",
        "country": "CA"
    },
    "00025C": {
        "oui_hex": "00-02-5C",
        "organization": "SCI Systems (Kunshan) Co., Ltd.",
        "address_1": "312 QING YANG ROAD",
        "address_2": "CHINA  CHINA  215300",
        "country": "CN"
    },
    "000087": {
        "oui_hex": "00-00-87",
        "organization": "HITACHI, LTD.",
        "address_1": "NETWORK ENGINEERING DIV.",
        "address_2": "  TOKYO 140",
        "country": "JP"
    },
    "000258": {
        "oui_hex": "00-02-58",
        "organization": "Flying Packets Communications",
        "address_1": "388 Market Street",
        "address_2": "San Francisco  CA  94111",
        "country": "US"
    },
    "00024E": {
        "oui_hex": "00-02-4E",
        "organization": "Datacard Group",
        "address_1": "11111 Bren Road West",
        "address_2": "Minnetonka  MN  55343",
        "country": "US"
    },
    "000242": {
        "oui_hex": "00-02-42",
        "organization": "Videoframe Systems",
        "address_1": "101 Providence Mine Road",
        "address_2": "Nevada City  CA  95959",
        "country": "US"
    },
    "000244": {
        "oui_hex": "00-02-44",
        "organization": "SURECOM Technology Co.",
        "address_1": "6F, No. 125, Sec. 2, Datung Rd.",
        "address_2": "Taiwan  Taiwan  R.O.C.",
        "country": "TW"
    },
    "00023E": {
        "oui_hex": "00-02-3E",
        "organization": "Selta Telematica S.p.a",
        "address_1": "Via Nazionale km 404.5",
        "address_2": "",
        "country": "IT"
    },
    "000241": {
        "oui_hex": "00-02-41",
        "organization": "Amer.com",
        "address_1": "7259 Bryan Dairy Road",
        "address_2": "Largo  FL  33777",
        "country": "US"
    },
    "000207": {
        "oui_hex": "00-02-07",
        "organization": "VisionGlobal Network Corp.",
        "address_1": "826 E. Stale Road",
        "address_2": "American Fork  UT  84003",
        "country": "US"
    },
    "000208": {
        "oui_hex": "00-02-08",
        "organization": "Unify Networks, Inc.",
        "address_1": "3160 De La Cruz Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000204": {
        "oui_hex": "00-02-04",
        "organization": "Bodmann Industries Elektronik GmbH",
        "address_1": "Messerschmittring 33",
        "address_2": "",
        "country": "DE"
    },
    "000229": {
        "oui_hex": "00-02-29",
        "organization": "Adtec Corporation",
        "address_1": "3F Megurohigashiyama Blg",
        "address_2": "",
        "country": "JP"
    },
    "00022D": {
        "oui_hex": "00-02-2D",
        "organization": "Agere Systems",
        "address_1": "P.O. Box 755",
        "address_2": "",
        "country": "NL"
    },
    "000226": {
        "oui_hex": "00-02-26",
        "organization": "XESystems, Inc.",
        "address_1": "317 Main Street",
        "address_2": "East Rochester  NY  14445",
        "country": "US"
    },
    "000225": {
        "oui_hex": "00-02-25",
        "organization": "One Stop Systems",
        "address_1": "2235 Enterprise Street",
        "address_2": "Escondido  CA  92029",
        "country": "US"
    },
    "000211": {
        "oui_hex": "00-02-11",
        "organization": "Nature Worldwide Technology Corp.",
        "address_1": "No. 1, Min-Chuan Street",
        "address_2": "Taiwan  Taiwan  R.O.C.",
        "country": "TW"
    },
    "000212": {
        "oui_hex": "00-02-12",
        "organization": "SierraCom",
        "address_1": "99 South Street",
        "address_2": "Hopkinton  Ma  01748",
        "country": "US"
    },
    "000217": {
        "oui_hex": "00-02-17",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00017A": {
        "oui_hex": "00-01-7A",
        "organization": "Chengdu Maipu Electric Industrial Co., Ltd.",
        "address_1": "NANYI BUILDING, CONSULATE RD.,",
        "address_2": "  P.R.",
        "country": "CN"
    },
    "000238": {
        "oui_hex": "00-02-38",
        "organization": "Serome Technology, Inc.",
        "address_1": "555-14, Baekang B/D 7F",
        "address_2": "Seoul  Korea  135-120",
        "country": "KR"
    },
    "000269": {
        "oui_hex": "00-02-69",
        "organization": "Nadatel Co., Ltd",
        "address_1": "9F CoWell Bldg, 66-1 Banpo-Dong",
        "address_2": "  KOREA  137-040",
        "country": "KR"
    },
    "000264": {
        "oui_hex": "00-02-64",
        "organization": "AudioRamp.com",
        "address_1": "15941 Red Hill Suite 205",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "000255": {
        "oui_hex": "00-02-55",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "000252": {
        "oui_hex": "00-02-52",
        "organization": "Carrier Corporation",
        "address_1": "One Carrier Place",
        "address_2": "Farmington  CT  06034-4015",
        "country": "US"
    },
    "000220": {
        "oui_hex": "00-02-20",
        "organization": "CANON FINETECH INC.",
        "address_1": "717, Yaguchi, Misato-shi,",
        "address_2": "Saitama    341-8527",
        "country": "JP"
    },
    "00020D": {
        "oui_hex": "00-02-0D",
        "organization": "Micronpc.com",
        "address_1": "900 E. Karcher Rd.",
        "address_2": "Nampa  IA  83687",
        "country": "US"
    },
    "0001D4": {
        "oui_hex": "00-01-D4",
        "organization": "Leisure Time, Inc.",
        "address_1": "4258 Communications Drive",
        "address_2": "Norcross  GA  30093",
        "country": "US"
    },
    "0001DD": {
        "oui_hex": "00-01-DD",
        "organization": "Avail Networks",
        "address_1": "305 E. Eisenhower Parkway",
        "address_2": "Ann Arbor  MI  48108",
        "country": "US"
    },
    "0001D5": {
        "oui_hex": "00-01-D5",
        "organization": "HAEDONG INFO & COMM CO., LTD",
        "address_1": "#801 The Corporation Center for Universi",
        "address_2": "Taejeon  Republic  of Korea 305",
        "country": "KR"
    },
    "0001D7": {
        "oui_hex": "00-01-D7",
        "organization": "F5 Networks, Inc.",
        "address_1": "1322 N. Whitman Lane",
        "address_2": "Liberty Lake  WA  99019",
        "country": "US"
    },
    "0001DE": {
        "oui_hex": "00-01-DE",
        "organization": "Trango Systems, Inc.",
        "address_1": "9939 V/A Pasar",
        "address_2": "San Diego  CA  92126",
        "country": "US"
    },
    "0001DC": {
        "oui_hex": "00-01-DC",
        "organization": "Activetelco",
        "address_1": "43222 Christy Street",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0001F9": {
        "oui_hex": "00-01-F9",
        "organization": "TeraGlobal Communications Corp.",
        "address_1": "9171 Towne Centre Drive",
        "address_2": "San Diego  CA  92122",
        "country": "US"
    },
    "0001FB": {
        "oui_hex": "00-01-FB",
        "organization": "DoTop Technology, Inc.",
        "address_1": "10F, No. 100, Min-Chyuan Road",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "0001F8": {
        "oui_hex": "00-01-F8",
        "organization": "TEXIO TECHNOLOGY CORPORATION",
        "address_1": "2-18-13 Shin Yokohama,",
        "address_2": "    222-0033",
        "country": "JP"
    },
    "0001BE": {
        "oui_hex": "00-01-BE",
        "organization": "Gigalink Co., Ltd.",
        "address_1": "6th F/L Diplomatic Center 1376-1",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001B1": {
        "oui_hex": "00-01-B1",
        "organization": "General Bandwidth",
        "address_1": "12303-B Technology Blvd.",
        "address_2": "Austin  TX  78727",
        "country": "US"
    },
    "0001BF": {
        "oui_hex": "00-01-BF",
        "organization": "Teleforce Co., Ltd.",
        "address_1": "721 yoshioka-cho kanonji-city",
        "address_2": "",
        "country": "JP"
    },
    "0001B4": {
        "oui_hex": "00-01-B4",
        "organization": "Wayport, Inc.",
        "address_1": "1609 Shoal Creek Blvd.",
        "address_2": "Austin  TX  78701",
        "country": "US"
    },
    "0001BA": {
        "oui_hex": "00-01-BA",
        "organization": "IC-Net, Inc.",
        "address_1": "5 Fl. Seasung Bldg., 311-27 Noryangjin-D",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001CF": {
        "oui_hex": "00-01-CF",
        "organization": "Alpha Data Parallel Systems, Ltd.",
        "address_1": "58 Timber Bush",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0001D0": {
        "oui_hex": "00-01-D0",
        "organization": "VitalPoint, Inc.",
        "address_1": "15770 Hopper Road",
        "address_2": "Peyton  CO  80831",
        "country": "US"
    },
    "0001B0": {
        "oui_hex": "00-01-B0",
        "organization": "Fulltek Technology Co., Ltd.",
        "address_1": "3F No. 8, Lane 130, Min Chuan Rd., Hsint",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0001A9": {
        "oui_hex": "00-01-A9",
        "organization": "BMW AG",
        "address_1": "Dept. FG-322",
        "address_2": "80788  Munich",
        "country": "DE"
    },
    "0001AA": {
        "oui_hex": "00-01-AA",
        "organization": "Airspan Communications, Ltd.",
        "address_1": "Cambridge House, Oxford Rd.,",
        "address_2": "",
        "country": "GB"
    },
    "00019E": {
        "oui_hex": "00-01-9E",
        "organization": "ESS Technology, Inc.",
        "address_1": "48401 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00017D": {
        "oui_hex": "00-01-7D",
        "organization": "ThermoQuest",
        "address_1": "355 River Oaks Parkway",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000181": {
        "oui_hex": "00-01-81",
        "organization": "Nortel Networks",
        "address_1": "1100 Technology Park Drive",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "000194": {
        "oui_hex": "00-01-94",
        "organization": "Capital Equipment Corporation",
        "address_1": "900 Middlesex Turnpike - Bldg. 2",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "000198": {
        "oui_hex": "00-01-98",
        "organization": "Darim Vision",
        "address_1": "Taejon Expo Venture Town",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001E8": {
        "oui_hex": "00-01-E8",
        "organization": "Force10 Networks, Inc.",
        "address_1": "1440 McCarthy Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0001E9": {
        "oui_hex": "00-01-E9",
        "organization": "Litton Marine Systems B.V.",
        "address_1": "118 Burlington Road",
        "address_2": "ENGLAND  KT3  4NR",
        "country": "GB"
    },
    "0001E5": {
        "oui_hex": "00-01-E5",
        "organization": "Supernet, Inc.",
        "address_1": "135-080 Daemeong Bldg.",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001A2": {
        "oui_hex": "00-01-A2",
        "organization": "Logical Co., Ltd.",
        "address_1": "4598 Murakushi-cho",
        "address_2": "  431-1207",
        "country": "JP"
    },
    "000185": {
        "oui_hex": "00-01-85",
        "organization": "Hitachi Aloka Medical, Ltd.",
        "address_1": "3-7-19, Imai Ome-city",
        "address_2": "  198-8577",
        "country": "JP"
    },
    "0001C7": {
        "oui_hex": "00-01-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000121": {
        "oui_hex": "00-01-21",
        "organization": "WatchGuard Technologies, Inc.",
        "address_1": "605 Fifth Ave. S",
        "address_2": "Seattle  WA  98104-3892",
        "country": "US"
    },
    "000129": {
        "oui_hex": "00-01-29",
        "organization": "DFI Inc.",
        "address_1": "100, Huan-Ho Street",
        "address_2": "Hsi-Chih City  Taipei Hsien",
        "country": "TW"
    },
    "000119": {
        "oui_hex": "00-01-19",
        "organization": "RTUnet (Australia)",
        "address_1": "8/3-5 Gilda Court",
        "address_2": "Mulgrave  Vic  3170",
        "country": "AU"
    },
    "000122": {
        "oui_hex": "00-01-22",
        "organization": "Trend Communications, Ltd.",
        "address_1": "Knaves Beech Estate",
        "address_2": "Bucks, HP10 9QZ",
        "country": "GB"
    },
    "00011A": {
        "oui_hex": "00-01-1A",
        "organization": "Hoffmann und Burmeister GbR",
        "address_1": "Niederberger Str. 75",
        "address_2": "D-53909 Zuelpich",
        "country": "DE"
    },
    "00010A": {
        "oui_hex": "00-01-0A",
        "organization": "CIS TECHNOLOGY INC.",
        "address_1": "16F, No. 75 Hsin Tai Wu Road",
        "address_2": "Taipei Hsien 221",
        "country": "TW"
    },
    "000167": {
        "oui_hex": "00-01-67",
        "organization": "HIOKI E.E. CORPORATION",
        "address_1": "81 Koizumi, Ueda, Nagano",
        "address_2": "386-1192  386-1192",
        "country": "JP"
    },
    "000168": {
        "oui_hex": "00-01-68",
        "organization": "VITANA CORPORATION",
        "address_1": "2500 Don Reid Drive",
        "address_2": "K1H 1E1  K1H 1E1",
        "country": "CA"
    },
    "000162": {
        "oui_hex": "00-01-62",
        "organization": "Cygnet Technologies, Inc.",
        "address_1": "1411 LeMay Drive #301",
        "address_2": "Carrollton  TX  75007",
        "country": "US"
    },
    "000154": {
        "oui_hex": "00-01-54",
        "organization": "G3M Corporation",
        "address_1": "4320 Stevens Creek Blvd. - Ste. #275",
        "address_2": "San Jose  CA  95129",
        "country": "US"
    },
    "000152": {
        "oui_hex": "00-01-52",
        "organization": "CHROMATEK INC.",
        "address_1": "6-10, Miyazaki 2-Chome",
        "address_2": "",
        "country": "JP"
    },
    "000150": {
        "oui_hex": "00-01-50",
        "organization": "GILAT COMMUNICATIONS, LTD.",
        "address_1": "21/D Yegia Kapayim Street",
        "address_2": "",
        "country": "IL"
    },
    "000151": {
        "oui_hex": "00-01-51",
        "organization": "Ensemble Communications",
        "address_1": "6256 Greenman Drive - Ste. #400",
        "address_2": "San Diego  CA  92122",
        "country": "US"
    },
    "000115": {
        "oui_hex": "00-01-15",
        "organization": "EXTRATECH CORPORATION",
        "address_1": "760 Thornton St., Unit 2",
        "address_2": "Post Falls  ID  83854",
        "country": "US"
    },
    "000101": {
        "oui_hex": "00-01-01",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "00010D": {
        "oui_hex": "00-01-0D",
        "organization": "Teledyne DALSA Inc.",
        "address_1": "880 McCaffrey",
        "address_2": "St-Laurent  Quebec  H4T 2C7",
        "country": "CA"
    },
    "000105": {
        "oui_hex": "00-01-05",
        "organization": "Beckhoff Automation GmbH",
        "address_1": "Eiserstraße 5",
        "address_2": "Verl  NRW  33415",
        "country": "DE"
    },
    "00B017": {
        "oui_hex": "00-B0-17",
        "organization": "InfoGear Technology Corp.",
        "address_1": "2055 Woodside Road",
        "address_2": "Redwood City  CA  94061",
        "country": "US"
    },
    "00012C": {
        "oui_hex": "00-01-2C",
        "organization": "Aravox Technologies, Inc.",
        "address_1": "16725 40th Place North",
        "address_2": "Plymouth  MN  55446",
        "country": "US"
    },
    "000142": {
        "oui_hex": "00-01-42",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000164": {
        "oui_hex": "00-01-64",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00015F": {
        "oui_hex": "00-01-5F",
        "organization": "DIGITAL DESIGN GmbH",
        "address_1": "Rauchstr. 21",
        "address_2": "  Berlin  D-10787",
        "country": "DE"
    },
    "00012B": {
        "oui_hex": "00-01-2B",
        "organization": "TELENET Co., Ltd.",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "00013F": {
        "oui_hex": "00-01-3F",
        "organization": "Neighbor World Co., Ltd.",
        "address_1": "114A YERC, 134, Shinchon_dong",
        "address_2": "120-749  120-749  KOREA",
        "country": "KR"
    },
    "000124": {
        "oui_hex": "00-01-24",
        "organization": "Acer Incorporated",
        "address_1": "21F, 88, Sec.1",
        "address_2": "Taipei Hsien 221",
        "country": "TW"
    },
    "003088": {
        "oui_hex": "00-30-88",
        "organization": "Ericsson",
        "address_1": "250 Holger Way",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "003020": {
        "oui_hex": "00-30-20",
        "organization": "TSI, Inc..",
        "address_1": "500 Cardigan Road",
        "address_2": "Shoreview  MN  55126",
        "country": "US"
    },
    "003095": {
        "oui_hex": "00-30-95",
        "organization": "Procomp Informatics, Ltd.",
        "address_1": "5F, 69-10, Sec. 2,",
        "address_2": "Tamshui, Taipei, Hsien",
        "country": "TW"
    },
    "0030CA": {
        "oui_hex": "00-30-CA",
        "organization": "Discovery Com",
        "address_1": "4935 Century Street",
        "address_2": "Huntsville  AL  35816",
        "country": "US"
    },
    "0030CE": {
        "oui_hex": "00-30-CE",
        "organization": "Zaffire",
        "address_1": "2630 Orchard Parkway",
        "address_2": "San Jose  CA  95134-2020",
        "country": "US"
    },
    "00307B": {
        "oui_hex": "00-30-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0030B5": {
        "oui_hex": "00-30-B5",
        "organization": "Tadiran Microwave Networks",
        "address_1": "4000 Greenbriar Drive",
        "address_2": "Stafford  TX  77477",
        "country": "US"
    },
    "0030B8": {
        "oui_hex": "00-30-B8",
        "organization": "RiverDelta Networks",
        "address_1": "Three Highwood Drive East",
        "address_2": "Tewksbury  MA  01876",
        "country": "US"
    },
    "003071": {
        "oui_hex": "00-30-71",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00303A": {
        "oui_hex": "00-30-3A",
        "organization": "MAATEL",
        "address_1": "495 RUE DE POMMARIN",
        "address_2": "38360 VOREPPE",
        "country": "FR"
    },
    "00304E": {
        "oui_hex": "00-30-4E",
        "organization": "BUSTEC PRODUCTION LTD.",
        "address_1": "WORLD AVIATION PARK",
        "address_2": "Shannon  County Clare",
        "country": "IE"
    },
    "0030A4": {
        "oui_hex": "00-30-A4",
        "organization": "Woodwind Communications System",
        "address_1": "20300 Century Blvd., Suite 200B",
        "address_2": "Germantown  MD  20874",
        "country": "US"
    },
    "00303B": {
        "oui_hex": "00-30-3B",
        "organization": "PowerCom Technology",
        "address_1": "2F, No. 34, Industry E. Road IV",
        "address_2": "Hsinchu 300",
        "country": "TW"
    },
    "0030BC": {
        "oui_hex": "00-30-BC",
        "organization": "Optronic AG",
        "address_1": "untereggerstrasse 53",
        "address_2": "9403 Goldach",
        "country": "CH"
    },
    "00B02D": {
        "oui_hex": "00-B0-2D",
        "organization": "ViaGate Technologies, Inc.",
        "address_1": "745 Route 202/206",
        "address_2": "Bridgewater  NJ  08807",
        "country": "US"
    },
    "0030EE": {
        "oui_hex": "00-30-EE",
        "organization": "DSG Technology, Inc.",
        "address_1": "6F-4 No. 270, Chwig Hsiao",
        "address_2": " Taipei",
        "country": "TW"
    },
    "00309E": {
        "oui_hex": "00-30-9E",
        "organization": "WORKBIT CORPORATION.",
        "address_1": "1-2-2 Chuou, Yamato",
        "address_2": "Kanagawa  242-0021",
        "country": "JP"
    },
    "0030DE": {
        "oui_hex": "00-30-DE",
        "organization": "WAGO Kontakttechnik GmbH",
        "address_1": "Hansastrasse 27",
        "address_2": "32423 Minden",
        "country": "DE"
    },
    "00303E": {
        "oui_hex": "00-30-3E",
        "organization": "Radcom Ltd.",
        "address_1": "12 Hanechoshet Street",
        "address_2": "Tel-Aviv 69710",
        "country": "IL"
    },
    "0030D7": {
        "oui_hex": "00-30-D7",
        "organization": "Innovative Systems, L.L.C.",
        "address_1": "1000 Innovative Drive",
        "address_2": "Mitchell  SD  57301",
        "country": "US"
    },
    "00B0CE": {
        "oui_hex": "00-B0-CE",
        "organization": "Viveris Technologies",
        "address_1": "1 rue Traversiere BP 20327",
        "address_2": "Rungis Cedex    94598",
        "country": "FR"
    },
    "00B01C": {
        "oui_hex": "00-B0-1C",
        "organization": "Westport Technologies",
        "address_1": "15 Capella Court, Unit 116",
        "address_2": "Nepean  Ontario",
        "country": "CA"
    },
    "00B04A": {
        "oui_hex": "00-B0-4A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00B048": {
        "oui_hex": "00-B0-48",
        "organization": "Marconi Communications Inc.",
        "address_1": "8616 Freeport Parkway",
        "address_2": "Irving  TX  75063",
        "country": "US"
    },
    "00301B": {
        "oui_hex": "00-30-1B",
        "organization": "SHUTTLE, INC.",
        "address_1": "5F, No. 34, Lane 60",
        "address_2": "Taipei",
        "country": "TW"
    },
    "003021": {
        "oui_hex": "00-30-21",
        "organization": "HSING TECH. ENTERPRISE CO.,LTD",
        "address_1": "2F, NO. 22, ALLLEY 38, LANE 91",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "00302C": {
        "oui_hex": "00-30-2C",
        "organization": "SYLANTRO SYSTEMS CORPORATION",
        "address_1": "1686 DELL AVENUE",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "0030DF": {
        "oui_hex": "00-30-DF",
        "organization": "KB/TEL TELECOMUNICACIONES",
        "address_1": "S.A. DE C.V.",
        "address_2": "Mexico City 14060",
        "country": "MX"
    },
    "003030": {
        "oui_hex": "00-30-30",
        "organization": "HARMONIX CORPORATION",
        "address_1": "1755 OSGOOD STREET",
        "address_2": "NORTH ANDOVER  MA  01845",
        "country": "US"
    },
    "003063": {
        "oui_hex": "00-30-63",
        "organization": "SANTERA SYSTEMS, INC.",
        "address_1": "2901 SUMMIT AVENUE - STE. #100",
        "address_2": "PLANO  TX  75074",
        "country": "US"
    },
    "0030A3": {
        "oui_hex": "00-30-A3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0030DD": {
        "oui_hex": "00-30-DD",
        "organization": "INDIGITA CORPORATION",
        "address_1": "30 Corporate Park Drive",
        "address_2": "Irvine  CA  92606",
        "country": "US"
    },
    "003099": {
        "oui_hex": "00-30-99",
        "organization": "BOENIG UND KALLENBACH OHG",
        "address_1": "AM SPOERKEL 100",
        "address_2": "",
        "country": "DE"
    },
    "0030F2": {
        "oui_hex": "00-30-F2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003051": {
        "oui_hex": "00-30-51",
        "organization": "ORBIT AVIONIC & COMMUNICATION",
        "address_1": "SYSTEMS, LTD.",
        "address_2": "",
        "country": "IL"
    },
    "00308E": {
        "oui_hex": "00-30-8E",
        "organization": "CROSS MATCH TECHNOLOGIES, INC.",
        "address_1": "3960 RCA Blvd., Suite 6001",
        "address_2": "Palm Beach  FL  33410",
        "country": "US"
    },
    "003027": {
        "oui_hex": "00-30-27",
        "organization": "KERBANGO, INC.",
        "address_1": "21771 STEVENS CREEK BLVD. #100",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "003033": {
        "oui_hex": "00-30-33",
        "organization": "ORIENT TELECOM CO., LTD.",
        "address_1": "MISUNG BULDING 115-7",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "003008": {
        "oui_hex": "00-30-08",
        "organization": "AVIO DIGITAL, INC.",
        "address_1": "957 INDUSTRIAL ROAD",
        "address_2": "SAN CARLOS  CA  94070",
        "country": "US"
    },
    "00301D": {
        "oui_hex": "00-30-1D",
        "organization": "SKYSTREAM, INC.",
        "address_1": "455 DeGuigne Drive",
        "address_2": "Sunnyvale  CA  94086-3835",
        "country": "US"
    },
    "0030BA": {
        "oui_hex": "00-30-BA",
        "organization": "AC&T SYSTEM CO., LTD.",
        "address_1": "ROOM 702, KEUM-WHA PLAZA",
        "address_2": "435-040  SOUTH  KOREA",
        "country": "KR"
    },
    "0030FD": {
        "oui_hex": "00-30-FD",
        "organization": "INTEGRATED SYSTEMS DESIGN",
        "address_1": "3650-G CENTRE CIRCLE DRIVE",
        "address_2": "FORT MILL  SC  29715",
        "country": "US"
    },
    "0030B9": {
        "oui_hex": "00-30-B9",
        "organization": "ECTEL",
        "address_1": "22240 COMSAT DRIVE",
        "address_2": "CLARKSBURG  MD  20871",
        "country": "US"
    },
    "00307D": {
        "oui_hex": "00-30-7D",
        "organization": "GRE AMERICA, INC.",
        "address_1": "425 HARBOR BLVD.",
        "address_2": "BELMONT  CA  94002",
        "country": "US"
    },
    "0030EF": {
        "oui_hex": "00-30-EF",
        "organization": "NEON TECHNOLOGY, INC.",
        "address_1": "85 WEST MONTAGUE EXPRESSWAY",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "003096": {
        "oui_hex": "00-30-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003039": {
        "oui_hex": "00-30-39",
        "organization": "SOFTBOOK PRESS",
        "address_1": "7745 HERSCHEL AVENUE",
        "address_2": "LA JOLLA  CA  92037",
        "country": "US"
    },
    "00D0F8": {
        "oui_hex": "00-D0-F8",
        "organization": "FUJIAN STAR TERMINAL",
        "address_1": "DEVICE CO., LTD.",
        "address_2": "FUZHOU  FUJIAN,  CHINA 350002",
        "country": "CN"
    },
    "00D0ED": {
        "oui_hex": "00-D0-ED",
        "organization": "XIOX",
        "address_1": "150 DOW STREET",
        "address_2": "MANCHESTER  NH  03101",
        "country": "US"
    },
    "00D097": {
        "oui_hex": "00-D0-97",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D08E": {
        "oui_hex": "00-D0-8E",
        "organization": "Grass Valley, A Belden Brand",
        "address_1": "3499, Douglas B. Floreani",
        "address_2": "Montreal  Quebec  H4S 2C6",
        "country": "CA"
    },
    "00D056": {
        "oui_hex": "00-D0-56",
        "organization": "SOMAT CORPORATION",
        "address_1": "702 KILLARNEY STREET",
        "address_2": "URBANA  IL  61801",
        "country": "US"
    },
    "00D0E0": {
        "oui_hex": "00-D0-E0",
        "organization": "DOOIN ELECTRONICS CO.",
        "address_1": "DOOIN BLDG. 16-6, SOONAE-DONG",
        "address_2": "  KOREA  463-020",
        "country": "KR"
    },
    "00D000": {
        "oui_hex": "00-D0-00",
        "organization": "FERRAN SCIENTIFIC, INC.",
        "address_1": "11558 SORRENTO VALLEY ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00D0D0": {
        "oui_hex": "00-D0-D0",
        "organization": "ZHONGXING TELECOM LTD.",
        "address_1": "8-9F BUILDING 54,301#",
        "address_2": "",
        "country": "CN"
    },
    "00D053": {
        "oui_hex": "00-D0-53",
        "organization": "CONNECTED SYSTEMS",
        "address_1": "126 W. FIGUEROA STREET",
        "address_2": "SANTA BARBARA  CA  93101",
        "country": "US"
    },
    "00D033": {
        "oui_hex": "00-D0-33",
        "organization": "DALIAN DAXIAN NETWORK",
        "address_1": "SYSTEM CO., LTD.",
        "address_2": "",
        "country": "CN"
    },
    "00D0D6": {
        "oui_hex": "00-D0-D6",
        "organization": "AETHRA TELECOMUNICAZIONI",
        "address_1": "VIA MATTEO RICCI, 10",
        "address_2": "",
        "country": "IT"
    },
    "00D063": {
        "oui_hex": "00-D0-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D047": {
        "oui_hex": "00-D0-47",
        "organization": "XN TECHNOLOGIES",
        "address_1": "P.O. BOX 350",
        "address_2": "CHENEY  WA  99004",
        "country": "US"
    },
    "00D055": {
        "oui_hex": "00-D0-55",
        "organization": "KATHREIN-WERKE KG",
        "address_1": "ANTON-KATHREIN-STRASS 1-3",
        "address_2": "",
        "country": "DE"
    },
    "00D03B": {
        "oui_hex": "00-D0-3B",
        "organization": "VISION PRODUCTS PTY. LTD.",
        "address_1": "SECOND AVENUE, TECHNOLOGY PARK",
        "address_2": "  AUSTRALIA  5095",
        "country": "AU"
    },
    "00D0B3": {
        "oui_hex": "00-D0-B3",
        "organization": "DRS Technologies Canada Ltd",
        "address_1": "700 Palladium Drive",
        "address_2": "Ottawa  Ontario  K2V 1C6",
        "country": "CA"
    },
    "00D0AF": {
        "oui_hex": "00-D0-AF",
        "organization": "CUTLER-HAMMER, INC.",
        "address_1": "PMP CENTER",
        "address_2": "PITTSBURGH  PA  15205",
        "country": "US"
    },
    "00D052": {
        "oui_hex": "00-D0-52",
        "organization": "ASCEND COMMUNICATIONS, INC.",
        "address_1": "1701 HARBOR BAY PARKWAY",
        "address_2": "ALAMEDA  CA  94502",
        "country": "US"
    },
    "00D0AD": {
        "oui_hex": "00-D0-AD",
        "organization": "TL INDUSTRIES",
        "address_1": "2541 TRACY ROAD",
        "address_2": "NORTHWOOD  OH  43619",
        "country": "US"
    },
    "00D0A4": {
        "oui_hex": "00-D0-A4",
        "organization": "ALANTRO COMMUNICATIONS",
        "address_1": "141 STONY CIRCLE,  STE. #210",
        "address_2": "SANTAROSA  CA  95401",
        "country": "US"
    },
    "00D0B0": {
        "oui_hex": "00-D0-B0",
        "organization": "BITSWITCH LTD.",
        "address_1": "3 MEADOW COURT, AMOS ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00D030": {
        "oui_hex": "00-D0-30",
        "organization": "Safetran Systems Corp",
        "address_1": "10655 7th Street",
        "address_2": "Rancho Cucamonga  CA  91730",
        "country": "US"
    },
    "00302A": {
        "oui_hex": "00-30-2A",
        "organization": "SOUTHERN INFORMATION",
        "address_1": "SYSTEM, INC.",
        "address_2": "HSINCHU  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "0030E1": {
        "oui_hex": "00-30-E1",
        "organization": "Network Equipment Technologies, Inc.",
        "address_1": "6900 Paseo Padre Parkway",
        "address_2": "Fremont  CA  94555",
        "country": "US"
    },
    "00302B": {
        "oui_hex": "00-30-2B",
        "organization": "INALP NETWORKS, INC.",
        "address_1": "MERIEDWEG 7",
        "address_2": "",
        "country": "CH"
    },
    "003001": {
        "oui_hex": "00-30-01",
        "organization": "SMP",
        "address_1": "22, RUE DES COSMONAUTES",
        "address_2": "",
        "country": "FR"
    },
    "00D08B": {
        "oui_hex": "00-D0-8B",
        "organization": "ADVA Optical Networking Ltd.",
        "address_1": "ADVAntage House",
        "address_2": "York    YO30 4RY",
        "country": "GB"
    },
    "00D0E4": {
        "oui_hex": "00-D0-E4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D05A": {
        "oui_hex": "00-D0-5A",
        "organization": "SYMBIONICS, LTD.",
        "address_1": "ST. JOHN'S INNOVATION PARK",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00D079": {
        "oui_hex": "00-D0-79",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D021": {
        "oui_hex": "00-D0-21",
        "organization": "REGENT ELECTRONICS CORP.",
        "address_1": "200 CENTENNIAL AVE.-STE. #201",
        "address_2": "PISCATAWAY  NJ  08854",
        "country": "US"
    },
    "00D09F": {
        "oui_hex": "00-D0-9F",
        "organization": "NOVTEK TEST SYSTEMS",
        "address_1": "2170 PARAGON DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00D0FE": {
        "oui_hex": "00-D0-FE",
        "organization": "ASTRAL POINT",
        "address_1": "COMMUNICATIONS, INC.",
        "address_2": "CHELMSFORD  MA  01824",
        "country": "US"
    },
    "00D0D4": {
        "oui_hex": "00-D0-D4",
        "organization": "V-BITS, INC.",
        "address_1": "2150 TRADE ZONE BLVD.",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00D084": {
        "oui_hex": "00-D0-84",
        "organization": "NEXCOMM SYSTEMS, INC.",
        "address_1": "SUIT #NAL-903,",
        "address_2": "SUNGNAM-CITY  SUNGNAM-CITY  KYUNGGI-DO,K",
        "country": "KR"
    },
    "00D099": {
        "oui_hex": "00-D0-99",
        "organization": "Elcard Wireless Systems Oy",
        "address_1": "P.O. BOX 120/BECKERINTIC 38",
        "address_2": "",
        "country": "FI"
    },
    "00D0E7": {
        "oui_hex": "00-D0-E7",
        "organization": "VCON TELECOMMUNICATION LTD.",
        "address_1": "22 MASKIT STREET",
        "address_2": "",
        "country": "IL"
    },
    "00D01B": {
        "oui_hex": "00-D0-1B",
        "organization": "MIMAKI ENGINEERING CO., LTD.",
        "address_1": "5-9-41 KITA SHINAGAWA",
        "address_2": "",
        "country": "JP"
    },
    "00D00D": {
        "oui_hex": "00-D0-0D",
        "organization": "MICROMERITICS INSTRUMENT",
        "address_1": "CORPORATION",
        "address_2": "NORCROSS  GA  30093-1877",
        "country": "US"
    },
    "00D054": {
        "oui_hex": "00-D0-54",
        "organization": "SAS INSTITUTE INC.",
        "address_1": "SAS CAMPUS DRIVE, R4",
        "address_2": "CARY  NC  27511",
        "country": "US"
    },
    "00D009": {
        "oui_hex": "00-D0-09",
        "organization": "HSING TECH. ENTERPRISE CO. LTD",
        "address_1": "NO.2, LANE 128, SEC. 2",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00D0F4": {
        "oui_hex": "00-D0-F4",
        "organization": "CARINTHIAN TECH INSTITUTE",
        "address_1": "RICHARD-WAGNER STR. 19",
        "address_2": "",
        "country": "AT"
    },
    "00D07D": {
        "oui_hex": "00-D0-7D",
        "organization": "COSINE COMMUNICATIONS",
        "address_1": "1200 BRIDGE PARKWAY",
        "address_2": "REDWOOD CITY  CA  94065",
        "country": "US"
    },
    "00D083": {
        "oui_hex": "00-D0-83",
        "organization": "INVERTEX, INC.",
        "address_1": "1012 MORSE AVENUE- STE.#9",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "00D0BA": {
        "oui_hex": "00-D0-BA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D098": {
        "oui_hex": "00-D0-98",
        "organization": "Photon Dynamics Canada Inc.",
        "address_1": "221 Whitehall Drive",
        "address_2": "    L3R 9T1",
        "country": "CA"
    },
    "00D0BE": {
        "oui_hex": "00-D0-BE",
        "organization": "EMUTEC INC.",
        "address_1": "P.O. BOX 3035",
        "address_2": "EVERETT  WA  98203",
        "country": "US"
    },
    "00D092": {
        "oui_hex": "00-D0-92",
        "organization": "GLENAYRE WESTERN MULTIPLEX",
        "address_1": "1196 BORREGAS AVENUE",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "00509D": {
        "oui_hex": "00-50-9D",
        "organization": "THE INDUSTREE B.V.",
        "address_1": "P.O. BOX 462",
        "address_2": "  THE",
        "country": "NL"
    },
    "00D0B8": {
        "oui_hex": "00-D0-B8",
        "organization": "Iomega Corporation",
        "address_1": "1821 West 4000 South",
        "address_2": "Roy  UT  84067",
        "country": "US"
    },
    "0050CB": {
        "oui_hex": "00-50-CB",
        "organization": "JETTER",
        "address_1": "GRAETERSTRASSE 2",
        "address_2": "",
        "country": "DE"
    },
    "005058": {
        "oui_hex": "00-50-58",
        "organization": "Sangoma Technologies",
        "address_1": "100 Renfrew Drive, Suite 100",
        "address_2": "Markham  ON  L3R 9R6",
        "country": "CA"
    },
    "005074": {
        "oui_hex": "00-50-74",
        "organization": "ADVANCED HI-TECH CORP.",
        "address_1": "1990 EAST GRAND AVE.",
        "address_2": "EL SEGUNDO  CA  90505",
        "country": "US"
    },
    "00500A": {
        "oui_hex": "00-50-0A",
        "organization": "IRIS TECHNOLOGIES, INC.",
        "address_1": "WESTMORELAND INDUSRIAL PARK",
        "address_2": "GREENSBURG  PA  15601",
        "country": "US"
    },
    "00506D": {
        "oui_hex": "00-50-6D",
        "organization": "VIDEOJET SYSTEMS",
        "address_1": "INTERNATIONAL INC.",
        "address_2": "WOODDALE  IL  60091-1073",
        "country": "US"
    },
    "0050CA": {
        "oui_hex": "00-50-CA",
        "organization": "NET TO NET TECHNOLOGIES",
        "address_1": "680 CENTRAL AVENUE - STE. #301",
        "address_2": "DOVER  NH  03820",
        "country": "US"
    },
    "00D0C7": {
        "oui_hex": "00-D0-C7",
        "organization": "PATHWAY, INC.",
        "address_1": "777 BETA DRIVE",
        "address_2": "MAYFIELD VILLAGE  OH  44143",
        "country": "US"
    },
    "00D07A": {
        "oui_hex": "00-D0-7A",
        "organization": "AMAQUEST COMPUTER CORP.",
        "address_1": "8/F, 79 HSIN-TAI",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00503F": {
        "oui_hex": "00-50-3F",
        "organization": "ANCHOR GAMES",
        "address_1": "815 PILOT ROAD - STE",
        "address_2": "LAS VEGAS  NV  89119",
        "country": "US"
    },
    "005032": {
        "oui_hex": "00-50-32",
        "organization": "PICAZO COMMUNICATIONS, INC.",
        "address_1": "61 DAGGETT DRIVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00D04A": {
        "oui_hex": "00-D0-4A",
        "organization": "PRESENCE TECHNOLOGY GMBH",
        "address_1": "+ CO. KG",
        "address_2": "",
        "country": "DE"
    },
    "00D074": {
        "oui_hex": "00-D0-74",
        "organization": "TAQUA SYSTEMS, INC.",
        "address_1": "1600 FALMOUTH RD. - STE",
        "address_2": "CENTERVILLE  MA  02632",
        "country": "US"
    },
    "00504D": {
        "oui_hex": "00-50-4D",
        "organization": "Tokyo Electron Device Limited",
        "address_1": "1, Higashikata-machi, Tsuzuki-ku,",
        "address_2": "Yokohama-shi  Kanagawa-ken",
        "country": "JP"
    },
    "005070": {
        "oui_hex": "00-50-70",
        "organization": "CHAINTECH COMPUTER CO., LTD.",
        "address_1": "5TH F, ALLEY 2, LANE 222",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "005023": {
        "oui_hex": "00-50-23",
        "organization": "PG DESIGN ELECTRONICS, INC.",
        "address_1": "48700 STRUCTURAL DRIVE",
        "address_2": "CHESTERFIELD  MI  48051",
        "country": "US"
    },
    "00509E": {
        "oui_hex": "00-50-9E",
        "organization": "Les Technologies SoftAcoustik Inc.",
        "address_1": "",
        "address_2": "Quebec G1K  3P6",
        "country": "CA"
    },
    "005071": {
        "oui_hex": "00-50-71",
        "organization": "AIWA CO., LTD.",
        "address_1": "1-11, KAMITOMATSURI 4-CHOME",
        "address_2": "UTSUNOMIYA-SHI, TOCHIGI-KEN 320-85",
        "country": "JP"
    },
    "00505F": {
        "oui_hex": "00-50-5F",
        "organization": "BRAND INNOVATORS",
        "address_1": "Steenovenweg 5",
        "address_2": "Helmond    5708 HN",
        "country": "NL"
    },
    "0050B4": {
        "oui_hex": "00-50-B4",
        "organization": "SATCHWELL CONTROL SYSTEMS, LTD",
        "address_1": "P.O. BOX 57,  94 FARNHAM ROAD",
        "address_2": "BERKSHIRE SL1 4UH",
        "country": "GB"
    },
    "0050D6": {
        "oui_hex": "00-50-D6",
        "organization": "ATLAS COPCO TOOLS AB",
        "address_1": "",
        "address_2": "S-105 23 STOCKHOLM",
        "country": "SE"
    },
    "005082": {
        "oui_hex": "00-50-82",
        "organization": "FORESSON CORPORATION",
        "address_1": "3F, NO.9 SEC.1",
        "address_2": "TAIPEI 10404",
        "country": "TW"
    },
    "0050DF": {
        "oui_hex": "00-50-DF",
        "organization": "AirFiber, Inc.",
        "address_1": "P.O. BOX 502148",
        "address_2": "SAN DIEGO  CA  92150-2148",
        "country": "US"
    },
    "0050C5": {
        "oui_hex": "00-50-C5",
        "organization": "ADS Technologies, Inc",
        "address_1": "12627 Hiddencreek Way",
        "address_2": "Cerritos  CA  90703",
        "country": "US"
    },
    "00508E": {
        "oui_hex": "00-50-8E",
        "organization": "OPTIMATION, INC.",
        "address_1": "P.O. BOX 14357",
        "address_2": "HUNTSVILLE  AL  35815",
        "country": "US"
    },
    "005028": {
        "oui_hex": "00-50-28",
        "organization": "AVAL COMMUNICATIONS",
        "address_1": "1777 NORTH CALIFORNIA BLVD.",
        "address_2": "WALNUT CREEK  CA  94596",
        "country": "US"
    },
    "00502F": {
        "oui_hex": "00-50-2F",
        "organization": "TollBridge Technologies, Inc.",
        "address_1": "872 HERMOSA DRIVE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0050FE": {
        "oui_hex": "00-50-FE",
        "organization": "PCTVnet ASA",
        "address_1": "STRANDVEILEN 50",
        "address_2": "N-1324 LYSAKER",
        "country": "NO"
    },
    "0050AB": {
        "oui_hex": "00-50-AB",
        "organization": "NALTEC, Inc.",
        "address_1": "1-1-15, Nakanogo, Shimizu-ku",
        "address_2": "Shizuoka-shi  Shizuoka  424-0888",
        "country": "JP"
    },
    "005037": {
        "oui_hex": "00-50-37",
        "organization": "KOGA ELECTRONICS CO.",
        "address_1": "5-8-10, TEHARA, RITTO-CHO",
        "address_2": "SHIGA, 420-3047",
        "country": "JP"
    },
    "0050A8": {
        "oui_hex": "00-50-A8",
        "organization": "OpenCon Systems, Inc.",
        "address_1": "377 HOES LANE",
        "address_2": "PISCATAWAY  NJ  08854",
        "country": "US"
    },
    "00509C": {
        "oui_hex": "00-50-9C",
        "organization": "BETA RESEARCH",
        "address_1": "BETASTR. 1",
        "address_2": "85774 UNTERFOEHRING",
        "country": "DE"
    },
    "0050B1": {
        "oui_hex": "00-50-B1",
        "organization": "GIDDINGS & LEWIS",
        "address_1": "660 S. MILITARY RD.",
        "address_2": "FOND DU LAC  WI  54935",
        "country": "US"
    },
    "005006": {
        "oui_hex": "00-50-06",
        "organization": "TAC AB",
        "address_1": "JAGERSHILLGATON 18",
        "address_2": "21375 MALMO",
        "country": "SE"
    },
    "005009": {
        "oui_hex": "00-50-09",
        "organization": "PHILIPS BROADBAND NETWORKS",
        "address_1": "64 PERIMETER CENTRE EAST",
        "address_2": "ATLANTA  GA  30346",
        "country": "US"
    },
    "005030": {
        "oui_hex": "00-50-30",
        "organization": "FUTURE PLUS SYSTEMS",
        "address_1": "36 OLDE ENGLISH RD.",
        "address_2": "BEDFORD  NH  03110",
        "country": "US"
    },
    "005078": {
        "oui_hex": "00-50-78",
        "organization": "MEGATON HOUSE, LTD.",
        "address_1": "ZIP: 224 NO.1-3-5 NAKAMACHIBAI",
        "address_2": "YOKOHAMA",
        "country": "JP"
    },
    "005002": {
        "oui_hex": "00-50-02",
        "organization": "OMNISEC AG",
        "address_1": "RIETSTRASSE 14",
        "address_2": "CH-8108 DAELLIKON",
        "country": "CH"
    },
    "00506A": {
        "oui_hex": "00-50-6A",
        "organization": "EDEVA, INC.",
        "address_1": "298 S. SUNNYVALE AVE. - #208",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0050AA": {
        "oui_hex": "00-50-AA",
        "organization": "KONICA MINOLTA HOLDINGS, INC.",
        "address_1": "1-6-1, Marunouchi,",
        "address_2": "Tokyo    100-0005",
        "country": "JP"
    },
    "005038": {
        "oui_hex": "00-50-38",
        "organization": "DAIN TELECOM CO., LTD.",
        "address_1": "2ND Flr., OH-SUNG BLDG. #2-28",
        "address_2": "YANGJAE-DONG, SEOCHO-GU  SEOUL",
        "country": "KR"
    },
    "0050B7": {
        "oui_hex": "00-50-B7",
        "organization": "BOSER TECHNOLOGY CO., LTD.",
        "address_1": "15F-6, 77 HSIN TAI WU ROAD",
        "address_2": "TAIPEI HSIEN",
        "country": "TW"
    },
    "009088": {
        "oui_hex": "00-90-88",
        "organization": "BAXALL SECURITY LTD.",
        "address_1": "UNIT 1 CASTLEHILL",
        "address_2": "STOCKPORT  Great Britain SK6 2SV",
        "country": "GB"
    },
    "00906C": {
        "oui_hex": "00-90-6C",
        "organization": "Sartorius Hamburg GmbH",
        "address_1": "Meiendorferstraße 205",
        "address_2": "Hamburg    D-22145",
        "country": "DE"
    },
    "0090A4": {
        "oui_hex": "00-90-A4",
        "organization": "ALTIGA NETWORKS",
        "address_1": "124 GROVE STREET",
        "address_2": "FRANKLIN  MA  02038-3206",
        "country": "US"
    },
    "0090F9": {
        "oui_hex": "00-90-F9",
        "organization": "Imagine Communications",
        "address_1": "3001 Dallas Parkway, Suite 300",
        "address_2": "Frisco  TX  75034",
        "country": "US"
    },
    "009089": {
        "oui_hex": "00-90-89",
        "organization": "SOFTCOM MICROSYSTEMS, INC.",
        "address_1": "47509 SEABRIDGE DRIVE",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "0090EE": {
        "oui_hex": "00-90-EE",
        "organization": "PERSONAL COMMUNICATIONS TECHNOLOGIES",
        "address_1": "50 STILES ROAD",
        "address_2": "SALEM  NH  03079",
        "country": "US"
    },
    "009080": {
        "oui_hex": "00-90-80",
        "organization": "NOT LIMITED, INC.",
        "address_1": "500 ALLERTON STREET, STE #102",
        "address_2": "REDWOOD CITY  CA  94063",
        "country": "US"
    },
    "0090E8": {
        "oui_hex": "00-90-E8",
        "organization": "MOXA TECHNOLOGIES CORP., LTD.",
        "address_1": "7F, NO. 2, ALY6, LN 235",
        "address_2": "SHIENG-TIEN CITY  TAIPEI",
        "country": "TW"
    },
    "0090A1": {
        "oui_hex": "00-90-A1",
        "organization": "Flying Pig Systems/High End Systems Inc.",
        "address_1": "2105 Gracy Farms Lane",
        "address_2": "Austin  TX  78758",
        "country": "US"
    },
    "009079": {
        "oui_hex": "00-90-79",
        "organization": "ClearOne, Inc.",
        "address_1": "299 WASHINGTON STREET",
        "address_2": "WOBURN  MA  01801",
        "country": "US"
    },
    "00909A": {
        "oui_hex": "00-90-9A",
        "organization": "ONE WORLD SYSTEMS, INC.",
        "address_1": "1144 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0090C2": {
        "oui_hex": "00-90-C2",
        "organization": "JK microsystems, Inc.",
        "address_1": "1275 YUBA AVENUE",
        "address_2": "SAN PABLO  CA  94806",
        "country": "US"
    },
    "0050D0": {
        "oui_hex": "00-50-D0",
        "organization": "MINERVA SYSTEMS",
        "address_1": "1585 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  84943",
        "country": "US"
    },
    "0050D8": {
        "oui_hex": "00-50-D8",
        "organization": "UNICORN COMPUTER CORP.",
        "address_1": "7 FL.,  NO. 96 KWANG FU NORTH ROAD",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "0050B2": {
        "oui_hex": "00-50-B2",
        "organization": "BRODEL GmbH",
        "address_1": "Distelbusch 24",
        "address_2": "Velbert  NRW  42549",
        "country": "DE"
    },
    "009076": {
        "oui_hex": "00-90-76",
        "organization": "FMT AIRCRAFT GATE SUPPORT SYSTEMS AB",
        "address_1": "",
        "address_2": "SE-231 32 TRELLEBORG",
        "country": "SE"
    },
    "009017": {
        "oui_hex": "00-90-17",
        "organization": "Zypcom, Inc",
        "address_1": "28400 Kohoutek Way",
        "address_2": "Union City  CA  94587-1212",
        "country": "US"
    },
    "009049": {
        "oui_hex": "00-90-49",
        "organization": "ENTRIDIA CORPORATION",
        "address_1": "101 PARK CENTER PLAZA",
        "address_2": "SAN JOSE  CA  95113-2218",
        "country": "US"
    },
    "0090E6": {
        "oui_hex": "00-90-E6",
        "organization": "ALi Corporation",
        "address_1": "6F, 246 NeiHu Road, Sec. 1",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "009070": {
        "oui_hex": "00-90-70",
        "organization": "NEO NETWORKS, INC.",
        "address_1": "10300 BREN ROAD EAST",
        "address_2": "MINNETONKA  MN  55343",
        "country": "US"
    },
    "009030": {
        "oui_hex": "00-90-30",
        "organization": "HONEYWELL-DATING",
        "address_1": "VIA TINTORETTO, 15",
        "address_2": "21012 CASSANO MAGNAGO (VA)",
        "country": "IT"
    },
    "009008": {
        "oui_hex": "00-90-08",
        "organization": "HanA Systems Inc.",
        "address_1": "EAHO B/D 740-1",
        "address_2": "SEOUL",
        "country": "KR"
    },
    "0090AC": {
        "oui_hex": "00-90-AC",
        "organization": "OPTIVISION, INC.",
        "address_1": "3450 HILLVIEW AVENUE",
        "address_2": "PALO ALTO  CA  94304",
        "country": "US"
    },
    "00904E": {
        "oui_hex": "00-90-4E",
        "organization": "DELEM BV",
        "address_1": "LUCHTHAVEN WEG 42",
        "address_2": "5657 EB EINDHOVEN",
        "country": "NL"
    },
    "0090ED": {
        "oui_hex": "00-90-ED",
        "organization": "CENTRAL SYSTEM RESEARCH CO., LTD.",
        "address_1": "4-13-2 HIYOSHICHO",
        "address_2": "KOKUBUNJI-CITY  TOKYO 18500032",
        "country": "JP"
    },
    "00901E": {
        "oui_hex": "00-90-1E",
        "organization": "Selesta Ingegneria S.p.A.",
        "address_1": "via di Francia, 28",
        "address_2": "Genova    16149",
        "country": "IT"
    },
    "009075": {
        "oui_hex": "00-90-75",
        "organization": "NEC DO BRASIL S.A.",
        "address_1": "RODOVIA PRESIDENTE DUTRA, KM 218",
        "address_2": "São Paulo-SP  CEP - 07210-902",
        "country": "BR"
    },
    "0090AD": {
        "oui_hex": "00-90-AD",
        "organization": "ASPECT ELECTRONICS, INC.",
        "address_1": "12740 EARHART AVE.",
        "address_2": "AUBURN  CA  95602",
        "country": "US"
    },
    "009001": {
        "oui_hex": "00-90-01",
        "organization": "NISHIMU ELECTRONICS INDUSTRIES CO., LTD.",
        "address_1": "700 TATENO MITAGAWA-CHO",
        "address_2": "KANZAKI-GUN SAGA PREF.",
        "country": "JP"
    },
    "009043": {
        "oui_hex": "00-90-43",
        "organization": "Tattile SRL",
        "address_1": "1-13-10 SHIROGANE  CHUO-KU",
        "address_2": "FUKUOKA-CITY",
        "country": "JP"
    },
    "0090CB": {
        "oui_hex": "00-90-CB",
        "organization": "Wireless OnLine, Inc.",
        "address_1": "4410 EL CAMINO REAL,  STE #101",
        "address_2": "LOS ALTOS  CA  94022",
        "country": "US"
    },
    "001063": {
        "oui_hex": "00-10-63",
        "organization": "STARGUIDE DIGITAL NETWORKS",
        "address_1": "5754 PACIFIC CENTER BLVD.",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "001023": {
        "oui_hex": "00-10-23",
        "organization": "Network Equipment Technologies",
        "address_1": "6900 Paseo Padre Parkway",
        "address_2": "Freemont  CA  94555-3660",
        "country": "US"
    },
    "00102B": {
        "oui_hex": "00-10-2B",
        "organization": "UMAX DATA SYSTEMS, INC.",
        "address_1": "NO. 1-1, R&D ROAD 2",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "00908A": {
        "oui_hex": "00-90-8A",
        "organization": "BAYLY COMMUNICATIONS, INC.",
        "address_1": "105 GREEN COURT",
        "address_2": "AJAX  Ontario  L1S 6W9",
        "country": "CA"
    },
    "00900E": {
        "oui_hex": "00-90-0E",
        "organization": "HANDLINK TECHNOLOGIES, INC.",
        "address_1": "5F, 24-2, Industry E. Road IV,",
        "address_2": "Hsinchu 30077",
        "country": "TW"
    },
    "0090C1": {
        "oui_hex": "00-90-C1",
        "organization": "Peco II, Inc.",
        "address_1": "7060 Huntley Road",
        "address_2": "Columbus  OH  43229",
        "country": "US"
    },
    "00108D": {
        "oui_hex": "00-10-8D",
        "organization": "Johnson Controls, Inc.",
        "address_1": "507 E. Michigan St.",
        "address_2": "Milwaukee  WI  53201",
        "country": "US"
    },
    "001045": {
        "oui_hex": "00-10-45",
        "organization": "Nortel Networks",
        "address_1": "OPTera Solutions Division",
        "address_2": "Kanata  Ontario K2K-2X3",
        "country": "CA"
    },
    "00107D": {
        "oui_hex": "00-10-7D",
        "organization": "AURORA COMMUNICATIONS, LTD.",
        "address_1": "P.O. BOX 1942",
        "address_2": "NSW 2113",
        "country": "AU"
    },
    "0090E4": {
        "oui_hex": "00-90-E4",
        "organization": "NEC AMERICA, INC.",
        "address_1": "3100 N.E. SHUTE ROAD",
        "address_2": "HILLSBORO  OR  97124",
        "country": "US"
    },
    "009040": {
        "oui_hex": "00-90-40",
        "organization": "Siemens Network Convergence LLC",
        "address_1": "Ten Technology Park Drive",
        "address_2": "Westford  MA  01886-3146",
        "country": "US"
    },
    "0090C8": {
        "oui_hex": "00-90-C8",
        "organization": "WAVERIDER COMMUNICATIONS (CANADA) INC.",
        "address_1": "",
        "address_2": "  British Columbia V1E 4R9",
        "country": "CA"
    },
    "00901B": {
        "oui_hex": "00-90-1B",
        "organization": "DIGITAL CONTROLS",
        "address_1": "305 PIONEER BLVD.",
        "address_2": "SPRINGBORO  OH  45066-1100",
        "country": "US"
    },
    "0090F7": {
        "oui_hex": "00-90-F7",
        "organization": "NBASE COMMUNICATIONS LTD.",
        "address_1": "INDUSTRIAL PARK",
        "address_2": "",
        "country": "IL"
    },
    "009012": {
        "oui_hex": "00-90-12",
        "organization": "GLOBESPAN SEMICONDUCTOR, INC.",
        "address_1": "100 SCHULZ DRIVE",
        "address_2": "RED BANK  NJ  07701",
        "country": "US"
    },
    "0090B7": {
        "oui_hex": "00-90-B7",
        "organization": "DIGITAL LIGHTWAVE, INC.",
        "address_1": "601 CLEVELAND STREET- 5TH FL.",
        "address_2": "CLEARWATER  FL  33755",
        "country": "US"
    },
    "0090A0": {
        "oui_hex": "00-90-A0",
        "organization": "8X8 INC.",
        "address_1": "2445 MISSION COLLEGE BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "009047": {
        "oui_hex": "00-90-47",
        "organization": "GIGA FAST E. LTD.",
        "address_1": "14F, NO.112, SEC. 1",
        "address_2": "Hsi-Chih  Taipei Hsien",
        "country": "TW"
    },
    "0090E1": {
        "oui_hex": "00-90-E1",
        "organization": "TELENA S.P.A.",
        "address_1": "VIA SAVONA, 146",
        "address_2": "20144 MILANO",
        "country": "IT"
    },
    "009032": {
        "oui_hex": "00-90-32",
        "organization": "PELCOMBE GROUP LTD.",
        "address_1": "MAIN ROAD",
        "address_2": "  ESSEX C012 4LP",
        "country": "GB"
    },
    "001062": {
        "oui_hex": "00-10-62",
        "organization": "NX SERVER, ILNC.",
        "address_1": "5401 E. LA PALMA AVE.",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "0010F0": {
        "oui_hex": "00-10-F0",
        "organization": "RITTAL-WERK RUDOLF LOH GmbH & Co.",
        "address_1": "AUF DEM STUTZELBERG",
        "address_2": "D-35745 HERBORN",
        "country": "DE"
    },
    "001001": {
        "oui_hex": "00-10-01",
        "organization": "Citel",
        "address_1": "Loughborough Innovation Centre",
        "address_2": "Loughborough    LE11 3EH",
        "country": "GB"
    },
    "00105C": {
        "oui_hex": "00-10-5C",
        "organization": "QUANTUM DESIGNS (H.K.) LTD.",
        "address_1": "5/F., SOMERSET HOUSE, TAIKOO PLACE",
        "address_2": "QUARRY BAY",
        "country": "HK"
    },
    "0010CF": {
        "oui_hex": "00-10-CF",
        "organization": "FIBERLANE COMMUNICATIONS",
        "address_1": "1318 REDWOOD WAY, #200",
        "address_2": "PETALUMA  CA  94954",
        "country": "US"
    },
    "001069": {
        "oui_hex": "00-10-69",
        "organization": "HELIOSS COMMUNICATIONS, INC.",
        "address_1": "391 TOTTEM POND RD.- STE#303",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "0010BF": {
        "oui_hex": "00-10-BF",
        "organization": "InterAir Wireless",
        "address_1": "485 CAYUGA ROAD",
        "address_2": "BUFFALO  NY  14225-0222",
        "country": "US"
    },
    "001026": {
        "oui_hex": "00-10-26",
        "organization": "ACCELERATED NETWORKS, INC.",
        "address_1": "31238 VIA COLINAS, UNIT",
        "address_2": "WESTLAKE VILLAGE  CA  91362",
        "country": "US"
    },
    "001036": {
        "oui_hex": "00-10-36",
        "organization": "INTER-TEL INTEGRATED SYSTEMS",
        "address_1": "7300 W. BOSTON STREET",
        "address_2": "CHANDLER  AZ  85226",
        "country": "US"
    },
    "001039": {
        "oui_hex": "00-10-39",
        "organization": "Vectron Systems AG",
        "address_1": "Willy-Brandt-Weg 41",
        "address_2": "48155 Muenster",
        "country": "DE"
    },
    "0010B6": {
        "oui_hex": "00-10-B6",
        "organization": "ENTRATA COMMUNICATIONS CORP.",
        "address_1": "574 HERITAGE RD.",
        "address_2": "SOUTHBURY  CT  06488",
        "country": "US"
    },
    "0010EC": {
        "oui_hex": "00-10-EC",
        "organization": "RPCG, LLC",
        "address_1": "749 MINER ROAD",
        "address_2": "HIGHLAND HTS  OH  44143-2117",
        "country": "US"
    },
    "001059": {
        "oui_hex": "00-10-59",
        "organization": "DIABLO RESEARCH CO. LLC",
        "address_1": "825 STEWART DRIVE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0010FC": {
        "oui_hex": "00-10-FC",
        "organization": "BROADBAND NETWORKS, INC.",
        "address_1": "37 STEVENSON ROAD",
        "address_2": "WINNIPEG, MANITOBA R3H 0H9",
        "country": "CA"
    },
    "001031": {
        "oui_hex": "00-10-31",
        "organization": "OBJECTIVE COMMUNICATIONS, INC.",
        "address_1": "75 ROCHESTER AVE.",
        "address_2": "PORTSMOUTH  NH  03801",
        "country": "US"
    },
    "00106D": {
        "oui_hex": "00-10-6D",
        "organization": "Axxcelera Broadband Wireless",
        "address_1": "1600 East Parham Road",
        "address_2": "Richmond  VA  23228",
        "country": "US"
    },
    "00104C": {
        "oui_hex": "00-10-4C",
        "organization": "Teledyne LeCroy, Inc",
        "address_1": "3385 Scott Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0010CC": {
        "oui_hex": "00-10-CC",
        "organization": "CLP COMPUTER LOGISTIK PLANUNG GmbH",
        "address_1": "BASSERMANNSTR. 21",
        "address_2": " D-81245 MUENCHEN",
        "country": "DE"
    },
    "001030": {
        "oui_hex": "00-10-30",
        "organization": "EION Inc.",
        "address_1": "320 March Road",
        "address_2": "Ottawa  ON  K2K 2E3",
        "country": "CA"
    },
    "0010D0": {
        "oui_hex": "00-10-D0",
        "organization": "WITCOM, LTD.",
        "address_1": "P.O.B. 2250",
        "address_2": "HAIFA  31021",
        "country": "IL"
    },
    "001093": {
        "oui_hex": "00-10-93",
        "organization": "CMS COMPUTERS, LTD.",
        "address_1": "201 ARCADIA",
        "address_2": "MUMBAI 400 0021",
        "country": "IN"
    },
    "00108F": {
        "oui_hex": "00-10-8F",
        "organization": "RAPTOR SYSTEMS",
        "address_1": "69 HICKORY AVE.",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "0010A4": {
        "oui_hex": "00-10-A4",
        "organization": "XIRCOM",
        "address_1": "2300 CORPORATE CENTER DR.",
        "address_2": "THOUSAND OAKS  CA  91320",
        "country": "US"
    },
    "0010F1": {
        "oui_hex": "00-10-F1",
        "organization": "I-O CORPORATION",
        "address_1": "2256 SOUTH 3600 WEST",
        "address_2": "SALT LAKE CITY  UT  84119",
        "country": "US"
    },
    "001066": {
        "oui_hex": "00-10-66",
        "organization": "ADVANCED CONTROL SYSTEMS, INC.",
        "address_1": "2755 NORTHWOODS PARKWAY",
        "address_2": "NORCROSS  GA  30071",
        "country": "US"
    },
    "0010AC": {
        "oui_hex": "00-10-AC",
        "organization": "IMCI TECHNOLOGIES",
        "address_1": "8401 OLD COURT HKOUSE RD",
        "address_2": "VIENNA  VA  22182",
        "country": "US"
    },
    "0010B1": {
        "oui_hex": "00-10-B1",
        "organization": "FOR-A CO., LTD.",
        "address_1": "2-3-3 OOSAKU",
        "address_2": "CHIBA PREF. 285",
        "country": "JP"
    },
    "0010EE": {
        "oui_hex": "00-10-EE",
        "organization": "CTI PRODUCTS, INC.",
        "address_1": "1211 W. SHARON RD.",
        "address_2": "CINCINNATI  OH  45240",
        "country": "US"
    },
    "001041": {
        "oui_hex": "00-10-41",
        "organization": "BRISTOL BABCOCK, INC.",
        "address_1": "1100 BUCKINGHAM STREET",
        "address_2": "WATERTOWN  CT  06795",
        "country": "US"
    },
    "0010AA": {
        "oui_hex": "00-10-AA",
        "organization": "MEDIA4, INC.",
        "address_1": "250 14TH ST. NW - STE #4002",
        "address_2": "ATLANTA  GA  30318",
        "country": "US"
    },
    "0010E8": {
        "oui_hex": "00-10-E8",
        "organization": "TELOCITY, INCORPORATED",
        "address_1": "992 SOUTH DE ANZA BLVD",
        "address_2": "SAN JOSE  CA  95129",
        "country": "US"
    },
    "0010A2": {
        "oui_hex": "00-10-A2",
        "organization": "TNS",
        "address_1": "800 Third Street, Suite B100",
        "address_2": "HERNDON  VA  20170",
        "country": "US"
    },
    "001065": {
        "oui_hex": "00-10-65",
        "organization": "RADYNE CORPORATION",
        "address_1": "5225 S. 37TH STREET",
        "address_2": "PHOENIX  AZ  85040",
        "country": "US"
    },
    "00109F": {
        "oui_hex": "00-10-9F",
        "organization": "PAVO, INC.",
        "address_1": "95 YESLER WAY",
        "address_2": "SEATTLE  WA  98104",
        "country": "US"
    },
    "00101D": {
        "oui_hex": "00-10-1D",
        "organization": "WINBOND ELECTRONICS CORP.",
        "address_1": "NO. 4, CREATION RD. III",
        "address_2": "HSIN CHU",
        "country": "TW"
    },
    "001084": {
        "oui_hex": "00-10-84",
        "organization": "K-BOT COMMUNICATIONS",
        "address_1": "P.O. BOX 410",
        "address_2": "NORTON  MA  02766",
        "country": "US"
    },
    "001000": {
        "oui_hex": "00-10-00",
        "organization": "CABLE TELEVISION LABORATORIES, INC.",
        "address_1": "858 Coal Creek Circle",
        "address_2": "Louisville  CO  80027",
        "country": "US"
    },
    "001009": {
        "oui_hex": "00-10-09",
        "organization": "HORANET",
        "address_1": " ZI Route de Niort – BP 70328",
        "address_2": "FONTENAY LE COMTE CEDEX  VENDEE   85206",
        "country": "FR"
    },
    "0010F8": {
        "oui_hex": "00-10-F8",
        "organization": "TEXIO TECHNOLOGY CORPORATION",
        "address_1": "2-18-13 Shin Yokohama,",
        "address_2": "    222-0033",
        "country": "JP"
    },
    "0010C0": {
        "oui_hex": "00-10-C0",
        "organization": "ARMA, Inc.",
        "address_1": "4851 Northshore Lane",
        "address_2": "North Little Rock  AR  72118",
        "country": "US"
    },
    "00105B": {
        "oui_hex": "00-10-5B",
        "organization": "NET INSIGHT AB",
        "address_1": "Västberga Allé 9",
        "address_2": "SE-1260  30 Hägersten",
        "country": "SE"
    },
    "001002": {
        "oui_hex": "00-10-02",
        "organization": "ACTIA",
        "address_1": "25 CHEMIN DE POUVOURVILLE",
        "address_2": "31432 TOULOUSE,  CEDEX 04",
        "country": "FR"
    },
    "0010EB": {
        "oui_hex": "00-10-EB",
        "organization": "SELSIUS SYSTEMS, INC.",
        "address_1": "5057 KELLER SPRINGS RD.",
        "address_2": "DALLAS  TX  75248",
        "country": "US"
    },
    "001057": {
        "oui_hex": "00-10-57",
        "organization": "Rebel.com, Inc.",
        "address_1": "150 ISABELLA STREET--STE. 1000",
        "address_2": "OTTAWA, ONTARIO K1S 1V7",
        "country": "CA"
    },
    "0010F9": {
        "oui_hex": "00-10-F9",
        "organization": "UNIQUE SYSTEMS, INC.",
        "address_1": "181 DON PARK RD",
        "address_2": "MARKHAM, ONTARIO L3R 1C2",
        "country": "CA"
    },
    "001075": {
        "oui_hex": "00-10-75",
        "organization": "Segate Technology LLC",
        "address_1": "10200 S De Anza Blvd",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00E003": {
        "oui_hex": "00-E0-03",
        "organization": "NOKIA WIRELESS BUSINESS COMMUN",
        "address_1": "ACCESS POINT PRODUCTS GROUP",
        "address_2": "CB4 0WS",
        "country": "GB"
    },
    "00E0F3": {
        "oui_hex": "00-E0-F3",
        "organization": "WebSprint Communications, Inc.",
        "address_1": "3026 SCOTT BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "08BBCC": {
        "oui_hex": "08-BB-CC",
        "organization": "AK-NORD EDV VERTRIEBSGES. mbH",
        "address_1": "FRIEDRICHSTRASSE 10",
        "address_2": "25436 TORNESCH",
        "country": "DE"
    },
    "00E0DB": {
        "oui_hex": "00-E0-DB",
        "organization": "ViaVideo Communications, Inc.",
        "address_1": "8900 SHOAL CREEK BLVD.",
        "address_2": "AUSTIN  TX  78757",
        "country": "US"
    },
    "00E0A6": {
        "oui_hex": "00-E0-A6",
        "organization": "TELOGY NETWORKS, INC.",
        "address_1": "20250 CENTURY BLVD.",
        "address_2": "GERMANTOWN  MD  20874",
        "country": "US"
    },
    "00E09F": {
        "oui_hex": "00-E0-9F",
        "organization": "PIXEL VISION",
        "address_1": "43 NAGOG PARK",
        "address_2": "ACTON  MA  01720",
        "country": "US"
    },
    "00E0CC": {
        "oui_hex": "00-E0-CC",
        "organization": "HERO SYSTEMS, LTD.",
        "address_1": "THE BARNES, COOMBELANDS LANE,",
        "address_2": "SURREY KT15 1HY  ENGLAND",
        "country": "GB"
    },
    "00E080": {
        "oui_hex": "00-E0-80",
        "organization": "CONTROL RESOURCES CORPORATION",
        "address_1": "16-00 POLLITT DRIVE",
        "address_2": "FAIR LAWN  NJ  07410",
        "country": "US"
    },
    "00E004": {
        "oui_hex": "00-E0-04",
        "organization": "PMC-SIERRA, INC.",
        "address_1": "105-8555 BAXTER PLACE",
        "address_2": "BURNABY, BC V5A 4V7",
        "country": "CA"
    },
    "00E03B": {
        "oui_hex": "00-E0-3B",
        "organization": "PROMINET CORPORATION",
        "address_1": "110 TURNPIKE RD. - STE. #208",
        "address_2": "WESTBOROUGH  MA  01581",
        "country": "US"
    },
    "00E0F5": {
        "oui_hex": "00-E0-F5",
        "organization": "TELES AG",
        "address_1": "DOVESTR. 2-4",
        "address_2": "10587 BERLIN",
        "country": "DE"
    },
    "00E0D7": {
        "oui_hex": "00-E0-D7",
        "organization": "SUNSHINE ELECTRONICS, INC.",
        "address_1": "46560 FREMONT BLVD. -STE. #113",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00E0B5": {
        "oui_hex": "00-E0-B5",
        "organization": "ARDENT COMMUNICATIONS CORP.",
        "address_1": "3801 ZANKER ROAD,  Suite A",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00E068": {
        "oui_hex": "00-E0-68",
        "organization": "MERRIMAC SYSTEMS INC.",
        "address_1": "2144 MC COY ROAD",
        "address_2": "CARROLLTON  TX  75006",
        "country": "US"
    },
    "00E049": {
        "oui_hex": "00-E0-49",
        "organization": "MICROWI ELECTRONIC GmbH",
        "address_1": "ZUSAMSTRASSE 8",
        "address_2": "D 86165 AUGSBURG",
        "country": "DE"
    },
    "00E095": {
        "oui_hex": "00-E0-95",
        "organization": "ADVANCED-VISION TECHNOLGIES CORP.",
        "address_1": "8F-1, 87 SECTION 3, CHUNG YANG RD,",
        "address_2": "Tu Cheng  Taipei",
        "country": "TW"
    },
    "00E00E": {
        "oui_hex": "00-E0-0E",
        "organization": "AVALON IMAGING SYSTEMS, INC.",
        "address_1": "3133 INDIAN ROAD",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00E048": {
        "oui_hex": "00-E0-48",
        "organization": "SDL COMMUNICATIONS, INC.",
        "address_1": "P.O. BOX 1303",
        "address_2": "EASTON  MA  02334",
        "country": "US"
    },
    "00E0CB": {
        "oui_hex": "00-E0-CB",
        "organization": "RESON, INC.",
        "address_1": "300 LOPEZ ROAD",
        "address_2": "GOLETA  CA  93117",
        "country": "US"
    },
    "00E0C8": {
        "oui_hex": "00-E0-C8",
        "organization": "VIRTUAL ACCESS, LTD.",
        "address_1": "WOODSIDE HOUSE, WINKFIELD,",
        "address_2": "WINDSOR, BERKSHIRE SL4 2DX  ENGLAND",
        "country": "GB"
    },
    "00E006": {
        "oui_hex": "00-E0-06",
        "organization": "SILICON INTEGRATED SYS. CORP.",
        "address_1": "16, CREATION RD. I",
        "address_2": "HSIN CHU",
        "country": "TW"
    },
    "00E0AC": {
        "oui_hex": "00-E0-AC",
        "organization": "MIDSCO, INC.",
        "address_1": "710 ROUTE 46 EAST",
        "address_2": "FAIRFIELD  NJ  07004",
        "country": "US"
    },
    "00E008": {
        "oui_hex": "00-E0-08",
        "organization": "AMAZING CONTROLS! INC.",
        "address_1": "1615 WYATT DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00E0AE": {
        "oui_hex": "00-E0-AE",
        "organization": "XAQTI CORPORATION",
        "address_1": " 1630 OAKLAND RD. #A-214",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00E0E0": {
        "oui_hex": "00-E0-E0",
        "organization": "SI ELECTRONICS, LTD.",
        "address_1": "28-16, SHIMOMARUKO 2-CHOME,",
        "address_2": "TOKYO 146",
        "country": "JP"
    },
    "00E050": {
        "oui_hex": "00-E0-50",
        "organization": "EXECUTONE INFORMATION SYSTEMS, INC.",
        "address_1": "478 WHEELERS FARMS ROAD",
        "address_2": "MILFORD  CT  06460",
        "country": "US"
    },
    "00E023": {
        "oui_hex": "00-E0-23",
        "organization": "TELRAD",
        "address_1": "P.O. BOX 50",
        "address_2": "LOD 71100",
        "country": "IL"
    },
    "00E02C": {
        "oui_hex": "00-E0-2C",
        "organization": "AST COMPUTER",
        "address_1": "16215 ALTON PARKWAY",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "00E067": {
        "oui_hex": "00-E0-67",
        "organization": "eac AUTOMATION-CONSULTING GmbH",
        "address_1": "HERMSDORFER DAMM 222",
        "address_2": "73467 BERLIN",
        "country": "DE"
    },
    "00E0FA": {
        "oui_hex": "00-E0-FA",
        "organization": "TRL TECHNOLOGY, LTD.",
        "address_1": "SHANNON WAY, ASHCHURCH,",
        "address_2": "TEWKESBURY, GLOS. GL20 8ND",
        "country": "GB"
    },
    "00E02A": {
        "oui_hex": "00-E0-2A",
        "organization": "TANDBERG TELEVISION AS",
        "address_1": "PHILIP PEDERSENS V 20",
        "address_2": "N-1324 LYSAKER",
        "country": "NO"
    },
    "00E04E": {
        "oui_hex": "00-E0-4E",
        "organization": "SANYO DENKI CO., LTD.",
        "address_1": "812-3, Shimonogou, Ueda-Shi",
        "address_2": "Nagano    386-1211",
        "country": "JP"
    },
    "00E012": {
        "oui_hex": "00-E0-12",
        "organization": "PLUTO TECHNOLOGIES INTERNATIONAL INC.",
        "address_1": "2511 55TH STREET",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00E04C": {
        "oui_hex": "00-E0-4C",
        "organization": "REALTEK SEMICONDUCTOR CORP.",
        "address_1": "1F, NO. 11, INDUSTRY E. RD. IX",
        "address_2": "HSINCHU 300",
        "country": "TW"
    },
    "00E051": {
        "oui_hex": "00-E0-51",
        "organization": "TALX CORPORATION",
        "address_1": "1850 BORMAN COURT",
        "address_2": "ST. LOUIS  MO  63146",
        "country": "US"
    },
    "00606B": {
        "oui_hex": "00-60-6B",
        "organization": "Synclayer Inc.",
        "address_1": "1-20 Himegaoka",
        "address_2": "GIFU 509-0249",
        "country": "JP"
    },
    "00603B": {
        "oui_hex": "00-60-3B",
        "organization": "AMTEC spa",
        "address_1": "LOC. S. MARTINO",
        "address_2": "53025 PIANCASTAGNAIO (SIENA)",
        "country": "IT"
    },
    "00E039": {
        "oui_hex": "00-E0-39",
        "organization": "PARADYNE CORP.",
        "address_1": "8545 126TH AVENUE NORTH",
        "address_2": "LARGO  FL  33773",
        "country": "US"
    },
    "00600B": {
        "oui_hex": "00-60-0B",
        "organization": "LOGWARE GmbH",
        "address_1": "SCHWEDENSTR. 9",
        "address_2": "D-13359 BERLIN",
        "country": "DE"
    },
    "00E0C7": {
        "oui_hex": "00-E0-C7",
        "organization": "EUROTECH SRL",
        "address_1": "VIA JACOPO LINUSSIO 1",
        "address_2": "33030 AMAROO (UD)",
        "country": "IT"
    },
    "00E0AF": {
        "oui_hex": "00-E0-AF",
        "organization": "GENERAL DYNAMICS INFORMATION SYSTEMS",
        "address_1": "COMPUTING DEVICES, LTD.",
        "address_2": "FALLS CHURCH  VA  22042-4523",
        "country": "US"
    },
    "00E054": {
        "oui_hex": "00-E0-54",
        "organization": "KODAI HITEC CO., LTD.",
        "address_1": "2-45 ONUMA HANYU CITY",
        "address_2": "SAITAMA.348",
        "country": "JP"
    },
    "00E0B9": {
        "oui_hex": "00-E0-B9",
        "organization": "BYAS SYSTEMS",
        "address_1": "2250 MONROE STREET,  #371",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "00604B": {
        "oui_hex": "00-60-4B",
        "organization": "Safe-com GmbH & Co. KG",
        "address_1": "Burg Lichtenfels 1",
        "address_2": "35104 Lichtenfels",
        "country": "DE"
    },
    "00E0EF": {
        "oui_hex": "00-E0-EF",
        "organization": "DIONEX",
        "address_1": "PO BOX 3603",
        "address_2": "SUNNYVALE  CA  94088-3603",
        "country": "US"
    },
    "00E02D": {
        "oui_hex": "00-E0-2D",
        "organization": "InnoMediaLogic, Inc.",
        "address_1": "3653 CHEMIN CHAMBLY",
        "address_2": "LONGUEUIL, QUEBEC J4L J4L    IN9",
        "country": "CA"
    },
    "00E035": {
        "oui_hex": "00-E0-35",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "00E090": {
        "oui_hex": "00-E0-90",
        "organization": "BECKMAN LAB. AUTOMATION DIV.",
        "address_1": "90 BOROLINE ROAD",
        "address_2": "ALLENDALE  NJ  07401",
        "country": "US"
    },
    "006001": {
        "oui_hex": "00-60-01",
        "organization": "InnoSys, Inc.",
        "address_1": "3095 RICHMOND PKWY #207",
        "address_2": "RICHMOND  CA  94806",
        "country": "US"
    },
    "0060FE": {
        "oui_hex": "00-60-FE",
        "organization": "LYNX SYSTEM DEVELOPERS, INC.",
        "address_1": "175N NEW BOSTON STREET",
        "address_2": "WOBURN  MA  01801",
        "country": "US"
    },
    "0060BD": {
        "oui_hex": "00-60-BD",
        "organization": "Enginuity Communications",
        "address_1": "3545 Stern Avenue",
        "address_2": "St Charles  IL  60174",
        "country": "US"
    },
    "000800": {
        "oui_hex": "00-08-00",
        "organization": "MULTITECH SYSTEMS, INC.",
        "address_1": "2205 WOODALE DRIVE",
        "address_2": "MOUNDS VIEW  MN  55112",
        "country": "US"
    },
    "00E085": {
        "oui_hex": "00-E0-85",
        "organization": "GLOBAL MAINTECH, INC.",
        "address_1": "6468 CITY WEST PARKWAY",
        "address_2": "EDEN PRAIRIE  MN  55344",
        "country": "US"
    },
    "00E0BE": {
        "oui_hex": "00-E0-BE",
        "organization": "GENROCO INTERNATIONAL, INC.",
        "address_1": "255 ENDERS COURT",
        "address_2": "SLINGER  WI  53086",
        "country": "US"
    },
    "00E0B6": {
        "oui_hex": "00-E0-B6",
        "organization": "Entrada Networks",
        "address_1": "9020 JUNCTION DRIVE",
        "address_2": "ANNAPOLIS JUNCTION  MD  20701",
        "country": "US"
    },
    "00E0F4": {
        "oui_hex": "00-E0-F4",
        "organization": "INSIDE Technology A/S",
        "address_1": "VENLIGHEDSVEJ 6",
        "address_2": "DK-2970 HOERSHOLM",
        "country": "DK"
    },
    "00E0A0": {
        "oui_hex": "00-E0-A0",
        "organization": "WILTRON CO.",
        "address_1": "490 JARVIS DRIVE",
        "address_2": "MORGAN HILL  CA  95037",
        "country": "US"
    },
    "00E0F1": {
        "oui_hex": "00-E0-F1",
        "organization": "THAT CORPORATION",
        "address_1": "734 FOREST STREET",
        "address_2": "MARLBOROUGH  MA  01752",
        "country": "US"
    },
    "0060D5": {
        "oui_hex": "00-60-D5",
        "organization": "AMADA MIYACHI Co., Ltd",
        "address_1": "95-3, FUTASUZUKA NODA",
        "address_2": "CHIBA    278-0016",
        "country": "JP"
    },
    "00603F": {
        "oui_hex": "00-60-3F",
        "organization": "PATAPSCO DESIGNS",
        "address_1": "5350 PARTNERS COURT",
        "address_2": "FREDERICK  MD  21703",
        "country": "US"
    },
    "0060B5": {
        "oui_hex": "00-60-B5",
        "organization": "KEBA GmbH",
        "address_1": "GEWERBEPARK URFAHR",
        "address_2": "A-4041 LINZ",
        "country": "AT"
    },
    "006014": {
        "oui_hex": "00-60-14",
        "organization": "EDEC CO., LTD.",
        "address_1": "9F OF T.O.C. BUILDING",
        "address_2": "SHINAGAWAKU,  TOKYO",
        "country": "JP"
    },
    "0060AC": {
        "oui_hex": "00-60-AC",
        "organization": "RESILIENCE CORPORATION",
        "address_1": "1755 EMBARCADERO ROAD-STE #120",
        "address_2": "PALO ALTO  CA  94303",
        "country": "US"
    },
    "00604E": {
        "oui_hex": "00-60-4E",
        "organization": "CYCLE COMPUTER CORPORATION, INC.",
        "address_1": "20245 STEVENS CREEK BLVD.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "0060E1": {
        "oui_hex": "00-60-E1",
        "organization": "ORCKIT COMMUNICATIONS LTD.",
        "address_1": "38 NAHALAT YIZHAK STREET",
        "address_2": "TEL-AVIV  67448",
        "country": "IL"
    },
    "0060D2": {
        "oui_hex": "00-60-D2",
        "organization": "LUCENT TECHNOLOGIES TAIWAN TELECOMMUNICATIONS CO., LTD.",
        "address_1": "#2, INNOVATION ROAD II",
        "address_2": "HSIN CHU",
        "country": "TW"
    },
    "006042": {
        "oui_hex": "00-60-42",
        "organization": "TKS (USA), INC.",
        "address_1": "1201 COMMERCE",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "006079": {
        "oui_hex": "00-60-79",
        "organization": "Mainstream Data, Inc.",
        "address_1": "375 Chipeta Way, Suite B",
        "address_2": "Salt Lake City  UT  84108",
        "country": "US"
    },
    "00609A": {
        "oui_hex": "00-60-9A",
        "organization": "NJK TECHNO CO.",
        "address_1": "N1-25 KAMIYASATO",
        "address_2": "KOMATSU  #923",
        "country": "JP"
    },
    "00602B": {
        "oui_hex": "00-60-2B",
        "organization": "PEAK AUDIO",
        "address_1": "1790 30TH STREET STE #414",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "0060F1": {
        "oui_hex": "00-60-F1",
        "organization": "EXP COMPUTER, INC.",
        "address_1": "141 EILEEN WAY",
        "address_2": "SYOSSET  NY  11791",
        "country": "US"
    },
    "0060E6": {
        "oui_hex": "00-60-E6",
        "organization": "SHOMITI SYSTEMS INCORPORATED",
        "address_1": "2099 GATEWAY PLACE - STE.#220",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "0060FF": {
        "oui_hex": "00-60-FF",
        "organization": "QuVis, Inc.",
        "address_1": "2921 SW WANAMAKER DRIVE",
        "address_2": "TOPEKA  KS  66614",
        "country": "US"
    },
    "006067": {
        "oui_hex": "00-60-67",
        "organization": "ACER NETXUS INC.",
        "address_1": "5F-3, 5 HSIN ANN ROAD  SBIP",
        "address_2": "HSINCHU 300",
        "country": "TJ"
    },
    "00609F": {
        "oui_hex": "00-60-9F",
        "organization": "PHAST CORPORATION",
        "address_1": "79 WEST 4500 SOUTH - BLDG.#14",
        "address_2": "SALT LAKE CITY  UT  84107",
        "country": "US"
    },
    "006040": {
        "oui_hex": "00-60-40",
        "organization": "NETRO CORP.",
        "address_1": "3120 SCOTT BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0060CC": {
        "oui_hex": "00-60-CC",
        "organization": "EMTRAK, INCORPORATED",
        "address_1": "7150 CAMPUS DRIVE, STE #180",
        "address_2": "COLORADO SPRINGS  CO  80920",
        "country": "US"
    },
    "00602C": {
        "oui_hex": "00-60-2C",
        "organization": "LINX Data Terminals, Inc.",
        "address_1": "625 DIGITAL DRIVE-STE #100",
        "address_2": "PLANO  TX  75075",
        "country": "US"
    },
    "00607E": {
        "oui_hex": "00-60-7E",
        "organization": "GIGALABS, INC.",
        "address_1": "290 SANTA ANA COURT",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0060CD": {
        "oui_hex": "00-60-CD",
        "organization": "VideoServer, Inc.",
        "address_1": "5 FORBES ROAD",
        "address_2": "LEXINGTON  MA  02173",
        "country": "US"
    },
    "0060AA": {
        "oui_hex": "00-60-AA",
        "organization": "INTELLIGENT DEVICES INC. (IDI)",
        "address_1": "1718-L BELMONT AVENUE",
        "address_2": "BALTIMORE  MD  21244",
        "country": "US"
    },
    "006025": {
        "oui_hex": "00-60-25",
        "organization": "ACTIVE IMAGING PLC",
        "address_1": "HATTORI HOUSE",
        "address_2": "MAIDENHEAD  Berkshire SL6 4UB",
        "country": "GB"
    },
    "0060A7": {
        "oui_hex": "00-60-A7",
        "organization": "MICROSENS GmbH & CO. KG",
        "address_1": "Kueferstrasse 16",
        "address_2": "D-59067 Hamm",
        "country": "DE"
    },
    "0005A8": {
        "oui_hex": "00-05-A8",
        "organization": "WYLE ELECTRONICS",
        "address_1": "3000 BOWERS AVENUE",
        "address_2": "SANTA CLARA  CA  95051-0919",
        "country": "US"
    },
    "0060E5": {
        "oui_hex": "00-60-E5",
        "organization": "FUJI AUTOMATION CO., LTD.",
        "address_1": "3-23-10, NEGISHI",
        "address_2": "URAWA-SHI, 336 SAITAMA",
        "country": "US"
    },
    "00605E": {
        "oui_hex": "00-60-5E",
        "organization": "LIBERTY TECHNOLOGY NETWORKING",
        "address_1": "P.O. BOX 11566",
        "address_2": "HATFIELD, PRETORIA 0028",
        "country": "ZA"
    },
    "0060C6": {
        "oui_hex": "00-60-C6",
        "organization": "DCS AG",
        "address_1": "SALZACHSTRASS 31",
        "address_2": "D-14129  BERLIN",
        "country": "DE"
    },
    "00601E": {
        "oui_hex": "00-60-1E",
        "organization": "SOFTLAB, INC.",
        "address_1": "P.O. BOX 8",
        "address_2": "CHIMNEY ROCK  CO  81127",
        "country": "US"
    },
    "006065": {
        "oui_hex": "00-60-65",
        "organization": "BERNECKER & RAINER INDUSTRIE-ELEKTRONIC GmbH",
        "address_1": "EGGELSBERG 120",
        "address_2": "5142 EGGELSBERG",
        "country": "AT"
    },
    "00605D": {
        "oui_hex": "00-60-5D",
        "organization": "SCANIVALVE CORP.",
        "address_1": "1722 N. MADSON STREET",
        "address_2": "LIBERTY LAKE  WA  99019",
        "country": "US"
    },
    "00606F": {
        "oui_hex": "00-60-6F",
        "organization": "CLARION CORPORATION OF AMERICA",
        "address_1": "25 Commerce Drive",
        "address_2": "Allendale  NJ  07401",
        "country": "US"
    },
    "00A010": {
        "oui_hex": "00-A0-10",
        "organization": "SYSLOGIC DATENTECHNIK AG",
        "address_1": "Bruggerstrasse 69",
        "address_2": "CH-5400 Baden",
        "country": "CH"
    },
    "00A059": {
        "oui_hex": "00-A0-59",
        "organization": "HAMILTON HALLMARK",
        "address_1": "2105 LUNDY AVENUE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00A039": {
        "oui_hex": "00-A0-39",
        "organization": "ROSS TECHNOLOGY, INC.",
        "address_1": "5316 HWY 290 WEST - STE. #500",
        "address_2": "AUSTIN  TX  78735",
        "country": "US"
    },
    "00A0AD": {
        "oui_hex": "00-A0-AD",
        "organization": "MARCONI SPA",
        "address_1": "VIA NEGRONE, 1A",
        "address_2": "16153 GENOVA CORNIGLIANO",
        "country": "IT"
    },
    "00A0D6": {
        "oui_hex": "00-A0-D6",
        "organization": "SBE, Inc.",
        "address_1": "4000 Executive Parkway",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "00A02E": {
        "oui_hex": "00-A0-2E",
        "organization": "BRAND COMMUNICATIONS, LTD.",
        "address_1": "ENTERPRISE HOUSE, CHIVERS WAY,",
        "address_2": "HISTON, CAMBRIDGE CB4 4ZR",
        "country": "GB"
    },
    "00604A": {
        "oui_hex": "00-60-4A",
        "organization": "SAIC IDEAS GROUP",
        "address_1": "7120 COLUMBIA GATEWAY DRIVE",
        "address_2": "COLUMBIA  MD  21046",
        "country": "US"
    },
    "00A0BD": {
        "oui_hex": "00-A0-BD",
        "organization": "I-TECH CORP.",
        "address_1": "10200 VALLEY VIEW ROAD",
        "address_2": "EDEN PRAIRIE  MN  55344",
        "country": "US"
    },
    "006090": {
        "oui_hex": "00-60-90",
        "organization": "Artiza Networks Inc",
        "address_1": "Faret Tachikawa Center Square, 2-36-2 Akebono-cho,",
        "address_2": "Tachikawa-shi,  Tokyo   190-0012",
        "country": "JP"
    },
    "00600D": {
        "oui_hex": "00-60-0D",
        "organization": "Digital Logic GmbH",
        "address_1": "Stahlwerkstraße 25",
        "address_2": "Mudersbach    57555",
        "country": "DE"
    },
    "006030": {
        "oui_hex": "00-60-30",
        "organization": "VILLAGE TRONIC ENTWICKLUNG",
        "address_1": "WELLWEG 95",
        "address_2": "31157 SARSTEDT",
        "country": "DE"
    },
    "00A08D": {
        "oui_hex": "00-A0-8D",
        "organization": "JACOMO CORPORATION",
        "address_1": "26900 E. PINK HILL ROAD",
        "address_2": "INDEPENDENCE  MO  64057",
        "country": "US"
    },
    "00A08E": {
        "oui_hex": "00-A0-8E",
        "organization": "Check Point Software Technologies",
        "address_1": "8333 Ridgepoint Dr.",
        "address_2": "Irving  TX  75063",
        "country": "US"
    },
    "00A0FC": {
        "oui_hex": "00-A0-FC",
        "organization": "IMAGE SCIENCES, INC.",
        "address_1": "7500 INNOVATION WAY",
        "address_2": "MASON  OH  45040",
        "country": "US"
    },
    "00A09C": {
        "oui_hex": "00-A0-9C",
        "organization": "Xyplex, Inc.",
        "address_1": "25 FOSTER STREET",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "00A00D": {
        "oui_hex": "00-A0-0D",
        "organization": "THE PANDA PROJECT",
        "address_1": "5201 CONGRESS AVE. - C-100",
        "address_2": "BOCA RATON  FL  33487",
        "country": "US"
    },
    "00A0E9": {
        "oui_hex": "00-A0-E9",
        "organization": "ELECTRONIC RETAILING SYSTEMS INTERNATIONAL",
        "address_1": "372 DANBURY ROAD",
        "address_2": "WILTON  CT  06897-2523",
        "country": "US"
    },
    "00A0BE": {
        "oui_hex": "00-A0-BE",
        "organization": "INTEGRATED CIRCUIT SYSTEMS, INC. COMMUNICATIONS GROUP",
        "address_1": "1271 PARKMOOR AVENUE",
        "address_2": "SAN JOSE  CA  95126-3448",
        "country": "US"
    },
    "00A016": {
        "oui_hex": "00-A0-16",
        "organization": "MICROPOLIS CORP.",
        "address_1": "21211 NORDHOFF STREET",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "00A048": {
        "oui_hex": "00-A0-48",
        "organization": "QUESTECH, LTD.",
        "address_1": "EASTHEATH AVENUE",
        "address_2": " BERKS, RG11 2PP",
        "country": "GB"
    },
    "00A003": {
        "oui_hex": "00-A0-03",
        "organization": "Siemens Switzerland Ltd., I B T HVP",
        "address_1": "Building Technologies Division, International Headquarters",
        "address_2": "Zug    6301",
        "country": "CH"
    },
    "00A0F9": {
        "oui_hex": "00-A0-F9",
        "organization": "BINTEC COMMUNICATIONS GMBH",
        "address_1": "SUEDWESTPARK 94",
        "address_2": "90449 NUERNBERG",
        "country": "DE"
    },
    "00A0F5": {
        "oui_hex": "00-A0-F5",
        "organization": "RADGUARD LTD.",
        "address_1": "8 HANECHOSHET STREET",
        "address_2": "TEL-AVIV  69710",
        "country": "IL"
    },
    "00A0CA": {
        "oui_hex": "00-A0-CA",
        "organization": "FUJITSU DENSO LTD.",
        "address_1": "3055 ORCHARD DRIVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00A022": {
        "oui_hex": "00-A0-22",
        "organization": "CENTRE FOR DEVELOPMENT OF ADVANCED COMPUTING",
        "address_1": "UNIVERSITY OF POONA CAMPUS",
        "address_2": "GANESH KHIND, Pune - 411 008",
        "country": "IN"
    },
    "00A0B6": {
        "oui_hex": "00-A0-B6",
        "organization": "SANRITZ AUTOMATION CO., LTD.",
        "address_1": "4-21 MINAMI NARUSE",
        "address_2": "",
        "country": ""
    },
    "00A079": {
        "oui_hex": "00-A0-79",
        "organization": "ALPS ELECTRIC (USA), INC.",
        "address_1": "3553 NORTH 1ST STREET",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00A0C0": {
        "oui_hex": "00-A0-C0",
        "organization": "DIGITAL LINK CORP.",
        "address_1": "217 HUMBOLDT COURT",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "00A01E": {
        "oui_hex": "00-A0-1E",
        "organization": "EST CORPORATION",
        "address_1": "120 ROYALL STREET",
        "address_2": "CANTON  MA  02021",
        "country": "US"
    },
    "00A0AE": {
        "oui_hex": "00-A0-AE",
        "organization": "NUCOM SYSTEMS, INC.",
        "address_1": "9F-6, NO 4, LANE",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00A062": {
        "oui_hex": "00-A0-62",
        "organization": "AES PRODATA",
        "address_1": "249 BALCATTA ROAD",
        "address_2": "WESTERN  AUSTRALIA  6021",
        "country": "AU"
    },
    "00A076": {
        "oui_hex": "00-A0-76",
        "organization": "CARDWARE LAB, INC.",
        "address_1": "285 SOBRANTE WAY, STE.",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "VI"
    },
    "00A0A1": {
        "oui_hex": "00-A0-A1",
        "organization": "EPIC DATA INC.",
        "address_1": "7280 RIVER ROAD",
        "address_2": "CANADA  V6X  1X5",
        "country": ""
    },
    "00A044": {
        "oui_hex": "00-A0-44",
        "organization": "NTT IT CO., LTD.",
        "address_1": "",
        "address_2": "  231",
        "country": "JP"
    },
    "00A011": {
        "oui_hex": "00-A0-11",
        "organization": "MUTOH INDUSTRIES LTD.",
        "address_1": "253 KANAGAWA-KEN,",
        "address_2": "",
        "country": "JP"
    },
    "00A0BA": {
        "oui_hex": "00-A0-BA",
        "organization": "PATTON ELECTRONICS CO.",
        "address_1": "7622 RICKENBACKER DRIVE",
        "address_2": "GAITHERSBURG  MD  20879",
        "country": "US"
    },
    "00A0B5": {
        "oui_hex": "00-A0-B5",
        "organization": "3H TECHNOLOGY",
        "address_1": "3375 SCOTT BLVD. #336",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00A04D": {
        "oui_hex": "00-A0-4D",
        "organization": "EDA INSTRUMENTS, INC.",
        "address_1": "4 THORNCLIFFE PARK DRIVE",
        "address_2": "    M4H 1H1",
        "country": "CA"
    },
    "00A086": {
        "oui_hex": "00-A0-86",
        "organization": "AMBER WAVE SYSTEMS, INC.",
        "address_1": "403 MASSACHUSETTS AVENUE",
        "address_2": "ACTON  MA  01720",
        "country": "US"
    },
    "00A0AF": {
        "oui_hex": "00-A0-AF",
        "organization": "WMS INDUSTRIES",
        "address_1": "3401 N. CALIFORNIA",
        "address_2": "CHICAGO  IL  60618",
        "country": "US"
    },
    "00A057": {
        "oui_hex": "00-A0-57",
        "organization": "LANCOM Systems GmbH",
        "address_1": "Adenauer Straße 20 /B2",
        "address_2": "Würselen    52146",
        "country": "DE"
    },
    "00A030": {
        "oui_hex": "00-A0-30",
        "organization": "CAPTOR NV/SA",
        "address_1": "DE HENE 13",
        "address_2": "",
        "country": "BE"
    },
    "00A0DE": {
        "oui_hex": "00-A0-DE",
        "organization": "YAMAHA CORPORATION",
        "address_1": "10-1 Nakazawa-cho, Naka-ku",
        "address_2": "Hamamatsu  Shizuoka  430-8650",
        "country": "JP"
    },
    "00A084": {
        "oui_hex": "00-A0-84",
        "organization": "Dataplex Pty Ltd",
        "address_1": "Ground floor,",
        "address_2": "MACQUARIE PARK  NSW  2113",
        "country": "AU"
    },
    "00A049": {
        "oui_hex": "00-A0-49",
        "organization": "DIGITECH INDUSTRIES, INC.",
        "address_1": "PO BOX 2267",
        "address_2": "DANBURY  CT  06810",
        "country": "US"
    },
    "00A09D": {
        "oui_hex": "00-A0-9D",
        "organization": "JOHNATHON FREEMAN TECHNOLOGIES",
        "address_1": "P.O. BOX 880114",
        "address_2": "SAN FRANCISCO  CA  94188",
        "country": "US"
    },
    "00A06B": {
        "oui_hex": "00-A0-6B",
        "organization": "DMS DORSCH MIKROSYSTEM GMBH",
        "address_1": "HOLMLUECK 13-15",
        "address_2": "",
        "country": "DE"
    },
    "00A0F8": {
        "oui_hex": "00-A0-F8",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "00A09F": {
        "oui_hex": "00-A0-9F",
        "organization": "COMMVISION CORP.",
        "address_1": "510 LOGUE AVE.",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00A06E": {
        "oui_hex": "00-A0-6E",
        "organization": "AUSTRON, INC.",
        "address_1": "P.O. BOX 14766",
        "address_2": "AUSTIN  TX  78761-4766",
        "country": "US"
    },
    "002022": {
        "oui_hex": "00-20-22",
        "organization": "NMS Communications",
        "address_1": "100 Crossing Boulevard",
        "address_2": "Framingham  MA  01702",
        "country": "US"
    },
    "0020AE": {
        "oui_hex": "00-20-AE",
        "organization": "ORNET DATA COMMUNICATION TECH.",
        "address_1": "P.O. BOX 323",
        "address_2": "",
        "country": "IL"
    },
    "0020AA": {
        "oui_hex": "00-20-AA",
        "organization": "Ericsson Television Limited",
        "address_1": "Solution Area Media",
        "address_2": "Comines Way, Hedge End  Southhampton  SO 30 4DA",
        "country": "GB"
    },
    "0020A4": {
        "oui_hex": "00-20-A4",
        "organization": "MULTIPOINT NETWORKS",
        "address_1": "19 DAVIS DRIVE",
        "address_2": "BELMONT  CA  94002-3001",
        "country": "US"
    },
    "000267": {
        "oui_hex": "00-02-67",
        "organization": "NODE RUNNER, INC.",
        "address_1": "2202 N. FORBES BLVD.",
        "address_2": "TUCSON  AZ  85745",
        "country": "US"
    },
    "0020B1": {
        "oui_hex": "00-20-B1",
        "organization": "COMTECH RESEARCH INC.",
        "address_1": "24271 TAHOE",
        "address_2": "LAGUNA NIGUEL  CA  92656",
        "country": "US"
    },
    "002032": {
        "oui_hex": "00-20-32",
        "organization": "ALCATEL TAISEL",
        "address_1": "4, MING SHENG STREET TU-CHENG",
        "address_2": "  TAIWAN  ROC",
        "country": "TW"
    },
    "0020E9": {
        "oui_hex": "00-20-E9",
        "organization": "DANTEL",
        "address_1": "P.O. BOX 55013",
        "address_2": "FRESNO  CA  93727-1388",
        "country": "US"
    },
    "002038": {
        "oui_hex": "00-20-38",
        "organization": "VME MICROSYSTEMS INTERNATIONAL CORPORATION",
        "address_1": "12090 S. MEMORIAL PARKWAY",
        "address_2": "HUNTSVILLE  AL  35803",
        "country": "US"
    },
    "0020A3": {
        "oui_hex": "00-20-A3",
        "organization": "Harmonic, Inc",
        "address_1": "4300 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "002059": {
        "oui_hex": "00-20-59",
        "organization": "MIRO COMPUTER PRODUCTS AG",
        "address_1": "CARL MIELE STR. 4",
        "address_2": "D-38112 BRAUNSCHWEIG",
        "country": "DE"
    },
    "002034": {
        "oui_hex": "00-20-34",
        "organization": "ROTEC INDUSTRIEAUTOMATION GMBH",
        "address_1": "GUTENBERGSTR. 15",
        "address_2": "",
        "country": "DE"
    },
    "002079": {
        "oui_hex": "00-20-79",
        "organization": "MIKRON GMBH",
        "address_1": "BRESLAUERSTR. 1-3",
        "address_2": "85386 ECHING",
        "country": "DE"
    },
    "002005": {
        "oui_hex": "00-20-05",
        "organization": "SIMPLE TECHNOLOGY",
        "address_1": "3001 DAIMLER ROAD",
        "address_2": "SANTA ANA  CA  92705",
        "country": "US"
    },
    "002018": {
        "oui_hex": "00-20-18",
        "organization": "CIS TECHNOLOGY INC.",
        "address_1": "FL. 9-1, NO. 94, PAO CHUNG RD.",
        "address_2": "TAIPEI HSIEN",
        "country": "TW"
    },
    "002098": {
        "oui_hex": "00-20-98",
        "organization": "HECTRONIC AB",
        "address_1": "BOX 3002",
        "address_2": "S-75003 UPPSALA",
        "country": "SE"
    },
    "0020FD": {
        "oui_hex": "00-20-FD",
        "organization": "ITV TECHNOLOGIES, INC.",
        "address_1": "6800 OWENSMOUTH AVE.  #230",
        "address_2": "CANOGA PARK  CA  91303",
        "country": "US"
    },
    "0020FA": {
        "oui_hex": "00-20-FA",
        "organization": "GDE SYSTEMS, INC.",
        "address_1": "P.O. BOX 85468 - BLDG.#61",
        "address_2": "SAN DIEGO  CA  92186-5468",
        "country": "US"
    },
    "0020C1": {
        "oui_hex": "00-20-C1",
        "organization": "SAXA, Inc.",
        "address_1": "NBF Platinum Tower 1-17-3 Shirokane",
        "address_2": "Tokyo    108-8050",
        "country": "JP"
    },
    "002080": {
        "oui_hex": "00-20-80",
        "organization": "SYNERGY (UK) LTD.",
        "address_1": "HARTCRAN HOUSE",
        "address_2": "WATFORD HERTS.  WD1 5EZ",
        "country": "GB"
    },
    "00C023": {
        "oui_hex": "00-C0-23",
        "organization": "TUTANKHAMON ELECTRONICS",
        "address_1": "2446 ESTAND WAY",
        "address_2": "PLEASANT HILL  CA  94523",
        "country": "US"
    },
    "00C08B": {
        "oui_hex": "00-C0-8B",
        "organization": "RISQ MODULAR SYSTEMS, INC.",
        "address_1": "39899 BALENTINE DRIVE-STE #375",
        "address_2": "NEWARK  CA  94560",
        "country": "US"
    },
    "0020C4": {
        "oui_hex": "00-20-C4",
        "organization": "INET,INC.",
        "address_1": "801 E. CAMPBELL-STE.#330",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "002074": {
        "oui_hex": "00-20-74",
        "organization": "SUNGWOON SYSTEMS",
        "address_1": "YUSUN BLDG.44-4",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00203C": {
        "oui_hex": "00-20-3C",
        "organization": "EUROTIME AB",
        "address_1": "BOX 277",
        "address_2": "",
        "country": "SE"
    },
    "002028": {
        "oui_hex": "00-20-28",
        "organization": "WEST EGG SYSTEMS, INC.",
        "address_1": "65 HIGH RIDGE ROAD-STE.#286",
        "address_2": "STAMFORD  CT  06905",
        "country": "US"
    },
    "002068": {
        "oui_hex": "00-20-68",
        "organization": "ISDYNE",
        "address_1": "11 ROXBURY AVENUE",
        "address_2": "NATICK  MA  01760",
        "country": "US"
    },
    "0020C8": {
        "oui_hex": "00-20-C8",
        "organization": "LARSCOM INCORPORATED",
        "address_1": "4600 PATRICK HENRY DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00209D": {
        "oui_hex": "00-20-9D",
        "organization": "LIPPERT AUTOMATIONSTECHNIK",
        "address_1": "D-68165 MANNHEIM",
        "address_2": "",
        "country": "DE"
    },
    "00209C": {
        "oui_hex": "00-20-9C",
        "organization": "PRIMARY ACCESS CORP.",
        "address_1": "10080 CARROLL CANYON RD",
        "address_2": "SAN DIEGO  CA  92131",
        "country": "US"
    },
    "00206D": {
        "oui_hex": "00-20-6D",
        "organization": "DATA RACE, INC.",
        "address_1": "11550 IH-10WEST  STE#395",
        "address_2": "SAN ANTONIO  TX  78230",
        "country": "US"
    },
    "00203A": {
        "oui_hex": "00-20-3A",
        "organization": "DIGITAL BI0METRICS INC.",
        "address_1": "5600 ROWLAND ROAD- STE.#205",
        "address_2": "MINNETONKA  MN  55364",
        "country": "US"
    },
    "002048": {
        "oui_hex": "00-20-48",
        "organization": "Marconi Communications",
        "address_1": "1000 Fore Drive",
        "address_2": "Warrendale  PA  15086-7502",
        "country": "US"
    },
    "0020DC": {
        "oui_hex": "00-20-DC",
        "organization": "DENSITRON TAIWAN LTD.",
        "address_1": "KYOWA NANABANKAN 5F",
        "address_2": "",
        "country": "JP"
    },
    "00200C": {
        "oui_hex": "00-20-0C",
        "organization": "ADASTRA SYSTEMS CORP.",
        "address_1": "28310 INDUSTRIAL BLVD.-STE-K",
        "address_2": "HAYWARD  CA  94545",
        "country": "US"
    },
    "002011": {
        "oui_hex": "00-20-11",
        "organization": "CANOPUS CO., LTD.",
        "address_1": "KOBE HI-TECH PARK",
        "address_2": "  651-22",
        "country": "JP"
    },
    "002051": {
        "oui_hex": "00-20-51",
        "organization": "Verilink Corporation",
        "address_1": "127 Jetplex Circle",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "00203B": {
        "oui_hex": "00-20-3B",
        "organization": "WISDM LTD.",
        "address_1": "ST. JOHNS INNOVATION CENTRE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0020BA": {
        "oui_hex": "00-20-BA",
        "organization": "CENTER FOR HIGH PERFORMANCE",
        "address_1": "COMPUTING OF WPI",
        "address_2": "MARLBORO  MA  01752",
        "country": "US"
    },
    "0020F5": {
        "oui_hex": "00-20-F5",
        "organization": "PANDATEL AG",
        "address_1": "FASANENWEG 25",
        "address_2": "",
        "country": "DE"
    },
    "00200E": {
        "oui_hex": "00-20-0E",
        "organization": "NSSLGlobal Technologies AS",
        "address_1": "Martin Linges vei 25",
        "address_2": "Fornebu    1364",
        "country": "NO"
    },
    "0020E7": {
        "oui_hex": "00-20-E7",
        "organization": "B&W NUCLEAR SERVICE COMPANY",
        "address_1": "SPECIAL PRODUCTS & INTEG.SVCS.",
        "address_2": "LYNCHBURG  VA  24502",
        "country": "US"
    },
    "0020F0": {
        "oui_hex": "00-20-F0",
        "organization": "UNIVERSAL MICROELECTRONICS CO.",
        "address_1": "3, 27TH RD., TAICHUNG IND.PARK",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "002089": {
        "oui_hex": "00-20-89",
        "organization": "T3PLUS NETWORKING, INC.",
        "address_1": "2840 SAN TOMAS EXPRESSWAY",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "002061": {
        "oui_hex": "00-20-61",
        "organization": "GarrettCom, Inc.",
        "address_1": "47823 Westinghouse Dr.",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "00C080": {
        "oui_hex": "00-C0-80",
        "organization": "NETSTAR, INC.",
        "address_1": "CEDAR BUSINESS CENTER",
        "address_2": "MINNEAPOLIS  MN  55425-1235",
        "country": "US"
    },
    "00C0B4": {
        "oui_hex": "00-C0-B4",
        "organization": "MYSON TECHNOLOGY, INC.",
        "address_1": "2F, NO. 3, INDUSTRY E. RD.IV",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00C045": {
        "oui_hex": "00-C0-45",
        "organization": "ISOLATION SYSTEMS, LTD.",
        "address_1": "26 SIX POINT ROAD",
        "address_2": "CANADA  M8Z  2W9",
        "country": "CA"
    },
    "0070B3": {
        "oui_hex": "00-70-B3",
        "organization": "DATA RECALL LTD.",
        "address_1": "SONDES PLACE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0070B0": {
        "oui_hex": "00-70-B0",
        "organization": "M/A-COM INC. COMPANIES",
        "address_1": "11717 EXPLORATION LANE",
        "address_2": "GERMANTOWN  MD  20767",
        "country": "US"
    },
    "00E6D3": {
        "oui_hex": "00-E6-D3",
        "organization": "NIXDORF COMPUTER CORP.",
        "address_1": "2520 MISSION COLLEGE ROAD",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00C0C3": {
        "oui_hex": "00-C0-C3",
        "organization": "ACUSON COMPUTED SONOGRAPHY",
        "address_1": "1220 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94039-7393",
        "country": "US"
    },
    "00C0B3": {
        "oui_hex": "00-C0-B3",
        "organization": "COMSTAT DATACOMM CORPORATION",
        "address_1": "1720 SPECTRUM DRIVE",
        "address_2": "LAWRENCEVILLE  GA  30243",
        "country": "US"
    },
    "00C0E5": {
        "oui_hex": "00-C0-E5",
        "organization": "GESPAC, S.A.",
        "address_1": "CHEMIN DES AULX 18",
        "address_2": "",
        "country": "CH"
    },
    "00C04D": {
        "oui_hex": "00-C0-4D",
        "organization": "MITEC, INC.",
        "address_1": "BR-KAMEIDO 1 BUILDING",
        "address_2": "",
        "country": "JP"
    },
    "00C047": {
        "oui_hex": "00-C0-47",
        "organization": "UNIMICRO SYSTEMS, INC.",
        "address_1": "44382 S. GRIMMER BLVD.",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C084": {
        "oui_hex": "00-C0-84",
        "organization": "DATA LINK CORP. LTD.",
        "address_1": "3-15-3 MIDORICHO",
        "address_2": "",
        "country": "JP"
    },
    "00C041": {
        "oui_hex": "00-C0-41",
        "organization": "DIGITAL TRANSMISSION SYSTEMS",
        "address_1": "4830 RIVER GREEN PARKWAY",
        "address_2": "DULUTH  GA  30136",
        "country": "US"
    },
    "00C01F": {
        "oui_hex": "00-C0-1F",
        "organization": "S.E.R.C.E.L.",
        "address_1": "B.P. 439",
        "address_2": "",
        "country": "FR"
    },
    "006086": {
        "oui_hex": "00-60-86",
        "organization": "LOGIC REPLACEMENT TECH. LTD.",
        "address_1": "14 ARKWRIGHT ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C059": {
        "oui_hex": "00-C0-59",
        "organization": "DENSO CORPORATION",
        "address_1": "1-1, Showa-cho,",
        "address_2": "Kariya-shi,  Aichi  448-8661",
        "country": "JP"
    },
    "00C0F1": {
        "oui_hex": "00-C0-F1",
        "organization": "SHINKO ELECTRIC CO., LTD.",
        "address_1": "COMPUTER SYSTEM DIVISION",
        "address_2": "  JAPAN  441-31",
        "country": "JP"
    },
    "00C0A1": {
        "oui_hex": "00-C0-A1",
        "organization": "TOKYO DENSHI SEKEI CO.",
        "address_1": "255-1 RENKOJI, TAMA-SHI",
        "address_2": "  JAPAN  206",
        "country": "JP"
    },
    "00C02E": {
        "oui_hex": "00-C0-2E",
        "organization": "NETWIZ",
        "address_1": "26 GOLOMB STREET",
        "address_2": "",
        "country": "IL"
    },
    "00C00D": {
        "oui_hex": "00-C0-0D",
        "organization": "ADVANCED LOGIC RESEARCH, INC.",
        "address_1": "9401 JERONIMO",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "00C081": {
        "oui_hex": "00-C0-81",
        "organization": "METRODATA LTD.",
        "address_1": "BLENHEIM HOUSE",
        "address_2": "TW20 8RY  TW20 8RY  ENGLAND",
        "country": "GB"
    },
    "00C03B": {
        "oui_hex": "00-C0-3B",
        "organization": "MULTIACCESS COMPUTING CORP.",
        "address_1": "5350 HOLLISTER AVE., STE.",
        "address_2": "SANTA BARBARA  CA  93111",
        "country": "US"
    },
    "00C082": {
        "oui_hex": "00-C0-82",
        "organization": "MOORE PRODUCTS CO.",
        "address_1": "SUMNEYTOWN PIKE",
        "address_2": "SPRING HOUSE  PA  19477",
        "country": "US"
    },
    "00C099": {
        "oui_hex": "00-C0-99",
        "organization": "YOSHIKI INDUSTRIAL CO.,LTD.",
        "address_1": "1-38 MATSUGASAKI 2-CHOME",
        "address_2": "  992",
        "country": "JP"
    },
    "00C001": {
        "oui_hex": "00-C0-01",
        "organization": "DIATEK PATIENT MANAGMENT",
        "address_1": "SYSTEMS, INC.",
        "address_2": "SAN DIEGO  CA  92121-1723",
        "country": "US"
    },
    "00C0F4": {
        "oui_hex": "00-C0-F4",
        "organization": "INTERLINK SYSTEM CO., LTD.",
        "address_1": "INTERLINK B/D, 476-20",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00C0E2": {
        "oui_hex": "00-C0-E2",
        "organization": "CALCOMP, INC.",
        "address_1": "2411 W. LAPALMA AVENUE",
        "address_2": "ANAHEIM  CA  92803-3250",
        "country": "US"
    },
    "00C07B": {
        "oui_hex": "00-C0-7B",
        "organization": "ASCEND COMMUNICATIONS, INC.",
        "address_1": "1701 HARBOR BAY PARKWAY",
        "address_2": "ALAMEDA  CA  94502",
        "country": "US"
    },
    "00C03C": {
        "oui_hex": "00-C0-3C",
        "organization": "TOWER TECH S.R.L.",
        "address_1": "VIA RIDOLFI 6,8",
        "address_2": "",
        "country": "IT"
    },
    "00C01D": {
        "oui_hex": "00-C0-1D",
        "organization": "GRAND JUNCTION NETWORKS, INC.",
        "address_1": "3101 WHIPPLE RD., #27",
        "address_2": "UNION CITY  CA  94587",
        "country": "US"
    },
    "00C035": {
        "oui_hex": "00-C0-35",
        "organization": "QUINTAR COMPANY",
        "address_1": "370 AMAPOLA AVE., STE.#106",
        "address_2": "TORRANCE  CA  90501",
        "country": "US"
    },
    "00C070": {
        "oui_hex": "00-C0-70",
        "organization": "SECTRA SECURE-TRANSMISSION AB",
        "address_1": "TEKNIKRINGEN 2",
        "address_2": "",
        "country": "SE"
    },
    "00C06D": {
        "oui_hex": "00-C0-6D",
        "organization": "BOCA RESEARCH, INC.",
        "address_1": "6401 CONGRESS AVENUE",
        "address_2": "BOCA RATON  FL  33487",
        "country": "US"
    },
    "00C0EA": {
        "oui_hex": "00-C0-EA",
        "organization": "ARRAY TECHNOLOGY LTD.",
        "address_1": "145 FRIMLEY ROAD",
        "address_2": "ENGLAND  GU15  2PS",
        "country": "GB"
    },
    "00C009": {
        "oui_hex": "00-C0-09",
        "organization": "KT TECHNOLOGY (S) PTE LTD",
        "address_1": "KT BUILDING",
        "address_2": "  SINGAPORE  0511",
        "country": "SG"
    },
    "00C0D6": {
        "oui_hex": "00-C0-D6",
        "organization": "J1 SYSTEMS, INC.",
        "address_1": "3 DUNWOODY PARK-STE.#103",
        "address_2": "ATLANTA  GA  30338",
        "country": "US"
    },
    "00C0DC": {
        "oui_hex": "00-C0-DC",
        "organization": "EOS TECHNOLOGIES, INC.",
        "address_1": "3945 FREEDOM CIRCLE, STE.#770",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00C072": {
        "oui_hex": "00-C0-72",
        "organization": "KNX LTD.",
        "address_1": "HOLLINGWOOD HOUSE",
        "address_2": "LS21 3HA  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C0AE": {
        "oui_hex": "00-C0-AE",
        "organization": "TOWERCOM CO. INC. DBA PC HOUSE",
        "address_1": "841 E. ARTESIA BLVD.",
        "address_2": "CARSON  CA  90746",
        "country": "US"
    },
    "00C0C2": {
        "oui_hex": "00-C0-C2",
        "organization": "INFINITE NETWORKS LTD.",
        "address_1": "19 BROOKSIDE ROAD, OXHEY",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C0AF": {
        "oui_hex": "00-C0-AF",
        "organization": "TEKLOGIX INC.",
        "address_1": "2100 MEADOWVALE BOULEVARD",
        "address_2": "CANADA  L5N  7J9",
        "country": "CA"
    },
    "00C07A": {
        "oui_hex": "00-C0-7A",
        "organization": "PRIVA B.V.",
        "address_1": "P.O. BOX 18",
        "address_2": "",
        "country": "NL"
    },
    "00C0F6": {
        "oui_hex": "00-C0-F6",
        "organization": "CELAN TECHNOLOGY INC.",
        "address_1": "NO. 101, MIN-HSIANG ST.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "CN"
    },
    "00C0F8": {
        "oui_hex": "00-C0-F8",
        "organization": "ABOUT COMPUTING INC.",
        "address_1": "P.O. BOX 172",
        "address_2": "BELMONT  MA  02178",
        "country": "US"
    },
    "00C078": {
        "oui_hex": "00-C0-78",
        "organization": "COMPUTER SYSTEMS ENGINEERING",
        "address_1": "46791 FREMONT BLVD.",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C09A": {
        "oui_hex": "00-C0-9A",
        "organization": "PHOTONICS CORPORATION",
        "address_1": "2940 NORTH FIRST STREET",
        "address_2": "SAN JOSE  CA  95123-2021",
        "country": "US"
    },
    "00C01A": {
        "oui_hex": "00-C0-1A",
        "organization": "COROMETRICS MEDICAL SYSTEMS",
        "address_1": "61 BARNES PARK ROAD NORTH",
        "address_2": "WALLINGFORD  CT  06492-0333",
        "country": "US"
    },
    "00C068": {
        "oui_hex": "00-C0-68",
        "organization": "HME Clear-Com LTD.",
        "address_1": "7400 Beach Drive",
        "address_2": "Cambridgeshire    CB25 9TP",
        "country": "GB"
    },
    "00C0D8": {
        "oui_hex": "00-C0-D8",
        "organization": "UNIVERSAL DATA SYSTEMS",
        "address_1": "5000 BRADFORD DRIVE",
        "address_2": "HUNTSVILLE  AL  35805-1993",
        "country": "US"
    },
    "004036": {
        "oui_hex": "00-40-36",
        "organization": "Zoom Telephonics, Inc",
        "address_1": "207 South St",
        "address_2": "Boston  MA  02111",
        "country": "US"
    },
    "004016": {
        "oui_hex": "00-40-16",
        "organization": "ADC - Global Connectivity Solutions Division",
        "address_1": "P.O. Box 1101",
        "address_2": "Minneapolis  MN  55440-1101",
        "country": "US"
    },
    "00406A": {
        "oui_hex": "00-40-6A",
        "organization": "KENTEK INFORMATION SYSTEMS,INC",
        "address_1": "2945 WILDERNESS PLACE",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00400A": {
        "oui_hex": "00-40-0A",
        "organization": "PIVOTAL TECHNOLOGIES, INC.",
        "address_1": "100 W. RINCON AVENUE-STE #211",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "004099": {
        "oui_hex": "00-40-99",
        "organization": "NEWGEN SYSTEMS CORP.",
        "address_1": "17580 NEWHOPE STREET",
        "address_2": "FOUNTAIN VALLEY  CA  92708",
        "country": "US"
    },
    "004011": {
        "oui_hex": "00-40-11",
        "organization": "ANDOVER CONTROLS CORPORATION",
        "address_1": "300 BRICKSTONE SQUARE",
        "address_2": "ANDOVER  MA  01810",
        "country": "US"
    },
    "0040A1": {
        "oui_hex": "00-40-A1",
        "organization": "ERGO COMPUTING",
        "address_1": "ONE INTERCONTINENTAL WAY",
        "address_2": "PEABODY  MA  01960",
        "country": "US"
    },
    "004081": {
        "oui_hex": "00-40-81",
        "organization": "MANNESMANN SCANGRAPHIC GMBH",
        "address_1": "RISSENER STRASSE 112-114",
        "address_2": "",
        "country": "DE"
    },
    "00C08C": {
        "oui_hex": "00-C0-8C",
        "organization": "PERFORMANCE TECHNOLOGIES, INC.",
        "address_1": "315 SCIENCE PARKWAY",
        "address_2": "ROCHESTER  NY  14620",
        "country": "US"
    },
    "00C007": {
        "oui_hex": "00-C0-07",
        "organization": "PINNACLE DATA SYSTEMS, INC.",
        "address_1": "1350 WEST FIFTH AVENUE",
        "address_2": "COLUMBUS  OH  43212",
        "country": "US"
    },
    "00C098": {
        "oui_hex": "00-C0-98",
        "organization": "CHUNTEX ELECTRONIC CO., LTD.",
        "address_1": "6F., NO.2, ALLEY 6, LANE 235",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00C0BE": {
        "oui_hex": "00-C0-BE",
        "organization": "ALCATEL - SEL",
        "address_1": "LORENZ STR",
        "address_2": "",
        "country": "DE"
    },
    "00C06E": {
        "oui_hex": "00-C0-6E",
        "organization": "HAFT TECHNOLOGY, INC.",
        "address_1": "DAINI-DOHO BLDG.",
        "address_2": "  305",
        "country": "JP"
    },
    "00C08A": {
        "oui_hex": "00-C0-8A",
        "organization": "Lauterbach GmbH",
        "address_1": "Altlaufstraße 40",
        "address_2": "  Höhenkirchen-Siegertsbrunn  85635",
        "country": "DE"
    },
    "00C0F7": {
        "oui_hex": "00-C0-F7",
        "organization": "ENGAGE COMMUNICATION, INC.",
        "address_1": "9053 SOQUEL DRIVE",
        "address_2": "APTOS  CA  95003-4034",
        "country": "US"
    },
    "0040B7": {
        "oui_hex": "00-40-B7",
        "organization": "STEALTH COMPUTER SYSTEMS",
        "address_1": "2341 REGINA CT.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0040AC": {
        "oui_hex": "00-40-AC",
        "organization": "SUPER WORKSTATION, INC.",
        "address_1": "2190 PARAGON DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "10005A": {
        "oui_hex": "10-00-5A",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "0040D1": {
        "oui_hex": "00-40-D1",
        "organization": "FUKUDA DENSHI CO., LTD.",
        "address_1": "R & D DEPARTMENT NO. 1",
        "address_2": "",
        "country": "JP"
    },
    "004069": {
        "oui_hex": "00-40-69",
        "organization": "LEMCOM SYSTEMS, INC.",
        "address_1": "2104 WEST PEORIA AVENUE",
        "address_2": "PHOENIX  AZ  85029",
        "country": "US"
    },
    "00403B": {
        "oui_hex": "00-40-3B",
        "organization": "SYNERJET INTERNATIONAL CORP.",
        "address_1": "5F, NO 35, KUANG FU S. ROAD",
        "address_2": "TAIWAN  R.  O. C.",
        "country": "TW"
    },
    "00803B": {
        "oui_hex": "00-80-3B",
        "organization": "APT COMMUNICATIONS, INC.",
        "address_1": "9607 DR. PERRY ROAD",
        "address_2": "IJAMSVILLE  MD  21754",
        "country": "US"
    },
    "00806A": {
        "oui_hex": "00-80-6A",
        "organization": "ERI (EMPAC RESEARCH INC.)",
        "address_1": "47560 SEABRIDGE DRIVE",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C0A8": {
        "oui_hex": "00-C0-A8",
        "organization": "GVC CORPORATION",
        "address_1": "1961 CONCOURSE DRIVE-STE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0040E0": {
        "oui_hex": "00-40-E0",
        "organization": "ATOMWIDE LTD.",
        "address_1": "23 THE GREENWAY",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0040A8": {
        "oui_hex": "00-40-A8",
        "organization": "IMF INTERNATIONAL LTD.",
        "address_1": "NO.5 2/F KINGSFORD IND. CENTRE",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "004070": {
        "oui_hex": "00-40-70",
        "organization": "INTERWARE CO., LTD.",
        "address_1": "7F KUDAN NEW CENTRAL BLDG.,",
        "address_2": "TOKYO 102  TOKYO 102",
        "country": "JP"
    },
    "00408A": {
        "oui_hex": "00-40-8A",
        "organization": "TPS TELEPROCESSING SYS. GMBH",
        "address_1": "SCHWADERMUCHLSTRASSE 4-8",
        "address_2": "",
        "country": "DE"
    },
    "0040FD": {
        "oui_hex": "00-40-FD",
        "organization": "LXE",
        "address_1": "303 RESEARCH DRIVE",
        "address_2": "NORCROSS  GA  30092",
        "country": "US"
    },
    "00403F": {
        "oui_hex": "00-40-3F",
        "organization": "SSANGYONG COMPUTER SYSTEMS",
        "address_1": "CORPORATION",
        "address_2": "  KOREA  100-705",
        "country": "KR"
    },
    "004082": {
        "oui_hex": "00-40-82",
        "organization": "LABORATORY EQUIPMENT CORP.",
        "address_1": "1-7-3 MINATOMACHI",
        "address_2": "  300",
        "country": "JP"
    },
    "0040F1": {
        "oui_hex": "00-40-F1",
        "organization": "CHUO ELECTRONICS CO., LTD.",
        "address_1": "1-9-9, MOTOHONGO-CHO",
        "address_2": "",
        "country": "JP"
    },
    "0040A9": {
        "oui_hex": "00-40-A9",
        "organization": "DATACOM INC.",
        "address_1": "146 HIGHWAY ROUTE 34 - STE 250",
        "address_2": "HOLMDEL  NJ  07733",
        "country": "US"
    },
    "0040E3": {
        "oui_hex": "00-40-E3",
        "organization": "QUIN SYSTEMS LTD",
        "address_1": "OAKLANDS BUSINESS CENTRE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "004091": {
        "oui_hex": "00-40-91",
        "organization": "PROCOMP INDUSTRIA ELETRONICA",
        "address_1": "AV. KENKITI SIMOMOTO, 767",
        "address_2": "",
        "country": "BR"
    },
    "0040EA": {
        "oui_hex": "00-40-EA",
        "organization": "PLAIN TREE SYSTEMS INC",
        "address_1": "CHIEF EXECTUVIE OFFICER",
        "address_2": "",
        "country": "CA"
    },
    "0040A7": {
        "oui_hex": "00-40-A7",
        "organization": "ITAUTEC PHILCO S.A.",
        "address_1": "GRUPO ITAUTEC PHILCO",
        "address_2": "",
        "country": "BR"
    },
    "004064": {
        "oui_hex": "00-40-64",
        "organization": "KLA INSTRUMENTS CORPORATION",
        "address_1": "160 RIO ROBLES",
        "address_2": "SAN JOSE  CA  95161-9055",
        "country": "US"
    },
    "004043": {
        "oui_hex": "00-40-43",
        "organization": "Nokia Siemens Networks GmbH & Co. KG.",
        "address_1": "Werner-von-Siemens Straße 2-6",
        "address_2": "Bruchsal  Baden-Württemberg  76646",
        "country": "DE"
    },
    "00405A": {
        "oui_hex": "00-40-5A",
        "organization": "GOLDSTAR INFORMATION & COMM.",
        "address_1": "533, HOGAE-DONG, ANYANG-SHI",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "004013": {
        "oui_hex": "00-40-13",
        "organization": "NTT DATA COMM. SYSTEMS CORP.",
        "address_1": "DEVELOPMENT HEADQUARTERS",
        "address_2": "TOKYO 135  TOKYO 135",
        "country": "JP"
    },
    "00400C": {
        "oui_hex": "00-40-0C",
        "organization": "GENERAL MICRO SYSTEMS, INC.",
        "address_1": "P.O. BOX 3689",
        "address_2": "RANCHO CUCAMONGA  CA  91729",
        "country": "US"
    },
    "00405E": {
        "oui_hex": "00-40-5E",
        "organization": "NORTH HILLS ISRAEL",
        "address_1": "P.O. BOX 1280",
        "address_2": "",
        "country": "IL"
    },
    "0040FA": {
        "oui_hex": "00-40-FA",
        "organization": "MICROBOARDS, INC.",
        "address_1": "31-8, TAKASECHO,FUNABASHI-CITY",
        "address_2": "CHIBA 273  CHIBA 273",
        "country": "JP"
    },
    "004014": {
        "oui_hex": "00-40-14",
        "organization": "COMSOFT GMBH",
        "address_1": "WACHHAUSSTR. 5A",
        "address_2": "",
        "country": "DE"
    },
    "004000": {
        "oui_hex": "00-40-00",
        "organization": "PCI COMPONENTES DA AMZONIA LTD",
        "address_1": "RUA JOSEF KRYSS",
        "address_2": "  01140  BRASIL",
        "country": "BR"
    },
    "00406C": {
        "oui_hex": "00-40-6C",
        "organization": "COPERNIQUE",
        "address_1": "6, MAIL DE L'EUROPE BP 25",
        "address_2": "",
        "country": "FR"
    },
    "004075": {
        "oui_hex": "00-40-75",
        "organization": "Tattile SRL",
        "address_1": "11-12 NORTHFIELD PROSPECT",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "004053": {
        "oui_hex": "00-40-53",
        "organization": "AMPRO COMPUTERS",
        "address_1": "990 ALMONDOR AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "008038": {
        "oui_hex": "00-80-38",
        "organization": "DATA RESEARCH & APPLICATIONS",
        "address_1": "9041 EXECUTIVE PARK DR.",
        "address_2": "KNOXVILLE  TN  37923-4609",
        "country": "US"
    },
    "00805E": {
        "oui_hex": "00-80-5E",
        "organization": "LSI LOGIC CORPORATION",
        "address_1": "1551 MCCARTHY BOULEVARD",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "008060": {
        "oui_hex": "00-80-60",
        "organization": "NETWORK INTERFACE CORPORATION",
        "address_1": "15019 WEST 95 STREET",
        "address_2": "LENEXA  KS  66215",
        "country": "US"
    },
    "0080C3": {
        "oui_hex": "00-80-C3",
        "organization": "BICC INFORMATION SYSTEMS & SVC",
        "address_1": "500 CAPABILITY GREEN, LUTON",
        "address_2": "ENGLAND  LU1  3LT",
        "country": "GB"
    },
    "008044": {
        "oui_hex": "00-80-44",
        "organization": "SYSTECH COMPUTER CORP.",
        "address_1": "6465 NANCY RIDGE DRIVE",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "008006": {
        "oui_hex": "00-80-06",
        "organization": "COMPUADD CORPORATION",
        "address_1": "ENGINEERING",
        "address_2": "AUSTIN  TX  78727",
        "country": "US"
    },
    "00809B": {
        "oui_hex": "00-80-9B",
        "organization": "JUSTSYSTEM CORPORATION",
        "address_1": "3-46 OKINOHAMAHIGASHI",
        "address_2": "",
        "country": "JP"
    },
    "0080DF": {
        "oui_hex": "00-80-DF",
        "organization": "ADC CODENOLL TECHNOLOGY CORP.",
        "address_1": "200 CORPORATE BLVD. SO.",
        "address_2": "YONKERS  NY  10701",
        "country": "US"
    },
    "008028": {
        "oui_hex": "00-80-28",
        "organization": "TRADPOST (HK) LTD",
        "address_1": "5/F, STAR CENTRE",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "008061": {
        "oui_hex": "00-80-61",
        "organization": "LITTON SYSTEMS, INC.",
        "address_1": "M/S 44-20",
        "address_2": "AGOURA HILLS  CA  91301-0500",
        "country": "US"
    },
    "0080F5": {
        "oui_hex": "00-80-F5",
        "organization": "Quantel Ltd",
        "address_1": "Turnpike Road",
        "address_2": "Newbury  Berkshire  RG14 2NX",
        "country": "GB"
    },
    "0080B9": {
        "oui_hex": "00-80-B9",
        "organization": "ARCHE TECHNOLIGIES INC.",
        "address_1": "48502 KATO ROAD",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "004063": {
        "oui_hex": "00-40-63",
        "organization": "VIA TECHNOLOGIES, INC.",
        "address_1": "5020 BRANDIN COURT",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00808A": {
        "oui_hex": "00-80-8A",
        "organization": "SUMMIT MICROSYSTEMS CORP.",
        "address_1": "710 LAKEWAY-STE.#150",
        "address_2": "SUNNYVALE  CA  940867",
        "country": "US"
    },
    "0080A7": {
        "oui_hex": "00-80-A7",
        "organization": "Honeywell International Inc",
        "address_1": "Vancouver Center of Excellence",
        "address_2": "North Vancouver    V7J 3S4",
        "country": "CA"
    },
    "008066": {
        "oui_hex": "00-80-66",
        "organization": "ARCOM CONTROL SYSTEMS, LTD.",
        "address_1": "UNIT 8, CLIFTON ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0080CB": {
        "oui_hex": "00-80-CB",
        "organization": "FALCO DATA PRODUCTS",
        "address_1": "440 POTRERO AVENUE",
        "address_2": "SUNNYVALE  CA  94086-4196",
        "country": "US"
    },
    "008007": {
        "oui_hex": "00-80-07",
        "organization": "DLOG NC-SYSTEME",
        "address_1": "WERNER-VON-SIEMENS STRASSE 13",
        "address_2": "    GERMANY",
        "country": ""
    },
    "008062": {
        "oui_hex": "00-80-62",
        "organization": "INTERFACE  CO.",
        "address_1": "8-26 OZU 5-CHOME MINAMI-KU",
        "address_2": "",
        "country": "JP"
    },
    "00801E": {
        "oui_hex": "00-80-1E",
        "organization": "XINETRON, INC.",
        "address_1": "2330 B. WALSH AVE.",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "0080E2": {
        "oui_hex": "00-80-E2",
        "organization": "T.D.I. CO., LTD.",
        "address_1": "DEVELOPMENT DIV.  #3 FUJI BLDG",
        "address_2": "",
        "country": "JP"
    },
    "008049": {
        "oui_hex": "00-80-49",
        "organization": "NISSIN ELECTRIC CO., LTD.",
        "address_1": "47, UMEZU - TAKASE - CHO",
        "address_2": "",
        "country": "JP"
    },
    "0080C1": {
        "oui_hex": "00-80-C1",
        "organization": "LANEX CORPORATION",
        "address_1": "10727 TUCKER STREET",
        "address_2": "BELTSVILLE  MD  20705",
        "country": "US"
    },
    "0080A3": {
        "oui_hex": "00-80-A3",
        "organization": "Lantronix",
        "address_1": "15353 Barranca Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0080BC": {
        "oui_hex": "00-80-BC",
        "organization": "HITACHI ENGINEERING CO., LTD",
        "address_1": "4-8-26, OMIKACHO",
        "address_2": "",
        "country": "JP"
    },
    "008036": {
        "oui_hex": "00-80-36",
        "organization": "REFLEX MANUFACTURING SYSTEMS",
        "address_1": "UNIT D, THE FLEMING CENTRE,",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "008083": {
        "oui_hex": "00-80-83",
        "organization": "AMDAHL",
        "address_1": "1250 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94088-3470",
        "country": "US"
    },
    "0080B8": {
        "oui_hex": "00-80-B8",
        "organization": "DMG MORI B.U.G. CO., LTD.",
        "address_1": "1-1-14 Techno park,",
        "address_2": "Shimonopporo, Atsubetsuku, Sapporo  Hokkaido  004-0015",
        "country": "JP"
    },
    "00804D": {
        "oui_hex": "00-80-4D",
        "organization": "CYCLONE MICROSYSTEMS, INC.",
        "address_1": "25 SCIENCE PARK",
        "address_2": "NEW HAVEN  CT  06511",
        "country": "US"
    },
    "0080D4": {
        "oui_hex": "00-80-D4",
        "organization": "CHASE RESEARCH LTD.",
        "address_1": "7 CHINEHAM BUSINESS PARK",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00803D": {
        "oui_hex": "00-80-3D",
        "organization": "SURIGIKEN CO.,  LTD.",
        "address_1": "YOUTH BLDG, 4-1-9 SHINJUKU",
        "address_2": "",
        "country": "JP"
    },
    "00808B": {
        "oui_hex": "00-80-8B",
        "organization": "DACOLL LIMITED",
        "address_1": "DACOLL HOUSE, GARDNERS LANE",
        "address_2": "SCOTLAND  EH48  1TP",
        "country": "GB"
    },
    "0080B2": {
        "oui_hex": "00-80-B2",
        "organization": "NETWORK EQUIPMENT TECHNOLOGIES",
        "address_1": "6900 PASEO PADRE PARKWAY",
        "address_2": "FREMONT  CA  94555",
        "country": "US"
    },
    "008076": {
        "oui_hex": "00-80-76",
        "organization": "MCNC",
        "address_1": "P.O. BOX 12889",
        "address_2": "RTP  NC  27709",
        "country": "US"
    },
    "00800B": {
        "oui_hex": "00-80-0B",
        "organization": "CSK CORPORATION",
        "address_1": "18F MATSUSHITA IMP BLDG,",
        "address_2": "  JAPAN  540",
        "country": "JP"
    },
    "008018": {
        "oui_hex": "00-80-18",
        "organization": "KOBE STEEL, LTD.",
        "address_1": "KOBE ISUZU RECRUIT BLDG.",
        "address_2": "",
        "country": "JP"
    },
    "008068": {
        "oui_hex": "00-80-68",
        "organization": "YAMATECH SCIENTIFIC LTD.",
        "address_1": "1255 LAIRD, SUITE 260",
        "address_2": "",
        "country": "CA"
    },
    "0080A8": {
        "oui_hex": "00-80-A8",
        "organization": "VITACOM CORPORATION",
        "address_1": "1330 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "008033": {
        "oui_hex": "00-80-33",
        "organization": "EMS Aviation, Inc.",
        "address_1": "121 WHITTENDALE DRIVE",
        "address_2": "MOORESTOWN  NJ  08057",
        "country": "US"
    },
    "00807C": {
        "oui_hex": "00-80-7C",
        "organization": "FIBERCOM, INC.",
        "address_1": "3353 ORANGE AVENUE NE",
        "address_2": "ROANOKE  VA  24012",
        "country": "US"
    },
    "008091": {
        "oui_hex": "00-80-91",
        "organization": "TOKYO ELECTRIC CO.,LTD",
        "address_1": "10-14 UCHIKANDA",
        "address_2": "TOKYO  JAPAN  101",
        "country": "JP"
    },
    "00008E": {
        "oui_hex": "00-00-8E",
        "organization": "SOLBOURNE COMPUTER, INC.",
        "address_1": "1900 PIKE ROAD",
        "address_2": "LONGMONT  COLORADO  80501",
        "country": "US"
    },
    "0000DC": {
        "oui_hex": "00-00-DC",
        "organization": "HAYES MICROCOMPUTER PRODUCTS",
        "address_1": "P.O. BOX 105203",
        "address_2": "ATLANTA  GA  30348",
        "country": "US"
    },
    "000063": {
        "oui_hex": "00-00-63",
        "organization": "BARCO CONTROL ROOMS GMBH",
        "address_1": "An der Rossweid 5",
        "address_2": "Karlsruhe    D-76229",
        "country": "DE"
    },
    "00004E": {
        "oui_hex": "00-00-4E",
        "organization": "AMPEX CORPORATION",
        "address_1": "581 CONFERENCE PLACE",
        "address_2": "GOLDEN  CO  80401",
        "country": "US"
    },
    "0000BD": {
        "oui_hex": "00-00-BD",
        "organization": "Mitsubishi Cable Industries, Ltd. / Ryosei Systems",
        "address_1": " 8, NISHINO-CHO, HIGASHI-MUKOJIMA",
        "address_2": "AMAGASAKI  HYOGO  660-0856",
        "country": "JP"
    },
    "00002E": {
        "oui_hex": "00-00-2E",
        "organization": "SOCIETE EVIRA",
        "address_1": "ZONE PORTUAIRE DE BREGAILLON",
        "address_2": "",
        "country": "FR"
    },
    "00003F": {
        "oui_hex": "00-00-3F",
        "organization": "SYNTREX, INC.",
        "address_1": "246 INDUSTRIAL WAY WEST",
        "address_2": "EATONTOWN  NJ  07724",
        "country": "US"
    },
    "00809D": {
        "oui_hex": "00-80-9D",
        "organization": "Commscraft Ltd.",
        "address_1": "PO BOX 160",
        "address_2": "",
        "country": "AU"
    },
    "0080F4": {
        "oui_hex": "00-80-F4",
        "organization": "TELEMECANIQUE ELECTRIQUE",
        "address_1": "33 BIS AVENUE,",
        "address_2": "",
        "country": "FR"
    },
    "008022": {
        "oui_hex": "00-80-22",
        "organization": "SCAN-OPTICS",
        "address_1": "201 TECHNOLOGY DRIVE",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "0000CD": {
        "oui_hex": "00-00-CD",
        "organization": "Allied Telesis Labs Ltd",
        "address_1": "27 Nazareth Avenue",
        "address_2": "Middleton  Christchurch  8024",
        "country": "NZ"
    },
    "0080DD": {
        "oui_hex": "00-80-DD",
        "organization": "GMX INC/GIMIX",
        "address_1": "3223 ARNOLD LANE",
        "address_2": "NORTHBROOK  IL  60062-2406",
        "country": "US"
    },
    "0080FB": {
        "oui_hex": "00-80-FB",
        "organization": "BVM LIMITED",
        "address_1": "Lakeside House, Brickyard Road,",
        "address_2": "Swanmore  SOUTHAMPTON  SO32 2SA",
        "country": "GB"
    },
    "0080B4": {
        "oui_hex": "00-80-B4",
        "organization": "SOPHIA SYSTEMS",
        "address_1": "3337 KIFER ROAD",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "00807F": {
        "oui_hex": "00-80-7F",
        "organization": "DY-4 INCORPORATED",
        "address_1": "333 PALLADIUM DRIVE, MS 312",
        "address_2": "",
        "country": "CA"
    },
    "00802D": {
        "oui_hex": "00-80-2D",
        "organization": "XYLOGICS INC",
        "address_1": "53 THIRD AVENUE",
        "address_2": "BURLINGTON  MA  01803",
        "country": "US"
    },
    "000061": {
        "oui_hex": "00-00-61",
        "organization": "GATEWAY COMMUNICATIONS",
        "address_1": "2941 ALTON AVENUE",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "0000EA": {
        "oui_hex": "00-00-EA",
        "organization": "UPNOD AB",
        "address_1": "BOX 23051",
        "address_2": "",
        "country": "SE"
    },
    "000043": {
        "oui_hex": "00-00-43",
        "organization": "MICRO TECHNOLOGY",
        "address_1": "4905 EAST LAPALMA",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "000017": {
        "oui_hex": "00-00-17",
        "organization": "Oracle",
        "address_1": "4200 Network Circle",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0000B2": {
        "oui_hex": "00-00-B2",
        "organization": "TELEVIDEO SYSTEMS, INC.",
        "address_1": "550 E. BROKAW ROAD",
        "address_2": "SAN JOSE  CA  95161-9048",
        "country": "US"
    },
    "0000EE": {
        "oui_hex": "00-00-EE",
        "organization": "NETWORK DESIGNERS, LTD.",
        "address_1": "UNIT 1A, HORNBEAM PARK",
        "address_2": "UNITED KINGDOM  HG2  8QT",
        "country": "GB"
    },
    "0000E5": {
        "oui_hex": "00-00-E5",
        "organization": "SIGMEX LTD.",
        "address_1": "SIGMA HOUSE",
        "address_2": "RH12  4UZ  ENGLAND",
        "country": "GB"
    },
    "000089": {
        "oui_hex": "00-00-89",
        "organization": "CAYMAN SYSTEMS INC.",
        "address_1": "26 LANSDOWNE STREET",
        "address_2": "CAMBRIDGE  MA  02139",
        "country": "US"
    },
    "0000FF": {
        "oui_hex": "00-00-FF",
        "organization": "CAMTEC ELECTRONICS LTD.",
        "address_1": "101 VAUGHAN WAY",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000B7": {
        "oui_hex": "00-00-B7",
        "organization": "DOVE COMPUTER CORPORATION",
        "address_1": "1200 NORTH 23RD STREET",
        "address_2": "WILMINGTON  NC  28405",
        "country": "US"
    },
    "0000F2": {
        "oui_hex": "00-00-F2",
        "organization": "SPIDER COMMUNICATIONS",
        "address_1": "7491 BRIAR ROAD",
        "address_2": "",
        "country": "CA"
    },
    "0000CC": {
        "oui_hex": "00-00-CC",
        "organization": "DENSAN CO., LTD.",
        "address_1": "1-23-11, KAMITAKAIDO",
        "address_2": "",
        "country": "JP"
    },
    "0000A4": {
        "oui_hex": "00-00-A4",
        "organization": "ACORN COMPUTERS LIMITED",
        "address_1": "FULBOURN ROAD, CHERRY HINTON",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000DB": {
        "oui_hex": "00-00-DB",
        "organization": "British Telecommunications plc",
        "address_1": "81 New Gate St",
        "address_2": "    England",
        "country": "GB"
    },
    "0000C1": {
        "oui_hex": "00-00-C1",
        "organization": "Madge Ltd.",
        "address_1": "Madge House",
        "address_2": "Maindenhead  Berkshire  SL6 2HP",
        "country": "GB"
    },
    "0000F6": {
        "oui_hex": "00-00-F6",
        "organization": "APPLIED MICROSYSTEMS CORP.",
        "address_1": "5020 148 AVENUE, N.E.",
        "address_2": "REDMOND  WA  98073-9702",
        "country": "US"
    },
    "000077": {
        "oui_hex": "00-00-77",
        "organization": "INTERPHASE CORPORATION",
        "address_1": "13800 SENLAC",
        "address_2": "DALLAS  TX  75234",
        "country": "US"
    },
    "0000A2": {
        "oui_hex": "00-00-A2",
        "organization": "Bay Networks",
        "address_1": "PO Box 58185",
        "address_2": "Santa Clara  CA  95052-8185",
        "country": "US"
    },
    "0000EC": {
        "oui_hex": "00-00-EC",
        "organization": "MICROPROCESS",
        "address_1": "97 BIS, RUE DE COLOMBES",
        "address_2": "",
        "country": "FR"
    },
    "0000C2": {
        "oui_hex": "00-00-C2",
        "organization": "INFORMATION PRESENTATION TECH.",
        "address_1": "23801 CALABASAS ROAD",
        "address_2": "CALABASAS  CA  91302",
        "country": "US"
    },
    "0000FC": {
        "oui_hex": "00-00-FC",
        "organization": "MEIKO",
        "address_1": "650 AZTEC WEST",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00006D": {
        "oui_hex": "00-00-6D",
        "organization": "CRAY COMMUNICATIONS, LTD.",
        "address_1": "P.O. BOX 254, CAXTON WAY",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0000DA": {
        "oui_hex": "00-00-DA",
        "organization": "ATEX",
        "address_1": "15 CROSBY DRIVE",
        "address_2": "BEDFORD  MA  01730",
        "country": "US"
    },
    "0000DD": {
        "oui_hex": "00-00-DD",
        "organization": "TCL INCORPORATED",
        "address_1": "41829 ALBRAE STREET",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "0000AE": {
        "oui_hex": "00-00-AE",
        "organization": "DASSAULT ELECTRONIQUE",
        "address_1": "55, QUAI MARCEL DASSAULT",
        "address_2": "",
        "country": "FR"
    },
    "0000A0": {
        "oui_hex": "00-00-A0",
        "organization": "SANYO Electric Co., Ltd.",
        "address_1": "5-5, Keihan-hondori 2-chome,",
        "address_2": "Moriguchi City  Osaka  570-8677",
        "country": "JP"
    },
    "0000C0": {
        "oui_hex": "00-00-C0",
        "organization": "WESTERN DIGITAL CORPORATION",
        "address_1": "8105 IRVINE CENTER DRIVE",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "000033": {
        "oui_hex": "00-00-33",
        "organization": "EGAN MACHINERY COMPANY",
        "address_1": "SOUTH ADAMSVILLE ROAD",
        "address_2": "SOMMERVILLE  NJ  08876",
        "country": "US"
    },
    "00009D": {
        "oui_hex": "00-00-9D",
        "organization": "LOCUS COMPUTING CORPORATION",
        "address_1": "9800 LA CIENEGA",
        "address_2": "INGLEWOOD  CA  90301",
        "country": "US"
    },
    "0000FD": {
        "oui_hex": "00-00-FD",
        "organization": "HIGH LEVEL HARDWARE",
        "address_1": "PO BOX 170 WINDMILL ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "000065": {
        "oui_hex": "00-00-65",
        "organization": "Network General Corporation",
        "address_1": "178 E Tsaman Dr",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000011": {
        "oui_hex": "00-00-11",
        "organization": "NORMEREL SYSTEMES",
        "address_1": "58 RUE POTTIER",
        "address_2": "",
        "country": "FR"
    },
    "000010": {
        "oui_hex": "00-00-10",
        "organization": "SYTEK INC.",
        "address_1": "1225 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "0000BC": {
        "oui_hex": "00-00-BC",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "08007E": {
        "oui_hex": "08-00-7E",
        "organization": "AMALGAMATED WIRELESS(AUS) LTD",
        "address_1": "NORTH RYDE DIVISION",
        "address_2": "  AUSTRALIA  2113",
        "country": "AU"
    },
    "08007F": {
        "oui_hex": "08-00-7F",
        "organization": "CARNEGIE-MELLON UNIVERSITY",
        "address_1": "INFORMATION TECHNOLOGY",
        "address_2": "PITTSBURGE  PA  15213",
        "country": "US"
    },
    "000099": {
        "oui_hex": "00-00-99",
        "organization": "MTX, INC.",
        "address_1": "3301 TERMINAL DRIVE",
        "address_2": "RALEIGH  NC  27604",
        "country": "US"
    },
    "0000C4": {
        "oui_hex": "00-00-C4",
        "organization": "WATERS DIV. OF MILLIPORE",
        "address_1": "34 MAPLE STREET",
        "address_2": "MILFORD  MA  01757",
        "country": "US"
    },
    "0000EB": {
        "oui_hex": "00-00-EB",
        "organization": "MATSUSHITA COMM. IND. CO. LTD.",
        "address_1": "3-1  4-CHOME",
        "address_2": "",
        "country": "JP"
    },
    "000028": {
        "oui_hex": "00-00-28",
        "organization": "PRODIGY SYSTEMS CORPORATION",
        "address_1": "2601 CASEY DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "08003B": {
        "oui_hex": "08-00-3B",
        "organization": "TORUS SYSTEMS LIMITED",
        "address_1": "SCIENCE PARK",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "08003C": {
        "oui_hex": "08-00-3C",
        "organization": "SCHLUMBERGER WELL SERVICES",
        "address_1": "AUSTIN ENGINEERING SERVICES",
        "address_2": "AUSTIN  TX  78720-0015",
        "country": "US"
    },
    "080034": {
        "oui_hex": "08-00-34",
        "organization": "FILENET CORPORATION",
        "address_1": "1575 CORPORATE DRIVE",
        "address_2": "COSTA MESA  CA  92626",
        "country": "US"
    },
    "080036": {
        "oui_hex": "08-00-36",
        "organization": "INTERGRAPH CORPORATION",
        "address_1": "ONE MADISON INDUSTRIAL PARK",
        "address_2": "HUNTSVILLE  AL  35807",
        "country": "US"
    },
    "080033": {
        "oui_hex": "08-00-33",
        "organization": "BAUSCH & LOMB",
        "address_1": "INTERACTIVE GRAPHICS DIVISION",
        "address_2": "AUSITN  TX  78671",
        "country": "US"
    },
    "080048": {
        "oui_hex": "08-00-48",
        "organization": "EUROTHERM GAUGING SYSTEMS",
        "address_1": "900 MIDDLESEX TURNPIKE, BDG. 6",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "080043": {
        "oui_hex": "08-00-43",
        "organization": "PIXEL COMPUTER INC.",
        "address_1": "260 FORDHAM ROAD",
        "address_2": "WILMINGTON  MA  01887",
        "country": "US"
    },
    "080045": {
        "oui_hex": "08-00-45",
        "organization": "CONCURRENT COMPUTER CORP.",
        "address_1": "2 CRESCENT PLACE",
        "address_2": "OCEANPORT  NJ  07757",
        "country": "US"
    },
    "080078": {
        "oui_hex": "08-00-78",
        "organization": "ACCELL CORPORATION",
        "address_1": "50 SAGINAW DRIVE",
        "address_2": "ROCHESTER  NY  14623",
        "country": "US"
    },
    "08006D": {
        "oui_hex": "08-00-6D",
        "organization": "WHITECHAPEL COMPUTER WORKS",
        "address_1": "75 WHITECHAPEL ROAD",
        "address_2": "LONDON  E1  1DU",
        "country": "GB"
    },
    "080030": {
        "oui_hex": "08-00-30",
        "organization": "CERN",
        "address_1": "CH-1211",
        "address_2": "GENEVE  SUISSE/SWITZ  023",
        "country": "CH"
    },
    "080031": {
        "oui_hex": "08-00-31",
        "organization": "LITTLE MACHINES INC.",
        "address_1": "4141 JUTLAND DRIVE",
        "address_2": "SAN DIEGO  CA  92117",
        "country": "US"
    },
    "08002E": {
        "oui_hex": "08-00-2E",
        "organization": "METAPHOR COMPUTER SYSTEMS",
        "address_1": "2500 GARCIA AVENUE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "080056": {
        "oui_hex": "08-00-56",
        "organization": "STANFORD LINEAR ACCEL. CENTER",
        "address_1": "2575 SANDHILL ROAD",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "08004F": {
        "oui_hex": "08-00-4F",
        "organization": "CYGNET SYSTEMS",
        "address_1": "2560 JUNCTION AVENUE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "080050": {
        "oui_hex": "08-00-50",
        "organization": "DAISY SYSTEMS CORP.",
        "address_1": "139 KIFER COURT",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "08005E": {
        "oui_hex": "08-00-5E",
        "organization": "COUNTERPOINT COMPUTER INC.",
        "address_1": "2127 RINGWOOD AVENUE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "080076": {
        "oui_hex": "08-00-76",
        "organization": "PC LAN TECHNOLOGIES",
        "address_1": "5780 LINCOLN DRIVE SUITE 106",
        "address_2": "MINNEAPOLIS  MN  55436",
        "country": "US"
    },
    "080075": {
        "oui_hex": "08-00-75",
        "organization": "DANSK DATA ELECTRONIK",
        "address_1": "HERLEV HOVEDGADE 199",
        "address_2": "",
        "country": "DK"
    },
    "08002B": {
        "oui_hex": "08-00-2B",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "080029": {
        "oui_hex": "08-00-29",
        "organization": "Megatek Corporation",
        "address_1": "16868 Via Del Campo Court",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "0270B0": {
        "oui_hex": "02-70-B0",
        "organization": "M/A-COM INC. COMPANIES",
        "address_1": "11717 EXPLORATION LANE",
        "address_2": "GERMANTOWN  MD  20767",
        "country": "US"
    },
    "000053": {
        "oui_hex": "00-00-53",
        "organization": "COMPUCORP",
        "address_1": "2211 MICHIGAN AVENUE",
        "address_2": "SANTA MONICA  CA  90404",
        "country": "US"
    },
    "080090": {
        "oui_hex": "08-00-90",
        "organization": "SONOMA SYSTEMS",
        "address_1": "4640 ADMIRALTY WAY,  STE. #600",
        "address_2": "MARINA DEL REY  CA  90292-6695",
        "country": "US"
    },
    "08000A": {
        "oui_hex": "08-00-0A",
        "organization": "NESTAR SYSTEMS INCORPORATED",
        "address_1": "2585 EAST BAYSHORE ROAD",
        "address_2": "PALO ALTO  CA  94303",
        "country": "US"
    },
    "00800F": {
        "oui_hex": "00-80-0F",
        "organization": "STANDARD MICROSYSTEMS",
        "address_1": "300 KENNEDY DRIVE",
        "address_2": "HAUPPAUGE  NY  11788",
        "country": "US"
    },
    "00406B": {
        "oui_hex": "00-40-6B",
        "organization": "SYSGEN",
        "address_1": "556 GIBRALTAR DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "08000F": {
        "oui_hex": "08-00-0F",
        "organization": "MITEL CORPORATION",
        "address_1": "350 LEGGET DRIVE",
        "address_2": "CANADA  K2K  1X3",
        "country": "CA"
    },
    "080023": {
        "oui_hex": "08-00-23",
        "organization": "Panasonic Communications Co., Ltd.",
        "address_1": "4-1-62 Minoshima Hakata Fukuoka",
        "address_2": "    812-8531",
        "country": "JP"
    },
    "B04FC3": {
        "oui_hex": "B0-4F-C3",
        "organization": "Shenzhen NVC Cloud Technology Co., Ltd.",
        "address_1": "Rm. 1406, Bld. 11A, Shenzhen Bay Eco-Technology Park, Nanshan Dist.,",
        "address_2": "Shenzhen  Guangdong  518063",
        "country": "CN"
    },
    "08001C": {
        "oui_hex": "08-00-1C",
        "organization": "KDD-KOKUSAI DEBNSIN DENWA CO.",
        "address_1": "FUJI XEROX CO., LTD. TELEGRAPH",
        "address_2": "  107",
        "country": "JP"
    },
    "00DD0C": {
        "oui_hex": "00-DD-0C",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "080018": {
        "oui_hex": "08-00-18",
        "organization": "PIRELLI FOCOM NETWORKS",
        "address_1": "DENTON DRIVE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000A6": {
        "oui_hex": "00-00-A6",
        "organization": "NETWORK GENERAL CORPORATION",
        "address_1": "1296 B LAWRENCE STATION ROAD",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "00BBF0": {
        "oui_hex": "00-BB-F0",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00408E": {
        "oui_hex": "00-40-8E",
        "organization": "Tattile SRL",
        "address_1": "2360 MARYLAND ROAD",
        "address_2": "WILLOW GROVE  PA  19090",
        "country": "US"
    },
    "000004": {
        "oui_hex": "00-00-04",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "00DD0E": {
        "oui_hex": "00-DD-0E",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "88571D": {
        "oui_hex": "88-57-1D",
        "organization": "Seongji Industry Company",
        "address_1": " 54-33, Dongtanhana 1-gil",
        "address_2": "Hwaseong-si  Gyeonggi-do  18423",
        "country": "KR"
    },
    "7CF31B": {
        "oui_hex": "7C-F3-1B",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0001C8": {
        "oui_hex": "00-01-C8",
        "organization": "CONRAD CORP.",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "CCEF03": {
        "oui_hex": "CC-EF-03",
        "organization": "Hunan Keyshare Communication Technology Co., Ltd.",
        "address_1": "No. 19 Building, CEC Software Park, No. 39 jianshan Rd",
        "address_2": "Changsha  Hunan  410205",
        "country": "CN"
    },
    "102FA3": {
        "oui_hex": "10-2F-A3",
        "organization": "Shenzhen Uvision-tech Technology Co.Ltd",
        "address_1": "shenzhen longhua Street",
        "address_2": "shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "7048F7": {
        "oui_hex": "70-48-F7",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "18E1CA": {
        "oui_hex": "18-E1-CA",
        "organization": "wanze",
        "address_1": "wanjinglu",
        "address_2": "dandong  Liaoning  118000",
        "country": "CN"
    },
    "ECBEDD": {
        "oui_hex": "EC-BE-DD",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "00C0B6": {
        "oui_hex": "00-C0-B6",
        "organization": "HVE, Inc.",
        "address_1": "Suite 2, 100 Executive Court",
        "address_2": "Waxahachie  TX  75165",
        "country": "US"
    },
    "309176": {
        "oui_hex": "30-91-76",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78C881": {
        "oui_hex": "78-C8-81",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "D44F68": {
        "oui_hex": "D4-4F-68",
        "organization": "Eidetic Communications Inc",
        "address_1": "3553 31st NW",
        "address_2": "Calgary  Alberta  T2L2K7",
        "country": "CA"
    },
    "749EA5": {
        "oui_hex": "74-9E-A5",
        "organization": "OHSUNG",
        "address_1": "335-4,SANHODAERO,GUMI,GYEONG BUK,KOREA",
        "address_2": "GUMI  GYEONG BUK  730-030",
        "country": "KR"
    },
    "8CC84B": {
        "oui_hex": "8C-C8-4B",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0C2FB0": {
        "oui_hex": "0C-2F-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B40216": {
        "oui_hex": "B4-02-16",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "54A493": {
        "oui_hex": "54-A4-93",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "6C1C71": {
        "oui_hex": "6C-1C-71",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "CC6A10": {
        "oui_hex": "CC-6A-10",
        "organization": "The Chamberlain Group, Inc",
        "address_1": "300 Windsor Drive",
        "address_2": "Oak Brook  IL  60523",
        "country": "US"
    },
    "F03F95": {
        "oui_hex": "F0-3F-95",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "185644": {
        "oui_hex": "18-56-44",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9C69D1": {
        "oui_hex": "9C-69-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "185A58": {
        "oui_hex": "18-5A-58",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "C43A35": {
        "oui_hex": "C4-3A-35",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "04D16E": {
        "oui_hex": "04-D1-6E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "040E3C": {
        "oui_hex": "04-0E-3C",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "C4E0DE": {
        "oui_hex": "C4-E0-DE",
        "organization": "Zhengzhou XindaJiean Information Technology Co.,Ltd.",
        "address_1": "Tianli building A, wisdom park, no. 139, yangjin road, jinshui district",
        "address_2": "Zhengzhou  Henan  450003",
        "country": "CN"
    },
    "901A4F": {
        "oui_hex": "90-1A-4F",
        "organization": "EM Microelectronic",
        "address_1": "Rue des Sors 3",
        "address_2": "Marin-Epagnier  Neuchatel  2074",
        "country": "CH"
    },
    "C84F0E": {
        "oui_hex": "C8-4F-0E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "6CD2BA": {
        "oui_hex": "6C-D2-BA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "303ABA": {
        "oui_hex": "30-3A-BA",
        "organization": "Guangzhou BaoLun Electronics Co., Ltd",
        "address_1": "No.1 Building B Block, Zhongcun Street, Panyu District",
        "address_2": "Guangzhou  guangdong  511400",
        "country": "CN"
    },
    "D88ADC": {
        "oui_hex": "D8-8A-DC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "10E953": {
        "oui_hex": "10-E9-53",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "7C48B2": {
        "oui_hex": "7C-48-B2",
        "organization": "Vida Resources Lte Ltd",
        "address_1": "10 Anson road, unit #16-20 International Plaza",
        "address_2": "Singapore    079903",
        "country": "SG"
    },
    "2CAB33": {
        "oui_hex": "2C-AB-33",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B887C6": {
        "oui_hex": "B8-87-C6",
        "organization": "Prudential Technology co.,LTD",
        "address_1": "UNIT 4,7/F BRIGHT WAY TOWER, NO33 MONG KOK RD,",
        "address_2": "Hong Kong    999077",
        "country": "CN"
    },
    "EC9C32": {
        "oui_hex": "EC-9C-32",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "4CADA8": {
        "oui_hex": "4C-AD-A8",
        "organization": "PANOPTICS CORP.",
        "address_1": "D-908 Bundang Technopark, 700 Pangyoro, Bundang",
        "address_2": "Seongnam  Gyeonggi  13516",
        "country": "KR"
    },
    "FC1CA1": {
        "oui_hex": "FC-1C-A1",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "D42DC5": {
        "oui_hex": "D4-2D-C5",
        "organization": "Panasonic i-PRO Sensing Solutions Co., Ltd.",
        "address_1": "4-1-62 Minoshima, Hakata-ku",
        "address_2": "Fukuoka City     812-8531",
        "country": "JP"
    },
    "E8D03C": {
        "oui_hex": "E8-D0-3C",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "1C1ADF": {
        "oui_hex": "1C-1A-DF",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "D4F547": {
        "oui_hex": "D4-F5-47",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "981BB5": {
        "oui_hex": "98-1B-B5",
        "organization": "ASSA ABLOY Korea Co., Ltd iRevo",
        "address_1": "10F of JEI PLATZ Bldg., 186, Gasandigital-ro, Geumcheon-gu",
        "address_2": "Seoul    08502",
        "country": "KR"
    },
    "34CB1A": {
        "oui_hex": "34-CB-1A",
        "organization": "Procter & Gamble Company",
        "address_1": "2 Procter & Gamble Plaza",
        "address_2": "Cincinnati  OH  45202",
        "country": "US"
    },
    "F0B107": {
        "oui_hex": "F0-B1-07",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "784F9B": {
        "oui_hex": "78-4F-9B",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "783A6C": {
        "oui_hex": "78-3A-6C",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "E04007": {
        "oui_hex": "E0-40-07",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "383FB3": {
        "oui_hex": "38-3F-B3",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "70CE8C": {
        "oui_hex": "70-CE-8C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4070F5": {
        "oui_hex": "40-70-F5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B035B5": {
        "oui_hex": "B0-35-B5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90AFD1": {
        "oui_hex": "90-AF-D1",
        "organization": "netKTI Co., Ltd",
        "address_1": "7-10F THE-ONE SQUARE, 135, Unjung-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13461",
        "country": "KR"
    },
    "800C67": {
        "oui_hex": "80-0C-67",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90812A": {
        "oui_hex": "90-81-2A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7817BE": {
        "oui_hex": "78-17-BE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F072EA": {
        "oui_hex": "F0-72-EA",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "B87BC5": {
        "oui_hex": "B8-7B-C5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F05136": {
        "oui_hex": "F0-51-36",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "105932": {
        "oui_hex": "10-59-32",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "207454": {
        "oui_hex": "20-74-54",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "B8C9B5": {
        "oui_hex": "B8-C9-B5",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "88ACC0": {
        "oui_hex": "88-AC-C0",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "90FD73": {
        "oui_hex": "90-FD-73",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1C1E38": {
        "oui_hex": "1C-1E-38",
        "organization": "PCCW Global, Inc.",
        "address_1": "475 Spring Park Pl Suite 100 Herndon VA 20170",
        "address_2": "Herndon  WA  20170",
        "country": "US"
    },
    "3C410E": {
        "oui_hex": "3C-41-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "88D98F": {
        "oui_hex": "88-D9-8F",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0045E2": {
        "oui_hex": "00-45-E2",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "006967": {
        "oui_hex": "00-69-67",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F86FDE": {
        "oui_hex": "F8-6F-DE",
        "organization": "Shenzhen Goodix Technology Co.,Ltd.",
        "address_1": " F13,Phase B,Tengfei Industrial Building,Futian Free Trade Zone,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518045",
        "country": "CN"
    },
    "646624": {
        "oui_hex": "64-66-24",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "B0F530": {
        "oui_hex": "B0-F5-30",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "740AE1": {
        "oui_hex": "74-0A-E1",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B4A898": {
        "oui_hex": "B4-A8-98",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0CE4A0": {
        "oui_hex": "0C-E4-A0",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "BC1AE4": {
        "oui_hex": "BC-1A-E4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "043F72": {
        "oui_hex": "04-3F-72",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "1C4D66": {
        "oui_hex": "1C-4D-66",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "502CC6": {
        "oui_hex": "50-2C-C6",
        "organization": "GREE ELECTRIC APPLIANCES, INC. OF ZHUHAI",
        "address_1": "Jinji West Road, Qianshan,",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "F4FEFB": {
        "oui_hex": "F4-FE-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "984914": {
        "oui_hex": "98-49-14",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "0CEE99": {
        "oui_hex": "0C-EE-99",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "00117E": {
        "oui_hex": "00-11-7E",
        "organization": "Midmark Corp",
        "address_1": "1001 Asbury Dr",
        "address_2": "Buffalo Grove  IL  60089",
        "country": "US"
    },
    "D028BA": {
        "oui_hex": "D0-28-BA",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "A428B7": {
        "oui_hex": "A4-28-B7",
        "organization": "Yangtze Memory Technologies Co., Ltd.",
        "address_1": "No.88 Weilai 3rd Road, East Lake High-tech Development Zone, Wuhan, Hubei, POC",
        "address_2": "Wuhan  Hubei  430078",
        "country": "CN"
    },
    "9492D2": {
        "oui_hex": "94-92-D2",
        "organization": "KCF Technologies, Inc.",
        "address_1": "336 S Fraser Street",
        "address_2": "State College  PA  16801",
        "country": "US"
    },
    "E4A8DF": {
        "oui_hex": "E4-A8-DF",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "8C53C3": {
        "oui_hex": "8C-53-C3",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "702F35": {
        "oui_hex": "70-2F-35",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C014B8": {
        "oui_hex": "C0-14-B8",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "00763D": {
        "oui_hex": "00-76-3D",
        "organization": "Veea",
        "address_1": "164 E 83rd Street",
        "address_2": "New York  NY  10028",
        "country": "US"
    },
    "3093BC": {
        "oui_hex": "30-93-BC",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "FCF5C4": {
        "oui_hex": "FC-F5-C4",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "E826B6": {
        "oui_hex": "E8-26-B6",
        "organization": "Inside Biometrics International Limited",
        "address_1": "Strathpeffer Road",
        "address_2": "Dingwall  Scotland  IV159QF",
        "country": "GB"
    },
    "54CE69": {
        "oui_hex": "54-CE-69",
        "organization": "Hikari Trading Co.,Ltd.",
        "address_1": "Hikari Building,7-4-14,Ginza,Chuo-ku",
        "address_2": "Tokyo    104-0061",
        "country": "JP"
    },
    "6CC63B": {
        "oui_hex": "6C-C6-3B",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "588E81": {
        "oui_hex": "58-8E-81",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "48B02D": {
        "oui_hex": "48-B0-2D",
        "organization": "NVIDIA Corporation",
        "address_1": "2701 San Tomas Expressway",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "4CE176": {
        "oui_hex": "4C-E1-76",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6CAEF6": {
        "oui_hex": "6C-AE-F6",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "FC8E6E": {
        "oui_hex": "FC-8E-6E",
        "organization": "StreamCCTV, LLC",
        "address_1": "1129 Northern Blvd, STE. 404",
        "address_2": "Manhasset    11030",
        "country": "US"
    },
    "E02AE6": {
        "oui_hex": "E0-2A-E6",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "641236": {
        "oui_hex": "64-12-36",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "788B2A": {
        "oui_hex": "78-8B-2A",
        "organization": "Zhen Shi Information Technology (Shanghai) Co., Ltd.",
        "address_1": "5F, Building 3?No. 401 Caobao Road, Xuhui District, Shanghai, China",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "AC64CF": {
        "oui_hex": "AC-64-CF",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "F06728": {
        "oui_hex": "F0-67-28",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "BCD767": {
        "oui_hex": "BC-D7-67",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "9CE176": {
        "oui_hex": "9C-E1-76",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "102959": {
        "oui_hex": "10-29-59",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E47684": {
        "oui_hex": "E4-76-84",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B41A1D": {
        "oui_hex": "B4-1A-1D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F05CD5": {
        "oui_hex": "F0-5C-D5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CDA6D": {
        "oui_hex": "3C-DA-6D",
        "organization": "Tiandy Technologies CO.,LTD",
        "address_1": "NO.8,haitai huake rd2 (outside ring road),huayuan new technology industrial park",
        "address_2": "Tianjin  Tianjin  300384",
        "country": "CN"
    },
    "F80DF0": {
        "oui_hex": "F8-0D-F0",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "9CE91C": {
        "oui_hex": "9C-E9-1C",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5C17CF": {
        "oui_hex": "5C-17-CF",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A4FA76": {
        "oui_hex": "A4-FA-76",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "70EA5A": {
        "oui_hex": "70-EA-5A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CFAD3": {
        "oui_hex": "3C-FA-D3",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8C6078": {
        "oui_hex": "8C-60-78",
        "organization": "Swissbit AG",
        "address_1": "Industriestrasse 4",
        "address_2": "Bronschhofen    CH-9552",
        "country": "CH"
    },
    "00DD25": {
        "oui_hex": "00-DD-25",
        "organization": "Shenzhen hechengdong Technology Co., Ltd",
        "address_1": "302, floor 3, no.90-5, Dayang Road, Xintian community, Fuhai street, Bao'an District",
        "address_2": "Shenzhen  GuangDong  518100",
        "country": "CN"
    },
    "8020E1": {
        "oui_hex": "80-20-E1",
        "organization": "BVBA DPTechnics",
        "address_1": "Westkapellestraat 396/44",
        "address_2": "Knokke-Heist  West-Vlaanderen  8300",
        "country": "BE"
    },
    "0445A1": {
        "oui_hex": "04-45-A1",
        "organization": "NIRIT- Xinwei  Telecom Technology Co., Ltd.",
        "address_1": "2-? ??????????? ??????, ?.12, ???.2",
        "address_2": "Moscow    115432",
        "country": "RU"
    },
    "8C97EA": {
        "oui_hex": "8C-97-EA",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "30AB6A": {
        "oui_hex": "30-AB-6A",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "749BE8": {
        "oui_hex": "74-9B-E8",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "5CBAEF": {
        "oui_hex": "5C-BA-EF",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "4C6371": {
        "oui_hex": "4C-63-71",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "D84DB9": {
        "oui_hex": "D8-4D-B9",
        "organization": "Wu Qi Technologies,Inc.",
        "address_1": "14/F, 107 Middle Road, Xiantao Big Data Valley, Yubei District",
        "address_2": "Chongqing  Chongqing  401120",
        "country": "CN"
    },
    "A04F85": {
        "oui_hex": "A0-4F-85",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "D807B6": {
        "oui_hex": "D8-07-B6",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "646E97": {
        "oui_hex": "64-6E-97",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78507C": {
        "oui_hex": "78-50-7C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001258": {
        "oui_hex": "00-12-58",
        "organization": "TechVoIP Sp z o.o.",
        "address_1": "Os. Boleslawa Chrobrego 117",
        "address_2": "Poznan  Wielkopolska  60-681",
        "country": "PL"
    },
    "347839": {
        "oui_hex": "34-78-39",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "6C1632": {
        "oui_hex": "6C-16-32",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F419E2": {
        "oui_hex": "F4-19-E2",
        "organization": "Volterra",
        "address_1": "2550 Great America Way #350",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "4CA003": {
        "oui_hex": "4C-A0-03",
        "organization": "VITEC",
        "address_1": "99 rue Pierre Semard",
        "address_2": "Chatillon    92320",
        "country": "FR"
    },
    "2C1A01": {
        "oui_hex": "2C-1A-01",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "24169D": {
        "oui_hex": "24-16-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "64F2FB": {
        "oui_hex": "64-F2-FB",
        "organization": "Hangzhou Ezviz Software Co.,Ltd.",
        "address_1": "Room 302, Unit B, Building 2, 399 Danfeng Road,Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "30809B": {
        "oui_hex": "30-80-9B",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "7422BB": {
        "oui_hex": "74-22-BB",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "6C0D34": {
        "oui_hex": "6C-0D-34",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "4C4576": {
        "oui_hex": "4C-45-76",
        "organization": "China Mobile(Hangzhou) Information Technology Co.,Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "B440A4": {
        "oui_hex": "B4-40-A4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48B8A3": {
        "oui_hex": "48-B8-A3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC428C": {
        "oui_hex": "BC-42-8C",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "nishida  6-1",
        "address_2": "Kakuda-City  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "F07CC7": {
        "oui_hex": "F0-7C-C7",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F4DBE3": {
        "oui_hex": "F4-DB-E3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D45EEC": {
        "oui_hex": "D4-5E-EC",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "74C929": {
        "oui_hex": "74-C9-29",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "D4CFF9": {
        "oui_hex": "D4-CF-F9",
        "organization": "Shenzhen SEI Robotics Co.,Ltd",
        "address_1": "501,Productivity Building A, #5 Hi-Tech Middle 2nd Road",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5CB29E": {
        "oui_hex": "5C-B2-9E",
        "organization": "ASCO Power Technologies",
        "address_1": "160 Park Avenue",
        "address_2": "Florham Park  NJ  07932",
        "country": "US"
    },
    "9CC9EB": {
        "oui_hex": "9C-C9-EB",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "94CC04": {
        "oui_hex": "94-CC-04",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "90EC77": {
        "oui_hex": "90-EC-77",
        "organization": "silicom",
        "address_1": "14 Atir-Yeda St/",
        "address_2": "Kfar-Sava  Israel  44000",
        "country": "IL"
    },
    "88C397": {
        "oui_hex": "88-C3-97",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "F0F6C1": {
        "oui_hex": "F0-F6-C1",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "540384": {
        "oui_hex": "54-03-84",
        "organization": "Hongkong Nano IC Technologies Co., Ltd",
        "address_1": "Rm. 19C, Lockhart Ctr., 301-307 Lockhart Rd., Wan Chai, Hong Kong",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "CN"
    },
    "60684E": {
        "oui_hex": "60-68-4E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8020FD": {
        "oui_hex": "80-20-FD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B4CE40": {
        "oui_hex": "B4-CE-40",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "305075": {
        "oui_hex": "30-50-75",
        "organization": "GN Audio A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK-2750",
        "country": "DK"
    },
    "04BDBF": {
        "oui_hex": "04-BD-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC7ABF": {
        "oui_hex": "BC-7A-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2CC546": {
        "oui_hex": "2C-C5-46",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0C839A": {
        "oui_hex": "0C-83-9A",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "E0E0FC": {
        "oui_hex": "E0-E0-FC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "94E7EA": {
        "oui_hex": "94-E7-EA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94E4BA": {
        "oui_hex": "94-E4-BA",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "347146": {
        "oui_hex": "34-71-46",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F4B78D": {
        "oui_hex": "F4-B7-8D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A416E7": {
        "oui_hex": "A4-16-E7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B40931": {
        "oui_hex": "B4-09-31",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "30B9B0": {
        "oui_hex": "30-B9-B0",
        "organization": "Intracom Asia Co., Ltd",
        "address_1": "4F., No77, Sec. 1, Xintai 5th Rd., Xizhi Dist.",
        "address_2": "New Taipei City  Taiwan  221",
        "country": "TW"
    },
    "D4DACD": {
        "oui_hex": "D4-DA-CD",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "0C35FE": {
        "oui_hex": "0C-35-FE",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "8C83DF": {
        "oui_hex": "8C-83-DF",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "AC4B1E": {
        "oui_hex": "AC-4B-1E",
        "organization": "Integri-Sys.Com LLC",
        "address_1": "9130 South Dadeland Bvld. Suite 1509",
        "address_2": "Miami  FL  33156",
        "country": "US"
    },
    "4CB911": {
        "oui_hex": "4C-B9-11",
        "organization": "Raisecom Technology CO.,LTD",
        "address_1": "No. 11, East Area, No. 10 Block, East Xibeiwang Road",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "B0E4D5": {
        "oui_hex": "B0-E4-D5",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "6869CA": {
        "oui_hex": "68-69-CA",
        "organization": "Hitachi, Ltd.",
        "address_1": "27-18, Minami Oi 6-chome, Shinagawa-ku",
        "address_2": "Tokyo    140-8572",
        "country": "JP"
    },
    "AC4A56": {
        "oui_hex": "AC-4A-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4EAB5": {
        "oui_hex": "F4-EA-B5",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001977": {
        "oui_hex": "00-19-77",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "08EA44": {
        "oui_hex": "08-EA-44",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "B0B5C3": {
        "oui_hex": "B0-B5-C3",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "704A0E": {
        "oui_hex": "70-4A-0E",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "08306B": {
        "oui_hex": "08-30-6B",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00869C": {
        "oui_hex": "00-86-9C",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "40476A": {
        "oui_hex": "40-47-6A",
        "organization": "Astro Gaming",
        "address_1": "340 Bryant St., Suite 101",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "4CCE2D": {
        "oui_hex": "4C-CE-2D",
        "organization": "Danlaw Inc",
        "address_1": "23700 research Dr.",
        "address_2": "Farmington Hills  MI  48335",
        "country": "US"
    },
    "B87CF2": {
        "oui_hex": "B8-7C-F2",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "BC0F9A": {
        "oui_hex": "BC-0F-9A",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "30B237": {
        "oui_hex": "30-B2-37",
        "organization": "GD Midea Air-Conditioning Equipment Co.,Ltd.",
        "address_1": "Midea Global Innovation Center,Beijiao Town,Shunde",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "2462CE": {
        "oui_hex": "24-62-CE",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "BC5A56": {
        "oui_hex": "BC-5A-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C09BF4": {
        "oui_hex": "C0-9B-F4",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "7CEF61": {
        "oui_hex": "7C-EF-61",
        "organization": "STR Elektronik Josef Schlechtinger GmbH",
        "address_1": "Auf dem Ohl 9",
        "address_2": "Wenden    57482",
        "country": "DE"
    },
    "400589": {
        "oui_hex": "40-05-89",
        "organization": "T-Mobile, USA",
        "address_1": "3625 132nd Ave SE",
        "address_2": "BELLEVUE  WA  98006",
        "country": "US"
    },
    "70039F": {
        "oui_hex": "70-03-9F",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "64A965": {
        "oui_hex": "64-A9-65",
        "organization": "Linkflow Co., Ltd.",
        "address_1": "54, Nonhyeon-ro 2-gil, Gangnam-gu",
        "address_2": "Seoul    06313",
        "country": "KR"
    },
    "68E209": {
        "oui_hex": "68-E2-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "045FB9": {
        "oui_hex": "04-5F-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "882B94": {
        "oui_hex": "88-2B-94",
        "organization": "MADOKA SYSTEM Co.,Ltd.",
        "address_1": "2-105 Hanasakidai Moriyama-ku",
        "address_2": "Nagoya    463-0808",
        "country": "JP"
    },
    "F4308B": {
        "oui_hex": "F4-30-8B",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "DC6B12": {
        "oui_hex": "DC-6B-12",
        "organization": "worldcns inc.",
        "address_1": "174, Namjo-ro 1-gil, Jocheon-eup",
        "address_2": "Jeju-si  Jeju-do  63335",
        "country": "KR"
    },
    "7458F3": {
        "oui_hex": "74-58-F3",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "A0DE0F": {
        "oui_hex": "A0-DE-0F",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F487C5": {
        "oui_hex": "F4-87-C5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "98DF82": {
        "oui_hex": "98-DF-82",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "3CF652": {
        "oui_hex": "3C-F6-52",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "080088": {
        "oui_hex": "08-00-88",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00010F": {
        "oui_hex": "00-01-0F",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "08B055": {
        "oui_hex": "08-B0-55",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "CC4E24": {
        "oui_hex": "CC-4E-24",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00E052": {
        "oui_hex": "00-E0-52",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "08AA55": {
        "oui_hex": "08-AA-55",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "5C0FFB": {
        "oui_hex": "5C-0F-FB",
        "organization": "Amino Communications Ltd",
        "address_1": "1010 Cambourne Business Park",
        "address_2": "Cambourne  Cambs  CB23 6DP",
        "country": "GB"
    },
    "54219D": {
        "oui_hex": "54-21-9D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C88BE8": {
        "oui_hex": "C8-8B-E8",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "404028": {
        "oui_hex": "40-40-28",
        "organization": "ZIV",
        "address_1": "Polígono Parque Tecnológico, 210",
        "address_2": "ZAMUDIO  VIZCAYA  48170",
        "country": "ES"
    },
    "000631": {
        "oui_hex": "00-06-31",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "A80577": {
        "oui_hex": "A8-05-77",
        "organization": "Netlist, Inc.",
        "address_1": "175 Technology",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "F041C6": {
        "oui_hex": "F0-41-C6",
        "organization": "Heat Tech Company, Ltd.",
        "address_1": "221A, Tikhookeanskaya st.",
        "address_2": "Khabarovsk    680033",
        "country": "RU"
    },
    "E43A65": {
        "oui_hex": "E4-3A-65",
        "organization": "MofiNetwork Inc",
        "address_1": "11 Boynton Cir",
        "address_2": "Markham  Ontario  L6C 1A8",
        "country": "CA"
    },
    "D8714D": {
        "oui_hex": "D8-71-4D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0CEC80": {
        "oui_hex": "0C-EC-80",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0015D2": {
        "oui_hex": "00-15-D2",
        "organization": "Xantech Corporation",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "001F40": {
        "oui_hex": "00-1F-40",
        "organization": "Speakercraft Inc.",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "C49886": {
        "oui_hex": "C4-98-86",
        "organization": "Qorvo Utrecht B.V.",
        "address_1": "Leidseveer 10",
        "address_2": "Utrecht  Utrecht  3511SB",
        "country": "NL"
    },
    "F86C03": {
        "oui_hex": "F8-6C-03",
        "organization": "Shenzhen Teleone Technology Co., Ltd",
        "address_1": "TOWER B 5/F, SHANSHUI BUILDING, NANSHAN YUNGU INNOVATION INDUSTRY PARK, 1183 LIUXIAN AVENUE, NANSHAN, SHENZHEN, CHINA",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "CC9ECA": {
        "oui_hex": "CC-9E-CA",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo  Espoo  02600",
        "country": "FI"
    },
    "3C306F": {
        "oui_hex": "3C-30-6F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "80E1BF": {
        "oui_hex": "80-E1-BF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "482CD0": {
        "oui_hex": "48-2C-D0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "DC7385": {
        "oui_hex": "DC-73-85",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "5455D5": {
        "oui_hex": "54-55-D5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "184593": {
        "oui_hex": "18-45-93",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "105DDC": {
        "oui_hex": "10-5D-DC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "34EAE7": {
        "oui_hex": "34-EA-E7",
        "organization": "Shanghai High-Flying Electronics  Technology Co., Ltd",
        "address_1": "Room 1002,#1Building,No.3000 Longdong Avenue,Pudong",
        "address_2": "Shanghai  Shanghai  201202",
        "country": "CN"
    },
    "D4ABCD": {
        "oui_hex": "D4-AB-CD",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "A0CAA5": {
        "oui_hex": "A0-CA-A5",
        "organization": "INTELLIGENCE TECHNOLOGY OF CEC CO., LTD",
        "address_1": "Tower A, NO.2 Lutuan Road, The sountern Of Future Science and Tech Zone, Changping District",
        "address_2": "Beijing  Beijing  102209",
        "country": "CN"
    },
    "58FDB1": {
        "oui_hex": "58-FD-B1",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "E8854B": {
        "oui_hex": "E8-85-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E02B96": {
        "oui_hex": "E0-2B-96",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28EC95": {
        "oui_hex": "28-EC-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001932": {
        "oui_hex": "00-19-32",
        "organization": "Gude Systems GmbH",
        "address_1": "Von-der-Wettern-Str. 23",
        "address_2": "Cologne  NRW  51149",
        "country": "DE"
    },
    "D0ABD5": {
        "oui_hex": "D0-AB-D5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "681729": {
        "oui_hex": "68-17-29",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B808CF": {
        "oui_hex": "B8-08-CF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DC7196": {
        "oui_hex": "DC-71-96",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "50E085": {
        "oui_hex": "50-E0-85",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1C1BB5": {
        "oui_hex": "1C-1B-B5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "983B8F": {
        "oui_hex": "98-3B-8F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D0C637": {
        "oui_hex": "D0-C6-37",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "04EA56": {
        "oui_hex": "04-EA-56",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D43B04": {
        "oui_hex": "D4-3B-04",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5C5F67": {
        "oui_hex": "5C-5F-67",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0C5415": {
        "oui_hex": "0C-54-15",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "302432": {
        "oui_hex": "30-24-32",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DC8B28": {
        "oui_hex": "DC-8B-28",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D83BBF": {
        "oui_hex": "D8-3B-BF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "14F6D8": {
        "oui_hex": "14-F6-D8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E0D4E8": {
        "oui_hex": "E0-D4-E8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F83441": {
        "oui_hex": "F8-34-41",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E470B8": {
        "oui_hex": "E4-70-B8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "94E6F7": {
        "oui_hex": "94-E6-F7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4C1D96": {
        "oui_hex": "4C-1D-96",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E00EE4": {
        "oui_hex": "E0-0E-E4",
        "organization": "DWnet Technologies(Suzhou) Corporation",
        "address_1": "No.8,Tangzhuang Road, Suzhou Industrial Park, Jiangsu, China",
        "address_2": "Suzhou    21500",
        "country": "CN"
    },
    "A8469D": {
        "oui_hex": "A8-46-9D",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco    94158",
        "country": "US"
    },
    "6CDEA9": {
        "oui_hex": "6C-DE-A9",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco    94158",
        "country": "US"
    },
    "703AA6": {
        "oui_hex": "70-3A-A6",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "8CCEFD": {
        "oui_hex": "8C-CE-FD",
        "organization": "Shenzhen zhouhai technology co.,LTD",
        "address_1": "401-403,415-416, Area A, Block B, West Silicon Valley, 5010 Baoan Avenue, Baoan District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "50FB19": {
        "oui_hex": "50-FB-19",
        "organization": "CHIPSEA TECHNOLOGIES (SHENZHEN) CORP.",
        "address_1": "9F,BLOCK A,GARDEN CITY DIGITAL BUILDING,NO.1079 NANHAI ROAD,NANSHAN DISTRICT",
        "address_2": "SHEN ZHEN  GUANG DONG  518000",
        "country": "CN"
    },
    "9408C7": {
        "oui_hex": "94-08-C7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "046C59": {
        "oui_hex": "04-6C-59",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "386893": {
        "oui_hex": "38-68-93",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "903FEA": {
        "oui_hex": "90-3F-EA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "20AB48": {
        "oui_hex": "20-AB-48",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CCD73C": {
        "oui_hex": "CC-D7-3C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C8CA63": {
        "oui_hex": "C8-CA-63",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "9437F7": {
        "oui_hex": "94-37-F7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "94E70B": {
        "oui_hex": "94-E7-0B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001EE0": {
        "oui_hex": "00-1E-E0",
        "organization": "Urmet SpA",
        "address_1": "Via Bologna 188/C",
        "address_2": "Torino  TO  I-10154",
        "country": "IT"
    },
    "98B8BC": {
        "oui_hex": "98-B8-BC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "184E16": {
        "oui_hex": "18-4E-16",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C03D03": {
        "oui_hex": "C0-3D-03",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A497B1": {
        "oui_hex": "A4-97-B1",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "BCA993": {
        "oui_hex": "BC-A9-93",
        "organization": "Cambium Networks Limited",
        "address_1": "Unit B2, Linhay Business Park,",
        "address_2": "Ashburton  Devon  TQ13 7UP",
        "country": "GB"
    },
    "D440D0": {
        "oui_hex": "D4-40-D0",
        "organization": "OCOSMOS Co., LTD",
        "address_1": "(Tamnip-Dong) #1, 263-1 Techno 2-Ro Yuseong-Gu",
        "address_2": "Daejeon  Daejeon  34026",
        "country": "KR"
    },
    "10746F": {
        "oui_hex": "10-74-6F",
        "organization": "MOTOROLA SOLUTIONS MALAYSIA SDN. BHD.",
        "address_1": "INNOPLEX, NO. 2A, MEDAN BAYAN LEPAS, BAYAN LEPAS TECHNOPLEX",
        "address_2": "BAYAN LEPAS  PENANG  11900",
        "country": "MY"
    },
    "DCD9AE": {
        "oui_hex": "DC-D9-AE",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai",
        "address_2": "Shanghai     201206",
        "country": "CN"
    },
    "1C08C1": {
        "oui_hex": "1C-08-C1",
        "organization": "LG Innotek",
        "address_1": "978-1 Jangduk dong, Gwangsangu",
        "address_2": "Gwangju  Gwangju  506-731",
        "country": "KR"
    },
    "44E6B0": {
        "oui_hex": "44-E6-B0",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "747A90": {
        "oui_hex": "74-7A-90",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "24E9CA": {
        "oui_hex": "24-E9-CA",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "14007D": {
        "oui_hex": "14-00-7D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "94AEF0": {
        "oui_hex": "94-AE-F0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00927D": {
        "oui_hex": "00-92-7D",
        "organization": "Ficosa Internationa(Taicang) C0.,Ltd.",
        "address_1": "No.518, Middle Suzhou Rd., Taicang Economy Developing Area,  Taicang,",
        "address_2": "Suzhou  Jiangsu  215400",
        "country": "CN"
    },
    "441622": {
        "oui_hex": "44-16-22",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "FC73FB": {
        "oui_hex": "FC-73-FB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "34873D": {
        "oui_hex": "34-87-3D",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "RM501,Building 13,No.99 TianZhou Road,Xuhui District,Shanghai,China",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "9CF61A": {
        "oui_hex": "9C-F6-1A",
        "organization": "Carrier Fire & Security",
        "address_1": "Kelvinstraat 7",
        "address_2": "DH Weert    6003",
        "country": "NL"
    },
    "044562": {
        "oui_hex": "04-45-62",
        "organization": "ANDRA Sp. z o. o.",
        "address_1": "Pryzmaty 6/8",
        "address_2": "Warszawa    02-226",
        "country": "PL"
    },
    "58B623": {
        "oui_hex": "58-B6-23",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "Xiaomi Campus, No. 33 Xi erqi Middle Road, Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "A022DE": {
        "oui_hex": "A0-22-DE",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "74F7F6": {
        "oui_hex": "74-F7-F6",
        "organization": "Shanghai Sunmi Technology Co.,Ltd.",
        "address_1": "Room 505, KIC Plaza, No.388 Song Hu Road, Yang Pu District, Shanghai, China",
        "address_2": "Shanghai  Yang Pu District  200433",
        "country": "CN"
    },
    "00269E": {
        "oui_hex": "00-26-9E",
        "organization": "Quanta Computer Inc.",
        "address_1": "NO. 211, WEN HWA 2RD., KUEI SHAN HSIANG, TAIPEI, SHIEN",
        "address_2": "TAO YUAN    333",
        "country": "TW"
    },
    "C45444": {
        "oui_hex": "C4-54-44",
        "organization": "Quanta Computer Inc.",
        "address_1": "No.211, Wen Hwa 2nd Rd., Kuei Shan Hsiang, Tao Yuan Shien, Taiwan, R. O. C.",
        "address_2": "Taoyuan  Taiwan  33377",
        "country": "TW"
    },
    "00C09F": {
        "oui_hex": "00-C0-9F",
        "organization": "Quanta Computer Inc.",
        "address_1": "7F., 116, HOU-KANG ST.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "001B24": {
        "oui_hex": "00-1B-24",
        "organization": "Quanta Computer Inc.",
        "address_1": "No. 211, Wen Hwa 2nd Rd.,",
        "address_2": "Kuei Shan Hsiang  Tao Yuan Shien  333",
        "country": "TW"
    },
    "C80AA9": {
        "oui_hex": "C8-0A-A9",
        "organization": "Quanta Computer Inc.",
        "address_1": "211, Wen Hwa 2nd Rd.,",
        "address_2": "Tao Yuan  Kuei Shan  33377",
        "country": "TW"
    },
    "60EB69": {
        "oui_hex": "60-EB-69",
        "organization": "Quanta Computer Inc.",
        "address_1": "211, Wen Hwa 2nd Rd.,Kuei Shan,",
        "address_2": "Tao Yuan    33377",
        "country": "TW"
    },
    "C0CC42": {
        "oui_hex": "C0-CC-42",
        "organization": "Sichuan Tianyi Comheart Telecom Co., Ltd.",
        "address_1": "No.198,First Section,Snow Mountain Avenue, Jinyuan Town, Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "CN"
    },
    "C08F20": {
        "oui_hex": "C0-8F-20",
        "organization": "Shenzhen Skyworth  Digital  Technology  CO., Ltd",
        "address_1": "4F,Block A, Skyworth?Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "241AE6": {
        "oui_hex": "24-1A-E6",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "60B76E": {
        "oui_hex": "60-B7-6E",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "1C5D80": {
        "oui_hex": "1C-5D-80",
        "organization": "Mitubishi Hitachi Power Systems Industries Co., Ltd.",
        "address_1": "Nakaku Aioimachi",
        "address_2": "Yokohama    2310012",
        "country": "JP"
    },
    "B42330": {
        "oui_hex": "B4-23-30",
        "organization": "Itron Inc",
        "address_1": "2111 N Molter Rd",
        "address_2": "Liberty Lake  WA  99019",
        "country": "US"
    },
    "084EBF": {
        "oui_hex": "08-4E-BF",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "3C9C0F": {
        "oui_hex": "3C-9C-0F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "08FBEA": {
        "oui_hex": "08-FB-EA",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "A802DB": {
        "oui_hex": "A8-02-DB",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "801605": {
        "oui_hex": "80-16-05",
        "organization": "Vodafone Italia S.p.A.",
        "address_1": "Via Lorenteggio nr. 240",
        "address_2": "Milan  Italy  20147",
        "country": "IT"
    },
    "5865E6": {
        "oui_hex": "58-65-E6",
        "organization": "infomark",
        "address_1": "#801, KINS TOWER, JEONGJA-DONG",
        "address_2": "SEONGNAM  GYOUNGGI  463-847",
        "country": "KR"
    },
    "0050F1": {
        "oui_hex": "00-50-F1",
        "organization": "Maxlinear, Inc",
        "address_1": "94 Em-Hamoshavot Way.",
        "address_2": "Petach-Tikva",
        "country": "IL"
    },
    "340F66": {
        "oui_hex": "34-0F-66",
        "organization": "Web Sensing LLC",
        "address_1": "P.O. Box 692",
        "address_2": "Hanover  NH  03755",
        "country": "US"
    },
    "5C443E": {
        "oui_hex": "5C-44-3E",
        "organization": "Skullcandy",
        "address_1": "6301 N. Landmark Dr.",
        "address_2": "Park City  UT  84098",
        "country": "US"
    },
    "F88200": {
        "oui_hex": "F8-82-00",
        "organization": "CaptionCall",
        "address_1": "4215 Riverboat Road",
        "address_2": "Salt Lake City  UT  84123",
        "country": "US"
    },
    "9CFFC2": {
        "oui_hex": "9C-FF-C2",
        "organization": "AVI Systems GmbH",
        "address_1": "Dr. Franz Wilhelmstraße 2A",
        "address_2": "Krems a. d. Donau    3500",
        "country": "AT"
    },
    "44D878": {
        "oui_hex": "44-D8-78",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "A0D807": {
        "oui_hex": "A0-D8-07",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "2C780E": {
        "oui_hex": "2C-78-0E",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "34B20A": {
        "oui_hex": "34-B2-0A",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "98F4AB": {
        "oui_hex": "98-F4-AB",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "D8BFC0": {
        "oui_hex": "D8-BF-C0",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "202681": {
        "oui_hex": "20-26-81",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "F4D620": {
        "oui_hex": "F4-D6-20",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "64FB92": {
        "oui_hex": "64-FB-92",
        "organization": "PPC Broadband Inc.",
        "address_1": "6176 E Molloy Rd",
        "address_2": "East Syracuse  NY  13057",
        "country": "US"
    },
    "141346": {
        "oui_hex": "14-13-46",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "949034": {
        "oui_hex": "94-90-34",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "987A10": {
        "oui_hex": "98-7A-10",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "542BDE": {
        "oui_hex": "54-2B-DE",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "98F781": {
        "oui_hex": "98-F7-81",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "7897C3": {
        "oui_hex": "78-97-C3",
        "organization": "DINGXIN INFORMATION TECHNOLOGY CO.,LTD",
        "address_1": "No.6 huasui Road,ZhuJiang Xincheng",
        "address_2": "Guangzhou  Guangdong  510623",
        "country": "CN"
    },
    "4C90DB": {
        "oui_hex": "4C-90-DB",
        "organization": "JL Audio",
        "address_1": "10369 N Commerce Pkwy",
        "address_2": "Mirimar  FL  33025",
        "country": "US"
    },
    "B899AE": {
        "oui_hex": "B8-99-AE",
        "organization": "Shenzhen MiaoMing  Intelligent Technology Co.,Ltd",
        "address_1": "Chudong science and technology park, 111 shaxin road, tangxia town,",
        "address_2": "dongguan city  guangdong province  523710",
        "country": "CN"
    },
    "E8D0B9": {
        "oui_hex": "E8-D0-B9",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "3C8F06": {
        "oui_hex": "3C-8F-06",
        "organization": "Shenzhen Libtor Technology Co.,Ltd",
        "address_1": "Room 608, Building A",
        "address_2": "Shenzhen City  Guangdong Province  518000",
        "country": "CN"
    },
    "B00875": {
        "oui_hex": "B0-08-75",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8CF112": {
        "oui_hex": "8C-F1-12",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "847637": {
        "oui_hex": "84-76-37",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "FC9435": {
        "oui_hex": "FC-94-35",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E02481": {
        "oui_hex": "E0-24-81",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8C0EA": {
        "oui_hex": "A8-C0-EA",
        "organization": "Pepwave Limited",
        "address_1": "A5, 5/F, HK Spinners Industrial Building, Phase 6, 481 Castle Peak Road",
        "address_2": "Cheung Sha Wan  Hong Kong  0",
        "country": "HK"
    },
    "182AD3": {
        "oui_hex": "18-2A-D3",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "80B07B": {
        "oui_hex": "80-B0-7B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C85A9F": {
        "oui_hex": "C8-5A-9F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "44AEAB": {
        "oui_hex": "44-AE-AB",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "A4F05E": {
        "oui_hex": "A4-F0-5E",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "1C687E": {
        "oui_hex": "1C-68-7E",
        "organization": "Shenzhen Qihu Intelligent Technology Company Limited",
        "address_1": "Room 201, Block A, No.1, Qianwan Road 1,Qianhai Shenzhen HongKong Modern Service Industry Cooperation Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C03656": {
        "oui_hex": "C0-36-56",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "5885A2": {
        "oui_hex": "58-85-A2",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "2CF89B": {
        "oui_hex": "2C-F8-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00071C": {
        "oui_hex": "00-07-1C",
        "organization": "AT&T",
        "address_1": "3300 E Renner Road",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "E0E8E6": {
        "oui_hex": "E0-E8-E6",
        "organization": "Shenzhen C-Data Technology Co., Ltd.",
        "address_1": "#601, Fl6, Bldg F, No.1008  Yangguang Community, Xili, Nanshan",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "500291": {
        "oui_hex": "50-02-91",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "001DDF": {
        "oui_hex": "00-1D-DF",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F., No. 98-1, Mincyuan Rd.",
        "address_2": "Sindian City  Taipei County  231",
        "country": "TW"
    },
    "8C0FFA": {
        "oui_hex": "8C-0F-FA",
        "organization": "Hutec co.,ltd",
        "address_1": "46, Gunpocheomdansaneop 2-ro",
        "address_2": "Gunpo-si  Gyeonggi-do  15880",
        "country": "KR"
    },
    "ACFE05": {
        "oui_hex": "AC-FE-05",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "782A79": {
        "oui_hex": "78-2A-79",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "786559": {
        "oui_hex": "78-65-59",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "50D2F5": {
        "oui_hex": "50-D2-F5",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "24526A": {
        "oui_hex": "24-52-6A",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "20DFB9": {
        "oui_hex": "20-DF-B9",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "5CCAD3": {
        "oui_hex": "5C-CA-D3",
        "organization": "CHIPSEA TECHNOLOGIES (SHENZHEN) CORP.",
        "address_1": "9F,BLOCK A,GARDEN CITY DIGITAL BUILDING,NO.1079 NANHAI ROAD,NANSHAN DISTRICT",
        "address_2": "SHEN ZHEN  GUANG DONG  518000",
        "country": "CN"
    },
    "28167F": {
        "oui_hex": "28-16-7F",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "B03E51": {
        "oui_hex": "B0-3E-51",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "5CE883": {
        "oui_hex": "5C-E8-83",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "100177": {
        "oui_hex": "10-01-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "44A191": {
        "oui_hex": "44-A1-91",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "6023A4": {
        "oui_hex": "60-23-A4",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "A4530E": {
        "oui_hex": "A4-53-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00403A": {
        "oui_hex": "00-40-3A",
        "organization": "IMPACT TECHNOLOGIES",
        "address_1": "6 RUE DE L'ACADIE",
        "address_2": "",
        "country": "FR"
    },
    "F887F1": {
        "oui_hex": "F8-87-F1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C28BF": {
        "oui_hex": "9C-28-BF",
        "organization": "Continental Automotive Czech Republic s.r.o.",
        "address_1": "Průmyslová 1851",
        "address_2": "Brandýs nad Labem    250 01",
        "country": "CZ"
    },
    "807215": {
        "oui_hex": "80-72-15",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "74D637": {
        "oui_hex": "74-D6-37",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "D05F64": {
        "oui_hex": "D0-5F-64",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "BCC31B": {
        "oui_hex": "BC-C3-1B",
        "organization": "Kygo Life A",
        "address_1": "Sjolyst Plass 3",
        "address_2": "Oslo    0278",
        "country": "NO"
    },
    "64DF10": {
        "oui_hex": "64-DF-10",
        "organization": "JingLue Semiconductor(SH) Ltd.",
        "address_1": "No.800 Naxian Rd",
        "address_2": "Shanghai    201210",
        "country": "CN"
    },
    "C463FB": {
        "oui_hex": "C4-63-FB",
        "organization": "Neatframe AS",
        "address_1": "Martin Linges Vei 25",
        "address_2": "Fornebu  Fornebu  1364",
        "country": "NO"
    },
    "0C8126": {
        "oui_hex": "0C-81-26",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "305714": {
        "oui_hex": "30-57-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60447A": {
        "oui_hex": "60-44-7A",
        "organization": "Water-i.d. GmbH",
        "address_1": "Daimlerstr. 20",
        "address_2": "Eggenstein    76344",
        "country": "DE"
    },
    "C8B1CD": {
        "oui_hex": "C8-B1-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1460CB": {
        "oui_hex": "14-60-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8F12A": {
        "oui_hex": "B8-F1-2A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04AB6A": {
        "oui_hex": "04-AB-6A",
        "organization": "Chun-il Co.,Ltd.",
        "address_1": "13-7, Gimhae-daero 2694 beon-gil,",
        "address_2": "Gimhae-si  Gyeongsangnam-do  50936",
        "country": "KR"
    },
    "544E45": {
        "oui_hex": "54-4E-45",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "04C807": {
        "oui_hex": "04-C8-07",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "04A222": {
        "oui_hex": "04-A2-22",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "489BD5": {
        "oui_hex": "48-9B-D5",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "3C8C93": {
        "oui_hex": "3C-8C-93",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "28FE65": {
        "oui_hex": "28-FE-65",
        "organization": "DongGuan Siyoto Electronics Co., Ltd",
        "address_1": "Hecheng Industrial District, QiaoTou Town",
        "address_2": "DongGuan City  Guangdong  523520",
        "country": "CN"
    },
    "1806F5": {
        "oui_hex": "18-06-F5",
        "organization": "RAD Data Communications, Ltd.",
        "address_1": "24 Raoul Wallenberg St.",
        "address_2": "Tel Aviv    69719",
        "country": "IL"
    },
    "7484E1": {
        "oui_hex": "74-84-E1",
        "organization": "Dongguan Haoyuan Electronics Co.,Ltd",
        "address_1": "NO.161 Kejizhong RoadLiuwu Shijie Town",
        "address_2": "Dongguan  Guangdong  523290",
        "country": "CN"
    },
    "44FB5A": {
        "oui_hex": "44-FB-5A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4459E3": {
        "oui_hex": "44-59-E3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "DC54D7": {
        "oui_hex": "DC-54-D7",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "44D3CA": {
        "oui_hex": "44-D3-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "889FAA": {
        "oui_hex": "88-9F-AA",
        "organization": "Hella Gutmann Solutions GmbH",
        "address_1": "Am Krebsbach 2",
        "address_2": "Ihringen   Baden Württemberg  79241",
        "country": "DE"
    },
    "E454E8": {
        "oui_hex": "E4-54-E8",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "20968A": {
        "oui_hex": "20-96-8A",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "8C1850": {
        "oui_hex": "8C-18-50",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Hangzhou  310000",
        "country": "CN"
    },
    "D8D4E6": {
        "oui_hex": "D8-D4-E6",
        "organization": "Hytec Inter Co., Ltd.",
        "address_1": "3-28-6 Yoyogi",
        "address_2": "Shibuya-ku  Tokyo  1510053",
        "country": "JP"
    },
    "683F1E": {
        "oui_hex": "68-3F-1E",
        "organization": "EFFECT Photonics B.V.",
        "address_1": "Kastanjelaan 400",
        "address_2": "Eindhoven  Noord-Brabant  5616 LZ",
        "country": "NL"
    },
    "0035FF": {
        "oui_hex": "00-35-FF",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F8E7A0": {
        "oui_hex": "F8-E7-A0",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "2CFFEE": {
        "oui_hex": "2C-FF-EE",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "840B7C": {
        "oui_hex": "84-0B-7C",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "48A73C": {
        "oui_hex": "48-A7-3C",
        "organization": "Sichuan tianyi kanghe communications co., LTD",
        "address_1": "No.198, section 1, xueshan avenue, jinyuan town, dayi county",
        "address_2": "chengdu  sichuan  611330",
        "country": "CN"
    },
    "C85D38": {
        "oui_hex": "C8-5D-38",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "F8A763": {
        "oui_hex": "F8-A7-63",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "A49813": {
        "oui_hex": "A4-98-13",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6C2990": {
        "oui_hex": "6C-29-90",
        "organization": "WiZ Connected Lighting Company Limited",
        "address_1": "Room 3805, 148 Electric Road",
        "address_2": "Hong Kong  0000  0000",
        "country": "HK"
    },
    "9835ED": {
        "oui_hex": "98-35-ED",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "084F0A": {
        "oui_hex": "08-4F-0A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8494D": {
        "oui_hex": "A8-49-4D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "44004D": {
        "oui_hex": "44-00-4D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "18CF24": {
        "oui_hex": "18-CF-24",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D89B3B": {
        "oui_hex": "D8-9B-3B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "88403B": {
        "oui_hex": "88-40-3B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "FC8743": {
        "oui_hex": "FC-87-43",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "807693": {
        "oui_hex": "80-76-93",
        "organization": "Newag SA",
        "address_1": "Wyspianskiego 3",
        "address_2": "Nowy Sacz  woj. Malopolskie  33-300",
        "country": "PL"
    },
    "BC9740": {
        "oui_hex": "BC-97-40",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "04885F": {
        "oui_hex": "04-88-5F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "C850CE": {
        "oui_hex": "C8-50-CE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "50F8A5": {
        "oui_hex": "50-F8-A5",
        "organization": "eWBM Co., Ltd.",
        "address_1": "14F, 9, Teheran-ro 20-gil",
        "address_2": "Gangnam-gu, Seoul    06236",
        "country": "KR"
    },
    "1449BC": {
        "oui_hex": "14-49-BC",
        "organization": "DrayTek Corp.",
        "address_1": "No. 26, Fushing Rd., Hukou, Hsinchu Industrial Park,",
        "address_2": "Hsinchu county    30352",
        "country": "TW"
    },
    "20F478": {
        "oui_hex": "20-F4-78",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "90735A": {
        "oui_hex": "90-73-5A",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "1C8259": {
        "oui_hex": "1C-82-59",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0004DF": {
        "oui_hex": "00-04-DF",
        "organization": "TERACOM TELEMATICA S.A",
        "address_1": "RUA AMERICA N.1000",
        "address_2": "Eldorado do Sul - RS    Brazil",
        "country": "BR"
    },
    "7438B7": {
        "oui_hex": "74-38-B7",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "8C04BA": {
        "oui_hex": "8C-04-BA",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00FA21": {
        "oui_hex": "00-FA-21",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C2302": {
        "oui_hex": "7C-23-02",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "18B6F7": {
        "oui_hex": "18-B6-F7",
        "organization": "NEW POS TECHNOLOGY LIMITED",
        "address_1": "AB Unit, 14th Floor,Block A, Financial Technology Building.No. 11 Keyuan Rd",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "5CB15F": {
        "oui_hex": "5C-B1-5F",
        "organization": "Oceanblue Cloud Technology Limited",
        "address_1": "253-261 Hennessy Road",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "18AACA": {
        "oui_hex": "18-AA-CA",
        "organization": "Sichuan tianyi kanghe communications co., LTD",
        "address_1": "No.198, section 1, xueshan avenue, jinyuan town, dayi county, sichuan province",
        "address_2": "chengdu  sichuan  611330",
        "country": "CN"
    },
    "D49DC0": {
        "oui_hex": "D4-9D-C0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "D0196A": {
        "oui_hex": "D0-19-6A",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "4413D0": {
        "oui_hex": "44-13-D0",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "2462AB": {
        "oui_hex": "24-62-AB",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "88B436": {
        "oui_hex": "88-B4-36",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "6CAB05": {
        "oui_hex": "6C-AB-05",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BE4": {
        "oui_hex": "00-0B-E4",
        "organization": "Hosiden Corporation",
        "address_1": "4-33",
        "address_2": "Yao-city  Osaka  581-0071",
        "country": "JP"
    },
    "60D248": {
        "oui_hex": "60-D2-48",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "485DEB": {
        "oui_hex": "48-5D-EB",
        "organization": "Just Add Power",
        "address_1": "12505 STARKEY RD STE A",
        "address_2": "LARGO  FL  33773",
        "country": "US"
    },
    "501395": {
        "oui_hex": "50-13-95",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "18D9EF": {
        "oui_hex": "18-D9-EF",
        "organization": "Shuttle Inc.",
        "address_1": "No. 30 Lane 76, Rei Kuang Rd",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "88DA33": {
        "oui_hex": "88-DA-33",
        "organization": "Beijing Xiaoyuer Network Technology Co., Ltd",
        "address_1": "Block K1, North American International Business Centre, 86 Beiyuan Road, Chaoyang District",
        "address_2": "Beijing  Beijing  100012",
        "country": "CN"
    },
    "84C78F": {
        "oui_hex": "84-C7-8F",
        "organization": "STORDIS GmbH",
        "address_1": "Rosenwiesstr. 17",
        "address_2": "Stuttgart    70567",
        "country": "DE"
    },
    "5041B9": {
        "oui_hex": "50-41-B9",
        "organization": "I-O DATA DEVICE,INC.",
        "address_1": "3-10,Sakurada-machi",
        "address_2": "Kanazawa  Ishikawa  920-8512",
        "country": "JP"
    },
    "80DABC": {
        "oui_hex": "80-DA-BC",
        "organization": "Megafone Limited",
        "address_1": "Unit 702,7/F,Bankok Bank Building,NO.18 Bonham Strand West",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "C09FE1": {
        "oui_hex": "C0-9F-E1",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "184644": {
        "oui_hex": "18-46-44",
        "organization": "Home Control Singapore Pte Ltd",
        "address_1": "151 Lorong Chuan",
        "address_2": "Singapore    556741",
        "country": "SG"
    },
    "B0700D": {
        "oui_hex": "B0-70-0D",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "346B5B": {
        "oui_hex": "34-6B-5B",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "84E892": {
        "oui_hex": "84-E8-92",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "301 Olcott St",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "78E2BD": {
        "oui_hex": "78-E2-BD",
        "organization": "Vodafone Automotive S.p.A.",
        "address_1": "via Astico 41",
        "address_2": "Varese  Italy/VA  21100",
        "country": "IT"
    },
    "F848FD": {
        "oui_hex": "F8-48-FD",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "20DA22": {
        "oui_hex": "20-DA-22",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C821DA": {
        "oui_hex": "C8-21-DA",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "E0B655": {
        "oui_hex": "E0-B6-55",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "002175": {
        "oui_hex": "00-21-75",
        "organization": "Pacific Satellite International Ltd.",
        "address_1": "20/F Tai Tung Building,",
        "address_2": "Wanchai    100000",
        "country": "HK"
    },
    "889746": {
        "oui_hex": "88-97-46",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "1CDE57": {
        "oui_hex": "1C-DE-57",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E0DCFF": {
        "oui_hex": "E0-DC-FF",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "608CDF": {
        "oui_hex": "60-8C-DF",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "00778D": {
        "oui_hex": "00-77-8D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E8C": {
        "oui_hex": "00-0E-8C",
        "organization": "Siemens AG",
        "address_1": "Siemensstraße 10",
        "address_2": "Regensburg    93055",
        "country": "DE"
    },
    "008764": {
        "oui_hex": "00-87-64",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "FC3342": {
        "oui_hex": "FC-33-42",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C468D0": {
        "oui_hex": "C4-68-D0",
        "organization": "VTech Telecommunications Ltd.",
        "address_1": "23/F, Tai Ping Industrial Centre, Block 1,",
        "address_2": "HONG KONG  NA  000000",
        "country": "HK"
    },
    "14AEDB": {
        "oui_hex": "14-AE-DB",
        "organization": "VTech Telecommunications Ltd.",
        "address_1": "23/F, Tai Ping Industrial Centre, Block 1,",
        "address_2": "HONG KONG  NA  000000",
        "country": "HK"
    },
    "78DB2F": {
        "oui_hex": "78-DB-2F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "8C0FA0": {
        "oui_hex": "8C-0F-A0",
        "organization": "di-soric GmbH & Co. KG",
        "address_1": "Steinbeisstrasse 6",
        "address_2": "Urbach    73660",
        "country": "DE"
    },
    "DCB808": {
        "oui_hex": "DC-B8-08",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "B0E71D": {
        "oui_hex": "B0-E7-1D",
        "organization": "Shanghai Maigantech Co.,Ltd",
        "address_1": "Room 2211,No.88 Caoxi North Rd,Xuhui District",
        "address_2": "Shanghai  Shanghai  200030",
        "country": "CN"
    },
    "F8BBBF": {
        "oui_hex": "F8-BB-BF",
        "organization": "eero inc.",
        "address_1": "500 Howard St Suite 900",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "846FCE": {
        "oui_hex": "84-6F-CE",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "20658E": {
        "oui_hex": "20-65-8E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "183D5E": {
        "oui_hex": "18-3D-5E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "DC7137": {
        "oui_hex": "DC-71-37",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "847C9B": {
        "oui_hex": "84-7C-9B",
        "organization": "GD Midea Air-Conditioning Equipment Co.,Ltd.",
        "address_1": "Midea Global Innovation Center,Beijiao Town,Shunde",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "3441A8": {
        "oui_hex": "34-41-A8",
        "organization": "ER-Telecom",
        "address_1": "Ovchinnikovskaya embankment, 20, Building 1",
        "address_2": "Moscow    115324",
        "country": "RU"
    },
    "34DB9C": {
        "oui_hex": "34-DB-9C",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "7440BE": {
        "oui_hex": "74-40-BE",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "04D4C4": {
        "oui_hex": "04-D4-C4",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "F0D4E2": {
        "oui_hex": "F0-D4-E2",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "A8E2C3": {
        "oui_hex": "A8-E2-C3",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "9020C2": {
        "oui_hex": "90-20-C2",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0CA06C": {
        "oui_hex": "0C-A0-6C",
        "organization": "Industrial Cyber Sensing Inc.",
        "address_1": "Unit 1A - 343 Montrose Street North",
        "address_2": "Cambridge  Ontario  N3H 2H6",
        "country": "CA"
    },
    "FCD2B6": {
        "oui_hex": "FC-D2-B6",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "804A14": {
        "oui_hex": "80-4A-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "703C69": {
        "oui_hex": "70-3C-69",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC2DA9": {
        "oui_hex": "AC-2D-A9",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "FCB662": {
        "oui_hex": "FC-B6-62",
        "organization": "IC Holdings LLC",
        "address_1": "9066 S 300 W",
        "address_2": "Sandy  UT  84070",
        "country": "US"
    },
    "48049F": {
        "oui_hex": "48-04-9F",
        "organization": "ELECOM CO., LTD",
        "address_1": "9FLand Axis Tower.1-1 fushimi machi,4-chome chuoku",
        "address_2": "osaka    5418765",
        "country": "JP"
    },
    "087F98": {
        "oui_hex": "08-7F-98",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "C85261": {
        "oui_hex": "C8-52-61",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C04121": {
        "oui_hex": "C0-41-21",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "7488BB": {
        "oui_hex": "74-88-BB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4CF12": {
        "oui_hex": "A4-CF-12",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "4C6AF6": {
        "oui_hex": "4C-6A-F6",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "489DD1": {
        "oui_hex": "48-9D-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B06FE0": {
        "oui_hex": "B0-6F-E0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44B994": {
        "oui_hex": "44-B9-94",
        "organization": "Douglas Lighting Controls",
        "address_1": "280 - 3605 Gilmore Way",
        "address_2": "Burnaby  BC  V5G4X5",
        "country": "CA"
    },
    "40A93F": {
        "oui_hex": "40-A9-3F",
        "organization": "Pivotal Commware, Inc.",
        "address_1": "1555 132nd Ave. NE",
        "address_2": "Bellevue  WA  98005",
        "country": "US"
    },
    "70BF92": {
        "oui_hex": "70-BF-92",
        "organization": "GN Audio A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK-2750",
        "country": "DK"
    },
    "C08C71": {
        "oui_hex": "C0-8C-71",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "F46F4E": {
        "oui_hex": "F4-6F-4E",
        "organization": "Echowell",
        "address_1": "7F-8, No. 8, Sec 1, JunShing Rd.",
        "address_2": "New Taipei City    24872",
        "country": "TW"
    },
    "2C3F0B": {
        "oui_hex": "2C-3F-0B",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "5C8816": {
        "oui_hex": "5C-88-16",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "002F5C": {
        "oui_hex": "00-2F-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4645D": {
        "oui_hex": "F4-64-5D",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "38F85E": {
        "oui_hex": "38-F8-5E",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "ACBB61": {
        "oui_hex": "AC-BB-61",
        "organization": "YSTen Technology Co.,Ltd",
        "address_1": "Room 1715,17/F North Star Times Tower,Chaoyang District,Beijing.",
        "address_2": "Beijing    100101",
        "country": "CN"
    },
    "2479F8": {
        "oui_hex": "24-79-F8",
        "organization": "KUPSON spol. s r.o.",
        "address_1": "Hradecka 787/14",
        "address_2": "Opava  Czech Republic  74601",
        "country": "CZ"
    },
    "7CFD82": {
        "oui_hex": "7C-FD-82",
        "organization": "GUANGDONG GENIUS TECHNOLOGY CO., LTD.",
        "address_1": "No.168, Middle Road Of East Gate",
        "address_2": "Xiaobian Community  Chang'an Town  523851",
        "country": "CN"
    },
    "180D2C": {
        "oui_hex": "18-0D-2C",
        "organization": "Intelbras",
        "address_1": "BR 101, km 210, S/N°",
        "address_2": "São José  Santa Catarina  88104800",
        "country": "BR"
    },
    "042DB4": {
        "oui_hex": "04-2D-B4",
        "organization": "First Property (Beijing) Co., Ltd Modern MOMA Branch",
        "address_1": "Room 301A，Building No.10, No.1 Xiangheyuan Road, Dongcheng District, Beijing City",
        "address_2": "Beijing  Beijing  100028",
        "country": "CN"
    },
    "04E0B0": {
        "oui_hex": "04-E0-B0",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "08ECF5": {
        "oui_hex": "08-EC-F5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D07650": {
        "oui_hex": "D0-76-50",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "60D0A9": {
        "oui_hex": "60-D0-A9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88CEFA": {
        "oui_hex": "88-CE-FA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "002706": {
        "oui_hex": "00-27-06",
        "organization": "YOISYS",
        "address_1": "309-52 SUNGSU-2GA, 1DONG, SUNGDONG-GU",
        "address_2": "SEOUL    133-827",
        "country": "KR"
    },
    "00CB51": {
        "oui_hex": "00-CB-51",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "C464B7": {
        "oui_hex": "C4-64-B7",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "EC4118": {
        "oui_hex": "EC-41-18",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "D8860B": {
        "oui_hex": "D8-86-0B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "342003": {
        "oui_hex": "34-20-03",
        "organization": "Shenzhen Feitengyun Technology Co.,LTD",
        "address_1": "7F 4building,Yalianhaoshida industrial Park",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "F07D68": {
        "oui_hex": "F0-7D-68",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd Rd., Neihu District,",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "40E3D6": {
        "oui_hex": "40-E3-D6",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B45D50": {
        "oui_hex": "B4-5D-50",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "78DAA2": {
        "oui_hex": "78-DA-A2",
        "organization": "Cynosure Technologies Co.,Ltd",
        "address_1": "Room 2708/2710, Building No.9A, Shenzhen Bay Science and Technology Ecological Park，Nanshan",
        "address_2": "Shenzhen city  Guangdong Province  518057",
        "country": "CN"
    },
    "38B19E": {
        "oui_hex": "38-B1-9E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "38E26E": {
        "oui_hex": "38-E2-6E",
        "organization": "ShenZhen Sweet Rain Electronics Co.,Ltd.",
        "address_1": "Xinghua Road",
        "address_2": "Shenzhen  Bao'an  518101",
        "country": "CN"
    },
    "00D050": {
        "oui_hex": "00-D0-50",
        "organization": "Iskratel d.o.o.",
        "address_1": "Ljubljanska cesta 24a",
        "address_2": "Kranj    4000",
        "country": "SI"
    },
    "70C9C6": {
        "oui_hex": "70-C9-C6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D4B92F": {
        "oui_hex": "D4-B9-2F",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "689A87": {
        "oui_hex": "68-9A-87",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "64AE88": {
        "oui_hex": "64-AE-88",
        "organization": "Polytec GmbH",
        "address_1": "Polytec Platz 1-7",
        "address_2": "Waldbronn  BW  76337",
        "country": "DE"
    },
    "ACA31E": {
        "oui_hex": "AC-A3-1E",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00177B": {
        "oui_hex": "00-17-7B",
        "organization": "Azalea Networks inc",
        "address_1": "673 S Milpitas Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "98DAC4": {
        "oui_hex": "98-DA-C4",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "502B98": {
        "oui_hex": "50-2B-98",
        "organization": "Es-tech International",
        "address_1": "228-70, Saneop-ro 155beon-gil, Gwonseon-gu, Suwon-si, Gyeonggi-do, Korea",
        "address_2": "Suwon    16648",
        "country": "KR"
    },
    "C82832": {
        "oui_hex": "C8-28-32",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "946A77": {
        "oui_hex": "94-6A-77",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "C4346B": {
        "oui_hex": "C4-34-6B",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "8084A9": {
        "oui_hex": "80-84-A9",
        "organization": "oshkosh Corporation",
        "address_1": "2307 Oregon Street",
        "address_2": "Oshkosh  WI  54902",
        "country": "US"
    },
    "F46E95": {
        "oui_hex": "F4-6E-95",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose    95119",
        "country": "US"
    },
    "4CC7D6": {
        "oui_hex": "4C-C7-D6",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "C80873": {
        "oui_hex": "C8-08-73",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "701BFB": {
        "oui_hex": "70-1B-FB",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "04766E": {
        "oui_hex": "04-76-6E",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "AC7A4D": {
        "oui_hex": "AC-7A-4D",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "KAKUDA-CITY  MIYAGI-PREF  981-1595",
        "country": "JP"
    },
    "001BB5": {
        "oui_hex": "00-1B-B5",
        "organization": "Cherry GmbH",
        "address_1": "Cherrystraße 1",
        "address_2": "Auerbach i. d. Opf.  Bayern  D-91275",
        "country": "DE"
    },
    "002643": {
        "oui_hex": "00-26-43",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "38C096": {
        "oui_hex": "38-C0-96",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "KAKUDA-CITY  MIYAGI-PREF  981-1595",
        "country": "JP"
    },
    "D05157": {
        "oui_hex": "D0-51-57",
        "organization": "LEAX Arkivator Telecom",
        "address_1": "NanShan District YueHaiMen Street",
        "address_2": "ShenZhen  GuangDong  518061",
        "country": "CN"
    },
    "288088": {
        "oui_hex": "28-80-88",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "64CE6E": {
        "oui_hex": "64-CE-6E",
        "organization": "Sierra Wireless",
        "address_1": "13811 Wireless Way",
        "address_2": "Richmond  BC  V6V 3A4",
        "country": "CA"
    },
    "1C3477": {
        "oui_hex": "1C-34-77",
        "organization": "Innovation Wireless",
        "address_1": "11869 Teale Street",
        "address_2": "Culver City  CA  90230",
        "country": "US"
    },
    "BC3E07": {
        "oui_hex": "BC-3E-07",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "48FDA3": {
        "oui_hex": "48-FD-A3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "001697": {
        "oui_hex": "00-16-97",
        "organization": "NEC Corporation",
        "address_1": "7-1, Shiba 5-chome Minato-ku,",
        "address_2": "tokyo  Tokyo  108-8001",
        "country": "JP"
    },
    "003013": {
        "oui_hex": "00-30-13",
        "organization": "NEC Corporation",
        "address_1": "1-10 Nisshincho, Fuchu",
        "address_2": "Tokyo 183-8501    0000",
        "country": "JP"
    },
    "049DFE": {
        "oui_hex": "04-9D-FE",
        "organization": "Hivesystem",
        "address_1": "816 Kranz-techno Bldg. 388 dunchondaero, jun",
        "address_2": "Gyeonggi-do    KSXX0024",
        "country": "KR"
    },
    "0CEC84": {
        "oui_hex": "0C-EC-84",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "9CDB07": {
        "oui_hex": "9C-DB-07",
        "organization": "Thum+Mahr GmbH",
        "address_1": "Heinrich-Hertz-Strasse 1-3",
        "address_2": "Monheim am Rhein  NRW  40789",
        "country": "DE"
    },
    "DCEB69": {
        "oui_hex": "DC-EB-69",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "004E35": {
        "oui_hex": "00-4E-35",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F81308": {
        "oui_hex": "F8-13-08",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "F8A2D6": {
        "oui_hex": "F8-A2-D6",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "182A44": {
        "oui_hex": "18-2A-44",
        "organization": "HIROSE ELECTRONIC SYSTEM",
        "address_1": "1-9-6 Ebisuminami",
        "address_2": "Shibuya  Tokyo  150-0022",
        "country": "JP"
    },
    "FC94CE": {
        "oui_hex": "FC-94-CE",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "90869B": {
        "oui_hex": "90-86-9B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E0189F": {
        "oui_hex": "E0-18-9F",
        "organization": "EM Microelectronic",
        "address_1": "Rue des Sors 3",
        "address_2": "Marin-Epagnier  Neuchatel  2074",
        "country": "CH"
    },
    "74366D": {
        "oui_hex": "74-36-6D",
        "organization": "Vodafone Italia S.p.A.",
        "address_1": "Via Lorenteggio nr. 240",
        "address_2": "Milan  Italy  20147",
        "country": "IT"
    },
    "84DB2F": {
        "oui_hex": "84-DB-2F",
        "organization": "Sierra Wireless",
        "address_1": "1381 Wireless Way",
        "address_2": "Richmond  BC  V6V 3A4",
        "country": "CA"
    },
    "9458CB": {
        "oui_hex": "94-58-CB",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "28EC9A": {
        "oui_hex": "28-EC-9A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "FCBE7B": {
        "oui_hex": "FC-BE-7B",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "B40FB3": {
        "oui_hex": "B4-0F-B3",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "EC5C68": {
        "oui_hex": "EC-5C-68",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C4E506": {
        "oui_hex": "C4-E5-06",
        "organization": "Piper Networks, Inc.",
        "address_1": "3636 Nobel Drive",
        "address_2": "San Diego  CA  92122",
        "country": "US"
    },
    "30EB5A": {
        "oui_hex": "30-EB-5A",
        "organization": "LANDIS + GYR",
        "address_1": "78th km Old National Road Athens-Corinth",
        "address_2": "Corinth     20100",
        "country": "GR"
    },
    "F80F6F": {
        "oui_hex": "F8-0F-6F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0080E3": {
        "oui_hex": "00-80-E3",
        "organization": "CORAL NETWORK CORPORATION",
        "address_1": "(NOW BAY NETWORKS)",
        "address_2": "SANTA CLARA  CA  95052-8185",
        "country": "US"
    },
    "B4C62E": {
        "oui_hex": "B4-C6-2E",
        "organization": "Molex CMS",
        "address_1": "2222 Wellington Court",
        "address_2": "Lisle  IL  60532",
        "country": "US"
    },
    "B8259A": {
        "oui_hex": "B8-25-9A",
        "organization": "Thalmic Labs",
        "address_1": "24 Charles Street West",
        "address_2": "Kitchener   Ontario   N2G 1H2",
        "country": "CA"
    },
    "282536": {
        "oui_hex": "28-25-36",
        "organization": "SHENZHEN HOLATEK CO.,LTD",
        "address_1": "Rm.1001,Unit 4,Bld.B,Kexing Science Park,Keyuan Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B8A175": {
        "oui_hex": "B8-A1-75",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "CCD3C1": {
        "oui_hex": "CC-D3-C1",
        "organization": "Vestel Elektronik San ve Tic. A.Ş.",
        "address_1": "Organize san",
        "address_2": "Manisa  Turket  45030",
        "country": "TR"
    },
    "0CD0F8": {
        "oui_hex": "0C-D0-F8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "745F90": {
        "oui_hex": "74-5F-90",
        "organization": "LAM Technologies",
        "address_1": "Viale Ludovico Ariosto, 492/D",
        "address_2": "Sesto Fiorentino  FIRENZE  50019",
        "country": "IT"
    },
    "A42655": {
        "oui_hex": "A4-26-55",
        "organization": "LTI Motion (Shanghai) Co., Ltd.",
        "address_1": "NO.80, Lane 2927, LaiYang Road Pudong New District",
        "address_2": "Shanghai  Shanghai  200137",
        "country": "CN"
    },
    "60A730": {
        "oui_hex": "60-A7-30",
        "organization": "Shenzhen Yipinfang Internet Technology Co.,Ltd",
        "address_1": "Shenzhen Konka R & D Building, 28th floor 21",
        "address_2": "GuangDong  Nanshan District  518000",
        "country": "CN"
    },
    "3C9BD6": {
        "oui_hex": "3C-9B-D6",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "F85B9C": {
        "oui_hex": "F8-5B-9C",
        "organization": "SB SYSTEMS Co.,Ltd",
        "address_1": "2F Ventureforum, 323, Pangyo-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonngi-do  453-400",
        "country": "KR"
    },
    "6CA928": {
        "oui_hex": "6C-A9-28",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "00D861": {
        "oui_hex": "00-D8-61",
        "organization": "Micro-Star INTL CO., LTD.",
        "address_1": "No.69, Lide St.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "74C17D": {
        "oui_hex": "74-C1-7D",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "8871B1": {
        "oui_hex": "88-71-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F0AF85": {
        "oui_hex": "F0-AF-85",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FCAE34": {
        "oui_hex": "FC-AE-34",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "DCDA80": {
        "oui_hex": "DC-DA-80",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "CC7286": {
        "oui_hex": "CC-72-86",
        "organization": "Xi'an Fengyu Information Technology Co., Ltd.",
        "address_1": "5F, Block A, STRC, No.10, Zhangba 5th Road, Yanta",
        "address_2": "Xi'an  Shaanxi  710077",
        "country": "CN"
    },
    "64EEB7": {
        "oui_hex": "64-EE-B7",
        "organization": "Netcore Technology Inc",
        "address_1": "Building 6, Baolong Plant, Able Technology Park, Longgang District,",
        "address_2": "Shenzhen    518116",
        "country": "CN"
    },
    "3881D7": {
        "oui_hex": "38-81-D7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "1804ED": {
        "oui_hex": "18-04-ED",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D43260": {
        "oui_hex": "D4-32-60",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "50DB3F": {
        "oui_hex": "50-DB-3F",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "1081B4": {
        "oui_hex": "10-81-B4",
        "organization": "Hunan Greatwall Galaxy Science and Technology Co.,Ltd.",
        "address_1": "No. 39, Jian Shan Road",
        "address_2": "Changsha  Hunan  410205",
        "country": "CN"
    },
    "004279": {
        "oui_hex": "00-42-79",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "00B8B3": {
        "oui_hex": "00-B8-B3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4DD9E": {
        "oui_hex": "F4-DD-9E",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "D4D919": {
        "oui_hex": "D4-D9-19",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "141114": {
        "oui_hex": "14-11-14",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "A45046": {
        "oui_hex": "A4-50-46",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "1C24CD": {
        "oui_hex": "1C-24-CD",
        "organization": "Askey Computer Corp.",
        "address_1": "10F, No.119, JIANKANG RD.,ZHINGHE DIST,",
        "address_2": "NEW TAIPEI CITY    23585",
        "country": "TW"
    },
    "007C2D": {
        "oui_hex": "00-7C-2D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "B47748": {
        "oui_hex": "B4-77-48",
        "organization": "Shenzhen Neoway Technology Co.,Ltd.",
        "address_1": "4F-2#,Lian Jian Science & Industry Park,Huarong Road,Dalang Street,Longhua District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F8501C": {
        "oui_hex": "F8-50-1C",
        "organization": "Tianjin Geneuo Technology Co.,Ltd",
        "address_1": "Technology Avenue South JingHai Economic Development Area,Tianjin China",
        "address_2": "Tianjin    301609",
        "country": "CN"
    },
    "44070B": {
        "oui_hex": "44-07-0B",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "F8C249": {
        "oui_hex": "F8-C2-49",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "B831B5": {
        "oui_hex": "B8-31-B5",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "ECF6BD": {
        "oui_hex": "EC-F6-BD",
        "organization": "SNCF MOBILITÉS",
        "address_1": "9 rue Jean-Philippe Rameau",
        "address_2": "SAINT-DENIS    93200",
        "country": "FR"
    },
    "38B4D3": {
        "oui_hex": "38-B4-D3",
        "organization": "BSH Hausgeraete GmbH",
        "address_1": "Im Gewerbepark B10",
        "address_2": "Regensburg    93059",
        "country": "DE"
    },
    "C84782": {
        "oui_hex": "C8-47-82",
        "organization": "Areson Technology Corp.",
        "address_1": "11F., No. 646, Sec. 5, Chongxin Rd., Sanchong District",
        "address_2": "New Taipei City    24158",
        "country": "TW"
    },
    "E89363": {
        "oui_hex": "E8-93-63",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "7C0CF6": {
        "oui_hex": "7C-0C-F6",
        "organization": "Guangdong Huiwei High-tech Co., Ltd.",
        "address_1": "E Block No. 1 in Ecological Area in Puzhai NewArea",
        "address_2": "Fengshun County, Meizhou  Guangdong province  514000",
        "country": "CN"
    },
    "749D79": {
        "oui_hex": "74-9D-79",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "00D6FE": {
        "oui_hex": "00-D6-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0CBF74": {
        "oui_hex": "0C-BF-74",
        "organization": "Morse Micro",
        "address_1": "113 / 2-4 Cornwallis Street",
        "address_2": "Eveleigh  NSW  2015",
        "country": "AU"
    },
    "FC8F7D": {
        "oui_hex": "FC-8F-7D",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "24BE18": {
        "oui_hex": "24-BE-18",
        "organization": "DADOUTEK COMPANY LIMITED",
        "address_1": "14/F, Wilson Logistics Centre,No.24-28 Kung Yip St",
        "address_2": "Kwai Chung  New Territories  000",
        "country": "CN"
    },
    "B41D2B": {
        "oui_hex": "B4-1D-2B",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "14C213": {
        "oui_hex": "14-C2-13",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70D313": {
        "oui_hex": "70-D3-13",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9C1D36": {
        "oui_hex": "9C-1D-36",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CCBBFE": {
        "oui_hex": "CC-BB-FE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4D931": {
        "oui_hex": "A4-D9-31",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BCFED9": {
        "oui_hex": "BC-FE-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "808223": {
        "oui_hex": "80-82-23",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "300A60": {
        "oui_hex": "30-0A-60",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "80D065": {
        "oui_hex": "80-D0-65",
        "organization": "CKS Corporation",
        "address_1": "1-24-11 Akebono",
        "address_2": "Tachikawa  Tokyo  190-0012",
        "country": "JP"
    },
    "283166": {
        "oui_hex": "28-31-66",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "C04004": {
        "oui_hex": "C0-40-04",
        "organization": "Medicaroid Corporation",
        "address_1": "1-6-4, Minatojima-minamimachi, Chuo-ku",
        "address_2": "Kobe    650-0047",
        "country": "JP"
    },
    "20AD56": {
        "oui_hex": "20-AD-56",
        "organization": "Continental Automotive Systems Inc.",
        "address_1": "21440 W. Lake Cook Rd.",
        "address_2": "Deer Park  IL  60010",
        "country": "US"
    },
    "5029F5": {
        "oui_hex": "50-29-F5",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "CC08FB": {
        "oui_hex": "CC-08-FB",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "BCAF91": {
        "oui_hex": "BC-AF-91",
        "organization": "TE Connectivity Sensor Solutions",
        "address_1": "4 rue Gaye-Marie, CS 83163",
        "address_2": "Toulouse    31027",
        "country": "FR"
    },
    "F0D7DC": {
        "oui_hex": "F0-D7-DC",
        "organization": "Wesine (Wuhan) Technology Co., Ltd.",
        "address_1": "10th Floor, Building 2, SBI Venture Street, Hongshan District",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "007204": {
        "oui_hex": "00-72-04",
        "organization": "Samsung Electronics Co., Ltd. ARTIK",
        "address_1": "1-1, Samsungjeonja-ro",
        "address_2": "Hwaseong-si  Gyeonggi-do  18448",
        "country": "KR"
    },
    "40C81F": {
        "oui_hex": "40-C8-1F",
        "organization": "Shenzhen Xinguodu Technology Co., Ltd.",
        "address_1": "F17A, JinSong Building, Tairan Industrial & Trade Park, Chegongmiao, Shennan Road，Futian District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "1459C0": {
        "oui_hex": "14-59-C0",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "8C61A3": {
        "oui_hex": "8C-61-A3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A81087": {
        "oui_hex": "A8-10-87",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A02833": {
        "oui_hex": "A0-28-33",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C8C2F5": {
        "oui_hex": "C8-C2-F5",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "F05849": {
        "oui_hex": "F0-58-49",
        "organization": "CareView Communications",
        "address_1": "405 State HWY 121 BYP",
        "address_2": "Lewisville   Texas  75067",
        "country": "US"
    },
    "34E5EC": {
        "oui_hex": "34-E5-EC",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "A4ED43": {
        "oui_hex": "A4-ED-43",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "94298D": {
        "oui_hex": "94-29-8D",
        "organization": "Shanghai AdaptComm Technology Co., Ltd.",
        "address_1": "3rd Floor, Building 14, No. 518 Xinzhuan Road, Songjiang District,",
        "address_2": "Shanghai    201600",
        "country": "CN"
    },
    "00AA6E": {
        "oui_hex": "00-AA-6E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0C7C28": {
        "oui_hex": "0C-7C-28",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "6843D7": {
        "oui_hex": "68-43-D7",
        "organization": "Agilecom Photonics Solutions Guangdong Limited",
        "address_1": "No.1-6, Shenwan Industrial Park, Shenwan Town",
        "address_2": "Zhongshan  Guangdong  528462",
        "country": "CN"
    },
    "20D80B": {
        "oui_hex": "20-D8-0B",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "8C8F8B": {
        "oui_hex": "8C-8F-8B",
        "organization": "China Mobile Chongqing branch",
        "address_1": "6 building, No. 2, Xingguang three road",
        "address_2": "Yubei District  Chongqing  401120",
        "country": "CN"
    },
    "B86A97": {
        "oui_hex": "B8-6A-97",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "000A5E": {
        "oui_hex": "00-0A-5E",
        "organization": "3COM",
        "address_1": "5400 Bayfront Plaza",
        "address_2": "Santa Clara  CA  95052-8145",
        "country": "US"
    },
    "00105A": {
        "oui_hex": "00-10-5A",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "006097": {
        "oui_hex": "00-60-97",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "006008": {
        "oui_hex": "00-60-08",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "001B6E": {
        "oui_hex": "00-1B-6E",
        "organization": "Keysight Technologies, Inc.",
        "address_1": "1400 Fountaingrove Pkwy.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "00040B": {
        "oui_hex": "00-04-0B",
        "organization": "3COM EUROPE LTD",
        "address_1": "BOUNDARY WAY",
        "address_2": "vvvvv  UNITED  KINGDOM",
        "country": "GB"
    },
    "000102": {
        "oui_hex": "00-01-02",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "8CFE74": {
        "oui_hex": "8C-FE-74",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "A8016D": {
        "oui_hex": "A8-01-6D",
        "organization": "Aiwa Corporation",
        "address_1": "965 W Chicago Ave",
        "address_2": "Chicago  IL  60642",
        "country": "US"
    },
    "0440A9": {
        "oui_hex": "04-40-A9",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "4C0143": {
        "oui_hex": "4C-01-43",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "E43493": {
        "oui_hex": "E4-34-93",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "342912": {
        "oui_hex": "34-29-12",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "604BAA": {
        "oui_hex": "60-4B-AA",
        "organization": "Magic Leap, Inc.",
        "address_1": "1855 Griffin Rd, Room B454",
        "address_2": "Dania Beach  FL  33004",
        "country": "US"
    },
    "4C364E": {
        "oui_hex": "4C-36-4E",
        "organization": "Panasonic Corporation  Connected Solutions Company",
        "address_1": "4-1-62 Minoshima, Hakata-ku",
        "address_2": "Fukuoka-shi  Fukuoka  812-8531",
        "country": "JP"
    },
    "BCA58B": {
        "oui_hex": "BC-A5-8B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "80CEB9": {
        "oui_hex": "80-CE-B9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0D3FC": {
        "oui_hex": "D0-D3-FC",
        "organization": "Mios, Ltd.",
        "address_1": "645 W. 9th St.",
        "address_2": "Los Angeles  CA  90015",
        "country": "US"
    },
    "6C6CD3": {
        "oui_hex": "6C-6C-D3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E049ED": {
        "oui_hex": "E0-49-ED",
        "organization": "Audeze LLC",
        "address_1": "3410 S Susan st",
        "address_2": "Santa Ana  CA  92704",
        "country": "US"
    },
    "8030E0": {
        "oui_hex": "80-30-E0",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "E85D86": {
        "oui_hex": "E8-5D-86",
        "organization": "CHANG YOW TECHNOLOGIES INTERNATIONAL CO.,LTD.",
        "address_1": " No 88 Shuren 6th St Wufong District",
        "address_2": "Taichung    413",
        "country": "TW"
    },
    "143719": {
        "oui_hex": "14-37-19",
        "organization": "PT Prakarsa Visi Valutama",
        "address_1": "Jl. Cideng Timur No.11D",
        "address_2": "Jakarta Pusat  Indonesia  10130",
        "country": "ID"
    },
    "582F40": {
        "oui_hex": "58-2F-40",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0890BA": {
        "oui_hex": "08-90-BA",
        "organization": "Danlaw Inc",
        "address_1": "23700 research Dr.",
        "address_2": "Farmington Hills    48335",
        "country": "US"
    },
    "94A3CA": {
        "oui_hex": "94-A3-CA",
        "organization": "KonnectONE, LLC",
        "address_1": "30 N Gould Street STE 4004",
        "address_2": "Sheridan  WY  82801",
        "country": "US"
    },
    "244CE3": {
        "oui_hex": "24-4C-E3",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno    89507",
        "country": "US"
    },
    "B8BEF4": {
        "oui_hex": "B8-BE-F4",
        "organization": "devolo AG",
        "address_1": "Charlottenburger Allee 67",
        "address_2": "Aachen  NRW  52068",
        "country": "DE"
    },
    "000157": {
        "oui_hex": "00-01-57",
        "organization": "SYSWAVE CO., LTD",
        "address_1": "Dongho B/D 5F, 221-2",
        "address_2": "  KOREA  135-010",
        "country": "KR"
    },
    "58FDBE": {
        "oui_hex": "58-FD-BE",
        "organization": "Shenzhen Taikaida Technology Co., Ltd",
        "address_1": "Shenzhen Baoan District Fuyong town Fengtang road Xintian building 613",
        "address_2": "shenzhen    518102",
        "country": "CN"
    },
    "F4F197": {
        "oui_hex": "F4-F1-97",
        "organization": "EMTAKE Inc",
        "address_1": "14, Pangyoyeok ro 192, Bundang gu",
        "address_2": "Seongnam city  Kyeonggi do  13524",
        "country": "KR"
    },
    "6CED51": {
        "oui_hex": "6C-ED-51",
        "organization": "NEXCONTROL Co.,Ltd",
        "address_1": "(#303-1007, Ssangyong 3th) 397, Seokcheon-ro",
        "address_2": "Bucheon-si  Gyeonggi-do  14449",
        "country": "KR"
    },
    "04C3E6": {
        "oui_hex": "04-C3-E6",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "286336": {
        "oui_hex": "28-63-36",
        "organization": "Siemens AG",
        "address_1": "Werner-von-Siemens Strasse 50",
        "address_2": "Amberg    92224",
        "country": "DE"
    },
    "14D169": {
        "oui_hex": "14-D1-69",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1062E5": {
        "oui_hex": "10-62-E5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0020B5": {
        "oui_hex": "00-20-B5",
        "organization": "YASKAWA ELECTRIC CORPORATION",
        "address_1": "2-1 Kurosakishiroishi, Yahatanishi-ku,",
        "address_2": "Kitakyushu    806-0004",
        "country": "JP"
    },
    "E06267": {
        "oui_hex": "E0-62-67",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "70B7AA": {
        "oui_hex": "70-B7-AA",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "84B31B": {
        "oui_hex": "84-B3-1B",
        "organization": "Kinexon GmbH",
        "address_1": "Schellingstrasse, 35",
        "address_2": "München    80799",
        "country": "DE"
    },
    "082525": {
        "oui_hex": "08-25-25",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C49500": {
        "oui_hex": "C4-95-00",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "F460E2": {
        "oui_hex": "F4-60-E2",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "E4D124": {
        "oui_hex": "E4-D1-24",
        "organization": " Mojo Networks, Inc.",
        "address_1": "339 N.Bernardo Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0013A3": {
        "oui_hex": "00-13-A3",
        "organization": "Siemens Home & Office Comm. Devices",
        "address_1": "4849 Alpha Road",
        "address_2": "Dallas    75244",
        "country": "US"
    },
    "B0B867": {
        "oui_hex": "B0-B8-67",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "C00380": {
        "oui_hex": "C0-03-80",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "98BB99": {
        "oui_hex": "98-BB-99",
        "organization": "Phicomm (Sichuan) Co.,Ltd.",
        "address_1": "125 longquan street park road,longquan district,chengdu city",
        "address_2": "Sichuan  Chengdu  610015",
        "country": "CN"
    },
    "002622": {
        "oui_hex": "00-26-22",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "F8272E": {
        "oui_hex": "F8-27-2E",
        "organization": "Mercku",
        "address_1": "509 Beaver Creek Rd.",
        "address_2": "Waterloo  Ontario  N2V 2L3",
        "country": "CA"
    },
    "9CC950": {
        "oui_hex": "9C-C9-50",
        "organization": "Baumer Holding",
        "address_1": "Hummelstrasse 17",
        "address_2": "Frauenfeld  Thurgau  8501",
        "country": "CH"
    },
    "F89910": {
        "oui_hex": "F8-99-10",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "50E0EF": {
        "oui_hex": "50-E0-EF",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "848A8D": {
        "oui_hex": "84-8A-8D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "1CC3EB": {
        "oui_hex": "1C-C3-EB",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "504C7E": {
        "oui_hex": "50-4C-7E",
        "organization": "THE 41ST INSTITUTE OF CETC",
        "address_1": "No.98 Xiangjiang Road,Huangdao District,Qingdao,Shandong",
        "address_2": "Qingdao  Shangdong  266555",
        "country": "CN"
    },
    "001413": {
        "oui_hex": "00-14-13",
        "organization": "Trebing & Himstedt Prozeßautomation GmbH & Co. KG",
        "address_1": "Wilhelm Hennemann Straße 13",
        "address_2": "Schwerin  Mecklenburg-Vorpommern  19061",
        "country": "DE"
    },
    "000799": {
        "oui_hex": "00-07-99",
        "organization": "Tipping Point Technologies, Inc.",
        "address_1": "7501 B N. Capital of TX Hwy.",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "D01CBB": {
        "oui_hex": "D0-1C-BB",
        "organization": "Beijing Ctimes Digital Technology Co., Ltd.",
        "address_1": "7th Floor, Jinzhou Building, Suzhou Street, No.79, Haidian District,",
        "address_2": "Beijing    100089",
        "country": "CN"
    },
    "7487BB": {
        "oui_hex": "74-87-BB",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "68DD26": {
        "oui_hex": "68-DD-26",
        "organization": "Shanghai Focus Vision Security Technology Co.,Ltd",
        "address_1": "No.4888 Hunan Rd, Pudong New District",
        "address_2": "Shanghai  Shanghai  201317",
        "country": "CN"
    },
    "2866E3": {
        "oui_hex": "28-66-E3",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "60F18A": {
        "oui_hex": "60-F1-8A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC3873": {
        "oui_hex": "EC-38-73",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "780473": {
        "oui_hex": "78-04-73",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A83E0E": {
        "oui_hex": "A8-3E-0E",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "10C172": {
        "oui_hex": "10-C1-72",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00151E": {
        "oui_hex": "00-15-1E",
        "organization": "ETHERNET Powerlink Standarization Group (EPSG)",
        "address_1": "c/o Zurich University of Applied Sciences",
        "address_2": "Winterthur    CH-8401",
        "country": "CH"
    },
    "00111E": {
        "oui_hex": "00-11-1E",
        "organization": "ETHERNET Powerlink Standarization Group (EPSG)",
        "address_1": "c/o University of Applied Sciences",
        "address_2": "Winterthur  ZH  CH-8401",
        "country": "CH"
    },
    "00409D": {
        "oui_hex": "00-40-9D",
        "organization": "DigiBoard",
        "address_1": "6400 FLYING CLOUD DRIVE",
        "address_2": "EDEN PRAIRIE  MN  55344",
        "country": "US"
    },
    "CC50E3": {
        "oui_hex": "CC-50-E3",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "DCE305": {
        "oui_hex": "DC-E3-05",
        "organization": "   ZAO NPK Rotek",
        "address_1": "Prospekt Mira",
        "address_2": "Moscow    129223",
        "country": "RU"
    },
    "A4DA32": {
        "oui_hex": "A4-DA-32",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "000EEE": {
        "oui_hex": "00-0E-EE",
        "organization": "Muco Industrie BV",
        "address_1": "Pleimuiden 12e",
        "address_2": "Amsterdam  NH  1046 AG",
        "country": "NL"
    },
    "7C1C4E": {
        "oui_hex": "7C-1C-4E",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "D8B6B7": {
        "oui_hex": "D8-B6-B7",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "002106": {
        "oui_hex": "00-21-06",
        "organization": "RIM Testing Services",
        "address_1": "440 Phillip Street",
        "address_2": "Waterloo  ON  N2L 5R9",
        "country": "CA"
    },
    "8C14B4": {
        "oui_hex": "8C-14-B4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "3C9872": {
        "oui_hex": "3C-98-72",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "40C3C6": {
        "oui_hex": "40-C3-C6",
        "organization": "SnapRoute",
        "address_1": "3960 Freedom Circle, Suite 100",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "5C9656": {
        "oui_hex": "5C-96-56",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "E06066": {
        "oui_hex": "E0-60-66",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "149346": {
        "oui_hex": "14-93-46",
        "organization": "PNI sensor corporation",
        "address_1": "2331 Circadian Way",
        "address_2": "Santa Rosa  CA  95407",
        "country": "US"
    },
    "DCE0EB": {
        "oui_hex": "DC-E0-EB",
        "organization": "Nanjing Aozheng Information Technology Co.Ltd",
        "address_1": "#E1-453, Zidong Road #1,Qixia District",
        "address_2": "Nanjing  jiangsu  210000",
        "country": "CN"
    },
    "EC8C9A": {
        "oui_hex": "EC-8C-9A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B48655": {
        "oui_hex": "B4-86-55",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2C4759": {
        "oui_hex": "2C-47-59",
        "organization": "Beijing MEGA preponderance Science & Technology Co. Ltd",
        "address_1": "Room 2201,No.8,Ruichuang International B Block,Wangjing East Road",
        "address_2": "Beijing    100102",
        "country": "CN"
    },
    "A41566": {
        "oui_hex": "A4-15-66",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Wei fang Export processing Zone",
        "address_2": "Wei Fang  Shan Dong  261205",
        "country": "CN"
    },
    "1C965A": {
        "oui_hex": "1C-96-5A",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road,Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Wei Fang  Shan Dong  261205",
        "country": "CN"
    },
    "401B5F": {
        "oui_hex": "40-1B-5F",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road,Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "A8E552": {
        "oui_hex": "A8-E5-52",
        "organization": "JUWEL Aquarium AG & Co. KG",
        "address_1": "Karl-Göx-Straße 1",
        "address_2": "Rotenburg / Wümme    27356",
        "country": "DE"
    },
    "5CCD7C": {
        "oui_hex": "5C-CD-7C",
        "organization": "MEIZU Technology Co.,Ltd.",
        "address_1": "MEIZU Tech Bldg., Technology& Innovation Coast",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "00138A": {
        "oui_hex": "00-13-8A",
        "organization": "Qingdao GoerTek Technology Co., Ltd.",
        "address_1": "Room 605,Innovation Building,Hi-tech Industrial Park,",
        "address_2": "QINGDAO  SHANDONG  266061",
        "country": "CN"
    },
    "A830AD": {
        "oui_hex": "A8-30-AD",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Wei fang Export processing Zone",
        "address_2": "Wei Fang  Shan Dong  261205",
        "country": "CN"
    },
    "BC5FF6": {
        "oui_hex": "BC-5F-F6",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C8E7D8": {
        "oui_hex": "C8-E7-D8",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr., Building 28, Cui Xi Fourth Road，Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "60D21C": {
        "oui_hex": "60-D2-1C",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "CC51B4": {
        "oui_hex": "CC-51-B4",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "00C3F4": {
        "oui_hex": "00-C3-F4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "B88AEC": {
        "oui_hex": "B8-8A-EC",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "D0D783": {
        "oui_hex": "D0-D7-83",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC3B77": {
        "oui_hex": "AC-3B-77",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "B0FC0D": {
        "oui_hex": "B0-FC-0D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "CCC92C": {
        "oui_hex": "CC-C9-2C",
        "organization": "Schindler - PORT Technology",
        "address_1": "via della Pace 22",
        "address_2": "Locarno  Ticino  6600",
        "country": "CH"
    },
    "001E39": {
        "oui_hex": "00-1E-39",
        "organization": "Comsys Communication Ltd.",
        "address_1": "9 Hamenofim st.",
        "address_2": "Herzelia    46725",
        "country": "IL"
    },
    "78725D": {
        "oui_hex": "78-72-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "FCE66A": {
        "oui_hex": "FC-E6-6A",
        "organization": "Industrial Software Co",
        "address_1": "85, Aleksandyr Malinov Blvd. Office 6",
        "address_2": "Sofia    1715",
        "country": "BG"
    },
    "7836CC": {
        "oui_hex": "78-36-CC",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "8CCF5C": {
        "oui_hex": "8C-CF-5C",
        "organization": "BEFEGA GmbH",
        "address_1": "Reichenbacher Str. 22",
        "address_2": "Schwabach  Bavaria  91126",
        "country": "DE"
    },
    "70C833": {
        "oui_hex": "70-C8-33",
        "organization": "Wirepas Oy",
        "address_1": "Visiokatu 4",
        "address_2": "Tampere    33720",
        "country": "FI"
    },
    "0C73EB": {
        "oui_hex": "0C-73-EB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "048AE1": {
        "oui_hex": "04-8A-E1",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "F0B5D1": {
        "oui_hex": "F0-B5-D1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "00E000": {
        "oui_hex": "00-E0-00",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "90848B": {
        "oui_hex": "90-84-8B",
        "organization": "HDR10+ Technologies, LLC",
        "address_1": "3855 SW 153rd Drive",
        "address_2": "Beaverton  OR  97006",
        "country": "US"
    },
    "C8D779": {
        "oui_hex": "C8-D7-79",
        "organization": "QING DAO HAIER TELECOM CO.,LTD.",
        "address_1": "No 1  Haier road,Hi-tech Zone，Qingdao，PR.China",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "10B36F": {
        "oui_hex": "10-B3-6F",
        "organization": "Bowei Technology Company Limited",
        "address_1": "2F,Building No.6C,1658,Gumei Rd",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "FC9BC6": {
        "oui_hex": "FC-9B-C6",
        "organization": "Sumavision Technologies Co.,Ltd",
        "address_1": "6F, Block A2, Power Creative Building,No.1 Shangdi East Road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "C8292A": {
        "oui_hex": "C8-29-2A",
        "organization": "Barun Electronics",
        "address_1": "869, Jangji-ri, Dongtan-myeon",
        "address_2": "Hwaseong-si  Gyeonggi-do  445812",
        "country": "KR"
    },
    "E482CC": {
        "oui_hex": "E4-82-CC",
        "organization": "Jumptronic GmbH",
        "address_1": "An der Weide 5",
        "address_2": "Springe    31832",
        "country": "DE"
    },
    "48605F": {
        "oui_hex": "48-60-5F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "B0416F": {
        "oui_hex": "B0-41-6F",
        "organization": "Shenzhen Maxtang Computer Co.,Ltd",
        "address_1": "6/F, Bldg.3, Honghui Industrial Park, Liuxian 2nd Rd., Bao'an Dist.",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "501D93": {
        "oui_hex": "50-1D-93",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2816A8": {
        "oui_hex": "28-16-A8",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "F8F532": {
        "oui_hex": "F8-F5-32",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "B083D6": {
        "oui_hex": "B0-83-D6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "80C7C5": {
        "oui_hex": "80-C7-C5",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E4434B": {
        "oui_hex": "E4-43-4B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "0CF5A4": {
        "oui_hex": "0C-F5-A4",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "9C2EA1": {
        "oui_hex": "9C-2E-A1",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "089734": {
        "oui_hex": "08-97-34",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F09CD7": {
        "oui_hex": "F0-9C-D7",
        "organization": "Guangzhou Blue Cheetah Intelligent Technology Co., Ltd.",
        "address_1": "Panyu District, Guangzhou City Panyu Avenue North 555 Panyu Energy Technology Park,Industry Building 2 seats 406-407",
        "address_2": "Guangzhou  Guangdong   511400",
        "country": "CN"
    },
    "BCE143": {
        "oui_hex": "BC-E1-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "647033": {
        "oui_hex": "64-70-33",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "846878": {
        "oui_hex": "84-68-78",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8D083": {
        "oui_hex": "C8-D0-83",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C6ABC": {
        "oui_hex": "0C-6A-BC",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "0080BA": {
        "oui_hex": "00-80-BA",
        "organization": "SPECIALIX (ASIA) PTE, LTD",
        "address_1": "3 WINTERSELLS ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "US"
    },
    "480BB2": {
        "oui_hex": "48-0B-B2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "CCC079": {
        "oui_hex": "CC-C0-79",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "E019D8": {
        "oui_hex": "E0-19-D8",
        "organization": "BH TECHNOLOGIES",
        "address_1": "12 RUE AMPERE",
        "address_2": "GRENOBLE    38000",
        "country": "FR"
    },
    "6030D4": {
        "oui_hex": "60-30-D4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F895EA": {
        "oui_hex": "F8-95-EA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18F1D8": {
        "oui_hex": "18-F1-D8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CCD5D": {
        "oui_hex": "3C-CD-5D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C7668": {
        "oui_hex": "7C-76-68",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "6C3838": {
        "oui_hex": "6C-38-38",
        "organization": "Marking System Technology Co., Ltd.",
        "address_1": "76-1, Hirakawa Yokomichi",
        "address_2": "Joyo-shi  Kyoto  610-0101",
        "country": "JP"
    },
    "30D9D9": {
        "oui_hex": "30-D9-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "780F77": {
        "oui_hex": "78-0F-77",
        "organization": "HangZhou Gubei Electronics Technology Co.,Ltd",
        "address_1": "HangZhou City, Zhejiang province Binjiang District Jiang Hong Road 611 Building 1 room 106",
        "address_2": "Hangzhou  ZheJiang  310052",
        "country": "CN"
    },
    "A438CC": {
        "oui_hex": "A4-38-CC",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "74721E": {
        "oui_hex": "74-72-1E",
        "organization": "Edison Labs Inc.",
        "address_1": "1122 Stanyan St",
        "address_2": "San Francisco  CA  94117",
        "country": "US"
    },
    "8C4CDC": {
        "oui_hex": "8C-4C-DC",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "Planex Volta Bldg., 2-11-9 Ebisu-Nishi,Shibuya-ku,Tokyo 150-0021,Japan",
        "address_2": "Tokyo  Tokyo  150-0021",
        "country": "JP"
    },
    "5065F3": {
        "oui_hex": "50-65-F3",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "3C9509": {
        "oui_hex": "3C-95-09",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "BCAB7C": {
        "oui_hex": "BC-AB-7C",
        "organization": "TRnP KOREA Co Ltd",
        "address_1": "room1308,239 SoHyungRo,WonMiGu,",
        "address_2": "BuChunCity  KyungKiDo  1135",
        "country": "KR"
    },
    "64CB5D": {
        "oui_hex": "64-CB-5D",
        "organization": "SIA TeleSet",
        "address_1": "Krāslavas iela 5",
        "address_2": "Vecstropi, Naujenes par., Daugavpils distr.    LV-5413",
        "country": "LV"
    },
    "5821E9": {
        "oui_hex": "58-21-E9",
        "organization": "TWPI",
        "address_1": "PMB# 335; 1121 Annapolis Road",
        "address_2": "Odenton  MD  21113",
        "country": "US"
    },
    "C49F4C": {
        "oui_hex": "C4-9F-4C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0C704A": {
        "oui_hex": "0C-70-4A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F0E3DC": {
        "oui_hex": "F0-E3-DC",
        "organization": "Tecon MT, LLC",
        "address_1": "3rd Khoroshevskaya st - 20",
        "address_2": "Moscow    123298",
        "country": "RU"
    },
    "A8DA01": {
        "oui_hex": "A8-DA-01",
        "organization": "Shenzhen NUOLIJIA Digital Technology Co.,Ltd",
        "address_1": "A Area of The Second Flood and D Area of The First Floor,Factory Building A,Youxinda Industrial Park,Gengyu Road,Tianliao Community,Gongming Street Office,Guangming New District,Shenzhen City,Guangdong,P.R.China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "7C2586": {
        "oui_hex": "7C-25-86",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F041C8": {
        "oui_hex": "F0-41-C8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "CC9916": {
        "oui_hex": "CC-99-16",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "EC7FC6": {
        "oui_hex": "EC-7F-C6",
        "organization": "ECCEL CORPORATION SAS",
        "address_1": "CRA 106 15A 25 LT 88 MZ 17 BG 1, ZONA FRANCA BOGOTA",
        "address_2": "BOGOTA  D.C.  110921",
        "country": "CO"
    },
    "4CABFC": {
        "oui_hex": "4C-AB-FC",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0010D8": {
        "oui_hex": "00-10-D8",
        "organization": "CALISTA",
        "address_1": "56A Packhorse Road",
        "address_2": "Bucks SL9 8EF  ENGLAND",
        "country": "GB"
    },
    "002194": {
        "oui_hex": "00-21-94",
        "organization": "Ping Communication",
        "address_1": "Brenden 18",
        "address_2": "Appenzell Meistersrüte  AI  9050",
        "country": "CH"
    },
    "5C5AEA": {
        "oui_hex": "5C-5A-EA",
        "organization": "FORD",
        "address_1": "17425 Federal Drive",
        "address_2": "Allen Park  MI  48101",
        "country": "US"
    },
    "000B7B": {
        "oui_hex": "00-0B-7B",
        "organization": "Test-Um Inc.",
        "address_1": "808 Calle Plano",
        "address_2": "Camarillo  CA  93012",
        "country": "US"
    },
    "30FD38": {
        "oui_hex": "30-FD-38",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001386": {
        "oui_hex": "00-13-86",
        "organization": "ABB Inc/Totalflow",
        "address_1": "123",
        "address_2": "Bartlesville  OK  74006",
        "country": "US"
    },
    "003C10": {
        "oui_hex": "00-3C-10",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "54A65C": {
        "oui_hex": "54-A6-5C",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "BCDDC2": {
        "oui_hex": "BC-DD-C2",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "98D863": {
        "oui_hex": "98-D8-63",
        "organization": "Shanghai High-Flying Electronics Technology Co., Ltd",
        "address_1": "Room 1002 ,#1Building,No.3000 Longdong Avenue,Pudong District,Shanghai,China",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "0CF346": {
        "oui_hex": "0C-F3-46",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "7CFF4D": {
        "oui_hex": "7C-FF-4D",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "C88F26": {
        "oui_hex": "C8-8F-26",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "703A73": {
        "oui_hex": "70-3A-73",
        "organization": "Shenzhen Sundray Technologies Company Limited",
        "address_1": "6th Floor,Block A1, Nanshan iPark, No.1001 XueYuan Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "10F9EB": {
        "oui_hex": "10-F9-EB",
        "organization": "Industria Fueguina de Relojería Electrónica s.a.",
        "address_1": "Sarmiento 2920",
        "address_2": "Rio Grande  Tierra de Fuego  V9420GIV",
        "country": "AR"
    },
    "80AD16": {
        "oui_hex": "80-AD-16",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "044EAF": {
        "oui_hex": "04-4E-AF",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "1894C6": {
        "oui_hex": "18-94-C6",
        "organization": "ShenZhen Chenyee Technology Co., Ltd.",
        "address_1": "32F, Tower A, East Pacific International Center, No.7888, Shennan Avenue, Futian District",
        "address_2": "Shenzhen    518040",
        "country": "CN"
    },
    "40BD32": {
        "oui_hex": "40-BD-32",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "CC8E71": {
        "oui_hex": "CC-8E-71",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "38F554": {
        "oui_hex": "38-F5-54",
        "organization": "HISENSE ELECTRIC CO.,LTD",
        "address_1": "No. 218, Qianwangang Rd",
        "address_2": "Qingdao  Shandong  266555",
        "country": "CN"
    },
    "88E90F": {
        "oui_hex": "88-E9-0F",
        "organization": "innomdlelab",
        "address_1": "Unnam 1 gil, 3",
        "address_2": "Seocho-gu  Seoul  06778",
        "country": "KR"
    },
    "003074": {
        "oui_hex": "00-30-74",
        "organization": "EQUIINET LTD.",
        "address_1": "EDISON HOUSE",
        "address_2": " SWINDON, SN3 5JA",
        "country": "GB"
    },
    "EC9B8B": {
        "oui_hex": "EC-9B-8B",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "B0B3AD": {
        "oui_hex": "B0-B3-AD",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "18A28A": {
        "oui_hex": "18-A2-8A",
        "organization": "Essel-T Co., Ltd",
        "address_1": "1211 kranztechno, 388 Dunchon-daero",
        "address_2": "Seongnam-si  Jungwon-gu, Gyeonggi-do  13403",
        "country": "KR"
    },
    "20365B": {
        "oui_hex": "20-36-5B",
        "organization": "Megafone Limited",
        "address_1": "Unit 702,7/F,Bankok Bank Building,NO.18 Bonham Strand West",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "E8DE00": {
        "oui_hex": "E8-DE-00",
        "organization": "ChongQing GuanFang Technology Co.,LTD",
        "address_1": "2F, A District,No.3 Middle Section of Mount Huangshan Avenue",
        "address_2": "ChongQing  ChongQing  401121",
        "country": "CN"
    },
    "70C94E": {
        "oui_hex": "70-C9-4E",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "70D081": {
        "oui_hex": "70-D0-81",
        "organization": "Beijing Netpower Technologies Inc.",
        "address_1": "Room 201, Block B, NO. 15 Building, EastZone",
        "address_2": "Courtyard10, Xibeiwang East Road  Haidian District, Beijing  100094",
        "country": "CN"
    },
    "FC643A": {
        "oui_hex": "FC-64-3A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A8515B": {
        "oui_hex": "A8-51-5B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54B7E5": {
        "oui_hex": "54-B7-E5",
        "organization": "Rayson Technology Co., Ltd.",
        "address_1": "1F No.9 R&D Rd.II, Science-Based Industrial Park",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "946372": {
        "oui_hex": "94-63-72",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "BC0FA7": {
        "oui_hex": "BC-0F-A7",
        "organization": "Ouster",
        "address_1": "350 Treat Ave",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "F8C120": {
        "oui_hex": "F8-C1-20",
        "organization": "Xi'an Link-Science Technology Co.,Ltd",
        "address_1": "1/F，Block F,Building zhichao Weilai,No.999,10#Caotan Road,Xi'an",
        "address_2": "xi'an    710016",
        "country": "CN"
    },
    "F0C9D1": {
        "oui_hex": "F0-C9-D1",
        "organization": "GD Midea Air-Conditioning Equipment Co.,Ltd.",
        "address_1": "Midea Global Innovation Center,Beijiao Town,Shunde",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "347E5C": {
        "oui_hex": "34-7E-5C",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "B4FBF9": {
        "oui_hex": "B4-FB-F9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "506F77": {
        "oui_hex": "50-6F-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0C41E9": {
        "oui_hex": "0C-41-E9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3CE824": {
        "oui_hex": "3C-E8-24",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "345A06": {
        "oui_hex": "34-5A-06",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "001936": {
        "oui_hex": "00-19-36",
        "organization": "STERLITE OPTICAL TECHNOLOGIES LIMITED",
        "address_1": "E-1,E-2,&E-3",
        "address_2": "AURANGABAD  MAHARASTRA  431136",
        "country": "IN"
    },
    "B89F09": {
        "oui_hex": "B8-9F-09",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "0402CA": {
        "oui_hex": "04-02-CA",
        "organization": "Shenzhen Vtsonic Co.,ltd",
        "address_1": "No.35,the 2nd Industrial Zone,Tangxiayong Village,Songgang Town,Bao'an District,Shenzhen,China.",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "3CFB5C": {
        "oui_hex": "3C-FB-5C",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "7440BB": {
        "oui_hex": "74-40-BB",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "1C1161": {
        "oui_hex": "1C-11-61",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "B4DE31": {
        "oui_hex": "B4-DE-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A44027": {
        "oui_hex": "A4-40-27",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B4F7A1": {
        "oui_hex": "B4-F7-A1",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "28EDE0": {
        "oui_hex": "28-ED-E0",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "88BD45": {
        "oui_hex": "88-BD-45",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54FCF0": {
        "oui_hex": "54-FC-F0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "306A85": {
        "oui_hex": "30-6A-85",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4CDD31": {
        "oui_hex": "4C-DD-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88B6EE": {
        "oui_hex": "88-B6-EE",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "70F220": {
        "oui_hex": "70-F2-20",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "D0817A": {
        "oui_hex": "D0-81-7A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98CA33": {
        "oui_hex": "98-CA-33",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68AB1E": {
        "oui_hex": "68-AB-1E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70EF00": {
        "oui_hex": "70-EF-00",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C87765": {
        "oui_hex": "C8-77-65",
        "organization": "Tiesse SpA",
        "address_1": "Via Asti",
        "address_2": "Ivrea  TO  10015",
        "country": "IT"
    },
    "2C37C5": {
        "oui_hex": "2C-37-C5",
        "organization": "Qingdao Haier Intelligent Home Appliance Technology Co.,Ltd",
        "address_1": "ingdao high-tech park haier road 1",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "CC40D0": {
        "oui_hex": "CC-40-D0",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7C7630": {
        "oui_hex": "7C-76-30",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "9822EF": {
        "oui_hex": "98-22-EF",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "788038": {
        "oui_hex": "78-80-38",
        "organization": "FUNAI ELECTRIC CO., LTD.",
        "address_1": "7-1, NAKAGAITO 7-CHOME",
        "address_2": "DAITO  OSAKA  5740013",
        "country": "JP"
    },
    "BCFFEB": {
        "oui_hex": "BC-FF-EB",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "000130": {
        "oui_hex": "00-01-30",
        "organization": "Extreme Networks, Inc.",
        "address_1": "3585 Monroe Street",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "FC0A81": {
        "oui_hex": "FC-0A-81",
        "organization": "Extreme Networks, Inc.",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "F045DA": {
        "oui_hex": "F0-45-DA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B80716": {
        "oui_hex": "B8-07-16",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "A8EEC6": {
        "oui_hex": "A8-EE-C6",
        "organization": "Muuselabs NV/SA",
        "address_1": "Rue du Tocsin 12",
        "address_2": "Brussels    1000",
        "country": "BE"
    },
    "E4F042": {
        "oui_hex": "E4-F0-42",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "4048FD": {
        "oui_hex": "40-48-FD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "20B399": {
        "oui_hex": "20-B3-99",
        "organization": "Enterasys",
        "address_1": "50 Minuteman Rd",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "CC2D21": {
        "oui_hex": "CC-2D-21",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "004097": {
        "oui_hex": "00-40-97",
        "organization": "DATEX DIVISION OF",
        "address_1": "INSTRUMENTARIUM CORP.",
        "address_2": "",
        "country": "FI"
    },
    "9C4FCF": {
        "oui_hex": "9C-4F-CF",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "D896E0": {
        "oui_hex": "D8-96-E0",
        "organization": "Alibaba Cloud Computing Ltd.",
        "address_1": "Yuhang District of Hangzhou Wenyi Road, Building 1, No. 969 Xixi Park, Zhejiang Province",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "001862": {
        "oui_hex": "00-18-62",
        "organization": "Seagate Technology",
        "address_1": "1280 Disc Drive",
        "address_2": "Shakopee  MN  55379",
        "country": "US"
    },
    "1CEEC9": {
        "oui_hex": "1C-EE-C9",
        "organization": "Elo touch solutions",
        "address_1": "1033 McCarthy Boulevard",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000C50": {
        "oui_hex": "00-0C-50",
        "organization": "Seagate Technology",
        "address_1": "M/S NW1F01",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "342AF1": {
        "oui_hex": "34-2A-F1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "207852": {
        "oui_hex": "20-78-52",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "C8DEC9": {
        "oui_hex": "C8-DE-C9",
        "organization": "Coriant",
        "address_1": "1415 W. Diehl Rd",
        "address_2": "Naperville  IL  60563",
        "country": "US"
    },
    "44D5A5": {
        "oui_hex": "44-D5-A5",
        "organization": "AddOn Computer",
        "address_1": "15775 Gateway cir",
        "address_2": "tustin  CA  92780",
        "country": "US"
    },
    "38F73D": {
        "oui_hex": "38-F7-3D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "C0A00D": {
        "oui_hex": "C0-A0-0D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0C6111": {
        "oui_hex": "0C-61-11",
        "organization": "Anda Technologies SAC",
        "address_1": "Av. Santa Cruz 888, Miraflores",
        "address_2": "Lima  Peru  Lima18",
        "country": "PE"
    },
    "0022C4": {
        "oui_hex": "00-22-C4",
        "organization": "epro GmbH",
        "address_1": "Joebkesweg 3",
        "address_2": "Gronau  NRW  48599",
        "country": "DE"
    },
    "1C330E": {
        "oui_hex": "1C-33-0E",
        "organization": "PernixData",
        "address_1": "1745 Technology Drive, Suite 800",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "B8F74A": {
        "oui_hex": "B8-F7-4A",
        "organization": "RCNTEC",
        "address_1": "Polkovaya street 3",
        "address_2": "Moscow    127018",
        "country": "RU"
    },
    "645106": {
        "oui_hex": "64-51-06",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "0C1539": {
        "oui_hex": "0C-15-39",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C5697": {
        "oui_hex": "6C-56-97",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0005FF": {
        "oui_hex": "00-05-FF",
        "organization": "SNS Solutions, Inc.",
        "address_1": "2nd Fl. Hill House,",
        "address_2": "",
        "country": "KR"
    },
    "F87B20": {
        "oui_hex": "F8-7B-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0AADB": {
        "oui_hex": "E0-AA-DB",
        "organization": "Nanjing PANENG Technology Development Co.,Ltd",
        "address_1": "NO.6 Paneng Road,Nanjing High-tech Zone,Jiang Su,China",
        "address_2": "Nanjing     210061",
        "country": "CN"
    },
    "ECF451": {
        "oui_hex": "EC-F4-51",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "581243": {
        "oui_hex": "58-12-43",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F., No.22, Dalin Rd.,",
        "address_2": "Taoyuan  Taoyuan County  33067",
        "country": "TW"
    },
    "A89FEC": {
        "oui_hex": "A8-9F-EC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00BE9E": {
        "oui_hex": "00-BE-9E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "54C57A": {
        "oui_hex": "54-C5-7A",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "58C17A": {
        "oui_hex": "58-C1-7A",
        "organization": "Cambium Networks Limited",
        "address_1": "Unit B2, Linhay Business Park,",
        "address_2": "Ashburton  Devon  TQ13 7UP",
        "country": "GB"
    },
    "38019F": {
        "oui_hex": "38-01-9F",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "245CCB": {
        "oui_hex": "24-5C-CB",
        "organization": "AXIe Consortium, Inc.",
        "address_1": "P.O. Box 1016",
        "address_2": "Niwot  CO  80544-1016",
        "country": "US"
    },
    "609BC8": {
        "oui_hex": "60-9B-C8",
        "organization": "Hipad Intelligent Technology Co., Ltd.",
        "address_1": "No. 688, East of Huangtang Street, LinkongEconomy District",
        "address_2": "Nanchang  Jiangxi  330000",
        "country": "CN"
    },
    "406A8E": {
        "oui_hex": "40-6A-8E",
        "organization": "Hangzhou Puwell OE Tech Ltd.",
        "address_1": "Letel Technology Park, 500 Qiuyi Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "1C0FAF": {
        "oui_hex": "1C-0F-AF",
        "organization": "Lucid Vision Labs",
        "address_1": "Unit 130 - 13200 Delf Place",
        "address_2": "Richmond  BC  V6V2A2",
        "country": "CA"
    },
    "88B4A6": {
        "oui_hex": "88-B4-A6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "28CF08": {
        "oui_hex": "28-CF-08",
        "organization": "ESSYS",
        "address_1": "gaetbeol-ro",
        "address_2": "Incheon    21999",
        "country": "KR"
    },
    "002128": {
        "oui_hex": "00-21-28",
        "organization": "Oracle Corporation",
        "address_1": "17 Network Circle",
        "address_2": "Menlo Park  CA  95025",
        "country": "US"
    },
    "001C73": {
        "oui_hex": "00-1C-73",
        "organization": "Arista Networks",
        "address_1": "5470 Great America Pkwy",
        "address_2": "Santa Clara    95054",
        "country": "US"
    },
    "2C8A72": {
        "oui_hex": "2C-8A-72",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "38AD8E": {
        "oui_hex": "38-AD-8E",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "34D0B8": {
        "oui_hex": "34-D0-B8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D06726": {
        "oui_hex": "D0-67-26",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "ECFAF4": {
        "oui_hex": "EC-FA-F4",
        "organization": "SenRa Tech Pvt. Ltd",
        "address_1": "133, First Floor, Lane No. 1, Westend Marg, Saidulajab",
        "address_2": "New Delhi    110030",
        "country": "IN"
    },
    "D88F76": {
        "oui_hex": "D8-8F-76",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "409C28": {
        "oui_hex": "40-9C-28",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5CA176": {
        "oui_hex": "5C-A1-76",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "583879": {
        "oui_hex": "58-38-79",
        "organization": "RICOH COMPANY, LTD.",
        "address_1": "1005, Shimo-ogino",
        "address_2": "Atsugi-City  Kanagawa-Pref.  243-0298",
        "country": "JP"
    },
    "F44C70": {
        "oui_hex": "F4-4C-70",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C8E7F0": {
        "oui_hex": "C8-E7-F0",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B0935B": {
        "oui_hex": "B0-93-5B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F449EF": {
        "oui_hex": "F4-49-EF",
        "organization": "EMSTONE",
        "address_1": "#310, Ace Techno Tower 3rd, 38 Digital-ro-29-gil",
        "address_2": "Guro-Gu  Seoul  08381",
        "country": "KR"
    },
    "54DF24": {
        "oui_hex": "54-DF-24",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "AC1DDF": {
        "oui_hex": "AC-1D-DF",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E8D819": {
        "oui_hex": "E8-D8-19",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "782D7E": {
        "oui_hex": "78-2D-7E",
        "organization": "TRENDnet, Inc.",
        "address_1": "20675 Manhattan Place",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "741AE0": {
        "oui_hex": "74-1A-E0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "24B209": {
        "oui_hex": "24-B2-09",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "FC65DE": {
        "oui_hex": "FC-65-DE",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "B06EBF": {
        "oui_hex": "B0-6E-BF",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "603D26": {
        "oui_hex": "60-3D-26",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "BC903A": {
        "oui_hex": "BC-90-3A",
        "organization": "Robert Bosch GmbH",
        "address_1": "Postfach 1661",
        "address_2": "Leonberg    71226",
        "country": "DE"
    },
    "D0B128": {
        "oui_hex": "D0-B1-28",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC5451": {
        "oui_hex": "BC-54-51",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "74860B": {
        "oui_hex": "74-86-0B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "182D98": {
        "oui_hex": "18-2D-98",
        "organization": "Jinwoo Industrial system",
        "address_1": "7F,Jinwoo Building,149 dosan-daero",
        "address_2": "seoul  gangnamgu  06036",
        "country": "KR"
    },
    "D8A534": {
        "oui_hex": "D8-A5-34",
        "organization": "Spectronix Corporation",
        "address_1": "3-28-15, Tarumi-cho",
        "address_2": "Suita-city  Osaka  564-0062",
        "country": "JP"
    },
    "EC51BC": {
        "oui_hex": "EC-51-BC",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "F079E8": {
        "oui_hex": "F0-79-E8",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "78321B": {
        "oui_hex": "78-32-1B",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "601803": {
        "oui_hex": "60-18-03",
        "organization": "Daikin Air-conditioning (Shanghai) Co., Ltd.",
        "address_1": "318 Shen Fu Road, Xin Zhuang Industry Zone, Shanghai, 201108, China",
        "address_2": "Shanghai    201108",
        "country": "CN"
    },
    "00A096": {
        "oui_hex": "00-A0-96",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "78617C": {
        "oui_hex": "78-61-7C",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "940E6B": {
        "oui_hex": "94-0E-6B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "64FB50": {
        "oui_hex": "64-FB-50",
        "organization": "RoomReady/Zdi, Inc.",
        "address_1": "2200 N. Main Street",
        "address_2": "Normal  IL  61761",
        "country": "US"
    },
    "74EAC8": {
        "oui_hex": "74-EA-C8",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "B4D64E": {
        "oui_hex": "B4-D6-4E",
        "organization": "Caldero Limited",
        "address_1": "Concordia Works, 30 Sovereign Street",
        "address_2": "Leeds  West Yorkshire  LS1 4BA",
        "country": "GB"
    },
    "F89DBB": {
        "oui_hex": "F8-9D-BB",
        "organization": "Tintri",
        "address_1": "303 Ravendale Dr",
        "address_2": "Mountain View  CA  94070",
        "country": "US"
    },
    "D8A01D": {
        "oui_hex": "D8-A0-1D",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "C4F312": {
        "oui_hex": "C4-F3-12",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "904E91": {
        "oui_hex": "90-4E-91",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "5CE8B7": {
        "oui_hex": "5C-E8-B7",
        "organization": "Oraimo Technology Limited",
        "address_1": "RMS 05-15，13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HONG KONG  HONG KONG  999077",
        "country": "HK"
    },
    "3C11B2": {
        "oui_hex": "3C-11-B2",
        "organization": "Fraunhofer FIT",
        "address_1": "Schloss Birlinghoven",
        "address_2": "Sankt Augustin    53754",
        "country": "DE"
    },
    "104B46": {
        "oui_hex": "10-4B-46",
        "organization": "Mitsubishi Electric Corporation",
        "address_1": "2-7-3",
        "address_2": "Chiyoda-ku  Tokyo  100-8310",
        "country": "JP"
    },
    "DC0C2D": {
        "oui_hex": "DC-0C-2D",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road, Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "D067E5": {
        "oui_hex": "D0-67-E5",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "8CFEB4": {
        "oui_hex": "8C-FE-B4",
        "organization": "VSOONTECH ELECTRONICS CO., LIMITED",
        "address_1": "18th, Floor, On Hong Commericial Building, 145 Hennessy Road, Wanchai, HONG KONG",
        "address_2": "HongKong    999077",
        "country": "HK"
    },
    "CC66B2": {
        "oui_hex": "CC-66-B2",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "9C65EE": {
        "oui_hex": "9C-65-EE",
        "organization": "DASAN Network Solutions",
        "address_1": "DASAN Tower 8F, 49 Daewangpangyo-ro644beon-gil Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13493",
        "country": "KR"
    },
    "78CA04": {
        "oui_hex": "78-CA-04",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "34298F": {
        "oui_hex": "34-29-8F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "5CEA1D": {
        "oui_hex": "5C-EA-1D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "181456": {
        "oui_hex": "18-14-56",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "0017C8": {
        "oui_hex": "00-17-C8",
        "organization": "KYOCERA Display Corporation",
        "address_1": "2-14-9, Tamagawadai",
        "address_2": "Tokyo    158-8610",
        "country": "JP"
    },
    "38E2DD": {
        "oui_hex": "38-E2-DD",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "885DFB": {
        "oui_hex": "88-5D-FB",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "58B42D": {
        "oui_hex": "58-B4-2D",
        "organization": "YSTen Technology Co.,Ltd",
        "address_1": "Room 1715,17/F North Star Times Tower,Chaoyang District,Beijing.",
        "address_2": "Beijing    100101",
        "country": "CN"
    },
    "E048D3": {
        "oui_hex": "E0-48-D3",
        "organization": "MOBIWIRE MOBILES (NINGBO) CO.,LTD",
        "address_1": "No.999,Dacheng East Road,",
        "address_2": "Fenghua  Zhejiang  315500",
        "country": "CN"
    },
    "58E28F": {
        "oui_hex": "58-E2-8F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "787B8A": {
        "oui_hex": "78-7B-8A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C16FC": {
        "oui_hex": "4C-16-FC",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "48BCA6": {
        "oui_hex": "48-BC-A6",
        "organization": "​ASUNG TECHNO CO.,Ltd",
        "address_1": "462, Dogok-ro, Songpa-gu, Seoul, Republic of Korea",
        "address_2": "SEOUL  Repubilc of KOREA  05574",
        "country": "KR"
    },
    "B009DA": {
        "oui_hex": "B0-09-DA",
        "organization": "Ring Solutions",
        "address_1": "1200 Atwater Drive, Suite 225",
        "address_2": "Malvern  PA  19355",
        "country": "US"
    },
    "00054F": {
        "oui_hex": "00-05-4F",
        "organization": "Garmin International",
        "address_1": "1200 E. 151st St",
        "address_2": "Olathe  KS  66062",
        "country": "US"
    },
    "005C86": {
        "oui_hex": "00-5C-86",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "30053F": {
        "oui_hex": "30-05-3F",
        "organization": "JTI Co.,Ltd.",
        "address_1": "102-1508, 36, Bucheon-ro 198beon-gil,",
        "address_2": "Buchcheon-si  Gyeonggi-do  14557",
        "country": "KR"
    },
    "B8DB1C": {
        "oui_hex": "B8-DB-1C",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "3C10E6": {
        "oui_hex": "3C-10-E6",
        "organization": "PHAZR Inc.",
        "address_1": "8, Presitige Circle, Suite 104",
        "address_2": "Allen  TX  75002",
        "country": "US"
    },
    "904506": {
        "oui_hex": "90-45-06",
        "organization": "Tokyo Boeki Medisys Inc.",
        "address_1": "1-14-21, Higashitoyoda",
        "address_2": " Hino  Tokyo  191-0052",
        "country": "JP"
    },
    "0021A1": {
        "oui_hex": "00-21-A1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "FCB698": {
        "oui_hex": "FC-B6-98",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22 Floor,Qilai Tower;889 Yishan Road",
        "address_2": "Shanghai  CHINA  200233",
        "country": "CN"
    },
    "0001CD": {
        "oui_hex": "00-01-CD",
        "organization": "ARtem",
        "address_1": "Olgastraße 152",
        "address_2": "",
        "country": "DE"
    },
    "5C546D": {
        "oui_hex": "5C-54-6D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "84A1D1": {
        "oui_hex": "84-A1-D1",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "909D7D": {
        "oui_hex": "90-9D-7D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "788C4D": {
        "oui_hex": "78-8C-4D",
        "organization": "Indyme Solutions, LLC",
        "address_1": "8295 Aero Place Ste 260",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "78BC1A": {
        "oui_hex": "78-BC-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E59": {
        "oui_hex": "00-0E-59",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "2, rue du petit Albi",
        "address_2": "CERGY SAINT CHRISTOPHE  val d'Oise  95800",
        "country": "FR"
    },
    "101D51": {
        "oui_hex": "10-1D-51",
        "organization": "8Mesh Networks Limited",
        "address_1": "Unit 607, 6/F, Yen Sheng Centre,",
        "address_2": "64 Hoi Yuen Road  Kwun Tong  000",
        "country": "HK"
    },
    "DCEB53": {
        "oui_hex": "DC-EB-53",
        "organization": "Wuhan QianXiao Elecronic Technology CO.,LTD",
        "address_1": "Guanggu Xinzhongxin, No.303 of Guanggu road, East lake development zone",
        "address_2": "wuhan  hubei  430000",
        "country": "CN"
    },
    "EC8AC7": {
        "oui_hex": "EC-8A-C7",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "88365F": {
        "oui_hex": "88-36-5F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "288CB8": {
        "oui_hex": "28-8C-B8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "FC7F56": {
        "oui_hex": "FC-7F-56",
        "organization": "CoSyst Control Systems GmbH",
        "address_1": "Martin-Albert-Str. 1",
        "address_2": "Nürnberg  Bayern  90491",
        "country": "DE"
    },
    "2C4053": {
        "oui_hex": "2C-40-53",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "0C8FFF": {
        "oui_hex": "0C-8F-FF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "54B121": {
        "oui_hex": "54-B1-21",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "788102": {
        "oui_hex": "78-81-02",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "84AA9C": {
        "oui_hex": "84-AA-9C",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "F0EFD2": {
        "oui_hex": "F0-EF-D2",
        "organization": "TF PAYMENT SERVICE CO., LTD",
        "address_1": "5F Shibadaimon Center Building, 1-10-11 Shibadaimon",
        "address_2": "Minato-ku  Tokyo  105-0012",
        "country": "JP"
    },
    "24B2DE": {
        "oui_hex": "24-B2-DE",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F4939F": {
        "oui_hex": "F4-93-9F",
        "organization": "Hon Hai Precision Ind. Co., Ltd.",
        "address_1": "GuangDongShenZhen",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "000726": {
        "oui_hex": "00-07-26",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "A211-A213 & B201-B210, 2F, Baiying Building, 1019#, Nanhai RD, Shekou Party, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "FC8B97": {
        "oui_hex": "FC-8B-97",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "B116,B118,A211-A213,B201-B213,A311-A313,B411-413,BF08-09 Nanshan Medical Instrument Industry Park,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "2CAB25": {
        "oui_hex": "2C-AB-25",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "B116,B118,A211-A213,B201-B213,A311-A313,B411-413,BF08-09 Nanshan Medical Instrument Industry Park,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "1CA532": {
        "oui_hex": "1C-A5-32",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "1#SongGang RD, Bao'an Dist., Shenzhen, Guangdong,China",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "001F92": {
        "oui_hex": "00-1F-92",
        "organization": "Avigilon Corporation",
        "address_1": "Box 378, 101 - 1001 West Broadway",
        "address_2": "Vancouver  BC  V6H 4E4",
        "country": "CA"
    },
    "000C03": {
        "oui_hex": "00-0C-03",
        "organization": "HDMI Licensing, LLC",
        "address_1": "1060 East Arques Ave.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "7CBACC": {
        "oui_hex": "7C-BA-CC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "94F128": {
        "oui_hex": "94-F1-28",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville    95747",
        "country": "US"
    },
    "101B54": {
        "oui_hex": "10-1B-54",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "A80C63": {
        "oui_hex": "A8-0C-63",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5CC307": {
        "oui_hex": "5C-C3-07",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E0107F": {
        "oui_hex": "E0-10-7F",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C4017C": {
        "oui_hex": "C4-01-7C",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "04FA3F": {
        "oui_hex": "04-FA-3F",
        "organization": "Opticore Inc.",
        "address_1": "97 Jungbudaero448beongil, Yeongtonggu",
        "address_2": "Suwonsi  Gyeonggido  16521",
        "country": "KR"
    },
    "540237": {
        "oui_hex": "54-02-37",
        "organization": "Teltronic AG",
        "address_1": "Gewerbestrasse 9",
        "address_2": "Biberist    4562",
        "country": "CH"
    },
    "4CB008": {
        "oui_hex": "4C-B0-08",
        "organization": "Shenzhen Gwelltimes Technology Co.,Ltd",
        "address_1": "A4 building 15floor Zhongying Jewelry Industrial Park Bulan Road No.31 Nanwan Street Longgang District Shenzhen City China",
        "address_2": "Shenzhen    518112",
        "country": "CN"
    },
    "E86FF2": {
        "oui_hex": "E8-6F-F2",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "005018": {
        "oui_hex": "00-50-18",
        "organization": "AMIT, Inc.",
        "address_1": "No.32, Huangong Rd.,",
        "address_2": "Yongkang City,  Tainan County  71041",
        "country": "TW"
    },
    "70DEF9": {
        "oui_hex": "70-DE-F9",
        "organization": "FAI WAH INTERNATIONAL (HONG KONG) LIMITED",
        "address_1": "Room 19, 8F.,Corporation Park, 11 On Lai Street,Shatin,Shek Mun,N.T.Hong Kong",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "B0EABC": {
        "oui_hex": "B0-EA-BC",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "94C691": {
        "oui_hex": "94-C6-91",
        "organization": "EliteGroup Computer Systems Co., LTD",
        "address_1": "No.239, Sec. 2, TiDing Blvd. Nei-Hu Dist.",
        "address_2": "Taipei  Taiwan  11439",
        "country": "TW"
    },
    "3CF591": {
        "oui_hex": "3C-F5-91",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "602101": {
        "oui_hex": "60-21-01",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "7CEB7F": {
        "oui_hex": "7C-EB-7F",
        "organization": "Dmet Products Corp.",
        "address_1": "118, Fujisoft Akihabara Bldg 12F, Kanda Neribeicho 3",
        "address_2": "Chiyodaku  Tokyo  1010022",
        "country": "JP"
    },
    "8C8580": {
        "oui_hex": "8C-85-80",
        "organization": "Smart Innovation LLC",
        "address_1": "7F,Tower B,Jianxing",
        "address_2": "ShenZhen  GuangZhou  518055",
        "country": "CN"
    },
    "404229": {
        "oui_hex": "40-42-29",
        "organization": "Layer3TV, Inc",
        "address_1": "1660 Wynkoop St - Suite 800",
        "address_2": "Denver  CO  80202",
        "country": "US"
    },
    "FC2F6B": {
        "oui_hex": "FC-2F-6B",
        "organization": "Everspin Technologies, Inc.",
        "address_1": "1347 N. Alma School Rd., Suite 220",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "287B09": {
        "oui_hex": "28-7B-09",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0025C4": {
        "oui_hex": "00-25-C4",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C0C520": {
        "oui_hex": "C0-C5-20",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "78B28D": {
        "oui_hex": "78-B2-8D",
        "organization": "Beijing Tengling Technology CO.Ltd",
        "address_1": "beijing haidian shangdi san jie",
        "address_2": "beijing    100086",
        "country": "CN"
    },
    "A88038": {
        "oui_hex": "A8-80-38",
        "organization": "ShenZhen MovingComm Technology Co., Limited",
        "address_1": "5F, FuXinFa Industrial Park, LiuXianDong Industrial Zone,",
        "address_2": "ShenZhen  GuangDong   518055",
        "country": "CN"
    },
    "F81D90": {
        "oui_hex": "F8-1D-90",
        "organization": "Solidwintech",
        "address_1": "6th Floor, SOLiD Space 220 Pangyoyeok-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeongi-do  13493",
        "country": "KR"
    },
    "A06A44": {
        "oui_hex": "A0-6A-44",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "DCBE7A": {
        "oui_hex": "DC-BE-7A",
        "organization": "Zhejiang Nurotron Biotechnology Co.",
        "address_1": "Building4, No.99 Xiaomao Rd",
        "address_2": "Hangzhou  zhejiang  310011",
        "country": "CN"
    },
    "3438B7": {
        "oui_hex": "34-38-B7",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "CC0677": {
        "oui_hex": "CC-06-77",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "784501": {
        "oui_hex": "78-45-01",
        "organization": "Biamp Systems",
        "address_1": "9300 SW Gemini Dr",
        "address_2": "Beaverton  OR  97008",
        "country": "US"
    },
    "309C23": {
        "oui_hex": "30-9C-23",
        "organization": "Micro-Star INTL CO., LTD.",
        "address_1": "No.69, Lide St.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "54D751": {
        "oui_hex": "54-D7-51",
        "organization": "Proximus",
        "address_1": "Bld du Roi Albert II 27",
        "address_2": "Brussels    1030",
        "country": "BE"
    },
    "14780B": {
        "oui_hex": "14-78-0B",
        "organization": "Varex Imaging Deutschland AG",
        "address_1": "Zweigniederlassung/Branch Walluf",
        "address_2": "In der Rehbach 22  Walluf  65396",
        "country": "DE"
    },
    "ACAFB9": {
        "oui_hex": "AC-AF-B9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88B111": {
        "oui_hex": "88-B1-11",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "8C395C": {
        "oui_hex": "8C-39-5C",
        "organization": "Bit4id Srl",
        "address_1": "Via Diocleziano, 107",
        "address_2": "Naples    80125",
        "country": "IT"
    },
    "D4258B": {
        "oui_hex": "D4-25-8B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "041B6D": {
        "oui_hex": "04-1B-6D",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F44156": {
        "oui_hex": "F4-41-56",
        "organization": "Arrikto Inc.",
        "address_1": "3505 El Camino Real",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "0080C2": {
        "oui_hex": "00-80-C2",
        "organization": "IEEE 802.1 Working Group",
        "address_1": "802.1 CHAIR c/o IEEE",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "688DB6": {
        "oui_hex": "68-8D-B6",
        "organization": "AETEK INC.",
        "address_1": " 3F, No.192, Lien-Cheng Rd., Chung-Ho,",
        "address_2": " New Taipei City    23553",
        "country": "TW"
    },
    "ECF342": {
        "oui_hex": "EC-F3-42",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "50FF20": {
        "oui_hex": "50-FF-20",
        "organization": "Keenetic Limited",
        "address_1": "1202, 12/F., AT TOWER, 180 ELECTRIC ROAD, NORTH POINT",
        "address_2": "HONG KONG    852",
        "country": "HK"
    },
    "E45740": {
        "oui_hex": "E4-57-40",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F894C2": {
        "oui_hex": "F8-94-C2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "70D379": {
        "oui_hex": "70-D3-79",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00F82C": {
        "oui_hex": "00-F8-2C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00C1B1": {
        "oui_hex": "00-C1-B1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4FCB1": {
        "oui_hex": "F4-FC-B1",
        "organization": "JJ Corp",
        "address_1": "88 Soha-ro",
        "address_2": "Gwangmyeong-si    14316",
        "country": "KR"
    },
    "D8C8E9": {
        "oui_hex": "D8-C8-E9",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "7CB960": {
        "oui_hex": "7C-B9-60",
        "organization": "Shanghai X-Cheng telecom LTD",
        "address_1": "ROOM 401, Building 5, No.3000 LONG DONG Avenue, Pudong New District, Shanghai",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "B03D96": {
        "oui_hex": "B0-3D-96",
        "organization": "Vision Valley FZ LLC",
        "address_1": "Dubai Internet City",
        "address_2": "Dubai  Dubai  500294",
        "country": "AE"
    },
    "986C5C": {
        "oui_hex": "98-6C-5C",
        "organization": "Jiangxi Gosun Guard Security Co.,Ltd",
        "address_1": "2rd floor,8 building Middle,Zhongxing Software Park,Changdong Avenue,Nanchang High Tech Zone,Nanchang city,Jiangxi province",
        "address_2": "Nan Chang City  Jiang Xi Province  330000",
        "country": "CN"
    },
    "24792A": {
        "oui_hex": "24-79-2A",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "30D386": {
        "oui_hex": "30-D3-86",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "70DB98": {
        "oui_hex": "70-DB-98",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B42A0E": {
        "oui_hex": "B4-2A-0E",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "9CC8AE": {
        "oui_hex": "9C-C8-AE",
        "organization": "Becton, Dickinson  and Company",
        "address_1": "1 Becton Drive",
        "address_2": "Franklin Lakes  MA   07417-1880",
        "country": "US"
    },
    "B0359F": {
        "oui_hex": "B0-35-9F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C0D962": {
        "oui_hex": "C0-D9-62",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,JIANKANG RD.,ZHONGHE DIST XINBEI CITY",
        "address_2": "taipei  TAIPEI  23585",
        "country": "TW"
    },
    "F80BCB": {
        "oui_hex": "F8-0B-CB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "50D37F": {
        "oui_hex": "50-D3-7F",
        "organization": "Yu Fly Mikly Way Science and Technology Co., Ltd.",
        "address_1": "6F, No. 1168 Huyi Road, Nanxiang Town Jiading District Shanghai 201800 CHINA",
        "address_2": "shanghai    201800",
        "country": "CN"
    },
    "181212": {
        "oui_hex": "18-12-12",
        "organization": "Cepton Technologies",
        "address_1": "103 Bonaventura Dr",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "70D923": {
        "oui_hex": "70-D9-23",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'an  DongGuan City,Guangdong  523860",
        "country": "CN"
    },
    "B83A08": {
        "oui_hex": "B8-3A-08",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "28B448": {
        "oui_hex": "28-B4-48",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "100501": {
        "oui_hex": "10-05-01",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "2CFAA2": {
        "oui_hex": "2C-FA-A2",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Rd",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "A49BF5": {
        "oui_hex": "A4-9B-F5",
        "organization": "Hybridserver Tec GmbH",
        "address_1": "Gutenbergring 26a",
        "address_2": "Norderstedt  Schleswig-Holstein  22848",
        "country": "DE"
    },
    "503DA1": {
        "oui_hex": "50-3D-A1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "F097E5": {
        "oui_hex": "F0-97-E5",
        "organization": "TAMIO, INC",
        "address_1": "12F-2, No.33, Sec. 1 , Mingsheng Rd.,Banqiao Dist",
        "address_2": "New Taipei City    22069",
        "country": "TW"
    },
    "4C1A3D": {
        "oui_hex": "4C-1A-3D",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "08028E": {
        "oui_hex": "08-02-8E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E8E732": {
        "oui_hex": "E8-E7-32",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "B47C9C": {
        "oui_hex": "B4-7C-9C",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "F4A739": {
        "oui_hex": "F4-A7-39",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F470AB": {
        "oui_hex": "F4-70-AB",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "2C5A0F": {
        "oui_hex": "2C-5A-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2C3124": {
        "oui_hex": "2C-31-24",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "503237": {
        "oui_hex": "50-32-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B0481A": {
        "oui_hex": "B0-48-1A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B49CDF": {
        "oui_hex": "B4-9C-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48BF6B": {
        "oui_hex": "48-BF-6B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C1DB8": {
        "oui_hex": "2C-1D-B8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "58821D": {
        "oui_hex": "58-82-1D",
        "organization": "H. Schomäcker GmbH",
        "address_1": "Heidestr. 183",
        "address_2": "Köln    51147",
        "country": "DE"
    },
    "D8A105": {
        "oui_hex": "D8-A1-05",
        "organization": "Syslane, Co., Ltd.",
        "address_1": "#1201, Megacenter, SKntechno-park,, Sangdaeweon-dong, Joongweon-gu",
        "address_2": "Seongnam  Outside the US, Mexico, or Canada  462-721",
        "country": "KR"
    },
    "BCA042": {
        "oui_hex": "BC-A0-42",
        "organization": "SHANGHAI FLYCO ELECTRICAL APPLIANCE CO.,LTD",
        "address_1": "No.555,Guang Fu Lin east Road,Songjiang District",
        "address_2": "Shanghai  Shanghai  201613",
        "country": "CN"
    },
    "3C0518": {
        "oui_hex": "3C-05-18",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "900628": {
        "oui_hex": "90-06-28",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B4A9FE": {
        "oui_hex": "B4-A9-FE",
        "organization": "GHIA Technology (Shenzhen) LTD",
        "address_1": "RM 1606, BLDG 3rd, COFCO Clouds Mansion",
        "address_2": "Shenzhen    518101",
        "country": "CN"
    },
    "08B258": {
        "oui_hex": "08-B2-58",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "9C84BF": {
        "oui_hex": "9C-84-BF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1CA0D3": {
        "oui_hex": "1C-A0-D3",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9CFCD1": {
        "oui_hex": "9C-FC-D1",
        "organization": "Aetheris Technology (Shanghai) Co., Ltd.",
        "address_1": "Room 225， Building No. 8, 433 Yuyuan Road",
        "address_2": "Shanghai  Shanghai  200040",
        "country": "CN"
    },
    "CCCE1E": {
        "oui_hex": "CC-CE-1E",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "0CF4D5": {
        "oui_hex": "0C-F4-D5",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "7C2664": {
        "oui_hex": "7C-26-64",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "AC6B0F": {
        "oui_hex": "AC-6B-0F",
        "organization": "CADENCE DESIGN SYSTEMS INC",
        "address_1": "2670 SEELY AVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "C8B5AD": {
        "oui_hex": "C8-B5-AD",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "7C3866": {
        "oui_hex": "7C-38-66",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0C61CF": {
        "oui_hex": "0C-61-CF",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "9C1D58": {
        "oui_hex": "9C-1D-58",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3805AC": {
        "oui_hex": "38-05-AC",
        "organization": "Piller Group GmbH",
        "address_1": "Abgunst 24",
        "address_2": "Osterode    37520",
        "country": "DE"
    },
    "346E9D": {
        "oui_hex": "34-6E-9D",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "6854C1": {
        "oui_hex": "68-54-C1",
        "organization": "ColorTokens, Inc.",
        "address_1": "2101 Tasman Dr. Suite 200A",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00111B": {
        "oui_hex": "00-11-1B",
        "organization": "Targa Systems Div L-3 Communications",
        "address_1": "2081 Merivale Rd",
        "address_2": "Ottawa  Ont  K2G 1G9",
        "country": "CA"
    },
    "6C750D": {
        "oui_hex": "6C-75-0D",
        "organization": "WiFiSONG",
        "address_1": "Rm. 605, Building 3, No. 75 Wenyi West Road",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "BC3F8F": {
        "oui_hex": "BC-3F-8F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "143004": {
        "oui_hex": "14-30-04",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4DC41": {
        "oui_hex": "F4-DC-41",
        "organization": "YOUNGZONE CULTURE (SHANGHAI) CORP",
        "address_1": "7-8th floor, #1 Building, 1006 Jinshajiang Road",
        "address_2": "Shanghai  Shanghai  200062",
        "country": "CN"
    },
    "C4836F": {
        "oui_hex": "C4-83-6F",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "7CC6C4": {
        "oui_hex": "7C-C6-C4",
        "organization": "Kolff Computer Supplies b.v.",
        "address_1": "Kuipershaven 22",
        "address_2": "Dordrecht  Zuid-Holland  3311 AL",
        "country": "NL"
    },
    "000F4F": {
        "oui_hex": "00-0F-4F",
        "organization": "PCS Systemtechnik GmbH",
        "address_1": "66 Hillside Rd",
        "address_2": "Auckland    1310",
        "country": "NZ"
    },
    "A80CCA": {
        "oui_hex": "A8-0C-CA",
        "organization": "Shenzhen Sundray Technologies Company Limited",
        "address_1": "6th Floor,Block A1, Nanshan iPark, No.1001 XueYuan Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "38AA3C": {
        "oui_hex": "38-AA-3C",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon    443-743",
        "country": "US"
    },
    "000302": {
        "oui_hex": "00-03-02",
        "organization": "Charles Industries, Ltd.",
        "address_1": "5600 Apollo Drive",
        "address_2": "Rolling Meadows  IL  60008",
        "country": "US"
    },
    "50A4D0": {
        "oui_hex": "50-A4-D0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "800010": {
        "oui_hex": "80-00-10",
        "organization": "AT&T",
        "address_1": "3300 E Renner Road",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "0024F1": {
        "oui_hex": "00-24-F1",
        "organization": "Shenzhen Fanhai Sanjiang Electronics Co., Ltd.",
        "address_1": "3Floor-Guangcai Xintiandi Building,Nanshan Rd,Nanshan,",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "142FFD": {
        "oui_hex": "14-2F-FD",
        "organization": "LT SECURITY INC",
        "address_1": "18738 SAN JOSE AVE",
        "address_2": "CITY OF INDUSTRY  CA  91748",
        "country": "US"
    },
    "0C3CCD": {
        "oui_hex": "0C-3C-CD",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Road, Sec.1,Tsao Tuen",
        "address_2": "Nan-Tou  Taiwan  54261",
        "country": "TW"
    },
    "14ABC5": {
        "oui_hex": "14-AB-C5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "50D213": {
        "oui_hex": "50-D2-13",
        "organization": "CviLux Corporation",
        "address_1": "9F,No.9,Lane 3,Sec.1,Chung-Cheng East Road, Tamshui",
        "address_2": "New Taipei City    25147",
        "country": "TW"
    },
    "001E29": {
        "oui_hex": "00-1E-29",
        "organization": "Hypertherm Inc",
        "address_1": "15 Great Hollow Rd",
        "address_2": "Hanover  NH  03755",
        "country": "US"
    },
    "5004B8": {
        "oui_hex": "50-04-B8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00D0B2": {
        "oui_hex": "00-D0-B2",
        "organization": "Xiotech Corporation",
        "address_1": "6455 FLYING CLOUD DRIVE",
        "address_2": "EDEN PRAIRIE  MN  55344",
        "country": "US"
    },
    "5CFF35": {
        "oui_hex": "5C-FF-35",
        "organization": "Wistron Corporation",
        "address_1": "21F, 88, Sec.1, Hsin Tai Wu Rd., Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "CC9F7A": {
        "oui_hex": "CC-9F-7A",
        "organization": "Chiun Mai Communication Systems, Inc",
        "address_1": "No.4, Minsheng St., Tucheng District",
        "address_2": "New Taipei City    23678",
        "country": "TW"
    },
    "78F29E": {
        "oui_hex": "78-F2-9E",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "64777D": {
        "oui_hex": "64-77-7D",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "9C50EE": {
        "oui_hex": "9C-50-EE",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "5/F,Building 8, 2388 ChenHang Road, MinHang District",
        "address_2": "shanghai    201114",
        "country": "CN"
    },
    "40ED98": {
        "oui_hex": "40-ED-98",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C891F9": {
        "oui_hex": "C8-91-F9",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "ACDCE5": {
        "oui_hex": "AC-DC-E5",
        "organization": "Procter & Gamble Company",
        "address_1": "2 Procter & Gamble Plaza",
        "address_2": "Cincinnati  OH  45202",
        "country": "US"
    },
    "00B362": {
        "oui_hex": "00-B3-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E4E4AB": {
        "oui_hex": "E4-E4-AB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60D262": {
        "oui_hex": "60-D2-62",
        "organization": "Tzukuri Pty Ltd",
        "address_1": "6 Lenthall Street",
        "address_2": "Kensington  NSW  2033",
        "country": "AU"
    },
    "8404D2": {
        "oui_hex": "84-04-D2",
        "organization": "Kirale Technologies SL",
        "address_1": "General Vara de Rey 9, 5B",
        "address_2": "Logrono  La Rioja  26001",
        "country": "ES"
    },
    "54FA96": {
        "oui_hex": "54-FA-96",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "60334B": {
        "oui_hex": "60-33-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38AFD7": {
        "oui_hex": "38-AF-D7",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "28993A": {
        "oui_hex": "28-99-3A",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "64EB8C": {
        "oui_hex": "64-EB-8C",
        "organization": "Seiko Epson Corporation",
        "address_1": "80 Harashinden",
        "address_2": "Shiojiri-shi  Nagano-ken  399-0785",
        "country": "JP"
    },
    "F48C50": {
        "oui_hex": "F4-8C-50",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DCD255": {
        "oui_hex": "DC-D2-55",
        "organization": "Kinpo Electronics, Inc.",
        "address_1": "No.147, Sec. 3, Beishen Rd",
        "address_2": "Shenkeng Dist.  New Taipei City  222",
        "country": "TW"
    },
    "A02C36": {
        "oui_hex": "A0-2C-36",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "000320": {
        "oui_hex": "00-03-20",
        "organization": "Xpeed, Inc.",
        "address_1": "99 W. Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "508A0F": {
        "oui_hex": "50-8A-0F",
        "organization": "SHENZHEN FISE TECHNOLOGY HOLDING CO.,LTD.",
        "address_1": "No.6 Building, Longfu Industrial Area, Huarong Road, Tongsheng Community, Dalang Street, Longhua New District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "7CCBE2": {
        "oui_hex": "7C-CB-E2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A8A5E2": {
        "oui_hex": "A8-A5-E2",
        "organization": "MSF-Vathauer Antriebstechnik GmbH & Co KG",
        "address_1": "Am Hessentuch 6-8",
        "address_2": "Detmold  Nordrhein-Westfalen  32758",
        "country": "DE"
    },
    "BCA8A6": {
        "oui_hex": "BC-A8-A6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "74FF4C": {
        "oui_hex": "74-FF-4C",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "68AF13": {
        "oui_hex": "68-AF-13",
        "organization": "Futura Mobility",
        "address_1": "515 PENNSYLVANIA AVE",
        "address_2": "FORT WASHINTON  PA  19034",
        "country": "US"
    },
    "681AB2": {
        "oui_hex": "68-1A-B2",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E04FBD": {
        "oui_hex": "E0-4F-BD",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "7CEBAE": {
        "oui_hex": "7C-EB-AE",
        "organization": "Ridgeline Instruments",
        "address_1": "4803 Innovation Drive, Suite 3B",
        "address_2": "Fort Collins  CO  80525",
        "country": "US"
    },
    "E0508B": {
        "oui_hex": "E0-50-8B",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "9C1E95": {
        "oui_hex": "9C-1E-95",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "60427F": {
        "oui_hex": "60-42-7F",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "E89EB4": {
        "oui_hex": "E8-9E-B4",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D46A6A": {
        "oui_hex": "D4-6A-6A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "98FD74": {
        "oui_hex": "98-FD-74",
        "organization": "ACT.CO.LTD",
        "address_1": "3-RD Floor 93, Sanbon-ro",
        "address_2": "Gunpo-si  Gyeonggi-do  15849",
        "country": "KR"
    },
    "64DB43": {
        "oui_hex": "64-DB-43",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "000E58": {
        "oui_hex": "00-0E-58",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "002590": {
        "oui_hex": "00-25-90",
        "organization": "Super Micro Computer, Inc.",
        "address_1": "980 Rock Avenue",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "AC1F6B": {
        "oui_hex": "AC-1F-6B",
        "organization": "Super Micro Computer, Inc.",
        "address_1": "980 Rock Ave",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000B2E": {
        "oui_hex": "00-0B-2E",
        "organization": "Cal-Comp Electronics & Communications Company Ltd.",
        "address_1": "No.147, Sec. 3, Beishen Rd",
        "address_2": "Shenkeng Dist  New Taipei City  ---",
        "country": "TW"
    },
    "4865EE": {
        "oui_hex": "48-65-EE",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D0F73B": {
        "oui_hex": "D0-F7-3B",
        "organization": "Helmut Mauell GmbH Werk Weida",
        "address_1": "Am Rosenhügel 1-7",
        "address_2": "Velbert    42553",
        "country": "DE"
    },
    "180675": {
        "oui_hex": "18-06-75",
        "organization": "Dilax Intelcom GmbH",
        "address_1": "Alt-Moabit 96b",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "000FC2": {
        "oui_hex": "00-0F-C2",
        "organization": "Uniwell Corporation",
        "address_1": "5-25, 3-chome, Tenma, Kita-ku",
        "address_2": "Osaka    530-0043",
        "country": "JP"
    },
    "6CEC5A": {
        "oui_hex": "6C-EC-5A",
        "organization": "Hon Hai Precision Ind. CO.,Ltd.",
        "address_1": "B22 Building, NO.52,Tongle Road, Foxconn Industrial Park, District Jiangnan, Nanning, Guangxi, China",
        "address_2": "Nanning  Guangxi  530031",
        "country": "CN"
    },
    "44C346": {
        "oui_hex": "44-C3-46",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "307496": {
        "oui_hex": "30-74-96",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "708A09": {
        "oui_hex": "70-8A-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CCC5EF": {
        "oui_hex": "CC-C5-EF",
        "organization": "Co-Comm Servicios Telecomunicaciones S.L.",
        "address_1": "Lisboa, 20 Las Rozas",
        "address_2": "Madrid  Madrid  28232",
        "country": "ES"
    },
    "9002A9": {
        "oui_hex": "90-02-A9",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "NO.1199 BinAn Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "C0288D": {
        "oui_hex": "C0-28-8D",
        "organization": "Logitech, Inc",
        "address_1": "4700 NW Camas Meadows Drive",
        "address_2": "Camas  WA  98607",
        "country": "US"
    },
    "0C4933": {
        "oui_hex": "0C-49-33",
        "organization": "Sichuan Jiuzhou Electronic Technology Co., Ltd.",
        "address_1": "No. 259, Jiuzhou Road",
        "address_2": "Mianyang City  Sichuan Province  621000",
        "country": "CN"
    },
    "000064": {
        "oui_hex": "00-00-64",
        "organization": "Yokogawa Digital Computer Corporation",
        "address_1": "Shinjuku MIDWEST Bldg.4-30-3",
        "address_2": "Yoyogi  Shibuya-ku, Tokyo  151-0053",
        "country": "JP"
    },
    "506B8D": {
        "oui_hex": "50-6B-8D",
        "organization": "Nutanix",
        "address_1": "1740 Technology Drive Ste #150",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "0038DF": {
        "oui_hex": "00-38-DF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4CAE5": {
        "oui_hex": "F4-CA-E5",
        "organization": "FREEBOX SAS",
        "address_1": "8 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "90004E": {
        "oui_hex": "90-00-4E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "7C2634": {
        "oui_hex": "7C-26-34",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "40F413": {
        "oui_hex": "40-F4-13",
        "organization": "Rubezh",
        "address_1": "Ulyanovskaya str. 28",
        "address_2": "Saratov    410056",
        "country": "RU"
    },
    "C8D3FF": {
        "oui_hex": "C8-D3-FF",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "C4BE84": {
        "oui_hex": "C4-BE-84",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "F4F524": {
        "oui_hex": "F4-F5-24",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "00BBC1": {
        "oui_hex": "00-BB-C1",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "24C1BD": {
        "oui_hex": "24-C1-BD",
        "organization": "CRRC DALIAN R&D CO.,LTD.",
        "address_1": "No.1 Haoyang North Street,Lvshun Economic Deveopment Zone",
        "address_2": "Dalian  Liaoning  116052",
        "country": "CN"
    },
    "00A2EE": {
        "oui_hex": "00-A2-EE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0059DC": {
        "oui_hex": "00-59-DC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00FD45": {
        "oui_hex": "00-FD-45",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "5098F3": {
        "oui_hex": "50-98-F3",
        "organization": "Rheem Australia Pty Ltd",
        "address_1": "1 Alan Street",
        "address_2": "Rydalmere  NSW  2116",
        "country": "AU"
    },
    "B4D135": {
        "oui_hex": "B4-D1-35",
        "organization": "Cloudistics",
        "address_1": "116000 Sunrise Valley Dr Suite 210",
        "address_2": "Reston  VA  20190",
        "country": "US"
    },
    "0013A5": {
        "oui_hex": "00-13-A5",
        "organization": "General Solutions, LTD.",
        "address_1": "5902 Sovereign Drive",
        "address_2": "Houston  Texas  77036",
        "country": "US"
    },
    "9C3DCF": {
        "oui_hex": "9C-3D-CF",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "248894": {
        "oui_hex": "24-88-94",
        "organization": "shenzhen lensun Communication Technology LTD",
        "address_1": "RM 201, Block 19, Zhiheng industry Park, Nantou Check point",
        "address_2": "Shenzhen   Guangdong  518000",
        "country": "CN"
    },
    "B04BBF": {
        "oui_hex": "B0-4B-BF",
        "organization": "PT HAN SUNG ELECTORONICS INDONESIA",
        "address_1": "JL.PALEM 1 BLOK DS-6",
        "address_2": "KAWASAN INDUSTRI BATIK LIPPO CIKARANG, DESA CIBATU, KECAMATAN CIKARANG SELATAN  BEKASI JAWA BARAT  17550",
        "country": "ID"
    },
    "CC2D83": {
        "oui_hex": "CC-2D-83",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D46E0E": {
        "oui_hex": "D4-6E-0E",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "88366C": {
        "oui_hex": "88-36-6C",
        "organization": "EFM Networks",
        "address_1": "6F, Benposra II 1197-1 Bojeong Giheung Gu",
        "address_2": "Yong In  Kyunggi do  446913",
        "country": "KR"
    },
    "48DA96": {
        "oui_hex": "48-DA-96",
        "organization": "Eddy Smart Home Solutions Inc.",
        "address_1": "1600-25 Sheppard Avenue West",
        "address_2": "Toronto  Ontario  M2N 6S6",
        "country": "CA"
    },
    "F074E4": {
        "oui_hex": "F0-74-E4",
        "organization": "Thundercomm Technology Co., Ltd",
        "address_1": "Building NO.4, 99# Xiantao Data Valley Zhonglu, Yubei District, Chongqing, China",
        "address_2": "chongqing    404100",
        "country": "CN"
    },
    "A0722C": {
        "oui_hex": "A0-72-2C",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "FCD848": {
        "oui_hex": "FC-D8-48",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "EC107B": {
        "oui_hex": "EC-10-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1C232C": {
        "oui_hex": "1C-23-2C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E00DB9": {
        "oui_hex": "E0-0D-B9",
        "organization": "Cree, Inc.",
        "address_1": "4600 Silicon Drive",
        "address_2": "Durham  NC  27703",
        "country": "US"
    },
    "DC0D30": {
        "oui_hex": "DC-0D-30",
        "organization": "Shenzhen Feasycom Technology Co., Ltd.",
        "address_1": "#2004, Huichao Science & Technology Building, Jinhai Road, Xixiang",
        "address_2": "Shenzhen  Guangdong  18000",
        "country": "CN"
    },
    "F0ACD7": {
        "oui_hex": "F0-AC-D7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9495A0": {
        "oui_hex": "94-95-A0",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "00A6CA": {
        "oui_hex": "00-A6-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "38D547": {
        "oui_hex": "38-D5-47",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "FC83C6": {
        "oui_hex": "FC-83-C6",
        "organization": "N-Radio Technologies Co., Ltd.",
        "address_1": "2#, 7F, Satellite Buiding, Keyuan Road, Nanshan",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "30B64F": {
        "oui_hex": "30-B6-4F",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "1C9D3E": {
        "oui_hex": "1C-9D-3E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "F02FA7": {
        "oui_hex": "F0-2F-A7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "18DED7": {
        "oui_hex": "18-DE-D7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C83DD4": {
        "oui_hex": "C8-3D-D4",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "E0B94D": {
        "oui_hex": "E0-B9-4D",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "D8452B": {
        "oui_hex": "D8-45-2B",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "E4186B": {
        "oui_hex": "E4-18-6B",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "008731": {
        "oui_hex": "00-87-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "88DEA9": {
        "oui_hex": "88-DE-A9",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "78888A": {
        "oui_hex": "78-88-8A",
        "organization": "CDR Sp. z o.o. Sp. k.",
        "address_1": "Palki 15",
        "address_2": "Zory    44-240",
        "country": "PL"
    },
    "0021D1": {
        "oui_hex": "00-21-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001FCC": {
        "oui_hex": "00-1F-CC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A42983": {
        "oui_hex": "A4-29-83",
        "organization": "Boeing Defence Australia",
        "address_1": "GPO Box 767",
        "address_2": "Brisbane  Queensland  4001",
        "country": "AU"
    },
    "EC8892": {
        "oui_hex": "EC-88-92",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "7487A9": {
        "oui_hex": "74-87-A9",
        "organization": "OCT Technology Co., Ltd.",
        "address_1": "8F. -2, No. 94, Baojhong Rd. Sindian Dist.",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "004A77": {
        "oui_hex": "00-4A-77",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A41437": {
        "oui_hex": "A4-14-37",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "60A10A": {
        "oui_hex": "60-A1-0A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8C71F8": {
        "oui_hex": "8C-71-F8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC051B": {
        "oui_hex": "CC-05-1B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8C7712": {
        "oui_hex": "8C-77-12",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9463D1": {
        "oui_hex": "94-63-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0021D2": {
        "oui_hex": "00-21-D2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5C497D": {
        "oui_hex": "5C-49-7D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "98234E": {
        "oui_hex": "98-23-4E",
        "organization": "Micromedia AG",
        "address_1": "Gartenweg 46",
        "address_2": "Buonas  Zug  6343",
        "country": "CH"
    },
    "503F98": {
        "oui_hex": "50-3F-98",
        "organization": "CMITECH",
        "address_1": "904-ho, 25, Simin-daero 248beon-gil, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  14067",
        "country": "KR"
    },
    "782079": {
        "oui_hex": "78-20-79",
        "organization": "ID Tech",
        "address_1": "10721 Walker St",
        "address_2": "Cypress  CA  90630",
        "country": "US"
    },
    "0C6076": {
        "oui_hex": "0C-60-76",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0CEEE6": {
        "oui_hex": "0C-EE-E6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "E4D53D": {
        "oui_hex": "E4-D5-3D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C0143D": {
        "oui_hex": "C0-14-3D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C01885": {
        "oui_hex": "C0-18-85",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00749C": {
        "oui_hex": "00-74-9C",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "19# Building,Star-net Science Plaza,Juyuanzhou, 618 Jinshan Road",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "5894CF": {
        "oui_hex": "58-94-CF",
        "organization": "Vertex Standard LMR, Inc.",
        "address_1": "4-8-8 Nakameguro",
        "address_2": "Meguro-ku   Tokyo  153-8644",
        "country": "JP"
    },
    "20F85E": {
        "oui_hex": "20-F8-5E",
        "organization": "Delta Electronics",
        "address_1": "252 Shangying Road",
        "address_2": "Taoyuan County  Taiwan  33341",
        "country": "TW"
    },
    "7825AD": {
        "oui_hex": "78-25-AD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, MAETAN-3DONG, PALDAL-GU",
        "address_2": "SUWON CITY  KYUNGKI-DO  442-742",
        "country": "KR"
    },
    "ECE09B": {
        "oui_hex": "EC-E0-9B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu,",
        "address_2": "Suwon-City  Gyeonggi-do  443-742",
        "country": "KR"
    },
    "0023E4": {
        "oui_hex": "00-23-E4",
        "organization": "IPnect co. ltd.",
        "address_1": "808 albatross B/D 237-18",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "70D4F2": {
        "oui_hex": "70-D4-F2",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "78D6F0": {
        "oui_hex": "78-D6-F0",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "Metan Dong 314, Youngtong Gu",
        "address_2": "Suwon  Kyung-gi Do.  443-743",
        "country": "KR"
    },
    "BC20A4": {
        "oui_hex": "BC-20-A4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "08D42B": {
        "oui_hex": "08-D4-2B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "789ED0": {
        "oui_hex": "78-9E-D0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0C4E7": {
        "oui_hex": "B0-C4-E7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A00798": {
        "oui_hex": "A0-07-98",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001FCD": {
        "oui_hex": "00-1F-CD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "38ECE4": {
        "oui_hex": "38-EC-E4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "945103": {
        "oui_hex": "94-51-03",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002490": {
        "oui_hex": "00-24-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0023D7": {
        "oui_hex": "00-23-D7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "549B12": {
        "oui_hex": "54-9B-12",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCA13E": {
        "oui_hex": "FC-A1-3E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "24C696": {
        "oui_hex": "24-C6-96",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "94D771": {
        "oui_hex": "94-D7-71",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E84E84": {
        "oui_hex": "E8-4E-84",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001632": {
        "oui_hex": "00-16-32",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, METAN-3DONG,",
        "address_2": "SUWON  KYUNGKI-DO  442-742",
        "country": "KR"
    },
    "E4E0C5": {
        "oui_hex": "E4-E0-C5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-do  443742",
        "country": "KR"
    },
    "C81479": {
        "oui_hex": "C8-14-79",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1CAF05": {
        "oui_hex": "1C-AF-05",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0016DB": {
        "oui_hex": "00-16-DB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "001EE2": {
        "oui_hex": "00-1E-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "20D5BF": {
        "oui_hex": "20-D5-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyeonggi-Do  443742",
        "country": "KR"
    },
    "5CE8EB": {
        "oui_hex": "5C-E8-EB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C0BDD1": {
        "oui_hex": "C0-BD-D1",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "B479A7": {
        "oui_hex": "B4-79-A7",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "7C11CB": {
        "oui_hex": "7C-11-CB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C25E1": {
        "oui_hex": "1C-25-E1",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "C0F636": {
        "oui_hex": "C0-F6-36",
        "organization": "Hangzhou Kuaiyue Technologies, Ltd.",
        "address_1": "Dongguan Hitech Park, Building 1-805, 288 Qiuyi Rd, Bingjiang District",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "001A22": {
        "oui_hex": "00-1A-22",
        "organization": "eQ-3 Entwicklung GmbH",
        "address_1": "Maiburger Str. 36",
        "address_2": "Leer  Niedersachsen  D-26789",
        "country": "DE"
    },
    "B0DF3A": {
        "oui_hex": "B0-DF-3A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "805719": {
        "oui_hex": "80-57-19",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "34BE00": {
        "oui_hex": "34-BE-00",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54E2E0": {
        "oui_hex": "54-E2-E0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "347A60": {
        "oui_hex": "34-7A-60",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001CC3": {
        "oui_hex": "00-1C-C3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "240DC2": {
        "oui_hex": "24-0D-C2",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "78521A": {
        "oui_hex": "78-52-1A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7085C6": {
        "oui_hex": "70-85-C6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "20BBC6": {
        "oui_hex": "20-BB-C6",
        "organization": "Jabil Circuit Hungary Ltd.",
        "address_1": "Huszár Andor 1.",
        "address_2": "Tiszaújváros    H-3580",
        "country": "HU"
    },
    "04FEA1": {
        "oui_hex": "04-FE-A1",
        "organization": "Fihonest communication co.,Ltd",
        "address_1": "Room902,Park road,Zhixing business-building",
        "address_2": "Dongguan  Guangdong  523560",
        "country": "CN"
    },
    "EC8CA2": {
        "oui_hex": "EC-8C-A2",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B80018": {
        "oui_hex": "B8-00-18",
        "organization": "Htel",
        "address_1": "Dunchon-dearo, Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13229",
        "country": "KR"
    },
    "7472B0": {
        "oui_hex": "74-72-B0",
        "organization": "Guangzhou Shiyuan Electronics Co., Ltd.",
        "address_1": "No.6, 4th Yunpu Road, Yunpu Industry District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "546C0E": {
        "oui_hex": "54-6C-0E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "EC8EAE": {
        "oui_hex": "EC-8E-AE",
        "organization": "Nagravision SA",
        "address_1": "Route de Geneve 22-24, PO 7980",
        "address_2": "Cheseaux  Vaud  1033",
        "country": "CH"
    },
    "A043DB": {
        "oui_hex": "A0-43-DB",
        "organization": "Sitael S.p.A.",
        "address_1": "Via San Sabino, 21",
        "address_2": "Mola di Bari  BA  70042",
        "country": "IT"
    },
    "E0E7BB": {
        "oui_hex": "E0-E7-BB",
        "organization": "Nureva, Inc.",
        "address_1": "1000, 1221 8th Street SW",
        "address_2": "Calgary  AB  T2R 0L4",
        "country": "CA"
    },
    "00808C": {
        "oui_hex": "00-80-8C",
        "organization": "NetAlly",
        "address_1": "310 Littleton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "049F81": {
        "oui_hex": "04-9F-81",
        "organization": "NetAlly",
        "address_1": "310 Littleton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "001087": {
        "oui_hex": "00-10-87",
        "organization": "XSTREAMIS PLC",
        "address_1": "OXFORD SCIENCE PARK",
        "address_2": "OXFORD 0X4 4GA    00000",
        "country": "US"
    },
    "00B0B3": {
        "oui_hex": "00-B0-B3",
        "organization": "XSTREAMIS PLC",
        "address_1": "Magdalen Centre",
        "address_2": "Oxford 0X4 4GA    0000",
        "country": "GB"
    },
    "049FCA": {
        "oui_hex": "04-9F-CA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "50016B": {
        "oui_hex": "50-01-6B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC482D": {
        "oui_hex": "AC-48-2D",
        "organization": "Ralinwi Nanjing Electronic Technology Co., Ltd.",
        "address_1": "3rd Floor, Building B,R&D Block 3, Xuzhuang Software Park, No. 699-27, Xuanwu Avenue",
        "address_2": "Nanjing  Jiangsu  210046",
        "country": "CN"
    },
    "002363": {
        "oui_hex": "00-23-63",
        "organization": "Zhuhai Raysharp Technology Co.,Ltd",
        "address_1": "No.119 of Huawei Road, Qianshan Science & Technology Park,",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "00001B": {
        "oui_hex": "00-00-1B",
        "organization": "Novell, Inc.",
        "address_1": "122 EAST 1700 SOUTH",
        "address_2": "PROVO  UT  84606",
        "country": "US"
    },
    "009058": {
        "oui_hex": "00-90-58",
        "organization": "Ultra Electronics Command & Control Systems",
        "address_1": "Knaves Beech Business Centre",
        "address_2": "Hemel Hemstead  Herts England  HP2 7BW",
        "country": "GB"
    },
    "001CFD": {
        "oui_hex": "00-1C-FD",
        "organization": "Universal Electronics, Inc.",
        "address_1": "6101 Gateway Drive",
        "address_2": "Cypress    90630",
        "country": "US"
    },
    "080087": {
        "oui_hex": "08-00-87",
        "organization": "Xyplex, Inc.",
        "address_1": "295 FOSTER STREET",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "DC1A01": {
        "oui_hex": "DC-1A-01",
        "organization": "Ecoliv Technology ( Shenzhen ) Ltd.",
        "address_1": "B-734, Tianhui building, Longhua Street, Pine Road, Longhua District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "00549F": {
        "oui_hex": "00-54-9F",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "2824FF": {
        "oui_hex": "28-24-FF",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "38256B": {
        "oui_hex": "38-25-6B",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "001CEF": {
        "oui_hex": "00-1C-EF",
        "organization": "Primax Electronics Ltd.",
        "address_1": "669, Ruey Kuang Road, Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000276": {
        "oui_hex": "00-02-76",
        "organization": "Primax Electronics Ltd.",
        "address_1": "No. 669, Ruey Kuang Road, Neihu",
        "address_2": "Taipei  Taiwan,  R.O.C.",
        "country": "TW"
    },
    "4CB21C": {
        "oui_hex": "4C-B2-1C",
        "organization": "Maxphotonics Co.,Ltd",
        "address_1": "Maxphotonics Industrial Park,Third Furong Road,Furong Industrial Area,Shajing,BaoAn",
        "address_2": "ShenZhen  GuangDong  518125",
        "country": "CN"
    },
    "205EF7": {
        "oui_hex": "20-5E-F7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "141F78": {
        "oui_hex": "14-1F-78",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D84710": {
        "oui_hex": "D8-47-10",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "35 East Mianxing Road,High-Tech Park,",
        "address_2": "MianYang  SiChuan  621000",
        "country": "CN"
    },
    "001972": {
        "oui_hex": "00-19-72",
        "organization": "Plexus (Xiamen) Co.,ltd.",
        "address_1": "No.6 Xiangxing 2 Road",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "002347": {
        "oui_hex": "00-23-47",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "0024A8": {
        "oui_hex": "00-24-A8",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "C09134": {
        "oui_hex": "C0-91-34",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "001969": {
        "oui_hex": "00-19-69",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0018B0": {
        "oui_hex": "00-18-B0",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0016CA": {
        "oui_hex": "00-16-CA",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000FCD": {
        "oui_hex": "00-0F-CD",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001BBA": {
        "oui_hex": "00-1B-BA",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0004DC": {
        "oui_hex": "00-04-DC",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000CF7": {
        "oui_hex": "00-0C-F7",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "00140E": {
        "oui_hex": "00-14-0E",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001E1F": {
        "oui_hex": "00-1E-1F",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "203AEF": {
        "oui_hex": "20-3A-EF",
        "organization": "Sivantos GmbH",
        "address_1": "Henri-Dunant-Strasse 100",
        "address_2": "Erlangen  Bavaria  91058",
        "country": "DE"
    },
    "005979": {
        "oui_hex": "00-59-79",
        "organization": "Networked Energy Services",
        "address_1": "5215 Hellyer Avenue",
        "address_2": "San Jose  CA  95138",
        "country": "US"
    },
    "207C8F": {
        "oui_hex": "20-7C-8F",
        "organization": "Quanta Microsystems,Inc.",
        "address_1": "No.5 Lane 91,Dongmei Rd.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000B34": {
        "oui_hex": "00-0B-34",
        "organization": "ShangHai Broadband Technologies CO.LTD",
        "address_1": "17F,No.122,HuangXing Road",
        "address_2": "ShangHai    200090",
        "country": "CN"
    },
    "74B57E": {
        "oui_hex": "74-B5-7E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B8BB23": {
        "oui_hex": "B8-BB-23",
        "organization": "Guangdong Nufront CSC Co., Ltd",
        "address_1": "A403-414, Building 13, No.232 Waihuan East Road, Higher           Education Mega Center, Guangdong 510006, China",
        "address_2": "Guangzhou  Guangdong  510006",
        "country": "CN"
    },
    "34EA34": {
        "oui_hex": "34-EA-34",
        "organization": "HangZhou Gubei Electronics Technology Co.,Ltd",
        "address_1": "Room 106, No.611 Jianghong Road, Binjiang District, Hangzhou, Zhejiang, China",
        "address_2": "Hangzhou  ZheJiang  310052",
        "country": "CN"
    },
    "3092F6": {
        "oui_hex": "30-92-F6",
        "organization": "SHANGHAI SUNMON COMMUNICATION TECHNOGY CO.,LTD",
        "address_1": "Suite 604-605,Xing Yuan Technology Plaza",
        "address_2": "00000  ShangHai  200233",
        "country": "CN"
    },
    "A8AD3D": {
        "oui_hex": "A8-AD-3D",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "24AF4A": {
        "oui_hex": "24-AF-4A",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "7C2064": {
        "oui_hex": "7C-20-64",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "600 March Drive",
        "address_2": "Kanata  Ontario  K2K2E6",
        "country": "CA"
    },
    "44DC91": {
        "oui_hex": "44-DC-91",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "2F F-NISSAY Ebisu Bldg 3-16-3 Higashi,",
        "address_2": "Shibuya-ku  Tokyo  150-0011",
        "country": "JP"
    },
    "E09DB8": {
        "oui_hex": "E0-9D-B8",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "Planex Volta Bldg., 2-11-9 Ebisu-Nishi,Shibuya-ku,",
        "address_2": "00000    1500021",
        "country": "US"
    },
    "000F59": {
        "oui_hex": "00-0F-59",
        "organization": "Phonak AG",
        "address_1": "Länggasse 17",
        "address_2": "Murten  FR  3280",
        "country": "CH"
    },
    "001478": {
        "oui_hex": "00-14-78",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F,Bldg.R1-B,Hi-tech Industrial Park,",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "48F8E1": {
        "oui_hex": "48-F8-E1",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "8C90D3": {
        "oui_hex": "8C-90-D3",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "0028F8": {
        "oui_hex": "00-28-F8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "58BC8F": {
        "oui_hex": "58-BC-8F",
        "organization": "Cognitive Systems Corp.",
        "address_1": "560 Westmount Road North",
        "address_2": "Waterloo  Ontario  N2L 0A9",
        "country": "CA"
    },
    "D455BE": {
        "oui_hex": "D4-55-BE",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "640DCE": {
        "oui_hex": "64-0D-CE",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "54D272": {
        "oui_hex": "54-D2-72",
        "organization": "Nuki Home Solutions GmbH",
        "address_1": "Muenzgrabenstrasse 92",
        "address_2": "Graz    8010",
        "country": "AT"
    },
    "EC26FB": {
        "oui_hex": "EC-26-FB",
        "organization": "TECC CO.,LTD.",
        "address_1": "Guam-ro 15-gil, Buk-gu",
        "address_2": "Daegu    720-849",
        "country": "KR"
    },
    "0020F4": {
        "oui_hex": "00-20-F4",
        "organization": "SPECTRIX CORPORATION",
        "address_1": "106 WILMOT ROAD, SUITE 250",
        "address_2": "DEERFIELD  IL  60015-5150",
        "country": "US"
    },
    "04EE91": {
        "oui_hex": "04-EE-91",
        "organization": "x-fabric GmbH",
        "address_1": "Nachodstraße 7",
        "address_2": "Berlin    10779",
        "country": "DE"
    },
    "B47443": {
        "oui_hex": "B4-74-43",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCF647": {
        "oui_hex": "FC-F6-47",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "18686A": {
        "oui_hex": "18-68-6A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C44BD1": {
        "oui_hex": "C4-4B-D1",
        "organization": "Wallys Communications  Teachnologies Co.,Ltd.",
        "address_1": "5-207, DongHong Pioneer Park, #99 YangYu Lane,",
        "address_2": "SuZhou  JiangSu  215000",
        "country": "CN"
    },
    "6CB9C5": {
        "oui_hex": "6C-B9-C5",
        "organization": "Delta Networks, Inc.",
        "address_1": "256 Yang Guang Street, Neihu",
        "address_2": "Taipei  Taiwan  11491",
        "country": "TW"
    },
    "30766F": {
        "oui_hex": "30-76-6F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "A8922C": {
        "oui_hex": "A8-92-2C",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F80CF3": {
        "oui_hex": "F8-0C-F3",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "C49A02": {
        "oui_hex": "C4-9A-02",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "001F6B": {
        "oui_hex": "00-1F-6B",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0026E2": {
        "oui_hex": "00-26-E2",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "DC4427": {
        "oui_hex": "DC-44-27",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "BC3400": {
        "oui_hex": "BC-34-00",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E8886C": {
        "oui_hex": "E8-88-6C",
        "organization": "Shenzhen SC Technologies Co.,LTD",
        "address_1": "4/FL,2Block,LianChuang Industrial Park,Bulan Road,Longgang",
        "address_2": "Shenzhen   Guangdong Province  518112",
        "country": "CN"
    },
    "0024FF": {
        "oui_hex": "00-24-FF",
        "organization": "QLogic Corporation",
        "address_1": "26650 Aliso Viejo Parkway",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "001E21": {
        "oui_hex": "00-1E-21",
        "organization": "Qisda Corporation",
        "address_1": "157 Shan-Ying Road, Gueishan",
        "address_2": "Taoyuan    333",
        "country": "TW"
    },
    "00039D": {
        "oui_hex": "00-03-9D",
        "organization": "Qisda Corporation",
        "address_1": "157 Shan Ying Road",
        "address_2": "GueiShan  Taoyuan  333",
        "country": "TW"
    },
    "00080D": {
        "oui_hex": "00-08-0D",
        "organization": "Toshiba",
        "address_1": "2-9, Suehiro-cho,",
        "address_2": "Tokyo    198-8710",
        "country": "JP"
    },
    "000E7B": {
        "oui_hex": "00-0E-7B",
        "organization": "Toshiba",
        "address_1": "2-9, Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "0003B2": {
        "oui_hex": "00-03-B2",
        "organization": "Radware",
        "address_1": "8 Hamrpe Hochvim",
        "address_2": "000    0000",
        "country": "IL"
    },
    "9C6121": {
        "oui_hex": "9C-61-21",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "00A0C6": {
        "oui_hex": "00-A0-C6",
        "organization": "Qualcomm Inc.",
        "address_1": "6455 LUSK BLVD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "649C81": {
        "oui_hex": "64-9C-81",
        "organization": "Qualcomm Inc.",
        "address_1": "5665 Morehouse Drive",
        "address_2": "San Diego  CA  92071",
        "country": "US"
    },
    "001A6A": {
        "oui_hex": "00-1A-6A",
        "organization": "Tranzas, Inc.",
        "address_1": "Queens tower C17",
        "address_2": "Yokohama  Kanagawa-ken  220-6217",
        "country": "JP"
    },
    "A47174": {
        "oui_hex": "A4-71-74",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4CB52": {
        "oui_hex": "F4-CB-52",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B808D7": {
        "oui_hex": "B8-08-D7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94611E": {
        "oui_hex": "94-61-1E",
        "organization": "Wata Electronics Co.,Ltd.",
        "address_1": "No 142,South Tanshen Road, Tanzhou Town,Zhongshan City,Guangdong,China",
        "address_2": "Zhongshan  Guangdong  528467",
        "country": "CN"
    },
    "00C0E4": {
        "oui_hex": "00-C0-E4",
        "organization": "SIEMENS BUILDING",
        "address_1": "TECHNOLOGIES, INC.",
        "address_2": "BUFFALO GROVE  IL  60089",
        "country": "US"
    },
    "000D10": {
        "oui_hex": "00-0D-10",
        "organization": "Embedtronics Oy",
        "address_1": "Leväsentie 23",
        "address_2": "Kuopio    70780",
        "country": "FI"
    },
    "001FA8": {
        "oui_hex": "00-1F-A8",
        "organization": "Smart Energy Instruments Inc.",
        "address_1": "297 Lakeshore Road East",
        "address_2": "Oakville  Ontario  L6J 1J3",
        "country": "CA"
    },
    "000FDB": {
        "oui_hex": "00-0F-DB",
        "organization": "Westell Technologies Inc.",
        "address_1": "750 N Commons Dr",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "3C0771": {
        "oui_hex": "3C-07-71",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "80414E": {
        "oui_hex": "80-41-4E",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "249442": {
        "oui_hex": "24-94-42",
        "organization": "OPEN ROAD SOLUTIONS , INC.",
        "address_1": "88-13 SHUILI  ROAD",
        "address_2": "HSINCHU    30059",
        "country": "TW"
    },
    "C46413": {
        "oui_hex": "C4-64-13",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0010CA": {
        "oui_hex": "00-10-CA",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield,  MA  02048",
        "country": "US"
    },
    "00E09E": {
        "oui_hex": "00-E0-9E",
        "organization": "Quantum Corporation",
        "address_1": "500 McCarthy Boulevard",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000A08": {
        "oui_hex": "00-0A-08",
        "organization": "Alpine Electronics, Inc.",
        "address_1": "20-1 Yoshima-Kogyodanchi",
        "address_2": "iwaki-city  Fukushima  970-1192",
        "country": "JP"
    },
    "206A8A": {
        "oui_hex": "20-6A-8A",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "168# First Avenue,Kunshan Export Processing Zone",
        "address_2": "Kunshan  Jiangsu  215300",
        "country": "CN"
    },
    "784476": {
        "oui_hex": "78-44-76",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "A1&A2 building,lantian technology park, xinyu road, xingqiao henggang block, shajing street, Baoan District",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "001165": {
        "oui_hex": "00-11-65",
        "organization": "ZNYX Networks, Inc.",
        "address_1": "48421 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000A68": {
        "oui_hex": "00-0A-68",
        "organization": "Solarflare Communications Inc.",
        "address_1": "Suite 100, 7505 Irvine Center Drive",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "002186": {
        "oui_hex": "00-21-86",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Sec.1, Taiping Road,",
        "address_2": "NANTOU    54261",
        "country": "TW"
    },
    "183919": {
        "oui_hex": "18-39-19",
        "organization": "Unicoi Systems",
        "address_1": "410 Peachtree Pkwy",
        "address_2": "Cumming  GA  30041",
        "country": "US"
    },
    "E8E0B7": {
        "oui_hex": "E8-E0-B7",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "680715": {
        "oui_hex": "68-07-15",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3CB6B7": {
        "oui_hex": "3C-B6-B7",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong  523860",
        "country": "CN"
    },
    "C42795": {
        "oui_hex": "C4-27-95",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "A020A6": {
        "oui_hex": "A0-20-A6",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "58528A": {
        "oui_hex": "58-52-8A",
        "organization": "Mitsubishi Electric Corporation",
        "address_1": "2-7-3 Marunouchi Chiyoda-ku",
        "address_2": "Tokyo    100-8310",
        "country": "JP"
    },
    "C4F1D1": {
        "oui_hex": "C4-F1-D1",
        "organization": "BEIJING SOGOU TECHNOLOGY DEVELOPMENT CO., LTD.",
        "address_1": "SOHU.COM INTERNET PLAZA, NO.1 PARK, ZHONGGUANCHUN EAST ROAD. HAIDIAN DISTRICT",
        "address_2": "Beijing    100000",
        "country": "CN"
    },
    "ACE77B": {
        "oui_hex": "AC-E7-7B",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "2C36A0": {
        "oui_hex": "2C-36-A0",
        "organization": "Capisco Limited",
        "address_1": "PO Box 938",
        "address_2": "Auckland    0943",
        "country": "NZ"
    },
    "B0B2DC": {
        "oui_hex": "B0-B2-DC",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "CC5D4E": {
        "oui_hex": "CC-5D-4E",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "404A03": {
        "oui_hex": "40-4A-03",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "C86C87": {
        "oui_hex": "C8-6C-87",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "001EC0": {
        "oui_hex": "00-1E-C0",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "645D92": {
        "oui_hex": "64-5D-92",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road, Chengdu, Sichuan",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "38BC1A": {
        "oui_hex": "38-BC-1A",
        "organization": "MEIZU Technology Co., Ltd.",
        "address_1": "MEIZU Tech Bldg., Technology & Innovation Coast",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "802994": {
        "oui_hex": "80-29-94",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "E0885D": {
        "oui_hex": "E0-88-5D",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "340AFF": {
        "oui_hex": "34-0A-FF",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "587E61": {
        "oui_hex": "58-7E-61",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "C0A1A2": {
        "oui_hex": "C0-A1-A2",
        "organization": "MarqMetrix",
        "address_1": "410 West Harrison ST #200",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "08D0B7": {
        "oui_hex": "08-D0-B7",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "ECD68A": {
        "oui_hex": "EC-D6-8A",
        "organization": "Shenzhen JMicron Intelligent Technology Developmen",
        "address_1": "Futian District, 13th Floor , Block B Building Tai",
        "address_2": "Shenzhen  Guangdong Province  518040",
        "country": "CN"
    },
    "5052D2": {
        "oui_hex": "50-52-D2",
        "organization": "Hangzhou Telin Technologies Co., Limited",
        "address_1": "8 floor,D Building,Paradise Software Park,No. 3 Xidoumen Road, Xihu District, Hangzhou",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "90EED9": {
        "oui_hex": "90-EE-D9",
        "organization": "UNIVERSAL DE DESARROLLOS ELECTRÓNICOS, SA",
        "address_1": "CRTA DE CASTELLAR, 298",
        "address_2": "TERRASSA  BARCELONA  08226",
        "country": "ES"
    },
    "606453": {
        "oui_hex": "60-64-53",
        "organization": "AOD Co.,Ltd.",
        "address_1": "No. 13155, Yuqing Street, High-Technology Development Zone,",
        "address_2": "Weifang  Shandong  261061",
        "country": "CN"
    },
    "6C98EB": {
        "oui_hex": "6C-98-EB",
        "organization": "Riverbed Technology, Inc.",
        "address_1": " 680 Folsom St.",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "009E1E": {
        "oui_hex": "00-9E-1E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00253E": {
        "oui_hex": "00-25-3E",
        "organization": "Sensus Metering Systems",
        "address_1": "10147 W. Emerald Street",
        "address_2": "Boise  Idaho  83704",
        "country": "US"
    },
    "C8AFE3": {
        "oui_hex": "C8-AF-E3",
        "organization": "Hefei Radio Communication Technology Co., Ltd",
        "address_1": " No.108, YinXing Road, High-tech Development Zone",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "CCA260": {
        "oui_hex": "CC-A2-60",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "7C574E": {
        "oui_hex": "7C-57-4E",
        "organization": "COBI GmbH",
        "address_1": "Solmsstrasse 4",
        "address_2": "Frankfurt am Main    60486",
        "country": "DE"
    },
    "28F10E": {
        "oui_hex": "28-F1-0E",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "045604": {
        "oui_hex": "04-56-04",
        "organization": "Gionee Communication Equipment Co.,Ltd.",
        "address_1": "21/F,Times Technology Building,No. 7028,Shennan Avenue,Futian District",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "34C0F9": {
        "oui_hex": "34-C0-F9",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "00FEC8": {
        "oui_hex": "00-FE-C8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2C5A8D": {
        "oui_hex": "2C-5A-8D",
        "organization": "SYSTRONIK Elektronik u. Systemtechnik GmbH",
        "address_1": "Gewerbestrasse 57",
        "address_2": "ILLMENSEE    88636",
        "country": "DE"
    },
    "10BEF5": {
        "oui_hex": "10-BE-F5",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "E47B3F": {
        "oui_hex": "E4-7B-3F",
        "organization": "BEIJING CO-CLOUD TECHNOLOGY LTD.",
        "address_1": "903 Room，Power Create E ，No.1 Shangdi East Road",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "0C8A87": {
        "oui_hex": "0C-8A-87",
        "organization": "AgLogica Holdings, Inc",
        "address_1": "333 Research Ct NW Ste 230",
        "address_2": "Norcross  GA  30092",
        "country": "US"
    },
    "54EDA3": {
        "oui_hex": "54-ED-A3",
        "organization": "Navdy, Inc.",
        "address_1": "575 7th Street",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "40F420": {
        "oui_hex": "40-F4-20",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "34A2A2": {
        "oui_hex": "34-A2-A2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "749D8F": {
        "oui_hex": "74-9D-8F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "945907": {
        "oui_hex": "94-59-07",
        "organization": "Shanghai HITE-BELDEN Network Technology Co., Ltd.",
        "address_1": "No. 777, Xinjun Ring Road, Pujiang Hi-Tech Park, Minhang District",
        "address_2": "Shanghai  Shanghai  201114",
        "country": "CN"
    },
    "001848": {
        "oui_hex": "00-18-48",
        "organization": "Vecima Networks Inc.",
        "address_1": "150 Cardinal Place",
        "address_2": "Saskatoon  SK  S7L 6H7",
        "country": "CA"
    },
    "0016FB": {
        "oui_hex": "00-16-FB",
        "organization": "SHENZHEN MTC CO LTD",
        "address_1": "5/F BenYuan Bldg,6015 ShenNan Road",
        "address_2": "ShenZhen  GuangDong  518040",
        "country": "CN"
    },
    "A0415E": {
        "oui_hex": "A0-41-5E",
        "organization": "Opsens Solution Inc.",
        "address_1": "2014 rue Cyrille-Duquet, suite 125",
        "address_2": "Quebec  QC  G1N 4N6",
        "country": "CA"
    },
    "A860B6": {
        "oui_hex": "A8-60-B6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C4B301": {
        "oui_hex": "C4-B3-01",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E05F45": {
        "oui_hex": "E0-5F-45",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "74CC39": {
        "oui_hex": "74-CC-39",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "3822D6": {
        "oui_hex": "38-22-D6",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "94E8C5": {
        "oui_hex": "94-E8-C5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6C3B6B": {
        "oui_hex": "6C-3B-6B",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "0022E7": {
        "oui_hex": "00-22-E7",
        "organization": "WPS Parking Systems",
        "address_1": "Hoevenweg 11",
        "address_2": "Eindhoven  Noord-Brabant  5652 AW",
        "country": "NL"
    },
    "4851B7": {
        "oui_hex": "48-51-B7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B8E779": {
        "oui_hex": "B8-E7-79",
        "organization": "9Solutions Oy",
        "address_1": "Teknologiantie 2",
        "address_2": "Oulu    90590",
        "country": "FI"
    },
    "C864C7": {
        "oui_hex": "C8-64-C7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "483B38": {
        "oui_hex": "48-3B-38",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1C9148": {
        "oui_hex": "1C-91-48",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "905F2E": {
        "oui_hex": "90-5F-2E",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "F823B2": {
        "oui_hex": "F8-23-B2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "341290": {
        "oui_hex": "34-12-90",
        "organization": "Treeview Co.,Ltd.",
        "address_1": "106/29 BANGLAMUNG",
        "address_2": "BANGLAMUNG  CHONBURI  20150",
        "country": "TH"
    },
    "7CFE4E": {
        "oui_hex": "7C-FE-4E",
        "organization": "Shenzhen Safe vision Technology Co.,LTD",
        "address_1": "Shenzhen ring view south road and 27 digital dragon industrial park industrial zone",
        "address_2": "shenzhen  Guangdong province  518110",
        "country": "CN"
    },
    "644FB0": {
        "oui_hex": "64-4F-B0",
        "organization": "Hyunjin.com",
        "address_1": " Hyochang-dong 5-86, Yongsan-gu",
        "address_2": "Seoul    140-896",
        "country": "KR"
    },
    "00E0E6": {
        "oui_hex": "00-E0-E6",
        "organization": "INCAA Computers",
        "address_1": "P.O. BOX 211",
        "address_2": "7300 AE APELDOORN    na",
        "country": "NL"
    },
    "28F366": {
        "oui_hex": "28-F3-66",
        "organization": "Shenzhen Bilian electronic CO.,LTD",
        "address_1": "NO 268，Fuqian Rd,Jutang Community,Guanlan town , LongHua new district,Shenzhen,518110,China.",
        "address_2": "Shenzhen    518110",
        "country": "CN"
    },
    "E0A3AC": {
        "oui_hex": "E0-A3-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC7574": {
        "oui_hex": "BC-75-74",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "20A680": {
        "oui_hex": "20-A6-80",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8828B3": {
        "oui_hex": "88-28-B3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4E597": {
        "oui_hex": "A4-E5-97",
        "organization": "Gessler GmbH",
        "address_1": "Gutenbergring 14",
        "address_2": "Rodgau    63110",
        "country": "DE"
    },
    "006CBC": {
        "oui_hex": "00-6C-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5C70A3": {
        "oui_hex": "5C-70-A3",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "001D08": {
        "oui_hex": "00-1D-08",
        "organization": "Jiangsu Yinhe  Electronics Co.,Ltd.",
        "address_1": "188 NANHUAN ROAD",
        "address_2": "ZHANGJIAGANG  JIANGSU  215611",
        "country": "CN"
    },
    "001D82": {
        "oui_hex": "00-1D-82",
        "organization": "GN Netcom A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK - 2750",
        "country": "DK"
    },
    "001317": {
        "oui_hex": "00-13-17",
        "organization": "GN Netcom A/S",
        "address_1": "Metalbuen 66",
        "address_2": "Ballerup  Skovlunde  DK-2750",
        "country": "DK"
    },
    "00A0A4": {
        "oui_hex": "00-A0-A4",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "749781": {
        "oui_hex": "74-97-81",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0001F4": {
        "oui_hex": "00-01-F4",
        "organization": "Enterasys",
        "address_1": "35 Industrial Way",
        "address_2": "Rochester  NH  03867",
        "country": "US"
    },
    "00109B": {
        "oui_hex": "00-10-9B",
        "organization": "Emulex Corporation",
        "address_1": "3333 Susan Street",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "00142A": {
        "oui_hex": "00-14-2A",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22, Alley 38, Lane 91, Sec. 1,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00115B": {
        "oui_hex": "00-11-5B",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22, Alley 38, Lane 91, Sec. 1, Nei Hu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "C03FD5": {
        "oui_hex": "C0-3F-D5",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No. 239, Sec. 2, Ti-Ding Blvd",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "ECA86B": {
        "oui_hex": "EC-A8-6B",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO. 239, Sec. 2, Ti Ding Blvd.",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "C89CDC": {
        "oui_hex": "C8-9C-DC",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO. 239, Sec. 2, Ti Ding Blvd.",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "002511": {
        "oui_hex": "00-25-11",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO. 239, Sec. 2, Ti Ding Blvd.",
        "address_2": "Taipei  Taiwan  11493",
        "country": "TW"
    },
    "4487FC": {
        "oui_hex": "44-87-FC",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO. 239, Sec. 2, Ti Ding Blvd.",
        "address_2": "Taipei  Taiwan  11493",
        "country": "TW"
    },
    "A86BAD": {
        "oui_hex": "A8-6B-AD",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D80F99": {
        "oui_hex": "D8-0F-99",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B4B15A": {
        "oui_hex": "B4-B1-5A",
        "organization": "Siemens AG Energy Management Division",
        "address_1": "Humboldtstr. 59",
        "address_2": "Nurnberg  Bavaria  90459",
        "country": "DE"
    },
    "002465": {
        "oui_hex": "00-24-65",
        "organization": "Elentec",
        "address_1": "401-13 Chunggye-Ri,Dongtan-Myun",
        "address_2": "Hwasung  Kyunggi  445-811",
        "country": "KR"
    },
    "00089F": {
        "oui_hex": "00-08-9F",
        "organization": "EFM Networks",
        "address_1": "403, 4th floor Elegance 1 Bldg.",
        "address_2": "Sungnam-si  Kyunggi-do  463-808",
        "country": "KR"
    },
    "0050FC": {
        "oui_hex": "00-50-FC",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "9CDF03": {
        "oui_hex": "9C-DF-03",
        "organization": "Harman/Becker Automotive Systems GmbH",
        "address_1": "Becker-Göring-Straße 16",
        "address_2": "Karlsbad  Baden-Württemberg  76307",
        "country": "DE"
    },
    "001188": {
        "oui_hex": "00-11-88",
        "organization": "Enterasys",
        "address_1": "35 Industrial Way",
        "address_2": "Rochester  NH  03867",
        "country": "US"
    },
    "0016FA": {
        "oui_hex": "00-16-FA",
        "organization": "ECI Telecom Ltd.",
        "address_1": "30 Hasivim St.",
        "address_2": "Petah Tikva    49133",
        "country": "US"
    },
    "F8A188": {
        "oui_hex": "F8-A1-88",
        "organization": "LED Roadway Lighting",
        "address_1": "115 Chain Lake Dr.",
        "address_2": "Halifax  NS  B3S 1B3",
        "country": "CA"
    },
    "A082AC": {
        "oui_hex": "A0-82-AC",
        "organization": "Linear DMS Solutions Sdn. Bhd.",
        "address_1": "135, Jalan Utara",
        "address_2": "PENANG  Pulau Pinang  11700",
        "country": "MY"
    },
    "A86AC1": {
        "oui_hex": "A8-6A-C1",
        "organization": "HanbitEDS Co., Ltd.",
        "address_1": "44-10, Techno 10-ro, Yuseong-gu",
        "address_2": "Daejeon  Daejeon  34027",
        "country": "KR"
    },
    "D463FE": {
        "oui_hex": "D4-63-FE",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "689361": {
        "oui_hex": "68-93-61",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "BC15AC": {
        "oui_hex": "BC-15-AC",
        "organization": "Vodafone Italia S.p.A.",
        "address_1": "Via Lorenteggio nr. 240",
        "address_2": "Milan  Italy  20147",
        "country": "IT"
    },
    "00BD82": {
        "oui_hex": "00-BD-82",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "94513D": {
        "oui_hex": "94-51-3D",
        "organization": "iSmart Alarm, Inc.",
        "address_1": "1290 Kifer Road Suite 306",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "001174": {
        "oui_hex": "00-11-74",
        "organization": " Mojo Networks, Inc.",
        "address_1": "339 N.Bernardo Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001954": {
        "oui_hex": "00-19-54",
        "organization": "Leaf Corporation.",
        "address_1": "Amuze 1F",
        "address_2": "Isehara City  Kanagawa-Pref.  259-1117",
        "country": "JP"
    },
    "9466E7": {
        "oui_hex": "94-66-E7",
        "organization": "WOM Engineering",
        "address_1": "13F., No. 192, Sec. 2, Zhongxing Rd., Xindian Dist.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "4CB8B5": {
        "oui_hex": "4C-B8-B5",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "7085C2": {
        "oui_hex": "70-85-C2",
        "organization": "ASRock Incorporation",
        "address_1": "2F., No. 37, Sec. 2, Jhongyang S. Rd., Beitou District,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "EC93ED": {
        "oui_hex": "EC-93-ED",
        "organization": "DDoS-Guard LTD",
        "address_1": "goroda Volos, 6, 904",
        "address_2": "Rostov-on-Don    344010",
        "country": "RU"
    },
    "30FC68": {
        "oui_hex": "30-FC-68",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "008A96": {
        "oui_hex": "00-8A-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BC60A7": {
        "oui_hex": "BC-60-A7",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "808C97": {
        "oui_hex": "80-8C-97",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "884-3, Seongnam-daero, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13517",
        "country": "KR"
    },
    "DCEE06": {
        "oui_hex": "DC-EE-06",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0452C7": {
        "oui_hex": "04-52-C7",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "F02745": {
        "oui_hex": "F0-27-45",
        "organization": "F-Secure Corporation",
        "address_1": "Tammasaarenkatu 7",
        "address_2": "Helsinki    00181",
        "country": "FI"
    },
    "54D0B4": {
        "oui_hex": "54-D0-B4",
        "organization": "Xiamen Four-Faith Communication Technology Co.,Ltd",
        "address_1": "3rd Floor,No,44,GuanRi Road,Software Park,XiaMen",
        "address_2": "XiaMen  Fujian  361000",
        "country": "CN"
    },
    "00137C": {
        "oui_hex": "00-13-7C",
        "organization": "Kaicom co., Ltd.",
        "address_1": "#109, Gayang Techno Town 1487, Gayang-dong,Kangso-gu",
        "address_2": "Seoul    157-810",
        "country": "KR"
    },
    "E85659": {
        "oui_hex": "E8-56-59",
        "organization": "Advanced-Connectek Inc.",
        "address_1": "No. 2,Alley 9, Lane 45, Baoxing Rd., Xiadian Dist.,",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "34BF90": {
        "oui_hex": "34-BF-90",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "CCB3F8": {
        "oui_hex": "CC-B3-F8",
        "organization": "FUJITSU ISOTEC LIMITED",
        "address_1": "135,Higashinozaki,Hobara-machi,",
        "address_2": "Date-shi  Fukushima  960-0695",
        "country": "JP"
    },
    "E4A471": {
        "oui_hex": "E4-A4-71",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "10F005": {
        "oui_hex": "10-F0-05",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "64CC2E": {
        "oui_hex": "64-CC-2E",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "8801F2": {
        "oui_hex": "88-01-F2",
        "organization": "Vitec System Engineering Inc.",
        "address_1": "203203 Kita-shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0001",
        "country": "JP"
    },
    "14D11F": {
        "oui_hex": "14-D1-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "DC094C": {
        "oui_hex": "DC-09-4C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C6758": {
        "oui_hex": "1C-67-58",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "24BCF8": {
        "oui_hex": "24-BC-F8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A0043E": {
        "oui_hex": "A0-04-3E",
        "organization": "Parker Hannifin Manufacturing Germany GmbH & Co. KG",
        "address_1": "Gutenbergstrasse 38",
        "address_2": "Kaarst  Select State  41564",
        "country": "DE"
    },
    "C84529": {
        "oui_hex": "C8-45-29",
        "organization": "IMK Networks Co.,Ltd",
        "address_1": "201-Ho jungribjunja, 16-3bunji,",
        "address_2": "Seoul    143-816",
        "country": "KR"
    },
    "7C477C": {
        "oui_hex": "7C-47-7C",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F877B8": {
        "oui_hex": "F8-77-B8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "F0D2F1": {
        "oui_hex": "F0-D2-F1",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "A8E3EE": {
        "oui_hex": "A8-E3-EE",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "00248D": {
        "oui_hex": "00-24-8D",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "00041F": {
        "oui_hex": "00-04-1F",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "20A90E": {
        "oui_hex": "20-A9-0E",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "EC438B": {
        "oui_hex": "EC-43-8B",
        "organization": "YAPTV",
        "address_1": "623 GangNamDa-Ro",
        "address_2": "Seocho-Gu  Seoul  06524",
        "country": "KR"
    },
    "980CA5": {
        "oui_hex": "98-0C-A5",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "441102": {
        "oui_hex": "44-11-02",
        "organization": "EDMI  Europe Ltd",
        "address_1": "The Grainger  Suite, Dobson House",
        "address_2": "Newcastle upon Tyne    NE3 3PF",
        "country": "GB"
    },
    "A85EE4": {
        "oui_hex": "A8-5E-E4",
        "organization": "12Sided Technology, LLC",
        "address_1": "1 Penn Plaza, 36th Floor",
        "address_2": "New York  NY  10119",
        "country": "US"
    },
    "182195": {
        "oui_hex": "18-21-95",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44783E": {
        "oui_hex": "44-78-3E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CA2F4": {
        "oui_hex": "0C-A2-F4",
        "organization": "Chameleon Technology (UK) Limited",
        "address_1": "Gardner House,  Hornbeam Park Avenue",
        "address_2": "Hornbeam Park  Harrogate  HG2 8NA",
        "country": "GB"
    },
    "BC44B0": {
        "oui_hex": "BC-44-B0",
        "organization": "Elastifile",
        "address_1": "Abba Even 8",
        "address_2": "Herzlia    4672526",
        "country": "IL"
    },
    "74BFB7": {
        "oui_hex": "74-BF-B7",
        "organization": "Nusoft Corporation",
        "address_1": "3F.-1, No. 880, Zhongzheng Rd.,",
        "address_2": "Zhonghe Dist., New Taipei City  Taiwan (R.O.C.)   235-86",
        "country": "TW"
    },
    "50DA00": {
        "oui_hex": "50-DA-00",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "F4ED5F": {
        "oui_hex": "F4-ED-5F",
        "organization": "SHENZHEN KTC TECHNOLOGY GROUP",
        "address_1": "Wuhe Street",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "00E0E4": {
        "oui_hex": "00-E0-E4",
        "organization": "FANUC ROBOTICS NORTH AMERICA, Inc.",
        "address_1": "3900 W. HAMLIN RD.",
        "address_2": "ROCHESTER HILLS  MI  48309-3253",
        "country": "US"
    },
    "000896": {
        "oui_hex": "00-08-96",
        "organization": "Printronix, Inc.",
        "address_1": "14600 Myford Rd.",
        "address_2": "Irvine  California  92623-9559",
        "country": "US"
    },
    "245EBE": {
        "oui_hex": "24-5E-BE",
        "organization": "QNAP Systems, Inc.",
        "address_1": "2F., No.22, Zhongxing Rd., Xizhi Dist.",
        "address_2": "New Taipei City    221",
        "country": "TW"
    },
    "0404EA": {
        "oui_hex": "04-04-EA",
        "organization": "Valens Semiconductor Ltd.",
        "address_1": "8 Hanagar Street",
        "address_2": "Hod Hasharon  Hod Hasharon  4501309",
        "country": "IL"
    },
    "800DD7": {
        "oui_hex": "80-0D-D7",
        "organization": "Latticework, Inc",
        "address_1": "2210 O'Toole Ave, Suite 250",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "D0B53D": {
        "oui_hex": "D0-B5-3D",
        "organization": "SEPRO ROBOTIQUE",
        "address_1": "ZI Acti-Est Les Ajoncs",
        "address_2": "LA ROCHE SUR YON    F85003",
        "country": "FR"
    },
    "00D0EC": {
        "oui_hex": "00-D0-EC",
        "organization": "NAKAYO Inc",
        "address_1": "Development Support Center 165 Higashiomuro-machi",
        "address_2": "Maebashi-shi  Gunma  379-2105",
        "country": "JP"
    },
    "4CCC6A": {
        "oui_hex": "4C-CC-6A",
        "organization": "Micro-Star INTL CO., LTD.",
        "address_1": "No.69, Lide St.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "30636B": {
        "oui_hex": "30-63-6B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70884D": {
        "oui_hex": "70-88-4D",
        "organization": "JAPAN RADIO CO., LTD.",
        "address_1": "5-1-1 SHIMORENJYAKU,",
        "address_2": "MITAKA-SHI, TOKYO    181-8510",
        "country": "JP"
    },
    "A4F1E8": {
        "oui_hex": "A4-F1-E8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "546751": {
        "oui_hex": "54-67-51",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "240B0A": {
        "oui_hex": "24-0B-0A",
        "organization": "Palo Alto Networks",
        "address_1": "4401 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "D099D5": {
        "oui_hex": "D0-99-D5",
        "organization": "Alcatel-Lucent",
        "address_1": "777 East Middlefield Road",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "14C3C2": {
        "oui_hex": "14-C3-C2",
        "organization": "K.A. Schmersal GmbH & Co. KG",
        "address_1": "Möddinghofe 30",
        "address_2": "Wuppertal  NRW  42279",
        "country": "DE"
    },
    "10785B": {
        "oui_hex": "10-78-5B",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "DC0077": {
        "oui_hex": "DC-00-77",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F4F5A5": {
        "oui_hex": "F4-F5-A5",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo    24101",
        "country": "FI"
    },
    "EC9B5B": {
        "oui_hex": "EC-9B-5B",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "2CCC15": {
        "oui_hex": "2C-CC-15",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "14BB6E": {
        "oui_hex": "14-BB-6E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "1886AC": {
        "oui_hex": "18-86-AC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001F5C": {
        "oui_hex": "00-1F-5C",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001F00": {
        "oui_hex": "00-1F-00",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "002547": {
        "oui_hex": "00-25-47",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0018C5": {
        "oui_hex": "00-18-C5",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    1790",
        "country": "DK"
    },
    "00164E": {
        "oui_hex": "00-16-4E",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002668": {
        "oui_hex": "00-26-68",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "00247D": {
        "oui_hex": "00-24-7D",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002265": {
        "oui_hex": "00-22-65",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "F88096": {
        "oui_hex": "F8-80-96",
        "organization": "Elsys Equipamentos Eletrônicos Ltda",
        "address_1": "Rod. Visconde de Porto Seguro, n.º 2.660, Sitio Recreio dos Cafezais",
        "address_2": "Valinhos  SP  13278327",
        "country": "BR"
    },
    "A811FC": {
        "oui_hex": "A8-11-FC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DAA": {
        "oui_hex": "00-1D-AA",
        "organization": "DrayTek Corp.",
        "address_1": "No. 26, Fu-Shing Road",
        "address_2": "Hsin-Chu    303",
        "country": "TW"
    },
    "E498D1": {
        "oui_hex": "E4-98-D1",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "ESPOO    02150",
        "country": "FI"
    },
    "6C2779": {
        "oui_hex": "6C-27-79",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "ESPOO    02150",
        "country": "FI"
    },
    "00CF1C": {
        "oui_hex": "00-CF-1C",
        "organization": "Communication Machinery Corporation",
        "address_1": "1226 ANACAPA",
        "address_2": "SANTA BARBARA  CA  93101",
        "country": "US"
    },
    "28CC01": {
        "oui_hex": "28-CC-01",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D8FB5E": {
        "oui_hex": "D8-FB-5E",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "002326": {
        "oui_hex": "00-23-26",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "0CBF15": {
        "oui_hex": "0C-BF-15",
        "organization": "Genetec Inc.",
        "address_1": "2280 boul Alfred-Nobel",
        "address_2": "St. Laurent  Quebec  H4S 2A4",
        "country": "CA"
    },
    "000D4B": {
        "oui_hex": "00-0D-4B",
        "organization": "Roku, Inc.",
        "address_1": "399 Sherman Ave. #12",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "0040FB": {
        "oui_hex": "00-40-FB",
        "organization": "CASCADE COMMUNICATIONS",
        "address_1": "PRODUCTION QUALITY ENGINEER",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "D0542D": {
        "oui_hex": "D0-54-2D",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22 Floor,Qilai Tower;889 Yishan Road",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "744AA4": {
        "oui_hex": "74-4A-A4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "001BA9": {
        "oui_hex": "00-1B-A9",
        "organization": "Brother industries, LTD.",
        "address_1": "Printing & Solutions Company, Development Management Dept.",
        "address_2": "Nagoya  Aichi  467-8561",
        "country": "JP"
    },
    "30A220": {
        "oui_hex": "30-A2-20",
        "organization": "ARG Telecom",
        "address_1": "No.69, W. Lavasani St. ,",
        "address_2": "Tehran  Tehran  1936938194",
        "country": "IR"
    },
    "6CF373": {
        "oui_hex": "6C-F3-73",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C3AAF": {
        "oui_hex": "9C-3A-AF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "781FDB": {
        "oui_hex": "78-1F-DB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4CA56D": {
        "oui_hex": "4C-A5-6D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B86CE8": {
        "oui_hex": "B8-6C-E8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CB319": {
        "oui_hex": "0C-B3-19",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "183F47": {
        "oui_hex": "18-3F-47",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B46293": {
        "oui_hex": "B4-62-93",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "50A4C8": {
        "oui_hex": "50-A4-C8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00001D": {
        "oui_hex": "00-00-1D",
        "organization": "Cabletron Systems, Inc.",
        "address_1": "35 INDUSTRIAL WAY",
        "address_2": "ROCHESTER  NH  03867",
        "country": "US"
    },
    "1867B0": {
        "oui_hex": "18-67-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "6C8336": {
        "oui_hex": "6C-83-36",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DCD87C": {
        "oui_hex": "DC-D8-7C",
        "organization": "Beijing Jingdong Century Trading Co., LTD.",
        "address_1": "28F,Building A Zhaolin Plaza,NO.19,Ronghua Middle road,BDA Beijing",
        "address_2": "Beijing    100176",
        "country": "CN"
    },
    "C4DA7D": {
        "oui_hex": "C4-DA-7D",
        "organization": "Ivium Technologies B.V.",
        "address_1": "De Zaale 11",
        "address_2": "Eindhoven  Noord Brabant  5612 AJ",
        "country": "NL"
    },
    "000B6A": {
        "oui_hex": "00-0B-6A",
        "organization": "Asiarock Technology Limited",
        "address_1": "P.O. Box957, Offshore Incorporations Cen",
        "address_2": "Road Town  Tortola  12345",
        "country": "VG"
    },
    "009096": {
        "oui_hex": "00-90-96",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "2F, NO. 2, LANE 497",
        "address_2": "TAIPEI  23136    12345",
        "country": "TW"
    },
    "001B9E": {
        "oui_hex": "00-1B-9E",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,",
        "address_2": "CHUNG-HO,TPIPEI    235",
        "country": "TW"
    },
    "E0CA94": {
        "oui_hex": "E0-CA-94",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,CHUNG-HO,TAIPEI,",
        "address_2": "TAIWAN  TAIPEI  235",
        "country": "TW"
    },
    "0026B6": {
        "oui_hex": "00-26-B6",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,CHUNG-HO,TAIPEI,",
        "address_2": "TAIWAN  TAIPEI  235",
        "country": "TW"
    },
    "002557": {
        "oui_hex": "00-25-57",
        "organization": "BlackBerry RTS",
        "address_1": "440 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 5W9",
        "country": "CA"
    },
    "001CCC": {
        "oui_hex": "00-1C-CC",
        "organization": "BlackBerry RTS",
        "address_1": "305 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "00300A": {
        "oui_hex": "00-30-0A",
        "organization": "Aztech Electronics Pte Ltd",
        "address_1": "31 UBI ROAD 1",
        "address_2": "singapore    408694",
        "country": "SG"
    },
    "001F3F": {
        "oui_hex": "00-1F-3F",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "246511": {
        "oui_hex": "24-65-11",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "C0FFD4": {
        "oui_hex": "C0-FF-D4",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "6CB0CE": {
        "oui_hex": "6C-B0-CE",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "008EF2": {
        "oui_hex": "00-8E-F2",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "9CD36D": {
        "oui_hex": "9C-D3-6D",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C40415": {
        "oui_hex": "C4-04-15",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E8FCAF": {
        "oui_hex": "E8-FC-AF",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "841B5E": {
        "oui_hex": "84-1B-5E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "2CB05D": {
        "oui_hex": "2C-B0-5D",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A021B7": {
        "oui_hex": "A0-21-B7",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0024B2": {
        "oui_hex": "00-24-B2",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001B2F": {
        "oui_hex": "00-1B-2F",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00264D": {
        "oui_hex": "00-26-4D",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F., No. 9 , Park Avenue II ,",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "849CA6": {
        "oui_hex": "84-9C-A6",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "E03E44": {
        "oui_hex": "E0-3E-44",
        "organization": "Broadcom",
        "address_1": "190 Mathilda Place",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "001F33": {
        "oui_hex": "00-1F-33",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "002040": {
        "oui_hex": "00-20-40",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "386BBB": {
        "oui_hex": "38-6B-BB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E86D52": {
        "oui_hex": "E8-6D-52",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3C754A": {
        "oui_hex": "3C-75-4A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E48399": {
        "oui_hex": "E4-83-99",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002143": {
        "oui_hex": "00-21-43",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "74F612": {
        "oui_hex": "74-F6-12",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002495": {
        "oui_hex": "00-24-95",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0024A0": {
        "oui_hex": "00-24-A0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00080E": {
        "oui_hex": "00-08-0E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00909C": {
        "oui_hex": "00-90-9C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001225": {
        "oui_hex": "00-12-25",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "145BD1": {
        "oui_hex": "14-5B-D1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6CC1D2": {
        "oui_hex": "6C-C1-D2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1C1448": {
        "oui_hex": "1C-14-48",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001784": {
        "oui_hex": "00-17-84",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001C11": {
        "oui_hex": "00-1C-11",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001E46": {
        "oui_hex": "00-1E-46",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0018A4": {
        "oui_hex": "00-18-A4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0018C0": {
        "oui_hex": "00-18-C0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002374": {
        "oui_hex": "00-23-74",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "ACE010": {
        "oui_hex": "AC-E0-10",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road, ChungHo",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "747548": {
        "oui_hex": "74-75-48",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0000B1": {
        "oui_hex": "00-00-B1",
        "organization": "Alpha Micro",
        "address_1": "3501 SUNFLOWER",
        "address_2": "SANTA ANA  CA  92704",
        "country": "US"
    },
    "001802": {
        "oui_hex": "00-18-02",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing Seventh Road,Science-based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001E45": {
        "oui_hex": "00-1E-45",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001CA4": {
        "oui_hex": "00-1C-A4",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001A75": {
        "oui_hex": "00-1A-75",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "78843C": {
        "oui_hex": "78-84-3C",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec,5-1-12,",
        "address_2": "Shinagawa-ku  Tokyo  141-0001",
        "country": "JP"
    },
    "0013A9": {
        "oui_hex": "00-13-A9",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec, 5-1-2 Kitashinagawa",
        "address_2": "Tokyo    141-0001",
        "country": "JP"
    },
    "000AD9": {
        "oui_hex": "00-0A-D9",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "000E07": {
        "oui_hex": "00-0E-07",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "94CE2C": {
        "oui_hex": "94-CE-2C",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "FC0FE6": {
        "oui_hex": "FC-0F-E6",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "74DE2B": {
        "oui_hex": "74-DE-2B",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "00225F": {
        "oui_hex": "00-22-5F",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "5C93A2": {
        "oui_hex": "5C-93-A2",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road, ChungHo, TaiPei Hsien",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "24FD52": {
        "oui_hex": "24-FD-52",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "2CD05A": {
        "oui_hex": "2C-D0-5A",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "74E543": {
        "oui_hex": "74-E5-43",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "0015CF": {
        "oui_hex": "00-15-CF",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6CFAA7": {
        "oui_hex": "6C-FA-A7",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road",
        "address_2": "Hsinchu    30352",
        "country": "TW"
    },
    "0023F1": {
        "oui_hex": "00-23-F1",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "54E4BD": {
        "oui_hex": "54-E4-BD",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "5th Floor, A Building, Haoye Logistics Park, Shugang Channel, Bao'an District,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "5414FD": {
        "oui_hex": "54-14-FD",
        "organization": "Orbbec 3D Technology International",
        "address_1": "950 Stephenson Hwy Suite 208",
        "address_2": "Troy  MI  48083",
        "country": "US"
    },
    "900BC1": {
        "oui_hex": "90-0B-C1",
        "organization": "Sprocomm Technologies CO.,Ltd",
        "address_1": "5D-506 F1.6 Block,Tianfa Building,Tianan Chegongmiao Industrial Park,Futian Dist,Shenzhen China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "001CA8": {
        "oui_hex": "00-1C-A8",
        "organization": "AirTies Wireless Networks",
        "address_1": "Gulbahar Mahallesi, Avni Diligil Sokak",
        "address_2": "ISTANBUL  ISTANBUL  34394",
        "country": "TR"
    },
    "485D60": {
        "oui_hex": "48-5D-60",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F ., No.94, Baozhong Rd.",
        "address_2": "Xindian City  Taipei County  231",
        "country": "TW"
    },
    "DC85DE": {
        "oui_hex": "DC-85-DE",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F ., No.94, Baozhong RD, Sindian,",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "B0EE45": {
        "oui_hex": "B0-EE-45",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F ., No.94, Baozhong Rd. , Xindian Dist.,",
        "address_2": "New Taipei City    231",
        "country": "US"
    },
    "00238E": {
        "oui_hex": "00-23-8E",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "001D8B": {
        "oui_hex": "00-1D-8B",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "0013C8": {
        "oui_hex": "00-13-C8",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "DC0B1A": {
        "oui_hex": "DC-0B-1A",
        "organization": "ADB Broadband Italia",
        "address_1": "via Sarca 222",
        "address_2": "Milano    20126",
        "country": "IT"
    },
    "0C6AE6": {
        "oui_hex": "0C-6A-E6",
        "organization": "Stanley Security Solutions",
        "address_1": "6161 East 75th Street",
        "address_2": "Indianapolis  IN  46250",
        "country": "US"
    },
    "842615": {
        "oui_hex": "84-26-15",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "F0842F": {
        "oui_hex": "F0-84-2F",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "54271E": {
        "oui_hex": "54-27-1E",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "28C2DD": {
        "oui_hex": "28-C2-DD",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "80A589": {
        "oui_hex": "80-A5-89",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "C40938": {
        "oui_hex": "C4-09-38",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building,,Star-net Science Plaza",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "001C50": {
        "oui_hex": "00-1C-50",
        "organization": "TCL Technoly Electronics (Huizhou) Co., Ltd.",
        "address_1": "10/F, Block A , TCL Tower",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00AA02": {
        "oui_hex": "00-AA-02",
        "organization": "Intel Corporation",
        "address_1": "445",
        "address_2": "piscataway  NJ  08554",
        "country": "US"
    },
    "ACE5F0": {
        "oui_hex": "AC-E5-F0",
        "organization": "Doppler Labs",
        "address_1": "611 Broadway Suite 523",
        "address_2": "New York  NY  10012",
        "country": "US"
    },
    "F48E38": {
        "oui_hex": "F4-8E-38",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "74C63B": {
        "oui_hex": "74-C6-3B",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "7C7A91": {
        "oui_hex": "7C-7A-91",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "AC7BA1": {
        "oui_hex": "AC-7B-A1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6C2995": {
        "oui_hex": "6C-29-95",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "984FEE": {
        "oui_hex": "98-4F-EE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E82AEA": {
        "oui_hex": "E8-2A-EA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "605718": {
        "oui_hex": "60-57-18",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C4D987": {
        "oui_hex": "C4-D9-87",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "FCF8AE": {
        "oui_hex": "FC-F8-AE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6036DD": {
        "oui_hex": "60-36-DD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "100BA9": {
        "oui_hex": "10-0B-A9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "8C705A": {
        "oui_hex": "8C-70-5A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "606720": {
        "oui_hex": "60-67-20",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7C5CF8": {
        "oui_hex": "7C-5C-F8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B4E1C4": {
        "oui_hex": "B4-E1-C4",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "E0757D": {
        "oui_hex": "E0-75-7D",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "34BB26": {
        "oui_hex": "34-BB-26",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "806C1B": {
        "oui_hex": "80-6C-1B",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "0016EB": {
        "oui_hex": "00-16-EB",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0018DE": {
        "oui_hex": "00-18-DE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5CE0C5": {
        "oui_hex": "5C-E0-C5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "58A839": {
        "oui_hex": "58-A8-39",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001E67": {
        "oui_hex": "00-1E-67",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0022FA": {
        "oui_hex": "00-22-FA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001500": {
        "oui_hex": "00-15-00",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A088B4": {
        "oui_hex": "A0-88-B4",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "648099": {
        "oui_hex": "64-80-99",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D07E35": {
        "oui_hex": "D0-7E-35",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001E65": {
        "oui_hex": "00-1E-65",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "348446": {
        "oui_hex": "34-84-46",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "044E06": {
        "oui_hex": "04-4E-06",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "00270E": {
        "oui_hex": "00-27-0E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0026B9": {
        "oui_hex": "00-26-B9",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "64006A": {
        "oui_hex": "64-00-6A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00D09E": {
        "oui_hex": "00-D0-9E",
        "organization": "2Wire Inc",
        "address_1": "694 TASMAN DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "0019E4": {
        "oui_hex": "00-19-E4",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  94538",
        "country": "US"
    },
    "001AC4": {
        "oui_hex": "00-1A-C4",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  94538",
        "country": "US"
    },
    "001B5B": {
        "oui_hex": "00-1B-5B",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "3CEA4F": {
        "oui_hex": "3C-EA-4F",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "DC7FA4": {
        "oui_hex": "DC-7F-A4",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "B0D5CC": {
        "oui_hex": "B0-D5-CC",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3829DD": {
        "oui_hex": "38-29-DD",
        "organization": "ONvocal Inc",
        "address_1": "104 Otis Street, Ste 28",
        "address_2": "Northborough  MA  01532",
        "country": "US"
    },
    "001EC7": {
        "oui_hex": "00-1E-C7",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Prkwy",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "002650": {
        "oui_hex": "00-26-50",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "002351": {
        "oui_hex": "00-23-51",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001E4F": {
        "oui_hex": "00-1E-4F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "5C260A": {
        "oui_hex": "5C-26-0A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock     78682",
        "country": "US"
    },
    "7845C4": {
        "oui_hex": "78-45-C4",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "C81F66": {
        "oui_hex": "C8-1F-66",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "0015C5": {
        "oui_hex": "00-15-C5",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001422": {
        "oui_hex": "00-14-22",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "109836": {
        "oui_hex": "10-98-36",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "800A80": {
        "oui_hex": "80-0A-80",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F8DB88": {
        "oui_hex": "F8-DB-88",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "3CA348": {
        "oui_hex": "3C-A3-48",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "E45AA2": {
        "oui_hex": "E4-5A-A2",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "CC3B3E": {
        "oui_hex": "CC-3B-3E",
        "organization": "Lester Electrical",
        "address_1": "625 W A Street",
        "address_2": "Lincoln  NE  68522",
        "country": "US"
    },
    "2082C0": {
        "oui_hex": "20-82-C0",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "DC6DCD": {
        "oui_hex": "DC-6D-CD",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "C4282D": {
        "oui_hex": "C4-28-2D",
        "organization": "Embedded Intellect Pty Ltd",
        "address_1": "Level 32, 101 Miller Street",
        "address_2": "North Sydney  NSW  2060",
        "country": "AU"
    },
    "5846E1": {
        "oui_hex": "58-46-E1",
        "organization": "Baxter International Inc",
        "address_1": "One Baxter Parkway",
        "address_2": "Deerfield  IL  60015",
        "country": "US"
    },
    "00173F": {
        "oui_hex": "00-17-3F",
        "organization": "Belkin International Inc.",
        "address_1": "501 West Walnut Street",
        "address_2": "Compton  CA  90220-5221",
        "country": "US"
    },
    "001CDF": {
        "oui_hex": "00-1C-DF",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "C05627": {
        "oui_hex": "C0-56-27",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "4C17EB": {
        "oui_hex": "4C-17-EB",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "CC33BB": {
        "oui_hex": "CC-33-BB",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 ROUTE DE L'EMPEREUR",
        "address_2": "RUEIL MALMAISON CEDEX  Choisissez l'état / la province  92848",
        "country": "FR"
    },
    "D86CE9": {
        "oui_hex": "D8-6C-E9",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "E8F1B0": {
        "oui_hex": "E8-F1-B0",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "5C6B32": {
        "oui_hex": "5C-6B-32",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "84DD20": {
        "oui_hex": "84-DD-20",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001831": {
        "oui_hex": "00-18-31",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "24FD5B": {
        "oui_hex": "24-FD-5B",
        "organization": "SmartThings, Inc.",
        "address_1": "456 University Avenue",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "2876CD": {
        "oui_hex": "28-76-CD",
        "organization": "Funshion Online Technologies Co.,Ltd",
        "address_1": "Tower B 1201, Jinqiu International Building, No.6, Zhichun Road, Haidian District",
        "address_2": "Beijing    100088",
        "country": "CN"
    },
    "205532": {
        "oui_hex": "20-55-32",
        "organization": "Gotech International Technology Limited",
        "address_1": "Unit 2506, 25/F, Prosperity Place,6 Shing Yip Street, Kwun Tong,  Kowloon",
        "address_2": "Hong Kong    00000",
        "country": "CN"
    },
    "2CFF65": {
        "oui_hex": "2C-FF-65",
        "organization": "Oki Electric Industry Co., Ltd.",
        "address_1": "1-7-12 Toranomon",
        "address_2": "Tokyo 105-8460",
        "country": "JP"
    },
    "2C27D7": {
        "oui_hex": "2C-27-D7",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "984BE1": {
        "oui_hex": "98-4B-E1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "002926": {
        "oui_hex": "00-29-26",
        "organization": "Applied Optoelectronics, Inc Taiwan Branch",
        "address_1": "No.18,Gong 4th Rd",
        "address_2": "New Taipei City  Linkou District  24452",
        "country": "TW"
    },
    "24BA13": {
        "oui_hex": "24-BA-13",
        "organization": "RISO KAGAKU CORPORATION",
        "address_1": "2-8-1 Gakuen-minami",
        "address_2": "Thukuba-shi  Ibaraki  305-0818",
        "country": "JP"
    },
    "0017E5": {
        "oui_hex": "00-17-E5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017EC": {
        "oui_hex": "00-17-EC",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017E7": {
        "oui_hex": "00-17-E7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017E9": {
        "oui_hex": "00-17-E9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "1CBA8C": {
        "oui_hex": "1C-BA-8C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0015E9": {
        "oui_hex": "00-15-E9",
        "organization": "D-Link Corporation",
        "address_1": "2F, No.233-2, Pao-Chiao Road",
        "address_2": "Hsin-Tien,  Taipei  231",
        "country": "TW"
    },
    "001B11": {
        "oui_hex": "00-1B-11",
        "organization": "D-Link Corporation",
        "address_1": "NO.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "00265A": {
        "oui_hex": "00-26-5A",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District    114",
        "country": "TW"
    },
    "C8BE19": {
        "oui_hex": "C8-BE-19",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "A4BA76": {
        "oui_hex": "A4-BA-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0050C2": {
        "oui_hex": "00-50-C2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "440010": {
        "oui_hex": "44-00-10",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0056CD": {
        "oui_hex": "00-56-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "006037": {
        "oui_hex": "00-60-37",
        "organization": "NXP Semiconductors",
        "address_1": "High Tech Campus 32, Office 1.21",
        "address_2": "SAF  AD  13456",
        "country": "NL"
    },
    "DCC0EB": {
        "oui_hex": "DC-C0-EB",
        "organization": "ASSA ABLOY CÔTE PICARDE",
        "address_1": "rue Alexandre Fichet",
        "address_2": "Oust-Marest    80460",
        "country": "FR"
    },
    "28BC56": {
        "oui_hex": "28-BC-56",
        "organization": "EMAC, Inc.",
        "address_1": "2390 EMAC Way",
        "address_2": "Carbondale  IL  62902",
        "country": "US"
    },
    "00CDFE": {
        "oui_hex": "00-CD-FE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0F895": {
        "oui_hex": "A0-F8-95",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park.",
        "address_2": "Nanshan District, Shenzhen  GUANGDONG  518053",
        "country": "CN"
    },
    "0078CD": {
        "oui_hex": "00-78-CD",
        "organization": "Ignition Design Labs",
        "address_1": "1550 Technology Drive",
        "address_2": "San Jose    95110",
        "country": "US"
    },
    "B436A9": {
        "oui_hex": "B4-36-A9",
        "organization": "Fibocom Wireless Inc.",
        "address_1": " 5/F,Tower A,Technology Building II,1057# Nanhai Blvd",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "70CA4D": {
        "oui_hex": "70-CA-4D",
        "organization": "Shenzhen lnovance Technology Co.,Ltd.",
        "address_1": "LiuXian 2 Road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "001A11": {
        "oui_hex": "00-1A-11",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheater Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "48DB50": {
        "oui_hex": "48-DB-50",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C8478C": {
        "oui_hex": "C8-47-8C",
        "organization": "Beken Corporation",
        "address_1": "Building 41, Capital of Tech Leaders, 1387 Zhangdong Road, Zhangjiang High-Tech Park, Pudong New District",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "9CEFD5": {
        "oui_hex": "9C-EF-D5",
        "organization": "Panda Wireless, Inc.",
        "address_1": "15559 Union Ave, Suite 300",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "9C3426": {
        "oui_hex": "9C-34-26",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "2C6E85": {
        "oui_hex": "2C-6E-85",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001DD1": {
        "oui_hex": "00-1D-D1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DCF": {
        "oui_hex": "00-1D-CF",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DD5": {
        "oui_hex": "00-1D-D5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DD4": {
        "oui_hex": "00-1D-D4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E498D6": {
        "oui_hex": "E4-98-D6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002283": {
        "oui_hex": "00-22-83",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0010DB": {
        "oui_hex": "00-10-DB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00121E": {
        "oui_hex": "00-12-1E",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "CCA462": {
        "oui_hex": "CC-A4-62",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "484520": {
        "oui_hex": "48-45-20",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C80E77": {
        "oui_hex": "C8-0E-77",
        "organization": "Le Shi Zhi Xin Electronic Technology (Tianjin) Limited",
        "address_1": "No.201-427,2F,Tthe Animation  Building B1 District£¬No. 126£¬Tianjin eco-city animation Road",
        "address_2": "Tianjin    300467",
        "country": "CN"
    },
    "106F3F": {
        "oui_hex": "10-6F-3F",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "9049FA": {
        "oui_hex": "90-49-FA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "BC0F64": {
        "oui_hex": "BC-0F-64",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0000C5": {
        "oui_hex": "00-00-C5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "6455B1": {
        "oui_hex": "64-55-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0002B3": {
        "oui_hex": "00-02-B3",
        "organization": "Intel Corporation",
        "address_1": "M/S:  JF3-420",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "000347": {
        "oui_hex": "00-03-47",
        "organization": "Intel Corporation",
        "address_1": "M/S:  JF3-420",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "000E0C": {
        "oui_hex": "00-0E-0C",
        "organization": "Intel Corporation",
        "address_1": "2111 NE  25th Avenue",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "D8D385": {
        "oui_hex": "D8-D3-85",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "18A905": {
        "oui_hex": "18-A9-05",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "001B78": {
        "oui_hex": "00-1B-78",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "E4FAFD": {
        "oui_hex": "E4-FA-FD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "94659C": {
        "oui_hex": "94-65-9C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B0C745": {
        "oui_hex": "B0-C7-45",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg.,30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref  460-8315",
        "country": "JP"
    },
    "14CFE2": {
        "oui_hex": "14-CF-E2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "44E137": {
        "oui_hex": "44-E1-37",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001320": {
        "oui_hex": "00-13-20",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0080E1": {
        "oui_hex": "00-80-E1",
        "organization": "STMicroelectronics SRL",
        "address_1": "1000 AZTEC WEST",
        "address_2": "london    12345",
        "country": "GB"
    },
    "F8DB7F": {
        "oui_hex": "F8-DB-7F",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "64A769": {
        "oui_hex": "64-A7-69",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "E899C4": {
        "oui_hex": "E8-99-C4",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "BCCFCC": {
        "oui_hex": "BC-CF-CC",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "0004EA": {
        "oui_hex": "00-04-EA",
        "organization": "Hewlett Packard",
        "address_1": "MAIL STOP 42LE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "001279": {
        "oui_hex": "00-12-79",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001321": {
        "oui_hex": "00-13-21",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000802": {
        "oui_hex": "00-08-02",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0002A5": {
        "oui_hex": "00-02-A5",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001871": {
        "oui_hex": "00-18-71",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000E7F": {
        "oui_hex": "00-0E-7F",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001185": {
        "oui_hex": "00-11-85",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "10604B": {
        "oui_hex": "10-60-4B",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "C8CBB8": {
        "oui_hex": "C8-CB-B8",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "843497": {
        "oui_hex": "84-34-97",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "6CC217": {
        "oui_hex": "6C-C2-17",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "1458D0": {
        "oui_hex": "14-58-D0",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "5C8A38": {
        "oui_hex": "5C-8A-38",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "EC9A74": {
        "oui_hex": "EC-9A-74",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "2C59E5": {
        "oui_hex": "2C-59-E5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D8FC38": {
        "oui_hex": "D8-FC-38",
        "organization": "Giantec Semiconductor Inc",
        "address_1": "No12, Lane647, Songtao Rd, Zhangjiang Hi-Tech Park",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "AC2A0C": {
        "oui_hex": "AC-2A-0C",
        "organization": "CSR ZHUZHOU INSTITUTE CO.,LTD.",
        "address_1": "Times Ave.,Zhuzhou,hunan,China",
        "address_2": "zhuzhou  Hunan  412001",
        "country": "CN"
    },
    "2C6798": {
        "oui_hex": "2C-67-98",
        "organization": "InTalTech Ltd.",
        "address_1": "Shlomo Ben David 5",
        "address_2": "Rishon LeZion    7536215",
        "country": "IL"
    },
    "00234D": {
        "oui_hex": "00-23-4D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "002556": {
        "oui_hex": "00-25-56",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "601888": {
        "oui_hex": "60-18-88",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D860B0": {
        "oui_hex": "D8-60-B0",
        "organization": "bioMérieux Italia S.p.A.",
        "address_1": "Via di Campigliano, 58",
        "address_2": "Bagno a Ripoli  Firenze  50012",
        "country": "IT"
    },
    "54E6FC": {
        "oui_hex": "54-E6-FC",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "74EA3A": {
        "oui_hex": "74-EA-3A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F81A67": {
        "oui_hex": "F8-1A-67",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "EC172F": {
        "oui_hex": "EC-17-2F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "847778": {
        "oui_hex": "84-77-78",
        "organization": "Cochlear Limited",
        "address_1": "1 University Avenue",
        "address_2": "Sydney  New South Wales  2109",
        "country": "AU"
    },
    "887F03": {
        "oui_hex": "88-7F-03",
        "organization": "Comper Technology Investment Limited",
        "address_1": "Room 710, Wangjing SOHO Tower 1-B",
        "address_2": "Beijing  Beijing  100102",
        "country": "CN"
    },
    "0019E0": {
        "oui_hex": "00-19-E0",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "South Building, No.5 Keyuan Road",
        "address_2": "Nanshan  Shenzhen  518057",
        "country": "CN"
    },
    "002586": {
        "oui_hex": "00-25-86",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F431C3": {
        "oui_hex": "F4-31-C3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64A5C3": {
        "oui_hex": "64-A5-C3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28565A": {
        "oui_hex": "28-56-5A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "6CB56B": {
        "oui_hex": "6C-B5-6B",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village,216,Hwangsaeul-ro,Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "BC3AEA": {
        "oui_hex": "BC-3A-EA",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN,DONGGUAN,GUANGDONG,CHINA",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "E422A5": {
        "oui_hex": "E4-22-A5",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "D4C9B2": {
        "oui_hex": "D4-C9-B2",
        "organization": "Quanergy Systems Inc",
        "address_1": "482 Mercury Drive",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "6021C0": {
        "oui_hex": "60-21-C0",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "88308A": {
        "oui_hex": "88-30-8A",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "5CDAD4": {
        "oui_hex": "5C-DA-D4",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "0026E8": {
        "oui_hex": "00-26-E8",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "002512": {
        "oui_hex": "00-25-12",
        "organization": "zte corporation",
        "address_1": "12/F ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  GUANGDONG  518057",
        "country": "CN"
    },
    "001C26": {
        "oui_hex": "00-1C-26",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "14E6E4": {
        "oui_hex": "14-E6-E4",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan,",
        "address_2": "Shenzhen  Guangdong Province,  518057",
        "country": "CN"
    },
    "344B50": {
        "oui_hex": "34-4B-50",
        "organization": "zte corporation",
        "address_1": "12/F,ZTE R&D Building,Kejinan Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "FCC897": {
        "oui_hex": "FC-C8-97",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0016CE": {
        "oui_hex": "00-16-CE",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "002268": {
        "oui_hex": "00-22-68",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "001882": {
        "oui_hex": "00-18-82",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "F1-20,Section F,Huawei Base,Bantian, Longgang District",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "D4EA0E": {
        "oui_hex": "D4-EA-0E",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "6CFA58": {
        "oui_hex": "6C-FA-58",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "20F3A3": {
        "oui_hex": "20-F3-A3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0C37DC": {
        "oui_hex": "0C-37-DC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "BC7670": {
        "oui_hex": "BC-76-70",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "24DBAC": {
        "oui_hex": "24-DB-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "1C1D67": {
        "oui_hex": "1C-1D-67",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "300ED5": {
        "oui_hex": "30-0E-D5",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "485AB6": {
        "oui_hex": "48-5A-B6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "543530": {
        "oui_hex": "54-35-30",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "F866D1": {
        "oui_hex": "F8-66-D1",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "2469A5": {
        "oui_hex": "24-69-A5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "EC233D": {
        "oui_hex": "EC-23-3D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78F5FD": {
        "oui_hex": "78-F5-FD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5C7D5E": {
        "oui_hex": "5C-7D-5E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "90671C": {
        "oui_hex": "90-67-1C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC25E0": {
        "oui_hex": "BC-25-E0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4E3FB": {
        "oui_hex": "F4-E3-FB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D02DB3": {
        "oui_hex": "D0-2D-B3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "E8CD2D": {
        "oui_hex": "E8-CD-2D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "84A8E4": {
        "oui_hex": "84-A8-E4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "0C96BF": {
        "oui_hex": "0C-96-BF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "60E701": {
        "oui_hex": "60-E7-01",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8088B": {
        "oui_hex": "E8-08-8B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A051C6": {
        "oui_hex": "A0-51-C6",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "F0EBD0": {
        "oui_hex": "F0-EB-D0",
        "organization": "Shanghai Feixun Communication Co.,Ltd.",
        "address_1": "Building 90,No,4855,Guangfulin Road",
        "address_2": "shanghai  Shanghai  201616",
        "country": "CN"
    },
    "643E8C": {
        "oui_hex": "64-3E-8C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "0012D2": {
        "oui_hex": "00-12-D2",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "A863F2": {
        "oui_hex": "A8-63-F2",
        "organization": "Texas Instruments",
        "address_1": "12203 S.W.Freeway, MS728",
        "address_2": "Stafford    77477",
        "country": "US"
    },
    "7C6097": {
        "oui_hex": "7C-60-97",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "CC53B5": {
        "oui_hex": "CC-53-B5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "60DE44": {
        "oui_hex": "60-DE-44",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "105172": {
        "oui_hex": "10-51-72",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "08E84F": {
        "oui_hex": "08-E8-4F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "888603": {
        "oui_hex": "88-86-03",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen    518129",
        "country": "CN"
    },
    "04F938": {
        "oui_hex": "04-F9-38",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "AC853D": {
        "oui_hex": "AC-85-3D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "4846FB": {
        "oui_hex": "48-46-FB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "D0FF50": {
        "oui_hex": "D0-FF-50",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "20C38F": {
        "oui_hex": "20-C3-8F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "7C669D": {
        "oui_hex": "7C-66-9D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D8DDFD": {
        "oui_hex": "D8-DD-FD",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D05FB8": {
        "oui_hex": "D0-5F-B8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "E0247F": {
        "oui_hex": "E0-24-7F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "00464B": {
        "oui_hex": "00-46-4B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "80FB06": {
        "oui_hex": "80-FB-06",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "6CA849": {
        "oui_hex": "6C-A8-49",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "64C354": {
        "oui_hex": "64-C3-54",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "50CD22": {
        "oui_hex": "50-CD-22",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "B4A95A": {
        "oui_hex": "B4-A9-5A",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "84EB18": {
        "oui_hex": "84-EB-18",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "EC1127": {
        "oui_hex": "EC-11-27",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "581626": {
        "oui_hex": "58-16-26",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "70E422": {
        "oui_hex": "70-E4-22",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00500F": {
        "oui_hex": "00-50-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7C1DD9": {
        "oui_hex": "7C-1D-D9",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "A086C6": {
        "oui_hex": "A0-86-C6",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "9C99A0": {
        "oui_hex": "9C-99-A0",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "584498": {
        "oui_hex": "58-44-98",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "00E0B0": {
        "oui_hex": "00-E0-B0",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E0FE": {
        "oui_hex": "00-E0-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E034": {
        "oui_hex": "00-E0-34",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E0F9": {
        "oui_hex": "00-E0-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "C8D719": {
        "oui_hex": "C8-D7-19",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine    92612",
        "country": "US"
    },
    "001079": {
        "oui_hex": "00-10-79",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001029": {
        "oui_hex": "00-10-29",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "000E08": {
        "oui_hex": "00-0E-08",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "170 West Tasman Dr.",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "4403A7": {
        "oui_hex": "44-03-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B0FAEB": {
        "oui_hex": "B0-FA-EB",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7CAD74": {
        "oui_hex": "7C-AD-74",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00603E": {
        "oui_hex": "00-60-3E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00602F": {
        "oui_hex": "00-60-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "006047": {
        "oui_hex": "00-60-47",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0050A2": {
        "oui_hex": "00-50-A2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00023D": {
        "oui_hex": "00-02-3D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "203A07": {
        "oui_hex": "20-3A-07",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00502A": {
        "oui_hex": "00-50-2A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "BC16F5": {
        "oui_hex": "BC-16-F5",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "FC5B39": {
        "oui_hex": "FC-5B-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "346F90": {
        "oui_hex": "34-6F-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "5CFC66": {
        "oui_hex": "5C-FC-66",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "D46D50": {
        "oui_hex": "D4-6D-50",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "74A02F": {
        "oui_hex": "74-A0-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "88908D": {
        "oui_hex": "88-90-8D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F07816": {
        "oui_hex": "F0-78-16",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00223A": {
        "oui_hex": "00-22-3A",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "0021BE": {
        "oui_hex": "00-21-BE",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "14DAE9": {
        "oui_hex": "14-DA-E9",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "F4CFE2": {
        "oui_hex": "F4-CF-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A80C0D": {
        "oui_hex": "A8-0C-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C07BBC": {
        "oui_hex": "C0-7B-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "24E9B3": {
        "oui_hex": "24-E9-B3",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0011D8": {
        "oui_hex": "00-11-D8",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "No.150, Li-Te Rd., Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "C08C60": {
        "oui_hex": "C0-8C-60",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E8EDF3": {
        "oui_hex": "E8-ED-F3",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E4C722": {
        "oui_hex": "E4-C7-22",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "64E950": {
        "oui_hex": "64-E9-50",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F41FC2": {
        "oui_hex": "F4-1F-C2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "44ADD9": {
        "oui_hex": "44-AD-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0C6803": {
        "oui_hex": "0C-68-03",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1CDEA7": {
        "oui_hex": "1C-DE-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F07F06": {
        "oui_hex": "F0-7F-06",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "88F031": {
        "oui_hex": "88-F0-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0018F3": {
        "oui_hex": "00-18-F3",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "001A92": {
        "oui_hex": "00-1A-92",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "000C41": {
        "oui_hex": "00-0C-41",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "0016B6": {
        "oui_hex": "00-16-B6",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "0018F8": {
        "oui_hex": "00-18-F8",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "00252E": {
        "oui_hex": "00-25-2E",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "54D46F": {
        "oui_hex": "54-D4-6F",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "A4A24A": {
        "oui_hex": "A4-A2-4A",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "44E08E": {
        "oui_hex": "44-E0-8E",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "00E036": {
        "oui_hex": "00-E0-36",
        "organization": "PIONEER CORPORATION",
        "address_1": "2610 Hanazono 4-Chome",
        "address_2": "Saitama Prefecture, 359-8    34567",
        "country": "JP"
    },
    "00E04F": {
        "oui_hex": "00-E0-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0010FF": {
        "oui_hex": "00-10-FF",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001054": {
        "oui_hex": "00-10-54",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0010F6": {
        "oui_hex": "00-10-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0010A6": {
        "oui_hex": "00-10-A6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "BCC810": {
        "oui_hex": "BC-C8-10",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "7CB21B": {
        "oui_hex": "7C-B2-1B",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville    30044",
        "country": "US"
    },
    "24767D": {
        "oui_hex": "24-76-7D",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "481D70": {
        "oui_hex": "48-1D-70",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "F0B2E5": {
        "oui_hex": "F0-B2-E5",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "002332": {
        "oui_hex": "00-23-32",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00236C": {
        "oui_hex": "00-23-6C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0023DF": {
        "oui_hex": "00-23-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002500": {
        "oui_hex": "00-25-00",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0025BC": {
        "oui_hex": "00-25-BC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5897BD": {
        "oui_hex": "58-97-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "5C838F": {
        "oui_hex": "5C-83-8F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "ECBD1D": {
        "oui_hex": "EC-BD-1D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0019E3": {
        "oui_hex": "00-19-E3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001B63": {
        "oui_hex": "00-1B-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001EC2": {
        "oui_hex": "00-1E-C2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001FF3": {
        "oui_hex": "00-1F-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0010FA": {
        "oui_hex": "00-10-FA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0050E4": {
        "oui_hex": "00-50-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000D93": {
        "oui_hex": "00-0D-93",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CFADF": {
        "oui_hex": "7C-FA-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78A3E4": {
        "oui_hex": "78-A3-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "148FC6": {
        "oui_hex": "14-8F-C6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "286AB8": {
        "oui_hex": "28-6A-B8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28E02C": {
        "oui_hex": "28-E0-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0B9BA": {
        "oui_hex": "E0-B9-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00C610": {
        "oui_hex": "00-C6-10",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8F6B1": {
        "oui_hex": "B8-F6-B1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8CFABA": {
        "oui_hex": "8C-FA-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CD1C3": {
        "oui_hex": "7C-D1-C3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0DCE2": {
        "oui_hex": "F0-DC-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24AB81": {
        "oui_hex": "24-AB-81",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0F847": {
        "oui_hex": "E0-F8-47",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28E7CF": {
        "oui_hex": "28-E7-CF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E4CE8F": {
        "oui_hex": "E4-CE-8F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A82066": {
        "oui_hex": "A8-20-66",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC52B7": {
        "oui_hex": "BC-52-B7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C5948": {
        "oui_hex": "5C-59-48",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8BCC8": {
        "oui_hex": "C8-BC-C8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E8040B": {
        "oui_hex": "E8-04-0B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "145A05": {
        "oui_hex": "14-5A-05",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1CABA7": {
        "oui_hex": "1C-AB-A7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0847A": {
        "oui_hex": "C0-84-7A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34159E": {
        "oui_hex": "34-15-9E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "58B035": {
        "oui_hex": "58-B0-35",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC86D8": {
        "oui_hex": "DC-86-D8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90B931": {
        "oui_hex": "90-B9-31",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0E140": {
        "oui_hex": "D0-E1-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24A2E1": {
        "oui_hex": "24-A2-E1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04214C": {
        "oui_hex": "04-21-4C",
        "organization": "Insight Energy Ventures LLC",
        "address_1": "123 W. Fifth St",
        "address_2": "Royal Oak  MI  48067",
        "country": "US"
    },
    "F832E4": {
        "oui_hex": "F8-32-E4",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "80EA96": {
        "oui_hex": "80-EA-96",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "600308": {
        "oui_hex": "60-03-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04F13E": {
        "oui_hex": "04-F1-3E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98F0AB": {
        "oui_hex": "98-F0-AB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7831C1": {
        "oui_hex": "78-31-C1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "783A84": {
        "oui_hex": "78-3A-84",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C8D4E": {
        "oui_hex": "5C-8D-4E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8863DF": {
        "oui_hex": "88-63-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "881FA1": {
        "oui_hex": "88-1F-A1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8E0EB": {
        "oui_hex": "C8-E0-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98B8E3": {
        "oui_hex": "98-B8-E3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "885395": {
        "oui_hex": "88-53-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "786C1C": {
        "oui_hex": "78-6C-1C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C8D79": {
        "oui_hex": "4C-8D-79",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1CE62B": {
        "oui_hex": "1C-E6-2B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C3021": {
        "oui_hex": "0C-30-21",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C3E9F": {
        "oui_hex": "0C-3E-9F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCFC48": {
        "oui_hex": "FC-FC-48",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C293F": {
        "oui_hex": "9C-29-3F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80A1AB": {
        "oui_hex": "80-A1-AB",
        "organization": "Intellisis",
        "address_1": "10350 Science Center Dr",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "84285A": {
        "oui_hex": "84-28-5A",
        "organization": "Saffron Solutions Inc",
        "address_1": "1337 Mass Ave #273",
        "address_2": "Arlington  MA  02476",
        "country": "US"
    },
    "D4B8FF": {
        "oui_hex": "D4-B8-FF",
        "organization": "Home Control Singapore Pte Ltd",
        "address_1": "620A Lorong 1 Toa Payoh",
        "address_2": "Singapore  Singapore  217909",
        "country": "SG"
    },
    "087402": {
        "oui_hex": "08-74-02",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "94F6A3": {
        "oui_hex": "94-F6-A3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98E0D9": {
        "oui_hex": "98-E0-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC29F5": {
        "oui_hex": "CC-29-F5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "285AEB": {
        "oui_hex": "28-5A-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F02475": {
        "oui_hex": "F0-24-75",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C1F23": {
        "oui_hex": "2C-1F-23",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "549F13": {
        "oui_hex": "54-9F-13",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0DBE2": {
        "oui_hex": "F0-DB-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "748114": {
        "oui_hex": "74-81-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18F643": {
        "oui_hex": "18-F6-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A45E60": {
        "oui_hex": "A4-5E-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A01828": {
        "oui_hex": "A0-18-28",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0034B": {
        "oui_hex": "D0-03-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "10417F": {
        "oui_hex": "10-41-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A8667F": {
        "oui_hex": "A8-66-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D02598": {
        "oui_hex": "D0-25-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80BE05": {
        "oui_hex": "80-BE-05",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24A074": {
        "oui_hex": "24-A0-74",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84788B": {
        "oui_hex": "84-78-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84A423": {
        "oui_hex": "84-A4-23",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "3C7873": {
        "oui_hex": "3C-78-73",
        "organization": "Airsonics",
        "address_1": "1289 Fordham Blvd.",
        "address_2": "Chapel Hill  NC  27514",
        "country": "US"
    },
    "9C88AD": {
        "oui_hex": "9C-88-AD",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "88947E": {
        "oui_hex": "88-94-7E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "C8A2CE": {
        "oui_hex": "C8-A2-CE",
        "organization": "Oasis Media Systems LLC",
        "address_1": "1073 Barley Sheaf Rd",
        "address_2": "Flemington  NJ  08822",
        "country": "US"
    },
    "58F496": {
        "oui_hex": "58-F4-96",
        "organization": "Source Chain",
        "address_1": "#407-4 eBIZ.Center",
        "address_2": "Seoul  seoul  ASI|KR|KS013|SEOUL",
        "country": "KR"
    },
    "587F57": {
        "oui_hex": "58-7F-57",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D07C2D": {
        "oui_hex": "D0-7C-2D",
        "organization": "Leie IOT technology Co., Ltd",
        "address_1": "9th floor,Hongchengxintai building,No.105,Yaojiayuan Road,Chaoyang District,Beijing",
        "address_2": "Beijing  Beijing  100026",
        "country": "CN"
    },
    "EC64E7": {
        "oui_hex": "EC-64-E7",
        "organization": "MOCACARE Corporation",
        "address_1": "887 Federation Way",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "40862E": {
        "oui_hex": "40-86-2E",
        "organization": "JDM MOBILE INTERNET SOLUTION CO., LTD.",
        "address_1": "",
        "address_2": "Jiashan  Zhejiang  314100",
        "country": "CN"
    },
    "C4BBEA": {
        "oui_hex": "C4-BB-EA",
        "organization": "Pakedge Device and Software Inc",
        "address_1": "3847 Breakwater Ave",
        "address_2": "Hayward  CA  94545",
        "country": "US"
    },
    "988744": {
        "oui_hex": "98-87-44",
        "organization": "Wuxi Hongda Science and Technology Co.,LTD",
        "address_1": "No.10 An Nan Road, Nan Quan Town, Bin Hu District",
        "address_2": "WUXI  Jiangsu  214128",
        "country": "CN"
    },
    "E8343E": {
        "oui_hex": "E8-34-3E",
        "organization": "Beijing Infosec Technologies Co., LTD.",
        "address_1": "Floor 4, Tower C, Global Finance and News Center",
        "address_2": "Beijing  Beijing  100052",
        "country": "CN"
    },
    "346987": {
        "oui_hex": "34-69-87",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "98F428": {
        "oui_hex": "98-F4-28",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A4CC32": {
        "oui_hex": "A4-CC-32",
        "organization": "Inficomm Co., Ltd",
        "address_1": "3F, B-31 Building, Tanglang Industry Park, Taoyuan Str, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "006D52": {
        "oui_hex": "00-6D-52",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A03299": {
        "oui_hex": "A0-32-99",
        "organization": "Lenovo (Beijing) Co., Ltd.",
        "address_1": "No.6, ChuangYe Road,",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "4054E4": {
        "oui_hex": "40-54-E4",
        "organization": "Wearsafe Labs Inc",
        "address_1": "1429 Park Street",
        "address_2": "Hartford  CT  06106",
        "country": "US"
    },
    "DC9A8E": {
        "oui_hex": "DC-9A-8E",
        "organization": "Nanjing Cocomm electronics co., LTD",
        "address_1": "Room 201,the Qinheng technology park building",
        "address_2": "Nanjing  Jiangsu  210012",
        "country": "CN"
    },
    "ACEE9E": {
        "oui_hex": "AC-EE-9E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B857D8": {
        "oui_hex": "B8-57-D8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "70BF3E": {
        "oui_hex": "70-BF-3E",
        "organization": "Charles River Laboratories",
        "address_1": "1023 Wappoo Road Suite 43B",
        "address_2": "Charleston  SC  29407",
        "country": "US"
    },
    "A8C87F": {
        "oui_hex": "A8-C8-7F",
        "organization": "Roqos, Inc.",
        "address_1": "1775 Greensboro Station Place",
        "address_2": "Mclean  Virginia  22102",
        "country": "US"
    },
    "3C831E": {
        "oui_hex": "3C-83-1E",
        "organization": "CKD Corporation",
        "address_1": "250, Ouji 2-Chome",
        "address_2": "Komaki  Aichi  485-8551",
        "country": "JP"
    },
    "90DFFB": {
        "oui_hex": "90-DF-FB",
        "organization": "HOMERIDER SYSTEMS",
        "address_1": "12 RUE REMORA",
        "address_2": "GRADIGNAN  GIRONDE  33170",
        "country": "FR"
    },
    "305A3A": {
        "oui_hex": "30-5A-3A",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "2C081C": {
        "oui_hex": "2C-08-1C",
        "organization": "OVH",
        "address_1": "2, rue Kellermann",
        "address_2": "Roubaix  Nord  59100",
        "country": "FR"
    },
    "C08488": {
        "oui_hex": "C0-84-88",
        "organization": "Finis Inc",
        "address_1": "7085-E Las Positas Rd",
        "address_2": "Livermore  CA  94551",
        "country": "US"
    },
    "38F557": {
        "oui_hex": "38-F5-57",
        "organization": "JOLATA, INC.",
        "address_1": "2262 N. FIRST ST.",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "54A3FA": {
        "oui_hex": "54-A3-FA",
        "organization": "BQT Solutions (Australia)Pty Ltd",
        "address_1": "Unit 29, 1 Talavera Road",
        "address_2": "North Ryde  NSW  2113",
        "country": "AU"
    },
    "246C8A": {
        "oui_hex": "24-6C-8A",
        "organization": "YUKAI Engineering",
        "address_1": "16-11-101, Tomihisa, Shinjuku",
        "address_2": "Tokyo  -  162-0067",
        "country": ""
    },
    "161110": {
        "oui_hex": "16-11-10",
        "organization": "16-11-101, Tomihisa, Shinjuku",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "ACC51B": {
        "oui_hex": "AC-C5-1B",
        "organization": "Zhuhai Pantum Electronics Co., Ltd.",
        "address_1": "Area A, 3rd floor, Building No.1, No.3883, Zhuhai Avenue, Zhuhai, Guangdong, China",
        "address_2": "Zhuhai  Guangdong  519000",
        "country": "CN"
    },
    "385F66": {
        "oui_hex": "38-5F-66",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "B844D9": {
        "oui_hex": "B8-44-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C7A03": {
        "oui_hex": "9C-7A-03",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "5CCF7F": {
        "oui_hex": "5C-CF-7F",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "681295": {
        "oui_hex": "68-12-95",
        "organization": "Lupine Lighting Systems GmbH",
        "address_1": "Winnberger Weg 11",
        "address_2": "Neumarkt  Bavaria  92318",
        "country": "DE"
    },
    "7011AE": {
        "oui_hex": "70-11-AE",
        "organization": "Music Life LTD",
        "address_1": "Unit E, 31/F, Billion Centre Tower A",
        "address_2": "Kowloon  N/A  00000",
        "country": "HK"
    },
    "041E7A": {
        "oui_hex": "04-1E-7A",
        "organization": "DSPWorks",
        "address_1": "12/947, MHB Colony, Gorai Road",
        "address_2": "Mumbai    400091",
        "country": "IN"
    },
    "84A788": {
        "oui_hex": "84-A7-88",
        "organization": "Perples",
        "address_1": "8F, 209 Dosan-daero,",
        "address_2": "Seoul    135-892",
        "country": "KR"
    },
    "AC60B6": {
        "oui_hex": "AC-60-B6",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "14B370": {
        "oui_hex": "14-B3-70",
        "organization": "Gigaset Digital Technology (Shenzhen) Co., Ltd.",
        "address_1": "11/F, Matsunichi Building, No.9996 Shen Nan Boulevard,  Nan Shan District, Shenzhen, China",
        "address_2": "ShenZhen  Guangdong  518000",
        "country": "CN"
    },
    "6889C1": {
        "oui_hex": "68-89-C1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C497B": {
        "oui_hex": "1C-49-7B",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road Hsinchu Industrial Park Hukou, Hsinchu 30352 TAIWAN, REPUBLIC OF CHINA",
        "address_2": "Hsinchu  TAIWAN  30352",
        "country": "TW"
    },
    "2CCF58": {
        "oui_hex": "2C-CF-58",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D09380": {
        "oui_hex": "D0-93-80",
        "organization": "Ducere Technologies Pvt. Ltd.",
        "address_1": "222B West Marredpally",
        "address_2": "Secunderabad  Telangana  500026",
        "country": "IN"
    },
    "68F956": {
        "oui_hex": "68-F9-56",
        "organization": "Objetivos y Servicio de Valor Añadido",
        "address_1": "c/Monte Esquinza, 28 1ºD",
        "address_2": "MADRID  MADRID  28010",
        "country": "ES"
    },
    "C8A9FC": {
        "oui_hex": "C8-A9-FC",
        "organization": "Goyoo Networks Inc.",
        "address_1": "Building D, Kelin Blocks, No.107, Dongsi North St,",
        "address_2": "Beijing  Beijing  100007",
        "country": "CN"
    },
    "FCFEC2": {
        "oui_hex": "FC-FE-C2",
        "organization": "Invensys Controls UK Limited",
        "address_1": "401 Southway Drive",
        "address_2": "Plymouth  Devon  Pl6 6QT",
        "country": "GB"
    },
    "689AB7": {
        "oui_hex": "68-9A-B7",
        "organization": "Atelier Vision Corporation",
        "address_1": "888-340 Nakagawa",
        "address_2": "Hamamatsu  Shizuoka  431-1304",
        "country": "JP"
    },
    "444CA8": {
        "oui_hex": "44-4C-A8",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "7C2BE1": {
        "oui_hex": "7C-2B-E1",
        "organization": "Shenzhen Ferex Electrical Co.,Ltd",
        "address_1": "Block 2,Jiuzhou Industrial Park,Gongming",
        "address_2": "Shenzhen  Guangdong  518107",
        "country": "CN"
    },
    "5031AD": {
        "oui_hex": "50-31-AD",
        "organization": "ABB Global Industries and Services Private Limited",
        "address_1": "21st floor, World Trade Center",
        "address_2": "Bangalore  Karnataka  560055",
        "country": "IN"
    },
    "143EBF": {
        "oui_hex": "14-3E-BF",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "FC2FEF": {
        "oui_hex": "FC-2F-EF",
        "organization": "UTT Technologies Co., Ltd.",
        "address_1": "Room 301, Building 9, No. 518 Xinzhuan",
        "address_2": "Shanghai  Shanghai  201612",
        "country": "CN"
    },
    "A4C138": {
        "oui_hex": "A4-C1-38",
        "organization": "Telink Semiconductor (Taipei) Co. Ltd.",
        "address_1": "Room 1050. 10F. Buld. H, No. 3-2 YuanQu St.,",
        "address_2": "Taipei  Taipei  11503",
        "country": "TW"
    },
    "20F510": {
        "oui_hex": "20-F5-10",
        "organization": "Codex Digital Limited",
        "address_1": "60 Poland Street",
        "address_2": "London  Greater London  W1F 7NT",
        "country": "GB"
    },
    "A8741D": {
        "oui_hex": "A8-74-1D",
        "organization": "PHOENIX CONTACT Electronics GmbH",
        "address_1": "Dringenauer Str. 30",
        "address_2": "Bad Pyrmont  -  D-31812",
        "country": "DE"
    },
    "F09A51": {
        "oui_hex": "F0-9A-51",
        "organization": "Shanghai Viroyal Electronic Technology Company Limited",
        "address_1": "LevelB,Building#3,401 Caobao Road,Shanghai,China",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "4CB82C": {
        "oui_hex": "4C-B8-2C",
        "organization": "Cambridge Mobile Telematics, Inc.",
        "address_1": "One Broadway, 14th Floor",
        "address_2": "Cambridge  MA  02142",
        "country": "US"
    },
    "E4A32F": {
        "oui_hex": "E4-A3-2F",
        "organization": "Shanghai Artimen Technology Co., Ltd.",
        "address_1": "Room 4462, Third Building, No. 505, Xinge Road, Xinqiao Town, SongJiang District, Shanghai City, China",
        "address_2": "Shanghai  Shanghai  201206",
        "country": "CN"
    },
    "F4672D": {
        "oui_hex": "F4-67-2D",
        "organization": "ShenZhen Topstar Technology Company",
        "address_1": "5/F Buliding 204,Tai Ran ShenZhen Science&Industry Park",
        "address_2": "ShenZhen  GuangZhou  518042",
        "country": "CN"
    },
    "A8D828": {
        "oui_hex": "A8-D8-28",
        "organization": "Ascensia Diabetes Care",
        "address_1": "5 Wood Hollow Rd,",
        "address_2": "Parsippany  NJ  07054",
        "country": "US"
    },
    "B869C2": {
        "oui_hex": "B8-69-C2",
        "organization": "Sunitec Enterprise Co., Ltd.",
        "address_1": "1F., No.35, Dayong St., Zhonghe Dist.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "88CBA5": {
        "oui_hex": "88-CB-A5",
        "organization": "Suzhou Torchstar Intelligent Technology Co.,Ltd",
        "address_1": "Rm1704B,Business Building, No.181, Cuiyuan Rd.,SIP",
        "address_2": "Suzhou  Jiangsu Province  215000",
        "country": "CN"
    },
    "7CA23E": {
        "oui_hex": "7C-A2-3E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "501AA5": {
        "oui_hex": "50-1A-A5",
        "organization": "GN Netcom A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup  Ballerup  DK-2750",
        "country": "DK"
    },
    "A48D3B": {
        "oui_hex": "A4-8D-3B",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "1C56FE": {
        "oui_hex": "1C-56-FE",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "B899B0": {
        "oui_hex": "B8-99-B0",
        "organization": "Cohere Technologies",
        "address_1": "404 Saratoga Avenue",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "D85DEF": {
        "oui_hex": "D8-5D-EF",
        "organization": "Busch-Jaeger Elektro GmbH",
        "address_1": "Freisenbergstrasse 2",
        "address_2": "Luedenscheid  NRW  58513",
        "country": "DE"
    },
    "88A2D7": {
        "oui_hex": "88-A2-D7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00323A": {
        "oui_hex": "00-32-3A",
        "organization": "so-logic",
        "address_1": "Lustkandlgasse 52",
        "address_2": "Vienna  Vienna  1090",
        "country": "AT"
    },
    "809FAB": {
        "oui_hex": "80-9F-AB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E00370": {
        "oui_hex": "E0-03-70",
        "organization": "ShenZhen Continental Wireless Technology Co., Ltd.",
        "address_1": "North 23F, Dongfang Technology Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "046169": {
        "oui_hex": "04-61-69",
        "organization": "MEDIA GLOBAL LINKS CO., LTD.",
        "address_1": "580-16, Horikawa-cho",
        "address_2": "Kawasaki  Kanagawa  212-0013",
        "country": "JP"
    },
    "BCEB5F": {
        "oui_hex": "BC-EB-5F",
        "organization": "Fujian Beifeng Telecom Technology Co., Ltd.",
        "address_1": "A-15, Huaqiao Economic Development Zone, Shuangyang, Luojiang,",
        "address_2": "quanzhou  fujian  362000",
        "country": "CN"
    },
    "AC5A14": {
        "oui_hex": "AC-5A-14",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F0AB54": {
        "oui_hex": "F0-AB-54",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "3C3178": {
        "oui_hex": "3C-31-78",
        "organization": "Qolsys Inc.",
        "address_1": "1900 The Alameda",
        "address_2": "San Jose  Ca  95126",
        "country": "US"
    },
    "08ECA9": {
        "oui_hex": "08-EC-A9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E04B45": {
        "oui_hex": "E0-4B-45",
        "organization": "Hi-P Electronics Pte Ltd",
        "address_1": "12 Ang Mo Kio Street 64",
        "address_2": "Singapore  Singapore  569088",
        "country": "SG"
    },
    "F46A92": {
        "oui_hex": "F4-6A-92",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F0D657": {
        "oui_hex": "F0-D6-57",
        "organization": "ECHOSENS",
        "address_1": "30 Place d'Italie",
        "address_2": "PARIS 13  Ile de France  75013",
        "country": "FR"
    },
    "9C37F4": {
        "oui_hex": "9C-37-F4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3C4711": {
        "oui_hex": "3C-47-11",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5CEB68": {
        "oui_hex": "5C-EB-68",
        "organization": "Cheerstar Technology Co., Ltd",
        "address_1": "5th Floor,Hongye Industrial Park,",
        "address_2": "ShenZhen  GuangDong  518006",
        "country": "CN"
    },
    "AC562C": {
        "oui_hex": "AC-56-2C",
        "organization": "LAVA INTERNATIONAL(H.K) LIMITED",
        "address_1": "UNIT L 1/F MAU LAM COMM BLDG 16-18",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "FC9AFA": {
        "oui_hex": "FC-9A-FA",
        "organization": "Motus Global Inc.",
        "address_1": "5394 Merrick Road",
        "address_2": "Massapequa  NY  11758",
        "country": "US"
    },
    "14157C": {
        "oui_hex": "14-15-7C",
        "organization": "TOKYO COSMOS ELECTRIC CO.,LTD.",
        "address_1": "2-268 Sobudai",
        "address_2": "Zama  Kanagawa  252-8550",
        "country": "JP"
    },
    "20E407": {
        "oui_hex": "20-E4-07",
        "organization": "Spark srl",
        "address_1": "Via A. Gramsci 86/A",
        "address_2": "Reggio Emilia    42124",
        "country": "IT"
    },
    "D09DAB": {
        "oui_hex": "D0-9D-AB",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "887384": {
        "oui_hex": "88-73-84",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "24693E": {
        "oui_hex": "24-69-3E",
        "organization": "innodisk Corporation",
        "address_1": "5F., No. 237, Sec. 1, Datong Rd., Xizhi Dist.",
        "address_2": "New Taipei City  Taiwan  221",
        "country": "TW"
    },
    "C0DC6A": {
        "oui_hex": "C0-DC-6A",
        "organization": "Qingdao Eastsoft Communication Technology Co.,LTD",
        "address_1": "Shandong QINGDAO, No. 16A, Shangqing Road, Shibei District",
        "address_2": "QINGDAO  Shandong  266023",
        "country": "CN"
    },
    "24B0A9": {
        "oui_hex": "24-B0-A9",
        "organization": "Shanghai Mobiletek Communication Ltd.",
        "address_1": "RM201, Building 9, No 99 Tianzhou RD, Shanghai China",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "1CC586": {
        "oui_hex": "1C-C5-86",
        "organization": "Absolute Acoustics",
        "address_1": "Av. Corifeu de Azevedo Marques, 1703",
        "address_2": "  Sao Paulo  05581-001",
        "country": "BR"
    },
    "407FE0": {
        "oui_hex": "40-7F-E0",
        "organization": "Glory Star Technics (ShenZhen) Limited",
        "address_1": "4/f, West Block, Xi Li Village, Xin Wu Industry Bldg., Nan Shan District, ShenZhen, China",
        "address_2": "Shenzhen  China",
        "country": "CN"
    },
    "C8E130": {
        "oui_hex": "C8-E1-30",
        "organization": "Milkyway Group Ltd",
        "address_1": "RM 405 Tung Ming Building",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "486EFB": {
        "oui_hex": "48-6E-FB",
        "organization": "Davit System Technology Co., Ltd.",
        "address_1": "#304 Hanlim Human Tower, LS-Ro 172",
        "address_2": "Gunpo-si  Gyeonggi-Do  435-824",
        "country": "KR"
    },
    "B0966C": {
        "oui_hex": "B0-96-6C",
        "organization": "Lanbowan Technology Ltd.",
        "address_1": "No. 60 Langbao Xi Road",
        "address_2": "Foshan  Guangdong  528051",
        "country": "CN"
    },
    "1CF03E": {
        "oui_hex": "1C-F0-3E",
        "organization": "Wearhaus Inc.",
        "address_1": "2041 Bancroft Way",
        "address_2": "Berkeley  CA  94704",
        "country": "US"
    },
    "C43ABE": {
        "oui_hex": "C4-3A-BE",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "883B8B": {
        "oui_hex": "88-3B-8B",
        "organization": "Cheering Connection Co. Ltd.",
        "address_1": "Room 602, Shenzhen Software Park T2-B",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E4F939": {
        "oui_hex": "E4-F9-39",
        "organization": "Minxon Hotel Technology INC.",
        "address_1": "3F, No.37, Dongxing Rd., Xinyi Dist.",
        "address_2": "Taipei  Taiwan  11070",
        "country": "TW"
    },
    "146B72": {
        "oui_hex": "14-6B-72",
        "organization": "Shenzhen Fortune Ship Technology Co., Ltd.",
        "address_1": "Room 701-716, 7th Floor,",
        "address_2": "Nanshan District, Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B8F080": {
        "oui_hex": "B8-F0-80",
        "organization": "SPS, INC.",
        "address_1": "70, Techno8-ro",
        "address_2": "Yuseong-gu  Daejeon  305-500",
        "country": "KR"
    },
    "805067": {
        "oui_hex": "80-50-67",
        "organization": "W & D TECHNOLOGY CORPORATION",
        "address_1": "1F., NO.22, GONGYEQU 31TH RD",
        "address_2": "TAICHUNG CITY  TAIWAN  40768",
        "country": "TW"
    },
    "78F944": {
        "oui_hex": "78-F9-44",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "247656": {
        "oui_hex": "24-76-56",
        "organization": "Shanghai Net Miles Fiber Optics Technology Co., LTD.",
        "address_1": "Flat F, 17th Floor, Southern International Mansion",
        "address_2": "Shanghai  Shanghai  201401",
        "country": "CN"
    },
    "F8CFC5": {
        "oui_hex": "F8-CF-C5",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "A47B85": {
        "oui_hex": "A4-7B-85",
        "organization": "ULTIMEDIA Co Ltd,",
        "address_1": "Guro-Gu Saeaml-ro 102",
        "address_2": "Seoul    152770",
        "country": "KR"
    },
    "5C5B35": {
        "oui_hex": "5C-5B-35",
        "organization": "Mist Systems, Inc.",
        "address_1": "1601 South De Anza Blvd, Suite 248",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "ECBAFE": {
        "oui_hex": "EC-BA-FE",
        "organization": "GIROPTIC",
        "address_1": "165 avenue de Bretagne",
        "address_2": "Lille  Nord  59000",
        "country": "FR"
    },
    "3C2C94": {
        "oui_hex": "3C-2C-94",
        "organization": "杭州德澜科技有限公司（HangZhou Delan Technology Co.,Ltd）",
        "address_1": "tianmushan road no.398,Xihu District, hangzhou city, zhejiang province, China",
        "address_2": "Hangzhou  ZheJiang  310013",
        "country": "CN"
    },
    "241B44": {
        "oui_hex": "24-1B-44",
        "organization": "Hangzhou Tuners Electronics Co., Ltd",
        "address_1": "5/F,Building No.1,No.619",
        "address_2": "BinJiang District, Hangzhou  ZheJiang  310053",
        "country": "CN"
    },
    "80A85D": {
        "oui_hex": "80-A8-5D",
        "organization": "Osterhout Design Group",
        "address_1": "153 Townsend Suite 570",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "ACCAAB": {
        "oui_hex": "AC-CA-AB",
        "organization": "Virtual Electric Inc",
        "address_1": "1314 Vanna Ct",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "485415": {
        "oui_hex": "48-54-15",
        "organization": "NET RULES TECNOLOGIA EIRELI",
        "address_1": "Rua Madre Cabrini, 240 - 7°andar",
        "address_2": "São Paulo  São Paulo  04020000",
        "country": "BR"
    },
    "7840E4": {
        "oui_hex": "78-40-E4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E09971": {
        "oui_hex": "E0-99-71",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "70DA9C": {
        "oui_hex": "70-DA-9C",
        "organization": "TECSEN",
        "address_1": "$401, Jeongsu Bd, 94-70,",
        "address_2": "SEOUL  NA  150-037",
        "country": "KR"
    },
    "2CA2B4": {
        "oui_hex": "2C-A2-B4",
        "organization": "Fortify Technologies, LLC",
        "address_1": "6200 Shingle Creek Pkwy, Suite 400",
        "address_2": "Minneapolis  Minnesota  55430",
        "country": "US"
    },
    "10D38A": {
        "oui_hex": "10-D3-8A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E48501": {
        "oui_hex": "E4-85-01",
        "organization": "Geberit International AG",
        "address_1": "Schachenstrasse 77",
        "address_2": "Jona  SG  8645",
        "country": "CH"
    },
    "206274": {
        "oui_hex": "20-62-74",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "E8162B": {
        "oui_hex": "E8-16-2B",
        "organization": "IDEO Security Co., Ltd.",
        "address_1": "1404, Seoul Forest IT Valley, 77, Seongsuil-ro",
        "address_2": "Seongdong-gu,  SEOUL  133-822",
        "country": "KR"
    },
    "B47356": {
        "oui_hex": "B4-73-56",
        "organization": "Hangzhou Treebear Networking Co., Ltd.",
        "address_1": "2F,Block A, Lianhe Building, 2#, Zijinghua RD, Xihu District",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "346895": {
        "oui_hex": "34-68-95",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "847303": {
        "oui_hex": "84-73-03",
        "organization": "Letv Mobile and Intelligent Information Technology (Beijing) Corporation Ltd.",
        "address_1": "5th floor,Hongchengxintai building,No.105,Yaojiayuan Road,Chaoyang District,Beijing",
        "address_2": "Beijing  Chaoyang  100025",
        "country": "CN"
    },
    "3CC2E1": {
        "oui_hex": "3C-C2-E1",
        "organization": "XINHUA CONTROL ENGINEERING CO.,LTD",
        "address_1": "160 Wenjing Road, Minhang",
        "address_2": "Shanghai  Shanghai  200245",
        "country": "CN"
    },
    "8C873B": {
        "oui_hex": "8C-87-3B",
        "organization": "Leica Camera AG",
        "address_1": "Am Leitz-Park 5",
        "address_2": "Wetzlar  Hessen  35578",
        "country": "DE"
    },
    "44F477": {
        "oui_hex": "44-F4-77",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "142971": {
        "oui_hex": "14-29-71",
        "organization": "NEMOA ELECTRONICS (HK) CO. LTD",
        "address_1": "ROOM 610, MINGYOU PURCHASING & DISPLAYING CENTER,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "78E980": {
        "oui_hex": "78-E9-80",
        "organization": "RainUs Co.,Ltd",
        "address_1": "E-703, Digital Empire, 16, Deogyeong-daero",
        "address_2": "Suwon-si  Gyeonggi-do  443-702",
        "country": "KR"
    },
    "E0FFF7": {
        "oui_hex": "E0-FF-F7",
        "organization": "Softiron Inc.",
        "address_1": "6540 Central Avenue",
        "address_2": "Newark  California  94560",
        "country": "US"
    },
    "3C6A9D": {
        "oui_hex": "3C-6A-9D",
        "organization": "Dexatek Technology LTD.",
        "address_1": "15F, NO.81, Sec.1, Xizhi Dist.,",
        "address_2": "New Taipei City    221",
        "country": "TW"
    },
    "349E34": {
        "oui_hex": "34-9E-34",
        "organization": "Evervictory Electronic Co.Ltd",
        "address_1": "Chu-Chi management district Humen Town, DongGuan GuangDong Province, China",
        "address_2": "DongGuan  GuangDong  523000",
        "country": "CN"
    },
    "700FC7": {
        "oui_hex": "70-0F-C7",
        "organization": "SHENZHEN IKINLOOP TECHNOLOGY CO.,LTD.",
        "address_1": "Room 8B,Building C, Tongfang Information Port, Langshan Road, Science",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "BC74D7": {
        "oui_hex": "BC-74-D7",
        "organization": "HangZhou JuRu Technology CO.,LTD",
        "address_1": "No.803 Room,Shuyu Building,No.98 Wenyi West Road,Hangzhou,Zhejiang,China",
        "address_2": "hangzhou  zhejiang  310053",
        "country": "CN"
    },
    "78EB14": {
        "oui_hex": "78-EB-14",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "3C4937": {
        "oui_hex": "3C-49-37",
        "organization": "ASSMANN Electronic GmbH",
        "address_1": "Auf dem Schueffel 3",
        "address_2": "Luedenscheid  Germany  58513",
        "country": "DE"
    },
    "844464": {
        "oui_hex": "84-44-64",
        "organization": "ServerU Inc",
        "address_1": "8100 NW 64th Street",
        "address_2": "Miami  FL  33166",
        "country": "US"
    },
    "003560": {
        "oui_hex": "00-35-60",
        "organization": "Rosen Aviation",
        "address_1": "1020 Owen Loop South",
        "address_2": "Eugene  Oregon  97402",
        "country": "US"
    },
    "F8BC41": {
        "oui_hex": "F8-BC-41",
        "organization": "Rosslare Enterprises Limited",
        "address_1": "Flat 912 Wing Fat Industrial Building",
        "address_2": "Kowloon Bay  Kowloon",
        "country": "HK"
    },
    "3CB792": {
        "oui_hex": "3C-B7-92",
        "organization": "Hitachi Maxell, Ltd., Optronics Division",
        "address_1": "5030 Totsuka-cho, Totsuka-ku",
        "address_2": "Yokohama  Kanagawa  244-0003",
        "country": "JP"
    },
    "F8B2F3": {
        "oui_hex": "F8-B2-F3",
        "organization": "GUANGZHOU BOSMA TECHNOLOGY CO.,LTD",
        "address_1": "FL.3,A5,No.11 Kaiyuan Ave., Scienc City,Guangzhou,CHINA",
        "address_2": "Guangzhou  GuangDong  510530",
        "country": "CN"
    },
    "28D98A": {
        "oui_hex": "28-D9-8A",
        "organization": "Hangzhou Konke Technology Co.,Ltd.",
        "address_1": "Hangzhou cuibai road 7, ROOM 422",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "D89341": {
        "oui_hex": "D8-93-41",
        "organization": "General Electric Global Research",
        "address_1": "2623 Camino Ramon",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "1C9ECB": {
        "oui_hex": "1C-9E-CB",
        "organization": "Beijing Nari Smartchip Microelectronics Company Limited",
        "address_1": "Northern Territory Xixiaokou Rd,Haidian district,Beijing 100192,China",
        "address_2": "beijing  beijing  100192",
        "country": "CN"
    },
    "D48DD9": {
        "oui_hex": "D4-8D-D9",
        "organization": "Meld Technology, Inc",
        "address_1": "725 San Aleso Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "DCC622": {
        "oui_hex": "DC-C6-22",
        "organization": "BUHEUNG SYSTEM",
        "address_1": "302, 45, Jeonpa-ro, 24 Beongil",
        "address_2": "Anyang-si  Gyeonggi-do  430-857",
        "country": "KR"
    },
    "902CC7": {
        "oui_hex": "90-2C-C7",
        "organization": "C-MAX Asia Limited",
        "address_1": "Unit 117, 1/F, Liven House",
        "address_2": "Kwun Tong  Kowloon  852",
        "country": "HK"
    },
    "8870EF": {
        "oui_hex": "88-70-EF",
        "organization": "SC Professional Trading Co., Ltd.",
        "address_1": "2 Soi Krungthepkreetar 21",
        "address_2": "Sapansoong  Bangkok  10250",
        "country": "TH"
    },
    "94C038": {
        "oui_hex": "94-C0-38",
        "organization": "Tallac Networks",
        "address_1": "6528 Lonetree Blvd.",
        "address_2": "Rocklin  CA  95765",
        "country": "US"
    },
    "6836B5": {
        "oui_hex": "68-36-B5",
        "organization": "DriveScale, Inc.",
        "address_1": "530 Lakeside Dr. #190",
        "address_2": "Sunnyvale  CALIFORNIA  94085",
        "country": "US"
    },
    "C40880": {
        "oui_hex": "C4-08-80",
        "organization": "Shenzhen UTEPO Tech Co., Ltd.",
        "address_1": "5/F Western Block, M-8 Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D88039": {
        "oui_hex": "D8-80-39",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "5C966A": {
        "oui_hex": "5C-96-6A",
        "organization": "RTNET",
        "address_1": "827-64, Yeoksam-dong, Kangnam-Gu",
        "address_2": "Seoul  -  135-080",
        "country": "KR"
    },
    "BCBC46": {
        "oui_hex": "BC-BC-46",
        "organization": "SKS Welding Systems GmbH",
        "address_1": "Marie-Curie-Str. 14",
        "address_2": "Kaiserslautern  Rheinlandpfalz  67661",
        "country": "DE"
    },
    "9816EC": {
        "oui_hex": "98-16-EC",
        "organization": "IC Intracom",
        "address_1": "550 Commerce Blvd",
        "address_2": "Oldsmar  Florida  34677",
        "country": "US"
    },
    "D062A0": {
        "oui_hex": "D0-62-A0",
        "organization": "China Essence Technology (Zhumadian) Co., Ltd.",
        "address_1": "4th Floor, Administrative Service Center Office of Yicheng District",
        "address_2": "Zhumadian  Henan Province  463000",
        "country": "CN"
    },
    "90179B": {
        "oui_hex": "90-17-9B",
        "organization": "Nanomegas",
        "address_1": "BD Ed.Machtens 79/22",
        "address_2": "BXL  Molenbeek  1080",
        "country": "BE"
    },
    "14F893": {
        "oui_hex": "14-F8-93",
        "organization": "Wuhan FiberHome Digital Technology Co.,Ltd.",
        "address_1": "No.88 YouKeyuan Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "582136": {
        "oui_hex": "58-21-36",
        "organization": "KMB systems, s.r.o.",
        "address_1": "Dr. M. Horakove 559",
        "address_2": "Liberec  Czech Republic  46006",
        "country": "CZ"
    },
    "800902": {
        "oui_hex": "80-09-02",
        "organization": "Keysight Technologies, Inc.",
        "address_1": "1400 Fountaingrove Pkwy.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "0499E6": {
        "oui_hex": "04-99-E6",
        "organization": "Shenzhen Yoostar Technology Co., Ltd",
        "address_1": "#503，Tower D, HUA HAN Innovation Park,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "70FF5C": {
        "oui_hex": "70-FF-5C",
        "organization": "Cheerzing Communication(Xiamen)Technology Co.,Ltd",
        "address_1": "Room N514,North Torch Building,5 Torch Road",
        "address_2": "Xiamen  Fujian  361005",
        "country": "CN"
    },
    "4C48DA": {
        "oui_hex": "4C-48-DA",
        "organization": "Beijing Autelan Technology Co.,Ltd",
        "address_1": "1-4F, 3rd Area, 9#Building Zhongguancun Software Park",
        "address_2": "  Beijing  100193",
        "country": "CN"
    },
    "205CFA": {
        "oui_hex": "20-5C-FA",
        "organization": "Yangzhou ChangLian Network Technology Co,ltd.",
        "address_1": "No.60, Shangfang Temple Road",
        "address_2": "Yangzhou City  Jiangsu  225000",
        "country": "CN"
    },
    "84930C": {
        "oui_hex": "84-93-0C",
        "organization": "InCoax Networks Europe AB",
        "address_1": "Strommavagen 2",
        "address_2": "Gavle  Sweden  80309",
        "country": "SE"
    },
    "1CA2B1": {
        "oui_hex": "1C-A2-B1",
        "organization": "ruwido austria gmbh",
        "address_1": "Koestendorferstrasse 8",
        "address_2": "Neumarkt a.W.  Salzburg  5202",
        "country": "AT"
    },
    "384B76": {
        "oui_hex": "38-4B-76",
        "organization": "AIRTAME ApS",
        "address_1": "Vestergade 20C",
        "address_2": "Copenhagen C  Copenhagen  1456",
        "country": "DK"
    },
    "38B1DB": {
        "oui_hex": "38-B1-DB",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "34F6D2": {
        "oui_hex": "34-F6-D2",
        "organization": "Panasonic Taiwan Co.,Ltd.",
        "address_1": "579,Yuan Shan Road",
        "address_2": "New Taipei  Taiwan  235",
        "country": ""
    },
    "307512": {
        "oui_hex": "30-75-12",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "64002D": {
        "oui_hex": "64-00-2D",
        "organization": "Powerlinq Co., LTD",
        "address_1": "13 PingDong Road 4 ,",
        "address_2": "Zhuhai  GD   519060",
        "country": ""
    },
    "B47C29": {
        "oui_hex": "B4-7C-29",
        "organization": "Shenzhen Guzidi Technology Co.,Ltd",
        "address_1": "South 6/F,Yingtang Building,No.5 Kejiyuan Road,Nanshan District,Shenzhen City,Guangdong Province,P.R. China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "D48F33": {
        "oui_hex": "D4-8F-33",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "54F876": {
        "oui_hex": "54-F8-76",
        "organization": "ABB AG",
        "address_1": "Trafoweg 4",
        "address_2": "Halle / Saale  Saxony-Anhalt  06112",
        "country": "DE"
    },
    "34B7FD": {
        "oui_hex": "34-B7-FD",
        "organization": "Guangzhou Younghead Electronic Technology Co.,Ltd",
        "address_1": "Room 206,Wenzhenxin Building,Block 3, No.2 Kefa RD,Hi-Tech Park, Nanshan District, Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "B41780": {
        "oui_hex": "B4-17-80",
        "organization": "DTI Group Ltd",
        "address_1": "50 Affleck Rd",
        "address_2": "Perth Airport  Western Australia  6105",
        "country": "AU"
    },
    "489D18": {
        "oui_hex": "48-9D-18",
        "organization": "Flashbay Limited",
        "address_1": "6 The Fountain Centre",
        "address_2": "London  London  SW6 2TW",
        "country": "GB"
    },
    "90203A": {
        "oui_hex": "90-20-3A",
        "organization": "BYD Precision Manufacture Co.,Ltd",
        "address_1": "Building 23#，NO.3009 BYD Road，Pingshan",
        "address_2": "Shenzhen  Guangdong  518118",
        "country": "CN"
    },
    "80EACA": {
        "oui_hex": "80-EA-CA",
        "organization": "Dialog Semiconductor Hellas SA",
        "address_1": "Leoforos Syggrou 143",
        "address_2": "Athens  Attiki  17121",
        "country": "GR"
    },
    "20A99B": {
        "oui_hex": "20-A9-9B",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "604826": {
        "oui_hex": "60-48-26",
        "organization": "Newbridge Technologies Int. Ltd.",
        "address_1": "35/F Central Plaza",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "38F33F": {
        "oui_hex": "38-F3-3F",
        "organization": "TATSUNO CORPORATION",
        "address_1": "2-6,Mita 3-Chome,Minato-ku",
        "address_2": "  Tokyo  108-8520",
        "country": "JP"
    },
    "D80CCF": {
        "oui_hex": "D8-0C-CF",
        "organization": "C.G.V. S.A.S.",
        "address_1": "18, RUE THEODORE MONOD",
        "address_2": "OSTWALD CEDEX  BAS-RHIN  67541",
        "country": "FR"
    },
    "4CBB58": {
        "oui_hex": "4C-BB-58",
        "organization": "Chicony Electronics Co., Ltd.",
        "address_1": "No.25, Wugong 6th Rd., Wugu Dist.,",
        "address_2": "New Taipei City 248,  TAIWAN, REPUBLIC OF CHINA  248",
        "country": "TW"
    },
    "A41242": {
        "oui_hex": "A4-12-42",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "D00AAB": {
        "oui_hex": "D0-0A-AB",
        "organization": "Yokogawa Digital Computer Corporation",
        "address_1": "Shinjuku MIDWEST Bldg.4-30-3",
        "address_2": "Yoyogi  Shibuya-ku, Tokyo  151-0053",
        "country": "JP"
    },
    "C40006": {
        "oui_hex": "C4-00-06",
        "organization": "Lipi Data Systems Ltd.",
        "address_1": "Mewar Industrial Area (M.I.A)",
        "address_2": "UDAIPUR  RAJASTHAN  313003",
        "country": "IN"
    },
    "38262B": {
        "oui_hex": "38-26-2B",
        "organization": "UTran Technology",
        "address_1": "No.130, Guoji Rd., Tucheng Dist.,",
        "address_2": "New Taipei City    23650",
        "country": "TW"
    },
    "480C49": {
        "oui_hex": "48-0C-49",
        "organization": "NAKAYO Inc",
        "address_1": "Development Support Center 165 Higashiomuro-machi",
        "address_2": "Maebashi-shi  Gunma  379-2105",
        "country": "JP"
    },
    "3CD9CE": {
        "oui_hex": "3C-D9-CE",
        "organization": "Eclipse WiFi",
        "address_1": "68 S Service Rd",
        "address_2": "Melville  NY  11747",
        "country": "US"
    },
    "6077E2": {
        "oui_hex": "60-77-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FC1910": {
        "oui_hex": "FC-19-10",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FC790B": {
        "oui_hex": "FC-79-0B",
        "organization": "Hitachi High Technologies America, Inc.",
        "address_1": "208 Fairforest Way",
        "address_2": "Greenville  SC  29607",
        "country": "US"
    },
    "6081F9": {
        "oui_hex": "60-81-F9",
        "organization": "Helium Systems, Inc",
        "address_1": "717 Market Street",
        "address_2": "San Francisco  CA  94102",
        "country": "US"
    },
    "8401A7": {
        "oui_hex": "84-01-A7",
        "organization": "Greyware Automation Products, Inc",
        "address_1": "308 Oriole Ct",
        "address_2": "Murphy  TX  75094",
        "country": "US"
    },
    "98F170": {
        "oui_hex": "98-F1-70",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "686E48": {
        "oui_hex": "68-6E-48",
        "organization": "Prophet Electronic Technology Corp.,Ltd",
        "address_1": "9F ,3 Building,No 1535,Hongmei Road ,Xuhui District",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "04C991": {
        "oui_hex": "04-C9-91",
        "organization": "Phistek INC.",
        "address_1": "5 Floor, No.188, Section 3, Datong Road",
        "address_2": "New Taipei City    221",
        "country": "TW"
    },
    "3CA10D": {
        "oui_hex": "3C-A1-0D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "646CB2": {
        "oui_hex": "64-6C-B2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "680571": {
        "oui_hex": "68-05-71",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "14B484": {
        "oui_hex": "14-B4-84",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F4C447": {
        "oui_hex": "F4-C4-47",
        "organization": "Coagent International Enterprise Limited",
        "address_1": "FLAT/RM 2 6F CROWN TND BLDG 106 HOW MING ST KWUN TONG",
        "address_2": "Hong Kong  Hong Kong  528133",
        "country": "CN"
    },
    "C8E42F": {
        "oui_hex": "C8-E4-2F",
        "organization": "Technical Research Design and Development",
        "address_1": "186 Lincoln street",
        "address_2": "Boston  MA  02111",
        "country": "US"
    },
    "C4C9EC": {
        "oui_hex": "C4-C9-EC",
        "organization": "Gugaoo   HK Limited",
        "address_1": "Unit 04, 7/F BRIGHT WAY TOWER",
        "address_2": "Kowloon, Hongkong",
        "country": "HK"
    },
    "34E42A": {
        "oui_hex": "34-E4-2A",
        "organization": "Automatic Bar Controls Inc.",
        "address_1": "790 Eubanks Dr",
        "address_2": "Vacaville  CA  95688",
        "country": "US"
    },
    "3059B7": {
        "oui_hex": "30-59-B7",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "20A787": {
        "oui_hex": "20-A7-87",
        "organization": "Bointec Taiwan Corporation Limited",
        "address_1": "1F, A20, L790, SEC.5,",
        "address_2": "TAIPEI  TAIWAN  11082",
        "country": "TW"
    },
    "A0FC6E": {
        "oui_hex": "A0-FC-6E",
        "organization": "Telegrafia a.s.",
        "address_1": "Lomena 7",
        "address_2": "Kosice  Slovakia  040 01",
        "country": ""
    },
    "2053CA": {
        "oui_hex": "20-53-CA",
        "organization": "Risk Technology Ltd",
        "address_1": "Matrix House, Merlin Court",
        "address_2": "Altrincham  Cheshire  WA14 5NL",
        "country": "GB"
    },
    "A43D78": {
        "oui_hex": "A4-3D-78",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "04572F": {
        "oui_hex": "04-57-2F",
        "organization": "Sertel Electronics UK Ltd",
        "address_1": "Rutland House, 148 Edmund Street,",
        "address_2": "Birmingham    B3 2FD",
        "country": "GB"
    },
    "D8977C": {
        "oui_hex": "D8-97-7C",
        "organization": "Grey Innovation",
        "address_1": "255 Mary St",
        "address_2": "Richmond  Victoria  3121",
        "country": "AU"
    },
    "BC8D0E": {
        "oui_hex": "BC-8D-0E",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "A49F85": {
        "oui_hex": "A4-9F-85",
        "organization": "Lyve Minds, Inc",
        "address_1": "10001 N. De Anza Blvd, Ste 300",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78923E": {
        "oui_hex": "78-92-3E",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "ACA9A0": {
        "oui_hex": "AC-A9-A0",
        "organization": "Audioengine, Ltd.",
        "address_1": "1535 Dido Mt Salem Rd",
        "address_2": "Ackerman  Ms  39735",
        "country": "US"
    },
    "A481EE": {
        "oui_hex": "A4-81-EE",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "78D66F": {
        "oui_hex": "78-D6-6F",
        "organization": "Aristocrat Technologies Australia Pty. Ltd.",
        "address_1": "Building A, Pinnacle Office Park",
        "address_2": "North Ryde  N.S.W.  2113",
        "country": "AU"
    },
    "441E91": {
        "oui_hex": "44-1E-91",
        "organization": "ARVIDA Intelligent Electronics Technology  Co.,Ltd.",
        "address_1": "No.3 Qiliang Road.,",
        "address_2": "Danyang  Jiangsu  212300",
        "country": "CN"
    },
    "C4626B": {
        "oui_hex": "C4-62-6B",
        "organization": "ZPT Vigantice",
        "address_1": "Vigantice 266",
        "address_2": "Roznov pod Radhostem    75661",
        "country": "CZ"
    },
    "EC1766": {
        "oui_hex": "EC-17-66",
        "organization": "Research Centre Module",
        "address_1": "3 Eight March 4Th Street",
        "address_2": "Moscow  Moscow  125190",
        "country": "RU"
    },
    "A0D12A": {
        "oui_hex": "A0-D1-2A",
        "organization": "AXPRO Technology Inc.",
        "address_1": "8F, No.128, sec. 4 Chung Hsiao E. RD.,",
        "address_2": "Taipei city    10866",
        "country": "TW"
    },
    "209AE9": {
        "oui_hex": "20-9A-E9",
        "organization": "Volacomm Co., Ltd",
        "address_1": "15F-6., No.7, Sec.3, New Taipei Blvd., Xinzhuang Dist., New Taipei City 242., Taiwan (R.O.C)",
        "address_2": "Xinzhuang Dist.  New Taipei City  242",
        "country": "TW"
    },
    "345D10": {
        "oui_hex": "34-5D-10",
        "organization": "Wytek",
        "address_1": "10 rue jean jaures",
        "address_2": "Poitiers    86000",
        "country": "FR"
    },
    "6C14F7": {
        "oui_hex": "6C-14-F7",
        "organization": "Erhardt+Leimer GmbH",
        "address_1": "Albert-Leimer-Platz 1",
        "address_2": "Stadtbergen    86391",
        "country": "DE"
    },
    "B0D59D": {
        "oui_hex": "B0-D5-9D",
        "organization": "Shenzhen Zowee Technology Co., Ltd",
        "address_1": "Block 5   （ZOWEE Technology Building),",
        "address_2": "Pingshan, Xili Town, Nanshan District  Shenzhen, Guangdong  518055",
        "country": "CN"
    },
    "6828BA": {
        "oui_hex": "68-28-BA",
        "organization": "Dejai",
        "address_1": "PO Box 101",
        "address_2": "Toorak  Vic  3142",
        "country": "AU"
    },
    "B05706": {
        "oui_hex": "B0-57-06",
        "organization": "Vallox Oy",
        "address_1": "Myllykylantie 9-11",
        "address_2": "Loimaa    32200",
        "country": "FI"
    },
    "48EE07": {
        "oui_hex": "48-EE-07",
        "organization": "Silver Palm Technologies LLC",
        "address_1": "9639 DOCTOR PERRY RD STE 123N",
        "address_2": "IJAMSVILLE  Maryland  21754",
        "country": "US"
    },
    "50C7BF": {
        "oui_hex": "50-C7-BF",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "205A00": {
        "oui_hex": "20-5A-00",
        "organization": "Coval",
        "address_1": "ZA Les Petits Champs",
        "address_2": "MONTELIER  Drome  26120",
        "country": "FR"
    },
    "A8A668": {
        "oui_hex": "A8-A6-68",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00EEBD": {
        "oui_hex": "00-EE-BD",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "38F708": {
        "oui_hex": "38-F7-08",
        "organization": "National Resource Management, Inc.",
        "address_1": "480 Neponset St.  Bldg. #2",
        "address_2": "Canton  MA  02021",
        "country": "US"
    },
    "E0DB88": {
        "oui_hex": "E0-DB-88",
        "organization": "Open Standard Digital-IF Interface for SATCOM Systems",
        "address_1": "3090 Raritan Ave",
        "address_2": "Aberdeen Proving Ground  MD  21001",
        "country": "US"
    },
    "A8BD3A": {
        "oui_hex": "A8-BD-3A",
        "organization": "UNIONMAN TECHNOLOGY CO.,LTD",
        "address_1": "18F, HUAYANG TOWER,YANDAYI ROAD",
        "address_2": "Huizhou  Guangdong  516007",
        "country": "CN"
    },
    "A824EB": {
        "oui_hex": "A8-24-EB",
        "organization": "ZAO NPO Introtest",
        "address_1": "Studencheskaya st. 55",
        "address_2": "Ekaterinburg  Sverdlovsk region  620078",
        "country": "RU"
    },
    "C40E45": {
        "oui_hex": "C4-0E-45",
        "organization": "ACK Networks,Inc.",
        "address_1": "Floor3,Building B.,No.1 ShangDi XinXi Rd.",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "3C89A6": {
        "oui_hex": "3C-89-A6",
        "organization": "KAPELSE",
        "address_1": "5 Allee De Saint-Cloud",
        "address_2": "54600 Villers Les Nancy",
        "country": "FR"
    },
    "A46CC1": {
        "oui_hex": "A4-6C-C1",
        "organization": "LTi REEnergy GmbH",
        "address_1": "Heinrich-Hertz-Straße 18",
        "address_2": "Unna  North Rhine-Westfalia  59423",
        "country": "DE"
    },
    "A8B9B3": {
        "oui_hex": "A8-B9-B3",
        "organization": "ESSYS",
        "address_1": "Daerung Post Tower 5 15F",
        "address_2": "Seoul  Gasan-Dong, Geumchen-gu  153-702",
        "country": "KR"
    },
    "6C09D6": {
        "oui_hex": "6C-09-D6",
        "organization": "Digiquest Electronics LTD",
        "address_1": "26 Park House",
        "address_2": "London    NW11 7PT",
        "country": "GB"
    },
    "481842": {
        "oui_hex": "48-18-42",
        "organization": "Shanghai Winaas Co. Equipment Co. Ltd.",
        "address_1": "8F Building A, WanDa Square",
        "address_2": "  Shanghai  200433",
        "country": "CN"
    },
    "447098": {
        "oui_hex": "44-70-98",
        "organization": "MING HONG TECHNOLOGY (SHEN ZHEN) LIMITED",
        "address_1": "Unit 906,South Block,Resources Tech Building,",
        "address_2": "Shenzhen  Guangdong province  518000",
        "country": "CN"
    },
    "9CBD9D": {
        "oui_hex": "9C-BD-9D",
        "organization": "SkyDisk, Inc.",
        "address_1": "2F Tenjin central place,",
        "address_2": "Fukuoka-shi  Fukuoka  810-0001",
        "country": "JP"
    },
    "74C621": {
        "oui_hex": "74-C6-21",
        "organization": "Zhejiang Hite Renewable Energy Co.,LTD",
        "address_1": "NO1320,2th Ring Road(South)",
        "address_2": "Tongxiang City  Zhejiang Province  314500",
        "country": "CN"
    },
    "D4319D": {
        "oui_hex": "D4-31-9D",
        "organization": "Sinwatec",
        "address_1": "76 Rikhard Zorge st.",
        "address_2": "Ufa  Bashkortostan  450075",
        "country": "RU"
    },
    "B068B6": {
        "oui_hex": "B0-68-B6",
        "organization": "Hangzhou OYE Technology Co. Ltd",
        "address_1": "Room 202 Building 12 Wenxinrenjia,",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "9C65F9": {
        "oui_hex": "9C-65-F9",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F-1, No. 207, Fusing Rd.",
        "address_2": "Taoyuan  Taiwan  33066",
        "country": "TW"
    },
    "487604": {
        "oui_hex": "48-76-04",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "2C534A": {
        "oui_hex": "2C-53-4A",
        "organization": "Shenzhen Winyao Electronic Limited",
        "address_1": "7B Block A Fuqiao Building Fuhua Road",
        "address_2": "Shen Zhen  Guangdong  518000",
        "country": "CN"
    },
    "A4BBAF": {
        "oui_hex": "A4-BB-AF",
        "organization": "Lime Instruments",
        "address_1": "1187 Brittmoore Road",
        "address_2": "Houston  TX  77043",
        "country": "US"
    },
    "F490CA": {
        "oui_hex": "F4-90-CA",
        "organization": "Tensorcom",
        "address_1": "5900 Pastuer Ct., Suite 105",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "E44C6C": {
        "oui_hex": "E4-4C-6C",
        "organization": "Shenzhen Guo Wei Electronic Co,. Ltd.",
        "address_1": "No 3038, Lo Sha Road, Liantang",
        "address_2": "Shenzhen  Guangdong  518004",
        "country": "CN"
    },
    "A8574E": {
        "oui_hex": "A8-57-4E",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B843E4": {
        "oui_hex": "B8-43-E4",
        "organization": "Vlatacom",
        "address_1": "Milutina Milankovica 5",
        "address_2": "Belgrade  Serbia  11080",
        "country": "RS"
    },
    "282246": {
        "oui_hex": "28-22-46",
        "organization": "Beijing Sinoix Communication Co., LTD",
        "address_1": "Gehua Tower Room 603",
        "address_2": "  Beijing  100000",
        "country": "CN"
    },
    "48B977": {
        "oui_hex": "48-B9-77",
        "organization": "PulseOn Oy",
        "address_1": "Tekniikantie 12",
        "address_2": "ESPOO  Uusimaa  02150",
        "country": "FI"
    },
    "7071B3": {
        "oui_hex": "70-71-B3",
        "organization": "Brain Corporation",
        "address_1": "5665 Morehouse Dr.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "64E625": {
        "oui_hex": "64-E6-25",
        "organization": "Woxu Wireless Co., Ltd",
        "address_1": "B103 Building1 No.6 Changjianghoujie",
        "address_2": "Nanjing    210000",
        "country": "US"
    },
    "10B713": {
        "oui_hex": "10-B7-13",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "100E7E": {
        "oui_hex": "10-0E-7E",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "208986": {
        "oui_hex": "20-89-86",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "44C56F": {
        "oui_hex": "44-C5-6F",
        "organization": "NGN Easy Satfinder (Tianjin) Electronic Co., Ltd",
        "address_1": "A4, Sifang Hi-tech Building, Nankai Hi-tech Industry Area, Ya'an Road, Nankai District",
        "address_2": "  Tianjin  300113",
        "country": "US"
    },
    "B898F7": {
        "oui_hex": "B8-98-F7",
        "organization": "Gionee Communication Equipment Co,Ltd.ShenZhen",
        "address_1": "21/F Times Technology Building, 7028 Shennan Road,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "848336": {
        "oui_hex": "84-83-36",
        "organization": "Newrun",
        "address_1": "#803 IT Convergence Industry Bldg., Kyungpook National Univ.",
        "address_2": "Daegu  N/A  702-010",
        "country": "KR"
    },
    "182012": {
        "oui_hex": "18-20-12",
        "organization": "Aztech Associates Inc.",
        "address_1": "805 Bayridge Dr.",
        "address_2": "Kingston  Ontario  K7P1T5",
        "country": "CA"
    },
    "B8266C": {
        "oui_hex": "B8-26-6C",
        "organization": "ANOV France",
        "address_1": "Chemin de Baillot",
        "address_2": "Montauban  Tarn &amp; Garonne  82000",
        "country": "FR"
    },
    "3C300C": {
        "oui_hex": "3C-30-0C",
        "organization": "Dewar Electronics Pty Ltd",
        "address_1": "32 Taylors Road",
        "address_2": "Croydon  Victoria  3136",
        "country": "AU"
    },
    "98FFD0": {
        "oui_hex": "98-FF-D0",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "A875E2": {
        "oui_hex": "A8-75-E2",
        "organization": "Aventura Technologies, Inc.",
        "address_1": "48 Mall Drive",
        "address_2": "Commack  NY  11725",
        "country": "US"
    },
    "B87AC9": {
        "oui_hex": "B8-7A-C9",
        "organization": "Siemens Ltd.",
        "address_1": "885 Mountain Hwy",
        "address_2": "Bayswater  Victoria  3153",
        "country": "AU"
    },
    "F06130": {
        "oui_hex": "F0-61-30",
        "organization": "Advantage Pharmacy Services, LLC",
        "address_1": "PO Box 7",
        "address_2": "Madison  MO  39130-0007",
        "country": "US"
    },
    "6C3C53": {
        "oui_hex": "6C-3C-53",
        "organization": "SoundHawk Corp",
        "address_1": "20380 Town Center Lane",
        "address_2": "Cupertino  Ca  95014",
        "country": "US"
    },
    "084027": {
        "oui_hex": "08-40-27",
        "organization": "Gridstore Inc.",
        "address_1": "1975 Landings Dr.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "38BF2F": {
        "oui_hex": "38-BF-2F",
        "organization": "Espec Corp.",
        "address_1": "5-2-5 Kanokodai Minamimachi",
        "address_2": "Kobe City  Hyogo  561-1514",
        "country": "JP"
    },
    "44C4A9": {
        "oui_hex": "44-C4-A9",
        "organization": "Opticom Communication, LLC",
        "address_1": "1050 Connecticut Avenue, NW",
        "address_2": "Washington  DC  20036",
        "country": "US"
    },
    "C4824E": {
        "oui_hex": "C4-82-4E",
        "organization": "Changzhou Uchip Electronics Co., LTD.",
        "address_1": "Room1801~1802,",
        "address_2": "  Shanghai  201206",
        "country": "CN"
    },
    "A47760": {
        "oui_hex": "A4-77-60",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "C85663": {
        "oui_hex": "C8-56-63",
        "organization": "Sunflex Europe GmbH",
        "address_1": "Konrad-Zuse-Str. 13",
        "address_2": "Schwerte  NRW  58239",
        "country": "DE"
    },
    "88FED6": {
        "oui_hex": "88-FE-D6",
        "organization": "ShangHai WangYong Software Co., Ltd.",
        "address_1": "Shanghai Pudong Zhangjiang Hi-Tech Park,",
        "address_2": "Pudong Software Park 22301-283  ShangHai  201203",
        "country": "CN"
    },
    "7C72E4": {
        "oui_hex": "7C-72-E4",
        "organization": "Unikey Technologies",
        "address_1": "2250 Lee Rd",
        "address_2": "Winter Park  FL  32789",
        "country": "US"
    },
    "7C2048": {
        "oui_hex": "7C-20-48",
        "organization": "KoamTac",
        "address_1": "116 Village Boulevard",
        "address_2": "Princeton  New Jersey  08540",
        "country": "US"
    },
    "8CB7F7": {
        "oui_hex": "8C-B7-F7",
        "organization": "Shenzhen UniStrong Science & Technology Co., Ltd",
        "address_1": "17/F, Global Digital Bldg, Hi-tech Park",
        "address_2": "Shen zhen  Guang dong  518000",
        "country": "CN"
    },
    "38B74D": {
        "oui_hex": "38-B7-4D",
        "organization": "Fijowave Limited",
        "address_1": "Synergy Centre",
        "address_2": "    Dublin 24",
        "country": "IE"
    },
    "180C14": {
        "oui_hex": "18-0C-14",
        "organization": "iSonea Limited",
        "address_1": "125 South Tremont Street",
        "address_2": "Oceanside  CA  92054",
        "country": "US"
    },
    "9CA9E4": {
        "oui_hex": "9C-A9-E4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "90F3B7": {
        "oui_hex": "90-F3-B7",
        "organization": "Kirisun Communications Co., Ltd.",
        "address_1": "3-6Flrs, ROBETA Building, 1 QiMin Road, Songping Shan Area, Science & Industry Park, Nanshan District",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "US"
    },
    "C4E92F": {
        "oui_hex": "C4-E9-2F",
        "organization": "AB Sciex",
        "address_1": "71 Four Valley Drive",
        "address_2": "Concord  Ontario  L4K 4V8",
        "country": "US"
    },
    "A88D7B": {
        "oui_hex": "A8-8D-7B",
        "organization": "SunDroid Global limited.",
        "address_1": "Room 1305B, Fiyta Science Building,",
        "address_2": "Shenzhen  Guang Dong  518057",
        "country": "CN"
    },
    "3CF748": {
        "oui_hex": "3C-F7-48",
        "organization": "Shenzhen Linsn Technology Development Co.,Ltd",
        "address_1": "Floor 4,Block 7,Zone 2,Baiwangxin Industrial Park",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "B07908": {
        "oui_hex": "B0-79-08",
        "organization": "Cummings Engineering",
        "address_1": "145 S. 79th St., Ste. 26",
        "address_2": "Chandler  AZ  85226",
        "country": "US"
    },
    "E47723": {
        "oui_hex": "E4-77-23",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1C63B7": {
        "oui_hex": "1C-63-B7",
        "organization": "OpenProducts 237 AB",
        "address_1": "Barsebäcksvägen 27",
        "address_2": "Löddeköpinge    24630",
        "country": "SE"
    },
    "B4527E": {
        "oui_hex": "B4-52-7E",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "94B9B4": {
        "oui_hex": "94-B9-B4",
        "organization": "Aptos Technology",
        "address_1": "5F., No.65, Guangfu N. Rd., Zhongxing Vil.,",
        "address_2": "Hsinchu    303",
        "country": "TW"
    },
    "6C15F9": {
        "oui_hex": "6C-15-F9",
        "organization": "Nautronix Limited",
        "address_1": "Blackwood House",
        "address_2": "Aberdeen    AB10 6XU",
        "country": "GB"
    },
    "18AA45": {
        "oui_hex": "18-AA-45",
        "organization": "Fon Technology",
        "address_1": "C/Quintanavides, 15 Edificio 2 Planta 1",
        "address_2": "",
        "country": "ES"
    },
    "902083": {
        "oui_hex": "90-20-83",
        "organization": "General Engine Management Systems Ltd.",
        "address_1": "GEMS",
        "address_2": "Egham  Surrey  TW208RN",
        "country": "GB"
    },
    "14B126": {
        "oui_hex": "14-B1-26",
        "organization": "Industrial Software Co",
        "address_1": "85, Aleksandyr Malinov Blvd. Office 6",
        "address_2": "Sofia    1715",
        "country": "BG"
    },
    "D850E6": {
        "oui_hex": "D8-50-E6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "DC3EF8": {
        "oui_hex": "DC-3E-F8",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "A49F89": {
        "oui_hex": "A4-9F-89",
        "organization": "Shanghai Rui Rui Communication Technology Co.Ltd.",
        "address_1": "Room 1130,Building No.1",
        "address_2": "  ShangHai  201199",
        "country": "CN"
    },
    "7060DE": {
        "oui_hex": "70-60-DE",
        "organization": "LaVision GmbH",
        "address_1": "Anna-Vandenhoeck-Ring 19",
        "address_2": "Goettingen  Niedersachsen  37081",
        "country": "DE"
    },
    "502E5C": {
        "oui_hex": "50-2E-5C",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "FCFE77": {
        "oui_hex": "FC-FE-77",
        "organization": "Hitachi Reftechno, Inc.",
        "address_1": "709-2 Tomita",
        "address_2": "Tochigi-shi  Tochigi-ken  329-4404",
        "country": "JP"
    },
    "70533F": {
        "oui_hex": "70-53-3F",
        "organization": "Alfa Instrumentos Eletronicos Ltda.",
        "address_1": "Rua Coronel Mario de Azevedo, 138",
        "address_2": "Sao Paulo  SP  02710-020",
        "country": "BR"
    },
    "407A80": {
        "oui_hex": "40-7A-80",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "644214": {
        "oui_hex": "64-42-14",
        "organization": "Swisscom Energy Solutions AG",
        "address_1": "Solothurnerstrasse 19",
        "address_2": "Olten    4600",
        "country": "CH"
    },
    "0CA694": {
        "oui_hex": "0C-A6-94",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "184462": {
        "oui_hex": "18-44-62",
        "organization": "Riava Networks, Inc.",
        "address_1": "Kato Bldg. 1F, 6-12-4 Soto-Kanda",
        "address_2": "Chiyoda-ku  Tokyo  1010021",
        "country": "JP"
    },
    "C03580": {
        "oui_hex": "C0-35-80",
        "organization": "A&R TECH",
        "address_1": "Marksteinergasse 13",
        "address_2": "Vienna    1210",
        "country": "AT"
    },
    "D08A55": {
        "oui_hex": "D0-8A-55",
        "organization": "Skullcandy",
        "address_1": "1441 Ute blvd.",
        "address_2": "Park City  Utah  84098",
        "country": "US"
    },
    "344F3F": {
        "oui_hex": "34-4F-3F",
        "organization": "IO-Power Technology Co., Ltd.",
        "address_1": "1F., No.100,",
        "address_2": "Hsinchu City    30055",
        "country": "TW"
    },
    "146080": {
        "oui_hex": "14-60-80",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "9CBB98": {
        "oui_hex": "9C-BB-98",
        "organization": "Shen Zhen RND Electronic Co.,LTD",
        "address_1": "G315,Hua Chuang Da business Certer",
        "address_2": "Shen Zhen  Guang Dong  518000",
        "country": "CN"
    },
    "50C271": {
        "oui_hex": "50-C2-71",
        "organization": "SECURETECH INC",
        "address_1": "#304, 799 Kwanyang-dong, Dongan-gu,",
        "address_2": "Anyang-ci  Gyunggi-do  431-767",
        "country": "KR"
    },
    "CC720F": {
        "oui_hex": "CC-72-0F",
        "organization": "Viscount Systems Inc.",
        "address_1": "4585 Tillicum Street",
        "address_2": "Burnaby  British Columbia  V5J 5K9",
        "country": "CA"
    },
    "742B62": {
        "oui_hex": "74-2B-62",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "643F5F": {
        "oui_hex": "64-3F-5F",
        "organization": "Exablaze",
        "address_1": "Level 6",
        "address_2": "Sydney  NSW  2000",
        "country": "AU"
    },
    "8C2F39": {
        "oui_hex": "8C-2F-39",
        "organization": "IBA Dosimetry GmbH",
        "address_1": "Bahnhofstrasse 5",
        "address_2": "Schwarzenbruck    90592",
        "country": "DE"
    },
    "C0A0BB": {
        "oui_hex": "C0-A0-BB",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "2CCD69": {
        "oui_hex": "2C-CD-69",
        "organization": "Aqavi.com",
        "address_1": "3 Riverway",
        "address_2": "Houston  TX  77056",
        "country": "US"
    },
    "F45F69": {
        "oui_hex": "F4-5F-69",
        "organization": "Matsufu Electronics distribution Company",
        "address_1": "Suites 1601~3, Kinwick Centre, 32 Hollywood Road, Hong Kong",
        "address_2": "Hong Kong",
        "country": "HK"
    },
    "28A1EB": {
        "oui_hex": "28-A1-EB",
        "organization": "ETEK TECHNOLOGY (SHENZHEN) CO.,LTD",
        "address_1": "A505-506、A509 Room,A5 Floor, Academy Of International Technology Innovation, Keji Nan 10th Road, Hi-Tech Industrial Park, Shenzhen, P.R.C.",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "B8F828": {
        "oui_hex": "B8-F8-28",
        "organization": "Changshu Gaoshida Optoelectronic Technology Co. Ltd.",
        "address_1": "Baimao Industrail Park Changshu  Jiangsu",
        "address_2": "Changshu  Jiangsu  215500",
        "country": "CN"
    },
    "3C1A57": {
        "oui_hex": "3C-1A-57",
        "organization": "Cardiopulmonary Corp",
        "address_1": "200 Cascade Blvd",
        "address_2": "Milford  CT  06460",
        "country": "US"
    },
    "541B5D": {
        "oui_hex": "54-1B-5D",
        "organization": "Techno-Innov",
        "address_1": "35 rue du champ Blanc",
        "address_2": "Meyzieu  Rhône  69330",
        "country": "FR"
    },
    "9CE7BD": {
        "oui_hex": "9C-E7-BD",
        "organization": "Winduskorea co., Ltd",
        "address_1": "RM313, Seoul-Garden Bldg,",
        "address_2": "Seoul    152-828",
        "country": "KR"
    },
    "3842A6": {
        "oui_hex": "38-42-A6",
        "organization": "Ingenieurbuero Stahlkopf",
        "address_1": "Ingenieurbuero Stahlkopf",
        "address_2": "Glockengießerweg 2  Bielefeld  33659",
        "country": "DE"
    },
    "2C553C": {
        "oui_hex": "2C-55-3C",
        "organization": "Gainspeed, Inc.",
        "address_1": "295 Santa Ana Court",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "248000": {
        "oui_hex": "24-80-00",
        "organization": "Westcontrol AS",
        "address_1": "Breivikvg 7",
        "address_2": "Joerpeland  -  4100",
        "country": "US"
    },
    "1C4BB9": {
        "oui_hex": "1C-4B-B9",
        "organization": "SMG ENTERPRISE, LLC",
        "address_1": "865 LOVE ST",
        "address_2": "ELK GROVE VILLAGE  IL  60007",
        "country": "US"
    },
    "346178": {
        "oui_hex": "34-61-78",
        "organization": "The Boeing Company",
        "address_1": "325 James S. McDonnell Blvd",
        "address_2": "Hazelwood  MO  63042-2513",
        "country": "US"
    },
    "1446E4": {
        "oui_hex": "14-46-E4",
        "organization": "AVISTEL",
        "address_1": "15 rue Auguste Bartholdi",
        "address_2": "Carrieres sur Seine    78420",
        "country": "FR"
    },
    "D095C7": {
        "oui_hex": "D0-95-C7",
        "organization": "Pantech Co., Ltd.",
        "address_1": "110-1 Ongjeong-Ri, Tongjin-Eup",
        "address_2": "Gimpo-Si  Gyounggi-Do  415-865",
        "country": "KR"
    },
    "D02C45": {
        "oui_hex": "D0-2C-45",
        "organization": "littleBits Electronics, Inc.",
        "address_1": "60 E. 11th Street",
        "address_2": "New York  NY  10003",
        "country": "US"
    },
    "044F8B": {
        "oui_hex": "04-4F-8B",
        "organization": "Adapteva, Inc.",
        "address_1": "1666 Massachusetts Ave",
        "address_2": "Lexington  MA  02420",
        "country": "US"
    },
    "B4A82B": {
        "oui_hex": "B4-A8-2B",
        "organization": "Histar Digital Electronics Co., Ltd.",
        "address_1": " Room 616,Block A,",
        "address_2": "Shenzhen  Baoan  518133",
        "country": "CN"
    },
    "284D92": {
        "oui_hex": "28-4D-92",
        "organization": "Luminator",
        "address_1": "900 Klein Road",
        "address_2": "Plano  Texas  75074",
        "country": "US"
    },
    "54FB58": {
        "oui_hex": "54-FB-58",
        "organization": "WISEWARE, Lda",
        "address_1": "Centro Social e Administrativo da ZIV",
        "address_2": "Zona Industrial de Vagos  Portugal  3840-385",
        "country": "PT"
    },
    "940BD5": {
        "oui_hex": "94-0B-D5",
        "organization": "Himax Technologies, Inc",
        "address_1": "No.26, Zilian Rd., Xinshi Dist.",
        "address_2": "Tainan City    741",
        "country": "TW"
    },
    "E0D1E6": {
        "oui_hex": "E0-D1-E6",
        "organization": "Aliph dba Jawbone",
        "address_1": "99 Rhode Island Street",
        "address_2": "San Francisco  California  94103",
        "country": "US"
    },
    "D82D9B": {
        "oui_hex": "D8-2D-9B",
        "organization": "Shenzhen G.Credit Communication Technology Co., Ltd",
        "address_1": "4/F, Suite A, XinNengYuan Building, 2239 Nanhai Rd., Nanshan Dist., Shenzhen, Guangdong,China",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "709BFC": {
        "oui_hex": "70-9B-FC",
        "organization": "Bryton Inc.",
        "address_1": "6F., No. 100, Zhouzi St., Neihu Dist.",
        "address_2": "Taipei City    11493",
        "country": "US"
    },
    "ACE42E": {
        "oui_hex": "AC-E4-2E",
        "organization": "SK hynix",
        "address_1": "SK u-Tower, 25-1, Jeongja-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-844",
        "country": "KR"
    },
    "78FE41": {
        "oui_hex": "78-FE-41",
        "organization": "Socus networks",
        "address_1": "2F.-2, No.215, Sec. 2, Chengde Rd., Datong Dist.,",
        "address_2": "Taipei City    103",
        "country": "TW"
    },
    "205721": {
        "oui_hex": "20-57-21",
        "organization": "Salix Technology CO., Ltd.",
        "address_1": "5F., No. 16, Lane 77, Hsing Ai Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "883612": {
        "oui_hex": "88-36-12",
        "organization": "SRC Computers, LLC",
        "address_1": "4240 N. Nevada Avenue",
        "address_2": "Colorado Springs  CO  80907",
        "country": "US"
    },
    "083571": {
        "oui_hex": "08-35-71",
        "organization": "CASwell INC.",
        "address_1": "8F,No.242,Bo-Ai St., Shu-Lin Dist.,New Taipei City ,Taiwan.",
        "address_2": "New Taipei City  Taiwan  23845",
        "country": "TW"
    },
    "9876B6": {
        "oui_hex": "98-76-B6",
        "organization": "Adafruit",
        "address_1": "150 Varick st",
        "address_2": "New York  NY  10013",
        "country": "US"
    },
    "503CC4": {
        "oui_hex": "50-3C-C4",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "US"
    },
    "2C7B84": {
        "oui_hex": "2C-7B-84",
        "organization": "OOO Petr Telegin",
        "address_1": "Gagarin avenue, 37, build P1",
        "address_2": "  Nizhny Novgorod  603009",
        "country": "RU"
    },
    "A4C0C7": {
        "oui_hex": "A4-C0-C7",
        "organization": "ShenZhen Hitom Communication Technology Co..LTD",
        "address_1": "Room 110,Unit A,No.1 Chuangye Building,43# YanShan Road,Shekou Area",
        "address_2": "ShenZhen  GuangDong  518052",
        "country": "CN"
    },
    "306112": {
        "oui_hex": "30-61-12",
        "organization": "PAV GmbH",
        "address_1": "Georg-Kaindl-Straße 11",
        "address_2": "Otterfing    83624",
        "country": "DE"
    },
    "789F4C": {
        "oui_hex": "78-9F-4C",
        "organization": "HOERBIGER Elektronik GmbH",
        "address_1": "Justinus-Kernerstr. 7",
        "address_2": "Ammerbuch  Baden-Wuerttemberg  D-72119",
        "country": "DE"
    },
    "18104E": {
        "oui_hex": "18-10-4E",
        "organization": "CEDINT-UPM",
        "address_1": "Campus de Montegancedo",
        "address_2": "  Madrid",
        "country": "ES"
    },
    "9C1465": {
        "oui_hex": "9C-14-65",
        "organization": "Edata Elektronik San. ve Tic. A.Ş.",
        "address_1": "Tantavi Mahallesi Menteşoğlu Cad.",
        "address_2": "İstanbul  -  34764",
        "country": "TR"
    },
    "4C55CC": {
        "oui_hex": "4C-55-CC",
        "organization": "Zentri Pty Ltd",
        "address_1": "Level 9, 191 Clarence St,",
        "address_2": "Sydney  NSW  2000",
        "country": "AU"
    },
    "00C5DB": {
        "oui_hex": "00-C5-DB",
        "organization": "Datatech Sistemas Digitales Avanzados SL",
        "address_1": "Cardenal Herrera Oria 165",
        "address_2": "  Madrid  28034",
        "country": "ES"
    },
    "8CF945": {
        "oui_hex": "8C-F9-45",
        "organization": "Power Automation pte Ltd",
        "address_1": "28 Ayer Rajah Crescent",
        "address_2": "    139959",
        "country": "SG"
    },
    "F842FB": {
        "oui_hex": "F8-42-FB",
        "organization": "Yasuda Joho Co.,ltd.",
        "address_1": "1-11-1",
        "address_2": "Minato-ku  Tokyo  105-0022",
        "country": "JP"
    },
    "887398": {
        "oui_hex": "88-73-98",
        "organization": "K2E Tekpoint",
        "address_1": "201,Winstower,278-51,Sungsoo2ga 3dong,Sungdong-gu,Seoul,S.Korea,133-123",
        "address_2": "Seoul  Sungdong-gu  133-123",
        "country": "KR"
    },
    "2C922C": {
        "oui_hex": "2C-92-2C",
        "organization": "Kishu Giken Kogyou Company Ltd,.",
        "address_1": "466 Nunohiki",
        "address_2": "Wakayama city  Wakayama prefecture  6410015",
        "country": "JP"
    },
    "D8FEE3": {
        "oui_hex": "D8-FE-E3",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "58F387": {
        "oui_hex": "58-F3-87",
        "organization": "HCCP",
        "address_1": "Gabriel Metsulaan 4a",
        "address_2": "EINDHOVEN    5611SP",
        "country": "NL"
    },
    "3C977E": {
        "oui_hex": "3C-97-7E",
        "organization": "IPS Technology Limited",
        "address_1": "7 Floor,E  block,Dong Hai Wang Building",
        "address_2": "Shenzhen  Guangodng  518000",
        "country": "CN"
    },
    "A4FB8D": {
        "oui_hex": "A4-FB-8D",
        "organization": "Hangzhou Dunchong Technology Co.Ltd",
        "address_1": "Yitian Square 1#401A",
        "address_2": "hangzhou  zhejiang  310051",
        "country": "US"
    },
    "F4CD90": {
        "oui_hex": "F4-CD-90",
        "organization": "Vispiron Rotec GmbH",
        "address_1": "Frankfurter Ring 224",
        "address_2": "München  Bayern  80807",
        "country": "DE"
    },
    "806C8B": {
        "oui_hex": "80-6C-8B",
        "organization": "KAESER KOMPRESSOREN AG",
        "address_1": "Carl-Kaeser-Strasse 26",
        "address_2": "Coburg  Bavaria  96450",
        "country": "DE"
    },
    "043D98": {
        "oui_hex": "04-3D-98",
        "organization": "ChongQing QingJia Electronics CO.,LTD",
        "address_1": "No.1,DianCe Village JiangBei District",
        "address_2": "  Chongqing city  400020",
        "country": "CN"
    },
    "E03E4A": {
        "oui_hex": "E0-3E-4A",
        "organization": "Cavanagh Group International",
        "address_1": "9180 Four Mile Creek Rd.",
        "address_2": "Gainesville  GA  30506",
        "country": "US"
    },
    "041B94": {
        "oui_hex": "04-1B-94",
        "organization": "Host Mobility AB",
        "address_1": "Anders Personsgatan 12",
        "address_2": "Gothenburg  Vastra Gotaland  41664",
        "country": "SE"
    },
    "A0CEC8": {
        "oui_hex": "A0-CE-C8",
        "organization": "CE LINK LIMITED",
        "address_1": "2/F, Building G, Licheng Tech. Ind. Zone",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "907A28": {
        "oui_hex": "90-7A-28",
        "organization": "Beijing Morncloud Information And Technology Co. Ltd.",
        "address_1": "A#1107, XiaoYun center",
        "address_2": "Chaoyang District  Beijing  100125",
        "country": "CN"
    },
    "1001CA": {
        "oui_hex": "10-01-CA",
        "organization": "Ashley Butterworth",
        "address_1": "P.O. Box 3410",
        "address_2": "Santa Clara  CA  95055",
        "country": "US"
    },
    "246AAB": {
        "oui_hex": "24-6A-AB",
        "organization": "IT-IS International",
        "address_1": "1 Wainstones Court",
        "address_2": "Middlesbrough  Cleveland  TS9 5JY",
        "country": "GB"
    },
    "FC4BBC": {
        "oui_hex": "FC-4B-BC",
        "organization": "Sunplus Technology Co., Ltd.",
        "address_1": "No.19, Innovation First Road",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "50A0BF": {
        "oui_hex": "50-A0-BF",
        "organization": "Alba Fiber Systems Inc.",
        "address_1": "265 E. Merrick Rd",
        "address_2": "Valley Stream  NY  11580",
        "country": "US"
    },
    "B836D8": {
        "oui_hex": "B8-36-D8",
        "organization": "Videoswitch",
        "address_1": "Uspallata 3579",
        "address_2": "Buenos Aires  Capital Federal  C1437JCS",
        "country": "AR"
    },
    "DC6F00": {
        "oui_hex": "DC-6F-00",
        "organization": "Livescribe, Inc.",
        "address_1": "7677 Oakport Street",
        "address_2": "Oakland  California  94621",
        "country": "US"
    },
    "54E3B0": {
        "oui_hex": "54-E3-B0",
        "organization": "JVL Industri Elektronik",
        "address_1": "Blokken 42",
        "address_2": "Birkeroed  Sjaelland  DK-3460",
        "country": "DK"
    },
    "804B20": {
        "oui_hex": "80-4B-20",
        "organization": "Ventilation Control",
        "address_1": "Kronenstrasse 34",
        "address_2": "Villingen-Schwenningen  Baden-Wuerttemberg  78054",
        "country": "DE"
    },
    "287994": {
        "oui_hex": "28-79-94",
        "organization": "Realplay Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7/F,Building E,SDG Information Port ,Kefeng Rd.,Hi-tech",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "107A86": {
        "oui_hex": "10-7A-86",
        "organization": "U&U ENGINEERING INC.",
        "address_1": "No.15, Gaoyang S. Rd",
        "address_2": "Taoyuan County    325-44",
        "country": "TW"
    },
    "40BD9E": {
        "oui_hex": "40-BD-9E",
        "organization": "Physio-Control, Inc",
        "address_1": "11811 Willows Rd NE",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "6C5779": {
        "oui_hex": "6C-57-79",
        "organization": "Aclima, Inc.",
        "address_1": "10 Lombard Street",
        "address_2": "San Francisco  California  94111",
        "country": "US"
    },
    "C0DA74": {
        "oui_hex": "C0-DA-74",
        "organization": "Hangzhou Sunyard Technology Co., Ltd.",
        "address_1": "No.3888 Jiangnan Ave, Binjiang District,",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "18D6CF": {
        "oui_hex": "18-D6-CF",
        "organization": "Kurth Electronic GmbH",
        "address_1": "Mühleweg 11",
        "address_2": "Eningen    72800",
        "country": "DE"
    },
    "F48139": {
        "oui_hex": "F4-81-39",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "1836FC": {
        "oui_hex": "18-36-FC",
        "organization": "Elecsys International Corporation",
        "address_1": "846 N Mart-Way Court",
        "address_2": "Olathe  KS  66061",
        "country": "US"
    },
    "A4D094": {
        "oui_hex": "A4-D0-94",
        "organization": "Erwin Peters Systemtechnik GmbH",
        "address_1": "Josef Baumann Strasse 37",
        "address_2": "Bochum    D44805",
        "country": "DE"
    },
    "882364": {
        "oui_hex": "88-23-64",
        "organization": "Watchnet DVR Inc",
        "address_1": "Unit 5 - 351 Ferrier St.",
        "address_2": "Markham  Ontario  L3R 5Z2",
        "country": "CA"
    },
    "581CBD": {
        "oui_hex": "58-1C-BD",
        "organization": "Affinegy",
        "address_1": "1705 S. Capital of Texas Hwy. Ste 310",
        "address_2": "Austin  Texas  78746",
        "country": "US"
    },
    "284FCE": {
        "oui_hex": "28-4F-CE",
        "organization": "Liaoning Wontel Science and Technology Development Co.,Ltd.",
        "address_1": "A704 Floor TaiHe building",
        "address_2": "Shenyang  Liaoning  110000",
        "country": "CN"
    },
    "048D38": {
        "oui_hex": "04-8D-38",
        "organization": "Netcore Technology Inc.",
        "address_1": "9F,B block,Tsinghua Information Guard",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "2C9464": {
        "oui_hex": "2C-94-64",
        "organization": "Cincoze Co., Ltd.",
        "address_1": "7F., No. 4 Aly. 1 Ln. 235, Baociao Rd.,",
        "address_2": "New Taipei City    23145",
        "country": "US"
    },
    "3065EC": {
        "oui_hex": "30-65-EC",
        "organization": "Wistron (ChongQing)",
        "address_1": "No.F08/F09,D zone,Konggang Functional Zone",
        "address_2": "  ChongQing  401120",
        "country": "CN"
    },
    "542CEA": {
        "oui_hex": "54-2C-EA",
        "organization": "PROTECTRON",
        "address_1": "140 zone industriel",
        "address_2": "  CASABLANCA  18600",
        "country": "MA"
    },
    "94B8C5": {
        "oui_hex": "94-B8-C5",
        "organization": "RuggedCom Inc.",
        "address_1": "300 Applewood Crescent",
        "address_2": "Concord  Ontario  L4K 5C7",
        "country": "CA"
    },
    "DC825B": {
        "oui_hex": "DC-82-5B",
        "organization": "JANUS, spol. s r.o.",
        "address_1": "Sarajevska 8",
        "address_2": "Prague  Czech Republic  12000",
        "country": "CZ"
    },
    "9CA577": {
        "oui_hex": "9C-A5-77",
        "organization": "Osorno Enterprises Inc.",
        "address_1": "976 Elgin Ave",
        "address_2": "Winnipeg  MB  R3E 1B4",
        "country": "CA"
    },
    "C04301": {
        "oui_hex": "C0-43-01",
        "organization": "Epec Oy",
        "address_1": "P.O. Box 194",
        "address_2": "Seinäjoki    60101",
        "country": "FI"
    },
    "E07C62": {
        "oui_hex": "E0-7C-62",
        "organization": "Whistle Labs, Inc.",
        "address_1": "251 Rhode Island Street, Suite 211",
        "address_2": "San Francisco  CA  94013",
        "country": "US"
    },
    "F07F0C": {
        "oui_hex": "F0-7F-0C",
        "organization": "Leopold Kostal GmbH &Co. KG",
        "address_1": "An der Bellmerei 10",
        "address_2": "Luedenscheid  NRW  D-58513",
        "country": "DE"
    },
    "4C6255": {
        "oui_hex": "4C-62-55",
        "organization": "SANMINA-SCI SYSTEM DE MEXICO S.A. DE C.V.",
        "address_1": "Carretera Guadalajara-chapala km 15.5 #45",
        "address_2": "TLAJOMULCO  JALISCO  45640",
        "country": "MX"
    },
    "082719": {
        "oui_hex": "08-27-19",
        "organization": "APS systems/electronic AG",
        "address_1": "Neumatt 4",
        "address_2": "Niederbuchsiten  SO  4626",
        "country": "CH"
    },
    "505AC6": {
        "oui_hex": "50-5A-C6",
        "organization": "GUANGDONG SUPER TELECOM CO.,LTD.",
        "address_1": "4/F,NO.1025-1027 Gaopu Rd",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "9C79AC": {
        "oui_hex": "9C-79-AC",
        "organization": "Suntec Software(Shanghai) Co., Ltd.",
        "address_1": "17F New Hualian Mansion",
        "address_2": "  Shanghai  200020",
        "country": "CN"
    },
    "4C9614": {
        "oui_hex": "4C-96-14",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B863BC": {
        "oui_hex": "B8-63-BC",
        "organization": "ROBOTIS, Co, Ltd",
        "address_1": "#1506 Ace high End Tower 3, 371-50",
        "address_2": "Seoul    153-787",
        "country": "KR"
    },
    "980D2E": {
        "oui_hex": "98-0D-2E",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "C419EC": {
        "oui_hex": "C4-19-EC",
        "organization": "Qualisys AB",
        "address_1": "Packhusgatan 6",
        "address_2": "Gothenburg    41113",
        "country": "SE"
    },
    "604A1C": {
        "oui_hex": "60-4A-1C",
        "organization": "SUYIN Corporation",
        "address_1": "No.377,Fude 1st Rd",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "D464F7": {
        "oui_hex": "D4-64-F7",
        "organization": "CHENGDU USEE DIGITAL TECHNOLOGY CO., LTD",
        "address_1": "NO.6 CHUANGYE ROAD",
        "address_2": "CHENGDU  SICHUAN  610041",
        "country": "CN"
    },
    "74D02B": {
        "oui_hex": "74-D0-2B",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "601E02": {
        "oui_hex": "60-1E-02",
        "organization": "EltexAlatau",
        "address_1": "Ibragimova 9",
        "address_2": "Almaty  Province  050032",
        "country": "KZ"
    },
    "E0C6B3": {
        "oui_hex": "E0-C6-B3",
        "organization": "MilDef AB",
        "address_1": "Box 22079",
        "address_2": "Helsingborg  Skane  25022",
        "country": "SE"
    },
    "6472D8": {
        "oui_hex": "64-72-D8",
        "organization": "GooWi Technology Co.,Limited",
        "address_1": "Unit C8.,9/F,Hongming Fatoty Building",
        "address_2": "99 How Ming Street  Kwun Tong  999077",
        "country": "HK"
    },
    "60601F": {
        "oui_hex": "60-60-1F",
        "organization": "SZ DJI TECHNOLOGY CO.,LTD",
        "address_1": "6/F,HKUST SZ IER Bldg,9 Yuexing 1st Rd",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5C8486": {
        "oui_hex": "5C-84-86",
        "organization": "Brightsource Industries Israel LTD",
        "address_1": "11 Kiryat Mada st",
        "address_2": "Jerusalem    91450",
        "country": "IL"
    },
    "50CD32": {
        "oui_hex": "50-CD-32",
        "organization": "NanJing Chaoran Science & Technology Co.,Ltd.",
        "address_1": " Block C,Floor 5,Tianzexingwang Building",
        "address_2": "NanJing City  JiangSu Province  210019",
        "country": "CN"
    },
    "BCBAE1": {
        "oui_hex": "BC-BA-E1",
        "organization": "AREC Inc.",
        "address_1": "3F, No.367, Sec.2, Wenhua Rd",
        "address_2": " Banqiao Dist  New Taipei City  220",
        "country": "TW"
    },
    "18FA6F": {
        "oui_hex": "18-FA-6F",
        "organization": "ISC applied systems corp",
        "address_1": "295 Labrosse",
        "address_2": "Pointe-claire  QC  H9R-1A3",
        "country": "CA"
    },
    "A01C05": {
        "oui_hex": "A0-1C-05",
        "organization": "NIMAX TELECOM CO.,LTD.",
        "address_1": "1F. NO.308-7,SEC.1,DATONG RD",
        "address_2": "NEW TAIPEI CITY    221",
        "country": "TW"
    },
    "60E00E": {
        "oui_hex": "60-E0-0E",
        "organization": "SHINSEI ELECTRONICS CO LTD",
        "address_1": "2-6-25",
        "address_2": "Amagasaki  Hyogo  660-0805",
        "country": "JP"
    },
    "545414": {
        "oui_hex": "54-54-14",
        "organization": "Digital RF Corea, Inc",
        "address_1": "2 Floor, SeMin B/D, 201, Jangdari-ro",
        "address_2": "Suwon-si  Gyeonggi-do  442-833",
        "country": "KR"
    },
    "24EB65": {
        "oui_hex": "24-EB-65",
        "organization": "SAET I.S. S.r.l.",
        "address_1": "Via Leinì 1/B",
        "address_2": "San Maurizio C.se  TO  10077",
        "country": "IT"
    },
    "D0F27F": {
        "oui_hex": "D0-F2-7F",
        "organization": "SteadyServ Technoligies, LLC",
        "address_1": "12895 Brighton Avenue",
        "address_2": "Carmel  IN  46032",
        "country": "US"
    },
    "E894F6": {
        "oui_hex": "E8-94-F6",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "188410": {
        "oui_hex": "18-84-10",
        "organization": "CoreTrust Inc.",
        "address_1": "14F Saman Bldg. 945 Daechi-dong",
        "address_2": "Seoul  Republic of Korea  135-280",
        "country": "KR"
    },
    "FC229C": {
        "oui_hex": "FC-22-9C",
        "organization": "Han Kyung I Net Co.,Ltd.",
        "address_1": "3F,Seung Eun Bldg",
        "address_2": "Yu Seong-Gu  Dae Jeon  305-335",
        "country": "KR"
    },
    "1832A2": {
        "oui_hex": "18-32-A2",
        "organization": "LAON TECHNOLOGY CO., LTD.",
        "address_1": "#1212 HO, BIZ CENTER, SKn TECHNOPARK",
        "address_2": "SEONGNAM  KYOUNGGI DO  462-721",
        "country": "KR"
    },
    "D4A499": {
        "oui_hex": "D4-A4-99",
        "organization": "InView Technology Corporation",
        "address_1": "8900 Shoal Creek Blvd",
        "address_2": "Austin  TX  78757",
        "country": "US"
    },
    "08482C": {
        "oui_hex": "08-48-2C",
        "organization": "Raycore Taiwan Co., LTD.",
        "address_1": "3F-5, No.351, Sec.2, Zongshan Rd",
        "address_2": "New Taipei city    23504",
        "country": "TW"
    },
    "DC2BCA": {
        "oui_hex": "DC-2B-CA",
        "organization": "Zera GmbH",
        "address_1": "Hauptstrasse 392",
        "address_2": "Koenigswinter  NRW  53639",
        "country": "DE"
    },
    "9498A2": {
        "oui_hex": "94-98-A2",
        "organization": "Shanghai LISTEN TECH.LTD",
        "address_1": "7F,A#,NO.3699,Gonghexin Road",
        "address_2": "SHANGHAI  SHANGHAI  200435",
        "country": "CN"
    },
    "E0EDC7": {
        "oui_hex": "E0-ED-C7",
        "organization": "Shenzhen Friendcom Technology Development Co., Ltd",
        "address_1": "6/F,17 Building, Guangqian Industrial Park,",
        "address_2": "Nanshan District, Shen Zhen CIty  Guang Dong  518055",
        "country": "CN"
    },
    "B4DD15": {
        "oui_hex": "B4-DD-15",
        "organization": "ControlThings Oy Ab",
        "address_1": "Werner Söderströmin katu 24",
        "address_2": "Porvoo  Finland  06100",
        "country": "FI"
    },
    "DC1DD4": {
        "oui_hex": "DC-1D-D4",
        "organization": "Microstep-MIS spol. s r.o.",
        "address_1": "Cavojskeho 1",
        "address_2": "Bratislava    84104",
        "country": "SK"
    },
    "FCDD55": {
        "oui_hex": "FC-DD-55",
        "organization": "Shenzhen WeWins wireless Co.,Ltd",
        "address_1": "6/F.,B Wing,Yuehai Piaza,Nanhai Road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B01743": {
        "oui_hex": "B0-17-43",
        "organization": "EDISON GLOBAL CIRCUITS LLC",
        "address_1": "1475  Sawdust Rd",
        "address_2": "Spring  TX  77380-2974",
        "country": "US"
    },
    "D0BE2C": {
        "oui_hex": "D0-BE-2C",
        "organization": "CNSLink Co., Ltd.",
        "address_1": "room 807, Jungang Induspia 5",
        "address_2": "Seongnam  Gyeonggi  462-807",
        "country": "US"
    },
    "40516C": {
        "oui_hex": "40-51-6C",
        "organization": "Grandex International Corporation",
        "address_1": "4F, 525 Chung Cheng Road",
        "address_2": "Hsin Tien Dist.  New Taipei City  231",
        "country": "TW"
    },
    "C0885B": {
        "oui_hex": "C0-88-5B",
        "organization": "SnD Tech Co., Ltd.",
        "address_1": " 1140-4 Triple Tower C-406",
        "address_2": "Bucheon Si  Gyeonggi-Do  420-852",
        "country": "KR"
    },
    "3CFB96": {
        "oui_hex": "3C-FB-96",
        "organization": "Emcraft Systems LLC",
        "address_1": "2191 S. El Camino Real",
        "address_2": "Oceanside  CA  92054",
        "country": "US"
    },
    "846223": {
        "oui_hex": "84-62-23",
        "organization": "Shenzhen Coship Electronics Co., Ltd.",
        "address_1": "Rainbow Bldg., North, Hi-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "1CFA68": {
        "oui_hex": "1C-FA-68",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "081F3F": {
        "oui_hex": "08-1F-3F",
        "organization": "WondaLink Inc.",
        "address_1": "2F, No. 23, R&D Road 2",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "1853E0": {
        "oui_hex": "18-53-E0",
        "organization": "Hanyang Digitech Co.Ltd",
        "address_1": "103, BANWOL-DONG, HWASEONG-SI, KYUNGGI-DO, KOREA",
        "address_2": "HWASEONG  KYUNGGI  445-330",
        "country": "KR"
    },
    "00C14F": {
        "oui_hex": "00-C1-4F",
        "organization": "DDL Co,.ltd.",
        "address_1": "6F AFT BLDG.",
        "address_2": "SAPPORO  HOKKAIDO  060-0035",
        "country": "JP"
    },
    "2C26C5": {
        "oui_hex": "2C-26-C5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "105F06": {
        "oui_hex": "10-5F-06",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "087999": {
        "oui_hex": "08-79-99",
        "organization": "AIM GmbH",
        "address_1": "Sasbacherstraße 2",
        "address_2": "Freiburg  BW  79111",
        "country": "US"
    },
    "C011A6": {
        "oui_hex": "C0-11-A6",
        "organization": "Fort-Telecom ltd.",
        "address_1": "Hrustalnaya 8a",
        "address_2": "  Perm  614107",
        "country": "RU"
    },
    "C04A00": {
        "oui_hex": "C0-4A-00",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "045FA7": {
        "oui_hex": "04-5F-A7",
        "organization": "Shenzhen Yichen Technology Development Co.,LTD",
        "address_1": "5/F Honghualing 2nd Industry Zone,Xili Town",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "94C962": {
        "oui_hex": "94-C9-62",
        "organization": "Teseq AG",
        "address_1": "Nordstrasse 11F",
        "address_2": "Luterbach  Solothurn  4542",
        "country": "CH"
    },
    "DC2A14": {
        "oui_hex": "DC-2A-14",
        "organization": "Shanghai Longjing Technology Co.",
        "address_1": "689 Chundong Road, Minhang District",
        "address_2": "  Shanghai  201108",
        "country": "CN"
    },
    "6886E7": {
        "oui_hex": "68-86-E7",
        "organization": "Orbotix, Inc.",
        "address_1": "1155 Canyon Blvd.",
        "address_2": "Boulder  CO  80302",
        "country": "US"
    },
    "C05E6F": {
        "oui_hex": "C0-5E-6F",
        "organization": "V. Stonkaus firma Kodinis Raktas",
        "address_1": "Ateities 10",
        "address_2": "  Vilnius  08303",
        "country": "LT"
    },
    "C0B8B1": {
        "oui_hex": "C0-B8-B1",
        "organization": "BitBox Ltd",
        "address_1": "Whitney Road",
        "address_2": "Basingstoke  Hampshire  RG24 8NS",
        "country": "GB"
    },
    "F82EDB": {
        "oui_hex": "F8-2E-DB",
        "organization": "RTW GmbH & Co. KG",
        "address_1": "Am Wassermann 25",
        "address_2": "Cologne  NRW  50829",
        "country": "DE"
    },
    "808B5C": {
        "oui_hex": "80-8B-5C",
        "organization": "Shenzhen Runhuicheng Technology Co., Ltd",
        "address_1": "315.3rd Floor Taoyuan Commercial Building A2 ridgepole Guang Qian Industrial Estate XiLi",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "D819CE": {
        "oui_hex": "D8-19-CE",
        "organization": "Telesquare",
        "address_1": "670, Sampyeong-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "E0CEC3": {
        "oui_hex": "E0-CE-C3",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "38F597": {
        "oui_hex": "38-F5-97",
        "organization": "home2net GmbH",
        "address_1": "Im Haslet 42",
        "address_2": "Woerth/Donau  Bayern  93086",
        "country": "DE"
    },
    "807B1E": {
        "oui_hex": "80-7B-1E",
        "organization": "Corsair Memory, Inc.",
        "address_1": "47100 Bayside Parkway",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "B4AB2C": {
        "oui_hex": "B4-AB-2C",
        "organization": "MtM Technology Corporation",
        "address_1": "12F, No. 186, Fuxing Road",
        "address_2": "Taoyuan City  Taoyuan County  33066",
        "country": "TW"
    },
    "74372F": {
        "oui_hex": "74-37-2F",
        "organization": "Tongfang Shenzhen Cloudcomputing Technology Co.,Ltd",
        "address_1": "4,1 Building,FinanceBase,NO.8KeFaRoad,Science park",
        "address_2": "ShenZhen City  GuangDong  518057",
        "country": "US"
    },
    "F0219D": {
        "oui_hex": "F0-21-9D",
        "organization": "Cal-Comp Electronics & Communications Company Ltd.",
        "address_1": "No.147, Sec. 3, Beishen Rd",
        "address_2": "Shenkeng Dist  New Taipei City  ---",
        "country": "TW"
    },
    "181725": {
        "oui_hex": "18-17-25",
        "organization": "Cameo Communications, Inc.",
        "address_1": "No. 276, Sinhu 1st Rd., Neihu District,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "8462A6": {
        "oui_hex": "84-62-A6",
        "organization": "EuroCB (Phils), Inc.",
        "address_1": "SFB No.2",
        "address_2": "Lapulapu CIty  Cebu  6015",
        "country": "PH"
    },
    "E4F365": {
        "oui_hex": "E4-F3-65",
        "organization": "Time-O-Matic, Inc.",
        "address_1": "1015 Maple St.",
        "address_2": "Danville  IL  61832",
        "country": "US"
    },
    "DCC0DB": {
        "oui_hex": "DC-C0-DB",
        "organization": "Shenzhen Kaiboer Technology Co., Ltd.",
        "address_1": "4/F, No. 11 Bldg., Yusheng Industrial Park, No. 467, Xixiang Sec.,",
        "address_2": "Shenzhen  Guangdong  518126",
        "country": "CN"
    },
    "AC5D10": {
        "oui_hex": "AC-5D-10",
        "organization": "Pace Americas",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  Ca  95131",
        "country": "US"
    },
    "FC626E": {
        "oui_hex": "FC-62-6E",
        "organization": "Beijing MDC Telecom",
        "address_1": "26 Xiaoyun Road #B2808, Chaoyang",
        "address_2": "  Beijing  100016",
        "country": "CN"
    },
    "84C8B1": {
        "oui_hex": "84-C8-B1",
        "organization": "Incognito Software Systems Inc.",
        "address_1": "#500 - 375 Water St",
        "address_2": "Vancouver  BC - British Columbia  V6B 5C6",
        "country": "CA"
    },
    "E8A364": {
        "oui_hex": "E8-A3-64",
        "organization": "Signal Path International / Peachtree Audio",
        "address_1": "2045 120th Ave NE",
        "address_2": "Bellevue  Washington  98005",
        "country": "US"
    },
    "BC51FE": {
        "oui_hex": "BC-51-FE",
        "organization": "Swann communications Pty Ltd",
        "address_1": "Unit 13",
        "address_2": "Port Melbourne  Victoria  3207",
        "country": "AU"
    },
    "88F490": {
        "oui_hex": "88-F4-90",
        "organization": "Jetmobile Pte Ltd",
        "address_1": "541 Orchard Road",
        "address_2": "Singapore    238881",
        "country": "SG"
    },
    "1C9179": {
        "oui_hex": "1C-91-79",
        "organization": "Integrated System Technologies Ltd",
        "address_1": "Suite 5 Birch House",
        "address_2": "Aldridge  West Midlands  WS9 0NF",
        "country": "GB"
    },
    "A0BAB8": {
        "oui_hex": "A0-BA-B8",
        "organization": "Pixon Imaging",
        "address_1": "9530 Towne Center Dr.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "74E424": {
        "oui_hex": "74-E4-24",
        "organization": "APISTE CORPORATION",
        "address_1": "1-4-16 Dojimahama, Kita-ku",
        "address_2": "Osaka  Japan  530-0004",
        "country": "JP"
    },
    "2411D0": {
        "oui_hex": "24-11-D0",
        "organization": "Chongqing Ehs Science and Technology Development Co.,Ltd.",
        "address_1": "Saturn Business Center C3-15-7,Starlight No.5 Street",
        "address_2": "  Chongqing  400060",
        "country": "CN"
    },
    "B461FF": {
        "oui_hex": "B4-61-FF",
        "organization": "Lumigon A/S",
        "address_1": "Baadehavnsgade 2A",
        "address_2": "Copenhagen SV  Denmark  2450",
        "country": "DK"
    },
    "A0A130": {
        "oui_hex": "A0-A1-30",
        "organization": "DLI Taiwan Branch office",
        "address_1": "No.18-5, No.738. Zhong Zheng Rd",
        "address_2": "Taipei New City    23511",
        "country": "TW"
    },
    "30215B": {
        "oui_hex": "30-21-5B",
        "organization": "Shenzhen Ostar Display Electronic Co.,Ltd",
        "address_1": "Room218, CASTD Incubator Building, High-tech South Street No.1,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "34FA40": {
        "oui_hex": "34-FA-40",
        "organization": "Guangzhou Robustel Technologies Co., Limited",
        "address_1": "B301, Tianchang Shangmaoyuan",
        "address_2": "Guangzhou  Guangdong  510660",
        "country": "CN"
    },
    "1C5A6B": {
        "oui_hex": "1C-5A-6B",
        "organization": "Philips Electronics Nederland BV",
        "address_1": "PO BOX 80045",
        "address_2": " Eindhoven    5600 JZ",
        "country": "NL"
    },
    "A875D6": {
        "oui_hex": "A8-75-D6",
        "organization": "FreeTek International Co., Ltd.",
        "address_1": "Unit D, 15/F, Tai Ping Ind.Ctr., Blk 2, 55 Ting Kok Rd.,",
        "address_2": "Hong Kong  Hong KOng  1111",
        "country": "HK"
    },
    "ECE915": {
        "oui_hex": "EC-E9-15",
        "organization": "STI Ltd",
        "address_1": "Osborn Way",
        "address_2": "Hook  Hampshire  RG27 9HX",
        "country": "GB"
    },
    "80D733": {
        "oui_hex": "80-D7-33",
        "organization": "QSR Automations, Inc.",
        "address_1": "2301 Stanley Gault Pkwy",
        "address_2": "Louisville  KY  40223",
        "country": "US"
    },
    "303D08": {
        "oui_hex": "30-3D-08",
        "organization": "GLINTT TES S.A.",
        "address_1": "Beloura Office Park, Ed.10",
        "address_2": "Sintra    2710-693",
        "country": "PT"
    },
    "A81FAF": {
        "oui_hex": "A8-1F-AF",
        "organization": "KRYPTON POLSKA",
        "address_1": "AL. JEROZOLIMSKIE 131",
        "address_2": "WARSZAWA  MAZOWIECKIE  02-304",
        "country": "PL"
    },
    "30D357": {
        "oui_hex": "30-D3-57",
        "organization": "Logosol, Inc.",
        "address_1": "5041 ROBERT J. MATHEWS PARKWAY",
        "address_2": "EL DORADO HILLS  California  95762",
        "country": "US"
    },
    "BC39A6": {
        "oui_hex": "BC-39-A6",
        "organization": "CSUN System Technology Co.,LTD",
        "address_1": "4-16-22,Chiyogaoka",
        "address_2": "Kawasaki-shi  Kanagawa Ken  2150005",
        "country": "JP"
    },
    "ECB541": {
        "oui_hex": "EC-B5-41",
        "organization": "SHINANO E and E Co.Ltd.",
        "address_1": "5511-6 Wada",
        "address_2": "Matsumoto City  Nagano  390-1242",
        "country": "JP"
    },
    "D410CF": {
        "oui_hex": "D4-10-CF",
        "organization": "Huanshun Network Science and Technology Co., Ltd.",
        "address_1": "No. 218-1, North Binjiang Road",
        "address_2": "yuyao  zhejiang  315400",
        "country": "CN"
    },
    "6CB311": {
        "oui_hex": "6C-B3-11",
        "organization": "Shenzhen Lianrui Electronics Co.,Ltd",
        "address_1": "Block C4 XinTang Industrial Park",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "10A743": {
        "oui_hex": "10-A7-43",
        "organization": "SK Mtek Limited",
        "address_1": "Flat/Rm 1808, 18F Tower II, Admirality",
        "address_2": "Hong Kong",
        "country": "HK"
    },
    "547FA8": {
        "oui_hex": "54-7F-A8",
        "organization": "TELCO systems, s.r.o.",
        "address_1": "Zvolenska cesta 20",
        "address_2": "Banska Bystrica  Slovak republic  974 05",
        "country": "SK"
    },
    "5474E6": {
        "oui_hex": "54-74-E6",
        "organization": "Webtech Wireless",
        "address_1": "215-4299 Canada Way",
        "address_2": "Burnaby  BC  V5G 1H3",
        "country": "CA"
    },
    "C46DF1": {
        "oui_hex": "C4-6D-F1",
        "organization": "DataGravity",
        "address_1": "10 Tara Blvd",
        "address_2": "Nashua  NH  03062",
        "country": "US"
    },
    "304449": {
        "oui_hex": "30-44-49",
        "organization": "PLATH GmbH",
        "address_1": "Gotenstrasse 18",
        "address_2": "  Hamburg  20097",
        "country": "DE"
    },
    "94FD2E": {
        "oui_hex": "94-FD-2E",
        "organization": "Shanghai Uniscope Technologies Co.,Ltd",
        "address_1": "5th Floor, Building 10,",
        "address_2": "  Shanghai  200233",
        "country": "CN"
    },
    "E4C146": {
        "oui_hex": "E4-C1-46",
        "organization": "Objetivos y Servicios de Valor A",
        "address_1": "C/ Monte Esquinza, 28, 1D",
        "address_2": "  Madrid  28017",
        "country": "ES"
    },
    "D40057": {
        "oui_hex": "D4-00-57",
        "organization": "MC Technologies GmbH",
        "address_1": "Kabelkamp 2",
        "address_2": "Hannover  Germany  30179",
        "country": "DE"
    },
    "5CE0F6": {
        "oui_hex": "5C-E0-F6",
        "organization": "NIC.br- Nucleo de Informacao e Coordenacao do Ponto BR",
        "address_1": "Av. das Nacoes Unidas, 11541, 7o andar",
        "address_2": "São Paulo  SP  04578-000",
        "country": "BR"
    },
    "C83D97": {
        "oui_hex": "C8-3D-97",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "0CF361": {
        "oui_hex": "0C-F3-61",
        "organization": "Java Information",
        "address_1": "Woolim Lions Valley 2nd B-1305",
        "address_2": "Seongnam-Si  Gyounggi-Do  462-120",
        "country": "KR"
    },
    "600F77": {
        "oui_hex": "60-0F-77",
        "organization": "SilverPlus, Inc",
        "address_1": "18 Technology Dr, #143",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "B0358D": {
        "oui_hex": "B0-35-8D",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "F8E4FB": {
        "oui_hex": "F8-E4-FB",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "8C4AEE": {
        "oui_hex": "8C-4A-EE",
        "organization": "GIGA TMS INC",
        "address_1": "9F-2 NO.31 Lane 169 Kang-ning Street, Hsi-Chih",
        "address_2": "Taipei County 221    221",
        "country": "TW"
    },
    "34C99D": {
        "oui_hex": "34-C9-9D",
        "organization": "EIDOLON COMMUNICATIONS TECHNOLOGY CO. LTD.",
        "address_1": "Room 603, 6/F., Wanchai Central Building, 89 Lockhart Road, Wanchai,",
        "address_2": "",
        "country": "HK"
    },
    "ACE64B": {
        "oui_hex": "AC-E6-4B",
        "organization": "Shenzhen Baojia Battery Technology Co., Ltd.",
        "address_1": "Block A, Tongfuyu Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518013",
        "country": "CN"
    },
    "789F87": {
        "oui_hex": "78-9F-87",
        "organization": "Siemens AG I IA PP PRM",
        "address_1": "Gleiwitzer Strasse 555",
        "address_2": "Nuremberg  Bavaria  90475",
        "country": "DE"
    },
    "08E5DA": {
        "oui_hex": "08-E5-DA",
        "organization": "NANJING FUJITSU COMPUTER PRODUCTS CO.,LTD.",
        "address_1": "NO.1,XIANXIN MID-ROAD",
        "address_2": "NANJING  JIANGSU  210046",
        "country": "CN"
    },
    "5884E4": {
        "oui_hex": "58-84-E4",
        "organization": "IP500 Alliance e.V.",
        "address_1": "Scharnhorststraße 16",
        "address_2": "Berlin    10115",
        "country": "DE"
    },
    "044BFF": {
        "oui_hex": "04-4B-FF",
        "organization": "GuangZhou Hedy Digital Technology Co., Ltd",
        "address_1": "B 701, Gaoke Building, TianHe Bei Road,",
        "address_2": "GuangZhou  GuangDong  510630",
        "country": "CN"
    },
    "E8718D": {
        "oui_hex": "E8-71-8D",
        "organization": "Elsys Equipamentos Eletronicos Ltda",
        "address_1": "Av. Torquato Tapajós, n. 1052 - B. Flores",
        "address_2": "Manaus  Amazonas  69.058-830",
        "country": "BR"
    },
    "D0738E": {
        "oui_hex": "D0-73-8E",
        "organization": "DONG OH PRECISION CO., LTD.",
        "address_1": "#282 SHINGAL-RI, JICSAN-EUP",
        "address_2": "CHEONAN-SI  CHUNGCHEONGNAM-DO  331-814",
        "country": "KR"
    },
    "64C944": {
        "oui_hex": "64-C9-44",
        "organization": "LARK Technologies, Inc",
        "address_1": "2570 W El Camino Real",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "0C93FB": {
        "oui_hex": "0C-93-FB",
        "organization": "BNS Solutions",
        "address_1": "PO Box 508",
        "address_2": "Walpole  MA  02081",
        "country": "US"
    },
    "E44F5F": {
        "oui_hex": "E4-4F-5F",
        "organization": "EDS Elektronik Destek San.Tic.Ltd.Sti",
        "address_1": "Meclis Mah. Hayran Sok. No:4",
        "address_2": "istanbul    34785",
        "country": "TR"
    },
    "E86D54": {
        "oui_hex": "E8-6D-54",
        "organization": "Digit Mobile Inc",
        "address_1": "5F.,No.550,Ruiguang Rd., Neihu Dist.,Taipei City 11492, Taiwan",
        "address_2": "Taipei  Taiwan  11492",
        "country": "TW"
    },
    "90B11C": {
        "oui_hex": "90-B1-1C",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "005D03": {
        "oui_hex": "00-5D-03",
        "organization": "Xilinx, Inc",
        "address_1": "2100 Logic drive",
        "address_2": "San Jose  CA  95124",
        "country": "US"
    },
    "802FDE": {
        "oui_hex": "80-2F-DE",
        "organization": "Zurich Instruments AG",
        "address_1": "Technoparkstrasse 1",
        "address_2": "  Zurich  8005",
        "country": "CH"
    },
    "5C38E0": {
        "oui_hex": "5C-38-E0",
        "organization": "Shanghai Super Electronics Technology Co.,LTD",
        "address_1": "1/F Building A 39 Hongcao Road",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "08AF78": {
        "oui_hex": "08-AF-78",
        "organization": "Totus Solutions, Inc.",
        "address_1": "1505 Wallace Drive, Suite 102",
        "address_2": "Carrollton  TX  75006",
        "country": "US"
    },
    "C8C791": {
        "oui_hex": "C8-C7-91",
        "organization": "Zero1.tv GmbH",
        "address_1": "Heinrich-Roller-Str. 16 B",
        "address_2": "  Berlin  10405",
        "country": "DE"
    },
    "ECD925": {
        "oui_hex": "EC-D9-25",
        "organization": "RAMI",
        "address_1": "7 RUE RAOUL FOLLEREAU",
        "address_2": "BUSSY ST GEORGES    77600",
        "country": "FR"
    },
    "1C9492": {
        "oui_hex": "1C-94-92",
        "organization": "RUAG Schweiz AG",
        "address_1": "RUAG Defence",
        "address_2": "Hombrechtikon  ZH  8634",
        "country": "CH"
    },
    "B889CA": {
        "oui_hex": "B8-89-CA",
        "organization": "ILJIN ELECTRIC Co., Ltd.",
        "address_1": "112-83, Annyeong-dong",
        "address_2": "Hwaseong  Gyeonggi-do  445-380",
        "country": "KR"
    },
    "64F50E": {
        "oui_hex": "64-F5-0E",
        "organization": "Kinion Technology Company Limited",
        "address_1": "ng Kon107A, 1/F, Enterprise Place,",
        "address_2": "",
        "country": "HK"
    },
    "D04CC1": {
        "oui_hex": "D0-4C-C1",
        "organization": "SINTRONES Technology Corp.",
        "address_1": "14F.-3, No.736, Zhongzheng Rd., Zhonghe Dist., New Taipei City 235, Taiwan (R.O.C.)",
        "address_2": "Taipei  N/A  235",
        "country": "TW"
    },
    "503F56": {
        "oui_hex": "50-3F-56",
        "organization": "Syncmold Enterprise Corp",
        "address_1": "9F., No.168, Jiankang Rd., Zhonghe Dist.",
        "address_2": "Xinbei City    235",
        "country": "US"
    },
    "8CEEC6": {
        "oui_hex": "8C-EE-C6",
        "organization": "Precepscion Pty. Ltd.",
        "address_1": "Level 10",
        "address_2": "Melbourne  Victoria  3000",
        "country": "AU"
    },
    "101248": {
        "oui_hex": "10-12-48",
        "organization": "ITG, Inc.",
        "address_1": "YASUHARA BLDG 302, 1-42-6, ITABASHI,",
        "address_2": "ITABASHI-KU  TOKYO  173-0004",
        "country": "US"
    },
    "1848D8": {
        "oui_hex": "18-48-D8",
        "organization": "Fastback Networks",
        "address_1": "2480 N 1st Street",
        "address_2": "San Jose  California  95131",
        "country": "US"
    },
    "F0D3E7": {
        "oui_hex": "F0-D3-E7",
        "organization": "Sensometrix SA",
        "address_1": "Rue Albert Richard 2",
        "address_2": "Geneva  GE  1201",
        "country": "CH"
    },
    "B01266": {
        "oui_hex": "B0-12-66",
        "organization": "Futaba-Kikaku",
        "address_1": "2-17-20-302 Yanaka",
        "address_2": "Taito-ku  Tokyo  110-0001",
        "country": "JP"
    },
    "172030": {
        "oui_hex": "17-20-30",
        "organization": "2-17-20-302 Yanaka",
        "address_1": "JP",
        "address_2": "",
        "country": ""
    },
    "7CC8D0": {
        "oui_hex": "7C-C8-D0",
        "organization": "TIANJIN YAAN TECHNOLOGY CO., LTD.",
        "address_1": "No.8 Ziyuan Road,Huayuan Industrial Zone",
        "address_2": "  Tianjin  300384",
        "country": "CN"
    },
    "88E917": {
        "oui_hex": "88-E9-17",
        "organization": "Tamaggo",
        "address_1": "2001 McGill College",
        "address_2": "Montreal  Quebec  H3A 3L3",
        "country": "CA"
    },
    "88615A": {
        "oui_hex": "88-61-5A",
        "organization": "Siano Mobile Silicon Ltd.",
        "address_1": "P.O. Box 8684",
        "address_2": "Netanya    42504",
        "country": "IL"
    },
    "70E24C": {
        "oui_hex": "70-E2-4C",
        "organization": "SAE IT-systems GmbH & Co. KG",
        "address_1": "Im Gewerbegebiet Pesch 14",
        "address_2": "Köln  NRW  50767",
        "country": "DE"
    },
    "00FD4C": {
        "oui_hex": "00-FD-4C",
        "organization": "NEVATEC",
        "address_1": "Lindaraja 2",
        "address_2": "Granada    18009",
        "country": "ES"
    },
    "144319": {
        "oui_hex": "14-43-19",
        "organization": "Creative&Link Technology Limited",
        "address_1": " ROOM 704 HONG JIN GE BLD. NO.3018,YANHE SOUTH ROAD",
        "address_2": "Shenzhen  Guangdong  518002",
        "country": "US"
    },
    "D8AF3B": {
        "oui_hex": "D8-AF-3B",
        "organization": "Hangzhou Bigbright Integrated communications system Co.,Ltd",
        "address_1": "The 6floor ,Building1,No.1418-41,Moganshan Road",
        "address_2": "Hangzhou  Zhejiang  310015",
        "country": "CN"
    },
    "6032F0": {
        "oui_hex": "60-32-F0",
        "organization": "Mplus technology",
        "address_1": "#201  Gayang Dong, Gangsea Gu",
        "address_2": "Seoul    157-793",
        "country": "KR"
    },
    "2829D9": {
        "oui_hex": "28-29-D9",
        "organization": "GlobalBeiMing technology (Beijing)Co. Ltd",
        "address_1": "Beijing  Chaoyang District 8 Guanghua Road A seat 320 rooms",
        "address_2": "  Beijing   100026",
        "country": "CN"
    },
    "1CC316": {
        "oui_hex": "1C-C3-16",
        "organization": "MileSight Technology Co., Ltd.",
        "address_1": "202-2,No.21 Wanghai Road, 2nd Software Park",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "6815D3": {
        "oui_hex": "68-15-D3",
        "organization": "Zaklady Elektroniki i Mechaniki Precyzyjnej R&G S.A.",
        "address_1": "ul. Traugutta 7",
        "address_2": "Mielec    39-300",
        "country": "PL"
    },
    "10F3DB": {
        "oui_hex": "10-F3-DB",
        "organization": "Gridco Systems, Inc.",
        "address_1": "10-L Commerice Way",
        "address_2": "Woburn  MA   01801",
        "country": "US"
    },
    "305D38": {
        "oui_hex": "30-5D-38",
        "organization": "Beissbarth",
        "address_1": "Hanauer Str. 101",
        "address_2": "Muenchen    80993",
        "country": "DE"
    },
    "60D2B9": {
        "oui_hex": "60-D2-B9",
        "organization": "REALAND BIO CO., LTD.",
        "address_1": "Room 201A, N.set, Jinshan Bd., No.248 Wushan Rd., Tianhe District",
        "address_2": "Guangzhou  Guangdong  510630",
        "country": "CN"
    },
    "30FD11": {
        "oui_hex": "30-FD-11",
        "organization": "MACROTECH (USA) INC.",
        "address_1": "1799 BAYSHORE HIGHWAY",
        "address_2": "BURLINGAME  CA  94010",
        "country": "US"
    },
    "C4DA26": {
        "oui_hex": "C4-DA-26",
        "organization": "NOBLEX SA",
        "address_1": "Vicente Padín Moreira 97",
        "address_2": "Ushuaia   Tierra del fuego  9410",
        "country": "AR"
    },
    "7CC8AB": {
        "oui_hex": "7C-C8-AB",
        "organization": "Acro Associates, Inc.",
        "address_1": "1990 Olivera Rd.",
        "address_2": "Concord  CA  94520",
        "country": "US"
    },
    "601929": {
        "oui_hex": "60-19-29",
        "organization": "VOLTRONIC POWER TECHNOLOGY(SHENZHEN) CORP.",
        "address_1": "1-4F,Building 5,YuSheng Industrial Park,No.467,Section Xixiang,National Highway 107,Xixiang,Bao An District,Shenzhen,China",
        "address_2": "Shenzhen  Shenzhen  518000",
        "country": "CN"
    },
    "48B253": {
        "oui_hex": "48-B2-53",
        "organization": "Marketaxess Corporation",
        "address_1": "299 Park Avenue",
        "address_2": "New York  NY  10171",
        "country": "US"
    },
    "74943D": {
        "oui_hex": "74-94-3D",
        "organization": "AgJunction",
        "address_1": "8444 N. 90th St",
        "address_2": "Scottsdale  AZ  85258",
        "country": "US"
    },
    "58CF4B": {
        "oui_hex": "58-CF-4B",
        "organization": "Lufkin Industries",
        "address_1": "811 Willow Oak Drive",
        "address_2": "Missouri City  Texas  77489",
        "country": "US"
    },
    "68B43A": {
        "oui_hex": "68-B4-3A",
        "organization": "WaterFurnace International, Inc.",
        "address_1": "9000 Conservation Way",
        "address_2": "Fort Wayne  IN  46809",
        "country": "US"
    },
    "4C7897": {
        "oui_hex": "4C-78-97",
        "organization": "Arrowhead Alarm Products Ltd",
        "address_1": "344B Rosedale Road",
        "address_2": "Auckland  Auckland  0751",
        "country": "NZ"
    },
    "44E8A5": {
        "oui_hex": "44-E8-A5",
        "organization": "Myreka Technologies Sdn. Bhd.",
        "address_1": "2-13, JALAN MAYANG PASIR 1,",
        "address_2": "Bayan Baru  Penang  11950",
        "country": "MY"
    },
    "D8AFF1": {
        "oui_hex": "D8-AF-F1",
        "organization": "Panasonic Appliances Company",
        "address_1": "2-3-1-2 Noji-higashi",
        "address_2": "Kusatsu City  Shiga  525-8555",
        "country": "JP"
    },
    "2C6289": {
        "oui_hex": "2C-62-89",
        "organization": "Regenersis (Glenrothes) Ltd",
        "address_1": "1 James Watt Avenue",
        "address_2": "Glenrothes  Fife  KY7 4UA",
        "country": "GB"
    },
    "58ECE1": {
        "oui_hex": "58-EC-E1",
        "organization": "Newport Corporation",
        "address_1": "1791 Deere Ave.",
        "address_2": "Irvine  California  92606",
        "country": "US"
    },
    "4C09B4": {
        "oui_hex": "4C-09-B4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "60D1AA": {
        "oui_hex": "60-D1-AA",
        "organization": "Vishal Telecommunications Pvt Ltd",
        "address_1": "25 Sitaram Building Dr D N Road",
        "address_2": "Mumbai  Maharastra  400001",
        "country": "IN"
    },
    "709BA5": {
        "oui_hex": "70-9B-A5",
        "organization": "Shenzhen Y&D Electronics Co.,LTD.",
        "address_1": "D zone3F,Shenzhen Academy of Aerospace Technology,Hi-Tech Park,south 10th Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F45433": {
        "oui_hex": "F4-54-33",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "B48910": {
        "oui_hex": "B4-89-10",
        "organization": "Coster T.E. S.P.A.",
        "address_1": "Via San Giovanni Battista De La Salle 4/a",
        "address_2": "Milano  MI  20132",
        "country": "IT"
    },
    "B0C83F": {
        "oui_hex": "B0-C8-3F",
        "organization": "Jiangsu Cynray IOT Co., Ltd.",
        "address_1": "Building D1, 1 Zidong road, Qixia district",
        "address_2": "Nanjing  Jiangsu  210000",
        "country": "CN"
    },
    "3CF392": {
        "oui_hex": "3C-F3-92",
        "organization": "Virtualtek. Co. Ltd",
        "address_1": "12F, ShinhanDm Bldg.,",
        "address_2": "  Seoul  121-708",
        "country": "KR"
    },
    "B482C5": {
        "oui_hex": "B4-82-C5",
        "organization": "Relay2, Inc.",
        "address_1": "1525 McCarthy Blvd.,",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "985E1B": {
        "oui_hex": "98-5E-1B",
        "organization": "ConversDigital Co., Ltd.",
        "address_1": "5308 5th Bldg., Dong Seoul Univ.",
        "address_2": "Seongnam  Gyeonggi  461714",
        "country": "KR"
    },
    "D48CB5": {
        "oui_hex": "D4-8C-B5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "909DE0": {
        "oui_hex": "90-9D-E0",
        "organization": "Newland Design + Assoc. Inc.",
        "address_1": "3186-G Airway Ave.",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "149FE8": {
        "oui_hex": "14-9F-E8",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,Torch Hi-tech Industry Development Zone",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "BCD940": {
        "oui_hex": "BC-D9-40",
        "organization": "ASR Co,.Ltd.",
        "address_1": "1-3-1 Sotokanda Chiyoda-ku",
        "address_2": "Tokyo    101-0021",
        "country": "JP"
    },
    "049C62": {
        "oui_hex": "04-9C-62",
        "organization": "BMT Medical Technology s.r.o.",
        "address_1": "Cejl 50",
        "address_2": "Brno    65660",
        "country": "CZ"
    },
    "0C2A69": {
        "oui_hex": "0C-2A-69",
        "organization": "electric imp, incorporated",
        "address_1": "5050 El Camino Real, Ste 221",
        "address_2": "Los Altos  California  94022",
        "country": "US"
    },
    "C455C2": {
        "oui_hex": "C4-55-C2",
        "organization": "Bach-Simpson",
        "address_1": "109 Meg Drive",
        "address_2": "London  Ontario  N6E3Z7",
        "country": "CA"
    },
    "00E8AB": {
        "oui_hex": "00-E8-AB",
        "organization": "Meggitt Training Systems, Inc.",
        "address_1": "296 Brogdon Rd",
        "address_2": "Suwanee  GA  30024",
        "country": "US"
    },
    "B4218A": {
        "oui_hex": "B4-21-8A",
        "organization": "Dog Hunter LLC",
        "address_1": "8 Faneuil Hall SQ",
        "address_2": "Boston  MA  02109",
        "country": "US"
    },
    "B4A4B5": {
        "oui_hex": "B4-A4-B5",
        "organization": "Zen Eye Co.,Ltd",
        "address_1": "#401, 157-5 Chunui-dong",
        "address_2": "Bucheon-si  Gyeonggi-do  420-859",
        "country": "KR"
    },
    "DC37D2": {
        "oui_hex": "DC-37-D2",
        "organization": "Hunan HKT Electronic Technology Co., Ltd",
        "address_1": "Room 428,4F,Hunan Environmental Science and Technology Committee Building,No 18 South of Wanjiali Road,Yuhua District,Changsha",
        "address_2": "Changsha  Hunan  410007",
        "country": "CN"
    },
    "407074": {
        "oui_hex": "40-70-74",
        "organization": "Life Technology (China) Co., Ltd",
        "address_1": "No.1, 2F, Nanshan Digital Culture Industrial base (East Tower  Podium) 10128 Shennan Blvd, Nanshan Dist.",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "20F002": {
        "oui_hex": "20-F0-02",
        "organization": "MTData Developments Pty. Ltd.",
        "address_1": "20 Miles Street",
        "address_2": "Mulgrave  Victoria  3170",
        "country": "AU"
    },
    "388AB7": {
        "oui_hex": "38-8A-B7",
        "organization": "ITC Networks",
        "address_1": "3F Daiwa Shibaura Bldg",
        "address_2": "Tokyo    105-0023",
        "country": "JP"
    },
    "BCC23A": {
        "oui_hex": "BC-C2-3A",
        "organization": "Thomson Video Networks",
        "address_1": "6, rue du Clos Courtel",
        "address_2": "Cesson Sevigne    35510",
        "country": "FR"
    },
    "1CF4CA": {
        "oui_hex": "1C-F4-CA",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "ACC2EC": {
        "oui_hex": "AC-C2-EC",
        "organization": "CLT INT'L IND. CORP.",
        "address_1": "11F-2, NO.1, ZHANQIAN",
        "address_2": "MIAOLI    36043",
        "country": "TW"
    },
    "A865B2": {
        "oui_hex": "A8-65-B2",
        "organization": "DONGGUAN YISHANG ELECTRONIC TECHNOLOGY CO., LIMITED",
        "address_1": "3rd floor, B# Building ,Houdefu Logistics Park,Qingshuiao,",
        "address_2": "Dongguan  Guangdong  523062",
        "country": "CN"
    },
    "E8D0FA": {
        "oui_hex": "E8-D0-FA",
        "organization": "MKS Instruments Deutschland GmbH",
        "address_1": "Schatzbogen 43",
        "address_2": "Munich    81829",
        "country": "DE"
    },
    "98262A": {
        "oui_hex": "98-26-2A",
        "organization": "Applied Research Associates, Inc",
        "address_1": "4300 San Mateo Boulevard NE",
        "address_2": "Albuquerque  NM  87110",
        "country": "US"
    },
    "3C9174": {
        "oui_hex": "3C-91-74",
        "organization": "ALONG COMMUNICATION TECHNOLOGY",
        "address_1": "1301, Zhenye International Business Center,",
        "address_2": "Shenzhen  Guandong  518000",
        "country": "CN"
    },
    "ACEE3B": {
        "oui_hex": "AC-EE-3B",
        "organization": "6harmonics Inc",
        "address_1": "21 Concourse Gate - Suite 10",
        "address_2": "Ottawa  Ontario  K2E 7S4",
        "country": "CA"
    },
    "1C6BCA": {
        "oui_hex": "1C-6B-CA",
        "organization": "Mitsunami Co., Ltd.",
        "address_1": "2-30-11, Nishi-gotanda, Shinagawa-ku",
        "address_2": "Tokyo    141-0031",
        "country": "JP"
    },
    "642400": {
        "oui_hex": "64-24-00",
        "organization": "Xorcom Ltd.",
        "address_1": "Teradyon Industrial Park",
        "address_2": "D.N Misgav    20179",
        "country": "IL"
    },
    "E83EFB": {
        "oui_hex": "E8-3E-FB",
        "organization": "GEODESIC LTD.",
        "address_1": "18,10TH CROSS, MAYURA STREET",
        "address_2": "BANGALORE  KARNATAKA  560094",
        "country": "IN"
    },
    "ECD19A": {
        "oui_hex": "EC-D1-9A",
        "organization": "Zhuhai Liming Industries Co., Ltd",
        "address_1": "No.6 Xinqing Rd,Xinqing Hi-Tech Industrial Park",
        "address_2": "Zhuhai  Guangdong  519100",
        "country": "CN"
    },
    "348137": {
        "oui_hex": "34-81-37",
        "organization": "UNICARD SA",
        "address_1": "UL.WADOWICKA 12",
        "address_2": "KRAKOW  woj. malopolskie  30-415",
        "country": "PL"
    },
    "38B12D": {
        "oui_hex": "38-B1-2D",
        "organization": "Sonotronic Nagel GmbH",
        "address_1": "Becker-Goering-Str. 17-25",
        "address_2": "Karlsbad    76307",
        "country": "DE"
    },
    "549D85": {
        "oui_hex": "54-9D-85",
        "organization": "EnerAccess inc",
        "address_1": "3154 Le Corbusier Blvd",
        "address_2": "Laval  Quebec  H7L 4S8",
        "country": "CA"
    },
    "B0750C": {
        "oui_hex": "B0-75-0C",
        "organization": "QA Cafe",
        "address_1": "33 Jewell Court",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "B4E1EB": {
        "oui_hex": "B4-E1-EB",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "3C363D": {
        "oui_hex": "3C-36-3D",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "808698": {
        "oui_hex": "80-86-98",
        "organization": "Netronics Technologies Inc.",
        "address_1": "600-15 Allstate Parkway",
        "address_2": "Markham  Ontario  L3R 5B4",
        "country": "CA"
    },
    "9CE10E": {
        "oui_hex": "9C-E1-0E",
        "organization": "NCTech Ltd",
        "address_1": "20-22 Braid Road",
        "address_2": "Edinburgh    EH10 6AD",
        "country": "GB"
    },
    "A06D09": {
        "oui_hex": "A0-6D-09",
        "organization": "Intelcan Technosystems Inc.",
        "address_1": "5490  Boul Thimens",
        "address_2": "Saint-Laurent  Quebec  H4R2K9",
        "country": "CA"
    },
    "60F3DA": {
        "oui_hex": "60-F3-DA",
        "organization": "Logic Way GmbH",
        "address_1": "Hagenower Str. 73",
        "address_2": "Schwerin  Mecklenburg-West Pomerania  19061",
        "country": "DE"
    },
    "FC5090": {
        "oui_hex": "FC-50-90",
        "organization": "SIMEX Sp. z o.o.",
        "address_1": "ul. Wielopole 7",
        "address_2": "Gdañsk  pomorskie  80-556",
        "country": "PL"
    },
    "60B982": {
        "oui_hex": "60-B9-82",
        "organization": "RO.VE.R. Laboratories S.p.A.",
        "address_1": "Via Parini, 2",
        "address_2": "Sirmione  Brescia  25019",
        "country": "IT"
    },
    "B46238": {
        "oui_hex": "B4-62-38",
        "organization": "Exablox",
        "address_1": "365 San Antonio Road",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "C8BBD3": {
        "oui_hex": "C8-BB-D3",
        "organization": "Embrane",
        "address_1": "2350 Mission College Blvd., Ste 703",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "8C604F": {
        "oui_hex": "8C-60-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4B980": {
        "oui_hex": "A4-B9-80",
        "organization": "Parking BOXX Inc.",
        "address_1": "382 NE 191st St. #93984",
        "address_2": "Miami  FL  33179-3899",
        "country": "US"
    },
    "A47C14": {
        "oui_hex": "A4-7C-14",
        "organization": "ChargeStorm AB",
        "address_1": "Laxholmstorget 3",
        "address_2": "Norrköping    60221",
        "country": "SE"
    },
    "8020AF": {
        "oui_hex": "80-20-AF",
        "organization": "Trade FIDES, a.s.",
        "address_1": "Dornych 57",
        "address_2": "Brno    61700",
        "country": "CZ"
    },
    "2C750F": {
        "oui_hex": "2C-75-0F",
        "organization": "Shanghai Dongzhou-Lawton Communication Technology Co. Ltd.",
        "address_1": "NO.188,FengyeRoad,BaoshanDistrict",
        "address_2": "shanghai    200949",
        "country": "CN"
    },
    "5C5015": {
        "oui_hex": "5C-50-15",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "980284": {
        "oui_hex": "98-02-84",
        "organization": "Theobroma Systems GmbH",
        "address_1": "Gutheil-Schoder Gasse 17",
        "address_2": "Wien    1230",
        "country": "US"
    },
    "1CD40C": {
        "oui_hex": "1C-D4-0C",
        "organization": "Kriwan Industrie-Elektronik GmbH",
        "address_1": "Allmand 11",
        "address_2": "Forchtenberg  Baden-Würtemberg  D-74670",
        "country": "DE"
    },
    "002D76": {
        "oui_hex": "00-2D-76",
        "organization": "TITECH GmbH",
        "address_1": "Otto-Hahn-Str. 6",
        "address_2": "Muelheim-Kaerlich    56218",
        "country": "DE"
    },
    "F8DB4C": {
        "oui_hex": "F8-DB-4C",
        "organization": "PNY Technologies, INC.",
        "address_1": "100 Jefferson Road",
        "address_2": "Parsippany  New Jersey  07054",
        "country": "US"
    },
    "0C9D56": {
        "oui_hex": "0C-9D-56",
        "organization": "Consort Controls Ltd",
        "address_1": "13 Campion Terrace",
        "address_2": "Leamington Spa    CV32 4SU",
        "country": "GB"
    },
    "3CB87A": {
        "oui_hex": "3C-B8-7A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "AC1461": {
        "oui_hex": "AC-14-61",
        "organization": "ATAW  Co., Ltd.",
        "address_1": "Dongan-gu Pyeongchon-dong 126-1",
        "address_2": "Anyang-si  Gyeonggi-do  431-755",
        "country": "KR"
    },
    "E4C6E6": {
        "oui_hex": "E4-C6-E6",
        "organization": "Mophie, LLC",
        "address_1": "2850 Red Hill Ave.",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "502D1D": {
        "oui_hex": "50-2D-1D",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "F48E09": {
        "oui_hex": "F4-8E-09",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "5848C0": {
        "oui_hex": "58-48-C0",
        "organization": "COFLEC",
        "address_1": "Parc d'activités du moulin de Massy",
        "address_2": "MASSY    91300",
        "country": "FR"
    },
    "8C57FD": {
        "oui_hex": "8C-57-FD",
        "organization": "LVX Western",
        "address_1": "700 54th ave North",
        "address_2": "St. Cloud  MN  56303",
        "country": "US"
    },
    "54E63F": {
        "oui_hex": "54-E6-3F",
        "organization": "ShenZhen LingKeWeiEr Technology Co., Ltd.",
        "address_1": "Room 625, YiJing Building, MeiLin Rd., FuTian District",
        "address_2": "ShenZhen  GuandDong  518000",
        "country": "CN"
    },
    "20FABB": {
        "oui_hex": "20-FA-BB",
        "organization": "Cambridge Executive Limited",
        "address_1": "St John's Innovation Centre",
        "address_2": "Cambridge  Cambridgeshire  CB40WS",
        "country": "GB"
    },
    "141A51": {
        "oui_hex": "14-1A-51",
        "organization": "Treetech Sistemas Digitais",
        "address_1": "Praca Claudino Alves, 141",
        "address_2": "Atibaia  São Paulo  12940-800",
        "country": "BR"
    },
    "587FC8": {
        "oui_hex": "58-7F-C8",
        "organization": "S2M",
        "address_1": "2 rue des champs",
        "address_2": "Saint Marcel    27950",
        "country": "FR"
    },
    "200505": {
        "oui_hex": "20-05-05",
        "organization": "RADMAX COMMUNICATION PRIVATE LIMITED",
        "address_1": "F-24/34, IIND FLOOR, SECTOR-7",
        "address_2": "DELHI  DELHI  110085",
        "country": "IN"
    },
    "C035BD": {
        "oui_hex": "C0-35-BD",
        "organization": "Velocytech Aps",
        "address_1": "Automatikvej 1, 3rd floor",
        "address_2": "SOEBORG    2860",
        "country": "DK"
    },
    "287184": {
        "oui_hex": "28-71-84",
        "organization": "Spire Payments",
        "address_1": "Units 3 & 6 Milford Trading Estate",
        "address_2": "Salisbury  Wiltshire  SP1 2UD",
        "country": "GB"
    },
    "7CB03E": {
        "oui_hex": "7C-B0-3E",
        "organization": "OSRAM GmbH",
        "address_1": "Berliner Allee 65",
        "address_2": "Augsburg  Bayern  86136",
        "country": "DE"
    },
    "3C9F81": {
        "oui_hex": "3C-9F-81",
        "organization": "Shenzhen CATIC Bit Communications Technology Co.,Ltd",
        "address_1": "in  Nanshan District,Shenzhen Software park Road 10 in Room 202",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "445F7A": {
        "oui_hex": "44-5F-7A",
        "organization": "Shihlin Electric & Engineering Corp.",
        "address_1": "16F  NO.88,  SEC,  6,  CHUNG  SHAN  N.  RD., TAIPEI",
        "address_2": "HsinChu  HsinFun Shiang  304",
        "country": "TW"
    },
    "441319": {
        "oui_hex": "44-13-19",
        "organization": "WKK TECHNOLOGY LTD.",
        "address_1": "23/F., One Kowloon, No.1, Wang Yuen Street,",
        "address_2": "    852",
        "country": "HK"
    },
    "18B591": {
        "oui_hex": "18-B5-91",
        "organization": "I-Storm",
        "address_1": "Hogye-dong, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  431-080",
        "country": "KR"
    },
    "BC8B55": {
        "oui_hex": "BC-8B-55",
        "organization": "NPP ELIKS America Inc. DBA T&M Atlantic",
        "address_1": "175 SW 7th St Suite 1812",
        "address_2": "Miami  FL  33130",
        "country": "US"
    },
    "C0493D": {
        "oui_hex": "C0-49-3D",
        "organization": "MAITRISE TECHNOLOGIQUE",
        "address_1": "224 RUE DE LA SAINTE BAUME",
        "address_2": "SAINT MAXIMIN LA SAINTE BAUME  VAR  83470",
        "country": "FR"
    },
    "C84544": {
        "oui_hex": "C8-45-44",
        "organization": "Asia Pacific CIS (Wuxi) Co, Ltd",
        "address_1": "No 11, Xikun Road, Wuxi New District",
        "address_2": "Wuxi  Jiangsu  214028",
        "country": "CN"
    },
    "E0EF25": {
        "oui_hex": "E0-EF-25",
        "organization": "Lintes Technology Co., Ltd.",
        "address_1": "9F-1., No.150, Jian 1st Rd., Zhonghe Dist.,",
        "address_2": " New Taipei City     23511",
        "country": "TW"
    },
    "50ED94": {
        "oui_hex": "50-ED-94",
        "organization": "EGATEL SL",
        "address_1": "Parque Tecnologico de Galicia",
        "address_2": "Ourense    32901",
        "country": "ES"
    },
    "48A22D": {
        "oui_hex": "48-A2-2D",
        "organization": "Shenzhen Huaxuchang Telecom Technology Co.,Ltd",
        "address_1": "Room 501 Block B, Cyber Time Plaza",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "C86000": {
        "oui_hex": "C8-60-00",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "AC0DFE": {
        "oui_hex": "AC-0D-FE",
        "organization": "Ekon GmbH - myGEKKO",
        "address_1": "Rienzfeldstraße 30",
        "address_2": "Bruneck  Südtirol (BZ)  39031",
        "country": "IT"
    },
    "FC5B26": {
        "oui_hex": "FC-5B-26",
        "organization": "MikroBits",
        "address_1": "Jalan Petung 31 Papringan",
        "address_2": "Yogyakarta  DIY  55281",
        "country": "ID"
    },
    "40F407": {
        "oui_hex": "40-F4-07",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "B01C91": {
        "oui_hex": "B0-1C-91",
        "organization": "Elim Co",
        "address_1": "4F Gagu Plaza B/D 81-9, jeongja-dong, Jangan-gu,",
        "address_2": "Suwon city  Gyeonggi-Do  440-300",
        "country": "KR"
    },
    "04F17D": {
        "oui_hex": "04-F1-7D",
        "organization": "Tarana Wireless",
        "address_1": "2105 Martin Luther King Jr Way",
        "address_2": "Berkeley  CA  94704",
        "country": "US"
    },
    "844915": {
        "oui_hex": "84-49-15",
        "organization": "vArmour Networks, Inc.",
        "address_1": "4633 OLD IRONSIDES DR",
        "address_2": "SANTA CLARA  CA  95054-1807",
        "country": "US"
    },
    "2CBE97": {
        "oui_hex": "2C-BE-97",
        "organization": "Ingenieurbuero Bickele und Buehler GmbH",
        "address_1": "St.Poeltener Str. 70",
        "address_2": "Stuttgart  BW  70469",
        "country": "DE"
    },
    "70A66A": {
        "oui_hex": "70-A6-6A",
        "organization": "Prox Dynamics AS",
        "address_1": "Smedsvingen 4",
        "address_2": "Hvalstad  Akershus  1395",
        "country": "NO"
    },
    "DC3E51": {
        "oui_hex": "DC-3E-51",
        "organization": "Solberg & Andersen AS",
        "address_1": "Litleaasvegen 61",
        "address_2": "Bergen    5132",
        "country": "NO"
    },
    "900A3A": {
        "oui_hex": "90-0A-3A",
        "organization": "PSG Plastic Service GmbH",
        "address_1": "Pinaer Str. 12-16",
        "address_2": "Mannheim  BW  68309",
        "country": "DE"
    },
    "28CD1C": {
        "oui_hex": "28-CD-1C",
        "organization": "Espotel Oy",
        "address_1": "Kappelitie 6",
        "address_2": "Espoo  Espoo  FI-02200",
        "country": "FI"
    },
    "D443A8": {
        "oui_hex": "D4-43-A8",
        "organization": "Changzhou Haojie Electric Co., Ltd.",
        "address_1": "No. 158,",
        "address_2": "Changzhou  Jiangsu  213022",
        "country": "CN"
    },
    "BCE59F": {
        "oui_hex": "BC-E5-9F",
        "organization": "WATERWORLD Technology Co.,LTD",
        "address_1": "6 Floor,Block B,Digital Building,Garden City,No.1079,Nanhai Road,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "US"
    },
    "7041B7": {
        "oui_hex": "70-41-B7",
        "organization": "Edwards Lifesciences LLC",
        "address_1": "One Edwards Way",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "DCA8CF": {
        "oui_hex": "DC-A8-CF",
        "organization": "New Spin Golf, LLC.",
        "address_1": "1637 Burr Oak Drive",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "A849A5": {
        "oui_hex": "A8-49-A5",
        "organization": "Lisantech Co., Ltd.",
        "address_1": "1108, STX V-Tower  Gasan-dong",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "A05E6B": {
        "oui_hex": "A0-5E-6B",
        "organization": "MELPER Co., Ltd.",
        "address_1": "207, 2nd FL.,Wonhyo Bldg.,1365-22",
        "address_2": "SEOUL    137-863",
        "country": "KR"
    },
    "D878E5": {
        "oui_hex": "D8-78-E5",
        "organization": "KUHN SA",
        "address_1": "4, impasse des fabriques",
        "address_2": "SAVERNE    67700",
        "country": "FR"
    },
    "D824BD": {
        "oui_hex": "D8-24-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3497FB": {
        "oui_hex": "34-97-FB",
        "organization": "ADVANCED RF TECHNOLOGIES INC",
        "address_1": "3116 W Vanowen St",
        "address_2": "Burbank  California  91505",
        "country": "US"
    },
    "F03A55": {
        "oui_hex": "F0-3A-55",
        "organization": "Omega Elektronik AS",
        "address_1": "Ege Serbest Bolgesi",
        "address_2": "Izmir    35410",
        "country": "TR"
    },
    "98BC57": {
        "oui_hex": "98-BC-57",
        "organization": "SVA TECHNOLOGIES CO.LTD",
        "address_1": "5F No.192 Tinglin Road,",
        "address_2": "SHANGHAI    200233",
        "country": "CN"
    },
    "DC3C2E": {
        "oui_hex": "DC-3C-2E",
        "organization": "Manufacturing System Insights, Inc.",
        "address_1": "2550 Ninth St.",
        "address_2": "Berkely  CA  94710",
        "country": "US"
    },
    "F83553": {
        "oui_hex": "F8-35-53",
        "organization": "Magenta Research Ltd.",
        "address_1": "128 Litchfield Road",
        "address_2": "New Milford  CT  06776",
        "country": "US"
    },
    "F4044C": {
        "oui_hex": "F4-04-4C",
        "organization": "ValenceTech Limited",
        "address_1": "Unit 1, 20/F., APEC Plaza",
        "address_2": "HONG KONG    NIL",
        "country": "CN"
    },
    "C467B5": {
        "oui_hex": "C4-67-B5",
        "organization": "Libratone A/S",
        "address_1": "Marielundvej 43 A",
        "address_2": "2730 HERLEV",
        "country": "DK"
    },
    "4C3910": {
        "oui_hex": "4C-39-10",
        "organization": "Newtek Electronics co., Ltd.",
        "address_1": "Byucksan-Sunyoung Technopia 1004,",
        "address_2": "Uiwang-City  Kyunggi-Do  437-821",
        "country": "KR"
    },
    "903AA0": {
        "oui_hex": "90-3A-A0",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "B06CBF": {
        "oui_hex": "B0-6C-BF",
        "organization": "3ality Digital Systems GmbH",
        "address_1": "Gut Mergenthau 1",
        "address_2": "Kissing  Bayern  86438",
        "country": "DE"
    },
    "54D0ED": {
        "oui_hex": "54-D0-ED",
        "organization": "AXIM Communications",
        "address_1": "1F., No. 5, Aly. 12, Ln. 15, Sec. 6, Sinyi Rd., Sinyi Dist.,",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "843611": {
        "oui_hex": "84-36-11",
        "organization": "hyungseul publishing networks",
        "address_1": "526-4, paju bookcity, munbal-li, gyoha-eup",
        "address_2": "paju-si  Gyeonggi-do  413-832",
        "country": "KR"
    },
    "3440B5": {
        "oui_hex": "34-40-B5",
        "organization": "IBM",
        "address_1": "3039 E Cornwallis Rd",
        "address_2": "Research Triangle Park  NC  27709",
        "country": "US"
    },
    "D4D748": {
        "oui_hex": "D4-D7-48",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "344F69": {
        "oui_hex": "34-4F-69",
        "organization": "EKINOPS SAS",
        "address_1": "3, Rue Blaise Pascal",
        "address_2": "LANNION  FRANCE  22300",
        "country": "FR"
    },
    "F8313E": {
        "oui_hex": "F8-31-3E",
        "organization": "endeavour GmbH",
        "address_1": "Max-Planck-Str. 04",
        "address_2": "Vreden  NRW  48691",
        "country": "DE"
    },
    "143605": {
        "oui_hex": "14-36-05",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "C81AFE": {
        "oui_hex": "C8-1A-FE",
        "organization": "DLOGIC GmbH",
        "address_1": "Rathausstrasse 14",
        "address_2": "Baar  ZG  6341",
        "country": "CH"
    },
    "EC63E5": {
        "oui_hex": "EC-63-E5",
        "organization": "ePBoard Design LLC",
        "address_1": "4065 E. La Palma Ave.",
        "address_2": "Anaheim  California  92807",
        "country": "US"
    },
    "94DB49": {
        "oui_hex": "94-DB-49",
        "organization": "SITCORP",
        "address_1": "7 RUE CADET",
        "address_2": "PARIS    75015",
        "country": "FR"
    },
    "F0620D": {
        "oui_hex": "F0-62-0D",
        "organization": "Shenzhen Egreat Tech Corp.,Ltd",
        "address_1": "4F,1Building,Chuangye Industrial park",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "2C67FB": {
        "oui_hex": "2C-67-FB",
        "organization": "ShenZhen Zhengjili Electronics Co., LTD",
        "address_1": "The Longhua Town Shenzhen City Streets huaning three house Science Park Road Chiayi Source fifth floor",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "3CE5B4": {
        "oui_hex": "3C-E5-B4",
        "organization": "KIDASEN INDUSTRIA E COMERCIO DE ANTENAS LTDA",
        "address_1": "AV SINCLER SAMBATTI, 1945",
        "address_2": "MARINGA  PARANA  87055-020",
        "country": "BR"
    },
    "08D09F": {
        "oui_hex": "08-D0-9F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "644BF0": {
        "oui_hex": "64-4B-F0",
        "organization": "CalDigit, Inc",
        "address_1": "1941 Miraloma Ave #B",
        "address_2": "Placentia  CA  92870",
        "country": "US"
    },
    "64ED62": {
        "oui_hex": "64-ED-62",
        "organization": "WOORI SYSTEMS Co., Ltd",
        "address_1": "101Ho #42-9, Jeongja-dong, Pundang-gu",
        "address_2": "Sungnam-si  Kyunggi-do  463-848",
        "country": "KR"
    },
    "2C002C": {
        "oui_hex": "2C-00-2C",
        "organization": "UNOWHY",
        "address_1": "11, rue Tronchet",
        "address_2": "Paris    75008",
        "country": "US"
    },
    "5CC9D3": {
        "oui_hex": "5C-C9-D3",
        "organization": "PALLADIUM ENERGY ELETRONICA DA AMAZONIA LTDA",
        "address_1": "AVENIDA BURITI, 4285",
        "address_2": "MANAUS  AMAZONAS  69075-000",
        "country": "BR"
    },
    "C87CBC": {
        "oui_hex": "C8-7C-BC",
        "organization": "Valink Co., Ltd.",
        "address_1": "1F Dongwon Bldg. 90, Dangsan-Dong 3-Ga Youngdungpo-Gu",
        "address_2": "Seoul    150-803",
        "country": "KR"
    },
    "B81413": {
        "oui_hex": "B8-14-13",
        "organization": "Keen High Holding(HK) Ltd.",
        "address_1": "25th Floor, In-long Development Centre, No.6025 Shennan Ave",
        "address_2": "Shenzhen  Guangdong   518040",
        "country": "CN"
    },
    "B4944E": {
        "oui_hex": "B4-94-4E",
        "organization": "WeTelecom Co., Ltd.",
        "address_1": "The'O Plus #915",
        "address_2": "Gunpo-si  Kyunggi-do  435-805",
        "country": "KR"
    },
    "E00B28": {
        "oui_hex": "E0-0B-28",
        "organization": "Inovonics",
        "address_1": "315 CTC Blvd",
        "address_2": "Louisville  CO  80027",
        "country": "US"
    },
    "48022A": {
        "oui_hex": "48-02-2A",
        "organization": "B-Link Electronic Limited",
        "address_1": "NO 268,FuQian Rd, JuTang Community,GuanLan town BaoAn district,ShenZhen, 518110,China",
        "address_2": "Shen Zhen  Guang Dong  518110",
        "country": "CN"
    },
    "18E80F": {
        "oui_hex": "18-E8-0F",
        "organization": "Viking Electronics Inc.",
        "address_1": "1531 Industrial St",
        "address_2": "Hudson  WI  54016",
        "country": "US"
    },
    "CC6BF1": {
        "oui_hex": "CC-6B-F1",
        "organization": "Sound Masking Inc.",
        "address_1": "47 - 23 - Glamis Drive Sw",
        "address_2": "Calgary  Alberta  T3E 6S3",
        "country": "CA"
    },
    "2C9717": {
        "oui_hex": "2C-97-17",
        "organization": "I.C.Y. B.V.",
        "address_1": "Houtsaachmole 35",
        "address_2": "Lemmer  Friesland  8531 WC",
        "country": "NL"
    },
    "2C3F38": {
        "oui_hex": "2C-3F-38",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4050E0": {
        "oui_hex": "40-50-E0",
        "organization": "Milton Security Group LLC",
        "address_1": "111 North Harbor Blvd",
        "address_2": "Fullerton  CA  92832",
        "country": "US"
    },
    "70CA9B": {
        "oui_hex": "70-CA-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A078BA": {
        "oui_hex": "A0-78-BA",
        "organization": "Pantech Co., Ltd.",
        "address_1": "110-1 Ongjeong-Ri, Tongjin-Eup",
        "address_2": "Gimpo-Si  Gyounggi-Do  415-865",
        "country": "KR"
    },
    "68BC0C": {
        "oui_hex": "68-BC-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "345B11": {
        "oui_hex": "34-5B-11",
        "organization": "EVI HEAT AB",
        "address_1": "Box 55",
        "address_2": "Kungsaengen    196 22",
        "country": "SE"
    },
    "78BAD0": {
        "oui_hex": "78-BA-D0",
        "organization": "Shinybow Technology Co. Ltd.",
        "address_1": "9Fl.,No.63,Ju Guang Rd.,Chung Ho Dist.",
        "address_2": "New Taipei    235",
        "country": "TW"
    },
    "24E6BA": {
        "oui_hex": "24-E6-BA",
        "organization": "JSC Zavod im. Kozitsky",
        "address_1": "Bld. 70, 5th line, V.O,",
        "address_2": "St.-Petersburg    199048",
        "country": "RU"
    },
    "CCA374": {
        "oui_hex": "CC-A3-74",
        "organization": "Guangdong Guanglian Electronic Technology Co.Ltd",
        "address_1": "B338,Block13,No.232 Waihuandonglu Road,High Education Mega Center",
        "address_2": "Guangzhou  Guangdong  510006",
        "country": "CN"
    },
    "58677F": {
        "oui_hex": "58-67-7F",
        "organization": "Clare Controls Inc.",
        "address_1": "7519 Pennsylvania Ave",
        "address_2": "Sarasota  FL  34243",
        "country": "US"
    },
    "0C5A19": {
        "oui_hex": "0C-5A-19",
        "organization": "Axtion Sdn Bhd",
        "address_1": "A13-07, Subang Avenue Serviced Suites",
        "address_2": "Subang Jaya  Selangor  47500",
        "country": "MY"
    },
    "A8BD1A": {
        "oui_hex": "A8-BD-1A",
        "organization": "Honey Bee (Hong Kong) Limited",
        "address_1": "Flat L, 12/F., Phase 4, Kwun Tong Industrial Ctr.,",
        "address_2": "",
        "country": "HK"
    },
    "248707": {
        "oui_hex": "24-87-07",
        "organization": "SEnergy Corporation",
        "address_1": "Koizumi Bldg. 3F, 1-38-18",
        "address_2": "Yokohama city  Kanagawa Pref.  224-0003",
        "country": "JP"
    },
    "C4C19F": {
        "oui_hex": "C4-C1-9F",
        "organization": "National Oilwell Varco Instrumentation, Monitoring, and Optimization (NOV IMO)",
        "address_1": "1200 Cypress Creek Rd.",
        "address_2": "Cedar Park  TX  78613",
        "country": "US"
    },
    "000830": {
        "oui_hex": "00-08-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C4EEAE": {
        "oui_hex": "C4-EE-AE",
        "organization": "VSS Monitoring",
        "address_1": "1850 Gateway Dr, Suite 500",
        "address_2": "San Mateo  CA  94404",
        "country": "US"
    },
    "F8D3A9": {
        "oui_hex": "F8-D3-A9",
        "organization": "AXAN Networks",
        "address_1": "2F Myungjin-Bldg Daechi-Dong Gangnam-Gu",
        "address_2": "Seoul     135-845",
        "country": "KR"
    },
    "BC779F": {
        "oui_hex": "BC-77-9F",
        "organization": "SBM Co., Ltd.",
        "address_1": "Hyunwoo Bldg 206, Anyang7-Dong",
        "address_2": "Anyang  Gyeonggi-Do  430-817",
        "country": "KR"
    },
    "406AAB": {
        "oui_hex": "40-6A-AB",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "9CA3BA": {
        "oui_hex": "9C-A3-BA",
        "organization": "SAKURA Internet Inc.",
        "address_1": "7-20-1 Nishi-shinjuku",
        "address_2": "Shinjuku-ku  Tokyo  1600023",
        "country": "JP"
    },
    "8C8A6E": {
        "oui_hex": "8C-8A-6E",
        "organization": "ESTUN AUTOMATION TECHNOLOY CO., LTD",
        "address_1": "16,Shuige Road",
        "address_2": "Nanjing  Jiangsu  211106",
        "country": "CN"
    },
    "988217": {
        "oui_hex": "98-82-17",
        "organization": "Disruptive Ltd",
        "address_1": "Windsor House",
        "address_2": "High Wycombe  Buckinghamshire  HP12 3NR",
        "country": "GB"
    },
    "9C5C8D": {
        "oui_hex": "9C-5C-8D",
        "organization": "FIREMAX INDÚSTRIA E COMÉRCIO DE PRODUTOS ELETRÔNICOS  LTDA",
        "address_1": "R: Vicente de Felice, 589 -  Jd.Ouro Verde",
        "address_2": "Limeira  São Paulo  13482-075",
        "country": "BR"
    },
    "D4206D": {
        "oui_hex": "D4-20-6D",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "7C1E52": {
        "oui_hex": "7C-1E-52",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "DCB4C4": {
        "oui_hex": "DC-B4-C4",
        "organization": "Microsoft XCG",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "ACCB09": {
        "oui_hex": "AC-CB-09",
        "organization": "Hefcom Metering (Pty) Ltd",
        "address_1": "PO Box 10770",
        "address_2": "Centurion  Gauteng  0046",
        "country": "ZA"
    },
    "1866E3": {
        "oui_hex": "18-66-E3",
        "organization": "Veros Systems, Inc.",
        "address_1": "PO Box 10534",
        "address_2": "College Station  Texas  77842",
        "country": "US"
    },
    "74FDA0": {
        "oui_hex": "74-FD-A0",
        "organization": "Compupal (Group) Corporation",
        "address_1": "No.1555 Jiashan Avenue",
        "address_2": "Jiashan  Zhejiang  314113",
        "country": "CN"
    },
    "CCB8F1": {
        "oui_hex": "CC-B8-F1",
        "organization": "EAGLE KINGDOM TECHNOLOGIES LIMITED",
        "address_1": "FLAT/ RM B 26/F TWO CHINACHEM PLAZA 68 CONNAUGHT ROAD CENTRAL HK",
        "address_2": "",
        "country": "HK"
    },
    "A429B7": {
        "oui_hex": "A4-29-B7",
        "organization": "bluesky",
        "address_1": "Rm1410 Tower A,Chengjian plaza,NO.18 beitaipingzhuang Road,Haidian district,",
        "address_2": "Beijing    100088",
        "country": "CN"
    },
    "48F317": {
        "oui_hex": "48-F3-17",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "CCF8F0": {
        "oui_hex": "CC-F8-F0",
        "organization": "Xi'an HISU Multimedia Technology Co.,Ltd.",
        "address_1": "3 Floor , NO.1 Building , Modern Business Enterprise Centre (East) , NO.69, Jinye road , XiÂ¡Â¯an",
        "address_2": "Xi'an City  Shanxi Province  710075",
        "country": "CN"
    },
    "04888C": {
        "oui_hex": "04-88-8C",
        "organization": "Eifelwerk Butler Systeme GmbH",
        "address_1": "Eifelwerkstrasse 1",
        "address_2": "Malbergweich    54655",
        "country": "DE"
    },
    "D45AB2": {
        "oui_hex": "D4-5A-B2",
        "organization": "Galleon Systems",
        "address_1": "Unit 9, Fortnum Close",
        "address_2": "Birmingham  West Midlands  B33 0LG",
        "country": "GB"
    },
    "30DE86": {
        "oui_hex": "30-DE-86",
        "organization": "Cedac Software S.r.l.",
        "address_1": "Via Toscana, 3",
        "address_2": "Castiglione dei Pepoli  Bologna  40035",
        "country": "IT"
    },
    "18C451": {
        "oui_hex": "18-C4-51",
        "organization": "Tucson Embedded Systems",
        "address_1": "5620 North Kolb Road",
        "address_2": "Tucson  AZ  85750",
        "country": "US"
    },
    "704642": {
        "oui_hex": "70-46-42",
        "organization": "CHYNG HONG ELECTRONIC CO., LTD.",
        "address_1": "No.80, Lane 258, Sec. 3, Hansi W. Rd.,",
        "address_2": "Taichung    40647",
        "country": "TW"
    },
    "D41C1C": {
        "oui_hex": "D4-1C-1C",
        "organization": "RCF S.P.A.",
        "address_1": "Via Raffaello Sanzio 13",
        "address_2": "Reggio Emilia  Italy  42124",
        "country": "IT"
    },
    "58920D": {
        "oui_hex": "58-92-0D",
        "organization": "Kinetic Avionics Limited",
        "address_1": "Elstree Aerodrome",
        "address_2": "Hertfordshire    WD6 3AW",
        "country": "GB"
    },
    "AC02EF": {
        "oui_hex": "AC-02-EF",
        "organization": "Comsis",
        "address_1": "3 rue Broussais",
        "address_2": "Paris    75014",
        "country": "FR"
    },
    "B8B42E": {
        "oui_hex": "B8-B4-2E",
        "organization": "Gionee Communication Equipment Co,Ltd.ShenZhen",
        "address_1": "21/F Times Technology Building, 7028 Shennan Road, Futian District,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "443EB2": {
        "oui_hex": "44-3E-B2",
        "organization": "DEOTRON Co., LTD.",
        "address_1": "506, Dain Bldg",
        "address_2": "Ansan  Kyonggi-do  425-856",
        "country": "KR"
    },
    "D059C3": {
        "oui_hex": "D0-59-C3",
        "organization": "CeraMicro Technology Corporation",
        "address_1": "4F, No. 16-1, Sec. 6, Mingcyuan East Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "182C91": {
        "oui_hex": "18-2C-91",
        "organization": "Concept Development, Inc.",
        "address_1": "1881 Langley Avenue",
        "address_2": "Irvine  CA  92614-5623",
        "country": "US"
    },
    "FC1794": {
        "oui_hex": "FC-17-94",
        "organization": "InterCreative Co., Ltd",
        "address_1": "897-6, HoGye-Dong, DongAn-Gu,",
        "address_2": "AnYang-Si,  GyeongGi-Do,  431-836",
        "country": "KR"
    },
    "B40B7A": {
        "oui_hex": "B4-0B-7A",
        "organization": "Brusa Elektronik AG",
        "address_1": "Neudorf 14",
        "address_2": "Sennwald  St. Gallen  9466",
        "country": "CH"
    },
    "280CB8": {
        "oui_hex": "28-0C-B8",
        "organization": "Mikrosay Yazilim ve Elektronik A.S.",
        "address_1": "Cevizli Mah. Tansel Cad.",
        "address_2": "Istanbul    34846",
        "country": "TR"
    },
    "3CC99E": {
        "oui_hex": "3C-C9-9E",
        "organization": "Huiyang Technology Co., Ltd",
        "address_1": "22D 7 Block ZhonghuiNewcity",
        "address_2": "Dongguan  Guangdong  523849",
        "country": "CN"
    },
    "2C1EEA": {
        "oui_hex": "2C-1E-EA",
        "organization": "AERODEV",
        "address_1": "No.59,1985 Lane,Chunshen Road,",
        "address_2": "Shanghai    200237",
        "country": "CN"
    },
    "1C8E8E": {
        "oui_hex": "1C-8E-8E",
        "organization": "DB Communication & Systems Co., ltd.",
        "address_1": "3-3 Yeongdeok-dong, Giheung-gu",
        "address_2": "Yongin-si  Gyeonggi-do  449-908",
        "country": "KR"
    },
    "24EC99": {
        "oui_hex": "24-EC-99",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "A44B15": {
        "oui_hex": "A4-4B-15",
        "organization": "Sun Cupid Technology (HK) LTD",
        "address_1": "Room 1201-3, 12/F., Tower 6",
        "address_2": "Tsim Sha Tsui",
        "country": "HK"
    },
    "48C862": {
        "oui_hex": "48-C8-62",
        "organization": "Simo Wireless,Inc.",
        "address_1": "326#,Building 4,Zhongxing Industrial Park,Chuangye",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "78BEB6": {
        "oui_hex": "78-BE-B6",
        "organization": "Enhanced Vision",
        "address_1": "5882 MACHINE DR.",
        "address_2": "Huntington Beach  California  92649",
        "country": "US"
    },
    "449CB5": {
        "oui_hex": "44-9C-B5",
        "organization": "Alcomp, Inc",
        "address_1": "11537 Walnut Lane",
        "address_2": "Fort Atkinson  WI  53538",
        "country": "US"
    },
    "B4FC75": {
        "oui_hex": "B4-FC-75",
        "organization": "SEMA Electronics(HK) CO.,LTD",
        "address_1": "Xialingbei Industrial Zone  Liaobu,",
        "address_2": "Dongguan  Guangdong  523411",
        "country": "CN"
    },
    "B0BF99": {
        "oui_hex": "B0-BF-99",
        "organization": "WIZITDONGDO",
        "address_1": "2F, 299-1, 3-DONG, SUNGSU 2-GA",
        "address_2": "SEOUL    133-833",
        "country": "KR"
    },
    "B82ADC": {
        "oui_hex": "B8-2A-DC",
        "organization": "EFR Europäische Funk-Rundsteuerung GmbH",
        "address_1": "Nymphenburger Straße 20b",
        "address_2": "Munich    80335",
        "country": "DE"
    },
    "40F14C": {
        "oui_hex": "40-F1-4C",
        "organization": "ISE Europe SPRL",
        "address_1": "Fauvette 1",
        "address_2": "Uccle    1180",
        "country": "BE"
    },
    "E8944C": {
        "oui_hex": "E8-94-4C",
        "organization": "Cogent Healthcare Systems Ltd",
        "address_1": "69 Alma Road",
        "address_2": "Berkshire    SL4 3HT",
        "country": "GB"
    },
    "9067F3": {
        "oui_hex": "90-67-F3",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "D4F0B4": {
        "oui_hex": "D4-F0-B4",
        "organization": "Napco Security Technologies",
        "address_1": "333 Bayview Ave",
        "address_2": "Amityville  NY  11701",
        "country": "US"
    },
    "68F895": {
        "oui_hex": "68-F8-95",
        "organization": "Redflow Limited",
        "address_1": "1/27 Counihan Rd",
        "address_2": "Brisbane  Queensland  4073",
        "country": "AU"
    },
    "70B921": {
        "oui_hex": "70-B9-21",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "A0E295": {
        "oui_hex": "A0-E2-95",
        "organization": "DAT System Co.,Ltd",
        "address_1": "Gun San Free Trade Area 511-1 ,",
        "address_2": "    573-540",
        "country": "KR"
    },
    "A0165C": {
        "oui_hex": "A0-16-5C",
        "organization": "Triteka LTD",
        "address_1": "Malha Technology Park",
        "address_2": "Jerusalem    96951",
        "country": "IL"
    },
    "9C417C": {
        "oui_hex": "9C-41-7C",
        "organization": "Hame  Technology Co.,  Limited",
        "address_1": "5F, No. 18 High Tech Middle Avenue One, High Tech Industrial Park, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "9C6ABE": {
        "oui_hex": "9C-6A-BE",
        "organization": "QEES ApS.",
        "address_1": "Naverland 31, 2.tv",
        "address_2": "Glostrup  Hovedstaden  2600",
        "country": "DK"
    },
    "9C934E": {
        "oui_hex": "9C-93-4E",
        "organization": "Xerox Corporation",
        "address_1": "Mail Stop 0214 - 7E",
        "address_2": "Webster  NY  14580",
        "country": "US"
    },
    "044665": {
        "oui_hex": "04-46-65",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "2C2172": {
        "oui_hex": "2C-21-72",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "900917": {
        "oui_hex": "90-09-17",
        "organization": "Far-sighted mobile",
        "address_1": "Technology Park Desay Building 6th-Floor",
        "address_2": "Shenzhen  Guangdong Province   518000",
        "country": "CN"
    },
    "2C8BF2": {
        "oui_hex": "2C-8B-F2",
        "organization": "Hitachi Metals America Ltd",
        "address_1": "1920 Zanker Road",
        "address_2": "San Jose   CA  95112",
        "country": "US"
    },
    "D8973B": {
        "oui_hex": "D8-97-3B",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "16/F Lu Plaza Building",
        "address_2": "Kwun Tong  Kowloon  00000",
        "country": "HK"
    },
    "3826CD": {
        "oui_hex": "38-26-CD",
        "organization": "ANDTEK",
        "address_1": "Am Soeldnermoos 17",
        "address_2": "Hallbergmoos  Bavaria  85399",
        "country": "DE"
    },
    "88BFD5": {
        "oui_hex": "88-BF-D5",
        "organization": "Simple Audio Ltd",
        "address_1": "Unit 59 Elderpark Workspace",
        "address_2": "Glasgow    G51 3TR",
        "country": "GB"
    },
    "24CBE7": {
        "oui_hex": "24-CB-E7",
        "organization": "MYK, Inc.",
        "address_1": "4-60-30-108, Kamoi,",
        "address_2": "Yokohama  Kanagawa  226-0003",
        "country": "JP"
    },
    "603010": {
        "oui_hex": "60-30-10",
        "organization": "4-60-30-108, Kamoi,",
        "address_1": "JP",
        "address_2": "",
        "country": ""
    },
    "B0A10A": {
        "oui_hex": "B0-A1-0A",
        "organization": "Pivotal Systems Corporation",
        "address_1": "4683  Chabot Drive",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "802DE1": {
        "oui_hex": "80-2D-E1",
        "organization": "Solarbridge Technologies",
        "address_1": "9229 Waterford Centre Blvd",
        "address_2": "Austin  TX  78758",
        "country": "US"
    },
    "F4A52A": {
        "oui_hex": "F4-A5-2A",
        "organization": "Hawa Technologies Inc",
        "address_1": "336 Hayes St",
        "address_2": "San Francisco  California  94102",
        "country": "US"
    },
    "0C6E4F": {
        "oui_hex": "0C-6E-4F",
        "organization": "PrimeVOLT Co., Ltd.",
        "address_1": "2F-3, No. 9, Lane 3, Jihu Rd, Neihu",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "E8B748": {
        "oui_hex": "E8-B7-48",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BC99BC": {
        "oui_hex": "BC-99-BC",
        "organization": "FonSee Technology Inc.",
        "address_1": "14F-2, No.32, Gaotie 2nd Rd.,",
        "address_2": "Zhubei City  Hsinchu County  302",
        "country": "TW"
    },
    "783F15": {
        "oui_hex": "78-3F-15",
        "organization": "EasySYNC Ltd.",
        "address_1": "Unit 1, 2 Seaward Place",
        "address_2": "Glasgow  Scotland  G41 1HH",
        "country": "GB"
    },
    "18D071": {
        "oui_hex": "18-D0-71",
        "organization": "DASAN CO., LTD.",
        "address_1": "DASAN Tower 7F, 49 Daewangpangyo-ro644beon-gil",
        "address_2": "Seongnam-si  Gyeonggi-do  463-760",
        "country": "KR"
    },
    "58E476": {
        "oui_hex": "58-E4-76",
        "organization": "CENTRON COMMUNICATIONS TECHNOLOGIES FUJIAN CO.,LTD",
        "address_1": "4th Floor,Jiaodajiepu Building,72# Kejierlu Road,",
        "address_2": "Xi'an  Shaanxi Province  710100",
        "country": "CN"
    },
    "447E95": {
        "oui_hex": "44-7E-95",
        "organization": "Alpha and Omega, Inc",
        "address_1": "4735 Montview Blvd",
        "address_2": "Denver  CO  80207",
        "country": "US"
    },
    "986022": {
        "oui_hex": "98-60-22",
        "organization": "EMW Co., Ltd.",
        "address_1": "80B-4L, 680-3 Gojan-Dong",
        "address_2": "Incheon    405-819",
        "country": "KR"
    },
    "B8D49D": {
        "oui_hex": "B8-D4-9D",
        "organization": "M Seven System Ltd.",
        "address_1": "24F, Trust Tower Bldg, 275-7, Yangjae2-Dong, Seocho-Gu",
        "address_2": "Seoul    137-739",
        "country": "KR"
    },
    "3C672C": {
        "oui_hex": "3C-67-2C",
        "organization": "Sciovid Inc.",
        "address_1": "387 S Silverbrook Dr",
        "address_2": "Anaheim  CA  92807",
        "country": "US"
    },
    "DC9B1E": {
        "oui_hex": "DC-9B-1E",
        "organization": "Intercom, Inc.",
        "address_1": "Sorimachi Bldg., 3-5, Taito 1-chome,",
        "address_2": "Taito-ku  Tokyo  110-8654",
        "country": "JP"
    },
    "BC5FF4": {
        "oui_hex": "BC-5F-F4",
        "organization": "ASRock Incorporation",
        "address_1": "2F.,No.37, Sec.2, Jhongyang S.Rd., Beitou Distric,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "E8B4AE": {
        "oui_hex": "E8-B4-AE",
        "organization": "Shenzhen C&D Electronics Co.,Ltd",
        "address_1": "Building 2, Xia You Song Mountain Top Industrial District, You Song Village",
        "address_2": "Shenzhen  Guang Dong  518000",
        "country": "CN"
    },
    "50FAAB": {
        "oui_hex": "50-FA-AB",
        "organization": "L-tek d.o.o.",
        "address_1": "Obrtna cesta 18",
        "address_2": "Sentjernej    8310",
        "country": "SI"
    },
    "3891FB": {
        "oui_hex": "38-91-FB",
        "organization": "Xenox Holding BV",
        "address_1": "Lingedijk 80",
        "address_2": "Tricht  Gelderland  4196 HC",
        "country": "NL"
    },
    "A8E018": {
        "oui_hex": "A8-E0-18",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "781DFD": {
        "oui_hex": "78-1D-FD",
        "organization": "Jabil Inc",
        "address_1": "10500 Dr. Martin Luther King Jr. St. N.",
        "address_2": "St. Petersburg  Florida  33716",
        "country": "US"
    },
    "18AEBB": {
        "oui_hex": "18-AE-BB",
        "organization": "Siemens Convergence Creators GmbH&Co.KG",
        "address_1": "Communications, Media and Technology",
        "address_2": "Hamburg    D-21079",
        "country": "DE"
    },
    "B0BDA1": {
        "oui_hex": "B0-BD-A1",
        "organization": "ZAKLAD ELEKTRONICZNY SIMS",
        "address_1": "POD SKARPA 51A",
        "address_2": "BYDGOSZCZ  KUJAWSKO-POMORSKIE  85-796",
        "country": "PL"
    },
    "70B265": {
        "oui_hex": "70-B2-65",
        "organization": "Hiltron s.r.l.",
        "address_1": "Strada Provinciale di Caserta, 218",
        "address_2": "Naples    80144",
        "country": "IT"
    },
    "CCC62B": {
        "oui_hex": "CC-C6-2B",
        "organization": "Tri-Systems Corporation",
        "address_1": "3-27-8 TRS Building 3F",
        "address_2": "Hachioji  Tokyo  192-0904",
        "country": "JP"
    },
    "D8C068": {
        "oui_hex": "D8-C0-68",
        "organization": "Netgenetech.co.,ltd.",
        "address_1": "704, Hanlim Venture Town., #689-6,",
        "address_2": "Gunpo-si    435-862",
        "country": "KR"
    },
    "601199": {
        "oui_hex": "60-11-99",
        "organization": "Siama Systems Inc",
        "address_1": "410 Saint-Nicolas Street",
        "address_2": "Montreal  Quebec  H2Y 2P5",
        "country": "CA"
    },
    "6C81FE": {
        "oui_hex": "6C-81-FE",
        "organization": "Mitsuba Corporation",
        "address_1": "1-2681",
        "address_2": "Kiryu  Gunma  376-8555",
        "country": "JP"
    },
    "C027B9": {
        "oui_hex": "C0-27-B9",
        "organization": "Beijing National Railway Research & Design Institute  of Signal & Communication Co., Ltd.",
        "address_1": "Building No.18, Huayuan YiLi,Fengtai District,",
        "address_2": "Beijing    100073",
        "country": "CN"
    },
    "147411": {
        "oui_hex": "14-74-11",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "F8A9DE": {
        "oui_hex": "F8-A9-DE",
        "organization": "PUISSANCE PLUS",
        "address_1": "222 Impasse Louis Lépine",
        "address_2": "Montauban    82000",
        "country": "FR"
    },
    "A88CEE": {
        "oui_hex": "A8-8C-EE",
        "organization": "MicroMade Galka i Drozdz sp.j.",
        "address_1": "ul. Wieniawskiego 16",
        "address_2": "Pila  Wielkopolskie  64-920",
        "country": "PL"
    },
    "DC2B66": {
        "oui_hex": "DC-2B-66",
        "organization": "InfoBLOCK S.A. de C.V.",
        "address_1": "Hegel 229 - 10",
        "address_2": "Mexico City  Distrito Federal  11570",
        "country": "MX"
    },
    "B8871E": {
        "oui_hex": "B8-87-1E",
        "organization": "Good Mind Industries Co., Ltd.",
        "address_1": "22, Ta Yeou 2nd St,",
        "address_2": "Kaohsiung    831",
        "country": "TW"
    },
    "D4F027": {
        "oui_hex": "D4-F0-27",
        "organization": "Trust Power Ltd.",
        "address_1": "13 Berkley Street",
        "address_2": "London    W1J 8DU",
        "country": "GB"
    },
    "0455CA": {
        "oui_hex": "04-55-CA",
        "organization": "BriView (Xiamen) Corp.",
        "address_1": "NO.1998 West of Fangshan Road,Xiang An Branch,Torch Hi-tech lndustrial Development Zone,",
        "address_2": "Xiamen city  Fujian Province  361102",
        "country": "CN"
    },
    "1435B3": {
        "oui_hex": "14-35-B3",
        "organization": "Future Designs, Inc.",
        "address_1": "2702 Triana Blvd",
        "address_2": "Huntsville  AL  35805",
        "country": "US"
    },
    "AC932F": {
        "oui_hex": "AC-93-2F",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "0054AF": {
        "oui_hex": "00-54-AF",
        "organization": "Continental Automotive Systems Inc.",
        "address_1": "21440 W. Lake Cook Rd.",
        "address_2": "Deer Park  IL  60010",
        "country": "US"
    },
    "ACCABA": {
        "oui_hex": "AC-CA-BA",
        "organization": "Midokura Co., Ltd.",
        "address_1": "7th Floor Azabudai Hinoki building",
        "address_2": "Tokyo    106-0041",
        "country": "JP"
    },
    "0C8112": {
        "oui_hex": "0C-81-12",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "9C95F8": {
        "oui_hex": "9C-95-F8",
        "organization": "SmartDoor Systems, LLC",
        "address_1": "5711-A Center Lane",
        "address_2": "Falls Church  Virginia  22041",
        "country": "US"
    },
    "7819F7": {
        "oui_hex": "78-19-F7",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "64094C": {
        "oui_hex": "64-09-4C",
        "organization": "Beijing Superbee Wireless Technology Co.,Ltd",
        "address_1": "B7,Science-Tech Fortune Center,",
        "address_2": "Beijing    100192",
        "country": "CN"
    },
    "7C7D41": {
        "oui_hex": "7C-7D-41",
        "organization": "Jinmuyu Electronics Co., Ltd.",
        "address_1": "Room 132, Building 16, Tianqiaowan",
        "address_2": "Beijing    101101",
        "country": "CN"
    },
    "4C1480": {
        "oui_hex": "4C-14-80",
        "organization": "NOREGON SYSTEMS, INC",
        "address_1": "100 N. MAIN ST.  SUITE 2200",
        "address_2": "WINSTON - SALEM  NC  27101",
        "country": "US"
    },
    "A4856B": {
        "oui_hex": "A4-85-6B",
        "organization": "Q Electronics Ltd",
        "address_1": "Beck House, Hawksworth Road",
        "address_2": "Leeds  West Yorkshire  LS18 4JP",
        "country": "GB"
    },
    "20D5AB": {
        "oui_hex": "20-D5-AB",
        "organization": "Korea Infocom Co.,Ltd.",
        "address_1": "5F Wintek B/D 511",
        "address_2": "Uiwang  Kyunggi-Do  437-830",
        "country": "KR"
    },
    "0CF3EE": {
        "oui_hex": "0C-F3-EE",
        "organization": "EM Microelectronic",
        "address_1": "Rue des Sors 3",
        "address_2": "Marin-Epagnier  Neuchatel  2074",
        "country": "CH"
    },
    "64D1A3": {
        "oui_hex": "64-D1-A3",
        "organization": "Sitecom Europe BV",
        "address_1": "Linatebaan 101",
        "address_2": "Rotterdam  Zuid Holland  3045 AH",
        "country": "NL"
    },
    "F43E9D": {
        "oui_hex": "F4-3E-9D",
        "organization": "Benu Networks, Inc.",
        "address_1": "300 Rd., Suite 110",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "04E2F8": {
        "oui_hex": "04-E2-F8",
        "organization": "AEP Ticketing solutions srl",
        "address_1": "Via dei Colli, 240",
        "address_2": "Signa  Firenze  50058",
        "country": "IT"
    },
    "EC9ECD": {
        "oui_hex": "EC-9E-CD",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way Suite 190",
        "address_2": "Tempe  Arizona  85282",
        "country": "US"
    },
    "8C5105": {
        "oui_hex": "8C-51-05",
        "organization": "Shenzhen ireadygo Information Technology CO.,LTD.",
        "address_1": "Room 02,11F,DESAY Building,No.1 Hi-Tech South Road",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "C8208E": {
        "oui_hex": "C8-20-8E",
        "organization": "Storagedata",
        "address_1": "Randstad 22117",
        "address_2": "Almere  Flevoland  1316BW",
        "country": "NL"
    },
    "5C5EAB": {
        "oui_hex": "5C-5E-AB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "9C807D": {
        "oui_hex": "9C-80-7D",
        "organization": "SYSCABLE Korea Inc.",
        "address_1": "2F KAMA Bldg 1461-15 Secho-3dong Seocho-Gu",
        "address_2": "Seoul    137-720",
        "country": "KR"
    },
    "28E297": {
        "oui_hex": "28-E2-97",
        "organization": "Shanghai InfoTM Microelectronics Co.,Ltd.",
        "address_1": "building 11,NO.115,lane 572,BiBo Road,",
        "address_2": "ShangHai    201203",
        "country": "CN"
    },
    "34B571": {
        "oui_hex": "34-B5-71",
        "organization": "PLDS",
        "address_1": "Schanzenfeldstrasse 2",
        "address_2": "Wetzlar  Hessen  35578",
        "country": "DE"
    },
    "3C7437": {
        "oui_hex": "3C-74-37",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "EC9233": {
        "oui_hex": "EC-92-33",
        "organization": "Eddyfi NDT Inc",
        "address_1": "2800, Louis-Lumiere street",
        "address_2": "Quebec  Quebec  G1P 0A4",
        "country": "CA"
    },
    "743889": {
        "oui_hex": "74-38-89",
        "organization": "ANNAX Anzeigesysteme GmbH",
        "address_1": "Wettersteinstrasse 18",
        "address_2": "Taufkirchen  Bavaria  82024",
        "country": "DE"
    },
    "44D2CA": {
        "oui_hex": "44-D2-CA",
        "organization": "Anvia TV Oy",
        "address_1": "PO Box 29",
        "address_2": "SEINAJOKI    FIN60101",
        "country": "FI"
    },
    "386E21": {
        "oui_hex": "38-6E-21",
        "organization": "Wasion Group Ltd.",
        "address_1": "No.468 West Tongzipo Road High-Tech Industrial Development Zone",
        "address_2": "Changsha City  Hunan Province,  410205",
        "country": "CN"
    },
    "2872F0": {
        "oui_hex": "28-72-F0",
        "organization": "ATHENA",
        "address_1": "42 RUE MONGE",
        "address_2": "PARIS    75005",
        "country": "FR"
    },
    "1C19DE": {
        "oui_hex": "1C-19-DE",
        "organization": "eyevis GmbH",
        "address_1": "Hundsschleestrasse 23",
        "address_2": "Reutlingen  BW  72766",
        "country": "DE"
    },
    "609E64": {
        "oui_hex": "60-9E-64",
        "organization": "Vivonic GmbH",
        "address_1": "Kurfuerst-Eppstein-Ring 4",
        "address_2": "Sailauf  Bayern  63877",
        "country": "DE"
    },
    "BC15A6": {
        "oui_hex": "BC-15-A6",
        "organization": "Taiwan Jantek Electronics,Ltd.",
        "address_1": "6F-1,No.1 Wu-Chuan 1St. Rd,Wu-Ku Industrial Park,",
        "address_2": "Sinchwang City  Taipei Hsien  24892",
        "country": "TW"
    },
    "DCDECA": {
        "oui_hex": "DC-DE-CA",
        "organization": "Akyllor",
        "address_1": "Britannia House, 22, 2F, Cator Road",
        "address_2": "Bandar Seri Begawan BS    8811",
        "country": "BN"
    },
    "A0AAFD": {
        "oui_hex": "A0-AA-FD",
        "organization": "EraThink Technologies Corp.",
        "address_1": "289 Bisheng Road Building 4,Floor 4",
        "address_2": "Shanghai    201204",
        "country": "CN"
    },
    "6CA906": {
        "oui_hex": "6C-A9-06",
        "organization": "Telefield Ltd",
        "address_1": "Flat D,2/F., Valiant Industrial Centre,2-12 Au Pui Wan Street,",
        "address_2": "Hongkong    852",
        "country": "CN"
    },
    "78223D": {
        "oui_hex": "78-22-3D",
        "organization": "Affirmed Networks",
        "address_1": "35 Nagog Park",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "3C02B1": {
        "oui_hex": "3C-02-B1",
        "organization": "Creation Technologies LP",
        "address_1": "3939 North Fraser Way",
        "address_2": "Burnaby  BC  V5J 5J2",
        "country": "CA"
    },
    "E441E6": {
        "oui_hex": "E4-41-E6",
        "organization": "Ottec Technology GmbH",
        "address_1": "Bünteweg 33",
        "address_2": "Gehrden  Lower Saxony  30989",
        "country": "DE"
    },
    "BC71C1": {
        "oui_hex": "BC-71-C1",
        "organization": "XTrillion, Inc.",
        "address_1": "1-12-3-4F",
        "address_2": "Chiyoda-ku  Tokyo  101-0041",
        "country": "JP"
    },
    "E0E8E8": {
        "oui_hex": "E0-E8-E8",
        "organization": "Olive Telecommunication Pvt. Ltd",
        "address_1": "862, Udyog Vihar",
        "address_2": "Gurgaon  Haryana  122016",
        "country": "IN"
    },
    "6052D0": {
        "oui_hex": "60-52-D0",
        "organization": "FACTS Engineering",
        "address_1": "8049 Photonics Drive",
        "address_2": "New Port Richey  FL  34655",
        "country": "US"
    },
    "B08991": {
        "oui_hex": "B0-89-91",
        "organization": "LGE",
        "address_1": "60-39 , Kasan -dong , Gumcheon-gu.",
        "address_2": "Seoul     153-801",
        "country": "KR"
    },
    "30142D": {
        "oui_hex": "30-14-2D",
        "organization": "Piciorgros GmbH",
        "address_1": "Claudiastrasse 5",
        "address_2": "Cologne  NRW  51149",
        "country": "DE"
    },
    "50AF73": {
        "oui_hex": "50-AF-73",
        "organization": "Shenzhen Bitland Information Technology Co., Ltd.",
        "address_1": "1-4F,44 Building,Tanglang Industrial Park and 1-6F,#7 Building,XiLi Tongfuyu Industrial Town,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "5C9AD8": {
        "oui_hex": "5C-9A-D8",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "A4C0E1": {
        "oui_hex": "A4-C0-E1",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "4C3B74": {
        "oui_hex": "4C-3B-74",
        "organization": "VOGTEC(H.K.) Co., Ltd",
        "address_1": "Flat 01, 2/F, On Ning Building,",
        "address_2": "Hong Kong    999077",
        "country": "CN"
    },
    "684352": {
        "oui_hex": "68-43-52",
        "organization": "Bhuu Limited",
        "address_1": "Office 1, 465 Mt Eden Road",
        "address_2": "Auckland    1023",
        "country": "NZ"
    },
    "ECE90B": {
        "oui_hex": "EC-E9-0B",
        "organization": "SISTEMA SOLUCOES ELETRONICAS LTDA - EASYTECH",
        "address_1": "RUA GUERRA DE AGUIAR, 220",
        "address_2": "São Paulo  SP  08275-260",
        "country": "BR"
    },
    "A08C9B": {
        "oui_hex": "A0-8C-9B",
        "organization": "Xtreme Technologies Corp",
        "address_1": "200 4616 Valiant Dr NW",
        "address_2": "Calgary  AB  T3A0X9",
        "country": "CA"
    },
    "A83944": {
        "oui_hex": "A8-39-44",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "74E06E": {
        "oui_hex": "74-E0-6E",
        "organization": "Ergophone GmbH",
        "address_1": "Temmlerstrasse 5",
        "address_2": "Marburg  Hessen  35039",
        "country": "DE"
    },
    "0CF0B4": {
        "oui_hex": "0C-F0-B4",
        "organization": "Globalsat International Technology Ltd",
        "address_1": "17th floor,China Youse Building,No.6013 Shennan Avenue,Futian District,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "48DF1C": {
        "oui_hex": "48-DF-1C",
        "organization": "Wuhan NEC Fibre Optic Communications industry Co. Ltd",
        "address_1": "3rd Road Guanshan,",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D49C8E": {
        "oui_hex": "D4-9C-8E",
        "organization": "University of FUKUI",
        "address_1": "3-9-1 Bunkyo",
        "address_2": "Fukui City    910-8507",
        "country": "JP"
    },
    "F8F014": {
        "oui_hex": "F8-F0-14",
        "organization": "RackWare Inc.",
        "address_1": "44053 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "2826A6": {
        "oui_hex": "28-26-A6",
        "organization": "PBR electronics GmbH",
        "address_1": "Berliner Strasse 5",
        "address_2": "Sandhausen  Baden Wuertemmberg  69207",
        "country": "DE"
    },
    "B428F1": {
        "oui_hex": "B4-28-F1",
        "organization": "E-Prime Co., Ltd.",
        "address_1": "Rm1207, Kolon Science Valley, 811,",
        "address_2": "Seoul    152050",
        "country": "KR"
    },
    "C01242": {
        "oui_hex": "C0-12-42",
        "organization": "Alpha Security Products",
        "address_1": "10715 Sikes Place, Ste. 200",
        "address_2": "Charlotte  NC  28277",
        "country": "US"
    },
    "BC20BA": {
        "oui_hex": "BC-20-BA",
        "organization": "Inspur (Shandong) Electronic Information Co., Ltd",
        "address_1": "No.1036 Shunya Rd.",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "1CFEA7": {
        "oui_hex": "1C-FE-A7",
        "organization": "IDentytech Solutins Ltd.",
        "address_1": "14 Hadaya Street",
        "address_2": "Ramat- Hasharon    47226",
        "country": "IL"
    },
    "304EC3": {
        "oui_hex": "30-4E-C3",
        "organization": "Tianjin Techua Technology Co., Ltd.",
        "address_1": "12-1-1401 Tianlinyuan Fulicheng Gulouxi Road,Nankai District",
        "address_2": "Tianjin    300101",
        "country": "CN"
    },
    "B4CFDB": {
        "oui_hex": "B4-CF-DB",
        "organization": "Shenzhen Jiuzhou Electric Co.,LTD",
        "address_1": "6F,Jiuzhou Electric Building,Southern No.12RD.,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "FCD4F2": {
        "oui_hex": "FC-D4-F2",
        "organization": "The Coca Cola Company",
        "address_1": "One Coca Cola Plaza",
        "address_2": "Atlanta  GA  30313",
        "country": "US"
    },
    "5C6A7D": {
        "oui_hex": "5C-6A-7D",
        "organization": "KENTKART EGE ELEKTRONIK SAN. VE TIC. LTD. STI.",
        "address_1": "1370 SK, NO:42/304,",
        "address_2": "MONTRO  IZMIR  35230",
        "country": "TR"
    },
    "44599F": {
        "oui_hex": "44-59-9F",
        "organization": "Criticare Systems, Inc",
        "address_1": "20925 Crossroads Circle",
        "address_2": "Waukasha  WI  53186",
        "country": "US"
    },
    "3C2F3A": {
        "oui_hex": "3C-2F-3A",
        "organization": "SFORZATO Corp.",
        "address_1": "863",
        "address_2": "HINO-SHI  TOKYO  191-0022",
        "country": "JP"
    },
    "74CE56": {
        "oui_hex": "74-CE-56",
        "organization": "Packet Force Technology Limited Company",
        "address_1": " 2F., No.25, Sec. 1, Shuangshi Rd., Central Dist.,",
        "address_2": "Taichung    40046",
        "country": "TW"
    },
    "AC2FA8": {
        "oui_hex": "AC-2F-A8",
        "organization": "Humannix Co.,Ltd.",
        "address_1": "#402, 98-4, Songpa-Dong, Songpa-Gu",
        "address_2": "Seoul    138-170",
        "country": "KR"
    },
    "1064E2": {
        "oui_hex": "10-64-E2",
        "organization": "ADFweb.com s.r.l.",
        "address_1": "Strada Nuova, 17",
        "address_2": "Mareno di Piave  Treviso  31010",
        "country": "IT"
    },
    "CC34D7": {
        "oui_hex": "CC-34-D7",
        "organization": "GEWISS S.P.A.",
        "address_1": "VIA ALESSANDRO VOLTA 1",
        "address_2": "CENATE SOTTO    24069",
        "country": "IT"
    },
    "F02A61": {
        "oui_hex": "F0-2A-61",
        "organization": "Waldo Networks, Inc.",
        "address_1": "4505 Spicewood Springs Rd",
        "address_2": "Austin  Texas  78759",
        "country": "US"
    },
    "C8A70A": {
        "oui_hex": "C8-A7-0A",
        "organization": "Verizon Business",
        "address_1": "One Digex Plaza",
        "address_2": "Beltsville  MD  20705",
        "country": "US"
    },
    "60DA23": {
        "oui_hex": "60-DA-23",
        "organization": "Estech Co.,Ltd",
        "address_1": "#717,133-1,Sangdaewon-Dong",
        "address_2": "Seongnam-Si  Gyeonggi-Do  462-120",
        "country": "KR"
    },
    "44DCCB": {
        "oui_hex": "44-DC-CB",
        "organization": "SEMINDIA SYSTEMS PVT LTD",
        "address_1": "1006/13, Sy No.49/1&3, 7th Mile, A.M Indl Estate,",
        "address_2": "Bangalore  Karnataka  560068",
        "country": "IN"
    },
    "A0DE05": {
        "oui_hex": "A0-DE-05",
        "organization": "JSC Irbis-T",
        "address_1": "39, Gorodskoy lane",
        "address_2": "Tula    300012",
        "country": "RU"
    },
    "0817F4": {
        "oui_hex": "08-17-F4",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "CCD811": {
        "oui_hex": "CC-D8-11",
        "organization": "Aiconn Technology Corporation",
        "address_1": "5F, NO. 9, Alley 2, Lane 35, Ji-Hu Rd., Nei-Hu,",
        "address_2": "Taipei City    11494",
        "country": "TW"
    },
    "F43814": {
        "oui_hex": "F4-38-14",
        "organization": "Shanghai Howell Electronic Co.,Ltd",
        "address_1": "5-5/F, Bldg.1, No.788 Fengzhen Rd.,",
        "address_2": "Shanghai     200434",
        "country": "CN"
    },
    "90610C": {
        "oui_hex": "90-61-0C",
        "organization": "Fida International (S) Pte Ltd",
        "address_1": "Blk 16, Kallang Place",
        "address_2": "    339156",
        "country": "SG"
    },
    "3C5F01": {
        "oui_hex": "3C-5F-01",
        "organization": "Synerchip Co., Ltd.",
        "address_1": "c/o Synerchip USA Corp.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "ECBBAE": {
        "oui_hex": "EC-BB-AE",
        "organization": "Digivoice Tecnologia em Eletronica Ltda",
        "address_1": "Alameda Juru, 159 - Torreo",
        "address_2": "Barueri  São Paulo  06455-010",
        "country": "BR"
    },
    "34A183": {
        "oui_hex": "34-A1-83",
        "organization": "AWare, Inc",
        "address_1": "614 Massachusetts Ave.",
        "address_2": "Cambridge  MA  02139",
        "country": "US"
    },
    "9873C4": {
        "oui_hex": "98-73-C4",
        "organization": "Sage Electronic Engineering LLC",
        "address_1": "201 Terry St.",
        "address_2": "Longmont  CO  80501",
        "country": "US"
    },
    "B40142": {
        "oui_hex": "B4-01-42",
        "organization": "GCI Science & Technology Co.,LTD",
        "address_1": "No.381,xingangzhong road ,",
        "address_2": "GuangZhou  GuangDong  510310",
        "country": "CN"
    },
    "740ABC": {
        "oui_hex": "74-0A-BC",
        "organization": "LightwaveRF Technology Ltd",
        "address_1": "Innovation Campus Birmingham",
        "address_2": "Faraday Wharf, Holt Street  Birmingham  B4 4BB",
        "country": "GB"
    },
    "10A13B": {
        "oui_hex": "10-A1-3B",
        "organization": "FUJIKURA RUBBER LTD.",
        "address_1": "1-840,Mihashi,Omiya",
        "address_2": "Saitama     330-0856",
        "country": "JP"
    },
    "F4E142": {
        "oui_hex": "F4-E1-42",
        "organization": "Delta Elektronika BV",
        "address_1": "Vissersdijk 4",
        "address_2": "Zierikzee    4301 ND",
        "country": "NL"
    },
    "AC8112": {
        "oui_hex": "AC-81-12",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road Hsinchu Industrial Park Hukou, Hsinchu 30352 TAIWAN, REPUBLIC OF CHINA",
        "address_2": "Hsinchu  TAIWAN  30352",
        "country": "TW"
    },
    "686359": {
        "oui_hex": "68-63-59",
        "organization": "Advanced Digital Broadcast SA",
        "address_1": "Avenue de Tournay 7",
        "address_2": "Pregny-Chambesy    1292",
        "country": "CH"
    },
    "28061E": {
        "oui_hex": "28-06-1E",
        "organization": "NINGBO GLOBAL USEFUL ELECTRIC CO.,LTD",
        "address_1": "No.88,Kechuang South Road,",
        "address_2": "Ningbo  Zhejiang  315000",
        "country": "CN"
    },
    "64E8E6": {
        "oui_hex": "64-E8-E6",
        "organization": "global moisture management system",
        "address_1": "11132 broad river road",
        "address_2": "irmo  sc  29063",
        "country": "US"
    },
    "E0D10A": {
        "oui_hex": "E0-D1-0A",
        "organization": "Katoudenkikougyousyo co ltd",
        "address_1": "oujihontyou1-4-13",
        "address_2": "kita-ku  tokyo-to  114-0022",
        "country": "JP"
    },
    "C44B44": {
        "oui_hex": "C4-4B-44",
        "organization": "Omniprint Inc.",
        "address_1": "1923 East Deere Ave.",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "18922C": {
        "oui_hex": "18-92-2C",
        "organization": "Virtual Instruments",
        "address_1": "100 Enterprise Way",
        "address_2": "Scotts Valley  CA  95066",
        "country": "US"
    },
    "A49B13": {
        "oui_hex": "A4-9B-13",
        "organization": "Digital Check",
        "address_1": "630 Dundee Rd. Suite 210",
        "address_2": "Northbrook  IL  60062",
        "country": "US"
    },
    "C8EE08": {
        "oui_hex": "C8-EE-08",
        "organization": "TANGTOP TECHNOLOGY CO.,LTD",
        "address_1": "1F,NO.153,Ligon St.,Beitou District",
        "address_2": "Taipei City     112",
        "country": "TW"
    },
    "7472F2": {
        "oui_hex": "74-72-F2",
        "organization": "Chipsip Technology Co., Ltd.",
        "address_1": "8F-1, No.186, Jian-Yi Road, ChungHo City,",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "48C8B6": {
        "oui_hex": "48-C8-B6",
        "organization": "SysTec GmbH",
        "address_1": "Ludwig-Erhard-Strasse 6",
        "address_2": "Bergheim-Glessen  NRW  50129",
        "country": "DE"
    },
    "3C6278": {
        "oui_hex": "3C-62-78",
        "organization": "SHENZHEN JETNET TECHNOLOGY CO.,LTD.",
        "address_1": "Room 403,4th floor,Qinghua Information Building,Keyuan Road,North District of Tech-Park,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C8D5FE": {
        "oui_hex": "C8-D5-FE",
        "organization": "Shenzhen Zowee Technology Co., Ltd",
        "address_1": "Block 5, Science and Technology Industrial Park of",
        "address_2": "Shenzhen  GuangDong  518055",
        "country": "CN"
    },
    "2C3068": {
        "oui_hex": "2C-30-68",
        "organization": "Pantech Co.,Ltd",
        "address_1": "110-1 Ongjeong-Ri, Tongjin-Eup",
        "address_2": "Gimpo-Si  Gyounggi-Do  415-865",
        "country": "KR"
    },
    "00BD27": {
        "oui_hex": "00-BD-27",
        "organization": "Exar Corp.",
        "address_1": "48720 Kato Rd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "5C4058": {
        "oui_hex": "5C-40-58",
        "organization": "Jefferson Audio Video Systems, Inc.",
        "address_1": "13020 Middletown Industrial Blvd.",
        "address_2": "Louisville  Kentucky  40223",
        "country": "US"
    },
    "58D08F": {
        "oui_hex": "58-D0-8F",
        "organization": "IEEE 1904.1 Working Group",
        "address_1": "1351 Redwood Way,",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "6C9CE9": {
        "oui_hex": "6C-9C-E9",
        "organization": "Nimble Storage",
        "address_1": "2645 Zanker Road",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CC09C8": {
        "oui_hex": "CC-09-C8",
        "organization": "IMAQLIQ LTD",
        "address_1": "Obvodny Canal 93A",
        "address_2": "St.Petersburg    191119",
        "country": "RU"
    },
    "9C4563": {
        "oui_hex": "9C-45-63",
        "organization": "DIMEP Sistemas",
        "address_1": "Av. Mofarrej, 840",
        "address_2": "São Paulo    05311000",
        "country": "BR"
    },
    "D43D67": {
        "oui_hex": "D4-3D-67",
        "organization": "Carma Industries Inc.",
        "address_1": "132 Walsh Road",
        "address_2": "Lindsay  Ontario  K9V 4R3",
        "country": "CA"
    },
    "E0A670": {
        "oui_hex": "E0-A6-70",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "58DB8D": {
        "oui_hex": "58-DB-8D",
        "organization": "Fast Co., Ltd.",
        "address_1": "2-11-1 Iwamotocho",
        "address_2": "Chiyoda-ku  Tokyo  101-0032",
        "country": "JP"
    },
    "E446BD": {
        "oui_hex": "E4-46-BD",
        "organization": "C&C TECHNIC TAIWAN CO., LTD.",
        "address_1": "ROOM6 13F, NO.2,Jian 8th ROAD",
        "address_2": "Taipei  Chungho City,   23511",
        "country": "TW"
    },
    "8CDD8D": {
        "oui_hex": "8C-DD-8D",
        "organization": "Wifly-City System Inc.",
        "address_1": "4F.,-1,NO 106,RUEIGUANG Rd.Neihu District,",
        "address_2": "Taipei City     114",
        "country": "TW"
    },
    "20A2E7": {
        "oui_hex": "20-A2-E7",
        "organization": "Lee-Dickens Ltd",
        "address_1": "Rushton Rd",
        "address_2": "Kettering  Northamptonshire  NN14 2QW",
        "country": "GB"
    },
    "FCEDB9": {
        "oui_hex": "FC-ED-B9",
        "organization": "Arrayent",
        "address_1": "570 El Camino Real #150-419",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "44ED57": {
        "oui_hex": "44-ED-57",
        "organization": "Longicorn, inc.",
        "address_1": "Rm1001-2, 10F, Byuksan Digital Valley1",
        "address_2": "Seoul    152-775",
        "country": "KR"
    },
    "EC98C1": {
        "oui_hex": "EC-98-C1",
        "organization": "Beijing Risbo Network Technology Co.,Ltd",
        "address_1": "1/F Yinyan Building 2A,No.23 Anningzhuangdonglu Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "38A95F": {
        "oui_hex": "38-A9-5F",
        "organization": "Actifio Inc",
        "address_1": "225 Wyman Street",
        "address_2": "Waltham  MA  02451",
        "country": "IN"
    },
    "F4DCDA": {
        "oui_hex": "F4-DC-DA",
        "organization": "Zhuhai Jiahe Communication Technology Co., limited",
        "address_1": "4/F,East Of B5,Sourth Software Park,Tangjia,",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "E80462": {
        "oui_hex": "E8-04-62",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DCD0F7": {
        "oui_hex": "DC-D0-F7",
        "organization": "Bentek Systems Ltd.",
        "address_1": "315 - 3750 46th Ave. SE",
        "address_2": "Calgary  AB  T2B 0L1",
        "country": "CA"
    },
    "D4A928": {
        "oui_hex": "D4-A9-28",
        "organization": "GreenWave Reality Inc",
        "address_1": "39 Parker",
        "address_2": "Irvine  California  92618",
        "country": "US"
    },
    "E06290": {
        "oui_hex": "E0-62-90",
        "organization": "Jinan Jovision Science & Technology Co., Ltd.",
        "address_1": "Room 407, Tower C, Cyber Port Building,",
        "address_2": "Jinan  Shandong  250013",
        "country": "CN"
    },
    "100E2B": {
        "oui_hex": "10-0E-2B",
        "organization": "NEC CASIO Mobile Communications",
        "address_1": "1753,Shimonumabe",
        "address_2": "Kawasaki-shi  Kanagawa  211-8666",
        "country": "JP"
    },
    "70E139": {
        "oui_hex": "70-E1-39",
        "organization": "3view Ltd",
        "address_1": "168-172 Old Street",
        "address_2": "London    EC1V 9BP",
        "country": "GB"
    },
    "18422F": {
        "oui_hex": "18-42-2F",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "C46354": {
        "oui_hex": "C4-63-54",
        "organization": "U-Raku, Inc.",
        "address_1": "401-1 Deba",
        "address_2": "Ritto-shi  Shiga  520-3041",
        "country": "JP"
    },
    "405FBE": {
        "oui_hex": "40-5F-BE",
        "organization": "RIM",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "6854F5": {
        "oui_hex": "68-54-F5",
        "organization": "enLighted Inc",
        "address_1": "1451 Grant Rd",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "7CB542": {
        "oui_hex": "7C-B5-42",
        "organization": "ACES Technology",
        "address_1": "#928, Hyundai Venture Ville",
        "address_2": "Seoul    135-539",
        "country": "KR"
    },
    "905446": {
        "oui_hex": "90-54-46",
        "organization": "TES ELECTRONIC SOLUTIONS",
        "address_1": "Immeuble Odyssee",
        "address_2": "BRUZ    35170",
        "country": "FR"
    },
    "544A05": {
        "oui_hex": "54-4A-05",
        "organization": "wenglor sensoric gmbh",
        "address_1": "wenglor Str. 3",
        "address_2": "Tettnang    88069",
        "country": "DE"
    },
    "98E165": {
        "oui_hex": "98-E1-65",
        "organization": "Accutome",
        "address_1": "3222 Phoenixville Pike",
        "address_2": "Malvern  PA  19355",
        "country": "US"
    },
    "785712": {
        "oui_hex": "78-57-12",
        "organization": "Mobile Integration Workgroup",
        "address_1": "4580 Klahanie DR SE STE 106",
        "address_2": "Issaquah  WA  98029",
        "country": "US"
    },
    "380A0A": {
        "oui_hex": "38-0A-0A",
        "organization": "Sky-City Communication and Electronics Limited Company",
        "address_1": "1109, Building A, Kefa Industrial park, Huanguan south road, Guanlan,",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "0CD696": {
        "oui_hex": "0C-D6-96",
        "organization": "Amimon Ltd",
        "address_1": "2 Maskit st",
        "address_2": "Herzlia    46733",
        "country": "IL"
    },
    "F4DC4D": {
        "oui_hex": "F4-DC-4D",
        "organization": "Beijing CCD Digital Technology Co., Ltd",
        "address_1": "107 Dongsi North Street, Dongcheng District,",
        "address_2": "Beijing    100007",
        "country": "CN"
    },
    "4013D9": {
        "oui_hex": "40-13-D9",
        "organization": "Global ES",
        "address_1": "Sinimäentie 8 b",
        "address_2": "Espoo    02631",
        "country": "FI"
    },
    "AC4FFC": {
        "oui_hex": "AC-4F-FC",
        "organization": "SVS-VISTEK GmbH",
        "address_1": "Muehlbachstraße 20",
        "address_2": "Seefeld  BY  82229",
        "country": "DE"
    },
    "B43741": {
        "oui_hex": "B4-37-41",
        "organization": "Consert, Inc.",
        "address_1": "4700 Falls of Neuse Rd.",
        "address_2": "Raleigh  NC  27609",
        "country": "US"
    },
    "94857A": {
        "oui_hex": "94-85-7A",
        "organization": "Evantage Industries Corp",
        "address_1": "815 Bridge St. W.",
        "address_2": "Waterloo  Ontario  N2V 2M7",
        "country": "CA"
    },
    "4083DE": {
        "oui_hex": "40-83-DE",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "8897DF": {
        "oui_hex": "88-97-DF",
        "organization": "Entrypass Corporation Sdn. Bhd.",
        "address_1": "No.40, Jalan TPP 1/10,",
        "address_2": "Puchong  Selangor Darul Ehsan  47100",
        "country": "MY"
    },
    "24AF54": {
        "oui_hex": "24-AF-54",
        "organization": "NEXGEN Mediatech Inc.",
        "address_1": "8F No. 150, Jianyi Rd.,",
        "address_2": "Chung Ho  Taipei Hsien  235",
        "country": "TW"
    },
    "F0F842": {
        "oui_hex": "F0-F8-42",
        "organization": "KEEBOX, Inc.",
        "address_1": "10 Poppy Trail",
        "address_2": "Rolling Hills  California  90274",
        "country": "US"
    },
    "DC4EDE": {
        "oui_hex": "DC-4E-DE",
        "organization": "SHINYEI TECHNOLOGY CO., LTD.",
        "address_1": "6-5-2, MINATOJIMA-MINAMIMACHI, CHUO-KU",
        "address_2": "KOBE  HYOGO  650-0047",
        "country": "JP"
    },
    "E087B1": {
        "oui_hex": "E0-87-B1",
        "organization": "Nata-Info Ltd.",
        "address_1": "28, Prokhorova str.",
        "address_2": "Yoshkar-Ola  Republic Mari-El  424007",
        "country": "RU"
    },
    "447C7F": {
        "oui_hex": "44-7C-7F",
        "organization": "Innolight Technology Corporation",
        "address_1": "3 Results Way",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D496DF": {
        "oui_hex": "D4-96-DF",
        "organization": "SUNGJIN C&T CO.,LTD",
        "address_1": "Daeya",
        "address_2": "Sheung  Gyeonggi  429-809",
        "country": "KR"
    },
    "5C864A": {
        "oui_hex": "5C-86-4A",
        "organization": "Secret Labs LLC",
        "address_1": "315 Bleecker St #308",
        "address_2": "New York  NY  10014",
        "country": "US"
    },
    "F0AD4E": {
        "oui_hex": "F0-AD-4E",
        "organization": "Globalscale Technologies, Inc.",
        "address_1": "5F, No. 2 Building, Minxing Industrial Park",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "903D5A": {
        "oui_hex": "90-3D-5A",
        "organization": "Shenzhen Wision Technology Holding Limited",
        "address_1": "Room 26A, Jinrun Building, N0.6019, Shennan Rd., Futian District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "7CA29B": {
        "oui_hex": "7C-A2-9B",
        "organization": "D.SignT GmbH & Co. KG",
        "address_1": "Marktstraße 10",
        "address_2": "Kerken    47647",
        "country": "DE"
    },
    "A04041": {
        "oui_hex": "A0-40-41",
        "organization": "SAMWONFA Co.,Ltd.",
        "address_1": "470-5, Moonhyun2-Dong",
        "address_2": "Busan    608-042",
        "country": "KR"
    },
    "40406B": {
        "oui_hex": "40-40-6B",
        "organization": "Icomera",
        "address_1": "Vikingsgatan 3",
        "address_2": "Göteborg    41104",
        "country": "SE"
    },
    "6C22AB": {
        "oui_hex": "6C-22-AB",
        "organization": "Ainsworth Game Technology",
        "address_1": "10 Holker Street",
        "address_2": "Newington  New South Wales  2127",
        "country": "AU"
    },
    "3018CF": {
        "oui_hex": "30-18-CF",
        "organization": "DEOS control systems GmbH",
        "address_1": "Birkenallee 113",
        "address_2": "Rheine  NRW  48432",
        "country": "DE"
    },
    "08FAE0": {
        "oui_hex": "08-FA-E0",
        "organization": "Fohhn Audio AG",
        "address_1": "Hohes Gestade 3-7",
        "address_2": "Nuertingen  BW  72622",
        "country": "DE"
    },
    "58B9E1": {
        "oui_hex": "58-B9-E1",
        "organization": "Crystalfontz America, Inc.",
        "address_1": "12412 E. Saltese Ave.",
        "address_2": "Spokane Valley  WA  99216",
        "country": "US"
    },
    "20D906": {
        "oui_hex": "20-D9-06",
        "organization": "Iota, Inc.",
        "address_1": "2212 Queen Anne Ave. N., #348",
        "address_2": "Seattle  WA  98109",
        "country": "US"
    },
    "F45595": {
        "oui_hex": "F4-55-95",
        "organization": "HENGBAO Corporation LTD.",
        "address_1": "8th Floor,Tower B,Xinsheng Mansion No.5 Financial Street,",
        "address_2": "Beijing    100140",
        "country": "CN"
    },
    "1C3A4F": {
        "oui_hex": "1C-3A-4F",
        "organization": "AccuSpec Electronics, LLC",
        "address_1": "8140 Hawthorne Drive",
        "address_2": "Erie  Pennsylvania  16509",
        "country": "US"
    },
    "9C4E20": {
        "oui_hex": "9C-4E-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D87533": {
        "oui_hex": "D8-75-33",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "9835B8": {
        "oui_hex": "98-35-B8",
        "organization": "Assembled Products Corporation",
        "address_1": "115 E. Linden",
        "address_2": "Rogers  Arkansas  72756",
        "country": "US"
    },
    "288915": {
        "oui_hex": "28-89-15",
        "organization": "CashGuard Sverige AB",
        "address_1": "Finlandsgatan 16",
        "address_2": "Kista    16474",
        "country": "SE"
    },
    "4C5DCD": {
        "oui_hex": "4C-5D-CD",
        "organization": "Oy Finnish Electric Vehicle Technologies Ltd",
        "address_1": "Majavantie 10",
        "address_2": "TUUSULA    FI-04320",
        "country": "FI"
    },
    "70D57E": {
        "oui_hex": "70-D5-7E",
        "organization": "Scalar Corporation",
        "address_1": "1F San-Ei Bldg",
        "address_2": "Shinjuku-ku  Tokyo  160-0023",
        "country": "JP"
    },
    "B0E39D": {
        "oui_hex": "B0-E3-9D",
        "organization": "CAT SYSTEM CO.,LTD.",
        "address_1": "3-147-27 Higasi-sinmachi Hirohata-ku",
        "address_2": "Himeji  Hyogo  671-1121",
        "country": "JP"
    },
    "7C2E0D": {
        "oui_hex": "7C-2E-0D",
        "organization": "Blackmagic Design",
        "address_1": "11 Gateway Court",
        "address_2": "Melbourne  Victoria  3207",
        "country": "AU"
    },
    "180C77": {
        "oui_hex": "18-0C-77",
        "organization": "Westinghouse Electric Company, LLC",
        "address_1": "1000 Westinghouse Drive",
        "address_2": "Cranberry Township  PA  16066",
        "country": "US"
    },
    "68CA00": {
        "oui_hex": "68-CA-00",
        "organization": "Octopus Systems Limited",
        "address_1": "36/F, 148 Electric Road",
        "address_2": "",
        "country": "HK"
    },
    "E0589E": {
        "oui_hex": "E0-58-9E",
        "organization": "Laerdal Medical",
        "address_1": "Tanke Svilandsgate 30",
        "address_2": "Stavanger    4002",
        "country": "NO"
    },
    "0C1DC2": {
        "oui_hex": "0C-1D-C2",
        "organization": "SeAH Networks",
        "address_1": "9F, IT Venture Tower East Wing 78 Garak-Dong,",
        "address_2": "Seoul  Songpa-gu  138-950",
        "country": "KR"
    },
    "5475D0": {
        "oui_hex": "54-75-D0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6089B7": {
        "oui_hex": "60-89-B7",
        "organization": "KAEL MÜHENDİSLİK ELEKTRONİK TİCARET SANAYİ LİMİTED ŞİRKETİ",
        "address_1": "Atatürk Mah. 78 sokak ,No:10, Büyükalan Mevkii",
        "address_2": "Izmir  Aegean  35175",
        "country": "TR"
    },
    "30525A": {
        "oui_hex": "30-52-5A",
        "organization": "NST Co., LTD",
        "address_1": "RM301,Daeryung Techno Town 2, 569-21",
        "address_2": "Seoul    153-771",
        "country": "KR"
    },
    "2CA780": {
        "oui_hex": "2C-A7-80",
        "organization": "True Technologies Inc.",
        "address_1": "R476, AngelCity 1st,",
        "address_2": "Seongnam,  Kyungki  463-862",
        "country": "KR"
    },
    "7C6F06": {
        "oui_hex": "7C-6F-06",
        "organization": "Caterpillar Trimble Control Technologies",
        "address_1": "5475 Kellenburger Rd.",
        "address_2": "Dayton  OH  45424",
        "country": "US"
    },
    "601283": {
        "oui_hex": "60-12-83",
        "organization": "TSB REAL TIME LOCATION SYSTEMS S.L.",
        "address_1": "Ronda Auguste y Louis Lumière 23, Nave 13",
        "address_2": "Parque Tecnológico de Valencia   Paterna (Valencia)  46980",
        "country": "ES"
    },
    "98DCD9": {
        "oui_hex": "98-DC-D9",
        "organization": "UNITEC Co., Ltd.",
        "address_1": "1-2-1-Shinyokohama",
        "address_2": "Yokohama-shi  Kanagawa  222-0033",
        "country": "JP"
    },
    "C0CFA3": {
        "oui_hex": "C0-CF-A3",
        "organization": "Creative Electronics & Software, Inc.",
        "address_1": "650 Sundown Road",
        "address_2": "South Elgin  IL  60177",
        "country": "US"
    },
    "94236E": {
        "oui_hex": "94-23-6E",
        "organization": "Shenzhen Junlan Electronic Ltd",
        "address_1": "Block C,No.2 Industrial District, Fuyuan, Tangwei,Fuyong, Bao'an",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "10E6AE": {
        "oui_hex": "10-E6-AE",
        "organization": "Source Technologies, LLC",
        "address_1": "2910 Whitehall Park Drive",
        "address_2": "Charlotte  NC  28273",
        "country": "US"
    },
    "FCE192": {
        "oui_hex": "FC-E1-92",
        "organization": "Sichuan Jinwangtong Electronic Science&Technology Co,.Ltd",
        "address_1": "No.28,Xinchuang Rd.,West Gaoxin District",
        "address_2": "Chengdu  Sichuan  611731",
        "country": "CN"
    },
    "408A9A": {
        "oui_hex": "40-8A-9A",
        "organization": "TITENG CO., Ltd.",
        "address_1": "7Fl. Shindo B/D 10 Garak-dong",
        "address_2": "Seoul    138-160",
        "country": "KR"
    },
    "F445ED": {
        "oui_hex": "F4-45-ED",
        "organization": "Portable Innovation Technology Ltd.",
        "address_1": "601-602, 6/F Park Building,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "5CE286": {
        "oui_hex": "5C-E2-86",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "8C640B": {
        "oui_hex": "8C-64-0B",
        "organization": "Beyond Devices d.o.o.",
        "address_1": "Trzaska cesta 515",
        "address_2": "Brezovica pri Ljubljani    SI-1351",
        "country": "SI"
    },
    "949C55": {
        "oui_hex": "94-9C-55",
        "organization": "Alta Data Technologies",
        "address_1": "4901 Rockaway Blvd, Building A",
        "address_2": "Rio Rancho  NM  87124",
        "country": "US"
    },
    "D479C3": {
        "oui_hex": "D4-79-C3",
        "organization": "Cameronet GmbH & Co. KG",
        "address_1": "Elberfelder Strasse 96",
        "address_2": "Remscheid  NRW  42853",
        "country": "DE"
    },
    "70D5E7": {
        "oui_hex": "70-D5-E7",
        "organization": "Wellcore Corporation",
        "address_1": "2870 Zanker Road",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3CF72A": {
        "oui_hex": "3C-F7-2A",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "545FA9": {
        "oui_hex": "54-5F-A9",
        "organization": "Teracom Limited",
        "address_1": "B-84, Sector - 60,",
        "address_2": "Noida  Uttar Pradesh  201 301",
        "country": "IN"
    },
    "6C32DE": {
        "oui_hex": "6C-32-DE",
        "organization": "Indieon Technologies Pvt. Ltd.",
        "address_1": "601, Alpha 2, Gigaspace IT Park",
        "address_2": "Pune   Maharastra  411014",
        "country": "IN"
    },
    "14A62C": {
        "oui_hex": "14-A6-2C",
        "organization": "S.M. Dezac S.A.",
        "address_1": "Vial Sant jordi S/N",
        "address_2": "Viladecavalls  Barcelona  08232",
        "country": "ES"
    },
    "547FEE": {
        "oui_hex": "54-7F-EE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "ACEA6A": {
        "oui_hex": "AC-EA-6A",
        "organization": "GENIX INFOCOMM CO., LTD.",
        "address_1": "2F, Daebo Bldg. #1009-34",
        "address_2": "Seoul    153-829",
        "country": "KR"
    },
    "E0BC43": {
        "oui_hex": "E0-BC-43",
        "organization": "C2 Microsystems, Inc.",
        "address_1": "2833 Junction Avenue",
        "address_2": "San Jose  California  95134",
        "country": "US"
    },
    "2CA835": {
        "oui_hex": "2C-A8-35",
        "organization": "RIM",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "C41ECE": {
        "oui_hex": "C4-1E-CE",
        "organization": "HMI Sources Ltd.",
        "address_1": "5 Floor, Suite 2, 233 Hsin Yi Road, Section 4",
        "address_2": "Taipei    10681",
        "country": "TW"
    },
    "A8F470": {
        "oui_hex": "A8-F4-70",
        "organization": "Fujian Newland Communication Science Technologies Co.,Ltd.",
        "address_1": "Newland Science & Technology Park No.1 Rujiang West Rd., Mawei,",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "8C736E": {
        "oui_hex": "8C-73-6E",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "B86491": {
        "oui_hex": "B8-64-91",
        "organization": "CK Telecom Ltd",
        "address_1": "Keji Avenue,Heyuan Hi-tech Development Zone",
        "address_2": "Heyuan   Guangdong Province  517000",
        "country": "CN"
    },
    "50F003": {
        "oui_hex": "50-F0-03",
        "organization": "Open Stack, Inc.",
        "address_1": "Advanced Research Center #411",
        "address_2": "Bun-Dang, Seong-Nam  Gyung-Gi  463-816",
        "country": "KR"
    },
    "DC49C9": {
        "oui_hex": "DC-49-C9",
        "organization": "CASCO SIGNAL LTD",
        "address_1": "No.489 Xizang Bei Road",
        "address_2": "Shanghai    200071",
        "country": "CN"
    },
    "70D880": {
        "oui_hex": "70-D8-80",
        "organization": "Upos System sp. z o.o.",
        "address_1": "Sienkiewicza 13",
        "address_2": "Knurow  Slaskie  44-190",
        "country": "PL"
    },
    "A05DC1": {
        "oui_hex": "A0-5D-C1",
        "organization": "TMCT Co., LTD.",
        "address_1": "5F-561, #19-11 SanChong Rd.",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "583CC6": {
        "oui_hex": "58-3C-C6",
        "organization": "Omneality Ltd.",
        "address_1": "10B Glossop Road",
        "address_2": "South Croydon  Surrey  CR2 0PU",
        "country": "GB"
    },
    "B0C8AD": {
        "oui_hex": "B0-C8-AD",
        "organization": "People Power Company",
        "address_1": "620 Lowell Ave",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "181714": {
        "oui_hex": "18-17-14",
        "organization": "DAEWOOIS",
        "address_1": "7F Namkwang Centlex Bldg. 440-4 Cheongcheon2-dong",
        "address_2": "Incheon  Pupyeong-gu  82",
        "country": "KR"
    },
    "F0EC39": {
        "oui_hex": "F0-EC-39",
        "organization": "Essec",
        "address_1": "Schoebroekstraat 48",
        "address_2": "Paal  Limburg  3583",
        "country": "BE"
    },
    "446C24": {
        "oui_hex": "44-6C-24",
        "organization": "Reallin Electronic Co.,Ltd",
        "address_1": "2/F, Building 3, No.202 Zhengzhong Rd, XiHu industry Park",
        "address_2": "Hang Zhou  Zhe Jiang  310030",
        "country": "CN"
    },
    "2046F9": {
        "oui_hex": "20-46-F9",
        "organization": "Advanced Network Devices (dba:AND)",
        "address_1": "3820 Ventura Drive",
        "address_2": "Arlington Heights  IL  60004",
        "country": "US"
    },
    "487119": {
        "oui_hex": "48-71-19",
        "organization": "SGB GROUP LTD.",
        "address_1": "13F,No.192,Sec.2,Chung Hsin Rd.,Hsin Tien City",
        "address_2": "Taipei     231",
        "country": "TW"
    },
    "04FE7F": {
        "oui_hex": "04-FE-7F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4B1EE": {
        "oui_hex": "A4-B1-EE",
        "organization": "H. ZANDER GmbH & Co. KG",
        "address_1": "Am Gut Wolf 15",
        "address_2": "Aachen    52070",
        "country": "DE"
    },
    "842141": {
        "oui_hex": "84-21-41",
        "organization": "Shenzhen Ginwave Technologies Ltd.",
        "address_1": "4/F,R2-A,High-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A0231B": {
        "oui_hex": "A0-23-1B",
        "organization": "TeleComp R&D Corp.",
        "address_1": "102 SW Orange Blossom",
        "address_2": "Lake City  Florida  32025",
        "country": "US"
    },
    "B8A3E0": {
        "oui_hex": "B8-A3-E0",
        "organization": "BenRui Technology Co.,Ltd",
        "address_1": "No.3A room A Unit Hongsong Building",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "3CF52C": {
        "oui_hex": "3C-F5-2C",
        "organization": "DSPECIALISTS GmbH",
        "address_1": "Helmholtzstr. 2-9 L",
        "address_2": "Berlin    10587",
        "country": "DE"
    },
    "EC4476": {
        "oui_hex": "EC-44-76",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6C1811": {
        "oui_hex": "6C-18-11",
        "organization": "Decatur Electronics",
        "address_1": "715 Bright Street",
        "address_2": "Decatur  IL  62522",
        "country": "US"
    },
    "F8E968": {
        "oui_hex": "F8-E9-68",
        "organization": "Egker Kft.",
        "address_1": "Szuglo u. 49.",
        "address_2": "Budapest    1145",
        "country": "HU"
    },
    "A8995C": {
        "oui_hex": "A8-99-5C",
        "organization": "aizo ag",
        "address_1": "Brandstrasse 33",
        "address_2": "Schlieren    8952",
        "country": "CH"
    },
    "4012E4": {
        "oui_hex": "40-12-E4",
        "organization": "Compass-EOS",
        "address_1": "7 Giborei Israel",
        "address_2": "Natanya    42504",
        "country": "IL"
    },
    "5403F5": {
        "oui_hex": "54-03-F5",
        "organization": "EBN Technology Corp.",
        "address_1": "10F, No.90, Sec. 1, Sintai 5th Rd.",
        "address_2": "Sijhih City  Taipei County  22102",
        "country": "US"
    },
    "04C05B": {
        "oui_hex": "04-C0-5B",
        "organization": "Tigo Energy",
        "address_1": "170 Knowles Dr",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "8038FD": {
        "oui_hex": "80-38-FD",
        "organization": "LeapFrog Enterprises, Inc.",
        "address_1": "6401 Holis Street",
        "address_2": "Emeryville  CA  94608",
        "country": "US"
    },
    "ACBEB6": {
        "oui_hex": "AC-BE-B6",
        "organization": "Visualedge Technology Co., Ltd.",
        "address_1": "13FL.-1 No. 716, Zhongzheng Road, Zhonghe City,",
        "address_2": "Taipei County,     23511",
        "country": "TW"
    },
    "2C9127": {
        "oui_hex": "2C-91-27",
        "organization": "Eintechno Corporation",
        "address_1": "3359-1, kako, Inami-cho",
        "address_2": "kako-gun  hyogo  675-1105",
        "country": "JP"
    },
    "AC583B": {
        "oui_hex": "AC-58-3B",
        "organization": "Human Assembler, Inc.",
        "address_1": "2-1-11-6F",
        "address_2": "Shibuya-ku  Tokyo  150-0002",
        "country": "JP"
    },
    "E8E776": {
        "oui_hex": "E8-E7-76",
        "organization": "Shenzhen Kootion Technology Co., Ltd",
        "address_1": "3/F, Building #4, XinJianXing Industrial Park",
        "address_2": "Shenzhen  Guangdong Province  518108",
        "country": "CN"
    },
    "681FD8": {
        "oui_hex": "68-1F-D8",
        "organization": "Siemens Industry, Inc.",
        "address_1": "10670 Treena Street",
        "address_2": "San Diego  CA  92131",
        "country": "US"
    },
    "4001C6": {
        "oui_hex": "40-01-C6",
        "organization": "3COM EUROPE LTD",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  HERTS.  HP2 4NW",
        "country": "GB"
    },
    "9C5E73": {
        "oui_hex": "9C-5E-73",
        "organization": "Calibre UK LTD",
        "address_1": "Cornwall House",
        "address_2": "Bradford  West Yorkshire  BD8 7JS",
        "country": "GB"
    },
    "5C1437": {
        "oui_hex": "5C-14-37",
        "organization": "Thyssenkrupp Aufzugswerke GmbH",
        "address_1": "Bernhaeuser Str.45",
        "address_2": "Neuhausen a.d.F    73765",
        "country": "DE"
    },
    "9C55B4": {
        "oui_hex": "9C-55-B4",
        "organization": "I.S.E. S.r.l.",
        "address_1": "Via della Canapiglia 5",
        "address_2": "Migliarino Pisano  PISA  56010",
        "country": "IT"
    },
    "4C63EB": {
        "oui_hex": "4C-63-EB",
        "organization": "Application Solutions (Electronics and Vision) Ltd",
        "address_1": "The Riverside Centre",
        "address_2": "Lewes  East Sussex  BN7 2AQ",
        "country": "GB"
    },
    "702F97": {
        "oui_hex": "70-2F-97",
        "organization": "Aava Mobile Oy",
        "address_1": "Nahkatehtaankatu 2",
        "address_2": "Oulu    90100",
        "country": "FI"
    },
    "10CA81": {
        "oui_hex": "10-CA-81",
        "organization": "PRECIA",
        "address_1": "Le ruissol VEYRAS",
        "address_2": "PRIVAS    07001",
        "country": "FR"
    },
    "40A6A4": {
        "oui_hex": "40-A6-A4",
        "organization": "PassivSystems Ltd",
        "address_1": "Medway House",
        "address_2": "Newbury  Berks  RG14 2PZ",
        "country": "GB"
    },
    "94BA31": {
        "oui_hex": "94-BA-31",
        "organization": "Visiontec da Amazônia Ltda.",
        "address_1": "Rod. Geraldo Scavone, 2300 - Galpao 27",
        "address_2": "Jacareí  SP  12305-490",
        "country": "BR"
    },
    "B894D2": {
        "oui_hex": "B8-94-D2",
        "organization": "Retail Innovation HTT AB",
        "address_1": "Sjöängsvägen 2",
        "address_2": "Sollentuna    S-192 72",
        "country": "SE"
    },
    "B0E97E": {
        "oui_hex": "B0-E9-7E",
        "organization": "Advanced Micro Peripherals",
        "address_1": "Unit 1 Harrier House",
        "address_2": "Witchford  Cambridgeshire  CB6 2HY",
        "country": "GB"
    },
    "F0C24C": {
        "oui_hex": "F0-C2-4C",
        "organization": "Zhejiang FeiYue Digital Technology Co., Ltd",
        "address_1": "Baoting Industrial Park, 531 Jiaogong Road",
        "address_2": " Hangzhou City  Zhejiang Province  310012",
        "country": "CN"
    },
    "E4751E": {
        "oui_hex": "E4-75-1E",
        "organization": "Getinge Sterilization AB",
        "address_1": "Box 69",
        "address_2": "Getinge    31044",
        "country": "SE"
    },
    "9C5B96": {
        "oui_hex": "9C-5B-96",
        "organization": "NMR Corporation",
        "address_1": "3F Esprit Build.,1-3-6 Nishi-Nippori",
        "address_2": "Arakawa-Ku  Tokyo  116-0013",
        "country": "JP"
    },
    "60F13D": {
        "oui_hex": "60-F1-3D",
        "organization": "JABLOCOM s.r.o.",
        "address_1": "V Nivach 12",
        "address_2": "Jablonec nad Nisou    466 01",
        "country": "CZ"
    },
    "50252B": {
        "oui_hex": "50-25-2B",
        "organization": "Nethra Imaging Incorporated",
        "address_1": "2855 Bowers Ave",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "F8811A": {
        "oui_hex": "F8-81-1A",
        "organization": "OVERKIZ",
        "address_1": "EUROPA 3",
        "address_2": "Archamps    74160",
        "country": "FR"
    },
    "3863F6": {
        "oui_hex": "38-63-F6",
        "organization": "3NOD MULTIMEDIA(SHENZHEN)CO.,LTD",
        "address_1": "F6,Building11,Shenzhen Software Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78B81A": {
        "oui_hex": "78-B8-1A",
        "organization": "INTER SALES A/S",
        "address_1": "Stavneagervej 22",
        "address_2": "Egaa    8250",
        "country": "DK"
    },
    "CC0080": {
        "oui_hex": "CC-00-80",
        "organization": "BETTINI SRL",
        "address_1": "VIA CESARE BATTISTI 22",
        "address_2": "CESANO MADERNO  MILAN  20031",
        "country": "IT"
    },
    "644BC3": {
        "oui_hex": "64-4B-C3",
        "organization": "Shanghai WOASiS Telecommunications Ltd., Co.",
        "address_1": "15F, Software Building,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "942E63": {
        "oui_hex": "94-2E-63",
        "organization": "Finsécur",
        "address_1": "52 rue Paul Lescop",
        "address_2": "Nanterre    92000",
        "country": "FR"
    },
    "AC8317": {
        "oui_hex": "AC-83-17",
        "organization": "Shenzhen Furtunetel Communication Co., Ltd",
        "address_1": "F19 building A zhongke plaza Nan yi street high-tech zone, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "ACD180": {
        "oui_hex": "AC-D1-80",
        "organization": "Crexendo Business Solutions, Inc.",
        "address_1": "10201 S. 5st  St.",
        "address_2": "Phoenix  AZ  85044",
        "country": "US"
    },
    "CCCC4E": {
        "oui_hex": "CC-CC-4E",
        "organization": "Sun Fountainhead USA. Corp",
        "address_1": "801 S. Garfiled AVE # 236",
        "address_2": "Los Angeles   California   91801",
        "country": "US"
    },
    "688540": {
        "oui_hex": "68-85-40",
        "organization": "IGI Mobile, Inc.",
        "address_1": "4F Kyongnam Bldg.,",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "A09A5A": {
        "oui_hex": "A0-9A-5A",
        "organization": "Time Domain",
        "address_1": "330 Wynn Drive",
        "address_2": "Huntsville  AL  35805",
        "country": "US"
    },
    "64A837": {
        "oui_hex": "64-A8-37",
        "organization": "Juni Korea Co., Ltd",
        "address_1": "E603 Bundang Techno-Park 151",
        "address_2": "Seongnam  Gyeonggi  463-760",
        "country": "KR"
    },
    "202CB7": {
        "oui_hex": "20-2C-B7",
        "organization": "Kong Yue Electronics & Information Industry (Xinhui) Ltd.",
        "address_1": "Kong Yue Industrial Park, 18 Kongyue Road, Jinguzhou",
        "address_2": "Jiangmen  Guangdong  529141",
        "country": "CN"
    },
    "609F9D": {
        "oui_hex": "60-9F-9D",
        "organization": "CloudSwitch",
        "address_1": "200 Wheeler Rd",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "48343D": {
        "oui_hex": "48-34-3D",
        "organization": "IEP GmbH",
        "address_1": "Am Pferdemarkt 9c",
        "address_2": "Langenhagen  Niedersachsen  30853",
        "country": "DE"
    },
    "D4AAFF": {
        "oui_hex": "D4-AA-FF",
        "organization": "MICRO WORLD",
        "address_1": "19370 VAN NESS AVE",
        "address_2": "TORRANCE   CA  90501",
        "country": "US"
    },
    "74E537": {
        "oui_hex": "74-E5-37",
        "organization": "RADSPIN",
        "address_1": "Songpa-gu Garak-dong 78",
        "address_2": "Seoul    138-950",
        "country": "KR"
    },
    "0026E9": {
        "oui_hex": "00-26-E9",
        "organization": "SP Corp",
        "address_1": "Guro 3-dong ,Guro-gu",
        "address_2": "Seoul    152-780",
        "country": "KR"
    },
    "0026EB": {
        "oui_hex": "00-26-EB",
        "organization": "Advanced Spectrum Technology Co., Ltd.",
        "address_1": "1F., No.67 Jhongjheng Rd.",
        "address_2": "Sinjhuang  Taiwan  242",
        "country": "TW"
    },
    "0026E1": {
        "oui_hex": "00-26-E1",
        "organization": "Stanford University, OpenFlow Group",
        "address_1": "353 Serra Mall",
        "address_2": "Stanford  CA  94305-9030",
        "country": "US"
    },
    "002717": {
        "oui_hex": "00-27-17",
        "organization": "CE Digital(Zhenjiang)Co.,Ltd",
        "address_1": "Wei 3 Road, Dingmao, Eco.Dev.Zone,",
        "address_2": "Zhenjiang    212009",
        "country": "CN"
    },
    "002716": {
        "oui_hex": "00-27-16",
        "organization": "Adachi-Syokai Co., Ltd.",
        "address_1": "228-2 Hazama Maki",
        "address_2": "Fukuchiyama-shi  Kyoto  620-0913",
        "country": "JP"
    },
    "0026DC": {
        "oui_hex": "00-26-DC",
        "organization": "Optical Systems Design",
        "address_1": "7/1 Vuko Place",
        "address_2": "Warriewood  NSW  2102",
        "country": "AU"
    },
    "002700": {
        "oui_hex": "00-27-00",
        "organization": "Shenzhen Siglent Technology Co., Ltd.",
        "address_1": "BUILDING A8,TANGLANG INDUSTRIAL ZONE,XILI,NANSHAN",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0026EC": {
        "oui_hex": "00-26-EC",
        "organization": "Legrand Home Systems, Inc",
        "address_1": "301 Fulling Mill Rd",
        "address_2": "Middletown  PA  17057",
        "country": "US"
    },
    "0026D4": {
        "oui_hex": "00-26-D4",
        "organization": "IRCA SpA",
        "address_1": "Viale Venezia 31 - C.P. 248",
        "address_2": "San Vendemiano (Treviso)  Italy  31020",
        "country": "IT"
    },
    "002663": {
        "oui_hex": "00-26-63",
        "organization": "Shenzhen Huitaiwei Tech. Ltd, co.",
        "address_1": "JianDa Building,501-502",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "002661": {
        "oui_hex": "00-26-61",
        "organization": "Irumtek Co., Ltd.",
        "address_1": "Apt 708  513-22 Joongil Eines Platz",
        "address_2": "Seongnam-City  Gyunggi-do  462-120",
        "country": "KR"
    },
    "00265B": {
        "oui_hex": "00-26-5B",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "002656": {
        "oui_hex": "00-26-56",
        "organization": "Sansonic Electronics USA",
        "address_1": "9950 Baldwin Place",
        "address_2": "El Monte  Cailfornia  91731",
        "country": "US"
    },
    "00267D": {
        "oui_hex": "00-26-7D",
        "organization": "A-Max Technology Macao Commercial Offshore Company Limited",
        "address_1": "Avenida Da Praia Grande No. 409",
        "address_2": "Macau",
        "country": "CN"
    },
    "00267C": {
        "oui_hex": "00-26-7C",
        "organization": "Metz-Werke GmbH & Co KG",
        "address_1": "Ohmstrasse 55",
        "address_2": "Zirndorf    90513",
        "country": "DE"
    },
    "002673": {
        "oui_hex": "00-26-73",
        "organization": "RICOH COMPANY,LTD.",
        "address_1": "810 Shimoimaizumi",
        "address_2": "Ebina-City  Kanagawa-Pref  243-0460",
        "country": "JP"
    },
    "00266D": {
        "oui_hex": "00-26-6D",
        "organization": "MobileAccess Networks",
        "address_1": "8391 Old Courthouse Rd.",
        "address_2": "Vienna  VA  22182",
        "country": "US"
    },
    "0026C0": {
        "oui_hex": "00-26-C0",
        "organization": "EnergyHub",
        "address_1": "232 3rd St C201",
        "address_2": "Brooklyn  NY  11215",
        "country": "US"
    },
    "0026C1": {
        "oui_hex": "00-26-C1",
        "organization": "ARTRAY CO., LTD.",
        "address_1": "5F Ueno Bldg, 1-17-5 Kouenjikita,",
        "address_2": "Tokyo    166-0002",
        "country": "JP"
    },
    "0026BE": {
        "oui_hex": "00-26-BE",
        "organization": "Schoonderbeek Elektronica Systemen B.V.",
        "address_1": "Roggestraat 3-5",
        "address_2": "Nieuw Vennep  Noord Holland  2153GC",
        "country": "NL"
    },
    "0026B5": {
        "oui_hex": "00-26-B5",
        "organization": "ICOMM Tele Ltd",
        "address_1": "304, Trendset Towers,",
        "address_2": "Hyderabad  AP  500034",
        "country": "IN"
    },
    "00268C": {
        "oui_hex": "00-26-8C",
        "organization": "StarLeaf Ltd.",
        "address_1": "Chaston House, Mill Court",
        "address_2": "Cambridge    CB22 5LD",
        "country": "GB"
    },
    "00268B": {
        "oui_hex": "00-26-8B",
        "organization": "Guangzhou Escene Computer Technology Limited",
        "address_1": "Room 209, No.54-56 Yuehe Building, Huacui Street, Tianhe Industrial Park",
        "address_2": "Guangzhou  Guangdong Province  510065",
        "country": "CN"
    },
    "00266F": {
        "oui_hex": "00-26-6F",
        "organization": "Coordiwise Technology Corp.",
        "address_1": "2F., No.123, Sec. 1, Lioujia 5th Rd.",
        "address_2": "Jhubei City, Hsinchu County    30272",
        "country": "TW"
    },
    "00266E": {
        "oui_hex": "00-26-6E",
        "organization": "Nissho-denki Co.,LTD.",
        "address_1": "3-7-6,chidori",
        "address_2": "ohta  Tokyo  146-0083",
        "country": "JP"
    },
    "0026C3": {
        "oui_hex": "00-26-C3",
        "organization": "Insightek Corp.",
        "address_1": "5F,NO.755,Chung Cheng Rd.,",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "002681": {
        "oui_hex": "00-26-81",
        "organization": "Interspiro AB",
        "address_1": "Box 2853",
        "address_2": "Täby    18728",
        "country": "SE"
    },
    "002683": {
        "oui_hex": "00-26-83",
        "organization": "Ajoho Enterprise Co., Ltd.",
        "address_1": "7F., No.101, Ruihu St.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00267F": {
        "oui_hex": "00-26-7F",
        "organization": "Zenterio AB",
        "address_1": "Diskettgatan 11B",
        "address_2": "Linköping    58335",
        "country": "SE"
    },
    "002698": {
        "oui_hex": "00-26-98",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00269B": {
        "oui_hex": "00-26-9B",
        "organization": "SOKRAT Ltd.",
        "address_1": "Volkonskogo 2",
        "address_2": "Irkutsk    664007",
        "country": "RU"
    },
    "0026A1": {
        "oui_hex": "00-26-A1",
        "organization": "Megger",
        "address_1": "4271 Bronze Way",
        "address_2": "Dallas  Texas  75237",
        "country": "US"
    },
    "002644": {
        "oui_hex": "00-26-44",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "002646": {
        "oui_hex": "00-26-46",
        "organization": "SHENYANG TONGFANG MULTIMEDIA TECHNOLOGY COMPANY LIMITED",
        "address_1": "No.10 Ping Nan East Road",
        "address_2": "Shenyang  Liao Ning  110014",
        "country": "CN"
    },
    "00263F": {
        "oui_hex": "00-26-3F",
        "organization": "LIOS Technology GmbH",
        "address_1": "Schanzenstraße 39",
        "address_2": "Köln  Germany  D-51063",
        "country": "DE"
    },
    "00263B": {
        "oui_hex": "00-26-3B",
        "organization": "Onbnetech",
        "address_1": "506, Samsung IT Valley, 197-5",
        "address_2": "Guro-Gu  Seoul  152-848",
        "country": "KR"
    },
    "002658": {
        "oui_hex": "00-26-58",
        "organization": "T-Platforms (Cyprus) Limited",
        "address_1": "Themistokli Dervi 3, Julia House",
        "address_2": "Nicosia    P.C.-1066",
        "country": "CY"
    },
    "00264C": {
        "oui_hex": "00-26-4C",
        "organization": "Shanghai DigiVision Technology Co., Ltd.",
        "address_1": "No. 333 Guangji Rd.",
        "address_2": "Shanghai    200083",
        "country": "CN"
    },
    "00262F": {
        "oui_hex": "00-26-2F",
        "organization": "HAMAMATSU TOA ELECTRONICS",
        "address_1": "9162-1",
        "address_2": "HAMAMATSU  SIZUOKA  431-2102",
        "country": "JP"
    },
    "002631": {
        "oui_hex": "00-26-31",
        "organization": "COMMTACT LTD",
        "address_1": "Nahal Snir 10",
        "address_2": "Yazne    81101",
        "country": "IL"
    },
    "0025FB": {
        "oui_hex": "00-25-FB",
        "organization": "Tunstall Healthcare A/S",
        "address_1": "Stroemmen 6",
        "address_2": "Noerresundby    9400",
        "country": "DK"
    },
    "0025F4": {
        "oui_hex": "00-25-F4",
        "organization": "KoCo Connector AG",
        "address_1": "Marienstraße 12",
        "address_2": "Berlin    10117",
        "country": "DE"
    },
    "002606": {
        "oui_hex": "00-26-06",
        "organization": "RAUMFELD GmbH",
        "address_1": "Reichenberger Str. 124",
        "address_2": "Berlin    10999",
        "country": "DE"
    },
    "002607": {
        "oui_hex": "00-26-07",
        "organization": "Enabling Technology Pty Ltd",
        "address_1": "23/44 Kings Park Road",
        "address_2": "West Perth  Western Australia  6005",
        "country": "AU"
    },
    "002624": {
        "oui_hex": "00-26-24",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290",
        "country": "US"
    },
    "002605": {
        "oui_hex": "00-26-05",
        "organization": "CC Systems AB",
        "address_1": "Box 83",
        "address_2": "Alfta    822 22",
        "country": "SE"
    },
    "002602": {
        "oui_hex": "00-26-02",
        "organization": "SMART Temps LLC",
        "address_1": "435 PARK PL CIRCLE SUITE 100",
        "address_2": "Mishawaka  IN  46545",
        "country": "US"
    },
    "00261A": {
        "oui_hex": "00-26-1A",
        "organization": "Femtocomm System Technology Corp.",
        "address_1": "2F.-2,No.28, Taiyuan St.,",
        "address_2": "Jhubei City,  Hsinchu Country,  30288",
        "country": "TW"
    },
    "002634": {
        "oui_hex": "00-26-34",
        "organization": "Infineta Systems, Inc",
        "address_1": "2870 Zanker Rd",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "002599": {
        "oui_hex": "00-25-99",
        "organization": "Hedon e.d. B.V.",
        "address_1": "Elektronicaweg 15",
        "address_2": "Delft  Zuid Holland  2628 XG",
        "country": "NL"
    },
    "002597": {
        "oui_hex": "00-25-97",
        "organization": "Kalki Communication Technologies",
        "address_1": "4th Floor, Survey. No. 17/1, Outer Ring Road",
        "address_2": "Opp. Prestige Cessna Park  Bangalore   560 103",
        "country": "IN"
    },
    "002592": {
        "oui_hex": "00-25-92",
        "organization": "Guangzhou Shirui Electronic Co., Ltd",
        "address_1": "301D, No.9, Caipin Road,",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "002594": {
        "oui_hex": "00-25-94",
        "organization": "Eurodesign BG LTD",
        "address_1": "Business Park Sofia, Building 4, Floor 2",
        "address_2": "Sofia    1113",
        "country": "BG"
    },
    "00259F": {
        "oui_hex": "00-25-9F",
        "organization": "TechnoDigital Technologies GmbH",
        "address_1": "Haesslerstraße 8",
        "address_2": "Erfurt  Thuringia  99096",
        "country": "DE"
    },
    "00259D": {
        "oui_hex": "00-25-9D",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002598": {
        "oui_hex": "00-25-98",
        "organization": "Zhong Shan City Litai Electronic Industrial Co. Ltd",
        "address_1": "No.3 Industrial District, Wuguishan, Cheng gui Road",
        "address_2": "Zhong shan City  Guang dong Province  528458",
        "country": "CN"
    },
    "0025E3": {
        "oui_hex": "00-25-E3",
        "organization": "Hanshinit Inc.",
        "address_1": "Dong-Won Bld 3F, 395-13, Gal-Ma 2, Seo-Gu",
        "address_2": "Daejeon    302-809",
        "country": "KR"
    },
    "0025D4": {
        "oui_hex": "00-25-D4",
        "organization": "General Dynamics Mission Systems",
        "address_1": "150 Rustcraft Road",
        "address_2": "Dedham  MA  02026",
        "country": "US"
    },
    "0025C2": {
        "oui_hex": "00-25-C2",
        "organization": "RingBell Co.,Ltd.",
        "address_1": "10586 KingGeorge Hwy",
        "address_2": "Surrey  B.C  V3T 2X3",
        "country": "CA"
    },
    "0025A7": {
        "oui_hex": "00-25-A7",
        "organization": "itron",
        "address_1": "5390 Triangle Parkway",
        "address_2": "Norcross  GA  30092",
        "country": "US"
    },
    "0025A9": {
        "oui_hex": "00-25-A9",
        "organization": "Shanghai Embedway Information Technologies Co.,Ltd",
        "address_1": "2F,Building 9,Lujiazui Software Park, No.20,Lane 91,E'Shan Road",
        "address_2": "Shanghai    200127",
        "country": "CN"
    },
    "0025CA": {
        "oui_hex": "00-25-CA",
        "organization": "LS Research, LLC",
        "address_1": "W66 N220 Commerce Court",
        "address_2": "Cedarburg  WI  53012",
        "country": "US"
    },
    "0025B4": {
        "oui_hex": "00-25-B4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0025B2": {
        "oui_hex": "00-25-B2",
        "organization": "MBDA Deutschland GmbH",
        "address_1": "Hagenauer Forst 27",
        "address_2": "Schrobenhausen  Bavaria  86529",
        "country": "DE"
    },
    "0025EF": {
        "oui_hex": "00-25-EF",
        "organization": "I-TEC Co., Ltd.",
        "address_1": "7/F,KAWARAMACHI KOYO BLDG.3-4-3,KAWARAMCHI,CHUO-KU,",
        "address_2": "OSAKA    541-0048",
        "country": "JP"
    },
    "002528": {
        "oui_hex": "00-25-28",
        "organization": "Daido Signal Co., Ltd.",
        "address_1": "6-17-19",
        "address_2": "Minato-ku  TOKYO  105-8650",
        "country": "JP"
    },
    "002526": {
        "oui_hex": "00-25-26",
        "organization": "Genuine Technologies Co., Ltd.",
        "address_1": "Klingelnberg Bldg.",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "00256B": {
        "oui_hex": "00-25-6B",
        "organization": "ATENIX E.E. s.r.l.",
        "address_1": "Via Torricelli, 15/b",
        "address_2": "VERONA  VR  37135",
        "country": "IT"
    },
    "00256E": {
        "oui_hex": "00-25-6E",
        "organization": "Van Breda B.V.",
        "address_1": "Mercuriusweg 21",
        "address_2": "Brummen  Gelderland  6971 GV",
        "country": "NL"
    },
    "002565": {
        "oui_hex": "00-25-65",
        "organization": "Vizimax Inc.",
        "address_1": "2284, rue de la Province",
        "address_2": "Longueuil  Québec  J4G 1G1",
        "country": "CA"
    },
    "00255E": {
        "oui_hex": "00-25-5E",
        "organization": "Shanghai Dare Technologies Co.,Ltd.",
        "address_1": "22F,Info Tech Building, No.1555,Kongjiang Road,",
        "address_2": "  Shanghai  200092",
        "country": "CN"
    },
    "00253B": {
        "oui_hex": "00-25-3B",
        "organization": "din Dietmar Nocker Facilitymanagement GmbH",
        "address_1": "Kotzinastrasse 5",
        "address_2": "Linz  Upper Austria  4030",
        "country": "AT"
    },
    "00253D": {
        "oui_hex": "00-25-3D",
        "organization": "DRS Consolidated Controls",
        "address_1": "21 South Street",
        "address_2": "Danbury  CT  06810-8147",
        "country": "US"
    },
    "002535": {
        "oui_hex": "00-25-35",
        "organization": "Minimax GmbH & Co KG",
        "address_1": "Industriestrasse 10/12",
        "address_2": "Bad Oldesloe  SH  23840",
        "country": "DE"
    },
    "002584": {
        "oui_hex": "00-25-84",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002579": {
        "oui_hex": "00-25-79",
        "organization": "J & F Labs",
        "address_1": "1214 W. Boston Post Road",
        "address_2": "Mamaroneck  NY  10543",
        "country": "US"
    },
    "00257F": {
        "oui_hex": "00-25-7F",
        "organization": "CallTechSolution Co.,Ltd",
        "address_1": "#123,Daewooprugio B/D,344-1, Seogyo-Dong,Mapo-gu",
        "address_2": "Seoul    121-837",
        "country": "KR"
    },
    "002577": {
        "oui_hex": "00-25-77",
        "organization": "D-BOX Technologies",
        "address_1": "2172 de la Province",
        "address_2": "Longueuil  Quebec  J4G 1R7",
        "country": "CA"
    },
    "002572": {
        "oui_hex": "00-25-72",
        "organization": "Nemo-Q International AB",
        "address_1": "Box 210",
        "address_2": "Sollentuna    19123",
        "country": "SE"
    },
    "002529": {
        "oui_hex": "00-25-29",
        "organization": "COMELIT GROUP S.P.A",
        "address_1": "DON ARRIGONI N. 5",
        "address_2": "SAN LORENZO, ROVETTA  BERGAMO  24020",
        "country": "IT"
    },
    "00252A": {
        "oui_hex": "00-25-2A",
        "organization": "Chengdu GeeYa Technology Co.,LTD",
        "address_1": "50 Shuxi Road,",
        "address_2": "Chengdu  SiChuan  610091",
        "country": "CN"
    },
    "00258A": {
        "oui_hex": "00-25-8A",
        "organization": "Pole/Zero Corporation",
        "address_1": "5530 Union Centre Drive",
        "address_2": "West Chester  OH  45069",
        "country": "US"
    },
    "00255F": {
        "oui_hex": "00-25-5F",
        "organization": "SenTec AG",
        "address_1": "Ringstrasse 39",
        "address_2": "Therwil    4106",
        "country": "CH"
    },
    "0024EC": {
        "oui_hex": "00-24-EC",
        "organization": "United Information Technology Co.,Ltd.",
        "address_1": "5/F,9th Building,Software Park,2nd Keji-zhong Road,High-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0024E6": {
        "oui_hex": "00-24-E6",
        "organization": "In Motion Technology Inc.",
        "address_1": "#350, 625 Agnes Street",
        "address_2": "New Westminster  BC  V3M 5Y4",
        "country": "CA"
    },
    "0024E7": {
        "oui_hex": "00-24-E7",
        "organization": "Plaster Networks",
        "address_1": "935 Hamilton Avenue",
        "address_2": "Menlo Park  CA  94025-1431",
        "country": "US"
    },
    "0024E4": {
        "oui_hex": "00-24-E4",
        "organization": "Withings",
        "address_1": "37bis rue du General Leclerc",
        "address_2": "Issy les Moulineaux    92442",
        "country": "FR"
    },
    "0024DE": {
        "oui_hex": "00-24-DE",
        "organization": "GLOBAL Technology Inc.",
        "address_1": "No.168,Shanshan Rd., Wangchun Industrial Park,",
        "address_2": "Ningbo    315176",
        "country": "CN"
    },
    "0024DC": {
        "oui_hex": "00-24-DC",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0024DB": {
        "oui_hex": "00-24-DB",
        "organization": "Alcohol Monitoring Systems",
        "address_1": "1241 W. Mineral Avenue",
        "address_2": "Littleton  CO  80120",
        "country": "US"
    },
    "002521": {
        "oui_hex": "00-25-21",
        "organization": "Logitek Electronic Systems, Inc.",
        "address_1": "5622 Edgemoor Drive",
        "address_2": "Houston  Texas  77081",
        "country": "US"
    },
    "00251F": {
        "oui_hex": "00-25-1F",
        "organization": "ZYNUS VISION INC.",
        "address_1": "1-1-7-1A",
        "address_2": "SAGAMIHARA  KANAGAWA  229-0039",
        "country": "JP"
    },
    "00251E": {
        "oui_hex": "00-25-1E",
        "organization": "ROTEL TECHNOLOGIES",
        "address_1": "CEVIZLIDERE 14.CD NO:2/19 BALGAT",
        "address_2": "ANKARA    06520",
        "country": "TR"
    },
    "002519": {
        "oui_hex": "00-25-19",
        "organization": "Viaas Inc",
        "address_1": "3175 South Winchester Blvd",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "0024D5": {
        "oui_hex": "00-24-D5",
        "organization": "Winward Industrial Limited",
        "address_1": "Rm.7, P Floor, Tower A,",
        "address_2": "HongKong    852",
        "country": "CN"
    },
    "0024DD": {
        "oui_hex": "00-24-DD",
        "organization": "Centrak, Inc.",
        "address_1": "207 Penns Trail",
        "address_2": "Newtown  PA  18940",
        "country": "US"
    },
    "0024EA": {
        "oui_hex": "00-24-EA",
        "organization": "iris-GmbH infrared & intelligent sensors",
        "address_1": "Ostendstraße 1-14",
        "address_2": "Berlin    12459",
        "country": "DE"
    },
    "0024ED": {
        "oui_hex": "00-24-ED",
        "organization": "YT Elec. Co,.Ltd.",
        "address_1": "Block B,2 Floor ,Bao Ying Industrial District,",
        "address_2": "Wu Lian Lu  Shenzhen  518116",
        "country": "CN"
    },
    "002503": {
        "oui_hex": "00-25-03",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002504": {
        "oui_hex": "00-25-04",
        "organization": "Valiant Communications Limited",
        "address_1": "71-1 Shivaji Marg",
        "address_2": "New Delhi  Delhi  110015",
        "country": "IN"
    },
    "002513": {
        "oui_hex": "00-25-13",
        "organization": "CXP DIGITAL BV",
        "address_1": "De Reulver 97A",
        "address_2": "Enschede    7544RT",
        "country": "NL"
    },
    "0024A4": {
        "oui_hex": "00-24-A4",
        "organization": "Siklu Communication",
        "address_1": "7 Shoham St., , 3rd Floor",
        "address_2": "Petah Tikva    49517",
        "country": "IL"
    },
    "00249A": {
        "oui_hex": "00-24-9A",
        "organization": "Beijing Zhongchuang Telecommunication Test Co., Ltd.",
        "address_1": "12-14,Block C,Beijing International Building,#18,Zhong Guan Cun Nan Road,",
        "address_2": "Beijing    100081",
        "country": "CN"
    },
    "00249E": {
        "oui_hex": "00-24-9E",
        "organization": "ADC-Elektronik GmbH",
        "address_1": "Östingstraße 13b",
        "address_2": "Hamm  NRW  D-59063",
        "country": "DE"
    },
    "00249F": {
        "oui_hex": "00-24-9F",
        "organization": "RIM Testing Services",
        "address_1": "440 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 5R9",
        "country": "CA"
    },
    "0024C2": {
        "oui_hex": "00-24-C2",
        "organization": "Asumo Co.,Ltd.",
        "address_1": "Oya-Kita 1-3-1",
        "address_2": "EBINA-CITY  KANAGAWA-PREF.  243-0419",
        "country": "JP"
    },
    "0024BF": {
        "oui_hex": "00-24-BF",
        "organization": "CIAT",
        "address_1": "30, Avenue Jean Falconnier",
        "address_2": "Culoz    01350",
        "country": "FR"
    },
    "0024C0": {
        "oui_hex": "00-24-C0",
        "organization": "NTI COMODO INC",
        "address_1": "Rm#502, Kangyong Bldg, Sungnam-dong",
        "address_2": "Sungnam-si  Kyunggi-do  462-827",
        "country": "KR"
    },
    "0024BB": {
        "oui_hex": "00-24-BB",
        "organization": "CENTRAL Corporation",
        "address_1": "NISSO 17 Bldg.7F 2-14-30",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "0024BC": {
        "oui_hex": "00-24-BC",
        "organization": "HuRob Co.,Ltd",
        "address_1": "2121, Jeongwang-Dong",
        "address_2": "Siheung-Si  Gyeonggi-Do  429-793",
        "country": "KR"
    },
    "0024AD": {
        "oui_hex": "00-24-AD",
        "organization": "Adolf Thies Gmbh & Co. KG",
        "address_1": "Hauptstraße 76",
        "address_2": "Göttingen    37083",
        "country": "DE"
    },
    "0024A7": {
        "oui_hex": "00-24-A7",
        "organization": "Advanced Video Communications Inc.",
        "address_1": "633 W 5th Street",
        "address_2": "Los Angeles  CA  90017",
        "country": "US"
    },
    "0024AB": {
        "oui_hex": "00-24-AB",
        "organization": "A7 Engineering, Inc.",
        "address_1": "12127 Kirkham Road Suite 101",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "002466": {
        "oui_hex": "00-24-66",
        "organization": "Unitron nv",
        "address_1": "Franrkijklaan 27",
        "address_2": "Poperinge  W-vl  8970",
        "country": "BE"
    },
    "00245F": {
        "oui_hex": "00-24-5F",
        "organization": "Vine Telecom CO.,Ltd.",
        "address_1": "191-4, 4F, Anyang-dong, Manan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  430-010",
        "country": "KR"
    },
    "002455": {
        "oui_hex": "00-24-55",
        "organization": "MuLogic BV",
        "address_1": "Olivier van Noortstraat 4",
        "address_2": "Schiedam  ZH  3124LA",
        "country": "NL"
    },
    "002488": {
        "oui_hex": "00-24-88",
        "organization": "Centre For Development Of Telematics",
        "address_1": "B01, Electronic City, Phase 1",
        "address_2": "Bangalore  Karnataka  560100",
        "country": "IN"
    },
    "00248F": {
        "oui_hex": "00-24-8F",
        "organization": "DO-MONIX",
        "address_1": "#501, Koreana B/D",
        "address_2": "Seongnam-si  Gyeonggi-do  82",
        "country": "KP"
    },
    "002479": {
        "oui_hex": "00-24-79",
        "organization": "Optec Displays, Inc.",
        "address_1": "528 S. 6th Avenue",
        "address_2": "City of Industry  California  91746",
        "country": "US"
    },
    "0024B7": {
        "oui_hex": "00-24-B7",
        "organization": "GridPoint, Inc.",
        "address_1": "2801 Clarendon Blvd.",
        "address_2": "Arlington  VA  22201",
        "country": "US"
    },
    "0024AE": {
        "oui_hex": "00-24-AE",
        "organization": "IDEMIA",
        "address_1": "18 chaussee Jules Cesar",
        "address_2": "OSNY    95520",
        "country": "FR"
    },
    "002468": {
        "oui_hex": "00-24-68",
        "organization": "Sumavision Technologies Co.,Ltd",
        "address_1": "6F, Block A2, Power Creative Building,No.1 Shangdi East Road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "00243A": {
        "oui_hex": "00-24-3A",
        "organization": "Ludl Electronic Products",
        "address_1": "171 Brady Ave",
        "address_2": "Hawthorne  NY  10532",
        "country": "US"
    },
    "002439": {
        "oui_hex": "00-24-39",
        "organization": "Digital Barriers Advanced Technologies",
        "address_1": "4th Floor",
        "address_2": "Glasgow  Lanarkshire  G1 2QQ",
        "country": "GB"
    },
    "002434": {
        "oui_hex": "00-24-34",
        "organization": "Lectrosonics, Inc.",
        "address_1": "581 Laser Rd.",
        "address_2": "Rio Rancho  NM  87124",
        "country": "US"
    },
    "00245A": {
        "oui_hex": "00-24-5A",
        "organization": "Nanjing Panda Electronics Company Limited",
        "address_1": "Zhongshan EastRoad 301,",
        "address_2": "NANJING  JIANGSU  210016",
        "country": "CN"
    },
    "00245B": {
        "oui_hex": "00-24-5B",
        "organization": "RAIDON TECHNOLOGY, INC.",
        "address_1": "4F-8, NO.16, Lane 609, Sec.5, Chung-Hsin Rd.,",
        "address_2": "San-Chung City  Taipei county,  24159",
        "country": "TW"
    },
    "002459": {
        "oui_hex": "00-24-59",
        "organization": "ABB Automation products GmbH",
        "address_1": "Eppelheimer Strasse 82",
        "address_2": "Heidelberg    69123",
        "country": "DE"
    },
    "00244E": {
        "oui_hex": "00-24-4E",
        "organization": "RadChips, Inc.",
        "address_1": "422 East Vermijo Ave.",
        "address_2": "Colorado Springs  CO  80903",
        "country": "US"
    },
    "00240D": {
        "oui_hex": "00-24-0D",
        "organization": "OnePath Networks LTD.",
        "address_1": "8 Hartom St",
        "address_2": "Jerusalem    91450",
        "country": "IL"
    },
    "00240B": {
        "oui_hex": "00-24-0B",
        "organization": "Virtual Computer Inc.",
        "address_1": "3 LAN Drive",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "002402": {
        "oui_hex": "00-24-02",
        "organization": "Op-Tection GmbH",
        "address_1": "Borsigstraße 80",
        "address_2": "Heinsberg  Germany  52525",
        "country": "DE"
    },
    "00242F": {
        "oui_hex": "00-24-2F",
        "organization": "Micron",
        "address_1": "8000 S Federal Way",
        "address_2": "Boise  ID  83716",
        "country": "US"
    },
    "002426": {
        "oui_hex": "00-24-26",
        "organization": "NOHMI BOSAI LTD.",
        "address_1": "7-3,Kudan-Minami 4-Chome,",
        "address_2": "Tokyo    102-8277",
        "country": "JP"
    },
    "002418": {
        "oui_hex": "00-24-18",
        "organization": "Nextwave Semiconductor",
        "address_1": "3610 Valley Centre Dr",
        "address_2": "San Diego  CA  92130",
        "country": "US"
    },
    "002412": {
        "oui_hex": "00-24-12",
        "organization": "Benign Technologies Co, Ltd.",
        "address_1": "504 room, 5F, South building, Forsafe Tower,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002429": {
        "oui_hex": "00-24-29",
        "organization": "MK MASTER INC.",
        "address_1": "6F, -1, NO. 110,SEC. 3, JHONGSHAN RD.,",
        "address_2": "JHONG-HE CITY,  TAIPEI COUNTY  235",
        "country": "TW"
    },
    "0023DB": {
        "oui_hex": "00-23-DB",
        "organization": "saxnet gmbh",
        "address_1": "Willy-Brandt-Ring 1",
        "address_2": "Oelsnitz  Sachsen  08606",
        "country": "DE"
    },
    "0023C8": {
        "oui_hex": "00-23-C8",
        "organization": "TEAM-R",
        "address_1": "Gragdanski str.111, A, 9-N",
        "address_2": "St. Petersburg    195265",
        "country": "RU"
    },
    "0023EB": {
        "oui_hex": "00-23-EB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0023EC": {
        "oui_hex": "00-23-EC",
        "organization": "Algorithmix GmbH",
        "address_1": "Klettgaustrasse 21",
        "address_2": "Waldshut-Tiengen  BW  79761",
        "country": "US"
    },
    "0023C1": {
        "oui_hex": "00-23-C1",
        "organization": "Securitas Direct AB",
        "address_1": "Angbatsbron 1",
        "address_2": "Malmö    21120",
        "country": "SE"
    },
    "0023AA": {
        "oui_hex": "00-23-AA",
        "organization": "HFR, Inc.",
        "address_1": "5F, Hana EZ Tower",
        "address_2": "Sungnam-si  Kyunggi-do  463-870",
        "country": "KR"
    },
    "0023A5": {
        "oui_hex": "00-23-A5",
        "organization": "SageTV, LLC",
        "address_1": "9800 S. La Cienega Blvd",
        "address_2": "Inglewood  CA  90301",
        "country": "US"
    },
    "00239E": {
        "oui_hex": "00-23-9E",
        "organization": "Jiangsu Lemote Technology Corporation Limited",
        "address_1": "Menglan Industrial Park,Yushan",
        "address_2": "Changshu  Jiangsu  215500",
        "country": "CN"
    },
    "0023FC": {
        "oui_hex": "00-23-FC",
        "organization": "Ultra Stereo Labs, Inc",
        "address_1": "181 Bonetti Drive",
        "address_2": "San Luis Obispo  CA  93401",
        "country": "US"
    },
    "0023BB": {
        "oui_hex": "00-23-BB",
        "organization": "Schmitt Industries",
        "address_1": "2765 NW Nicolai St",
        "address_2": "Portland  Oregon  97210",
        "country": "US"
    },
    "00238D": {
        "oui_hex": "00-23-8D",
        "organization": "Techno Design Co., Ltd.",
        "address_1": "312-2",
        "address_2": "Aso-gun  Kumamoto-ken  861-2401",
        "country": "JP"
    },
    "002387": {
        "oui_hex": "00-23-87",
        "organization": "ThinkFlood, Inc.",
        "address_1": "138 Claflin St",
        "address_2": "Belmont  MA  02478",
        "country": "US"
    },
    "002384": {
        "oui_hex": "00-23-84",
        "organization": "GGH Engineering s.r.l.",
        "address_1": "Via Agucchi 84/2",
        "address_2": "Bologna    40133",
        "country": "IT"
    },
    "002391": {
        "oui_hex": "00-23-91",
        "organization": "Maxian",
        "address_1": "21th Fl. KINS tower, 25-1",
        "address_2": "Seongnam-city  Gyeonggi-do  463-847",
        "country": "KR"
    },
    "002392": {
        "oui_hex": "00-23-92",
        "organization": "Proteus Industries Inc.",
        "address_1": "340 Pioneer Way",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "002393": {
        "oui_hex": "00-23-93",
        "organization": "AJINEXTEK",
        "address_1": "9-3, Holimdong, Dalseogu",
        "address_2": "Daegu    704-240",
        "country": "KR"
    },
    "00237F": {
        "oui_hex": "00-23-7F",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "00236F": {
        "oui_hex": "00-23-6F",
        "organization": "DAQ System",
        "address_1": "Rm 913, SungNam Woolim Lions VAlley I, 311-3",
        "address_2": "Sungnam-Si  Kyunggi-Do,  462-806",
        "country": "KR"
    },
    "002330": {
        "oui_hex": "00-23-30",
        "organization": "DIZIPIA, INC.",
        "address_1": "15th Floor, East Wing, IT Venture Tower",
        "address_2": "Seoul    138160",
        "country": "KR"
    },
    "002369": {
        "oui_hex": "00-23-69",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "0022F8": {
        "oui_hex": "00-22-F8",
        "organization": "PIMA Electronic Systems Ltd.",
        "address_1": "5 Hatzoref St.",
        "address_2": "Holon    58856",
        "country": "IL"
    },
    "00231C": {
        "oui_hex": "00-23-1C",
        "organization": "Fourier Systems Ltd.",
        "address_1": "16 Hamelacha St",
        "address_2": "Rosh Haayin    48091",
        "country": "IL"
    },
    "00231D": {
        "oui_hex": "00-23-1D",
        "organization": "Deltacom Electronics Ltd",
        "address_1": "2F,ZIT,7km Tzarigradsko Shose",
        "address_2": "Sofia  Sofia-grad  1784",
        "country": "BG"
    },
    "0022D7": {
        "oui_hex": "00-22-D7",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0022D6": {
        "oui_hex": "00-22-D6",
        "organization": "Cypak AB",
        "address_1": "P.O. BOX 2332",
        "address_2": "Stockholm    103 18",
        "country": "SE"
    },
    "0022D0": {
        "oui_hex": "00-22-D0",
        "organization": "Polar Electro Oy",
        "address_1": "Professorintie 5",
        "address_2": "Kempele  Oulu  90440",
        "country": "FI"
    },
    "00230A": {
        "oui_hex": "00-23-0A",
        "organization": "ARBURG GmbH & Co KG",
        "address_1": "Arthur Hehl Straße",
        "address_2": "Lossburg    D-72290",
        "country": "DE"
    },
    "0022C3": {
        "oui_hex": "00-22-C3",
        "organization": "Zeeport Technology Inc.",
        "address_1": "1F,No231,Xianzheng 2nd Rd.",
        "address_2": "HsinChu  Taiwan  300",
        "country": "TW"
    },
    "002316": {
        "oui_hex": "00-23-16",
        "organization": "KISAN ELECTRONICS CO",
        "address_1": "317-15",
        "address_2": "SEOUNG-DONG GU  SEOUL  133-123",
        "country": "KR"
    },
    "00230F": {
        "oui_hex": "00-23-0F",
        "organization": "Hirsch Electronics Corporation",
        "address_1": "1900 Carnegie, Bldg. B",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "00232D": {
        "oui_hex": "00-23-2D",
        "organization": "SandForce",
        "address_1": "12950 Saratoga Ave.",
        "address_2": "Saratoga  California  95070-4658",
        "country": "US"
    },
    "002323": {
        "oui_hex": "00-23-23",
        "organization": "Zylin AS",
        "address_1": "Auglendsdalen 78",
        "address_2": "Stavanger    4017",
        "country": "NO"
    },
    "0022DE": {
        "oui_hex": "00-22-DE",
        "organization": "OPPO Digital, Inc.",
        "address_1": "2629B Terminal Blvd",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0022F1": {
        "oui_hex": "00-22-F1",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0022A2": {
        "oui_hex": "00-22-A2",
        "organization": "Xtramus Technologies",
        "address_1": "5th Fl., No. 102, Lide St.,",
        "address_2": "Zhonghe City  Taipei County  235",
        "country": "TW"
    },
    "00229E": {
        "oui_hex": "00-22-9E",
        "organization": "Social Aid Research Co., Ltd.",
        "address_1": "South 3, West 10, Chuo-ku",
        "address_2": "Sapporo  Hokkaido  060-0063",
        "country": "JP"
    },
    "002285": {
        "oui_hex": "00-22-85",
        "organization": "NOMUS COMM SYSTEMS",
        "address_1": "601, Gunjan Tower,",
        "address_2": "Baroda  Gujarat  390023",
        "country": "IN"
    },
    "002281": {
        "oui_hex": "00-22-81",
        "organization": "Daintree Networks Pty",
        "address_1": "1 Dalmore Drive",
        "address_2": "Scoresby  Victoria  3179",
        "country": "AU"
    },
    "002255": {
        "oui_hex": "00-22-55",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00224E": {
        "oui_hex": "00-22-4E",
        "organization": "SEEnergy Corp.",
        "address_1": "4F, No.61, Dongsing RD.",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "002287": {
        "oui_hex": "00-22-87",
        "organization": "Titan Wireless LLC",
        "address_1": "3914 Gattis School Rd",
        "address_2": "Round Rock  Texas  78664",
        "country": "US"
    },
    "002288": {
        "oui_hex": "00-22-88",
        "organization": "Sagrad, Inc.",
        "address_1": "751 North Drive",
        "address_2": "Melbourne  FL  32934",
        "country": "US"
    },
    "002273": {
        "oui_hex": "00-22-73",
        "organization": "Techway",
        "address_1": "Rm 1002, Daehyun Techno World Bd,",
        "address_2": "Uiwang-Si,  Kyungki-Do  437-820",
        "country": "KR"
    },
    "00226B": {
        "oui_hex": "00-22-6B",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "002267": {
        "oui_hex": "00-22-67",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002295": {
        "oui_hex": "00-22-95",
        "organization": "SGM Technology for lighting spa",
        "address_1": "Via Pio La Torre 1",
        "address_2": "Tavullia  PU  61010",
        "country": "IT"
    },
    "00225A": {
        "oui_hex": "00-22-5A",
        "organization": "Garde Security AB",
        "address_1": "Box 78",
        "address_2": "Soderhamn    S-826 22",
        "country": "SE"
    },
    "002242": {
        "oui_hex": "00-22-42",
        "organization": "Alacron Inc.",
        "address_1": "71 Spit Brook Rd.",
        "address_2": "Nashua  NH  03060",
        "country": "US"
    },
    "002234": {
        "oui_hex": "00-22-34",
        "organization": "Corventis Inc.",
        "address_1": "1410 Energy Park Dr. Suite #1",
        "address_2": "St. Paul  Minnesota  55108",
        "country": "US"
    },
    "0021F7": {
        "oui_hex": "00-21-F7",
        "organization": "HPN Supply Chain",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "0021F4": {
        "oui_hex": "00-21-F4",
        "organization": "INRange Systems, Inc",
        "address_1": "3316 5th Avenue, Suite 100",
        "address_2": "Altoona  PA  16602",
        "country": "US"
    },
    "0021F5": {
        "oui_hex": "00-21-F5",
        "organization": "Western Engravers Supply, Inc.",
        "address_1": "17621 N Black Canyon Highway",
        "address_2": "Phoenix  AZ  85023",
        "country": "US"
    },
    "002232": {
        "oui_hex": "00-22-32",
        "organization": "Design Design Technology Ltd",
        "address_1": "Unit 9, Ash Road South",
        "address_2": "Wrexham  North Wales  LL13 9UG",
        "country": "GB"
    },
    "00222B": {
        "oui_hex": "00-22-2B",
        "organization": "Nucomm, Inc.",
        "address_1": "101 Bilby Road",
        "address_2": "Hackettstown  NJ  07840",
        "country": "US"
    },
    "002226": {
        "oui_hex": "00-22-26",
        "organization": "Avaak, Inc.",
        "address_1": "9645 Scranton Rd., Suitie 110",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002221": {
        "oui_hex": "00-22-21",
        "organization": "ITOH DENKI CO,LTD.",
        "address_1": "1146-2, Asazuma-cho",
        "address_2": "Kasai  Hyogo  679-0180",
        "country": "JP"
    },
    "00221D": {
        "oui_hex": "00-22-1D",
        "organization": "Freegene Technology LTD",
        "address_1": "3/F ,C BLDG,Weipengda Industrial Park",
        "address_2": "Shenzhen  Gongdong  518109",
        "country": "CN"
    },
    "002224": {
        "oui_hex": "00-22-24",
        "organization": "Good Will Instrument Co., Ltd.",
        "address_1": "No. 7-1 Jhongsing Road,",
        "address_2": "Taipei    236",
        "country": "TW"
    },
    "002245": {
        "oui_hex": "00-22-45",
        "organization": "Leine & Linde AB",
        "address_1": "Box 8",
        "address_2": "Strängnäs  Södermanland  SE-645 21",
        "country": "SE"
    },
    "002249": {
        "oui_hex": "00-22-49",
        "organization": "HOME MULTIENERGY SL",
        "address_1": "Capitán HAYA 1",
        "address_2": "MADRID    28020",
        "country": "ES"
    },
    "002240": {
        "oui_hex": "00-22-40",
        "organization": "Universal Telecom S/A",
        "address_1": "Avenida Paulista, 2444 - 17 andar",
        "address_2": "São Paulo    01310-300",
        "country": "BR"
    },
    "00220F": {
        "oui_hex": "00-22-0F",
        "organization": "MoCA (Multimedia over Coax Alliance)",
        "address_1": "90 Inverness Circle East",
        "address_2": "Englewood  CA  94583",
        "country": "US"
    },
    "00220A": {
        "oui_hex": "00-22-0A",
        "organization": "OnLive, Inc",
        "address_1": "1091 N Shoreline Blvd",
        "address_2": "Mountainview  California  94043",
        "country": "US"
    },
    "002203": {
        "oui_hex": "00-22-03",
        "organization": "Glensound Electronics Ltd",
        "address_1": "1 - 6 Brooks Place",
        "address_2": "Maidstone  Kent  ME17 1UN",
        "country": "GB"
    },
    "002204": {
        "oui_hex": "00-22-04",
        "organization": "KORATEK",
        "address_1": "Geumjeong-dong",
        "address_2": "Gunpo-si  Gyeonggi-do  435-825",
        "country": "KR"
    },
    "0021FF": {
        "oui_hex": "00-21-FF",
        "organization": "Cyfrowy Polsat SA",
        "address_1": "Łubinowa",
        "address_2": "Warsaw  Mazowieckie  03-878",
        "country": "PL"
    },
    "0021E4": {
        "oui_hex": "00-21-E4",
        "organization": "I-WIN",
        "address_1": "27 Rue des Econdeaux",
        "address_2": "EPINAY SUR SEINE  Seine Saint Denis  93800",
        "country": "FR"
    },
    "0021E5": {
        "oui_hex": "00-21-E5",
        "organization": "Display Solution AG",
        "address_1": "Talhofstraße 32a",
        "address_2": "Gilching  D  82205",
        "country": "DE"
    },
    "00221B": {
        "oui_hex": "00-22-1B",
        "organization": "Morega Systems",
        "address_1": "5770 Hurontario Street",
        "address_2": "Mississauga  Ontario  L5R 3G5",
        "country": "CA"
    },
    "0021B2": {
        "oui_hex": "00-21-B2",
        "organization": "Fiberblaze A/S",
        "address_1": "Kildevangsvej 9",
        "address_2": "Roskilde    4000",
        "country": "DK"
    },
    "0021AC": {
        "oui_hex": "00-21-AC",
        "organization": "Infrared Integrated Systems Ltd",
        "address_1": "Park Circle, Tithe Barn Way",
        "address_2": "Northampton  Northants  NN4 9BG",
        "country": "GB"
    },
    "00218E": {
        "oui_hex": "00-21-8E",
        "organization": "MEKICS CO., LTD.",
        "address_1": "Industrial Zone 861-10, Taegye-Dong",
        "address_2": "Chunchon  Kangwon  200-944",
        "country": "KR"
    },
    "00218F": {
        "oui_hex": "00-21-8F",
        "organization": "Avantgarde Acoustic Lautsprechersysteme GmbH",
        "address_1": "Nibelungenstraße 349",
        "address_2": "Lautertal - Reichenbach  Hessen  D-64686",
        "country": "DE"
    },
    "00217E": {
        "oui_hex": "00-21-7E",
        "organization": "Telit Communication s.p.a",
        "address_1": "Via stazione di prosecco 5B",
        "address_2": "SGONICO  Trieste  34010",
        "country": "IT"
    },
    "002187": {
        "oui_hex": "00-21-87",
        "organization": "Imacs GmbH",
        "address_1": "Mittelfeldstrasse 25",
        "address_2": "Kornwestheim  Germany  D-70806",
        "country": "DE"
    },
    "002181": {
        "oui_hex": "00-21-81",
        "organization": "Si2 Microsystems Limited",
        "address_1": "No 84, Sy No 150, EPIP, Whitefield Industrial Area",
        "address_2": "Bangalore  Karnataka  560066",
        "country": "IN"
    },
    "0021C2": {
        "oui_hex": "00-21-C2",
        "organization": "GL Communications Inc",
        "address_1": "818 West Diamond Ave",
        "address_2": "Gaithersburg  MD  20878",
        "country": "US"
    },
    "0021E2": {
        "oui_hex": "00-21-E2",
        "organization": "visago Systems & Controls GmbH & Co. KG",
        "address_1": "Neuwiesenstraße 20",
        "address_2": "Weilheim an der Teck    D-73235",
        "country": "DE"
    },
    "0021DD": {
        "oui_hex": "00-21-DD",
        "organization": "Northstar Systems Corp",
        "address_1": "5F, No.200 Gang Qian Rd",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0021D5": {
        "oui_hex": "00-21-D5",
        "organization": "X2E GmbH",
        "address_1": "Raiffeisenstrasse 9",
        "address_2": "Winden  Rheinland-Pfalz  76872",
        "country": "DE"
    },
    "0021A2": {
        "oui_hex": "00-21-A2",
        "organization": "EKE-Electronics Ltd.",
        "address_1": "Piispanportti 7",
        "address_2": "ESPOO    02240",
        "country": "FI"
    },
    "0021C9": {
        "oui_hex": "00-21-C9",
        "organization": "Wavecom Asia Pacific Limited",
        "address_1": "201 Bio-Informatics Centre,  No.2 Science Park West Ave",
        "address_2": "",
        "country": "HK"
    },
    "00214A": {
        "oui_hex": "00-21-4A",
        "organization": "Pixel Velocity, Inc",
        "address_1": "3917 Research Park Dr.",
        "address_2": "Ann Arbor  MI  48108",
        "country": "US"
    },
    "002146": {
        "oui_hex": "00-21-46",
        "organization": "Sanmina-SCI",
        "address_1": "13000 South Memorial Parkway",
        "address_2": "Huntsville  AL  35803",
        "country": "US"
    },
    "00216E": {
        "oui_hex": "00-21-6E",
        "organization": "Function ATI (Huizhou) Telecommunications Co., Ltd.",
        "address_1": "No. 8, Huitai Road, Huitai Industrial Zone",
        "address_2": "Huizhou City  Guangdong Province  516006",
        "country": "CN"
    },
    "00216D": {
        "oui_hex": "00-21-6D",
        "organization": "Soltech Co., Ltd.",
        "address_1": "#30-3,3F",
        "address_2": "Yongsan Ku  Seoul  140837",
        "country": "KR"
    },
    "002165": {
        "oui_hex": "00-21-65",
        "organization": "Presstek Inc.",
        "address_1": "55 Executive Drive",
        "address_2": "Hudson  New Hampshire  03051",
        "country": "US"
    },
    "00211F": {
        "oui_hex": "00-21-1F",
        "organization": "SHINSUNG DELTATECH CO.,LTD.",
        "address_1": "44-10",
        "address_2": "CHANGWON-CITY  KYUNGNAM-DO  641-290",
        "country": "KR"
    },
    "002124": {
        "oui_hex": "00-21-24",
        "organization": "Optos Plc",
        "address_1": "Queensferry House",
        "address_2": "Dunfermline  Fife  KY11 8GR",
        "country": "GB"
    },
    "002133": {
        "oui_hex": "00-21-33",
        "organization": "Building B, Inc",
        "address_1": "1000 NW 65th Street, Suite 300",
        "address_2": "Ft. Lauderdale  FL  33309",
        "country": "US"
    },
    "002134": {
        "oui_hex": "00-21-34",
        "organization": "Brandywine Communications",
        "address_1": "1153 Warner Ave",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "00213A": {
        "oui_hex": "00-21-3A",
        "organization": "Winchester Systems Inc.",
        "address_1": "101 Billerica Avenue",
        "address_2": "Billerica,  MA  01862",
        "country": "US"
    },
    "00212E": {
        "oui_hex": "00-21-2E",
        "organization": "dresden-elektronik",
        "address_1": "Enno-Heidebroek-Str. 12",
        "address_2": "Dresden  Saxony  D-01237",
        "country": "DE"
    },
    "002130": {
        "oui_hex": "00-21-30",
        "organization": "Keico Hightech Inc.",
        "address_1": "Ace twin tower I, 12th Fl.",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "00215B": {
        "oui_hex": "00-21-5B",
        "organization": "SenseAnywhere",
        "address_1": "Lisztlaan 2",
        "address_2": "Roosendaal    4702 KJ",
        "country": "NL"
    },
    "00214E": {
        "oui_hex": "00-21-4E",
        "organization": "GS Yuasa Power Supply Ltd.",
        "address_1": "1, Inobanba-cho, Nishinosho, Kisshoin, Minami-ku,",
        "address_2": "Kyoto    601-8520",
        "country": "JP"
    },
    "002142": {
        "oui_hex": "00-21-42",
        "organization": "Advanced Control Systems doo",
        "address_1": "Bulevar Zorana Djindjica 8a",
        "address_2": "Belgrade  Serbia  11070",
        "country": "YU"
    },
    "001FFA": {
        "oui_hex": "00-1F-FA",
        "organization": "Coretree, Co, Ltd",
        "address_1": "#502 IT Venture Town, 694",
        "address_2": "Daejeon    305-510",
        "country": "KR"
    },
    "001FF5": {
        "oui_hex": "00-1F-F5",
        "organization": "Kongsberg Defence & Aerospace",
        "address_1": "Olav Brunborgs vei 6",
        "address_2": "Billingstad    1396",
        "country": "NO"
    },
    "001FF2": {
        "oui_hex": "00-1F-F2",
        "organization": "VIA Technologies, Inc.",
        "address_1": "1F, 531, Chung-Cheng Road",
        "address_2": "Hsin-Tien  Taipei  231",
        "country": "TW"
    },
    "002101": {
        "oui_hex": "00-21-01",
        "organization": "Aplicaciones Electronicas Quasar (AEQ)",
        "address_1": "C/Rey Pastor 40",
        "address_2": "Leganes  Madrid  28914",
        "country": "ES"
    },
    "002103": {
        "oui_hex": "00-21-03",
        "organization": "GHI Electronics, LLC",
        "address_1": "35555 Garfield Rd.",
        "address_2": "Clinton Township  MI  48035",
        "country": "US"
    },
    "001FF8": {
        "oui_hex": "00-1F-F8",
        "organization": "Siemens AG, Sector Industry, Drive Technologies, Motion Control Systems",
        "address_1": "Frauenauracherstraße 80",
        "address_2": "Erlangen  Bavaria  91056",
        "country": "DE"
    },
    "001FD0": {
        "oui_hex": "00-1F-D0",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "001FD1": {
        "oui_hex": "00-1F-D1",
        "organization": "OPTEX CO.,LTD.",
        "address_1": "5-8-12",
        "address_2": "Otsu  Shiga  520-0101",
        "country": "JP"
    },
    "001FC9": {
        "oui_hex": "00-1F-C9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001FDC": {
        "oui_hex": "00-1F-DC",
        "organization": "Mobile Safe Track Ltd",
        "address_1": "Niemenkatu 73",
        "address_2": "15149  Lahti",
        "country": "FI"
    },
    "001FD6": {
        "oui_hex": "00-1F-D6",
        "organization": "Shenzhen Allywll",
        "address_1": "Kejiyuan Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002117": {
        "oui_hex": "00-21-17",
        "organization": "Tellord",
        "address_1": "Gurogu Gurodong 170-5 Woolim e-Biz Center 709",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "00210F": {
        "oui_hex": "00-21-0F",
        "organization": "Cernium Corp",
        "address_1": "1943 Isaac Newton Sq",
        "address_2": "Reston  VA  20190",
        "country": "US"
    },
    "001FF1": {
        "oui_hex": "00-1F-F1",
        "organization": "Paradox Hellas S.A.",
        "address_1": "3 Korinthoy St",
        "address_2": "Athens  Attiki  14451",
        "country": "GR"
    },
    "001FE6": {
        "oui_hex": "00-1F-E6",
        "organization": "Alphion Corporation",
        "address_1": "196 Princeton Hightstown Rd.",
        "address_2": "Princeton Junction  NJ  08550",
        "country": "US"
    },
    "001FCF": {
        "oui_hex": "00-1F-CF",
        "organization": "MSI Technology GmbH",
        "address_1": "Hanauer Landstraße 328-330",
        "address_2": "Frankfurt am Main  Hessen  60314",
        "country": "DE"
    },
    "001F9C": {
        "oui_hex": "00-1F-9C",
        "organization": "LEDCO",
        "address_1": "47801 W Anchor Court",
        "address_2": "Plymouth  MI  48170",
        "country": "US"
    },
    "001F90": {
        "oui_hex": "00-1F-90",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001F91": {
        "oui_hex": "00-1F-91",
        "organization": "DBS Lodging Technologies, LLC",
        "address_1": "21196 Limber",
        "address_2": "Mission Viejo  CA  92692",
        "country": "US"
    },
    "001F98": {
        "oui_hex": "00-1F-98",
        "organization": "DAIICHI-DENTSU LTD.",
        "address_1": "OOMORI 690-1",
        "address_2": "KANI  GIFU  509-0238",
        "country": "JP"
    },
    "001F93": {
        "oui_hex": "00-1F-93",
        "organization": "Xiotech Corporation",
        "address_1": "6455 Flying Cloud Drive",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "001F51": {
        "oui_hex": "00-1F-51",
        "organization": "HD Communications Corp",
        "address_1": "2180 Fifth Ave",
        "address_2": "Ronkonkoma  NY  11779",
        "country": "US"
    },
    "001F53": {
        "oui_hex": "00-1F-53",
        "organization": "GEMAC Chemnitz GmbH",
        "address_1": "Zwickauer Straße 227",
        "address_2": "Chemnitz  Sachsen  09116",
        "country": "DE"
    },
    "001F50": {
        "oui_hex": "00-1F-50",
        "organization": "Swissdis AG",
        "address_1": "Grasweg 7",
        "address_2": "Schwarzhaeusern  BE  4911",
        "country": "CH"
    },
    "001F4C": {
        "oui_hex": "00-1F-4C",
        "organization": "Roseman Engineering Ltd",
        "address_1": "65 Weizman Street",
        "address_2": "Givataim  Israel  53468",
        "country": "IL"
    },
    "001FA9": {
        "oui_hex": "00-1F-A9",
        "organization": "Atlanta DTH, Inc.",
        "address_1": "5388 New Peachtree Rd",
        "address_2": "Chamblee  GA  30341",
        "country": "US"
    },
    "001FA3": {
        "oui_hex": "00-1F-A3",
        "organization": "T&W Electronics(Shenzhen)Co.,Ltd.",
        "address_1": "2F,Baiying Building, No.1019,",
        "address_2": "ShenZhen  GuangDong  518067",
        "country": "CN"
    },
    "001FA2": {
        "oui_hex": "00-1F-A2",
        "organization": "Datron World Communications, Inc.",
        "address_1": "3030 Enterprise Court",
        "address_2": "Vista  California  92081",
        "country": "US"
    },
    "001F70": {
        "oui_hex": "00-1F-70",
        "organization": "Botik Technologies LTD",
        "address_1": "Trudovaya, 1",
        "address_2": "Pereslavl-Zalessky  Yaroslavskaya  152020",
        "country": "RU"
    },
    "001F64": {
        "oui_hex": "00-1F-64",
        "organization": "Beijing Autelan Technology Inc.",
        "address_1": "Room B-12B01, Keshi Plaza, Xinxi road,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001F6D": {
        "oui_hex": "00-1F-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F24": {
        "oui_hex": "00-1F-24",
        "organization": "DIGITVIEW TECHNOLOGY CO., LTD.",
        "address_1": "NO. 14-22, TIAN-FU ,",
        "address_2": "TAIPEI COUNTY    237",
        "country": "TW"
    },
    "001F21": {
        "oui_hex": "00-1F-21",
        "organization": "Inner Mongolia Yin An Science & Technology Development Co.,L",
        "address_1": "YinAn Building Yiwei Road.RuYi",
        "address_2": "Beijing    010010",
        "country": "CN"
    },
    "001F22": {
        "oui_hex": "00-1F-22",
        "organization": "Source Photonics, Inc.",
        "address_1": "20550 Nordhoff Street",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "001F1D": {
        "oui_hex": "00-1F-1D",
        "organization": "Atlas Material Testing Technology LLC",
        "address_1": "4114 N. Ravenswood Ave.",
        "address_2": "Chicago  IL  60613",
        "country": "US"
    },
    "001F15": {
        "oui_hex": "00-1F-15",
        "organization": "Bioscrypt Inc",
        "address_1": "505 Cochrane Drive",
        "address_2": "Markham  Ontario  L3R 8E3",
        "country": "CA"
    },
    "001F2B": {
        "oui_hex": "00-1F-2B",
        "organization": "Orange Logic",
        "address_1": "#706 AceTechnoTower 10-cha,470-5",
        "address_2": "SEOUL    153-789",
        "country": "KR"
    },
    "001F2A": {
        "oui_hex": "00-1F-2A",
        "organization": "ACCM",
        "address_1": "Obour Industrial City, Industrial zone A, lot14, block 12006.",
        "address_2": "Cairo",
        "country": "EG"
    },
    "001F30": {
        "oui_hex": "00-1F-30",
        "organization": "Travelping",
        "address_1": "",
        "address_2": "Chemnitz  Saxony  09113",
        "country": "DE"
    },
    "001F48": {
        "oui_hex": "00-1F-48",
        "organization": "Mojix Inc.",
        "address_1": "11075 Santa Monica Blvd.",
        "address_2": "Los Angeles  Ca  90025",
        "country": "US"
    },
    "001F3E": {
        "oui_hex": "00-1F-3E",
        "organization": "RP-Technik e.K.",
        "address_1": "Hermann-Staudinger-Str. 10-16",
        "address_2": "Rodgau  Hessen  63110",
        "country": "DE"
    },
    "001EF0": {
        "oui_hex": "00-1E-F0",
        "organization": "Gigafin Networks",
        "address_1": "19050 Pruneridge",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001EF2": {
        "oui_hex": "00-1E-F2",
        "organization": "Micro Motion Inc",
        "address_1": "7070 Winchester Circle",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "001F37": {
        "oui_hex": "00-1F-37",
        "organization": "Genesis I&C",
        "address_1": "#515 lisantekeunotaun",
        "address_2": "Goyang  Gyeonggi  410-722",
        "country": "KR"
    },
    "001F2C": {
        "oui_hex": "00-1F-2C",
        "organization": "Starbridge Networks",
        "address_1": "3265 Meridian Parkway",
        "address_2": "Weston  FL  33331",
        "country": "US"
    },
    "001F31": {
        "oui_hex": "00-1F-31",
        "organization": "Radiocomp",
        "address_1": "Krakesvej 17",
        "address_2": "Hilleroed  Copenhagen  3400",
        "country": "DK"
    },
    "001F12": {
        "oui_hex": "00-1F-12",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001EEA": {
        "oui_hex": "00-1E-EA",
        "organization": "Sensor Switch, Inc.",
        "address_1": "900 Northrop Road",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "001F04": {
        "oui_hex": "00-1F-04",
        "organization": "Granch Ltd.",
        "address_1": "40 Koroleva str.",
        "address_2": "Novosibirsk  NSO  630015",
        "country": "RU"
    },
    "001E94": {
        "oui_hex": "00-1E-94",
        "organization": "SUPERCOM TECHNOLOGY CORPORATION",
        "address_1": "8F, NO 100-1, Ming-Chuan Rd.",
        "address_2": "Shing Tien  Taipei  231",
        "country": "TW"
    },
    "001E8F": {
        "oui_hex": "00-1E-8F",
        "organization": "CANON INC.",
        "address_1": "3-30-2",
        "address_2": "Ohta-Ku  Tokyo  146-8501",
        "country": "JP"
    },
    "001EA5": {
        "oui_hex": "00-1E-A5",
        "organization": "ROBOTOUS, Inc.",
        "address_1": "Nex Center-201(Lab.), SK n Technopark",
        "address_2": "Seongnam-si  Gyeonggi-do  462-120",
        "country": "KR"
    },
    "001EA7": {
        "oui_hex": "00-1E-A7",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001EA0": {
        "oui_hex": "00-1E-A0",
        "organization": "XLN-t",
        "address_1": "Hoogstraat 52",
        "address_2": "Putte  Antwerp  B2580",
        "country": "BE"
    },
    "001E98": {
        "oui_hex": "00-1E-98",
        "organization": "GreenLine Communications",
        "address_1": "Alrabiah - Alrabeea Street",
        "address_2": "Amman  Central Region  11953",
        "country": "JO"
    },
    "001E9A": {
        "oui_hex": "00-1E-9A",
        "organization": "HAMILTON Bonaduz AG",
        "address_1": "Via Crusch 8",
        "address_2": "Bonaduz  Graubuenden  7402",
        "country": "CH"
    },
    "001EDF": {
        "oui_hex": "00-1E-DF",
        "organization": "Master Industrialization Center Kista",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "001EE3": {
        "oui_hex": "00-1E-E3",
        "organization": "T&W Electronics (ShenZhen) Co.,Ltd",
        "address_1": "2F Baiying Building, No.19, NanhaiRd., Nanshan Dist",
        "address_2": "ShenZhen  GuangDong  518052",
        "country": "CN"
    },
    "001ED9": {
        "oui_hex": "00-1E-D9",
        "organization": "Mitsubishi Precision Co.,LTd.",
        "address_1": "345 KAMIMACHIYA",
        "address_2": "KAMAKURA-City  KANAGAWA-Prefecture  247-8505",
        "country": "JP"
    },
    "001ED3": {
        "oui_hex": "00-1E-D3",
        "organization": "Dot Technology Int'l Co., Ltd.",
        "address_1": "Unit 1001, Fourseas Building 208-212, Nathan Road",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "001EA6": {
        "oui_hex": "00-1E-A6",
        "organization": "Best IT World (India) Pvt. Ltd.",
        "address_1": "87/70/93 Mistry Industrial Complex,",
        "address_2": "Mumbai  Maharashtra  400093",
        "country": "IN"
    },
    "001E83": {
        "oui_hex": "00-1E-83",
        "organization": "LAN/MAN Standards Association (LMSC)",
        "address_1": "C/O IEEE Standards Association",
        "address_2": "Piscataway  NJ  08855-1331",
        "country": "US"
    },
    "001E7C": {
        "oui_hex": "00-1E-7C",
        "organization": "Taiwick Limited",
        "address_1": "5/F., Block E, Hing Yip Factory Bldg.,",
        "address_2": "Hong Kong  China  852",
        "country": "HK"
    },
    "001ECF": {
        "oui_hex": "00-1E-CF",
        "organization": "PHILIPS ELECTRONICS UK LTD",
        "address_1": "PHILIPS CENTRE",
        "address_2": "GUILDFORD  SURREY  GU2 8XH",
        "country": "GB"
    },
    "001E22": {
        "oui_hex": "00-1E-22",
        "organization": "ARVOO Imaging Products BV",
        "address_1": "Tasveld 13",
        "address_2": "Montfoort  UT  3417 XS",
        "country": "NL"
    },
    "001E1A": {
        "oui_hex": "00-1E-1A",
        "organization": "Best Source Taiwan Inc.",
        "address_1": "2F, No.16, Lane 56, Jhongjheng W. Rd.,",
        "address_2": "Jhubei City,  Hsinchu County  302",
        "country": "TW"
    },
    "001E19": {
        "oui_hex": "00-1E-19",
        "organization": "GTRI",
        "address_1": "M/S 0821",
        "address_2": "Atlanta  GA  30332",
        "country": "US"
    },
    "001E14": {
        "oui_hex": "00-1E-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E44": {
        "oui_hex": "00-1E-44",
        "organization": "SANTEC",
        "address_1": "An der Strusbek 31",
        "address_2": "Ahrensburg  Schleswig Holstein  22926",
        "country": "DE"
    },
    "001E62": {
        "oui_hex": "00-1E-62",
        "organization": "Siemon",
        "address_1": "27 Siemon Company Drive",
        "address_2": "Watertown  CT  06795",
        "country": "US"
    },
    "001E5C": {
        "oui_hex": "00-1E-5C",
        "organization": "RB GeneralEkonomik",
        "address_1": "Bulevar despota stefana 59a",
        "address_2": "Beograd  Serbia  11000",
        "country": "YU"
    },
    "001E5D": {
        "oui_hex": "00-1E-5D",
        "organization": "Holosys d.o.o.",
        "address_1": "Kovinska 4",
        "address_2": "Zagreb    10090",
        "country": "HR"
    },
    "001E78": {
        "oui_hex": "00-1E-78",
        "organization": "Owitek Technology Ltd.,",
        "address_1": "No.2, Lane 78, Cingshan 6th St.,",
        "address_2": "Taoyuan County    32657",
        "country": "TW"
    },
    "001E7A": {
        "oui_hex": "00-1E-7A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E27": {
        "oui_hex": "00-1E-27",
        "organization": "SBN TECH Co.,Ltd.",
        "address_1": "#706 Industrial Academic Center, Konkuk University, Hwayang-dong, Gwangjin-gu",
        "address_2": "Seoul    143-701",
        "country": "KR"
    },
    "001E60": {
        "oui_hex": "00-1E-60",
        "organization": "Digital Lighting Systems, Inc",
        "address_1": "12302 Sw 128th ct,   #105",
        "address_2": "Miami  FL  33186",
        "country": "US"
    },
    "001E6C": {
        "oui_hex": "00-1E-6C",
        "organization": "Opaque Systems",
        "address_1": "4820 Fisher Road",
        "address_2": "Athens  OH  45701",
        "country": "US"
    },
    "001E2F": {
        "oui_hex": "00-1E-2F",
        "organization": "DiMoto Pty Ltd",
        "address_1": "7 Meljaren Place",
        "address_2": "Buderim  Queensland  4556",
        "country": "AU"
    },
    "001E36": {
        "oui_hex": "00-1E-36",
        "organization": "IPTE",
        "address_1": "Geleenlaan 5",
        "address_2": "Genk  Limburg  3600",
        "country": "BE"
    },
    "001DA7": {
        "oui_hex": "00-1D-A7",
        "organization": "Seamless Internet",
        "address_1": "2050 Russett Way Suite 338",
        "address_2": "Carson City  Nevada  89703",
        "country": "US"
    },
    "001DA5": {
        "oui_hex": "00-1D-A5",
        "organization": "WB Electronics",
        "address_1": "Langelandsvej 1A",
        "address_2": "Herning  Herning  7400",
        "country": "DK"
    },
    "001DA8": {
        "oui_hex": "00-1D-A8",
        "organization": "Takahata Electronics Co.,Ltd",
        "address_1": "1188,Kubota,Kubota-machi",
        "address_2": "Yonezawa-shi  Yamagata-Pref.  992-0003",
        "country": "JP"
    },
    "001DA9": {
        "oui_hex": "00-1D-A9",
        "organization": "Castles Technology, Co., LTD",
        "address_1": "2F, No.205, Sec 3 Beishin Rd.,",
        "address_2": "Hsin-Tien City  Taipei  231",
        "country": "TW"
    },
    "001DCB": {
        "oui_hex": "00-1D-CB",
        "organization": "Exéns Development Oy",
        "address_1": "Kauppakatu 36",
        "address_2": "Kajaani  Kainuu  87100",
        "country": "FI"
    },
    "001DCA": {
        "oui_hex": "00-1D-CA",
        "organization": "PAV Electronics Limited",
        "address_1": "7 Laverock Road",
        "address_2": "Airdrie  Lanarkshire  ML6 7UD",
        "country": "GB"
    },
    "001DC2": {
        "oui_hex": "00-1D-C2",
        "organization": "XORTEC OY",
        "address_1": "Höytämöntie 6",
        "address_2": "Lempäälä   Pirkanmaa  33880",
        "country": "FI"
    },
    "001E0E": {
        "oui_hex": "00-1E-0E",
        "organization": "MAXI VIEW HOLDINGS LIMITED",
        "address_1": "Suite 2302,23/F Great Eagle Centre, 23 Harbour Road, Wanchai",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "001E0F": {
        "oui_hex": "00-1E-0F",
        "organization": "Briot International",
        "address_1": "2 rue roger Bonnet",
        "address_2": "Pont de l'Arche  Eure  27340",
        "country": "FR"
    },
    "001DE3": {
        "oui_hex": "00-1D-E3",
        "organization": "Intuicom",
        "address_1": "4900 Nautilus CT N",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "001DDE": {
        "oui_hex": "00-1D-DE",
        "organization": "Zhejiang Broadcast&Television Technology Co.,Ltd.",
        "address_1": "Building No.16,Xidoumen Industry Park,Wenyi Road,",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "001DE5": {
        "oui_hex": "00-1D-E5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001DEC": {
        "oui_hex": "00-1D-EC",
        "organization": "Marusys",
        "address_1": "Eunsung Bldg. 5F",
        "address_2": "Seoul    135-763",
        "country": "KR"
    },
    "001DE8": {
        "oui_hex": "00-1D-E8",
        "organization": "Nikko Denki Tsushin Corporation(NDTC)",
        "address_1": "440 Kamoshida-town, Aoba-ku",
        "address_2": "Yokohama    227-0033",
        "country": "JP"
    },
    "001DDA": {
        "oui_hex": "00-1D-DA",
        "organization": "Mikroelektronika spol. s r. o.",
        "address_1": "Dráby 849",
        "address_2": "Vysoké Mýto  CZ  566 01",
        "country": "CZ"
    },
    "001DB0": {
        "oui_hex": "00-1D-B0",
        "organization": "FuJian HengTong Information Technology Co.,Ltd",
        "address_1": "No.14-804,Building 2,JinXiuFuCheng,No.338,HuaLin Road",
        "address_2": "FuZhou City  FuJian Province  350001",
        "country": "CN"
    },
    "001DB8": {
        "oui_hex": "00-1D-B8",
        "organization": "Intoto Inc.",
        "address_1": "3100 De La Cruz Blvd.  #300",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001DF5": {
        "oui_hex": "00-1D-F5",
        "organization": "Sunshine Co,LTD",
        "address_1": "1-3-5 Kojimachi",
        "address_2": "TOKYO  Kanto region  102-0083",
        "country": "JP"
    },
    "001DF0": {
        "oui_hex": "00-1D-F0",
        "organization": "Vidient Systems, Inc.",
        "address_1": "4000 Burton Drive",
        "address_2": "Santa Clara  CA  94054",
        "country": "US"
    },
    "001DFE": {
        "oui_hex": "00-1D-FE",
        "organization": "Palm, Inc",
        "address_1": "950 West Maude Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "001D52": {
        "oui_hex": "00-1D-52",
        "organization": "Defzone B.V.",
        "address_1": "Transportcentrum 10",
        "address_2": "Enschede  Overijssel  7547 RW",
        "country": "NL"
    },
    "001D4A": {
        "oui_hex": "00-1D-4A",
        "organization": "Carestream Health, Inc.",
        "address_1": "150 Verona Street",
        "address_2": "Rochestser  NY  14608",
        "country": "US"
    },
    "001D96": {
        "oui_hex": "00-1D-96",
        "organization": "WatchGuard Video",
        "address_1": "3001 Summit Ave.",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "001D8F": {
        "oui_hex": "00-1D-8F",
        "organization": "PureWave Networks",
        "address_1": "2660-C Marine Way",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001D8C": {
        "oui_hex": "00-1D-8C",
        "organization": "La Crosse Technology LTD",
        "address_1": "2809 Losey Blvd. So.",
        "address_2": "La Crosse  WI  54601",
        "country": "US"
    },
    "001D64": {
        "oui_hex": "00-1D-64",
        "organization": "Adam Communications Systems Int Ltd",
        "address_1": "The Mission",
        "address_2": "Stockport  Cheshire  SK1 3AH",
        "country": "GB"
    },
    "001D5E": {
        "oui_hex": "00-1D-5E",
        "organization": "COMING MEDIA CORP.",
        "address_1": "BONA Bld. 4th Fl., 548-18",
        "address_2": "Seoul    135-158",
        "country": "KR"
    },
    "001D55": {
        "oui_hex": "00-1D-55",
        "organization": "ZANTAZ, Inc",
        "address_1": "5758 W. Las Positas Avenue",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "001DA1": {
        "oui_hex": "00-1D-A1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D71": {
        "oui_hex": "00-1D-71",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D65": {
        "oui_hex": "00-1D-65",
        "organization": "Microwave Radio Communications",
        "address_1": "101 Billerica Avemue, Bldg 6",
        "address_2": "N. Billerica  MA  01862",
        "country": "US"
    },
    "001D50": {
        "oui_hex": "00-1D-50",
        "organization": "SPINETIX SA",
        "address_1": "Parc Scientifique de l'EPFL, Bâtiment C",
        "address_2": "Lausanne  VD  1015",
        "country": "CH"
    },
    "001D45": {
        "oui_hex": "00-1D-45",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D69": {
        "oui_hex": "00-1D-69",
        "organization": "Knorr-Bremse IT-Services GmbH",
        "address_1": "Moosacher Str. 80",
        "address_2": "Muenchen  BY  80809",
        "country": "DE"
    },
    "001CF8": {
        "oui_hex": "00-1C-F8",
        "organization": "Parade Technologies, Ltd.",
        "address_1": "C/O Parade Technologies, Inc.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "001CF7": {
        "oui_hex": "00-1C-F7",
        "organization": "AudioScience",
        "address_1": "729 west 16th st",
        "address_2": "Costa Mesa  California  92627",
        "country": "US"
    },
    "001CF6": {
        "oui_hex": "00-1C-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001CF5": {
        "oui_hex": "00-1C-F5",
        "organization": "Wiseblue Technology Limited",
        "address_1": "Rm G5, 5/F, Kingsford Industrial Building Phase II, 26-32 Kwai Hei Street,",
        "address_2": "Kwai Chung  N.T.",
        "country": "HK"
    },
    "001CEE": {
        "oui_hex": "00-1C-EE",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "001D07": {
        "oui_hex": "00-1D-07",
        "organization": "Shenzhen Sang Fei Consumer Communications Co.,Ltd",
        "address_1": "11 Science and Technology Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001D06": {
        "oui_hex": "00-1D-06",
        "organization": "HM Electronics, Inc.",
        "address_1": "14110 Stowe Drive",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "001D01": {
        "oui_hex": "00-1D-01",
        "organization": "Neptune Digital",
        "address_1": "Mednarodni mejni prehod 6",
        "address_2": "Vrtojba  Nova Gorica  5290",
        "country": "SI"
    },
    "001D33": {
        "oui_hex": "00-1D-33",
        "organization": "Maverick Systems Inc.",
        "address_1": "908, Daerungposttower 2-cha, 182-13",
        "address_2": "Seoul    152-790",
        "country": "KR"
    },
    "001D2C": {
        "oui_hex": "00-1D-2C",
        "organization": "Wavetrend Technologies (Pty) Limited",
        "address_1": "Wavetrend House, Building 816/3",
        "address_2": "Gauteng    2021",
        "country": "ZA"
    },
    "001CCF": {
        "oui_hex": "00-1C-CF",
        "organization": "LIMETEK",
        "address_1": "#213-1, Byucksan Digital Valley II, 480-10, Gasan-dong,",
        "address_2": "Seoul    153-783",
        "country": "KR"
    },
    "001D24": {
        "oui_hex": "00-1D-24",
        "organization": "Aclara Power-Line Systems Inc.",
        "address_1": "945 Hornet Drive",
        "address_2": "Hazelwood  MO  63042",
        "country": "US"
    },
    "001D18": {
        "oui_hex": "00-1D-18",
        "organization": "Power Innovation GmbH",
        "address_1": "Rehland 2",
        "address_2": "Achim  Niedersachsen  28832",
        "country": "DE"
    },
    "001D1B": {
        "oui_hex": "00-1D-1B",
        "organization": "Sangean Electronics Inc.",
        "address_1": "No. 18, Lane 7, Li-De street",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001D17": {
        "oui_hex": "00-1D-17",
        "organization": "Digital Sky Corporation",
        "address_1": "5-5-15 Sotokanda,",
        "address_2": "Chiyoda-ku  Tokyo  101-0021",
        "country": "JP"
    },
    "001D27": {
        "oui_hex": "00-1D-27",
        "organization": "NAC-INTERCOM",
        "address_1": "AVDA. RICARDO MELLA 123-B",
        "address_2": "VIGO  PONTEVEDRA  36330",
        "country": "ES"
    },
    "001CE3": {
        "oui_hex": "00-1C-E3",
        "organization": "Optimedical Systems",
        "address_1": "235 Hembree Park Drive",
        "address_2": "Roswell  GA  30076",
        "country": "US"
    },
    "001CDE": {
        "oui_hex": "00-1C-DE",
        "organization": "Interactive Multimedia eXchange Inc.",
        "address_1": "NO. 165 Wenlin Road.",
        "address_2": "Taipei  Taiwan  111",
        "country": "TW"
    },
    "001D36": {
        "oui_hex": "00-1D-36",
        "organization": "ELECTRONICS CORPORATION OF INDIA LIMITED",
        "address_1": "CONTROL AND AUTOMATION DIVISION-3",
        "address_2": "HYDERABAD  ANDHRA PRADESH  500 062",
        "country": "IN"
    },
    "001C80": {
        "oui_hex": "00-1C-80",
        "organization": "New Business Division/Rhea-Information CO., LTD.",
        "address_1": "4F 594 Yeong Pung Bldg, Gueui-Dong",
        "address_2": "Seoul  Gwangjin-Gu  143-200",
        "country": "KR"
    },
    "001C83": {
        "oui_hex": "00-1C-83",
        "organization": "New Level Telecom Co., Ltd.",
        "address_1": "INNOPLEX 1-703",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "001C76": {
        "oui_hex": "00-1C-76",
        "organization": "The Wandsworth Group Ltd",
        "address_1": "Albert Drive",
        "address_2": "Woking  Surrey  GU21 5SE",
        "country": "GB"
    },
    "001C72": {
        "oui_hex": "00-1C-72",
        "organization": "Mayer & Cie GmbH & Co KG",
        "address_1": "Emil Mayer Strasse 10",
        "address_2": "Albstadt  Baden-Württemberg  72461",
        "country": "DE"
    },
    "001CAD": {
        "oui_hex": "00-1C-AD",
        "organization": "Wuhan Telecommunication Devices Co.,Ltd",
        "address_1": "88 Youkeyuan Road,Hongshan District",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "001CA7": {
        "oui_hex": "00-1C-A7",
        "organization": "International Quartz Limited",
        "address_1": "2nd Floor, 2, Dai Wang Street,",
        "address_2": "  Hong Kong  852",
        "country": "CN"
    },
    "001CAB": {
        "oui_hex": "00-1C-AB",
        "organization": "Meyer Sound Laboratories, Inc.",
        "address_1": "2832 San Pablo Ave.",
        "address_2": "Berkeley  CA  94702",
        "country": "US"
    },
    "001C9E": {
        "oui_hex": "00-1C-9E",
        "organization": "Dualtech IT AB",
        "address_1": "Banehagsgatan 1F",
        "address_2": "GOTHENBURG  Västra Götaland  41451",
        "country": "SE"
    },
    "001CC8": {
        "oui_hex": "00-1C-C8",
        "organization": "INDUSTRONIC Industrie-Electronic GmbH & Co. KG",
        "address_1": "Carl-Jacob-Kolb-Weg 1",
        "address_2": "Wertheim  Baden-Württemberg  97877",
        "country": "DE"
    },
    "001CC6": {
        "oui_hex": "00-1C-C6",
        "organization": "ProStor Systems",
        "address_1": "5555 Central Avenue",
        "address_2": "Boulder  Colorado  80301",
        "country": "US"
    },
    "001CBE": {
        "oui_hex": "00-1C-BE",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001C94": {
        "oui_hex": "00-1C-94",
        "organization": "LI-COR Biosciences",
        "address_1": "4647 Superior Street",
        "address_2": "Lincoln  NE  68504",
        "country": "US"
    },
    "001C8C": {
        "oui_hex": "00-1C-8C",
        "organization": "DIAL TECHNOLOGY LTD.",
        "address_1": "6F-4, NO.18, LANE.609, SEC.5, CHONGSIN RD.,",
        "address_2": "SANCHONG CITY  TAIPEI COUNTY  241",
        "country": "TW"
    },
    "001CCA": {
        "oui_hex": "00-1C-CA",
        "organization": "Shanghai Gaozhi Science & Technology Development Co.",
        "address_1": "No.283 Qin Jiang Rd. Shanghai,China",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "001CC9": {
        "oui_hex": "00-1C-C9",
        "organization": "Kaise Electronic Technology Co., Ltd.",
        "address_1": "No.678, Wunsyue Rd., Zuoying District,",
        "address_2": "Kaohsiung    813",
        "country": "TW"
    },
    "001C93": {
        "oui_hex": "00-1C-93",
        "organization": "ExaDigm Inc",
        "address_1": "2871 Pullman St",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "001C85": {
        "oui_hex": "00-1C-85",
        "organization": "Eunicorn",
        "address_1": "226-16 unbo b/d suckchon-dong songpa-gu",
        "address_2": "seoul    138845",
        "country": "KR"
    },
    "001C67": {
        "oui_hex": "00-1C-67",
        "organization": "Pumpkin Networks, Inc.",
        "address_1": "3FL JungHo Bldg, 108-4 Sangdo-Dong, Dongjak-Gu",
        "address_2": "SEOUL    156-030",
        "country": "KR"
    },
    "001C60": {
        "oui_hex": "00-1C-60",
        "organization": "CSP Frontier Technologies,Inc.",
        "address_1": "3-2-3,Sasazuka",
        "address_2": "Shibuya-ku  Tokyo  151-0073",
        "country": "JP"
    },
    "001C6A": {
        "oui_hex": "00-1C-6A",
        "organization": "Weiss Engineering Ltd.",
        "address_1": "Florastrasse 42",
        "address_2": "Uster  ZH  8610",
        "country": "CH"
    },
    "001C0A": {
        "oui_hex": "00-1C-0A",
        "organization": "Shenzhen AEE Technology Co.,Ltd.",
        "address_1": "1st Floor B Building, Shenzhen,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001C0D": {
        "oui_hex": "00-1C-0D",
        "organization": "G-Technology, Inc.",
        "address_1": "1653 Stanford Street",
        "address_2": "Santa Monica  CA  90404",
        "country": "US"
    },
    "001C03": {
        "oui_hex": "00-1C-03",
        "organization": "Betty TV Technology AG",
        "address_1": "Hardturmstrasse 2",
        "address_2": "Zurich    80005",
        "country": "CH"
    },
    "001C46": {
        "oui_hex": "00-1C-46",
        "organization": "QTUM",
        "address_1": "#507 Byucksan/Kyungin Digital Valley 2 481-10",
        "address_2": "Seoul    153-783",
        "country": "KR"
    },
    "001C42": {
        "oui_hex": "00-1C-42",
        "organization": "Parallels, Inc.",
        "address_1": "660 SW 39h Street",
        "address_2": "Renton  WA  98057",
        "country": "US"
    },
    "001C3E": {
        "oui_hex": "00-1C-3E",
        "organization": "ECKey Corporation",
        "address_1": "206A W James St",
        "address_2": "Lancaster  PA  17603",
        "country": "US"
    },
    "001C51": {
        "oui_hex": "00-1C-51",
        "organization": "Celeno Communications",
        "address_1": "22 Zarhin Street",
        "address_2": "Ra'anana    43665",
        "country": "IL"
    },
    "001C54": {
        "oui_hex": "00-1C-54",
        "organization": "Hillstone Networks Inc",
        "address_1": "A-1905 e-Wing Center",
        "address_2": "Beijing    100086",
        "country": "CN"
    },
    "001C59": {
        "oui_hex": "00-1C-59",
        "organization": "DEVON IT",
        "address_1": "1100 FIRST AVENUE",
        "address_2": "KING OF PRUSSIA  PA  19406",
        "country": "US"
    },
    "001C22": {
        "oui_hex": "00-1C-22",
        "organization": "Aeris Elettronica s.r.l.",
        "address_1": "Zona Ind.le Vallecupa",
        "address_2": "Colonnella  Teramo  64010",
        "country": "IT"
    },
    "001C1D": {
        "oui_hex": "00-1C-1D",
        "organization": "CHENZHOU GOSPELL DIGITAL TECHNOLOGY CO.,LTD",
        "address_1": "BAILUTANG,SUXIAN DISTRICT,",
        "address_2": "CHENZHOU  HUNAN  423025",
        "country": "CN"
    },
    "001C39": {
        "oui_hex": "00-1C-39",
        "organization": "S Netsystems Inc.",
        "address_1": "10F Sungwon Bldg., 141 Samsung-Dong",
        "address_2": "Seoul    135-716",
        "country": "KR"
    },
    "001C37": {
        "oui_hex": "00-1C-37",
        "organization": "Callpod, Inc.",
        "address_1": "850 W. Jackson",
        "address_2": "Chicago  IL  60607",
        "country": "US"
    },
    "001C33": {
        "oui_hex": "00-1C-33",
        "organization": "Sutron",
        "address_1": "21300 Ridgetop Cir",
        "address_2": "Sterling  VA  20166",
        "country": "US"
    },
    "001BF6": {
        "oui_hex": "00-1B-F6",
        "organization": "CONWISE Technology Corporation Ltd.",
        "address_1": "2F No.44, Park Ave. 2, Hsinchu Science Park",
        "address_2": "Hsinchu City    30075",
        "country": "TW"
    },
    "001BF8": {
        "oui_hex": "00-1B-F8",
        "organization": "Digitrax Inc.",
        "address_1": "2443 Transmitter Rd,",
        "address_2": "Panama City  FL  32404",
        "country": "US"
    },
    "001C2F": {
        "oui_hex": "00-1C-2F",
        "organization": "Pfister GmbH",
        "address_1": "Stätzlinger  SStraße 70",
        "address_2": "Augsburg  Bavaria  86165",
        "country": "DE"
    },
    "001C27": {
        "oui_hex": "00-1C-27",
        "organization": "Sunell Electronics Co.",
        "address_1": "3rd Floor,Bldg.514,BaGua Rd",
        "address_2": "ShenZhen  Guangdong  518029",
        "country": "CN"
    },
    "001C0F": {
        "oui_hex": "00-1C-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C48": {
        "oui_hex": "00-1C-48",
        "organization": "WiDeFi, Inc.",
        "address_1": "1333 Gateway Blvd",
        "address_2": "Melbourne  FL  32901",
        "country": "US"
    },
    "001BAD": {
        "oui_hex": "00-1B-AD",
        "organization": "iControl Incorporated",
        "address_1": "3235 Kifer Road",
        "address_2": "Santa Clara  California  95051",
        "country": "US"
    },
    "001BA7": {
        "oui_hex": "00-1B-A7",
        "organization": "Lorica Solutions",
        "address_1": "275 Northpointe Parkway",
        "address_2": "Amherst  NY  14228",
        "country": "US"
    },
    "001BA5": {
        "oui_hex": "00-1B-A5",
        "organization": "MyungMin Systems, Inc.",
        "address_1": "#410,Doosan Venture Dime 2-cha,1307-37",
        "address_2": "Kyungki-do    431-060",
        "country": "KR"
    },
    "001BF1": {
        "oui_hex": "00-1B-F1",
        "organization": "Nanjing SilverNet Software Co., Ltd.",
        "address_1": "3/F, 10 building, Nanjing World Window Technology & Software Park",
        "address_2": "Nanjing  Jiangsu  210013",
        "country": "CN"
    },
    "001BEF": {
        "oui_hex": "00-1B-EF",
        "organization": "Blossoms Digital Technology Co.,Ltd.",
        "address_1": "BLK25,Hengfeng Ind.City,Hezhou",
        "address_2": "Shenzhen  Guangdong  518126",
        "country": "CN"
    },
    "001BEB": {
        "oui_hex": "00-1B-EB",
        "organization": "DMP Electronics INC.",
        "address_1": "8F., No.12, Wucyuan 7th Rd.,",
        "address_2": "Taipei County    248",
        "country": "TW"
    },
    "001BA2": {
        "oui_hex": "00-1B-A2",
        "organization": "IDS Imaging Development Systems GmbH",
        "address_1": "Dimbacher Str. 6",
        "address_2": "Obersulm  BW  74182",
        "country": "DE"
    },
    "001B9D": {
        "oui_hex": "00-1B-9D",
        "organization": "Novus Security Sp. z o.o.",
        "address_1": "ul. Puławska 431",
        "address_2": "Warsaw  woj. mazowieckie  02-801",
        "country": "PL"
    },
    "001BC9": {
        "oui_hex": "00-1B-C9",
        "organization": "FSN DISPLAY INC",
        "address_1": "Baeksuk-Dong 1141-1, Ilsan Techno Town 1009",
        "address_2": "Koyang-si  Kyeonggi-Do  410722",
        "country": "KR"
    },
    "001BC3": {
        "oui_hex": "00-1B-C3",
        "organization": "Mobisolution Co.,Ltd",
        "address_1": "848-16",
        "address_2": "Gumi  Gyeongbuk  730-300",
        "country": "KR"
    },
    "001BCE": {
        "oui_hex": "00-1B-CE",
        "organization": "Measurement Devices Ltd",
        "address_1": "Redwood House",
        "address_2": "York  Yorkshire  YO266QR",
        "country": "GB"
    },
    "001BB8": {
        "oui_hex": "00-1B-B8",
        "organization": "BLUEWAY ELECTRONIC CO;LTD",
        "address_1": "Workshop B,Dong Feng Village,",
        "address_2": "HuiZhou  GuangDong  516008",
        "country": "CN"
    },
    "001BB2": {
        "oui_hex": "00-1B-B2",
        "organization": "Intellect International NV",
        "address_1": "Kleine Kloosterstraat 23",
        "address_2": "Zaventem  Vlaamse brabant  1932",
        "country": "BE"
    },
    "001BE7": {
        "oui_hex": "00-1B-E7",
        "organization": "Postek Electronics Co., Ltd.",
        "address_1": "Suite 510, Shanghang Building",
        "address_2": "Shen Zhen  Guang Dong  518028",
        "country": "CN"
    },
    "001BE3": {
        "oui_hex": "00-1B-E3",
        "organization": "Health Hero Network, Inc.",
        "address_1": "2000 Seaport Blvd.",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "001BDC": {
        "oui_hex": "00-1B-DC",
        "organization": "Vencer Co., Ltd.",
        "address_1": "20F-1, No.77, Sec.1, Hsin Tai Wu Rd.,",
        "address_2": "Hsi Chih  Taipei  221",
        "country": "TW"
    },
    "001BD5": {
        "oui_hex": "00-1B-D5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B95": {
        "oui_hex": "00-1B-95",
        "organization": "VIDEO SYSTEMS SRL",
        "address_1": "Loc. Gorizzo, 16",
        "address_2": "CAMINO AL TAGLIAMENTO  UD",
        "country": "IT"
    },
    "001B90": {
        "oui_hex": "00-1B-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B7F": {
        "oui_hex": "00-1B-7F",
        "organization": "TMN Technologies Telecomunicacoes Ltda",
        "address_1": "Rua Nilza, 422",
        "address_2": "São Paulo  SP  03651-120",
        "country": "BR"
    },
    "001B7E": {
        "oui_hex": "00-1B-7E",
        "organization": "Beckmann GmbH",
        "address_1": "Brandtstraße 1",
        "address_2": "Hoevelhof  NRW  33161",
        "country": "DE"
    },
    "001B7A": {
        "oui_hex": "00-1B-7A",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001B34": {
        "oui_hex": "00-1B-34",
        "organization": "Focus System Inc.",
        "address_1": "19F-1, No. 266 Wen Hwa 2nd Rd., Sec. 1",
        "address_2": "Linkou  Taipei County",
        "country": "TW"
    },
    "001B3A": {
        "oui_hex": "00-1B-3A",
        "organization": "SIMS Corp.",
        "address_1": "RAON Bldg, 9F, 92-8, Wonhyoro-2ga, Yongsan-gu",
        "address_2": "Seoul    140-847",
        "country": "KR"
    },
    "001B2E": {
        "oui_hex": "00-1B-2E",
        "organization": "Sinkyo Electron Inc",
        "address_1": "3-3-21 asahigaoka",
        "address_2": "hino-city  Tokyo  191-0065",
        "country": "JP"
    },
    "001B5F": {
        "oui_hex": "00-1B-5F",
        "organization": "Alien Technology",
        "address_1": "18220 Butterfield Blvd.",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "001B61": {
        "oui_hex": "00-1B-61",
        "organization": "Digital Acoustics, LLC",
        "address_1": "37 Sherwood Terrace",
        "address_2": "Lake Bluff  IL  60044",
        "country": "US"
    },
    "001B5E": {
        "oui_hex": "00-1B-5E",
        "organization": "BPL Limited",
        "address_1": "BPL Towers",
        "address_2": "Bangalore  Karnataka  560001",
        "country": "IN"
    },
    "001B5C": {
        "oui_hex": "00-1B-5C",
        "organization": "Azuretec Co., Ltd.",
        "address_1": "3F, No.8, Alley 8, Lane 45, Baoxing Rd., Xindian Dist.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "001B72": {
        "oui_hex": "00-1B-72",
        "organization": "Sicep s.p.a.",
        "address_1": "Via calabria, 14",
        "address_2": "Certaldo    50052",
        "country": "IT"
    },
    "001B74": {
        "oui_hex": "00-1B-74",
        "organization": "MiraLink Corporation",
        "address_1": "111 SW 5th Ave.",
        "address_2": "Portland  OR  97204",
        "country": "US"
    },
    "001B6D": {
        "oui_hex": "00-1B-6D",
        "organization": "Midtronics, Inc.",
        "address_1": "7000 Monroe St.",
        "address_2": "Willowbrook  IL  60527",
        "country": "US"
    },
    "001B6F": {
        "oui_hex": "00-1B-6F",
        "organization": "Teletrak Ltd",
        "address_1": "214 Kepa Road",
        "address_2": "Auckland    1071",
        "country": "NZ"
    },
    "001B4B": {
        "oui_hex": "00-1B-4B",
        "organization": "SANION Co., Ltd.",
        "address_1": "#208 ACETECHNO TOWER, 55-7, MULLAE-DONG 3GA,",
        "address_2": "YEONGDEUNGPO-GU  SEOUL  150-992",
        "country": "KR"
    },
    "001B2D": {
        "oui_hex": "00-1B-2D",
        "organization": "Med-Eng Systems Inc.",
        "address_1": "2400 St. Laurent Blvd.",
        "address_2": "Ottawa  Ontario  K1G 6C4",
        "country": "CA"
    },
    "001B87": {
        "oui_hex": "00-1B-87",
        "organization": "Deepsound Tech. Co., Ltd",
        "address_1": "3F No. 576 Sec. 1, Minsheng N. Rd., Gueishan Township,",
        "address_2": "Taoyuan    333",
        "country": "TW"
    },
    "001B4D": {
        "oui_hex": "00-1B-4D",
        "organization": "Areca Technology Corporation",
        "address_1": "8F., No. 22, Lane 35, Ji-Hu Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001AE3": {
        "oui_hex": "00-1A-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001ADF": {
        "oui_hex": "00-1A-DF",
        "organization": "Interactivetv Pty Limited",
        "address_1": "Suite 10 Level 3",
        "address_2": "Pyrmont, Sydney  NSW  2009",
        "country": "US"
    },
    "001AE1": {
        "oui_hex": "00-1A-E1",
        "organization": "EDGE ACCESS INC",
        "address_1": "5440 BEAUMONT CENTER BLVD",
        "address_2": "TAMPA  FL  33634",
        "country": "US"
    },
    "001AE8": {
        "oui_hex": "00-1A-E8",
        "organization": "Unify Software and Solutions GmbH & Co. KG",
        "address_1": " Mies-van-der-Rohe-Strasse 6",
        "address_2": "Munich    80807",
        "country": "DE"
    },
    "001AE9": {
        "oui_hex": "00-1A-E9",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001AE5": {
        "oui_hex": "00-1A-E5",
        "organization": "Mvox Technologies Inc.",
        "address_1": "19050 Pruneridge Ave",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001AE4": {
        "oui_hex": "00-1A-E4",
        "organization": "Medicis Technologies Corporation",
        "address_1": "11818 North Creek Parkway N.",
        "address_2": "Bothell  WA  98011",
        "country": "US"
    },
    "001AF8": {
        "oui_hex": "00-1A-F8",
        "organization": "Copley Controls Corporation",
        "address_1": "20 Dan Road",
        "address_2": "Canton  MA  02021",
        "country": "US"
    },
    "001AF5": {
        "oui_hex": "00-1A-F5",
        "organization": "PENTAONE. CO., LTD.",
        "address_1": "Hyo Chang Bldg, 3F, 1013-6, Inkye-dong Paldal-Gu,",
        "address_2": "Suwon City  Gyunggi-Do  422-833",
        "country": "KR"
    },
    "001AED": {
        "oui_hex": "00-1A-ED",
        "organization": "INCOTEC GmbH",
        "address_1": "Blomestrasse 25 - 27",
        "address_2": "Bielefeld  NRW  33609",
        "country": "DE"
    },
    "001AEE": {
        "oui_hex": "00-1A-EE",
        "organization": "Shenztech Ltd",
        "address_1": "813, 8F, HOLLYWOOD PLAZA, 610 NATHAN ROAD,",
        "address_2": "KOWLOON    852",
        "country": "HK"
    },
    "001ACE": {
        "oui_hex": "00-1A-CE",
        "organization": "YUPITERU CORPORATION",
        "address_1": "3, Dannoue, Iwazu-cho, Okazaki-city, Aichi",
        "address_2": "Okazaki  Aichi  444-2144",
        "country": "JP"
    },
    "001ACC": {
        "oui_hex": "00-1A-CC",
        "organization": "Celestial Semiconductor, Ltd",
        "address_1": "Ugland House, South Church Street,",
        "address_2": "George Town,   Cayman Islands  00000",
        "country": "KY"
    },
    "001AD2": {
        "oui_hex": "00-1A-D2",
        "organization": "Eletronica Nitron Ltda",
        "address_1": "Rua Dr. Ulisses Escobar 415",
        "address_2": "Camanducaia  Minas Gerais  37650-000",
        "country": "BR"
    },
    "001B1D": {
        "oui_hex": "00-1B-1D",
        "organization": "Phoenix International Co., Ltd",
        "address_1": "11F. No.42-1, Sec.1, Zhongyang N. Rd. Beitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "001B1A": {
        "oui_hex": "00-1B-1A",
        "organization": "e-trees Japan, Inc.",
        "address_1": "Oowada-cho 2-9-2",
        "address_2": "Hachioji-city  Tokyo  150-0001",
        "country": "JP"
    },
    "001B12": {
        "oui_hex": "00-1B-12",
        "organization": "Apprion",
        "address_1": "Nasa Ames Rerearch Center",
        "address_2": "Moffett Field  California  94035",
        "country": "US"
    },
    "001AFE": {
        "oui_hex": "00-1A-FE",
        "organization": "SOFACREAL",
        "address_1": "149 avenue du MAINE",
        "address_2": "PARIS  Region Parisienne  75014",
        "country": "FR"
    },
    "001AF1": {
        "oui_hex": "00-1A-F1",
        "organization": "Embedded Artists AB",
        "address_1": "Davidshallsgatan 16",
        "address_2": "Malmoe    21145",
        "country": "SE"
    },
    "001B0D": {
        "oui_hex": "00-1B-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B0A": {
        "oui_hex": "00-1B-0A",
        "organization": "Intelligent Distributed Controls Ltd",
        "address_1": "Keynes House, Chester Park",
        "address_2": "Derby  Derbyshire  DE21 4AS",
        "country": "GB"
    },
    "001AB1": {
        "oui_hex": "00-1A-B1",
        "organization": "Asia Pacific Satellite Industries Co., Ltd.",
        "address_1": "9th FL, IT Castle 2-Dong, #550-1, Gasan-Dong, GeumCheon-Gu,",
        "address_2": "Seoul    153-768",
        "country": "KR"
    },
    "001AB7": {
        "oui_hex": "00-1A-B7",
        "organization": "Ethos Networks LTD.",
        "address_1": "2 Maskit St.",
        "address_2": "Herzlia    46766",
        "country": "IL"
    },
    "001AB2": {
        "oui_hex": "00-1A-B2",
        "organization": "Cyber Solutions Inc.",
        "address_1": "6-6-3, Minami Yoshinari",
        "address_2": "Sendai  Miyagi-ken  989-3204",
        "country": "JP"
    },
    "001A97": {
        "oui_hex": "00-1A-97",
        "organization": "fitivision technology Inc.",
        "address_1": "8F, No. 356, Sec. 1, Neihu Rd",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001A90": {
        "oui_hex": "00-1A-90",
        "organization": "Trópico Sistemas e Telecomunicações da Amazônia LTDA.",
        "address_1": "Rod.  Campinas-Mogi-Mirim (SP 340)  Km 118,5",
        "address_2": "Campinas  São Paulo  13.086-902",
        "country": "BR"
    },
    "001A94": {
        "oui_hex": "00-1A-94",
        "organization": "Votronic GmbH",
        "address_1": "Saarbruecker Str. 8",
        "address_2": "St. Ingbert  Saarland  66386",
        "country": "DE"
    },
    "001A86": {
        "oui_hex": "00-1A-86",
        "organization": "AdvancedIO Systems Inc",
        "address_1": "595 Howe Street, Suite 502",
        "address_2": "Vancouver  BC  V6C 2T5",
        "country": "CA"
    },
    "001AC7": {
        "oui_hex": "00-1A-C7",
        "organization": "UNIPOINT",
        "address_1": "7F Gwangsung Bld 831-47 YeokSam-Dong",
        "address_2": "Seoul    135-936",
        "country": "KR"
    },
    "001AC0": {
        "oui_hex": "00-1A-C0",
        "organization": "JOYBIEN TECHNOLOGIES CO., LTD.",
        "address_1": "14F-7, NO.2, JIAN 8TH RD.,",
        "address_2": "NEW TAIPEI CITY  TAIWAN  23511",
        "country": "TW"
    },
    "001A9E": {
        "oui_hex": "00-1A-9E",
        "organization": "ICON Digital International Limited",
        "address_1": "Suite2209, 22/F., SkyLine Tower,",
        "address_2": "",
        "country": "CN"
    },
    "001A98": {
        "oui_hex": "00-1A-98",
        "organization": "Asotel Communication Limited Taiwan Branch",
        "address_1": "3G17, No5, Hsin Yi Road, Sec. 5",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001A72": {
        "oui_hex": "00-1A-72",
        "organization": "Mosart Semiconductor Corp.",
        "address_1": "23F., No.33, Sec.1,",
        "address_2": "Taipei    220",
        "country": "TW"
    },
    "001A68": {
        "oui_hex": "00-1A-68",
        "organization": "Weltec Enterprise Co., Ltd.",
        "address_1": "2F, No. 351 Yung Ho Rd.",
        "address_2": "Chung Ho    235",
        "country": "TW"
    },
    "001AC2": {
        "oui_hex": "00-1A-C2",
        "organization": "YEC Co.,Ltd.",
        "address_1": "543-9 Tsuruma",
        "address_2": "Machida  Tokyo  194-0004",
        "country": "JP"
    },
    "001AA5": {
        "oui_hex": "00-1A-A5",
        "organization": "BRN Phoenix",
        "address_1": "2500 Augustine Drive, Suite 200",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001AA2": {
        "oui_hex": "00-1A-A2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001A9C": {
        "oui_hex": "00-1A-9C",
        "organization": "RightHand Technologies, Inc.",
        "address_1": "7450 W Wilson Avenue",
        "address_2": "Chicago  IL  60706",
        "country": "US"
    },
    "001A7E": {
        "oui_hex": "00-1A-7E",
        "organization": "LN Srithai Comm Ltd.",
        "address_1": "71/12 M.5, Bangna-Trad Rd, KM.52, Thakam",
        "address_2": "Bangpakong  Chachoengsao  24130",
        "country": "TH"
    },
    "001A5A": {
        "oui_hex": "00-1A-5A",
        "organization": "Korea Electric Power Data Network  (KDN) Co., Ltd",
        "address_1": "665 NAESON-DONG,",
        "address_2": "GYEONGGI-DO  UIWANG-SI, NAESON-DONG  437-082",
        "country": "KR"
    },
    "001A5F": {
        "oui_hex": "00-1A-5F",
        "organization": "KitWorks.fi Ltd.",
        "address_1": "Snowpolis",
        "address_2": "Vuokatti  Kainuu  88610",
        "country": "FI"
    },
    "001A35": {
        "oui_hex": "00-1A-35",
        "organization": "BARTEC GmbH",
        "address_1": "Schulstraße 30",
        "address_2": "Gotteszell  Bavaria  94239",
        "country": "DE"
    },
    "001A37": {
        "oui_hex": "00-1A-37",
        "organization": "Lear Corporation",
        "address_1": "Industriestrasse 48",
        "address_2": "Kronach  Bayern  96317",
        "country": "DE"
    },
    "001A38": {
        "oui_hex": "00-1A-38",
        "organization": "Sanmina-SCI",
        "address_1": "13000 South Memorial Parkway",
        "address_2": "Huntsville  AL  35803",
        "country": "US"
    },
    "001A2B": {
        "oui_hex": "00-1A-2B",
        "organization": "Ayecom Technology Co., Ltd.",
        "address_1": "No. 25, R&D Road 2, Science-Based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001A28": {
        "oui_hex": "00-1A-28",
        "organization": "ASWT Co., LTD. Taiwan Branch H.K.",
        "address_1": "7F., No.3 Lane 91, Dongmei Rd.",
        "address_2": "Hsinchu    30070",
        "country": "TW"
    },
    "001A2C": {
        "oui_hex": "00-1A-2C",
        "organization": "SATEC Co.,LTD",
        "address_1": "358-4, Palgok2-Dong, Sangnok-Gu",
        "address_2": "Ansan-Si  Kyungki-Do  426-190",
        "country": "KR"
    },
    "001A27": {
        "oui_hex": "00-1A-27",
        "organization": "Ubistar",
        "address_1": "8F, Seongo Building, 587-23",
        "address_2": "Seoul    135-747",
        "country": "KR"
    },
    "001A21": {
        "oui_hex": "00-1A-21",
        "organization": "Brookhuis Applied Technologies BV",
        "address_1": "PO Box 79",
        "address_2": "Enschede    NL-7500",
        "country": "NL"
    },
    "0019FF": {
        "oui_hex": "00-19-FF",
        "organization": "Finnzymes",
        "address_1": "800 West Cummings Park",
        "address_2": "Woburn  MA  01801",
        "country": "US"
    },
    "0019FA": {
        "oui_hex": "00-19-FA",
        "organization": "Cable Vision Electronics CO., LTD.",
        "address_1": "12F-3, No.16, Chien Pa Rd.",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001A5D": {
        "oui_hex": "00-1A-5D",
        "organization": "Mobinnova Corp.",
        "address_1": "11F, 845, CHUNG SHAN RD",
        "address_2": "TAOYUAN    33059",
        "country": "TW"
    },
    "001A4D": {
        "oui_hex": "00-1A-4D",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "001A48": {
        "oui_hex": "00-1A-48",
        "organization": "Takacom Corporation",
        "address_1": "304-709 Aza-Nishiyanma",
        "address_2": "Toki-shi  Gifu-ken  509-5202",
        "country": "JP"
    },
    "001A0B": {
        "oui_hex": "00-1A-0B",
        "organization": "BONA TECHNOLOGY INC.",
        "address_1": "4F, E-Place Bldg., 719-24",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "001A06": {
        "oui_hex": "00-1A-06",
        "organization": "OpVista, Inc.",
        "address_1": "870 North McCarthy Blvd.",
        "address_2": "Milpitas  California  95035",
        "country": "US"
    },
    "001A2E": {
        "oui_hex": "00-1A-2E",
        "organization": "Ziova Coporation",
        "address_1": "Unit 3, 7-9 Sherriffs road",
        "address_2": "Lonsdale  S.A.  5160",
        "country": "AU"
    },
    "001A32": {
        "oui_hex": "00-1A-32",
        "organization": "ACTIVA MULTIMEDIA",
        "address_1": "SICP CSE",
        "address_2": "SANT JOAN DESPI  BARCELONA  08970",
        "country": "ES"
    },
    "001A00": {
        "oui_hex": "00-1A-00",
        "organization": "MATRIX INC.",
        "address_1": "AS bld.3-13-20",
        "address_2": "Osaka    530-0047",
        "country": "JP"
    },
    "0019AD": {
        "oui_hex": "00-19-AD",
        "organization": "BOBST SA",
        "address_1": "rte des flumeaux 50",
        "address_2": "PRILLY  VD  1008",
        "country": "CH"
    },
    "0019A2": {
        "oui_hex": "00-19-A2",
        "organization": "ORDYN TECHNOLOGIES",
        "address_1": "Ozone Manay Tech Park,",
        "address_2": "Bangalore     560 068",
        "country": "IN"
    },
    "0019A5": {
        "oui_hex": "00-19-A5",
        "organization": "RadarFind Corporation",
        "address_1": "2100 Gateway Centre Blvd., Suite 150",
        "address_2": "Morrisville  NC  27560",
        "country": "US"
    },
    "001993": {
        "oui_hex": "00-19-93",
        "organization": "Changshu Switchgear MFG. Co.,Ltd. (Former Changshu Switchgea",
        "address_1": "No. 8 Jianye Road",
        "address_2": "Changshu  Jiangsu  215500",
        "country": "CN"
    },
    "0019F1": {
        "oui_hex": "00-19-F1",
        "organization": "Star Communication Network Technology Co.,Ltd",
        "address_1": "10/F,Tower B,SOHO New Town,No.88 jianguoRoad,Chaoyang District",
        "address_2": "Beijing    100022",
        "country": "CN"
    },
    "0019EC": {
        "oui_hex": "00-19-EC",
        "organization": "Sagamore Systems, Inc.",
        "address_1": "55 Middlesex Street",
        "address_2": "North Chelmsford  MA  01863",
        "country": "US"
    },
    "0019CC": {
        "oui_hex": "00-19-CC",
        "organization": "RCG (HK) Ltd",
        "address_1": "9/F., Core C, Cyberport 3",
        "address_2": "",
        "country": "HK"
    },
    "0019C8": {
        "oui_hex": "00-19-C8",
        "organization": "AnyDATA Corporation",
        "address_1": "18902 Bardeen Ave.",
        "address_2": "Irvine  CA  91612",
        "country": "US"
    },
    "0019C4": {
        "oui_hex": "00-19-C4",
        "organization": "Infocrypt Inc.",
        "address_1": "711, BYUCKSAN DIGITAL VALLEY 1 212-16,",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "0019BC": {
        "oui_hex": "00-19-BC",
        "organization": "ELECTRO CHANCE SRL",
        "address_1": "CARHUE 3179",
        "address_2": "CAPITAL FEDERAL  BUENOS AIRES  1440",
        "country": "AR"
    },
    "00199B": {
        "oui_hex": "00-19-9B",
        "organization": "Diversified Technical Systems, Inc.",
        "address_1": "909 Electric Avenue",
        "address_2": "Seal Beach  California  90740",
        "country": "US"
    },
    "001990": {
        "oui_hex": "00-19-90",
        "organization": "ELM DATA Co., Ltd.",
        "address_1": "2-15 TECHNO-PARK 1-CHOME",
        "address_2": "SAPPORO  HOKKAIDO  004-0015",
        "country": "JP"
    },
    "00198F": {
        "oui_hex": "00-19-8F",
        "organization": "Nokia Bell N.V.",
        "address_1": "Copernicuslaan 50",
        "address_2": "Antwerp    B-2018",
        "country": "BE"
    },
    "0019D8": {
        "oui_hex": "00-19-D8",
        "organization": "MAXFOR",
        "address_1": "#E 809, Bundang, Techno-Park",
        "address_2": "Seongnam-City  Gyeonggi-Do  463-760",
        "country": "KR"
    },
    "0019D5": {
        "oui_hex": "00-19-D5",
        "organization": "IP Innovations, Inc.",
        "address_1": "1517 146th Ave",
        "address_2": "Dorr  MI  49323",
        "country": "US"
    },
    "0019A3": {
        "oui_hex": "00-19-A3",
        "organization": "asteel electronique atlantique",
        "address_1": "za de la lande de saint jean",
        "address_2": "sainte marie de redon    35600",
        "country": "FR"
    },
    "0019EA": {
        "oui_hex": "00-19-EA",
        "organization": "TeraMage Technologies Co., Ltd.",
        "address_1": "Golden Land Building Suite 907",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "00196E": {
        "oui_hex": "00-19-6E",
        "organization": "Metacom (Pty) Ltd.",
        "address_1": "6 Ndabeni Business Park",
        "address_2": "Cape Town  Western Cape  7405",
        "country": "ZA"
    },
    "001965": {
        "oui_hex": "00-19-65",
        "organization": "YuHua TelTech (ShangHai) Co., Ltd.",
        "address_1": "YuHua R&D Building,27 xin jin qiao road,",
        "address_2": "SHANGHAI    201206",
        "country": "CN"
    },
    "001966": {
        "oui_hex": "00-19-66",
        "organization": "Asiarock Technology Limited",
        "address_1": "P.O. Box957, Offshore Incorporations Centre",
        "address_2": "Road Town  Tortola",
        "country": "VG"
    },
    "00197B": {
        "oui_hex": "00-19-7B",
        "organization": "Picotest Corp.",
        "address_1": "8F-1, 286-9, Hsin-Ya Rd., 80673",
        "address_2": "Kaohsiung    80673",
        "country": "TW"
    },
    "001973": {
        "oui_hex": "00-19-73",
        "organization": "Zeugma Systems",
        "address_1": "Suite 250",
        "address_2": "Richmond  BC  V6V 2R2",
        "country": "CA"
    },
    "001975": {
        "oui_hex": "00-19-75",
        "organization": "Beijing Huisen networks technology Inc",
        "address_1": "Jia#2 of Xili of Baiyun road,Xicheng district",
        "address_2": "Beijing    100045",
        "country": "CN"
    },
    "001940": {
        "oui_hex": "00-19-40",
        "organization": "Rackable Systems",
        "address_1": "1933 Milmont Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00193C": {
        "oui_hex": "00-19-3C",
        "organization": "HighPoint Technologies Incorporated",
        "address_1": "1161 Cadillac Court",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00195C": {
        "oui_hex": "00-19-5C",
        "organization": "Innotech Corporation",
        "address_1": "3-17-6",
        "address_2": "Yokohama  Kanagawa  222-8580",
        "country": "JP"
    },
    "00195F": {
        "oui_hex": "00-19-5F",
        "organization": "Valemount Networks Corporation",
        "address_1": "1201- 5th Ave",
        "address_2": "Valemount  BC  V0E2Z0",
        "country": "CA"
    },
    "001948": {
        "oui_hex": "00-19-48",
        "organization": "AireSpider Networks",
        "address_1": "1171 Montague Express Way",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001943": {
        "oui_hex": "00-19-43",
        "organization": "Belden",
        "address_1": "793 Fort Mill Highway",
        "address_2": "Fort Mill  South Carolina  29715",
        "country": "US"
    },
    "00192E": {
        "oui_hex": "00-19-2E",
        "organization": "Spectral Instruments, Inc.",
        "address_1": "420 N Bonita Ave",
        "address_2": "Tucson  AZ  85745",
        "country": "US"
    },
    "00192B": {
        "oui_hex": "00-19-2B",
        "organization": "Aclara RF Systems Inc.",
        "address_1": "30400 Solon Road",
        "address_2": "Solon  OH  44139",
        "country": "US"
    },
    "00191E": {
        "oui_hex": "00-19-1E",
        "organization": "Beyondwiz Co., Ltd.",
        "address_1": "3F, Daechang Bldg.,",
        "address_2": "Sungnam  Kyungki-do  463-825",
        "country": "KR"
    },
    "001981": {
        "oui_hex": "00-19-81",
        "organization": "Vivox Inc",
        "address_1": "40 Speen Street",
        "address_2": "Framingham  MA  01701",
        "country": "US"
    },
    "001945": {
        "oui_hex": "00-19-45",
        "organization": "RF COncepts, LLC",
        "address_1": "1148 Wagner Drive",
        "address_2": "Sevierville  TN  37862",
        "country": "US"
    },
    "00191F": {
        "oui_hex": "00-19-1F",
        "organization": "Microlink communications Inc.",
        "address_1": "8F , 31 , Hsintai Road , Chupei City , Hsinchu",
        "address_2": "Chupei  Taiwan  302",
        "country": "TW"
    },
    "001920": {
        "oui_hex": "00-19-20",
        "organization": "KUME electric Co.,Ltd.",
        "address_1": "4-2-24 Kitakawara",
        "address_2": "Itami-city  Hyougo",
        "country": "JP"
    },
    "001926": {
        "oui_hex": "00-19-26",
        "organization": "BitsGen Co., Ltd.",
        "address_1": "#502, Owner's Tower, #16-5, Sunea-dong",
        "address_2": "Bundang-gu  Seongnam-si  463-825",
        "country": "KR"
    },
    "001929": {
        "oui_hex": "00-19-29",
        "organization": "2M2B Montadora de Maquinas Bahia Brasil LTDA",
        "address_1": "Rua Djalma dutra, 668, Sete Portas",
        "address_2": "Salvador  Bahia  40240080",
        "country": "BR"
    },
    "0018F1": {
        "oui_hex": "00-18-F1",
        "organization": "Chunichi Denshi Co.,LTD.",
        "address_1": "1 Denjiyama",
        "address_2": "Nagoya  Aichi  458-8525",
        "country": "JP"
    },
    "0018F2": {
        "oui_hex": "00-18-F2",
        "organization": "Beijing Tianyu Communication Equipment Co., Ltd",
        "address_1": "27th Floor, Tengda Plaza",
        "address_2": "Beijing    100044",
        "country": "CN"
    },
    "0018EC": {
        "oui_hex": "00-18-EC",
        "organization": "Welding Technology Corporation",
        "address_1": "24775 Crestview Court",
        "address_2": "Farmington Hills  MI  48335",
        "country": "US"
    },
    "0018ED": {
        "oui_hex": "00-18-ED",
        "organization": "Accutech Ultrasystems Co., Ltd.",
        "address_1": "11F-4, No. 150,",
        "address_2": "CHUNG-HO CITY,  TAIPEI HSIEN,  235",
        "country": "TW"
    },
    "00190B": {
        "oui_hex": "00-19-0B",
        "organization": "Southern Vision Systems, Inc.",
        "address_1": "8215 Madison Blvd, Suite 150",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "001903": {
        "oui_hex": "00-19-03",
        "organization": "Bigfoot Networks Inc",
        "address_1": "3925 West Braker Lane",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "001900": {
        "oui_hex": "00-19-00",
        "organization": "Intelliverese - DBA Voicecom",
        "address_1": "5900 Windward Parkway",
        "address_2": "Alpharetta  Georgia  30005",
        "country": "US"
    },
    "001902": {
        "oui_hex": "00-19-02",
        "organization": "Cambridge Consultants Ltd",
        "address_1": "Science Park",
        "address_2": "Cambridge  Cambs  CB4 0DW",
        "country": "GB"
    },
    "00192A": {
        "oui_hex": "00-19-2A",
        "organization": "Antiope Associates",
        "address_1": "18 Clay Street",
        "address_2": "Fair Haven  New Jersey  07704",
        "country": "US"
    },
    "00190F": {
        "oui_hex": "00-19-0F",
        "organization": "Advansus Corp.",
        "address_1": "No.5 Shing Yeh Street, Kwei Hsiang",
        "address_2": "Taoyuan    333",
        "country": "TW"
    },
    "001911": {
        "oui_hex": "00-19-11",
        "organization": "Just In Mobile Information Technologies (Shanghai) Co., Ltd.",
        "address_1": "5th Floor, 2nd Area, Haiwangxing Building, 62 Xingguang Ave., N.High-Tech Park",
        "address_2": "Chongqing    401121",
        "country": "CN"
    },
    "0018E0": {
        "oui_hex": "00-18-E0",
        "organization": "ANAVEO",
        "address_1": "Les Carrés du parc",
        "address_2": "CHAMPAGNE au MONT D'OR  Rhône  F-69410",
        "country": "FR"
    },
    "001917": {
        "oui_hex": "00-19-17",
        "organization": "Posiflex Inc.",
        "address_1": "6, Wu-Chuan Road",
        "address_2": "Taipei Hsien    248",
        "country": "TW"
    },
    "001918": {
        "oui_hex": "00-19-18",
        "organization": "Interactive Wear AG",
        "address_1": "Petersbrunner Strasse 3",
        "address_2": "Starnberg  Bayern  82319",
        "country": "DE"
    },
    "0018CB": {
        "oui_hex": "00-18-CB",
        "organization": "Tecobest Technology Limited",
        "address_1": "53/F.,Block A,United Plaza,",
        "address_2": "Shenzhen  Guangdong  518026",
        "country": "CN"
    },
    "0018CE": {
        "oui_hex": "00-18-CE",
        "organization": "Dreamtech Co., Ltd",
        "address_1": "#340-5, Yang-dang Ri, Jik-san Myeon",
        "address_2": "Cheon-an si  Chung-Nam  330810",
        "country": "KR"
    },
    "001894": {
        "oui_hex": "00-18-94",
        "organization": "NPCore, Inc.",
        "address_1": "1001, ISBIZ Tower",
        "address_2": "Youngdungpo Gu  Seoul  150-105",
        "country": "KR"
    },
    "001898": {
        "oui_hex": "00-18-98",
        "organization": "KINGSTATE ELECTRONICS CORPORATION",
        "address_1": "10F, No.69-11, Sec.2, Chung Cheng E. Rd.,",
        "address_2": "Taipei County    251",
        "country": "TW"
    },
    "001892": {
        "oui_hex": "00-18-92",
        "organization": "ads-tec GmbH",
        "address_1": "Raiffeisenstrasse 14",
        "address_2": "Leinfelden-Echterdingen  BW  70771",
        "country": "DE"
    },
    "001891": {
        "oui_hex": "00-18-91",
        "organization": "Zhongshan General K-mate Electronics Co., Ltd",
        "address_1": "3/F B1 Building, Fuwan Ind. Zone Sun Wen East Road",
        "address_2": "Zhongshan  Guangdong  528403",
        "country": "CN"
    },
    "0018AD": {
        "oui_hex": "00-18-AD",
        "organization": "NIDEC SANKYO CORPORATION",
        "address_1": "5329, Shimosuwa-machi, Suwa-gun",
        "address_2": "  Nagano  393-8511",
        "country": "JP"
    },
    "0018AC": {
        "oui_hex": "00-18-AC",
        "organization": "Shanghai Jiao Da HISYS Technology Co. Ltd.",
        "address_1": "7F Haoran HiTech Bldg., No.1954 Huashan Road",
        "address_2": "shanghai  xuhui  200030",
        "country": "US"
    },
    "0018AB": {
        "oui_hex": "00-18-AB",
        "organization": "BEIJING LHWT MICROELECTRONICS INC.",
        "address_1": "18/F,QUANTUM PLAZA,NO.27 ZHI CHUN RD.,HAI DIAN DISTRICT,BEIJING",
        "address_2": "",
        "country": "CN"
    },
    "0018A5": {
        "oui_hex": "00-18-A5",
        "organization": "ADigit Technologies Corp.",
        "address_1": "Rm D302E,No.185 3F-2,Kur-Wong Road,",
        "address_2": "Tao-yuan,    325",
        "country": "TW"
    },
    "001878": {
        "oui_hex": "00-18-78",
        "organization": "Mackware GmbH",
        "address_1": "Schänzle 13",
        "address_2": "Waiblingen  Baden-Württemberg  71332",
        "country": "DE"
    },
    "00186A": {
        "oui_hex": "00-18-6A",
        "organization": "Global Link Digital Technology Co,.LTD",
        "address_1": "Qibaoyiding Ind.Area",
        "address_2": "Dongguan  Guangdong  523051",
        "country": "CN"
    },
    "00186B": {
        "oui_hex": "00-18-6B",
        "organization": "Sambu Communics CO., LTD.",
        "address_1": "38B-1L Namdong Industrial Complex",
        "address_2": "Incheon    405-100",
        "country": "KR"
    },
    "00186E": {
        "oui_hex": "00-18-6E",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "0018A6": {
        "oui_hex": "00-18-A6",
        "organization": "Persistent Systems, LLC",
        "address_1": "118 N. Howard St. #72",
        "address_2": "Baltimore  MD  21201",
        "country": "US"
    },
    "00189B": {
        "oui_hex": "00-18-9B",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290-1102",
        "country": "US"
    },
    "0018B2": {
        "oui_hex": "00-18-B2",
        "organization": "ADEUNIS RF",
        "address_1": "283 Rue NEEL",
        "address_2": "CROLLES  ISERE  38920",
        "country": "FR"
    },
    "0018B3": {
        "oui_hex": "00-18-B3",
        "organization": "TEC WizHome Co., Ltd.",
        "address_1": "18fl., In-Song bldg., 194-15,",
        "address_2": "Seoul    100-952",
        "country": "KR"
    },
    "0018BD": {
        "oui_hex": "00-18-BD",
        "organization": "SHENZHEN DVBWORLD TECHNOLOGY CO., LTD.",
        "address_1": "2ND FLOOR, BUILDING A, QINGHU XINQIAO INDUSTRY AREA,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "001867": {
        "oui_hex": "00-18-67",
        "organization": "Datalogic ADC",
        "address_1": "433 N. Fair Oaks Ave",
        "address_2": "Pasadena  CA  91103",
        "country": "US"
    },
    "001865": {
        "oui_hex": "00-18-65",
        "organization": "Siemens Healthcare Diagnostics Manufacturing Ltd",
        "address_1": "Northern Road",
        "address_2": "Sudbury  Suffolk  C010 2XQ",
        "country": "GB"
    },
    "001877": {
        "oui_hex": "00-18-77",
        "organization": "Amplex A/S",
        "address_1": "Silkeborgvej 2",
        "address_2": "Aarhus C    8000",
        "country": "DK"
    },
    "001889": {
        "oui_hex": "00-18-89",
        "organization": "WinNet Solutions Limited",
        "address_1": "Rm804, Kornhill Metro Tower, Quarry Bay",
        "address_2": "  HK  852",
        "country": "HK"
    },
    "0017F9": {
        "oui_hex": "00-17-F9",
        "organization": "Forcom Sp. z o.o.",
        "address_1": "Gajowa 6",
        "address_2": "Poznan  WLKP  60-815",
        "country": "PL"
    },
    "0017F4": {
        "oui_hex": "00-17-F4",
        "organization": "ZERON ALLIANCE",
        "address_1": " 3F DOORI BUILD. 244-14 bunji, Poi-dong, Gangnam-gu",
        "address_2": "SEOUL    135-965",
        "country": "KR"
    },
    "0017F7": {
        "oui_hex": "00-17-F7",
        "organization": "CEM Solutions Pvt Ltd",
        "address_1": "49,Kanija Bhavan",
        "address_2": "Bangalore  Karnataka  560 001",
        "country": "IN"
    },
    "0017ED": {
        "oui_hex": "00-17-ED",
        "organization": "WooJooIT Ltd.",
        "address_1": "Hankooktire B/D 4th floor, 501-19,",
        "address_2": "Yangcheon-gu,  Seoul  158-839",
        "country": "KR"
    },
    "001843": {
        "oui_hex": "00-18-43",
        "organization": "Dawevision Ltd",
        "address_1": "197 High Street",
        "address_2": "Cottenham  Cambridge  CB4 8RX",
        "country": "GB"
    },
    "00182C": {
        "oui_hex": "00-18-2C",
        "organization": "Ascend Networks, Inc.",
        "address_1": "No. 4 - 4, Lane 413, ChungChan Road,",
        "address_2": "BenQuao City  Taipei  220",
        "country": "TW"
    },
    "00181D": {
        "oui_hex": "00-18-1D",
        "organization": "ASIA ELECTRONICS CO.,LTD",
        "address_1": "620-3 DOCHEON-DONG",
        "address_2": "GWANGJU    506-301",
        "country": "KR"
    },
    "00181F": {
        "oui_hex": "00-18-1F",
        "organization": "Palmmicro Communications",
        "address_1": "Room 0611, Bldg.B Tsinghua Tongfang Technology Plaza",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "00181B": {
        "oui_hex": "00-18-1B",
        "organization": "TaiJin Metal Co., Ltd.",
        "address_1": "#95-9, Hangdong7-Ga, Joong-Gu",
        "address_2": "In Cheon    400-037",
        "country": "KR"
    },
    "001805": {
        "oui_hex": "00-18-05",
        "organization": "Beijing InHand Networking Technology Co.,Ltd.",
        "address_1": "West Wing 11th Floor of Qiming International Mansion",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "00180D": {
        "oui_hex": "00-18-0D",
        "organization": "Terabytes Server Storage Tech Corp",
        "address_1": "14257 E Don Julian Rd",
        "address_2": "City of Industry  CA  91746",
        "country": "US"
    },
    "001854": {
        "oui_hex": "00-18-54",
        "organization": "Argard Co., Ltd",
        "address_1": "2571 Lardprao Rd.",
        "address_2": "wangthonglang  Bangkok  10310",
        "country": "TH"
    },
    "001847": {
        "oui_hex": "00-18-47",
        "organization": "AceNet Technology Inc.",
        "address_1": "133 Vienna Dr.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001836": {
        "oui_hex": "00-18-36",
        "organization": "REJ Co.,Ltd",
        "address_1": "2-3-2 Fukuura, Kanazawa-ku",
        "address_2": "Yokohama  Kanagawa  236-8641",
        "country": "JP"
    },
    "0017CC": {
        "oui_hex": "00-17-CC",
        "organization": "Alcatel-Lucent",
        "address_1": "601 Data Dr.",
        "address_2": "Plano  TX  75075",
        "country": "US"
    },
    "0017C4": {
        "oui_hex": "00-17-C4",
        "organization": "Quanta Microsystems, INC.",
        "address_1": "188 Wenhwa 2nd RD., Kueishan Hsiang",
        "address_2": "Taoyuan Shien    333",
        "country": "TW"
    },
    "00179E": {
        "oui_hex": "00-17-9E",
        "organization": "Sirit Inc",
        "address_1": "2525 Meridian Parkway",
        "address_2": "Durham  NC  27713",
        "country": "US"
    },
    "0017A7": {
        "oui_hex": "00-17-A7",
        "organization": "Mobile Computing Promotion Consortium",
        "address_1": "3-5-12 Shiba-Koen",
        "address_2": "Tokyo    105-0011",
        "country": "JP"
    },
    "00179F": {
        "oui_hex": "00-17-9F",
        "organization": "Apricorn",
        "address_1": "12191 Kirkham RD",
        "address_2": "Poway  California  92064",
        "country": "US"
    },
    "0017B4": {
        "oui_hex": "00-17-B4",
        "organization": "Remote Security Systems, LLC",
        "address_1": "4806 Upper Brandon Place",
        "address_2": "Marietta  Georgia  30068",
        "country": "US"
    },
    "0017AC": {
        "oui_hex": "00-17-AC",
        "organization": "O'Neil Product Development Inc.",
        "address_1": "8 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0017AD": {
        "oui_hex": "00-17-AD",
        "organization": "AceNet Corporation",
        "address_1": "7F-4, No.146, Wen-Shin Road",
        "address_2": "Gueishan  TAOYUAN",
        "country": "TW"
    },
    "0017DD": {
        "oui_hex": "00-17-DD",
        "organization": "Clipsal Australia",
        "address_1": "33-37 Port Wakefield Rd",
        "address_2": "Gepps Cross  South Australia  5094",
        "country": "AU"
    },
    "0017D9": {
        "oui_hex": "00-17-D9",
        "organization": "AAI Corporation",
        "address_1": "P.O. Box 126",
        "address_2": "Hunt Valley  Maryland  21030",
        "country": "US"
    },
    "0017DC": {
        "oui_hex": "00-17-DC",
        "organization": "DAEMYUNG ZERO1",
        "address_1": "#809,Hyosung Intellian",
        "address_2": "Anyang-si  Gyeonggi-do  431-060",
        "country": "KR"
    },
    "0017BF": {
        "oui_hex": "00-17-BF",
        "organization": "Coherent Research Limited",
        "address_1": "8 Princess Mews",
        "address_2": "Kingston upon Thames  Surrey  KT1 2SZ",
        "country": "GB"
    },
    "0017BD": {
        "oui_hex": "00-17-BD",
        "organization": "Tibetsystem",
        "address_1": "6F IT Castle II 550-1 Gasan-dong",
        "address_2": "Seoul  Geumcheon-gu  153-803",
        "country": "KR"
    },
    "0017A1": {
        "oui_hex": "00-17-A1",
        "organization": "3soft inc.",
        "address_1": "shinyoung bldg 4f, chungdam-dong, gangnam-gu",
        "address_2": "seoul    135-100",
        "country": "KR"
    },
    "001792": {
        "oui_hex": "00-17-92",
        "organization": "Falcom Wireless Comunications Gmbh",
        "address_1": "Gewerbering 6",
        "address_2": "Langewiesen  Thuringia  98704",
        "country": "DE"
    },
    "001797": {
        "oui_hex": "00-17-97",
        "organization": "Telsy Elettronica S.p.A.",
        "address_1": "Corso Svizzera 185",
        "address_2": "Torino    10149",
        "country": "IT"
    },
    "00178C": {
        "oui_hex": "00-17-8C",
        "organization": "Independent Witness, Inc",
        "address_1": "1515 West 2200 South",
        "address_2": "Salt Lake City  UT  84119",
        "country": "US"
    },
    "0017CB": {
        "oui_hex": "00-17-CB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0017D3": {
        "oui_hex": "00-17-D3",
        "organization": "Etymotic Research, Inc.",
        "address_1": "61 Martin Lane",
        "address_2": "Elk Grove Village  IL  60061",
        "country": "US"
    },
    "001788": {
        "oui_hex": "00-17-88",
        "organization": "Philips Lighting BV",
        "address_1": "High Tech Campus 45",
        "address_2": "Eindhoven  Noord Brabant  5656 AE",
        "country": "NL"
    },
    "00173C": {
        "oui_hex": "00-17-3C",
        "organization": "Extreme Engineering Solutions",
        "address_1": "7878 Big Sky Drive",
        "address_2": "Madison  WI  53719",
        "country": "US"
    },
    "001736": {
        "oui_hex": "00-17-36",
        "organization": "iiTron Inc.",
        "address_1": "88 Mercy St.",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "001737": {
        "oui_hex": "00-17-37",
        "organization": "Industrie Dial Face S.p.A.",
        "address_1": "via Canzo, 4",
        "address_2": "Peschiera Borromeo  Milano  20068",
        "country": "IT"
    },
    "001733": {
        "oui_hex": "00-17-33",
        "organization": "SFR",
        "address_1": "42 Quai du point du jour",
        "address_2": "Boulogne Billancourt  Hauts de Seine  92659",
        "country": "FR"
    },
    "001758": {
        "oui_hex": "00-17-58",
        "organization": "ThruVision Ltd",
        "address_1": "Central 127, No.18",
        "address_2": "Abingdon  Oxfordshire  OX14 4SA",
        "country": "GB"
    },
    "00174F": {
        "oui_hex": "00-17-4F",
        "organization": "iCatch Inc.",
        "address_1": "10F-2, No. 109, Sec. 6, Mincyuan E. Rd.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00174A": {
        "oui_hex": "00-17-4A",
        "organization": "SOCOMEC",
        "address_1": "rue de Westhouse",
        "address_2": "BENFELD CEDEX    67235",
        "country": "FR"
    },
    "00174E": {
        "oui_hex": "00-17-4E",
        "organization": "Parama-tech Co.,Ltd.",
        "address_1": "2-19-8, Sharyo, Higashi-ku",
        "address_2": "Fukuoka    812-0068",
        "country": "JP"
    },
    "00176F": {
        "oui_hex": "00-17-6F",
        "organization": "PAX Computer Technology(Shenzhen) Ltd.",
        "address_1": "4/F, No.3 Building, Software Park, Second Central Science-Tech Road, High-Tech",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "001771": {
        "oui_hex": "00-17-71",
        "organization": "APD Communications Ltd",
        "address_1": "Newlands Centre",
        "address_2": "HULL    HU6 7TQ",
        "country": "GB"
    },
    "00175B": {
        "oui_hex": "00-17-5B",
        "organization": "ACS Solutions Switzerland Ltd.",
        "address_1": "Frankenstrasse 70",
        "address_2": "Bern- Buempliz    3018",
        "country": "CH"
    },
    "001729": {
        "oui_hex": "00-17-29",
        "organization": "Ubicod Co.LTD",
        "address_1": "7F Chun-gin Bldg, 53-5 Wonhyo-ro",
        "address_2": "Seoul    140-719",
        "country": "KR"
    },
    "001727": {
        "oui_hex": "00-17-27",
        "organization": "Thermo Ramsey Italia s.r.l.",
        "address_1": "Strada Rivoltana km 6/7",
        "address_2": "Rodano  Milano  20090",
        "country": "IT"
    },
    "00172A": {
        "oui_hex": "00-17-2A",
        "organization": "Proware Technology Corp.(By Unifosa)",
        "address_1": "6Fl., No. 4, Alley 1, Lane 235, PaoChao Rd., Sindian Dist.,",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "001725": {
        "oui_hex": "00-17-25",
        "organization": "Liquid Computing",
        "address_1": "340 Terry Fox Drive",
        "address_2": "Ottawa  Ontario  K2K 3A2",
        "country": "CA"
    },
    "001764": {
        "oui_hex": "00-17-64",
        "organization": "ATMedia GmbH",
        "address_1": "Stuhlsatzenhausweg 69",
        "address_2": "Saarbruecken  Saarland  66123",
        "country": "DE"
    },
    "00175E": {
        "oui_hex": "00-17-5E",
        "organization": "Zed-3",
        "address_1": "501 Valley Way",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001766": {
        "oui_hex": "00-17-66",
        "organization": "Accense Technology, Inc.",
        "address_1": "35 Tansumachi",
        "address_2": "Shinjyuku-ku  Tokyo  1620833",
        "country": "JP"
    },
    "0016D0": {
        "oui_hex": "00-16-D0",
        "organization": "ATech elektronika d.o.o.",
        "address_1": "Bac pri Materiji 30",
        "address_2": "Materija  SI  6242",
        "country": "SI"
    },
    "0016C3": {
        "oui_hex": "00-16-C3",
        "organization": "BA Systems Inc",
        "address_1": "6895 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "0016F0": {
        "oui_hex": "00-16-F0",
        "organization": "Dell",
        "address_1": "909 Hermosa Ct",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "0016F8": {
        "oui_hex": "00-16-F8",
        "organization": "AVIQTECH TECHNOLOGY CO., LTD.",
        "address_1": "6F 12, Li-hsin Road, SBIP",
        "address_2": "Hsin-chu    300",
        "country": "TW"
    },
    "0016E8": {
        "oui_hex": "00-16-E8",
        "organization": "Sigma Designs, Inc.",
        "address_1": "1778 McCarthy Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001703": {
        "oui_hex": "00-17-03",
        "organization": "MOSDAN Internation Co.,Ltd",
        "address_1": "No.216 Xiwei,Shanhua Dist,",
        "address_2": "Tainan    741",
        "country": "TW"
    },
    "0016FC": {
        "oui_hex": "00-16-FC",
        "organization": "TOHKEN CO.,LTD.",
        "address_1": "2-16-20 Tamagawa",
        "address_2": "Chofu  Tokyo  182-0025",
        "country": "JP"
    },
    "0016E9": {
        "oui_hex": "00-16-E9",
        "organization": "Tiba Medical Inc",
        "address_1": "5024 Lakewood Drive",
        "address_2": "Plano  TX  75093",
        "country": "US"
    },
    "0016DC": {
        "oui_hex": "00-16-DC",
        "organization": "ARCHOS",
        "address_1": "12 rue AMPERE",
        "address_2": "IGNY  ESSONNES  91430",
        "country": "FR"
    },
    "001714": {
        "oui_hex": "00-17-14",
        "organization": "BR Controls Nederland bv",
        "address_1": "Branderweg 1",
        "address_2": "Zwolle  Overijssel  8042 PD",
        "country": "NL"
    },
    "00171B": {
        "oui_hex": "00-17-1B",
        "organization": "Innovation Lab Corp.",
        "address_1": "12FL., No. 285, Sec. 2, TiDing Blvd.,",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "001709": {
        "oui_hex": "00-17-09",
        "organization": "Exalt Communications",
        "address_1": "580 Division Street",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "0016C1": {
        "oui_hex": "00-16-C1",
        "organization": "Eleksen Ltd",
        "address_1": "Pinewood Studios",
        "address_2": "Iver  Bucks  SL0 0NH",
        "country": "US"
    },
    "0016A9": {
        "oui_hex": "00-16-A9",
        "organization": "2EI",
        "address_1": "Rua dos Rubis, 77 - Assumpcao",
        "address_2": "Aguas de Lindoia  São Paulo  13940-000",
        "country": "BR"
    },
    "0016B0": {
        "oui_hex": "00-16-B0",
        "organization": "VK Corporation",
        "address_1": "VK B/D, 548-6, Anyang 8dong, Manan-gu",
        "address_2": "Anyang  Kyounggi  430-8903",
        "country": "KR"
    },
    "0016B1": {
        "oui_hex": "00-16-B1",
        "organization": "KBS",
        "address_1": "88 rue Pierre Sémard",
        "address_2": "Moissy cedex  Ile de France  77552",
        "country": "FR"
    },
    "0016AE": {
        "oui_hex": "00-16-AE",
        "organization": "INVENTEL",
        "address_1": "35 rue Tournefort",
        "address_2": "PARIS    75005",
        "country": "FR"
    },
    "0016AC": {
        "oui_hex": "00-16-AC",
        "organization": "Toho Technology Corp.",
        "address_1": "HIGASHI 5-1",
        "address_2": "INAZAWA-CITY  AICHI  492-8501",
        "country": "JP"
    },
    "001683": {
        "oui_hex": "00-16-83",
        "organization": "WEBIO International Co.,.Ltd.",
        "address_1": "21F.,No.171 Songde Rd.,Sinyi District",
        "address_2": "Taipei    11085",
        "country": "TW"
    },
    "001684": {
        "oui_hex": "00-16-84",
        "organization": "Donjin Co.,Ltd.",
        "address_1": "21F,Cangsong Building,Tairan,Futian",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "001687": {
        "oui_hex": "00-16-87",
        "organization": "Chubb CSC-Vendor AP",
        "address_1": "Ottawa STN",
        "address_2": "Ottawa    K1G 6W6",
        "country": "CA"
    },
    "00167F": {
        "oui_hex": "00-16-7F",
        "organization": "Bluebird Soft Inc.",
        "address_1": "562-21 Gangnam-gu,",
        "address_2": "Seoul    135-890",
        "country": "KR"
    },
    "00164C": {
        "oui_hex": "00-16-4C",
        "organization": "PLANET INT Co., Ltd",
        "address_1": "8th Floor, Saeum B/D, 1361-5",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "001649": {
        "oui_hex": "00-16-49",
        "organization": "SetOne GmbH",
        "address_1": "Hegenheimer Str. 2",
        "address_2": "Weil am Rhein    D-79576",
        "country": "DE"
    },
    "001647": {
        "oui_hex": "00-16-47",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001665": {
        "oui_hex": "00-16-65",
        "organization": "Cellon France",
        "address_1": "Route d'Angers Le Mans cedex 9",
        "address_2": "Le Mans  Sarthe  72081",
        "country": "FR"
    },
    "00165F": {
        "oui_hex": "00-16-5F",
        "organization": "Fairmount Automation",
        "address_1": "4621 West Chester Pike",
        "address_2": "Newtown Square  PA  19073",
        "country": "US"
    },
    "00167C": {
        "oui_hex": "00-16-7C",
        "organization": "iRex Technologies BV",
        "address_1": "HighTech Campus",
        "address_2": "Eindhoven  Brabant  5656AE",
        "country": "NL"
    },
    "001673": {
        "oui_hex": "00-16-73",
        "organization": "Bury GmbH & Co. KG",
        "address_1": "Robert-Koch-Str. 1-7",
        "address_2": "Loehne  Germany  32584",
        "country": "DE"
    },
    "001694": {
        "oui_hex": "00-16-94",
        "organization": "Sennheiser Communications A/S",
        "address_1": "Langager 6",
        "address_2": "Solrød Strand  Copenhagen  2680",
        "country": "DK"
    },
    "00169C": {
        "oui_hex": "00-16-9C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001657": {
        "oui_hex": "00-16-57",
        "organization": "Aegate Ltd",
        "address_1": "Technology Centre",
        "address_2": "Melbourn  Hertfordshire  SG8 6DP",
        "country": "GB"
    },
    "00168C": {
        "oui_hex": "00-16-8C",
        "organization": "DSL Partner AS",
        "address_1": "Havreveien 49",
        "address_2": "Oslo    0680",
        "country": "NO"
    },
    "00161B": {
        "oui_hex": "00-16-1B",
        "organization": "Micronet Corporation",
        "address_1": "1788-388 Nomura Hirooka",
        "address_2": "Shiojiri-shi  Nagano-ken  399-0702",
        "country": "JP"
    },
    "001618": {
        "oui_hex": "00-16-18",
        "organization": "HIVION Co., Ltd.",
        "address_1": "2F., Akyung Bldg., 54-10, Munjeong-dong,",
        "address_2": "Songpa-Gu  Seoul",
        "country": "KR"
    },
    "00161E": {
        "oui_hex": "00-16-1E",
        "organization": "Woojinnet",
        "address_1": "292 osan dongtan",
        "address_2": "hwaseong  kyonggi  445-813",
        "country": "KR"
    },
    "00161F": {
        "oui_hex": "00-16-1F",
        "organization": "SUNWAVETEC Co., Ltd.",
        "address_1": "#823, Kwanyang-dong, Dongan-ku",
        "address_2": "Anyang-si  Kyungki-do  431-060",
        "country": "US"
    },
    "001614": {
        "oui_hex": "00-16-14",
        "organization": "Picosecond Pulse Labs",
        "address_1": "2500 55th Street",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "00160E": {
        "oui_hex": "00-16-0E",
        "organization": "Optica Technologies Inc.",
        "address_1": "2051 Dogwood Street",
        "address_2": "Louisville  CO  80027",
        "country": "US"
    },
    "001643": {
        "oui_hex": "00-16-43",
        "organization": "Sunhillo Corporation",
        "address_1": "444 Kelley Drive",
        "address_2": "West Berlin  New Jersey  08091",
        "country": "US"
    },
    "001644": {
        "oui_hex": "00-16-44",
        "organization": "LITE-ON Technology Corp.",
        "address_1": "18F, No.392, Ruey Kuang Road, Niehu,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00163E": {
        "oui_hex": "00-16-3E",
        "organization": "Xensource, Inc.",
        "address_1": "2300 Geng Rd.",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "0015FD": {
        "oui_hex": "00-15-FD",
        "organization": "Complete Media Systems",
        "address_1": "Grove Place",
        "address_2": "Warninglid  West sussex  RH17 5SN",
        "country": "GB"
    },
    "0015F6": {
        "oui_hex": "00-15-F6",
        "organization": "SCIENCE AND ENGINEERING SERVICES, INC.",
        "address_1": "4015 PULASKI PIKE NW",
        "address_2": "HUNTSVILLE  AL  35810",
        "country": "US"
    },
    "001634": {
        "oui_hex": "00-16-34",
        "organization": "Mathtech, Inc.",
        "address_1": "6402 Arlington Blvd.,",
        "address_2": "Falls Church  Virginia  22042-2356",
        "country": "US"
    },
    "00162C": {
        "oui_hex": "00-16-2C",
        "organization": "Xanboo",
        "address_1": "115 West 30th, 6th Fl",
        "address_2": "New York  NY  10001",
        "country": "US"
    },
    "001605": {
        "oui_hex": "00-16-05",
        "organization": "YORKVILLE SOUND INC.",
        "address_1": "4625 WITMER INDUSTRIAL ESTATE",
        "address_2": "NIAGARA FALLS  NY  14305",
        "country": "US"
    },
    "0015F9": {
        "oui_hex": "00-15-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0015E3": {
        "oui_hex": "00-15-E3",
        "organization": "Dream Technologies Corporation",
        "address_1": "Ebisu Prime Square, 1-1-39 Hiroo",
        "address_2": "Tokyo    150-0012",
        "country": "JP"
    },
    "0015E0": {
        "oui_hex": "00-15-E0",
        "organization": "Ericsson",
        "address_1": "Nya Vattentornet",
        "address_2": "Lund    SE-221 83",
        "country": "NO"
    },
    "0015F3": {
        "oui_hex": "00-15-F3",
        "organization": "PELTOR AB",
        "address_1": "Box 2341",
        "address_2": "SE-331 02  Värnamo    SE-331 02",
        "country": "SE"
    },
    "0015E7": {
        "oui_hex": "00-15-E7",
        "organization": "Quantec Tontechnik",
        "address_1": "Mittenwalderstr.63",
        "address_2": "München    D-81377",
        "country": "DE"
    },
    "0015D3": {
        "oui_hex": "00-15-D3",
        "organization": "Pantech&Curitel Communications, Inc.",
        "address_1": "1451-34, Seocho-dong, Seocho-Gu",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "0015AD": {
        "oui_hex": "00-15-AD",
        "organization": "Accedian Networks",
        "address_1": "4878 Levy, suite 202",
        "address_2": "St-Laurent  Quebec  H9P 2V4",
        "country": "CA"
    },
    "0015AC": {
        "oui_hex": "00-15-AC",
        "organization": "Capelon AB",
        "address_1": "Jägerhorns  väg 1",
        "address_2": "Kungens Kurva  Stockholm  S-141 75",
        "country": "SE"
    },
    "0015A9": {
        "oui_hex": "00-15-A9",
        "organization": "KWANG WOO I&C CO.,LTD",
        "address_1": "898-23, Hogye-dong,Dongan-gu",
        "address_2": "    431-080",
        "country": "KR"
    },
    "00E0A8": {
        "oui_hex": "00-E0-A8",
        "organization": "SAT GmbH & Co.",
        "address_1": "RUTHNERGASSE 1",
        "address_2": "VIENNA A-1210",
        "country": "AT"
    },
    "001574": {
        "oui_hex": "00-15-74",
        "organization": "Horizon Semiconductors Ltd.",
        "address_1": "9 Hamenofim St.",
        "address_2": "Herzliya    46120",
        "country": "IL"
    },
    "00158A": {
        "oui_hex": "00-15-8A",
        "organization": "SURECOM Technology Corp.",
        "address_1": "6F, No. 125, Sec. 2, Datung Rd.",
        "address_2": "Shijr City, Taipei County    221",
        "country": "TW"
    },
    "00158E": {
        "oui_hex": "00-15-8E",
        "organization": "Plustek.INC",
        "address_1": "13F-1,No3(Building F) Yuan Qu Street",
        "address_2": "Taipei  Yuan Qu  115",
        "country": "TW"
    },
    "001589": {
        "oui_hex": "00-15-89",
        "organization": "D-MAX Technology Co.,Ltd",
        "address_1": "7F-6,NO.26,Lian Cheng RD.,Chung-Ho City",
        "address_2": "Taipei Hsien    235",
        "country": "US"
    },
    "0015B4": {
        "oui_hex": "00-15-B4",
        "organization": "Polymap  Wireless LLC",
        "address_1": "310 S. Williams Blvd. Ste. 350",
        "address_2": "Tucson  AZ  85711",
        "country": "US"
    },
    "0015CA": {
        "oui_hex": "00-15-CA",
        "organization": "TeraRecon, Inc.",
        "address_1": "2955 Campus Drive, Suite 325",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "001598": {
        "oui_hex": "00-15-98",
        "organization": "Kolektor group",
        "address_1": "Vojkova 10",
        "address_2": "Idrija    5280",
        "country": "SI"
    },
    "001512": {
        "oui_hex": "00-15-12",
        "organization": "Zurich University of Applied Sciences",
        "address_1": "Technikumstrasse 9",
        "address_2": "Winterthur  ZH  CH-8401",
        "country": "CH"
    },
    "00150A": {
        "oui_hex": "00-15-0A",
        "organization": "Sonoa Systems, Inc",
        "address_1": "3900 Freedom Circle",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001570": {
        "oui_hex": "00-15-70",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "00156E": {
        "oui_hex": "00-15-6E",
        "organization": "A. W. Communication Systems Ltd",
        "address_1": "Crook Barn",
        "address_2": "Carlisle  Cumbria  CA6 6LH",
        "country": "GB"
    },
    "001568": {
        "oui_hex": "00-15-68",
        "organization": "Dilithium Networks",
        "address_1": "5401 Old Redwood Hwy",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "00154B": {
        "oui_hex": "00-15-4B",
        "organization": "Wonde Proud Technology Co., Ltd",
        "address_1": "21F., No.100, Sec.1, Shintai 5th Rd",
        "address_2": "Sijhih city  Taipei County  221",
        "country": "TW"
    },
    "001548": {
        "oui_hex": "00-15-48",
        "organization": "CUBE TECHNOLOGIES",
        "address_1": "46 A CHEMIN DU MOULIN CARRON",
        "address_2": "69570 DARDILLY  FRANCE",
        "country": "FR"
    },
    "00155F": {
        "oui_hex": "00-15-5F",
        "organization": "GreenPeak Technologies",
        "address_1": "Spinnerijstraat 14",
        "address_2": "Zele    9240",
        "country": "BE"
    },
    "00155A": {
        "oui_hex": "00-15-5A",
        "organization": "DAINIPPON PHARMACEUTICAL CO., LTD.",
        "address_1": "2-6-8, DOSHOMACHI, CHUO-KU",
        "address_2": "OSAKA CITY  OSAKA PREF.  541-8524",
        "country": "JP"
    },
    "00151D": {
        "oui_hex": "00-15-1D",
        "organization": "M2I CORPORATION",
        "address_1": "Kyonggi Venture Anyang technical center, 13th Floor, 572-5, Anyang 8-Dong, Manan-Gu",
        "address_2": "Anyang-Shi  Kyonggi-Do  430-731",
        "country": "KR"
    },
    "00153C": {
        "oui_hex": "00-15-3C",
        "organization": "Kprotech Co., Ltd.",
        "address_1": "2nd Floor, # 202, Myoung-ji e-Space II",
        "address_2": "An-yang City  Gyeong-gi Do  430-817",
        "country": "KR"
    },
    "00153A": {
        "oui_hex": "00-15-3A",
        "organization": "Shenzhen Syscan Technology Co.,Ltd.",
        "address_1": "13F, Olympic Plaza,",
        "address_2": "Shenzhen  Guangdong  518034",
        "country": "CN"
    },
    "001532": {
        "oui_hex": "00-15-32",
        "organization": "Consumer Technologies Group, LLC",
        "address_1": "801 Brookhollow",
        "address_2": "Efland  NC  27243",
        "country": "US"
    },
    "00149B": {
        "oui_hex": "00-14-9B",
        "organization": "Nokota Communications, LLC",
        "address_1": "200 Galleria Parkway",
        "address_2": "Atlanta  Georgia  30339",
        "country": "US"
    },
    "0014A1": {
        "oui_hex": "00-14-A1",
        "organization": "Synchronous Communication Corp",
        "address_1": "9 floor, No168, Rueiguang Road, Neihu District",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00149E": {
        "oui_hex": "00-14-9E",
        "organization": "UbONE Co., Ltd",
        "address_1": "Shinyoung B.D. 602, SeoHyeon2-Dong",
        "address_2": "Seongnam-si  Gyeongg-do  463-824",
        "country": "KR"
    },
    "0014A2": {
        "oui_hex": "00-14-A2",
        "organization": "Core Micro Systems Inc.",
        "address_1": "Wacore Kaname-cho Bldg. 9F, 11-2, Nakamaru-cho",
        "address_2": "Itabashi-ku  Tokyo  173-0026",
        "country": "JP"
    },
    "0014AD": {
        "oui_hex": "00-14-AD",
        "organization": "Gassner Wiege- und Meßtechnik GmbH",
        "address_1": "Münchner Bundesstraße",
        "address_2": "Salzburg    A-5020",
        "country": "AT"
    },
    "0014AF": {
        "oui_hex": "00-14-AF",
        "organization": "Datasym POS Inc.",
        "address_1": "45 Dalkeith Drive",
        "address_2": "Brantford  Ontario  N3P1M1",
        "country": "CA"
    },
    "0014A9": {
        "oui_hex": "00-14-A9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0014FF": {
        "oui_hex": "00-14-FF",
        "organization": "Precise Automation, Inc.",
        "address_1": "1402 Alexandra Blvd",
        "address_2": "Crystal Lake  IL  60014",
        "country": "US"
    },
    "0014FA": {
        "oui_hex": "00-14-FA",
        "organization": "AsGa S.A.",
        "address_1": "Rod Roberto Moreira Km 04",
        "address_2": "Paulinia  São Paulo  13140-000",
        "country": "BR"
    },
    "0014FB": {
        "oui_hex": "00-14-FB",
        "organization": "Technical Solutions Inc.",
        "address_1": "101-7188 Progress Way",
        "address_2": "Delta  BC  V4G 1M6",
        "country": "CA"
    },
    "0014D2": {
        "oui_hex": "00-14-D2",
        "organization": "Kyuden Technosystems Corporation",
        "address_1": "4-19-18 SHIMIZU,MINAMI-KU",
        "address_2": "FUKUOKA    815-0031",
        "country": "JP"
    },
    "0014DC": {
        "oui_hex": "00-14-DC",
        "organization": "Communication System Design & Manufacturing (CSDM)",
        "address_1": "Postbus 181",
        "address_2": "Bussum  NH  1400 AD",
        "country": "NL"
    },
    "0014CD": {
        "oui_hex": "00-14-CD",
        "organization": "DigitalZone Co., Ltd.",
        "address_1": "No. 1001 E&C VentureDreamTower2",
        "address_2": "Seoul    152-848",
        "country": "KR"
    },
    "0014C0": {
        "oui_hex": "00-14-C0",
        "organization": "Symstream Technology Group Ltd",
        "address_1": "Level 1, 3 Chester Street",
        "address_2": "Oakleigh  Victoria  3166",
        "country": "AU"
    },
    "0014C1": {
        "oui_hex": "00-14-C1",
        "organization": "U.S. Robotics Corporation",
        "address_1": "935 National Parkway",
        "address_2": "Schaumburg  IL  60173-5157",
        "country": "US"
    },
    "0014C4": {
        "oui_hex": "00-14-C4",
        "organization": "Vitelcom Mobile Technology",
        "address_1": "PTA, Avda, Juan López Peñalver, nº 7",
        "address_2": "Campanillas.  Malaga.",
        "country": "ES"
    },
    "0014EC": {
        "oui_hex": "00-14-EC",
        "organization": "Acro Telecom",
        "address_1": "714 Woolim e-Biz Center 170-5 Guro-dong",
        "address_2": "Guro-Gu  Seoul  152-769",
        "country": "KR"
    },
    "0014EB": {
        "oui_hex": "00-14-EB",
        "organization": "AwarePoint Corporation",
        "address_1": "8899 University Center Lane",
        "address_2": "San Diego  CA  92122",
        "country": "US"
    },
    "0014AB": {
        "oui_hex": "00-14-AB",
        "organization": "Senhai Electronic Technology Co., Ltd.",
        "address_1": "Rm.10A. 28/F.SEGPlaza Huaqiangbei Road",
        "address_2": "Shengzhen  Guangdong  518031",
        "country": "CN"
    },
    "0014B0": {
        "oui_hex": "00-14-B0",
        "organization": "Naeil Community",
        "address_1": "#506 AceTwin Tower 1, Guro-Dong",
        "address_2": "Seoul  Guro-Gu  152779",
        "country": "KR"
    },
    "0014F4": {
        "oui_hex": "00-14-F4",
        "organization": "DekTec Digital Video B.V.",
        "address_1": "Van Riebeeckweg 43A",
        "address_2": "Hilversum  NH  1212AE",
        "country": "NL"
    },
    "0014F5": {
        "oui_hex": "00-14-F5",
        "organization": "OSI Security Devices",
        "address_1": "1580 Jayken Way",
        "address_2": "Chula Vista  California  91911",
        "country": "US"
    },
    "00148E": {
        "oui_hex": "00-14-8E",
        "organization": "Tele Power Inc.",
        "address_1": "1-46-15#B1F",
        "address_2": "Nerima-ku  Tokyo  176-0005",
        "country": "JP"
    },
    "00148F": {
        "oui_hex": "00-14-8F",
        "organization": "Protronic (Far East) Ltd.",
        "address_1": "Rm. 2504, Nanyang Plaza,",
        "address_2": "Kwun Tong  Kowloon",
        "country": "HK"
    },
    "00148C": {
        "oui_hex": "00-14-8C",
        "organization": "General Dynamics Mission Systems",
        "address_1": "150 Rustcraft Road",
        "address_2": "Dedham  MA  02026",
        "country": "US"
    },
    "001487": {
        "oui_hex": "00-14-87",
        "organization": "American Technology Integrators",
        "address_1": "1358 Rosalia Ave",
        "address_2": "San Jose  CA  95130",
        "country": "US"
    },
    "001444": {
        "oui_hex": "00-14-44",
        "organization": "Grundfos Holding",
        "address_1": "Poul Due Jensensvej 7",
        "address_2": "Bjerringbro    DK8850",
        "country": "DK"
    },
    "001437": {
        "oui_hex": "00-14-37",
        "organization": "GSTeletech Co.,Ltd.",
        "address_1": "1385-14, Juan-Dong, Nam-gu",
        "address_2": "  Incheon  402-200",
        "country": "KR"
    },
    "001431": {
        "oui_hex": "00-14-31",
        "organization": "PDL Electronics Ltd",
        "address_1": "81 Austin Street",
        "address_2": "Napier  Hawkes Bay",
        "country": "NZ"
    },
    "00144D": {
        "oui_hex": "00-14-4D",
        "organization": "Intelligent Systems",
        "address_1": "11101 Johns Hopkins Road",
        "address_2": "Laurel  MD  20723",
        "country": "US"
    },
    "00144A": {
        "oui_hex": "00-14-4A",
        "organization": "Taiwan Thick-Film Ind. Corp.",
        "address_1": "NO.126,Wuu Gong 2nd RD,",
        "address_2": "Taipei Hsien    248",
        "country": "TW"
    },
    "001445": {
        "oui_hex": "00-14-45",
        "organization": "Telefon-Gradnja d.o.o.",
        "address_1": "Plesivicka 3",
        "address_2": "Sveta Nedelja  Zupanija Zagrebacka  10431",
        "country": "HR"
    },
    "001468": {
        "oui_hex": "00-14-68",
        "organization": "CelPlan International, Inc.",
        "address_1": "1920 Association Drive",
        "address_2": "Reston  VA  20191",
        "country": "US"
    },
    "00147C": {
        "oui_hex": "00-14-7C",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "001481": {
        "oui_hex": "00-14-81",
        "organization": "Multilink Inc",
        "address_1": "580 Ternes Ave",
        "address_2": "Elyria  OH  44035",
        "country": "US"
    },
    "001464": {
        "oui_hex": "00-14-64",
        "organization": "Cryptosoft",
        "address_1": "Lermontova str, 3",
        "address_2": "  Penza region  440026",
        "country": "RU"
    },
    "00145E": {
        "oui_hex": "00-14-5E",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "001458": {
        "oui_hex": "00-14-58",
        "organization": "HS Automatic ApS",
        "address_1": "Bjerringbrovej 70",
        "address_2": "Rodovre    2610",
        "country": "DK"
    },
    "001421": {
        "oui_hex": "00-14-21",
        "organization": "Total Wireless Technologies Pte. Ltd.",
        "address_1": "Blk 1003, Bukit Merah Central, #04-18",
        "address_2": "    159836",
        "country": "SG"
    },
    "001420": {
        "oui_hex": "00-14-20",
        "organization": "G-Links networking company",
        "address_1": "1FL. NO.15-49, MING DER SECOND ROAD,",
        "address_2": "Keelung    206",
        "country": "TW"
    },
    "001418": {
        "oui_hex": "00-14-18",
        "organization": "C4Line",
        "address_1": "1001 Hyundai Parisian,",
        "address_2": "Yangchun-Gu  Seoul  158-050",
        "country": "KR"
    },
    "00141B": {
        "oui_hex": "00-14-1B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0013F0": {
        "oui_hex": "00-13-F0",
        "organization": "Wavefront Semiconductor",
        "address_1": "4746 44th Ave SW",
        "address_2": "Seattle  WA  98116",
        "country": "US"
    },
    "0013EF": {
        "oui_hex": "00-13-EF",
        "organization": "Kingjon Digital Technology Co.,Ltd",
        "address_1": "Room 827,Huanan Dianli Bulding,No.2050",
        "address_2": "Shenzhen  GuangDong  518031",
        "country": "CN"
    },
    "0013EB": {
        "oui_hex": "00-13-EB",
        "organization": "Sysmaster Corporation",
        "address_1": "5801 Christie Ave.",
        "address_2": "Emeryville  CA  94608",
        "country": "US"
    },
    "0013EC": {
        "oui_hex": "00-13-EC",
        "organization": "Netsnapper Technologies SARL",
        "address_1": "2160 Century Park East 1806",
        "address_2": "Los Angeles  CA  90067-2236",
        "country": "US"
    },
    "00142B": {
        "oui_hex": "00-14-2B",
        "organization": "Edata Communication Inc.",
        "address_1": "2F-1, No. 872, Chung-Cheng Rd",
        "address_2": "  Taipei Hsien  235",
        "country": "TW"
    },
    "00142C": {
        "oui_hex": "00-14-2C",
        "organization": "Koncept International, Inc.",
        "address_1": "2500 E Foothill Blvd. #407",
        "address_2": "Pasadena  CA  91107",
        "country": "US"
    },
    "001424": {
        "oui_hex": "00-14-24",
        "organization": "Merry Electrics CO., LTD.",
        "address_1": "NO.22,23rd ROAD",
        "address_2": "TAICHUNG CITY    40850",
        "country": "TW"
    },
    "0013D0": {
        "oui_hex": "00-13-D0",
        "organization": "t+ Medical Ltd",
        "address_1": "174E Milton Park",
        "address_2": "Abingdon    OX14 4SE",
        "country": "GB"
    },
    "0013D2": {
        "oui_hex": "00-13-D2",
        "organization": "PAGE IBERICA, S.A.",
        "address_1": "AV. DE LA INDUSTRIA, 24",
        "address_2": "TRES CANTOS  MADRID  28760",
        "country": "ES"
    },
    "0013D1": {
        "oui_hex": "00-13-D1",
        "organization": "KIRK telecom A/S",
        "address_1": "Langmarksvej 34",
        "address_2": "Horsens    8700",
        "country": "DK"
    },
    "00140F": {
        "oui_hex": "00-14-0F",
        "organization": "Federal State Unitary Enterprise Leningrad R&D Institute of",
        "address_1": "11 Warshawskaya St.",
        "address_2": "  St. Petersburg  196128",
        "country": "RU"
    },
    "001407": {
        "oui_hex": "00-14-07",
        "organization": "Sperian Protection Instrumentation",
        "address_1": "651 South Main Street",
        "address_2": "Middletown  CT  06457",
        "country": "US"
    },
    "001406": {
        "oui_hex": "00-14-06",
        "organization": "Go Networks",
        "address_1": "126 Yigal Alon st.",
        "address_2": "Tel Aviv    67443",
        "country": "IL"
    },
    "00140A": {
        "oui_hex": "00-14-0A",
        "organization": "WEPIO Co., Ltd.",
        "address_1": "#1125, Opus1, Gurodongcomplex building",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "0013FA": {
        "oui_hex": "00-13-FA",
        "organization": "LifeSize Communications, Inc",
        "address_1": "901 S. Mopac",
        "address_2": "Austin  TX  78746",
        "country": "US"
    },
    "0013FB": {
        "oui_hex": "00-13-FB",
        "organization": "RKC INSTRUMENT INC.",
        "address_1": "16-6, Kugahara 5-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8515",
        "country": "JP"
    },
    "0013DC": {
        "oui_hex": "00-13-DC",
        "organization": "IBTEK INC.",
        "address_1": "16F, 30, Pei-Ping East Rd.,",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "0013BA": {
        "oui_hex": "00-13-BA",
        "organization": "ReadyLinks Inc",
        "address_1": "6595 Edenvale Boulevard",
        "address_2": "Eden Prairie  MN  55346",
        "country": "US"
    },
    "0013B8": {
        "oui_hex": "00-13-B8",
        "organization": "RyCo Electronic Systems Limited",
        "address_1": "Unit E, Cartel Business Estate",
        "address_2": "Harlow  Essex  CM20 2TT",
        "country": "GB"
    },
    "0013B6": {
        "oui_hex": "00-13-B6",
        "organization": "Sling Media, Inc.",
        "address_1": "1840 Gateway Center",
        "address_2": "San Mateo  CA  94404",
        "country": "US"
    },
    "00137D": {
        "oui_hex": "00-13-7D",
        "organization": "Dynalab, Inc.",
        "address_1": "555 Lancaster Ave.",
        "address_2": "Reynoldsburg  OH  43068",
        "country": "US"
    },
    "001383": {
        "oui_hex": "00-13-83",
        "organization": "Application Technologies and Engineering Research Laboratory",
        "address_1": "Shinjuku 1-chome Bldg.",
        "address_2": "Shinjuku-ku  Tokyo  160-0022",
        "country": "JP"
    },
    "001387": {
        "oui_hex": "00-13-87",
        "organization": "27M Technologies AB",
        "address_1": "Diskettgatan 11",
        "address_2": "Linköping     S-583 35",
        "country": "SE"
    },
    "001373": {
        "oui_hex": "00-13-73",
        "organization": "BLwave Electronics Co., Ltd",
        "address_1": "23FGH, Block A,ZhenYe Building , BaoAn Nan Road , LuoHu , Shenzhen , China",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "001366": {
        "oui_hex": "00-13-66",
        "organization": "Neturity Technologies Inc.",
        "address_1": "830 Stewart Drive",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00135B": {
        "oui_hex": "00-13-5B",
        "organization": "PanelLink Cinema, LLC",
        "address_1": "1070 E Arques Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00136F": {
        "oui_hex": "00-13-6F",
        "organization": "PacketMotion, Inc.",
        "address_1": "2121 El Camino Real",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "001368": {
        "oui_hex": "00-13-68",
        "organization": "Saab Danmark A/S",
        "address_1": "Alsion 2",
        "address_2": "Soenderborg  DK  6400",
        "country": "DK"
    },
    "0013B4": {
        "oui_hex": "00-13-B4",
        "organization": "Appear TV",
        "address_1": "P.O. Box 8 Lilleaker",
        "address_2": "Oslo    NO-0216",
        "country": "NO"
    },
    "0013AE": {
        "oui_hex": "00-13-AE",
        "organization": "Radiance Technologies, Inc.",
        "address_1": "350 Wynn Dr.",
        "address_2": "Huntsville  Alabama  35805",
        "country": "US"
    },
    "001397": {
        "oui_hex": "00-13-97",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "0013C3": {
        "oui_hex": "00-13-C3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0013BD": {
        "oui_hex": "00-13-BD",
        "organization": "HYMATOM SA",
        "address_1": "Zone Industrielle",
        "address_2": "VENDARGUES  HERAULT  34740",
        "country": "FR"
    },
    "001391": {
        "oui_hex": "00-13-91",
        "organization": "OUEN CO.,LTD.",
        "address_1": "Gotanda NT Bldg.7F,",
        "address_2": "Shinagawa-ku  Tokyo  141-0022",
        "country": "JP"
    },
    "001323": {
        "oui_hex": "00-13-23",
        "organization": "Cap Co., Ltd.",
        "address_1": "11F,684-2,deungchon 3-dong,gangseo-gu",
        "address_2": "Seoul    157-754",
        "country": "KR"
    },
    "001314": {
        "oui_hex": "00-13-14",
        "organization": "Asiamajor Inc.",
        "address_1": "6F-9, No. 268, Lian-Cheng Rd., Junghe City,",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "001316": {
        "oui_hex": "00-13-16",
        "organization": "L-S-B Broadcast Technologies GmbH",
        "address_1": "Gustav-Stresemann-Str. 8",
        "address_2": "Bingen  Rheinland-Pfalz  55411",
        "country": "DE"
    },
    "001312": {
        "oui_hex": "00-13-12",
        "organization": "Amedia Networks Inc.",
        "address_1": "101 Crawfords Corner Rd",
        "address_2": "Holmdel  NJ  07733",
        "country": "US"
    },
    "001336": {
        "oui_hex": "00-13-36",
        "organization": "Tianjin 712 Communication Broadcasting co., ltd.",
        "address_1": "No.185, Xinda Road, Hebei District",
        "address_2": "Tianjin    300140",
        "country": "CN"
    },
    "00135E": {
        "oui_hex": "00-13-5E",
        "organization": "EAB/RWI/K",
        "address_1": "Färögatan 6",
        "address_2": "Stockholm  Kista  164 80",
        "country": "SE"
    },
    "00134E": {
        "oui_hex": "00-13-4E",
        "organization": "Valox Systems, Inc.",
        "address_1": "#704, Ace Twin tower 2, 212-30, Guro-3dong, Guro-gu",
        "address_2": "Seoul    152-779",
        "country": "KR"
    },
    "001344": {
        "oui_hex": "00-13-44",
        "organization": "Fargo Electronics Inc.",
        "address_1": "6533 Flying Cloud Drive",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "001348": {
        "oui_hex": "00-13-48",
        "organization": "Artila Electronics Co., Ltd.",
        "address_1": "2F., No.1, Alley 8, Siwei Lane, Zhongzheng Rd.,",
        "address_2": "Xindian City  Taipei County  231",
        "country": "TW"
    },
    "0012EF": {
        "oui_hex": "00-12-EF",
        "organization": "OneAccess SA",
        "address_1": "28 rue de la Redoute",
        "address_2": "Fontenay aux Roses    92260",
        "country": "FR"
    },
    "0012E9": {
        "oui_hex": "00-12-E9",
        "organization": "Abbey Systems Ltd",
        "address_1": "Level 4, 220 Willis St",
        "address_2": "Wellington    6030",
        "country": "NZ"
    },
    "001300": {
        "oui_hex": "00-13-00",
        "organization": "IT-FACTORY, INC.",
        "address_1": "1-16-26 TAKAGI MINAMI-KU",
        "address_2": "FUKUOKA-SHI  FUKUOKA-KEN  815-0004",
        "country": "JP"
    },
    "001322": {
        "oui_hex": "00-13-22",
        "organization": "DAQ Electronics, Inc.",
        "address_1": "262B Old New Brunswick Road",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "0012D5": {
        "oui_hex": "00-12-D5",
        "organization": "Motion Reality Inc.",
        "address_1": "200 North Cobb Parkway",
        "address_2": "Marietta  GA  30062",
        "country": "US"
    },
    "0012D8": {
        "oui_hex": "00-12-D8",
        "organization": "International Games System Co., Ltd.",
        "address_1": "No.130, Wu-Gung Rd., Wu-Gu Industrial Park,",
        "address_2": "Taipei    248",
        "country": "TW"
    },
    "00129A": {
        "oui_hex": "00-12-9A",
        "organization": "IRT Electronics Pty Ltd",
        "address_1": "26 Hotham Parade",
        "address_2": "Artarmon  NSW  2064",
        "country": "AU"
    },
    "00128D": {
        "oui_hex": "00-12-8D",
        "organization": "STB Datenservice GmbH",
        "address_1": "Weinsbergstraße 190",
        "address_2": "Köln  NRW  50825",
        "country": "DE"
    },
    "0012DB": {
        "oui_hex": "00-12-DB",
        "organization": "ZIEHL industrie-elektronik GmbH + Co KG",
        "address_1": "Daimlerstraße 13",
        "address_2": "Schwäbisch Hall    74523",
        "country": "DE"
    },
    "0012D6": {
        "oui_hex": "00-12-D6",
        "organization": "Jiangsu Yitong High-Tech Co.,Ltd",
        "address_1": "No 216 Huanghe Road",
        "address_2": "Changshu  Jiangsu  215500",
        "country": "CN"
    },
    "0012DA": {
        "oui_hex": "00-12-DA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0012D3": {
        "oui_hex": "00-12-D3",
        "organization": "Zetta Systems, Inc.",
        "address_1": "17311 135th AVE NE",
        "address_2": "Woodinville  WA  98072",
        "country": "US"
    },
    "0012A2": {
        "oui_hex": "00-12-A2",
        "organization": "VITA",
        "address_1": "PO Box 19658",
        "address_2": "Fountain Hills  AZ  85269",
        "country": "US"
    },
    "0012A5": {
        "oui_hex": "00-12-A5",
        "organization": "Dolphin Interconnect Solutions AS",
        "address_1": "NILS Hansens Vei 13",
        "address_2": "Oslo    0667",
        "country": "NO"
    },
    "0012A8": {
        "oui_hex": "00-12-A8",
        "organization": "intec GmbH",
        "address_1": "Rahmedestraße 90",
        "address_2": "Luedenscheid  NRW  58507",
        "country": "DE"
    },
    "00129E": {
        "oui_hex": "00-12-9E",
        "organization": "Surf Communications Inc.",
        "address_1": "Room 313, 3F, Bldg.52, No. 195, Chung Hsing Rd., Sec 4, Chutung, HsinChu, Taiwan",
        "address_2": "HsinChu    310",
        "country": "TW"
    },
    "0012BA": {
        "oui_hex": "00-12-BA",
        "organization": "FSI Systems, Inc.",
        "address_1": "5847 County Road 41",
        "address_2": "Farmington  NY  14425",
        "country": "US"
    },
    "0012B2": {
        "oui_hex": "00-12-B2",
        "organization": "AVOLITES LTD.",
        "address_1": "184 PARK AVENUE",
        "address_2": "LONDON    NW10 7XL",
        "country": "GB"
    },
    "0012AE": {
        "oui_hex": "00-12-AE",
        "organization": "HLS HARD-LINE Solutions Inc.",
        "address_1": "53 Main Street",
        "address_2": "Dowling  Ontario  P0M 1R0",
        "country": "CA"
    },
    "0012AF": {
        "oui_hex": "00-12-AF",
        "organization": "ELPRO Technologies",
        "address_1": "9 / 12 Billabong St.",
        "address_2": "Stafford  Queensland  4053",
        "country": "AU"
    },
    "0012E6": {
        "oui_hex": "00-12-E6",
        "organization": "SPECTEC COMPUTER CO., LTD.",
        "address_1": "6F., No. 92, Nanking E. Rd. Sec. 5,",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "001236": {
        "oui_hex": "00-12-36",
        "organization": "ConSentry Networks",
        "address_1": "1690 McCandless Dr",
        "address_2": "Milipitas  CA  95035",
        "country": "US"
    },
    "001235": {
        "oui_hex": "00-12-35",
        "organization": "Andrew Corporation",
        "address_1": "2601 Telecom Pkwy",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "001245": {
        "oui_hex": "00-12-45",
        "organization": "Zellweger Analytics, Inc.",
        "address_1": "405 Barclay Blvd.",
        "address_2": "Lincolnshire  Illinois  60069",
        "country": "US"
    },
    "001242": {
        "oui_hex": "00-12-42",
        "organization": "Millennial Net",
        "address_1": " 285 Billerica Road",
        "address_2": "Chelmsford  MA  01803",
        "country": "US"
    },
    "001241": {
        "oui_hex": "00-12-41",
        "organization": "a2i marketing center",
        "address_1": "1024-4  Duksan Bldg Bangbaedong Seochogu Seoul Korea",
        "address_2": "SEOUL    137-060",
        "country": "KR"
    },
    "00123B": {
        "oui_hex": "00-12-3B",
        "organization": "KeRo Systems ApS",
        "address_1": "Allikevej 3",
        "address_2": "Hørsholm    2970",
        "country": "DK"
    },
    "001287": {
        "oui_hex": "00-12-87",
        "organization": "Digital Everywhere Unterhaltungselektronik GmbH",
        "address_1": "Maria Gailer Strasse 16",
        "address_2": "Villach  Kärnten  9500",
        "country": "AT"
    },
    "001282": {
        "oui_hex": "00-12-82",
        "organization": "Qovia",
        "address_1": "7470 New Technology Way",
        "address_2": "Frederick  MD  21703",
        "country": "US"
    },
    "001285": {
        "oui_hex": "00-12-85",
        "organization": "Gizmondo Europe Ltd",
        "address_1": "1 Meadow Gate Avenue",
        "address_2": "Farnborough  Hampshire  GU14 6FG",
        "country": "GB"
    },
    "001277": {
        "oui_hex": "00-12-77",
        "organization": "Korenix Technologies Co., Ltd.",
        "address_1": "11F-1, No. 108, MinQuan Rd.",
        "address_2": "Xindian City  Taipei  231",
        "country": "TW"
    },
    "00126D": {
        "oui_hex": "00-12-6D",
        "organization": "University of California, Berkeley",
        "address_1": "EECS Department",
        "address_2": "Berkeley  CA  94720-1776",
        "country": "US"
    },
    "001267": {
        "oui_hex": "00-12-67",
        "organization": "Panasonic Corporation",
        "address_1": "2460-1, Uegawa-Cho",
        "address_2": "Matsusaka-City  Mie  571-8506",
        "country": "JP"
    },
    "001265": {
        "oui_hex": "00-12-65",
        "organization": "Enerdyne Technologies, Inc.",
        "address_1": "1935 Cordell Court",
        "address_2": "El Cajon  CA  92020",
        "country": "US"
    },
    "001257": {
        "oui_hex": "00-12-57",
        "organization": "LeapComm Communication Technologies Inc.",
        "address_1": "RM1804-05 South Tower Hong Kong Plaza, No.283 Huaihai Zhong Road",
        "address_2": "Shanghai    200021",
        "country": "CN"
    },
    "001251": {
        "oui_hex": "00-12-51",
        "organization": "SILINK",
        "address_1": "13 RUE POMEYS",
        "address_2": "LE TAILLAN    33320",
        "country": "FR"
    },
    "00128E": {
        "oui_hex": "00-12-8E",
        "organization": "Q-Free ASA",
        "address_1": "Th. Owesensgt. 35c",
        "address_2": "Trondheim    7443",
        "country": "NO"
    },
    "001292": {
        "oui_hex": "00-12-92",
        "organization": "Griffin Technology",
        "address_1": "1930 Air Lane Drive",
        "address_2": "Nashville  TN  37210",
        "country": "US"
    },
    "0011F3": {
        "oui_hex": "00-11-F3",
        "organization": "NeoMedia Europe AG",
        "address_1": "Jens-Otto-Krag-Straße 11",
        "address_2": "Würselen    52146",
        "country": "DE"
    },
    "0011E9": {
        "oui_hex": "00-11-E9",
        "organization": "STARNEX CO., LTD.",
        "address_1": "4th Floor, C&C Bldg, 228-2",
        "address_2": "Kwangjin-gu  Seoul  143-200",
        "country": "KR"
    },
    "0011EC": {
        "oui_hex": "00-11-EC",
        "organization": "AVIX INC.",
        "address_1": "1-1, Fukuura, Kanazawa-ku",
        "address_2": "Yokohama-shi  Kanagawa  236-0004",
        "country": "JP"
    },
    "0011E7": {
        "oui_hex": "00-11-E7",
        "organization": "WORLDSAT - Texas de France",
        "address_1": "220, rue Gustave Eiffel",
        "address_2": "Aix en Provence  Bouches du Rhone  13854",
        "country": "FR"
    },
    "001202": {
        "oui_hex": "00-12-02",
        "organization": "Decrane Aerospace - Audio International Inc.",
        "address_1": "7300 Industry Drive",
        "address_2": "North Little Rock  AR  72117",
        "country": "US"
    },
    "0011FE": {
        "oui_hex": "00-11-FE",
        "organization": "Keiyo System Research, Inc.",
        "address_1": "Hamada park Bldg. 6F",
        "address_2": "Chiba-city  Chiba-pref  260-0028",
        "country": "JP"
    },
    "0011FD": {
        "oui_hex": "00-11-FD",
        "organization": "KORG INC.",
        "address_1": "4015-2, Yanokuchi",
        "address_2": "Inagi-City  TOKYO  206-0812",
        "country": "JP"
    },
    "0011FA": {
        "oui_hex": "00-11-FA",
        "organization": "Rane Corporation",
        "address_1": "10802 47th Avenue West",
        "address_2": "Mukilteo  WA  98275-5098",
        "country": "US"
    },
    "0011CE": {
        "oui_hex": "00-11-CE",
        "organization": "Ubisense Limited",
        "address_1": "St. Andrews House",
        "address_2": "Chesterton  Cambridge  CB4 1DL",
        "country": "GB"
    },
    "0011D0": {
        "oui_hex": "00-11-D0",
        "organization": "Tandberg Data ASA",
        "address_1": "Kjelsåsveien 161",
        "address_2": "Oslo    0411",
        "country": "NO"
    },
    "0011C3": {
        "oui_hex": "00-11-C3",
        "organization": "Transceiving System Technology Corporation",
        "address_1": "NO.85,Sec.2,Gongdaowu Rd.,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0011C2": {
        "oui_hex": "00-11-C2",
        "organization": "United Fiber Optic Communication",
        "address_1": "13-1,NO.700,Jungjeng RD,Junghe City",
        "address_2": "Junghe City  Taipei  235",
        "country": "TW"
    },
    "001228": {
        "oui_hex": "00-12-28",
        "organization": "Data Ltd.",
        "address_1": "J. Hagaru 9",
        "address_2": "Bratislava    830 05",
        "country": "SK"
    },
    "00121F": {
        "oui_hex": "00-12-1F",
        "organization": "Harding Instruments",
        "address_1": "9431-41Ave",
        "address_2": "Edmonton  AB  T6E 5X7",
        "country": "CA"
    },
    "001220": {
        "oui_hex": "00-12-20",
        "organization": "Cadco Systems",
        "address_1": "2363 Merritt Dr",
        "address_2": "Garland  Texas  75041",
        "country": "US"
    },
    "001229": {
        "oui_hex": "00-12-29",
        "organization": "BroadEasy Technologies Co.,Ltd",
        "address_1": "24th Floor,Tower A,JinShan Mansion,",
        "address_2": "Nanjing  Jiangsu  210009",
        "country": "CN"
    },
    "001226": {
        "oui_hex": "00-12-26",
        "organization": "Japan Direx Corporation",
        "address_1": "Kyocera Harajuku Bldg.",
        "address_2": "Shibuya-ku  Tokyo  150-0001",
        "country": "JP"
    },
    "001222": {
        "oui_hex": "00-12-22",
        "organization": "Skardin (UK) Ltd",
        "address_1": "No. 5 Greenway (RO24)",
        "address_2": "Harlow  Essex  CM19 5QB",
        "country": "GB"
    },
    "0011E8": {
        "oui_hex": "00-11-E8",
        "organization": "Tixi.Com",
        "address_1": "Karmeliterweg 114",
        "address_2": "Berlin    13465",
        "country": "DE"
    },
    "0011E0": {
        "oui_hex": "00-11-E0",
        "organization": "U-MEDIA Communications, Inc.",
        "address_1": " 9F, No.1 Jin-Shan St.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00120D": {
        "oui_hex": "00-12-0D",
        "organization": "Advanced Telecommunication Technologies, Inc.",
        "address_1": "10390 Wilshire Boulevard",
        "address_2": "Los Angeles  California  90024",
        "country": "US"
    },
    "00120E": {
        "oui_hex": "00-12-0E",
        "organization": "AboCom",
        "address_1": "1F , No. 21, Yanfa 2nd Rd., SBIP",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "0011F2": {
        "oui_hex": "00-11-F2",
        "organization": "Institute of Network Technologies",
        "address_1": "17-th Line Vasilevsky Ostrov, 54-1",
        "address_2": "St.Petersburg    199178",
        "country": "RU"
    },
    "001210": {
        "oui_hex": "00-12-10",
        "organization": "WideRay Corp",
        "address_1": "25 Kearny Street",
        "address_2": "San Francisco  CA  94108",
        "country": "US"
    },
    "0011A4": {
        "oui_hex": "00-11-A4",
        "organization": "JStream Technologies Inc.",
        "address_1": "Bldg.53, R405, 195 Sec.4, Chung Hsing Rd.",
        "address_2": "Chutung,   Hsinchu  310",
        "country": "TW"
    },
    "001198": {
        "oui_hex": "00-11-98",
        "organization": "Prism Media Products Limited",
        "address_1": "William James House",
        "address_2": "Cambridge  Cambridgeshire  CB4 0WX",
        "country": "GB"
    },
    "001197": {
        "oui_hex": "00-11-97",
        "organization": "Monitoring Technologies Limited",
        "address_1": "14 Attenburys Park Estate",
        "address_2": "Timperley  Cheshire  WA14 5QE",
        "country": "GB"
    },
    "001199": {
        "oui_hex": "00-11-99",
        "organization": "2wcom Systems GmbH",
        "address_1": "Am Sophienhof 8",
        "address_2": "Flensburg    24941",
        "country": "DE"
    },
    "0011A7": {
        "oui_hex": "00-11-A7",
        "organization": "Infilco Degremont Inc.",
        "address_1": "8007 Discovery Dr.",
        "address_2": "Richmond  Virginia  23255-1390",
        "country": "US"
    },
    "0011A9": {
        "oui_hex": "00-11-A9",
        "organization": "MOIMSTONE Co., LTD",
        "address_1": "7th Floor JoongPyung Building 64-1",
        "address_2": "Seoul    137-900",
        "country": "KR"
    },
    "0011A3": {
        "oui_hex": "00-11-A3",
        "organization": "LanReady Technologies Inc.",
        "address_1": "4F, No. 337, SinHu 2nd Road., NeiHu District",
        "address_2": "  Taipei  114",
        "country": "TW"
    },
    "001176": {
        "oui_hex": "00-11-76",
        "organization": "Intellambda Systems, Inc.",
        "address_1": "48501 Warm Springs Blvd, #107",
        "address_2": "Fremont  California  94539",
        "country": "US"
    },
    "001177": {
        "oui_hex": "00-11-77",
        "organization": "Coaxial Networks, Inc.",
        "address_1": "4633 Old Ironsides Dr",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001170": {
        "oui_hex": "00-11-70",
        "organization": "GSC SRL",
        "address_1": "VIA PER VIMERCATE",
        "address_2": "USMATE VELATE  MILANO  20040",
        "country": "IT"
    },
    "00116B": {
        "oui_hex": "00-11-6B",
        "organization": "Digital Data Communications Asia Co.,Ltd",
        "address_1": "8F,No.41,Lane 221,Kang-Chien RD.,Nei-Hu Dis.,",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "001169": {
        "oui_hex": "00-11-69",
        "organization": "EMS Satcom",
        "address_1": "Green Lane",
        "address_2": "Tewkesbury  Gloucestershire  GL20 8HD",
        "country": "GB"
    },
    "001162": {
        "oui_hex": "00-11-62",
        "organization": "STAR MICRONICS CO.,LTD.",
        "address_1": "536 Shimizunanatsushinya",
        "address_2": "Shizuoka    424-0066",
        "country": "JP"
    },
    "001181": {
        "oui_hex": "00-11-81",
        "organization": "InterEnergy Co.Ltd,",
        "address_1": "3F Shinyokohama Bosei Bldg.",
        "address_2": "Yokohama city  Kanagawa  222-0033",
        "country": "JP"
    },
    "001194": {
        "oui_hex": "00-11-94",
        "organization": "Chi Mei Communication Systems, Inc.",
        "address_1": "11F, No.39, Chung Hua RD. Sec 1",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "0011BF": {
        "oui_hex": "00-11-BF",
        "organization": "AESYS S.p.A.",
        "address_1": "Via Artigiani, 41",
        "address_2": "Brusaporto  Bergamo  24060",
        "country": "IT"
    },
    "0011B7": {
        "oui_hex": "00-11-B7",
        "organization": "Octalix B.V.",
        "address_1": "Molensteijn 60",
        "address_2": "De Meern    NL-3454 PT",
        "country": "NL"
    },
    "0011B9": {
        "oui_hex": "00-11-B9",
        "organization": "Inner Range Pty. Ltd.",
        "address_1": "1 Millenium Court",
        "address_2": "Knoxfield  Victoria  3180",
        "country": "AU"
    },
    "001109": {
        "oui_hex": "00-11-09",
        "organization": "Micro-Star International",
        "address_1": "No 69, Li-De Street, Jung-He City,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "001104": {
        "oui_hex": "00-11-04",
        "organization": "TELEXY",
        "address_1": "1116, HYUNDAI 41 TOWER, 917-9",
        "address_2": "SEOUL    158-723",
        "country": "KR"
    },
    "001161": {
        "oui_hex": "00-11-61",
        "organization": "NetStreams, LLC",
        "address_1": "3600 W. Parmer Lane",
        "address_2": "Austin  TX  78727",
        "country": "US"
    },
    "001156": {
        "oui_hex": "00-11-56",
        "organization": "Pharos Systems NZ",
        "address_1": "Level 3, 123 Carlton Gore Road",
        "address_2": "Auckland  NZ  1001",
        "country": "NZ"
    },
    "001159": {
        "oui_hex": "00-11-59",
        "organization": "MATISSE NETWORKS INC",
        "address_1": "339 N BERNARDO AVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00115C": {
        "oui_hex": "00-11-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00115D": {
        "oui_hex": "00-11-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001126": {
        "oui_hex": "00-11-26",
        "organization": "Venstar Inc.",
        "address_1": "9250 Owensmouth Ave.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "00112E": {
        "oui_hex": "00-11-2E",
        "organization": "CEICOM",
        "address_1": "17 rue Gaston Evrard",
        "address_2": "Toulouse Cedex 1    31094",
        "country": "FR"
    },
    "001122": {
        "oui_hex": "00-11-22",
        "organization": "CIMSYS Inc",
        "address_1": "#301,Sinsung-clean BLDG,140, Nongseo-Ri,Kiheung-Eup",
        "address_2": "Yongin-City  Kyunggi-Do  449-711",
        "country": "KR"
    },
    "001117": {
        "oui_hex": "00-11-17",
        "organization": "CESNET",
        "address_1": "Zikova 4",
        "address_2": "Praha 6    160 00",
        "country": "CZ"
    },
    "001116": {
        "oui_hex": "00-11-16",
        "organization": "COTEAU VERT CO., LTD.",
        "address_1": "3-3-19 KACHIDOKI",
        "address_2": "CHUO-KU  TOKYO  104-0054",
        "country": "JP"
    },
    "001110": {
        "oui_hex": "00-11-10",
        "organization": "Maxanna Technology Co., Ltd.",
        "address_1": "Room201, No.42-3, Luyuan Road",
        "address_2": "Guangzhou    510095",
        "country": "CN"
    },
    "00113B": {
        "oui_hex": "00-11-3B",
        "organization": "Micronet Communications Inc.",
        "address_1": "12F-1, No. 100, Min-Chuan Road",
        "address_2": "Hsin-Tien  Taipei  231",
        "country": "TW"
    },
    "00113D": {
        "oui_hex": "00-11-3D",
        "organization": "KN SOLTEC CO.,LTD.",
        "address_1": "98B-5L NAMDONG INDUSTRIAL COMPLEX #662-4 GOJAN-DONG",
        "address_2": "NAMDONG-GU  INCHEON  405-818",
        "country": "KR"
    },
    "001134": {
        "oui_hex": "00-11-34",
        "organization": "MediaCell, Inc.",
        "address_1": "600 17th St",
        "address_2": "Denver  CO  80202",
        "country": "US"
    },
    "001135": {
        "oui_hex": "00-11-35",
        "organization": "Grandeye Ltd",
        "address_1": "6 Huxley Road",
        "address_2": "Guildford  Surrey  GU2 7RE",
        "country": "GB"
    },
    "001121": {
        "oui_hex": "00-11-21",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001149": {
        "oui_hex": "00-11-49",
        "organization": "Proliphix Inc.",
        "address_1": "3 Lan Drive",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "000FC0": {
        "oui_hex": "00-0F-C0",
        "organization": "DELCOMp",
        "address_1": "Technologielaan 3",
        "address_2": "Leuven    B-3000",
        "country": "BE"
    },
    "000FBA": {
        "oui_hex": "00-0F-BA",
        "organization": "Tevebox AB",
        "address_1": "Berglinds vag 13",
        "address_2": "warmdo    S-13900",
        "country": "SE"
    },
    "000FB8": {
        "oui_hex": "00-0F-B8",
        "organization": "CallURL Inc.",
        "address_1": "3F-11, No. 508 Sec.  5, Chung-Hsiao E. Rd.",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "000FB7": {
        "oui_hex": "00-0F-B7",
        "organization": "Cavium",
        "address_1": "2315 N First Street",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000FD3": {
        "oui_hex": "00-0F-D3",
        "organization": "Digium",
        "address_1": "445 Jan Davis Drive NW",
        "address_2": "Huntsville  AL  35806",
        "country": "US"
    },
    "000FD1": {
        "oui_hex": "00-0F-D1",
        "organization": "Applied Wireless Identifications Group, Inc.",
        "address_1": "382 Route 59, Section 292",
        "address_2": "Monsey  New York  10952",
        "country": "US"
    },
    "000FC1": {
        "oui_hex": "00-0F-C1",
        "organization": "WAVE Corporation",
        "address_1": "3-25-5 Chidori",
        "address_2": "Ohta-ku  Tokyo  146-0083",
        "country": "JP"
    },
    "001100": {
        "oui_hex": "00-11-00",
        "organization": "Schneider Electric",
        "address_1": "5460 Pottsville Pike",
        "address_2": "Leesport  PA  19533",
        "country": "US"
    },
    "000FFA": {
        "oui_hex": "00-0F-FA",
        "organization": "Optinel Systems, Inc.",
        "address_1": "6835 Deerpath Rd.",
        "address_2": "Elkridge  MD  21075",
        "country": "US"
    },
    "000FFD": {
        "oui_hex": "00-0F-FD",
        "organization": "Glorytek Network Inc.",
        "address_1": "5F.-3, No.16, Sec. 1, Dongda Rd.,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000FF9": {
        "oui_hex": "00-0F-F9",
        "organization": "Valcretec, Inc.",
        "address_1": "Byucksan Digital Valley II 15F",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "000FC4": {
        "oui_hex": "00-0F-C4",
        "organization": "NST co.,LTD.",
        "address_1": "4-3-1 SHINMIYAKODA",
        "address_2": "HAMAMATSU  SHIZUOKA  431-2103",
        "country": "JP"
    },
    "000FC9": {
        "oui_hex": "00-0F-C9",
        "organization": "Allnet GmbH",
        "address_1": "Maistraße 2",
        "address_2": "Germering  Bavaria  82110",
        "country": "DE"
    },
    "000FC6": {
        "oui_hex": "00-0F-C6",
        "organization": "Eurocom Industries A/S",
        "address_1": "porsvej 2",
        "address_2": "Aalborg  NV  DK-9200",
        "country": "DK"
    },
    "000FBE": {
        "oui_hex": "00-0F-BE",
        "organization": "e-w/you Inc.",
        "address_1": "3F FINE Bldg. 6-17-17",
        "address_2": "Shinagawa-ku,  Tokyo  140-0013",
        "country": "JP"
    },
    "000FA9": {
        "oui_hex": "00-0F-A9",
        "organization": "PC Fabrik",
        "address_1": "Buchenstrasse 13-15",
        "address_2": "Dresden  Sachsen  01097",
        "country": "DE"
    },
    "000FA0": {
        "oui_hex": "00-0F-A0",
        "organization": "CANON KOREA BUSINESS SOLUTIONS INC.",
        "address_1": "736 Wonsi-Dong",
        "address_2": "Ansan-si  Kyunggi-do  425-090",
        "country": "KR"
    },
    "000F9A": {
        "oui_hex": "00-0F-9A",
        "organization": "Synchrony, Inc.",
        "address_1": "6410 Commonwealth Drive",
        "address_2": "Roanoke  VA  24018",
        "country": "US"
    },
    "000FEA": {
        "oui_hex": "00-0F-EA",
        "organization": "Giga-Byte Technology Co.,LTD.",
        "address_1": "No.215,Nan-Ping Road,Ping-Jen City,",
        "address_2": "Ping-Jen  Taoyuan  324",
        "country": "TW"
    },
    "000FF7": {
        "oui_hex": "00-0F-F7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000FD8": {
        "oui_hex": "00-0F-D8",
        "organization": "Force, Inc.",
        "address_1": "825 Park Street",
        "address_2": "Christiansburg  Va  24073",
        "country": "US"
    },
    "000F8D": {
        "oui_hex": "00-0F-8D",
        "organization": "FAST TV-Server AG",
        "address_1": "Ruedesheimerstraße 11-13",
        "address_2": "Munich  Germany  80686",
        "country": "DE"
    },
    "000F85": {
        "oui_hex": "00-0F-85",
        "organization": "ADDO-Japan Corporation",
        "address_1": "Shin Edobashi Bldg. 4F, 8-6 Nihombashi Kobuna-cho",
        "address_2": "Chuo-ku  Tokyo  103-0024",
        "country": "JP"
    },
    "000F82": {
        "oui_hex": "00-0F-82",
        "organization": "Mortara Instrument, Inc.",
        "address_1": "7865 N. 86th St.",
        "address_2": "Milwaukee  WI  53224",
        "country": "US"
    },
    "000F49": {
        "oui_hex": "00-0F-49",
        "organization": "Northover Solutions Limited",
        "address_1": "Heath Cottage",
        "address_2": "Larling  Norfolk  NR16 2RB",
        "country": "GB"
    },
    "000F4B": {
        "oui_hex": "00-0F-4B",
        "organization": "Oracle Corporation",
        "address_1": "900 Chelmsford Street",
        "address_2": "Lowell  MA  01851",
        "country": "US"
    },
    "000F44": {
        "oui_hex": "00-0F-44",
        "organization": "Tivella Inc.",
        "address_1": "795 Main Street",
        "address_2": "Half Moon Bay  CA  94019",
        "country": "US"
    },
    "000F4A": {
        "oui_hex": "00-0F-4A",
        "organization": "Kyushu-kyohan co.,ltd",
        "address_1": "2-6-3,Koganemachi",
        "address_2": "Kitakyushu-city  Fukuoka  802-0071",
        "country": "JP"
    },
    "000F81": {
        "oui_hex": "00-0F-81",
        "organization": "PAL Pacific Inc.",
        "address_1": "79405 Highway 111",
        "address_2": "La Quinta  CA  92253",
        "country": "US"
    },
    "000F7F": {
        "oui_hex": "00-0F-7F",
        "organization": "UBSTORAGE Co.,Ltd.",
        "address_1": "#A-108, Seoul_Sanup_Jiwon_Center",
        "address_2": "Ganseo-gu  Seoul  157-840",
        "country": "KR"
    },
    "000F95": {
        "oui_hex": "00-0F-95",
        "organization": "ELECOM Co.,LTD Laneed Division",
        "address_1": "8F Kanda-Muromachi Bldg.",
        "address_2": "Chiyoda-Ku, Tokyo.    101-0052",
        "country": "JP"
    },
    "000F55": {
        "oui_hex": "00-0F-55",
        "organization": "Datawire Communication Networks Inc.",
        "address_1": "10 Carlson Court, Suite 300",
        "address_2": "Toronto  Ontario  M9W 6L2",
        "country": "CA"
    },
    "000F56": {
        "oui_hex": "00-0F-56",
        "organization": "Continuum Photonics Inc",
        "address_1": "5 Fortune Drive",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "000F60": {
        "oui_hex": "00-0F-60",
        "organization": "Lifetron Co.,Ltd",
        "address_1": "6-7,Tenjinnishimachi",
        "address_2": "Osaka  Osaka Prefecture  530-0045",
        "country": "JP"
    },
    "000F5B": {
        "oui_hex": "00-0F-5B",
        "organization": "Delta Information Systems, Inc.",
        "address_1": "300 Welsh Road, Bldg. 3",
        "address_2": "Horsham  PA  19044-2273",
        "country": "US"
    },
    "000F8A": {
        "oui_hex": "00-0F-8A",
        "organization": "WideView",
        "address_1": "F. 6, No. 8, Wu-chuan 2 Rd, Hsin-Chuang City",
        "address_2": "Taipei Country    242",
        "country": "TW"
    },
    "000F90": {
        "oui_hex": "00-0F-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000F77": {
        "oui_hex": "00-0F-77",
        "organization": "DENTUM CO.,LTD",
        "address_1": "Wookyung B/D 602 #678-6",
        "address_2": "Seoul    157-030",
        "country": "KR"
    },
    "000F7B": {
        "oui_hex": "00-0F-7B",
        "organization": "Arce Sistemas, S.A.",
        "address_1": "C/Padre Larramendi, 3 - 2º",
        "address_2": "Bilbao  Vizcaya  48012",
        "country": "ES"
    },
    "000F68": {
        "oui_hex": "00-0F-68",
        "organization": "Vavic Network Technology, Inc.",
        "address_1": "1st Floor, 15 Jiangong Road",
        "address_2": "Guangzhou  Guangdong  510665",
        "country": "CN"
    },
    "000EE2": {
        "oui_hex": "00-0E-E2",
        "organization": "Custom Engineering",
        "address_1": "Via Beretttine 2/b",
        "address_2": "Fontevivo  Parma  43010",
        "country": "IT"
    },
    "000EE3": {
        "oui_hex": "00-0E-E3",
        "organization": "Chiyu Technology Co.,Ltd",
        "address_1": "No. 28, Renai Road, Chiayi, 600",
        "address_2": "Chiayi    600",
        "country": "TW"
    },
    "000EE5": {
        "oui_hex": "00-0E-E5",
        "organization": "bitWallet, Inc.",
        "address_1": "Gate City Ohsaki West Tower 18F, 1-11-1 Osaki, Shinagawa-ku",
        "address_2": "Tokyo    1410032",
        "country": "JP"
    },
    "000EDA": {
        "oui_hex": "00-0E-DA",
        "organization": "C-TECH UNITED CORP.",
        "address_1": "5F, No 665, CHUNG CHEN RD.",
        "address_2": "HSIN CHUANG CITT  of TAIPEI HSIEN    242",
        "country": "TW"
    },
    "000ECF": {
        "oui_hex": "00-0E-CF",
        "organization": "PROFIBUS Nutzerorganisation e.V.",
        "address_1": "Haid-und-Neu-Straße 7",
        "address_2": "Karlsruhe  Baden-Württemberg  76131",
        "country": "DE"
    },
    "000EEB": {
        "oui_hex": "00-0E-EB",
        "organization": "Sandmartin(zhong shan)Electronics Co.,Ltd",
        "address_1": "3st Industrial Area,Tan Zhou,",
        "address_2": "Zhongshan  Guangdong  528467",
        "country": "CN"
    },
    "000EEC": {
        "oui_hex": "00-0E-EC",
        "organization": "Orban",
        "address_1": "1525 Alvarado St.",
        "address_2": "San Leandro  CA  94577",
        "country": "US"
    },
    "000EEF": {
        "oui_hex": "00-0E-EF",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000EF1": {
        "oui_hex": "00-0E-F1",
        "organization": "EZQUEST INC.",
        "address_1": "23311 E. LA PALMA AVE.",
        "address_2": "YORBA LINDA  CA  92887",
        "country": "US"
    },
    "000EE7": {
        "oui_hex": "00-0E-E7",
        "organization": "AAC ELECTRONICS CORP.",
        "address_1": "FLOOR 7,SIXTH BUILDING OF NAIANYOU TNAN INDUSTRIAL AREA,NANSHAN DISTRICT",
        "address_2": "SHENZHEN  PROVINCE GUANGDONG  518054",
        "country": "CN"
    },
    "000F1C": {
        "oui_hex": "00-0F-1C",
        "organization": "DigitAll World Co., Ltd",
        "address_1": "Sejin Bld 2F, 689 ilwon2-dong,",
        "address_2": "gangnam-gu  Seoul  135-946",
        "country": "KR"
    },
    "000F1A": {
        "oui_hex": "00-0F-1A",
        "organization": "Gaming Support B.V.",
        "address_1": "Industrie weg 29",
        "address_2": "  Rotterdam  3044 AS",
        "country": "NL"
    },
    "000F0A": {
        "oui_hex": "00-0F-0A",
        "organization": "Clear Edge Networks",
        "address_1": "11250 El Camino Real",
        "address_2": "San Diego  CA  92130",
        "country": "US"
    },
    "000F02": {
        "oui_hex": "00-0F-02",
        "organization": "Digicube Technology Co., Ltd",
        "address_1": "8F,No. 51, Lane  35, Jihu Rd.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000F2F": {
        "oui_hex": "00-0F-2F",
        "organization": "W-LINX TECHNOLOGY CO., LTD.",
        "address_1": " 2F,ELLEN L. SKELTON BUILDING,FISHER LANE ROAD",
        "address_2": "TORTOLA",
        "country": "VG"
    },
    "000F2D": {
        "oui_hex": "00-0F-2D",
        "organization": "CHUNG-HSIN ELECTRIC & MACHINERY MFG.CORP.",
        "address_1": "NO. 25, Wen-Te Rd., Lo-Shan Village",
        "address_2": "Kwei Shan Hsiang  Taoyuan Hsien  330",
        "country": "TW"
    },
    "000EF7": {
        "oui_hex": "00-0E-F7",
        "organization": "Vulcan Portals Inc",
        "address_1": "505 5th Ave South, Suite 900",
        "address_2": "Seattle  WA  98104",
        "country": "US"
    },
    "000EF0": {
        "oui_hex": "00-0E-F0",
        "organization": "Festo AG & Co. KG",
        "address_1": "Ruiterstraße 82",
        "address_2": "Esslingen    73734",
        "country": "DE"
    },
    "000EE9": {
        "oui_hex": "00-0E-E9",
        "organization": "WayTech Development, Inc.",
        "address_1": "11Floor, 253 Min-Sheng Road",
        "address_2": "HsinChu    300",
        "country": "TW"
    },
    "000F40": {
        "oui_hex": "00-0F-40",
        "organization": "Optical Internetworking Forum",
        "address_1": "48377 Fremont Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000F33": {
        "oui_hex": "00-0F-33",
        "organization": "DUALi Inc.",
        "address_1": "#505 Samsung Techno Park Bldg 471",
        "address_2": "Suwon  Gyeonggi-do  442-824",
        "country": "KR"
    },
    "000F05": {
        "oui_hex": "00-0F-05",
        "organization": "3B SYSTEM INC.",
        "address_1": "1727, SANKYUK2-DONG, BUK-GU",
        "address_2": "DAEGU    702-845",
        "country": "KR"
    },
    "000EC9": {
        "oui_hex": "00-0E-C9",
        "organization": "YOKO Technology Corp.",
        "address_1": "6F, No.10, Lane16, Sec2, Sze-Chuan Rd., Pan-",
        "address_2": "Taipei    886",
        "country": "TW"
    },
    "000EBD": {
        "oui_hex": "00-0E-BD",
        "organization": "Burdick, a Quinton Compny",
        "address_1": "500 Burdick Parkway",
        "address_2": "Deerfield  WI  53531",
        "country": "US"
    },
    "000EB9": {
        "oui_hex": "00-0E-B9",
        "organization": "HASHIMOTO Electronics Industry Co.,Ltd.",
        "address_1": "3866-12 Takasu-cho",
        "address_2": "Matsusaka  Mie  515-0104",
        "country": "JP"
    },
    "000EB2": {
        "oui_hex": "00-0E-B2",
        "organization": "Micro-Research Finland Oy",
        "address_1": "Välitalontie 83 C",
        "address_2": "Helsinki    FIN-00660",
        "country": "FI"
    },
    "000ED0": {
        "oui_hex": "00-0E-D0",
        "organization": "Privaris, Inc.",
        "address_1": "675 Peter Jefferson Pkwy, Ste 150",
        "address_2": "Charlottesville  Virginia  22911",
        "country": "US"
    },
    "000EC3": {
        "oui_hex": "00-0E-C3",
        "organization": "Logic Controls, Inc.",
        "address_1": "355 Denton Avenue",
        "address_2": "New Hyde Park  NY  11040",
        "country": "US"
    },
    "000EC4": {
        "oui_hex": "00-0E-C4",
        "organization": "Iskra Transmission d.d.",
        "address_1": "Stegne 11",
        "address_2": "Ljubljana    1000",
        "country": "SI"
    },
    "000EC1": {
        "oui_hex": "00-0E-C1",
        "organization": "MYNAH Technologies",
        "address_1": "504 Trade Center Blvd",
        "address_2": "Chesterfield  MO  63005",
        "country": "US"
    },
    "000E82": {
        "oui_hex": "00-0E-82",
        "organization": "Commtech Wireless",
        "address_1": "115/396 Scarborough Beach Rd",
        "address_2": "Perth  WA  6017",
        "country": "AU"
    },
    "000E89": {
        "oui_hex": "00-0E-89",
        "organization": "CLEMATIC",
        "address_1": "101 rue Pierre SEMARD",
        "address_2": "CHATILLON  R.P.  92320",
        "country": "US"
    },
    "000E79": {
        "oui_hex": "00-0E-79",
        "organization": "Ample Communications Inc.",
        "address_1": "4034 Clipper Ct.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000EA1": {
        "oui_hex": "00-0E-A1",
        "organization": "Formosa Teletek Corporation",
        "address_1": "358,Huaya 2nd Rd.",
        "address_2": "Taoyuan    333",
        "country": "TW"
    },
    "000E98": {
        "oui_hex": "00-0E-98",
        "organization": "HME Clear-Com LTD.",
        "address_1": "7400 Beach Drive",
        "address_2": "Cambridgeshire    CB25 9TP",
        "country": "GB"
    },
    "000E99": {
        "oui_hex": "00-0E-99",
        "organization": "Spectrum Digital, Inc",
        "address_1": "12502 Exchange Drive, Suite 440",
        "address_2": "Stafford  TX  77477",
        "country": "US"
    },
    "000E95": {
        "oui_hex": "00-0E-95",
        "organization": "Fujiya Denki Seisakusho Co.,Ltd.",
        "address_1": "8F Fukushima BLDG. 6-25-11,Nishi-Gotanda",
        "address_2": "Shinagawa-Ku  Tokyo  141-0031",
        "country": "JP"
    },
    "000E97": {
        "oui_hex": "00-0E-97",
        "organization": "Ultracker Technology CO., Inc",
        "address_1": "14F-1, No. 888, Jingguo Road, Taoyuan City,",
        "address_2": "Taoyuan    330",
        "country": "TW"
    },
    "000EA7": {
        "oui_hex": "00-0E-A7",
        "organization": "Endace Technology",
        "address_1": "85 Alexandra Street",
        "address_2": "Hamilton    3204",
        "country": "NZ"
    },
    "000E6F": {
        "oui_hex": "00-0E-6F",
        "organization": "IRIS Corporation Berhad",
        "address_1": "IRIS Smart Technology Complex",
        "address_2": "Kuala Lumpur  WP  57000",
        "country": "MY"
    },
    "000EB5": {
        "oui_hex": "00-0E-B5",
        "organization": "Ecastle Electronics Co., Ltd.",
        "address_1": "#502, Namjang B/D, Bangbae-dong,",
        "address_2": "Seoul    137-818",
        "country": "KR"
    },
    "000E50": {
        "oui_hex": "00-0E-50",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "000E4B": {
        "oui_hex": "00-0E-4B",
        "organization": "atrium c and i",
        "address_1": "124-4, Ojeon-dong,",
        "address_2": "Uiwang-city  Kyunggi-Do  437-819",
        "country": "KR"
    },
    "000E2B": {
        "oui_hex": "00-0E-2B",
        "organization": "Safari Technologies",
        "address_1": "63855 M40 Hwy",
        "address_2": "Lawton  MI  49065",
        "country": "US"
    },
    "000E28": {
        "oui_hex": "00-0E-28",
        "organization": "Dynamic Ratings P/L",
        "address_1": "C/O Wilson Transformer Co.",
        "address_2": "Glen Waverley  Victoria  3150",
        "country": "AU"
    },
    "000E24": {
        "oui_hex": "00-0E-24",
        "organization": "Huwell Technology Inc.",
        "address_1": "1F 82-21, Majin Building",
        "address_2": "Seoul    135-010",
        "country": "KR"
    },
    "000E3F": {
        "oui_hex": "00-0E-3F",
        "organization": "Soronti, Inc.",
        "address_1": "12159 Business Park Dr, Suite 140",
        "address_2": "Draper  Utah  84020",
        "country": "US"
    },
    "000E45": {
        "oui_hex": "00-0E-45",
        "organization": "Beijing Newtry Electronic Technology Ltd",
        "address_1": "PO Box 95, No. 1 Bei Sha Tan,",
        "address_2": "Beijing    10083",
        "country": "CN"
    },
    "000E1D": {
        "oui_hex": "00-0E-1D",
        "organization": "ARION Technology Inc.",
        "address_1": "3F, Pica Bldg, 894-2, Hogye 2 Dong",
        "address_2": "An-Yang City  Gyeonggi-Do",
        "country": "KR"
    },
    "000E12": {
        "oui_hex": "00-0E-12",
        "organization": "Adaptive Micro Systems Inc.",
        "address_1": "7840 North 86th St.",
        "address_2": "Milwaukee  WI  53224",
        "country": "US"
    },
    "000E4F": {
        "oui_hex": "00-0E-4F",
        "organization": "Trajet GmbH",
        "address_1": "Rebenring 33",
        "address_2": "Braunschweig  Nds.  38106",
        "country": "DE"
    },
    "000E38": {
        "oui_hex": "00-0E-38",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E36": {
        "oui_hex": "00-0E-36",
        "organization": "HEINESYS, Inc.",
        "address_1": "3F, Sungkwang Bldg. 456-13, Sungnae-dong",
        "address_2": "Seoul    134-848",
        "country": "KR"
    },
    "000E17": {
        "oui_hex": "00-0E-17",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000E15": {
        "oui_hex": "00-0E-15",
        "organization": "Tadlys LTD",
        "address_1": "ISRAELI SHIMON 3",
        "address_2": "RISHON lEZYYON  ISRAEL  75654",
        "country": "US"
    },
    "000E01": {
        "oui_hex": "00-0E-01",
        "organization": "ASIP Technologies Inc.",
        "address_1": "10F-2, NO.322, Sec.1, Guangfu Rd.,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000DCB": {
        "oui_hex": "00-0D-CB",
        "organization": "Petcomkorea Co., Ltd.",
        "address_1": "5F,689-47,Geumjeong-dong,Gunpo-si,Kyungg",
        "address_2": "Kyunggi-do  gunpo-si  435-050",
        "country": "KR"
    },
    "000DCC": {
        "oui_hex": "00-0D-CC",
        "organization": "NEOSMART Corp.",
        "address_1": "Yoon-B/D 4F, 475-31, Bangbae 2-dong",
        "address_2": "Seoul  Seocho-gu  147-819",
        "country": "KR"
    },
    "000DCE": {
        "oui_hex": "00-0D-CE",
        "organization": "Dynavac Technology Pte Ltd",
        "address_1": "30 Tuas Avenue 9",
        "address_2": "    639183",
        "country": "SG"
    },
    "000DE8": {
        "oui_hex": "00-0D-E8",
        "organization": "Nasaco Electronics Pte. Ltd",
        "address_1": "Level 4, Nasaco Tech Centre",
        "address_2": "    486056",
        "country": "SG"
    },
    "000DE9": {
        "oui_hex": "00-0D-E9",
        "organization": "Napatech Aps",
        "address_1": "Rundofrbivej 271, 1",
        "address_2": "Naerum    2850",
        "country": "DK"
    },
    "000DE6": {
        "oui_hex": "00-0D-E6",
        "organization": "YOUNGBO ENGINEERING CO.,LTD",
        "address_1": "Mt.22, Jaeunga-ri, Jigsan-Eup,",
        "address_2": "Cheonan-shi  Chungcheongnam-do  #330-810",
        "country": "KR"
    },
    "000DC3": {
        "oui_hex": "00-0D-C3",
        "organization": "First Communication, Inc.",
        "address_1": "1F, No.36, Industry E. Rd. IV.,",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "000DB9": {
        "oui_hex": "00-0D-B9",
        "organization": "PC Engines GmbH",
        "address_1": "Flughofstrasse 58",
        "address_2": "8152  Glattbrugg",
        "country": "CH"
    },
    "000DB7": {
        "oui_hex": "00-0D-B7",
        "organization": "SANKO ELECTRIC CO,.LTD",
        "address_1": "7-23 Tamanoi-cho Atsuta-ku",
        "address_2": "Nagoya-shi  Aichi  456-0025",
        "country": "JP"
    },
    "000DAC": {
        "oui_hex": "00-0D-AC",
        "organization": "Japan CBM Corporation",
        "address_1": "5-68-10 Nakano,",
        "address_2": "Nakano-Ku  Tokyo  164-0001",
        "country": "JP"
    },
    "000DDF": {
        "oui_hex": "00-0D-DF",
        "organization": "Japan Image & Network Inc.",
        "address_1": "5-29-12 Shiba",
        "address_2": "Minato-ku  Tokyo  108-0014",
        "country": "JP"
    },
    "000DDB": {
        "oui_hex": "00-0D-DB",
        "organization": "AIRWAVE TECHNOLOGIES INC.",
        "address_1": "3F,No.9,Industry E. 9th Road",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000E04": {
        "oui_hex": "00-0E-04",
        "organization": "CMA/Microdialysis AB",
        "address_1": "Dalvägen  10 / Box 2",
        "address_2": "Solna    171 18",
        "country": "SE"
    },
    "000D2A": {
        "oui_hex": "00-0D-2A",
        "organization": "Scanmatic AS",
        "address_1": "Kilsund",
        "address_2": "Staubø    4920",
        "country": "NO"
    },
    "000D29": {
        "oui_hex": "00-0D-29",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000D26": {
        "oui_hex": "00-0D-26",
        "organization": "Primagraphics Limited",
        "address_1": "Cambridge House, No.2 Focus Four",
        "address_2": "Letchworth Garden City  Hertfordshire  SG6 2TU",
        "country": "GB"
    },
    "000D46": {
        "oui_hex": "00-0D-46",
        "organization": "Parker SSD Drives",
        "address_1": "9225 Forsyth Park Drive",
        "address_2": "Charlotte  NC  28273-3884",
        "country": "US"
    },
    "000D41": {
        "oui_hex": "00-0D-41",
        "organization": "Siemens AG ICM MP UC RD IT KLF1",
        "address_1": "Suedstrasse 9",
        "address_2": "Kamp-Lintfort  NRW  47475",
        "country": "DE"
    },
    "000D42": {
        "oui_hex": "00-0D-42",
        "organization": "Newbest Development Limited",
        "address_1": "3/F  Unit 311-312",
        "address_2": "  Shatin  NT",
        "country": "HK"
    },
    "000D3C": {
        "oui_hex": "00-0D-3C",
        "organization": "i.Tech Dynamic Ltd",
        "address_1": "Room 1112, Metroplaza Tower 2, 223 Hing",
        "address_2": "    852",
        "country": "HK"
    },
    "000D55": {
        "oui_hex": "00-0D-55",
        "organization": "SANYCOM Technology Co.,Ltd",
        "address_1": "6F,Beijing Capital Times Square,88# Xich",
        "address_2": "Beijing    100031",
        "country": "CN"
    },
    "000D57": {
        "oui_hex": "00-0D-57",
        "organization": "Fujitsu I-Network Systems Limited.",
        "address_1": "1-403 kosugi-cho nakahara-ku",
        "address_2": "kawasaki  kanagawa  211-0063",
        "country": "JP"
    },
    "000D58": {
        "oui_hex": "00-0D-58",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000D51": {
        "oui_hex": "00-0D-51",
        "organization": "DIVR Systems, Inc.",
        "address_1": "2161 Saturn Ct.",
        "address_2": "Bakersfield  CA  93308",
        "country": "US"
    },
    "000D39": {
        "oui_hex": "00-0D-39",
        "organization": "Network Electronics",
        "address_1": "Box 1020",
        "address_2": "Sandefjord  Sandefjord  N3204",
        "country": "NO"
    },
    "000D35": {
        "oui_hex": "00-0D-35",
        "organization": "PAC International Ltd",
        "address_1": "1 Park Gate Close",
        "address_2": "Stockport  Cheshire  SK6 2SZ",
        "country": "GB"
    },
    "000D95": {
        "oui_hex": "00-0D-95",
        "organization": "Opti-cell, Inc.",
        "address_1": "100 High Tower Blvd.,  Suite 301",
        "address_2": "Pittsburgh  PA  15205",
        "country": "US"
    },
    "000D91": {
        "oui_hex": "00-0D-91",
        "organization": "Eclipse (HQ Espana) S.L.",
        "address_1": "CC de Negocios",
        "address_2": "Puerto de Banus  Marbella  29660",
        "country": "ES"
    },
    "000D62": {
        "oui_hex": "00-0D-62",
        "organization": "Funkwerk Dabendorf GmbH",
        "address_1": "Maerkische Strasse",
        "address_2": "Dabendorf  Brandenburg  15806",
        "country": "DE"
    },
    "000D65": {
        "oui_hex": "00-0D-65",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000D45": {
        "oui_hex": "00-0D-45",
        "organization": "Tottori SANYO Electric Co., Ltd.",
        "address_1": "3-201, Minami Yoshikata",
        "address_2": "Tottori City  Tottori  680-8634",
        "country": "JP"
    },
    "000DA1": {
        "oui_hex": "00-0D-A1",
        "organization": "MIRAE ITS Co.,LTD.",
        "address_1": "7F, ChangHyun B/D,960-1,HoGye1Dong",
        "address_2": "AnYang  KyongiGiDo  431-840",
        "country": "KR"
    },
    "000D80": {
        "oui_hex": "00-0D-80",
        "organization": "Online Development Inc",
        "address_1": "7209 Chapman Hwy",
        "address_2": "Knoxville  Tn  37920",
        "country": "US"
    },
    "000D13": {
        "oui_hex": "00-0D-13",
        "organization": "Wilhelm Rutenbeck GmbH&Co.KG",
        "address_1": "Niederworth 1-10",
        "address_2": "Schalksmühle  NRW  58579",
        "country": "DE"
    },
    "000D19": {
        "oui_hex": "00-0D-19",
        "organization": "ROBE Show lighting",
        "address_1": "Hazovice 2090",
        "address_2": "Roznov pod Radhostem    756 61",
        "country": "US"
    },
    "000D1C": {
        "oui_hex": "00-0D-1C",
        "organization": "Amesys Defense",
        "address_1": "1030 Av de la LAUZIERE",
        "address_2": "AIX en PROVENCE  Cedex 03  13794",
        "country": "FR"
    },
    "000CED": {
        "oui_hex": "00-0C-ED",
        "organization": "Real Digital Media",
        "address_1": "485 North Keller Road",
        "address_2": "Maitland  FL  32751",
        "country": "US"
    },
    "000CF0": {
        "oui_hex": "00-0C-F0",
        "organization": "M & N GmbH",
        "address_1": "Dieselstr 18",
        "address_2": "Rosbach v.d.H.    61191",
        "country": "DE"
    },
    "000CF4": {
        "oui_hex": "00-0C-F4",
        "organization": "AKATSUKI ELECTRIC MFG.CO.,LTD.",
        "address_1": "593-1,aoji­ cho",
        "address_2": "kusatsu shi  shiga  525-0041",
        "country": "JP"
    },
    "000CF3": {
        "oui_hex": "00-0C-F3",
        "organization": "CALL IMAGE SA",
        "address_1": "867 Route Imperiale",
        "address_2": "BAILLARGUES    34670",
        "country": "FR"
    },
    "000CCF": {
        "oui_hex": "00-0C-CF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000CD8": {
        "oui_hex": "00-0C-D8",
        "organization": "M. K. Juchheim GmbH & Co",
        "address_1": "Moltkestraße 13 - 31",
        "address_2": "Fulda  Hessen  36039",
        "country": "DE"
    },
    "000CC6": {
        "oui_hex": "00-0C-C6",
        "organization": "Ka-Ro electronics GmbH",
        "address_1": "Pascalstraße 22",
        "address_2": "Aachen  NW  52076",
        "country": "DE"
    },
    "000D01": {
        "oui_hex": "00-0D-01",
        "organization": "P&E Microcomputer Systems, Inc.",
        "address_1": "710 Commonwealth Ave",
        "address_2": "Boston  Ma  02215",
        "country": "US"
    },
    "000D00": {
        "oui_hex": "00-0D-00",
        "organization": "Seaway Networks Inc.",
        "address_1": "1 Chrysalis Way",
        "address_2": "Ottawa  Ontario  K2G 6P9",
        "country": "CA"
    },
    "000CF9": {
        "oui_hex": "00-0C-F9",
        "organization": "Xylem Water Solutions",
        "address_1": "Gesallvagen",
        "address_2": "",
        "country": "SE"
    },
    "000CC4": {
        "oui_hex": "00-0C-C4",
        "organization": "Tiptel AG",
        "address_1": "Halskestrasse 1",
        "address_2": "Ratingen  NRW  40880",
        "country": "DE"
    },
    "000CBA": {
        "oui_hex": "00-0C-BA",
        "organization": "Jamex, Inc.",
        "address_1": "2415 N Triphammer Rd",
        "address_2": "Ithaca  NY  14850",
        "country": "US"
    },
    "000CD1": {
        "oui_hex": "00-0C-D1",
        "organization": "SFOM Technology Corp.",
        "address_1": "No.18, Lane 32, Wufu 1st Rd., Luju shian",
        "address_2": "Luju Shiang  Tauyuan County  338",
        "country": "TW"
    },
    "000CCE": {
        "oui_hex": "00-0C-CE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000CE0": {
        "oui_hex": "00-0C-E0",
        "organization": "Trek Diagnostics Inc.",
        "address_1": "982 Keynote Circle",
        "address_2": "Cleveland  Ohio  44131",
        "country": "US"
    },
    "000CE2": {
        "oui_hex": "00-0C-E2",
        "organization": "Rolls-Royce",
        "address_1": "105 N. Sandusky St.",
        "address_2": "Mt. Vernon  Ohio  43050",
        "country": "US"
    },
    "000D0C": {
        "oui_hex": "00-0D-0C",
        "organization": "MDI Security Systems",
        "address_1": "9518 Ninth Street",
        "address_2": "Rancho Cucamonga  CA  91730",
        "country": "US"
    },
    "000D16": {
        "oui_hex": "00-0D-16",
        "organization": "UHS Systems Pty Ltd",
        "address_1": "PO Box 6264",
        "address_2": "Alexandria  NSW  2015",
        "country": "AU"
    },
    "000D1F": {
        "oui_hex": "00-0D-1F",
        "organization": "AV Digital",
        "address_1": "Pottendorfer Strasse 25-27/4/1/1",
        "address_2": "Wien    1120",
        "country": "AT"
    },
    "000CAD": {
        "oui_hex": "00-0C-AD",
        "organization": "BTU International",
        "address_1": "23 Esquire Rd",
        "address_2": "North Billerica  MA  01862",
        "country": "US"
    },
    "000CAA": {
        "oui_hex": "00-0C-AA",
        "organization": "Cubic Transportation Systems Inc",
        "address_1": "1308 S. Washington Street",
        "address_2": "Tullahoma  TN  37388",
        "country": "US"
    },
    "000CAC": {
        "oui_hex": "00-0C-AC",
        "organization": "Citizen Watch Co., Ltd.",
        "address_1": "6-1-12, Tanashi-cho",
        "address_2": "Nishi-Tokyo-shi  Tokyo  188-8511",
        "country": "JP"
    },
    "000CAE": {
        "oui_hex": "00-0C-AE",
        "organization": "Ailocom Oy",
        "address_1": "Hatanpaan valtatie 24",
        "address_2": "TAMPERE  FIN  33950",
        "country": "FI"
    },
    "000CA3": {
        "oui_hex": "00-0C-A3",
        "organization": "Rancho Technology, Inc.",
        "address_1": "10783 Bell Court",
        "address_2": "Rancho Cucamonga  CA  19730",
        "country": "US"
    },
    "000C9C": {
        "oui_hex": "00-0C-9C",
        "organization": "Chongho information & communications",
        "address_1": "Chongho Bldg, #7-61 Yangjae-dong, Seocho",
        "address_2": "Seoul    137-130",
        "country": "KR"
    },
    "000C97": {
        "oui_hex": "00-0C-97",
        "organization": "NV ADB TTV Technologies SA",
        "address_1": "LEUVENSESTEENWEG,585",
        "address_2": "ZAVENTEM  Vlaamse brabant  1930",
        "country": "BE"
    },
    "000C8F": {
        "oui_hex": "00-0C-8F",
        "organization": "Nergal s.r.l.",
        "address_1": "Viale Bardanzellu,8",
        "address_2": "Roma    00155",
        "country": "IT"
    },
    "000C92": {
        "oui_hex": "00-0C-92",
        "organization": "WolfVision Gmbh",
        "address_1": "VWP",
        "address_2": "Goetzis  Vorarlberg  A-6840",
        "country": "AT"
    },
    "000C93": {
        "oui_hex": "00-0C-93",
        "organization": "Xeline Co., Ltd.",
        "address_1": "7F. Chungjin Bldg., 475-22",
        "address_2": "Seoul    137-819",
        "country": "KR"
    },
    "000C7F": {
        "oui_hex": "00-0C-7F",
        "organization": "synertronixx GmbH",
        "address_1": "Lange Laube 22",
        "address_2": "Hannover  Niedersachsen  30159",
        "country": "DE"
    },
    "000C81": {
        "oui_hex": "00-0C-81",
        "organization": "Schneider Electric (Australia)",
        "address_1": "80 Schneider Road",
        "address_2": "Eagle Farm   Qld  4009",
        "country": "AU"
    },
    "000C9E": {
        "oui_hex": "00-0C-9E",
        "organization": "MemoryLink Corp.",
        "address_1": "36 Jewelers Park Drive",
        "address_2": "Neenah  Wisconsin  54957",
        "country": "US"
    },
    "000C95": {
        "oui_hex": "00-0C-95",
        "organization": "PrimeNet",
        "address_1": "Hongik University, 72-1, Sangsu-Dong, Ma",
        "address_2": "Seoul    121-791",
        "country": "KR"
    },
    "000C76": {
        "oui_hex": "00-0C-76",
        "organization": "MICRO-STAR INTERNATIONAL CO., LTD.",
        "address_1": "No 69, Li-De Street, Jung-He City, Taipe",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000C80": {
        "oui_hex": "00-0C-80",
        "organization": "Opelcomm Inc.",
        "address_1": "46750 Fremont Blvd. Ste 210",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000C7D": {
        "oui_hex": "00-0C-7D",
        "organization": "TEIKOKU ELECTRIC MFG. CO., LTD",
        "address_1": "60,HIRANO",
        "address_2": "IBO-GUN  HYOGO  679-4395",
        "country": "JP"
    },
    "000CB7": {
        "oui_hex": "00-0C-B7",
        "organization": "Nanjing Huazhuo Electronics Co., Ltd.",
        "address_1": "No.77 Gaohu Road",
        "address_2": "Nanjing  Jiangsu  211100",
        "country": "CN"
    },
    "000C68": {
        "oui_hex": "00-0C-68",
        "organization": "SigmaTel, Inc.",
        "address_1": "201 Jones Road",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "000C07": {
        "oui_hex": "00-0C-07",
        "organization": "Iftest AG",
        "address_1": "Schwimmbadstrasse 43",
        "address_2": "Wettingen  AG  5430",
        "country": "CH"
    },
    "000C0C": {
        "oui_hex": "00-0C-0C",
        "organization": "APPRO TECHNOLOGY INC.",
        "address_1": "13F, No. 66 Chung-Cheng Rd,",
        "address_2": "Hsin-Chuang  Taipei  242",
        "country": "TW"
    },
    "000C0E": {
        "oui_hex": "00-0C-0E",
        "organization": "XtremeSpectrum, Inc.",
        "address_1": "8133 Leesburg Pike",
        "address_2": "Vienna  VA  22182",
        "country": "US"
    },
    "000C12": {
        "oui_hex": "00-0C-12",
        "organization": "Micro-Optronic-Messtechnik GmbH",
        "address_1": "Lessingstrasse 14",
        "address_2": "Langebrück  Saxony  D-01465",
        "country": "DE"
    },
    "000C10": {
        "oui_hex": "00-0C-10",
        "organization": "PNI Corporation",
        "address_1": "5464 Skylane Blvd #A",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "000C40": {
        "oui_hex": "00-0C-40",
        "organization": "Altech Controls",
        "address_1": "1545 Industial Drive",
        "address_2": "Missouri City  Texas  77489",
        "country": "US"
    },
    "000C3E": {
        "oui_hex": "00-0C-3E",
        "organization": "Crest Audio",
        "address_1": "16-00 Pollitt Drive",
        "address_2": "Fair Lawn  NJ  07410",
        "country": "US"
    },
    "000C3A": {
        "oui_hex": "00-0C-3A",
        "organization": "Oxance",
        "address_1": "75-85 rue Richelieu",
        "address_2": "les Lucs sur Boulogne    85170",
        "country": "FR"
    },
    "000C35": {
        "oui_hex": "00-0C-35",
        "organization": "KaVo Dental GmbH & Co. KG",
        "address_1": "Bismarkring 39",
        "address_2": "Biberach/Riss  Baden-Württemberg  88400",
        "country": "DE"
    },
    "000C56": {
        "oui_hex": "00-0C-56",
        "organization": "Megatel Computer (1986) Corp.",
        "address_1": "586 Main Street",
        "address_2": "Glen Williams  Ontario  L7G 3T6",
        "country": "CA"
    },
    "000C57": {
        "oui_hex": "00-0C-57",
        "organization": "MACKIE Engineering Services Belgium BVBA",
        "address_1": "Industriepark Noord 10",
        "address_2": "Sint Niklaas    B-9100",
        "country": "BE"
    },
    "000C23": {
        "oui_hex": "00-0C-23",
        "organization": "Beijing Lanchuan Tech. Co., Ltd.",
        "address_1": "Rm220,No.30 Shangyuancun,Gaoliangqiaolu,",
        "address_2": "Beijing    100044",
        "country": "CN"
    },
    "000C25": {
        "oui_hex": "00-0C-25",
        "organization": "Allied Telesis Labs, Inc.",
        "address_1": "Suite 450",
        "address_2": "Raleigh  NC  27606",
        "country": "US"
    },
    "000C18": {
        "oui_hex": "00-0C-18",
        "organization": "Zenisu Keisoku Inc.",
        "address_1": "2-13-37",
        "address_2": "Fuchu-shi  Tokyo  183-0027",
        "country": "JP"
    },
    "000C0A": {
        "oui_hex": "00-0C-0A",
        "organization": "Guangdong Province Electronic Technology Research Institute",
        "address_1": "Electronic Technology Building,NO.61-65,",
        "address_2": "Guangzhou  Guangdong  510630",
        "country": "CN"
    },
    "000C0B": {
        "oui_hex": "00-0C-0B",
        "organization": "Broadbus Technologies",
        "address_1": "80 Central Street",
        "address_2": "Boxborough  Massachusetts  01719",
        "country": "US"
    },
    "000C4A": {
        "oui_hex": "00-0C-4A",
        "organization": "Cygnus Microsystems (P) Limited",
        "address_1": "93, Phase II,",
        "address_2": "Hyderabad  Andhra Pradesh  500051",
        "country": "IN"
    },
    "000C54": {
        "oui_hex": "00-0C-54",
        "organization": "Pedestal Networks, Inc",
        "address_1": "6503 Dumbarton Circle",
        "address_2": "Fremont  CA  94555",
        "country": "US"
    },
    "000C37": {
        "oui_hex": "00-0C-37",
        "organization": "Geomation, Inc.",
        "address_1": "25188 Genesee Trail Road",
        "address_2": "Golden  CO  80401",
        "country": "US"
    },
    "000BE8": {
        "oui_hex": "00-0B-E8",
        "organization": "AOIP",
        "address_1": "6 rue Maryse BASTIE",
        "address_2": "COURCOURONNES  Idf  91080",
        "country": "FR"
    },
    "000BDC": {
        "oui_hex": "00-0B-DC",
        "organization": "AKCP",
        "address_1": "67/285  Muangake Village #8",
        "address_2": "Amphur Muang  Patomthanee  12000",
        "country": "TH"
    },
    "000BD8": {
        "oui_hex": "00-0B-D8",
        "organization": "Industrial Scientific Corp.",
        "address_1": "1001 Oakdale Road",
        "address_2": "Oakdale  PA  15071",
        "country": "US"
    },
    "000BD7": {
        "oui_hex": "00-0B-D7",
        "organization": "DORMA Time + Access GmbH",
        "address_1": "Mainzer Straße 36-52",
        "address_2": "Bonn  Nordrheinwestfalen  53179",
        "country": "DE"
    },
    "000BDD": {
        "oui_hex": "00-0B-DD",
        "organization": "TOHOKU RICOH Co., LTD.",
        "address_1": "3-1 Shinmeido",
        "address_2": "Shibata  Miyagi pref.  989-1695",
        "country": "JP"
    },
    "000BE5": {
        "oui_hex": "00-0B-E5",
        "organization": "HIMS International Corporation",
        "address_1": "139-9",
        "address_2": "Daejeon  Daejeon  305-806",
        "country": "KR"
    },
    "000BE9": {
        "oui_hex": "00-0B-E9",
        "organization": "Actel Corporation",
        "address_1": "200 Valley Road",
        "address_2": "Mt. Arlington  NJ  07856",
        "country": "US"
    },
    "000BE3": {
        "oui_hex": "00-0B-E3",
        "organization": "Key Stream Co., Ltd.",
        "address_1": "No. 2 Nagaoka Bldg. 4F,  2-8-5 Hatchobor",
        "address_2": "Chuo-ku  Tokyo  104-0032",
        "country": "JP"
    },
    "000BD3": {
        "oui_hex": "00-0B-D3",
        "organization": "cd3o",
        "address_1": "402 W Broadway",
        "address_2": "San Deigo  CA  92101",
        "country": "US"
    },
    "000BD5": {
        "oui_hex": "00-0B-D5",
        "organization": "Nvergence, Inc.",
        "address_1": "Jeil Bldg. 4th, Samsung-dong 168-26, Kan",
        "address_2": "Seoul    135-090",
        "country": "KR"
    },
    "000BD1": {
        "oui_hex": "00-0B-D1",
        "organization": "Aeronix, Inc.",
        "address_1": "1775 W. Hibiscus Blvd,",
        "address_2": "Melbourne  FL  32901",
        "country": "US"
    },
    "000BD2": {
        "oui_hex": "00-0B-D2",
        "organization": "Remopro Technology Inc.",
        "address_1": "No. 443, Huannan RD.,",
        "address_2": "Pingjen City  Taoyuan  324",
        "country": "TW"
    },
    "000BC7": {
        "oui_hex": "00-0B-C7",
        "organization": "ICET S.p.A.",
        "address_1": "Via Quarto Negroni, 63",
        "address_2": "Cecchina di Ariccia  Roma  00040",
        "country": "IT"
    },
    "000BB8": {
        "oui_hex": "00-0B-B8",
        "organization": "Kihoku Electronic Co.",
        "address_1": "Marukatubiru 3F 4-9-6",
        "address_2": "Osakashi  Osaka-hu  556-0005",
        "country": "JP"
    },
    "000BC0": {
        "oui_hex": "00-0B-C0",
        "organization": "China IWNComm Co., Ltd.",
        "address_1": "4F.C Xietong Building,No.12 Gaoxin 2nd r",
        "address_2": "Xi'an  shaanxi  710075",
        "country": "CN"
    },
    "000BB0": {
        "oui_hex": "00-0B-B0",
        "organization": "Sysnet Telematica srl",
        "address_1": "Viale Berbera, 49",
        "address_2": "Milan    20162",
        "country": "IT"
    },
    "000BB4": {
        "oui_hex": "00-0B-B4",
        "organization": "RDC Semiconductor Inc.,",
        "address_1": "6F-1 , No.2-1, Lihsin Rd, Science-Based",
        "address_2": "Hsin Chu    300",
        "country": "TW"
    },
    "000BCC": {
        "oui_hex": "00-0B-CC",
        "organization": "JUSAN, S.A.",
        "address_1": "Vivero, 5",
        "address_2": "MADRID    28040",
        "country": "ES"
    },
    "000BAC": {
        "oui_hex": "00-0B-AC",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "000BF9": {
        "oui_hex": "00-0B-F9",
        "organization": "Gemstone Communications, Inc.",
        "address_1": "6Fl., No. 102,  Hengyang Rd.",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "000BFC": {
        "oui_hex": "00-0B-FC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BEA": {
        "oui_hex": "00-0B-EA",
        "organization": "Zultys Technologies",
        "address_1": "785 Lucern Drive",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "000B9F": {
        "oui_hex": "00-0B-9F",
        "organization": "Neue ELSA GmbH",
        "address_1": "Sonnenweg 11",
        "address_2": "Aachen    52070",
        "country": "DE"
    },
    "000B98": {
        "oui_hex": "00-0B-98",
        "organization": "NiceTechVision",
        "address_1": "IntelZone 703",
        "address_2": "YongIn  Gugal-ri  Ki Heung  KyoungKiDo  354-2",
        "country": "KR"
    },
    "000B95": {
        "oui_hex": "00-0B-95",
        "organization": "eBet Gaming Systems Pty Ltd",
        "address_1": "Suite D, 255 Rawson Street",
        "address_2": "Auburn  NSW  2144",
        "country": "AU"
    },
    "000B9E": {
        "oui_hex": "00-0B-9E",
        "organization": "Yasing Technology Corp.",
        "address_1": "No. 50, Ta Hsueh Road, HsinChu, Taiwan",
        "address_2": "HsinChu    300",
        "country": "TW"
    },
    "000B88": {
        "oui_hex": "00-0B-88",
        "organization": "Vidisco ltd.",
        "address_1": "17 Yechiel Dresner",
        "address_2": "Petach-Tikva    49277",
        "country": "IL"
    },
    "000B54": {
        "oui_hex": "00-0B-54",
        "organization": "BiTMICRO Networks, Inc.",
        "address_1": "47929 Fremont Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000B8C": {
        "oui_hex": "00-0B-8C",
        "organization": "Flextronics",
        "address_1": "Migdal HaEmek",
        "address_2": "23108  Hataasia 1",
        "country": "IL"
    },
    "000B8A": {
        "oui_hex": "00-0B-8A",
        "organization": "MITEQ Inc.",
        "address_1": "100 Davids Drive",
        "address_2": "Hauppauge  NY  11788-2034",
        "country": "US"
    },
    "000B90": {
        "oui_hex": "00-0B-90",
        "organization": "ADVA Optical Networking Ltd.",
        "address_1": "ADVAntage House",
        "address_2": "York    YO30 4RY",
        "country": "GB"
    },
    "000B79": {
        "oui_hex": "00-0B-79",
        "organization": "X-COM, Inc.",
        "address_1": "8809 Sudley Road",
        "address_2": "Manassas  VA  20110",
        "country": "US"
    },
    "000B4B": {
        "oui_hex": "00-0B-4B",
        "organization": "VISIOWAVE SA",
        "address_1": "Route de la Pierre 22",
        "address_2": "ECUBLENS  VAUD  CH-1024",
        "country": "CH"
    },
    "000B36": {
        "oui_hex": "00-0B-36",
        "organization": "Productivity Systems, Inc.",
        "address_1": "1711 Analog Drive",
        "address_2": "Richardson  TX  75081-1944",
        "country": "US"
    },
    "000B35": {
        "oui_hex": "00-0B-35",
        "organization": "Quad Bit System co., Ltd.",
        "address_1": "402 Gayang Technotown",
        "address_2": "Seoul  Kangseogu  157-810",
        "country": "KR"
    },
    "000B75": {
        "oui_hex": "00-0B-75",
        "organization": "Iosoft Ltd.",
        "address_1": "5 Woodlark Road",
        "address_2": "Cambridge  Cambs.  CB3 0HT",
        "country": "GB"
    },
    "000B70": {
        "oui_hex": "00-0B-70",
        "organization": "Load Technology, Inc.",
        "address_1": "4225 Production Court",
        "address_2": "Las Vegas  NV  89115",
        "country": "US"
    },
    "000B6F": {
        "oui_hex": "00-0B-6F",
        "organization": "Media Streaming Networks Inc",
        "address_1": "1905 Anam Tower, 702-10, Yeoksam dong, K",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "000B43": {
        "oui_hex": "00-0B-43",
        "organization": "Microscan Systems, Inc.",
        "address_1": "700 SW 39th St",
        "address_2": "Renton  WA  98057",
        "country": "US"
    },
    "000B45": {
        "oui_hex": "00-0B-45",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000B4C": {
        "oui_hex": "00-0B-4C",
        "organization": "Clarion (M) Sdn Bhd",
        "address_1": "Phase 3",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "000B63": {
        "oui_hex": "00-0B-63",
        "organization": "Kaleidescape",
        "address_1": "One First Street, Suite Sixteen",
        "address_2": "Los Altos  CA  94022",
        "country": "US"
    },
    "000B68": {
        "oui_hex": "00-0B-68",
        "organization": "Addvalue Communications Pte Ltd",
        "address_1": "28,TAI SENG STREET #06-02",
        "address_2": "Singapore    534106",
        "country": "SG"
    },
    "000B58": {
        "oui_hex": "00-0B-58",
        "organization": "Astronautics C.A  LTD",
        "address_1": "23 hayarkon street",
        "address_2": "Bnei Brak    51261",
        "country": "IL"
    },
    "000B55": {
        "oui_hex": "00-0B-55",
        "organization": "ADInstruments",
        "address_1": "P. O. Box 587",
        "address_2": "Dunedin  Otago  9001",
        "country": "NZ"
    },
    "000B87": {
        "oui_hex": "00-0B-87",
        "organization": "American Reliance Inc.",
        "address_1": "11801 Goldring Rd",
        "address_2": "Arcadia  CA  91006",
        "country": "US"
    },
    "000B0D": {
        "oui_hex": "00-0B-0D",
        "organization": "Air2U, Inc.",
        "address_1": "No. 5-1 Innovation Rd 1, Science-based P",
        "address_2": "Hsin-Chu  Taiwan  300",
        "country": "TW"
    },
    "000B0B": {
        "oui_hex": "00-0B-0B",
        "organization": "Corrent Corporation",
        "address_1": "1711 W. Greentree Dr.",
        "address_2": "Tempe  AZ  85284-2717",
        "country": "US"
    },
    "000B08": {
        "oui_hex": "00-0B-08",
        "organization": "Pillar Data Systems",
        "address_1": "1371 McCarthy Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000B27": {
        "oui_hex": "00-0B-27",
        "organization": "Scion Corporation",
        "address_1": "82 Worman's Mill Court",
        "address_2": "Frederick  MD  21701",
        "country": "US"
    },
    "000B21": {
        "oui_hex": "00-0B-21",
        "organization": "G-Star Communications Inc.",
        "address_1": "5F, 69-10, Sec. 2, Chung Cheng East Road",
        "address_2": "Taipei Hsien    251",
        "country": "TW"
    },
    "000ADA": {
        "oui_hex": "00-0A-DA",
        "organization": "Vindicator Technologies",
        "address_1": "5307 Industrial Oaks Blvd.",
        "address_2": "Austin  Texas  78735",
        "country": "US"
    },
    "000AC9": {
        "oui_hex": "00-0A-C9",
        "organization": "Zambeel Inc",
        "address_1": "45700 Northport Loop East",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000B25": {
        "oui_hex": "00-0B-25",
        "organization": "Aeluros",
        "address_1": "201 San Antonio Circle #172",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "000B1A": {
        "oui_hex": "00-0B-1A",
        "organization": "Industrial Defender, Inc.",
        "address_1": "16 Chestnut Street",
        "address_2": "Foxborough  MA  02035",
        "country": "US"
    },
    "000B18": {
        "oui_hex": "00-0B-18",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000B15": {
        "oui_hex": "00-0B-15",
        "organization": "Platypus Technology",
        "address_1": "4/1 Atchison St",
        "address_2": "St Leonards  NSW  2065",
        "country": "AU"
    },
    "000AFA": {
        "oui_hex": "00-0A-FA",
        "organization": "Traverse Technologies Australia",
        "address_1": "Unit 13, 240 Sydney Rd",
        "address_2": "Coburg  Victoria  3058",
        "country": "AU"
    },
    "000AFC": {
        "oui_hex": "00-0A-FC",
        "organization": "Core Tec Communications, LLC",
        "address_1": "49 Leavenworth Street",
        "address_2": "Waterbury  CT  06702",
        "country": "US"
    },
    "000AEC": {
        "oui_hex": "00-0A-EC",
        "organization": "Koatsu Gas Kogyo Co., Ltd.",
        "address_1": "1-5, Doyama-cho, Kita-ku, Osaka",
        "address_2": "Osaka    530-8411",
        "country": "JP"
    },
    "000AE7": {
        "oui_hex": "00-0A-E7",
        "organization": "ELIOP S.A.",
        "address_1": "Avenida de Manoteras, 30",
        "address_2": "Madrid    E-28050",
        "country": "ES"
    },
    "000AE8": {
        "oui_hex": "00-0A-E8",
        "organization": "Cathay Roxus Information Technology Co. LTD",
        "address_1": "Fuhua mansion building A/B 4F",
        "address_2": "Beijing    100027",
        "country": "CN"
    },
    "000ADD": {
        "oui_hex": "00-0A-DD",
        "organization": "Allworx Corp.",
        "address_1": "245 East Main Street",
        "address_2": "East Rochester  NY  14604",
        "country": "US"
    },
    "000AE1": {
        "oui_hex": "00-0A-E1",
        "organization": "EG Technology",
        "address_1": "250 15th Street",
        "address_2": "Atlanta  GA  30318",
        "country": "US"
    },
    "000ADF": {
        "oui_hex": "00-0A-DF",
        "organization": "Gennum Corporation",
        "address_1": "P.O Box 489",
        "address_2": "Burlington  Ontario  L7R 3Y3",
        "country": "CA"
    },
    "000B3F": {
        "oui_hex": "00-0B-3F",
        "organization": "Anthology Solutions Inc.",
        "address_1": "1722 Ringwood Ave.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000B3C": {
        "oui_hex": "00-0B-3C",
        "organization": "Cygnal Integrated Products, Inc.",
        "address_1": "4301 Westbank Drive",
        "address_2": "Austin  TX  78746",
        "country": "US"
    },
    "000AF1": {
        "oui_hex": "00-0A-F1",
        "organization": "Clarity Design, Inc.",
        "address_1": "13029 Danielson Street",
        "address_2": "Poway  CA  92064-8810",
        "country": "US"
    },
    "000AF3": {
        "oui_hex": "00-0A-F3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000A8D": {
        "oui_hex": "00-0A-8D",
        "organization": "EUROTHERM LIMITED",
        "address_1": "FARADAY CLOSE",
        "address_2": "WORTHING  WEST SUSSEX  BN13 3PL",
        "country": "GB"
    },
    "000A9F": {
        "oui_hex": "00-0A-9F",
        "organization": "Pannaway Technologies, Inc.",
        "address_1": "215 Commerce Way",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "000A8F": {
        "oui_hex": "00-0A-8F",
        "organization": "Aska International Inc.",
        "address_1": "306 Riverseven",
        "address_2": "Kochi    780-8088",
        "country": "JP"
    },
    "000AA0": {
        "oui_hex": "00-0A-A0",
        "organization": "Cedar Point Communications",
        "address_1": "16 Route 111, Bldg 3",
        "address_2": "Derry  NH  03038",
        "country": "US"
    },
    "000A8E": {
        "oui_hex": "00-0A-8E",
        "organization": "Invacom Ltd",
        "address_1": "Business and Technology Centre",
        "address_2": "Stevenage  Hertfordshire  SG1 2DX",
        "country": "GB"
    },
    "000AC1": {
        "oui_hex": "00-0A-C1",
        "organization": "Futuretel",
        "address_1": "21580 Stevens Creek Blvd, Suite 208",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000ABE": {
        "oui_hex": "00-0A-BE",
        "organization": "OPNET Technologies CO., LTD.",
        "address_1": "3F, NO.5, Industry E. Rd. IX, Science-Ba",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000AC3": {
        "oui_hex": "00-0A-C3",
        "organization": "eM Technics Co., Ltd.",
        "address_1": "7F., IT Venture Tower., 78,",
        "address_2": "Seoul    138-803",
        "country": "KR"
    },
    "000AC4": {
        "oui_hex": "00-0A-C4",
        "organization": "Daewoo Teletech Co., Ltd",
        "address_1": "265-3, Seohyeon, Bundang",
        "address_2": "Seongnam  Gyeonggi",
        "country": "KR"
    },
    "000AC0": {
        "oui_hex": "00-0A-C0",
        "organization": "Fuyoh Video Industry CO., LTD.",
        "address_1": "7-25 Higashi Kibogaoka",
        "address_2": "Yokohama-shi  Kanagawa-ken  246-0008",
        "country": "JP"
    },
    "000AAE": {
        "oui_hex": "00-0A-AE",
        "organization": "Rosemount Process Analytical",
        "address_1": "6573A Cochran Rd.",
        "address_2": "Solon  Ohio  44139-3922",
        "country": "US"
    },
    "000AB3": {
        "oui_hex": "00-0A-B3",
        "organization": "Fa. GIRA",
        "address_1": "Dahlienstraße",
        "address_2": "Radevormwald  Nordrhein-Westfalen  42477",
        "country": "DE"
    },
    "000ABA": {
        "oui_hex": "00-0A-BA",
        "organization": "Arcon Technology Limited",
        "address_1": "Rm. 3711-12, 37/F., Cable TV Tower ,",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "000AB6": {
        "oui_hex": "00-0A-B6",
        "organization": "COMPUNETIX, INC",
        "address_1": "2420 MOSSIDE BLVD.",
        "address_2": "MONROEVILLE  PA  15146",
        "country": "US"
    },
    "000AAF": {
        "oui_hex": "00-0A-AF",
        "organization": "Pipal Systems",
        "address_1": "2903 Bunker Hill Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000A76": {
        "oui_hex": "00-0A-76",
        "organization": "Beida Jade Bird Huaguang Technology Co.,Ltd",
        "address_1": "No.207 Chengfu Road, Haidian District",
        "address_2": "Beijing    100871",
        "country": "CN"
    },
    "000AB2": {
        "oui_hex": "00-0A-B2",
        "organization": "Fresnel Wireless Systems",
        "address_1": "1333 Gateway Drive",
        "address_2": "Melbourne  FL  32901",
        "country": "US"
    },
    "000AAA": {
        "oui_hex": "00-0A-AA",
        "organization": "AltiGen Communications Inc.",
        "address_1": "47427 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000A99": {
        "oui_hex": "00-0A-99",
        "organization": "Calamp Wireless Networks Inc",
        "address_1": "101-5540 Ferrier Street",
        "address_2": "Town of Mount-Royal  Quebec  H4P 1M2",
        "country": "CA"
    },
    "000A93": {
        "oui_hex": "00-0A-93",
        "organization": "W2 Networks, Inc.",
        "address_1": "5808 NW Lac Leman Drive",
        "address_2": "Issaquah  Washington  98027",
        "country": "US"
    },
    "000A89": {
        "oui_hex": "00-0A-89",
        "organization": "Creval Systems, Inc.",
        "address_1": "2F,24-4,Sanwolgok-Dong,Sungbuk-Ku,Seoul,",
        "address_2": "Seoul    136-120",
        "country": "KR"
    },
    "000A80": {
        "oui_hex": "00-0A-80",
        "organization": "Telkonet Inc.",
        "address_1": "20374 Seneca Meadows Pkwy",
        "address_2": "Germantown  MD  21401",
        "country": "US"
    },
    "000A79": {
        "oui_hex": "00-0A-79",
        "organization": "corega K.K",
        "address_1": "1-19-20, Shinyokohama",
        "address_2": "Yokohama-city  Kanagawa-ken  222-0033",
        "country": "JP"
    },
    "000A5C": {
        "oui_hex": "00-0A-5C",
        "organization": "Carel s.p.a.",
        "address_1": "Via dell' Industria, 11",
        "address_2": "Brugine  Padova  35020",
        "country": "IT"
    },
    "000A5A": {
        "oui_hex": "00-0A-5A",
        "organization": "GreenNET Technologies Co.,Ltd.",
        "address_1": "No.10, Qiongyu Road,Sciences-based Indus",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "000A56": {
        "oui_hex": "00-0A-56",
        "organization": "HITACHI Maxell Ltd.",
        "address_1": "6-20-1 Kinunodai",
        "address_2": "Yawara-mura, Tsukuba-gun  IBARAKI  300-2496",
        "country": "JP"
    },
    "000A51": {
        "oui_hex": "00-0A-51",
        "organization": "GyroSignal Technology Co., Ltd.",
        "address_1": "5F,No. 77,Lide St.",
        "address_2": "Zhonghe City  Taipei County  23556",
        "country": "TW"
    },
    "000A2C": {
        "oui_hex": "00-0A-2C",
        "organization": "Active Tchnology Corporation",
        "address_1": "16-23, Shibaura 2-Chome,",
        "address_2": "Tokyo  Tokyo  108-0023",
        "country": "JP"
    },
    "000A2A": {
        "oui_hex": "00-0A-2A",
        "organization": "QSI Systems Inc.",
        "address_1": "7 Raymond Avenue",
        "address_2": "Salem  NH  03079",
        "country": "US"
    },
    "000A23": {
        "oui_hex": "00-0A-23",
        "organization": "Parama Networks Inc",
        "address_1": "1955 The Alameda",
        "address_2": "San Jose  CA  95126",
        "country": "US"
    },
    "000A1F": {
        "oui_hex": "00-0A-1F",
        "organization": "ART WARE Telecommunication Co., Ltd.",
        "address_1": "806 Ace Techno Tower #1, 197-17",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "000A0A": {
        "oui_hex": "00-0A-0A",
        "organization": "SUNIX Co., Ltd.",
        "address_1": "3Fl., No. 76, Baugau Rd.,",
        "address_2": "Shindian  Taipei  231",
        "country": "TW"
    },
    "000A05": {
        "oui_hex": "00-0A-05",
        "organization": "Widax Corp.",
        "address_1": "269 Stevens Street",
        "address_2": "Hyannis  MA  02668",
        "country": "US"
    },
    "000A34": {
        "oui_hex": "00-0A-34",
        "organization": "Identicard Systems Incorporated",
        "address_1": "40 Citation Lane",
        "address_2": "Lancaster  Pennsylvania  17606",
        "country": "US"
    },
    "000A30": {
        "oui_hex": "00-0A-30",
        "organization": "Visteon Corporation",
        "address_1": "One Village Center Drive",
        "address_2": "Van Buren Twp  MI  48111",
        "country": "US"
    },
    "000A2F": {
        "oui_hex": "00-0A-2F",
        "organization": "Artnix Inc.",
        "address_1": "Chungjin B/D, 475-22 Bangbae, Seocho",
        "address_2": "Seoul    137-819",
        "country": "KR"
    },
    "000A15": {
        "oui_hex": "00-0A-15",
        "organization": "Silicon Data, Inc",
        "address_1": "4699 Old Ironsides Dr., #150",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000A1B": {
        "oui_hex": "00-0A-1B",
        "organization": "Stream Labs",
        "address_1": "Leninskie gori 1, bild 77",
        "address_2": "Moskow    119992",
        "country": "RU"
    },
    "000A1A": {
        "oui_hex": "00-0A-1A",
        "organization": "Imerge Ltd",
        "address_1": "Unit 6, Bar Hill Business Park",
        "address_2": "Bar Hill  Cambridge  CB3 8SL",
        "country": "GB"
    },
    "000A60": {
        "oui_hex": "00-0A-60",
        "organization": "Autostar Technology Pte Ltd",
        "address_1": "Unit 04-10 TECHplace II",
        "address_2": "Singapore  Singapore  569876",
        "country": "SG"
    },
    "000A5D": {
        "oui_hex": "00-0A-5D",
        "organization": "FingerTec Worldwide Sdn Bhd",
        "address_1": "No 6, 8 & 10",
        "address_2": "Bandar Kinrara 47100 PUchong  Selangor",
        "country": "MY"
    },
    "000A39": {
        "oui_hex": "00-0A-39",
        "organization": "LoPA Information Technology",
        "address_1": "710-9, Dae Lim 3-Dong",
        "address_2": "Young Deung po-gu  Seoul, Korea  150-814",
        "country": "KR"
    },
    "000A37": {
        "oui_hex": "00-0A-37",
        "organization": "Procera Networks, Inc.",
        "address_1": "1299 Orleans Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000A53": {
        "oui_hex": "00-0A-53",
        "organization": "Intronics, Incorporated",
        "address_1": "2020 Lafayette Blvd.",
        "address_2": "Fredericksburg  Virginia  22401",
        "country": "US"
    },
    "000A4A": {
        "oui_hex": "00-0A-4A",
        "organization": "Targa Systems Ltd.",
        "address_1": "1905 Grandtech Centre,",
        "address_2": "Shatin  N.T.",
        "country": "HK"
    },
    "0009D6": {
        "oui_hex": "00-09-D6",
        "organization": "KNC One GmbH",
        "address_1": "Hohe Welle 10 B",
        "address_2": "Evessen    38173",
        "country": "DE"
    },
    "0009C7": {
        "oui_hex": "00-09-C7",
        "organization": "Movistec",
        "address_1": "110-5 Maryoung -ri Seosu-myun",
        "address_2": "Kunsan  Chonbuk  573-940",
        "country": "KR"
    },
    "0009C9": {
        "oui_hex": "00-09-C9",
        "organization": "BlueWINC Co., Ltd.",
        "address_1": "401 Korea Design Center",
        "address_2": "Seongnam City  Kyonggi杁o  463-828",
        "country": "KR"
    },
    "0009D4": {
        "oui_hex": "00-09-D4",
        "organization": "Transtech Networks",
        "address_1": "100 Wood Avenue",
        "address_2": "Iselin  NJ  08830",
        "country": "US"
    },
    "0009CB": {
        "oui_hex": "00-09-CB",
        "organization": "HBrain",
        "address_1": "#705 Kwanglim Bldg 179 KumiDong",
        "address_2": "Seongnam  GyeonggiDo  463-810",
        "country": "KR"
    },
    "0009F1": {
        "oui_hex": "00-09-F1",
        "organization": "Yamaki Electric Corporation",
        "address_1": "3-7-22 Shimomeguro",
        "address_2": "Meguro-ku  Tokyo  153-0064",
        "country": "JP"
    },
    "0009F4": {
        "oui_hex": "00-09-F4",
        "organization": "Alcon Laboratories, Inc.",
        "address_1": "6201 South Freeway",
        "address_2": "Fort Worth  Tx  76134",
        "country": "US"
    },
    "0009F5": {
        "oui_hex": "00-09-F5",
        "organization": "Emerson Network Power Co.,Ltd",
        "address_1": "1/F,3/F Electric Building Huawei Base,Ba",
        "address_2": "ShenZhen  GuangDong  518029",
        "country": "CN"
    },
    "0009EA": {
        "oui_hex": "00-09-EA",
        "organization": "YEM Inc.",
        "address_1": "1-3-33",
        "address_2": "Atsugi-shi  Kanagawa  243-0021",
        "country": "JP"
    },
    "0009C5": {
        "oui_hex": "00-09-C5",
        "organization": "KINGENE Technology Corporation",
        "address_1": "7F, No. 144, Minchuan E. Rd. Sec. 3",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "0009CD": {
        "oui_hex": "00-09-CD",
        "organization": "HUDSON SOFT CO.,LTD.",
        "address_1": "C62,Geijutsu-no-mori",
        "address_2": "Sapporo  Hokkaido  005-0864",
        "country": "JP"
    },
    "0009C0": {
        "oui_hex": "00-09-C0",
        "organization": "6WIND",
        "address_1": "1, place Charles de Gaulle",
        "address_2": "Montigny-le-Bretonneux    78180",
        "country": "FR"
    },
    "0009BF": {
        "oui_hex": "00-09-BF",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0009E3": {
        "oui_hex": "00-09-E3",
        "organization": "Angel Iglesias S.A.",
        "address_1": "Polígono 27 Martutene",
        "address_2": "San Sebastián  Guipúzcoa  20014",
        "country": "ES"
    },
    "0009B4": {
        "oui_hex": "00-09-B4",
        "organization": "KISAN TELECOM CO., LTD.",
        "address_1": "9F, Teawon Bldg., 65 Bangyi-Dong",
        "address_2": "Songpa-Gu  Seoul  138-828",
        "country": "KR"
    },
    "0009AE": {
        "oui_hex": "00-09-AE",
        "organization": "OKANO ELECTRIC CO.,LTD",
        "address_1": "2-8-18 KANAYAMA-CHO",
        "address_2": "HIGASHIKURUME  TOKYO  203-0003",
        "country": "JP"
    },
    "0009BA": {
        "oui_hex": "00-09-BA",
        "organization": "MAKU Informationstechik GmbH",
        "address_1": "Gewerbehofstraße 7",
        "address_2": "Essen  NRW  45145",
        "country": "DE"
    },
    "000A04": {
        "oui_hex": "00-0A-04",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "000971": {
        "oui_hex": "00-09-71",
        "organization": "Time Management, Inc.",
        "address_1": "11 Lake Gatlin Road",
        "address_2": "Orlando  Florida  32806",
        "country": "US"
    },
    "000974": {
        "oui_hex": "00-09-74",
        "organization": "Innopia Technologies, Inc.",
        "address_1": "5F., Institute of Technology",
        "address_2": "Seoul    133-791",
        "country": "KR"
    },
    "00098B": {
        "oui_hex": "00-09-8B",
        "organization": "Entropic Communications, Inc.",
        "address_1": "9276 Scranton Rd #200",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00097E": {
        "oui_hex": "00-09-7E",
        "organization": "IMI TECHNOLOGY CO., LTD",
        "address_1": "2nd floor, Eun Seok Building, 729-1",
        "address_2": "Gangnam-gu  Seoul  135-080",
        "country": "KR"
    },
    "00096A": {
        "oui_hex": "00-09-6A",
        "organization": "Cloverleaf Communications Inc.",
        "address_1": "2 Willow St.",
        "address_2": "Southborough  MA  01745-1027",
        "country": "US"
    },
    "00095A": {
        "oui_hex": "00-09-5A",
        "organization": "RACEWOOD TECHNOLOGY",
        "address_1": "5F-2,NO.6,CHUNG-HSING RD.,SEC.1,WU-GU",
        "address_2": "TAIPEI    248",
        "country": "TW"
    },
    "00094E": {
        "oui_hex": "00-09-4E",
        "organization": "BARTECH SYSTEMS INTERNATIONAL, INC",
        "address_1": "251 Najoles Rd Suite A",
        "address_2": "Millersville  Maryland  21108",
        "country": "US"
    },
    "000947": {
        "oui_hex": "00-09-47",
        "organization": "Aztek, Inc.",
        "address_1": "23 Spectrum Pointe #209",
        "address_2": "Lake Forest  California  92630",
        "country": "US"
    },
    "000951": {
        "oui_hex": "00-09-51",
        "organization": "Apogee Imaging Systems",
        "address_1": "151 Sunrise Avenue",
        "address_2": "Roseville  CA  95661",
        "country": "US"
    },
    "00093D": {
        "oui_hex": "00-09-3D",
        "organization": "Newisys,Inc.",
        "address_1": "6200 Bridgepoint Parkway",
        "address_2": "Austin  TX  78730",
        "country": "US"
    },
    "000967": {
        "oui_hex": "00-09-67",
        "organization": "Tachyon, Inc",
        "address_1": "9339 Carroll Park Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000996": {
        "oui_hex": "00-09-96",
        "organization": "RDI",
        "address_1": "20406 Earl St.",
        "address_2": "Torrance  CA  90503",
        "country": "US"
    },
    "00090C": {
        "oui_hex": "00-09-0C",
        "organization": "Mayekawa Mfg. Co. Ltd.",
        "address_1": "16825 IH 35 North",
        "address_2": "Selma  Texas  78154",
        "country": "US"
    },
    "00090D": {
        "oui_hex": "00-09-0D",
        "organization": "LEADER ELECTRONICS CORP.",
        "address_1": "2-6-33, TSUNASHIMA-HIGASHI",
        "address_2": "YOKOHAMA  KANAGAWA  223-8505",
        "country": "JP"
    },
    "0008FE": {
        "oui_hex": "00-08-FE",
        "organization": "UNIK C&C Co.,Ltd.",
        "address_1": "706-13 UNIK BLDG 17F",
        "address_2": "SEOUL    135-080",
        "country": "KR"
    },
    "0008FF": {
        "oui_hex": "00-08-FF",
        "organization": "Trilogy Communications Ltd",
        "address_1": "26 Focus Way",
        "address_2": "Andover  Hampshire  SP10 5NY",
        "country": "GB"
    },
    "000904": {
        "oui_hex": "00-09-04",
        "organization": "MONDIAL electronic",
        "address_1": "Eggelsberg 73",
        "address_2": "Eggelsberg  Oberoesterreich  5142",
        "country": "AT"
    },
    "00091F": {
        "oui_hex": "00-09-1F",
        "organization": "A&D Co., Ltd.",
        "address_1": "1-243 Asahi",
        "address_2": "Kitamoto-shi  Saitama  364-8585",
        "country": "JP"
    },
    "000924": {
        "oui_hex": "00-09-24",
        "organization": "Telebau GmbH",
        "address_1": "Am Kraehenberg 1",
        "address_2": "Waldeck-Sachsenhausen  Germany  34513",
        "country": "DE"
    },
    "000921": {
        "oui_hex": "00-09-21",
        "organization": "Planmeca Oy",
        "address_1": "Asentajankatu 6",
        "address_2": "HELSINKI    00810 HELSIN",
        "country": "FI"
    },
    "000919": {
        "oui_hex": "00-09-19",
        "organization": "MDS Gateways",
        "address_1": "Clonshaugh Industrial Estate",
        "address_2": "Dublin 17",
        "country": "IE"
    },
    "000918": {
        "oui_hex": "00-09-18",
        "organization": "SAMSUNG TECHWIN CO.,LTD",
        "address_1": "42",
        "address_2": "CHANGWON  KYONGNAM  641-716",
        "country": "KR"
    },
    "00092F": {
        "oui_hex": "00-09-2F",
        "organization": "Akom Technology Corporation",
        "address_1": "5F, No. 323, Yang-Guang St.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0008EF": {
        "oui_hex": "00-08-EF",
        "organization": "DIBAL,S.A.",
        "address_1": "Astintze Kalea 24",
        "address_2": "Derio  Vizcaya  48160",
        "country": "ES"
    },
    "0008F0": {
        "oui_hex": "00-08-F0",
        "organization": "Next Generation Systems, Inc.",
        "address_1": "PO BOX 31205",
        "address_2": "Dayton  OH  45437-0205",
        "country": "US"
    },
    "0008E9": {
        "oui_hex": "00-08-E9",
        "organization": "NextGig",
        "address_1": "9820-B Towne Centre Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000910": {
        "oui_hex": "00-09-10",
        "organization": "Simple Access Inc.",
        "address_1": "600 McCaffrey Street",
        "address_2": "St-Laurent  Quebec  H4T1N1",
        "country": "CA"
    },
    "000914": {
        "oui_hex": "00-09-14",
        "organization": "COMPUTROLS INC.",
        "address_1": "221 Bark Drive",
        "address_2": "Harvey  LA  70058",
        "country": "US"
    },
    "0008E7": {
        "oui_hex": "00-08-E7",
        "organization": "SHI ControlSystems,Ltd.",
        "address_1": "19,Natusima",
        "address_2": "Yokosuka  Kanagawa  237-8555",
        "country": "JP"
    },
    "0008D7": {
        "oui_hex": "00-08-D7",
        "organization": "HOW CORPORATION",
        "address_1": "1-11-17 Chiyoda",
        "address_2": "Sagamihara  Kanagawa  229-0037",
        "country": "JP"
    },
    "0008FC": {
        "oui_hex": "00-08-FC",
        "organization": "Gigaphoton Inc.",
        "address_1": "YOKOKURA SHINDEN400",
        "address_2": "OYAMA  TOTIGI  323-8558",
        "country": "JP"
    },
    "000938": {
        "oui_hex": "00-09-38",
        "organization": "Allot Communications",
        "address_1": "Hanagar 22 st'",
        "address_2": "Hod-Hasharon    45800",
        "country": "IL"
    },
    "0008BF": {
        "oui_hex": "00-08-BF",
        "organization": "Aptus Elektronik AB",
        "address_1": "FO Petersons G 6",
        "address_2": "",
        "country": "SE"
    },
    "0008B8": {
        "oui_hex": "00-08-B8",
        "organization": "E.F. Johnson",
        "address_1": "299 Johnson Ave.",
        "address_2": "Waseca  MN  56093",
        "country": "US"
    },
    "0008BB": {
        "oui_hex": "00-08-BB",
        "organization": "NetExcell",
        "address_1": "15375 Barranca Pkwy, #E-106",
        "address_2": "Irvine  CA  92679",
        "country": "US"
    },
    "0008BE": {
        "oui_hex": "00-08-BE",
        "organization": "XENPAK MSA Group",
        "address_1": "Care of: Agilent Technologies",
        "address_2": "Ipswich  Suffolk  Ip1 5PB",
        "country": "GB"
    },
    "0008C1": {
        "oui_hex": "00-08-C1",
        "organization": "Avistar Communications Corporation",
        "address_1": "15851 Dallas Pkwy.",
        "address_2": "Addison  TX  75001",
        "country": "US"
    },
    "0008C6": {
        "oui_hex": "00-08-C6",
        "organization": "Philips Consumer Communications",
        "address_1": "Route d'Angers",
        "address_2": "Cedex 9",
        "country": "FR"
    },
    "000865": {
        "oui_hex": "00-08-65",
        "organization": "JASCOM CO., LTD",
        "address_1": "JUAN INDUSTRIAL COMPLEX 330, 17-1,",
        "address_2": "JUAN-DONG NAM-GU  INCHEON  402-200",
        "country": "KR"
    },
    "000864": {
        "oui_hex": "00-08-64",
        "organization": "Fasy S.p.A.",
        "address_1": "Via Tognasca 7",
        "address_2": "Gallarate  Varese  21013",
        "country": "US"
    },
    "000860": {
        "oui_hex": "00-08-60",
        "organization": "LodgeNet Entertainment Corp.",
        "address_1": "3900 W. Innovation Street",
        "address_2": "Sioux Falls  SD  57107",
        "country": "US"
    },
    "000897": {
        "oui_hex": "00-08-97",
        "organization": "Quake Technologies",
        "address_1": "2880 Zanker Road",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000890": {
        "oui_hex": "00-08-90",
        "organization": "AVILINKS SA",
        "address_1": "Etic Center - CS 77 729",
        "address_2": "Cesson Sevigne Cedex    35577",
        "country": "FR"
    },
    "00088D": {
        "oui_hex": "00-08-8D",
        "organization": "Sigma-Links Inc.",
        "address_1": "550-1 Higashiasakawa-cho,",
        "address_2": "Tokyo    193-8550",
        "country": "JP"
    },
    "0008A8": {
        "oui_hex": "00-08-A8",
        "organization": "Systec Co., Ltd.",
        "address_1": "19 Nochidori, Nawa",
        "address_2": "Tokai  Aichi  476-0002",
        "country": "JP"
    },
    "0008A4": {
        "oui_hex": "00-08-A4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "08006B": {
        "oui_hex": "08-00-6B",
        "organization": "ACCEL TECHNOLOGIES INC.",
        "address_1": "7358 TRADE STREET",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "000884": {
        "oui_hex": "00-08-84",
        "organization": "Index Braille AB",
        "address_1": "Box 155",
        "address_2": "",
        "country": "SE"
    },
    "0007E8": {
        "oui_hex": "00-07-E8",
        "organization": "EdgeWave",
        "address_1": "15333 Avenue of Science",
        "address_2": "San Diego  CA  92128",
        "country": "US"
    },
    "0007EB": {
        "oui_hex": "00-07-EB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0007EC": {
        "oui_hex": "00-07-EC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000851": {
        "oui_hex": "00-08-51",
        "organization": "Canadian Bank Note Company, Ltd.",
        "address_1": "18 Auriga Dr.",
        "address_2": "    K2E 7T9",
        "country": "CA"
    },
    "000859": {
        "oui_hex": "00-08-59",
        "organization": "ShenZhen Unitone Electronics Co., Ltd.",
        "address_1": "2 Southern Floor 702 Building",
        "address_2": "",
        "country": "CN"
    },
    "00084E": {
        "oui_hex": "00-08-4E",
        "organization": "DivergeNet, Inc.",
        "address_1": "2142 Bering Dr.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000819": {
        "oui_hex": "00-08-19",
        "organization": "Banksys",
        "address_1": "Haachtsesteenweg 1442",
        "address_2": "",
        "country": "BE"
    },
    "00081A": {
        "oui_hex": "00-08-1A",
        "organization": "Sanrad Intelligence Storage Communications (2000) Ltd.",
        "address_1": "32 Habarzel St., Entrace B",
        "address_2": "",
        "country": "IL"
    },
    "000810": {
        "oui_hex": "00-08-10",
        "organization": "Key Technology, Inc.",
        "address_1": "150 Avery St.",
        "address_2": "Walla Walla  WA  99362",
        "country": "US"
    },
    "000807": {
        "oui_hex": "00-08-07",
        "organization": "Access Devices Limited",
        "address_1": "Sixth Floor, 58 Oxbridge Road",
        "address_2": "",
        "country": "GB"
    },
    "0007FC": {
        "oui_hex": "00-07-FC",
        "organization": "Adept Systems Inc.",
        "address_1": "2100 Boca Rio Rd.",
        "address_2": "Boca Raton  FL  33433",
        "country": "US"
    },
    "000825": {
        "oui_hex": "00-08-25",
        "organization": "Acme Packet",
        "address_1": "71 Third Avenue",
        "address_2": "Woburn  MA  01803",
        "country": "US"
    },
    "0007DC": {
        "oui_hex": "00-07-DC",
        "organization": "Atek Co, Ltd.",
        "address_1": "B dong #205 hanyang venture park",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00081F": {
        "oui_hex": "00-08-1F",
        "organization": "Pou Yuen Tech Corp. Ltd.",
        "address_1": "16F, No. 107, Sect. 3, Taichung Keng Rd.",
        "address_2": "",
        "country": "TW"
    },
    "0007C6": {
        "oui_hex": "00-07-C6",
        "organization": "VDS Vosskuhler GmbH",
        "address_1": "Weibe Breite 7",
        "address_2": "",
        "country": "DE"
    },
    "0007F5": {
        "oui_hex": "00-07-F5",
        "organization": "Bridgeco Co AG",
        "address_1": "Ringstr. 14",
        "address_2": "",
        "country": "CH"
    },
    "000794": {
        "oui_hex": "00-07-94",
        "organization": "Simple Devices, Inc.",
        "address_1": "111 Anza Blvd., Suite 120",
        "address_2": "Burlingame  CA  94010",
        "country": "US"
    },
    "000797": {
        "oui_hex": "00-07-97",
        "organization": "Netpower Co., Ltd.",
        "address_1": "Baekam Bldg., 6F",
        "address_2": "Seoul    138-162",
        "country": "KR"
    },
    "00078C": {
        "oui_hex": "00-07-8C",
        "organization": "Elektronikspecialisten i Borlange AB",
        "address_1": "Box 50",
        "address_2": "    SE 780",
        "country": "SE"
    },
    "0007CC": {
        "oui_hex": "00-07-CC",
        "organization": "Kaba Benzing GmbH",
        "address_1": "Albertistrabe 3",
        "address_2": "",
        "country": "DE"
    },
    "0007C0": {
        "oui_hex": "00-07-C0",
        "organization": "NetZerver Inc.",
        "address_1": "26 West Lone Cactus Drive",
        "address_2": "Phoenix  AZ  85027",
        "country": "US"
    },
    "00047E": {
        "oui_hex": "00-04-7E",
        "organization": "Siqura B.V.",
        "address_1": "Zuidelijk Halfrond 4",
        "address_2": "",
        "country": "NL"
    },
    "0007BC": {
        "oui_hex": "00-07-BC",
        "organization": "Identix Inc.",
        "address_1": "6591 Sierra Lane",
        "address_2": "Dublin  CA  94568",
        "country": "US"
    },
    "0007A9": {
        "oui_hex": "00-07-A9",
        "organization": "Novasonics",
        "address_1": "1390 Willow Road",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "0007A1": {
        "oui_hex": "00-07-A1",
        "organization": "VIASYS Healthcare GmbH",
        "address_1": "Leibnizstraße 7",
        "address_2": "Hoechberg  Bavaria  97204",
        "country": "DE"
    },
    "00079E": {
        "oui_hex": "00-07-9E",
        "organization": "Ilinx Co., Ltd.",
        "address_1": "4th Floor Korea Telecom, Yangjae Branch",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0007A0": {
        "oui_hex": "00-07-A0",
        "organization": "e-Watch Inc.",
        "address_1": "7800 IH 10 West",
        "address_2": "San Antonio  TX  78229",
        "country": "US"
    },
    "000788": {
        "oui_hex": "00-07-88",
        "organization": "Clipcomm, Inc.",
        "address_1": "5th Fl, Ssangyang Bldg.",
        "address_2": "Seoul    151-827",
        "country": "KR"
    },
    "000781": {
        "oui_hex": "00-07-81",
        "organization": "Itron Inc.",
        "address_1": "2818 N. Sullivan Road",
        "address_2": "Spokane  WA  99216",
        "country": "US"
    },
    "00076B": {
        "oui_hex": "00-07-6B",
        "organization": "Stralfors AB",
        "address_1": "Langgatan 21",
        "address_2": "",
        "country": "SE"
    },
    "000768": {
        "oui_hex": "00-07-68",
        "organization": "Danfoss A/S",
        "address_1": "E16-N12, DK-6430 Nordborg",
        "address_2": "",
        "country": ""
    },
    "00075F": {
        "oui_hex": "00-07-5F",
        "organization": "VCS Video Communication Systems AG",
        "address_1": "Forchheimer Str. 4",
        "address_2": "",
        "country": "DE"
    },
    "0007B8": {
        "oui_hex": "00-07-B8",
        "organization": "Corvalent Corporation",
        "address_1": "1101 Arrow Point Dr #501",
        "address_2": "Cedar Park  TX  78613",
        "country": "US"
    },
    "00077B": {
        "oui_hex": "00-07-7B",
        "organization": "Millimetrix Broadband Networks",
        "address_1": "Kibutz Givat Hashelosha 48800",
        "address_2": "",
        "country": "IL"
    },
    "000769": {
        "oui_hex": "00-07-69",
        "organization": "Italiana Macchi SpA",
        "address_1": "Via Matteotti 1",
        "address_2": "",
        "country": "IT"
    },
    "00071A": {
        "oui_hex": "00-07-1A",
        "organization": "Finedigital Inc.",
        "address_1": "4th Fl. Bomi Bldg., 661 Deungchon 3 Dong",
        "address_2": "Seoul    157-033",
        "country": "KR"
    },
    "00071E": {
        "oui_hex": "00-07-1E",
        "organization": "Tri-M Engineering / Nupak Dev. Corp.",
        "address_1": "6-1301 Ketch Court",
        "address_2": "    V3K 6X7",
        "country": "CA"
    },
    "000717": {
        "oui_hex": "00-07-17",
        "organization": "Wieland Electric GmbH",
        "address_1": "Brennerstraße 10-14",
        "address_2": "",
        "country": "DE"
    },
    "000711": {
        "oui_hex": "00-07-11",
        "organization": "Acterna",
        "address_1": "6620 Network Way",
        "address_2": "Indianapolis  IN  46278",
        "country": "US"
    },
    "000702": {
        "oui_hex": "00-07-02",
        "organization": "Varex Imaging",
        "address_1": "1678 South Pioneer Road",
        "address_2": "Salt Lake City  UT  84104",
        "country": "US"
    },
    "000705": {
        "oui_hex": "00-07-05",
        "organization": "Endress & Hauser GmbH & Co",
        "address_1": "Hauptstrabe 1 - Postfach 1261",
        "address_2": "",
        "country": "DE"
    },
    "0006FF": {
        "oui_hex": "00-06-FF",
        "organization": "Sheba Systems Co., Ltd.",
        "address_1": "5th Fl. Hyundai Jad B/D",
        "address_2": "Seoul    134-030",
        "country": "KR"
    },
    "000741": {
        "oui_hex": "00-07-41",
        "organization": "Sierra Automated Systems",
        "address_1": "2821 Burton Ave.",
        "address_2": "Burbank  CA  91504",
        "country": "US"
    },
    "000745": {
        "oui_hex": "00-07-45",
        "organization": "Radlan Computer Communications Ltd.",
        "address_1": "Atidim Technology Park",
        "address_2": "Tel Aviv    61131",
        "country": "IL"
    },
    "00073E": {
        "oui_hex": "00-07-3E",
        "organization": "China Great-Wall Computer Shenzhen Co., Ltd.",
        "address_1": "Research & Development Center, Kefa Road",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "000733": {
        "oui_hex": "00-07-33",
        "organization": "DANCONTROL Engineering",
        "address_1": "Italiensvej 1-5",
        "address_2": "",
        "country": "DK"
    },
    "00072B": {
        "oui_hex": "00-07-2B",
        "organization": "Jung Myung Telecom Co., Ltd.",
        "address_1": "5Fl Silla Technovil., 39-3 Dang-Dong",
        "address_2": "",
        "country": "KR"
    },
    "000718": {
        "oui_hex": "00-07-18",
        "organization": "iCanTek Co., Ltd.",
        "address_1": "2nd Fl. DK Plaza II, 376-5,",
        "address_2": "Sungman-si, Kyonggi-do    463-805",
        "country": "KR"
    },
    "000716": {
        "oui_hex": "00-07-16",
        "organization": "J & S Marine Ltd.",
        "address_1": "Pottington Business Park",
        "address_2": "Devon    EX31 1LY",
        "country": "GB"
    },
    "00075C": {
        "oui_hex": "00-07-5C",
        "organization": "Eastman Kodak Company",
        "address_1": "343 State Street",
        "address_2": "Rochester  NY  146501245",
        "country": "US"
    },
    "000756": {
        "oui_hex": "00-07-56",
        "organization": "Juyoung Telecom",
        "address_1": "#201, Dunsan Building",
        "address_2": "Taejon    302-846",
        "country": "KR"
    },
    "00075A": {
        "oui_hex": "00-07-5A",
        "organization": "Air Products and Chemicals, Inc.",
        "address_1": "7201 Hamilton Blvd.",
        "address_2": "Allentown  PA  18195-1501",
        "country": "US"
    },
    "000748": {
        "oui_hex": "00-07-48",
        "organization": "The Imaging Source Europe",
        "address_1": "Sommerstraße 34-36",
        "address_2": "",
        "country": "DE"
    },
    "000746": {
        "oui_hex": "00-07-46",
        "organization": "TURCK, Inc.",
        "address_1": "3000 Campus Drive",
        "address_2": "Plymouth  MN  55441",
        "country": "US"
    },
    "00073B": {
        "oui_hex": "00-07-3B",
        "organization": "Tenovis GmbH & Co KG",
        "address_1": "Kleyerstraße 94",
        "address_2": "",
        "country": "DE"
    },
    "000731": {
        "oui_hex": "00-07-31",
        "organization": "Ophir-Spiricon LLC",
        "address_1": "3050 N 300 W",
        "address_2": "North Logan  UT  84341",
        "country": "US"
    },
    "00070A": {
        "oui_hex": "00-07-0A",
        "organization": "Unicom Automation Co., Ltd.",
        "address_1": "Silk Bldg 3-31-11",
        "address_2": "Tokyo    164-0012",
        "country": "JP"
    },
    "000709": {
        "oui_hex": "00-07-09",
        "organization": "Westerstrand Urfabrik AB",
        "address_1": "Box 133",
        "address_2": "",
        "country": "SE"
    },
    "0006EB": {
        "oui_hex": "00-06-EB",
        "organization": "Global Data",
        "address_1": "2250 Obispo Ave #105",
        "address_2": "Signal Hill  CA  90806",
        "country": "US"
    },
    "0006D3": {
        "oui_hex": "00-06-D3",
        "organization": "Alpha Telecom, Inc. U.S.A.",
        "address_1": "1394 Borregor Ave.",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000647": {
        "oui_hex": "00-06-47",
        "organization": "Etrali S.A.",
        "address_1": "221, Rue La Fontaine",
        "address_2": "",
        "country": "FR"
    },
    "0006A4": {
        "oui_hex": "00-06-A4",
        "organization": "INNOWELL Corp.",
        "address_1": "#717 ChongGu Bluevill",
        "address_2": "    463-825",
        "country": "KR"
    },
    "0006D6": {
        "oui_hex": "00-06-D6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0006CB": {
        "oui_hex": "00-06-CB",
        "organization": "Jotron Electronics A/S",
        "address_1": "Pob 54",
        "address_2": "",
        "country": "NO"
    },
    "0006CD": {
        "oui_hex": "00-06-CD",
        "organization": "Leaf Imaging Ltd.",
        "address_1": "7th Hatnufa st",
        "address_2": "Petach-Tikva    49002",
        "country": "IL"
    },
    "000695": {
        "oui_hex": "00-06-95",
        "organization": "Ensure Technologies, Inc.",
        "address_1": "3526 West Liberty",
        "address_2": "Ann Arbor  MI  48103",
        "country": "US"
    },
    "000691": {
        "oui_hex": "00-06-91",
        "organization": "PT Inovacao",
        "address_1": "Rua Eng. Jose F. Pinto Basto",
        "address_2": "",
        "country": "PT"
    },
    "000692": {
        "oui_hex": "00-06-92",
        "organization": "Intruvert Networks, Inc.",
        "address_1": "Suite 102",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00068B": {
        "oui_hex": "00-06-8B",
        "organization": "AirRunner Technologies, Inc.",
        "address_1": "2401 Lupine Trail",
        "address_2": "South Lake Tahoe  CA  96150",
        "country": "US"
    },
    "000688": {
        "oui_hex": "00-06-88",
        "organization": "Telways Communication Co., Ltd.",
        "address_1": "3F, No. 53, Lane 258",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0006AB": {
        "oui_hex": "00-06-AB",
        "organization": "W-Link Systems, Inc.",
        "address_1": "No. 20, Park Ave. II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0006AC": {
        "oui_hex": "00-06-AC",
        "organization": "Intersoft Co.",
        "address_1": "#1803 sun-kyoung Officetel",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000694": {
        "oui_hex": "00-06-94",
        "organization": "Mobillian Corporation",
        "address_1": "11031 Via Frontera",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "0006C7": {
        "oui_hex": "00-06-C7",
        "organization": "RFNET Technologies Pte Ltd (S)",
        "address_1": "Unit 233 Innovation Centre Blk 2",
        "address_2": "    637722",
        "country": "SG"
    },
    "0006B9": {
        "oui_hex": "00-06-B9",
        "organization": "A5TEK Corp.",
        "address_1": "1233 Alderwood Ave.",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0006B3": {
        "oui_hex": "00-06-B3",
        "organization": "Diagraph Corporation",
        "address_1": "3401 Rider Trail South",
        "address_2": "Earth City  MO  63045-1110",
        "country": "US"
    },
    "0006E3": {
        "oui_hex": "00-06-E3",
        "organization": "Quantitative Imaging Corporation",
        "address_1": "8081 Lougheed Highway",
        "address_2": "",
        "country": "CA"
    },
    "0006E4": {
        "oui_hex": "00-06-E4",
        "organization": "Citel Technologies Ltd.",
        "address_1": "Wheatcroft Business Park",
        "address_2": "Nottigham    NG12 4DG",
        "country": "GB"
    },
    "0006A1": {
        "oui_hex": "00-06-A1",
        "organization": "Celsian Technologies, Inc.",
        "address_1": "3002 Dow Ave., Unit 138",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "0006D9": {
        "oui_hex": "00-06-D9",
        "organization": "IPM-Net S.p.A.",
        "address_1": "Via Remo De Feo",
        "address_2": "",
        "country": "IT"
    },
    "000663": {
        "oui_hex": "00-06-63",
        "organization": "Human Technology Co., Ltd.",
        "address_1": "3rd Fl, Hyungok Bldg.,",
        "address_2": "Kangnam-ku  Seoul",
        "country": "KR"
    },
    "000665": {
        "oui_hex": "00-06-65",
        "organization": "Sunny Giken, Inc.",
        "address_1": "3-1-9 Nishidai Itami-shi",
        "address_2": "Hyogo-pref.    664-0858",
        "country": "JP"
    },
    "000669": {
        "oui_hex": "00-06-69",
        "organization": "Datasound Laboratories Ltd",
        "address_1": "5 Business Park West, Avenue One",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "00066E": {
        "oui_hex": "00-06-6E",
        "organization": "Delta Electronics, Inc.",
        "address_1": "11F, 266 Wen-Hwa 2nd Road,",
        "address_2": "",
        "country": "TW"
    },
    "00061B": {
        "oui_hex": "00-06-1B",
        "organization": "Notebook Development Lab.  Lenovo Japan Ltd.",
        "address_1": "1623-14 Shimotsuruma",
        "address_2": "    242-8502",
        "country": "JP"
    },
    "00060F": {
        "oui_hex": "00-06-0F",
        "organization": "Narad Networks Inc",
        "address_1": "515 Groton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "000610": {
        "oui_hex": "00-06-10",
        "organization": "Abeona Networks Inc",
        "address_1": "46117 Landing Parkway",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "000611": {
        "oui_hex": "00-06-11",
        "organization": "Zeus Wireless, Inc.",
        "address_1": "8325 Guilford Road",
        "address_2": "Columbia  MD  21046",
        "country": "US"
    },
    "0005EC": {
        "oui_hex": "00-05-EC",
        "organization": "Mosaic Systems Inc.",
        "address_1": "7 Campbell Park",
        "address_2": "Somerville  MA  02144",
        "country": "US"
    },
    "000662": {
        "oui_hex": "00-06-62",
        "organization": "MBM Technology Ltd.",
        "address_1": "Victoria Rd.",
        "address_2": "",
        "country": "GB"
    },
    "00065A": {
        "oui_hex": "00-06-5A",
        "organization": "Strix Systems",
        "address_1": "310 N. Westlake Blvd.",
        "address_2": "Westlake Village  CA  91362",
        "country": "US"
    },
    "000652": {
        "oui_hex": "00-06-52",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000656": {
        "oui_hex": "00-06-56",
        "organization": "Tactel AB",
        "address_1": "Norra Vallgatan 64",
        "address_2": "",
        "country": "SE"
    },
    "000641": {
        "oui_hex": "00-06-41",
        "organization": "ITCN",
        "address_1": "8571 Gander Creek Drive",
        "address_2": "Miamisburg  OH  45342",
        "country": "US"
    },
    "000648": {
        "oui_hex": "00-06-48",
        "organization": "Seedsware, Inc.",
        "address_1": " 3-7-16 Technostage,",
        "address_2": "Izumi,  Osaka  594-1144",
        "country": "JP"
    },
    "00064C": {
        "oui_hex": "00-06-4C",
        "organization": "Invicta Networks, Inc.",
        "address_1": "13873 Park Center Road",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "000674": {
        "oui_hex": "00-06-74",
        "organization": "Spectrum Control, Inc.",
        "address_1": "8061 Avonia Road",
        "address_2": "Fairview  PA  16415",
        "country": "US"
    },
    "000638": {
        "oui_hex": "00-06-38",
        "organization": "Sungjin C&C Co., Ltd.",
        "address_1": "1543-6, Seocho-dong, Seocho-gu,",
        "address_2": "Seoul    137-073",
        "country": "KR"
    },
    "000635": {
        "oui_hex": "00-06-35",
        "organization": "PacketAir Networks, Inc.",
        "address_1": "11545 W. Bernardo Ct.",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "00061A": {
        "oui_hex": "00-06-1A",
        "organization": "Zetari Inc.",
        "address_1": "411 Waverly Oaks Rd.",
        "address_2": "Waltham  MA  02452-8401",
        "country": "US"
    },
    "00061F": {
        "oui_hex": "00-06-1F",
        "organization": "Vision Components GmbH",
        "address_1": "Ottostraße 2",
        "address_2": "",
        "country": "DE"
    },
    "000687": {
        "oui_hex": "00-06-87",
        "organization": "Omnitron Systems Technology, Inc.",
        "address_1": "140 Technology",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000602": {
        "oui_hex": "00-06-02",
        "organization": "Cirkitech Electronics Co.",
        "address_1": "B1-2, No. 361, Fu-Xing First Road",
        "address_2": "  Tao-Yuan",
        "country": "TW"
    },
    "0005C0": {
        "oui_hex": "00-05-C0",
        "organization": "Digital Network Alacarte Co., Ltd.",
        "address_1": "A104, Seoul Business Incubator",
        "address_2": "Seoul    157-030,",
        "country": "KR"
    },
    "0005B8": {
        "oui_hex": "00-05-B8",
        "organization": "Electronic Design Associates, Inc.",
        "address_1": "331 Arcado Rd. NW",
        "address_2": "Lilburn  GA  30047-2841",
        "country": "US"
    },
    "0005BA": {
        "oui_hex": "00-05-BA",
        "organization": "Area Netwoeks, Inc.",
        "address_1": "1148 Euclid Ave., Suite 400",
        "address_2": "Cleveland  OH  4415",
        "country": "US"
    },
    "0005BF": {
        "oui_hex": "00-05-BF",
        "organization": "JustEzy Technology, Inc.",
        "address_1": "5F, No. 324, Sec. 1, Junghua Rd.",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "0005D5": {
        "oui_hex": "00-05-D5",
        "organization": "Speedcom Wireless",
        "address_1": "7020 Professional Pkwy East",
        "address_2": "Sarasota  FL  34240-8514",
        "country": "US"
    },
    "0005C5": {
        "oui_hex": "00-05-C5",
        "organization": "Flaga HF",
        "address_1": "Vesturhlid 7",
        "address_2": "",
        "country": "IS"
    },
    "0005CA": {
        "oui_hex": "00-05-CA",
        "organization": "Hitron Technology, Inc.",
        "address_1": "HSINCHU SBIP SUBSIDIARY",
        "address_2": "Hsin-chu",
        "country": "TW"
    },
    "0005D2": {
        "oui_hex": "00-05-D2",
        "organization": "DAP Technologies",
        "address_1": "955 Fernand Dufour,",
        "address_2": "    G1M 3B2",
        "country": "CA"
    },
    "0005B1": {
        "oui_hex": "00-05-B1",
        "organization": "ASB Technology BV",
        "address_1": "De Ronde 15A",
        "address_2": "",
        "country": "NL"
    },
    "000599": {
        "oui_hex": "00-05-99",
        "organization": "DRS Test and Energy Management or DRS-TEM",
        "address_1": "110 Wynn Drive",
        "address_2": "Huntsville  AL  35805",
        "country": "US"
    },
    "00059A": {
        "oui_hex": "00-05-9A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0005AB": {
        "oui_hex": "00-05-AB",
        "organization": "Cyber Fone, Inc.",
        "address_1": "989 Old Eagle School Road",
        "address_2": "Wayne  PA  19087",
        "country": "US"
    },
    "000592": {
        "oui_hex": "00-05-92",
        "organization": "Pultek Corp.",
        "address_1": "74-1, Yamashita-cho,",
        "address_2": "    231-0023",
        "country": "JP"
    },
    "00058B": {
        "oui_hex": "00-05-8B",
        "organization": "IPmental, Inc.",
        "address_1": "8F-9, No. 35, Hsin Tai Rd.",
        "address_2": "",
        "country": "TW"
    },
    "0005AC": {
        "oui_hex": "00-05-AC",
        "organization": "Northern Digital, Inc.",
        "address_1": "103 Randall Drive",
        "address_2": "Waterloo   Ontario  N2V 1C5",
        "country": "CA"
    },
    "0005AD": {
        "oui_hex": "00-05-AD",
        "organization": "Topspin Communications, Inc.",
        "address_1": "515 Ellis Street",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0005D1": {
        "oui_hex": "00-05-D1",
        "organization": "Metavector Technologies",
        "address_1": "Steenweg Op Gierle, 100",
        "address_2": "",
        "country": "BE"
    },
    "0005FB": {
        "oui_hex": "00-05-FB",
        "organization": "ShareGate, Inc.",
        "address_1": "9805 Double R Blvd.",
        "address_2": "Reno  NV  89511-5917",
        "country": "US"
    },
    "0005FE": {
        "oui_hex": "00-05-FE",
        "organization": "Traficon N.V.",
        "address_1": "Bissegemsestraat 45",
        "address_2": "",
        "country": "BE"
    },
    "0005F0": {
        "oui_hex": "00-05-F0",
        "organization": "SATEC",
        "address_1": "P.O. Box 45022",
        "address_2": "  91450",
        "country": "IL"
    },
    "000530": {
        "oui_hex": "00-05-30",
        "organization": "Andiamo Systems, Inc.",
        "address_1": "375 E. Tasman Dr.",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000538": {
        "oui_hex": "00-05-38",
        "organization": "Merilus, Inc.",
        "address_1": "#307-46165 Yale Road",
        "address_2": "    V2P 2P2",
        "country": "CA"
    },
    "00052B": {
        "oui_hex": "00-05-2B",
        "organization": "HORIBA, Ltd.",
        "address_1": "2 Miyanohigashi, Kisshoin,",
        "address_2": "    601-8510",
        "country": "JP"
    },
    "00051D": {
        "oui_hex": "00-05-1D",
        "organization": "Airocon, Inc.",
        "address_1": "116 Houghton Lane",
        "address_2": "Boxboro  MA  01719",
        "country": "US"
    },
    "000515": {
        "oui_hex": "00-05-15",
        "organization": "Nuark Co., Ltd.",
        "address_1": "12F, Anyang K center, 1591-9, Burim-dong",
        "address_2": "  Gunggi-do  431-065",
        "country": "KR"
    },
    "000516": {
        "oui_hex": "00-05-16",
        "organization": "SMART Modular Technologies",
        "address_1": "4305 Cushing Pkwy",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000577": {
        "oui_hex": "00-05-77",
        "organization": "SM Information & Communication",
        "address_1": "330-1 Yangjaedong",
        "address_2": "    137-130",
        "country": "KR"
    },
    "000570": {
        "oui_hex": "00-05-70",
        "organization": "Baydel Ltd.",
        "address_1": "Baydel House",
        "address_2": "",
        "country": "GB"
    },
    "00056E": {
        "oui_hex": "00-05-6E",
        "organization": "National Enhance Technology, Inc.",
        "address_1": "2F, No. 196-3, Tatung Rd., Sec. 3,",
        "address_2": "",
        "country": "TW"
    },
    "00056D": {
        "oui_hex": "00-05-6D",
        "organization": "Pacific Corporation",
        "address_1": "2-23-3 Ebisu-Minami Shibuya",
        "address_2": "",
        "country": "JP"
    },
    "000581": {
        "oui_hex": "00-05-81",
        "organization": "Snell",
        "address_1": "Southleigh Park House",
        "address_2": "Hampshire    P09 2PE",
        "country": "GB"
    },
    "00057D": {
        "oui_hex": "00-05-7D",
        "organization": "Sun Communications, Inc.",
        "address_1": "Gloria Bldg 6th",
        "address_2": "Tokyo    162-082",
        "country": "JP"
    },
    "000586": {
        "oui_hex": "00-05-86",
        "organization": "Lucent Technologies",
        "address_1": "1701 Harbor Bay Parkway",
        "address_2": "Alameda  CA  94502",
        "country": "US"
    },
    "00057B": {
        "oui_hex": "00-05-7B",
        "organization": "Chung Nam Electronic Co., Ltd.",
        "address_1": "Unit 3, 1/F, Festigood Centre",
        "address_2": "Tsuen  Fanling,",
        "country": "HK"
    },
    "000571": {
        "oui_hex": "00-05-71",
        "organization": "Seiwa Electronics Co.",
        "address_1": "757 Amabouki, Kukizaki-Machi",
        "address_2": "    300-1253",
        "country": "JP"
    },
    "000549": {
        "oui_hex": "00-05-49",
        "organization": "Salira Optical Network Systems",
        "address_1": "2694 Orchard Parkway",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00054C": {
        "oui_hex": "00-05-4C",
        "organization": "RF Innovations Pty Ltd",
        "address_1": "22 Boulder Road",
        "address_2": "Malaga  WA   6090",
        "country": "AU"
    },
    "000543": {
        "oui_hex": "00-05-43",
        "organization": "IQ Wireless GmbH",
        "address_1": "Carl-Scheele-Str. 14",
        "address_2": "",
        "country": "DE"
    },
    "00055C": {
        "oui_hex": "00-05-5C",
        "organization": "Kowa Company, Ltd.",
        "address_1": "Chofugaoka 3-3-1,",
        "address_2": "    182-0021",
        "country": "JP"
    },
    "000510": {
        "oui_hex": "00-05-10",
        "organization": "Infinite Shanghai Communication Terminals Ltd.",
        "address_1": "777 Chungiao Road, Pudong",
        "address_2": "",
        "country": "CN"
    },
    "0004FF": {
        "oui_hex": "00-04-FF",
        "organization": "Acronet Co., Ltd.",
        "address_1": "Saman B/D 2Fl",
        "address_2": "    137-064",
        "country": "KR"
    },
    "000501": {
        "oui_hex": "00-05-01",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000508": {
        "oui_hex": "00-05-08",
        "organization": "Inetcam, Inc.",
        "address_1": "10171 Pacific Mesa Blvd.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00051B": {
        "oui_hex": "00-05-1B",
        "organization": "Magic Control Technology Corporation",
        "address_1": "6F, No. 120-11 Chung Shan Rd.",
        "address_2": "",
        "country": "TW"
    },
    "000513": {
        "oui_hex": "00-05-13",
        "organization": "VTLinx Multimedia Systems, Inc.",
        "address_1": "8401 Colesville Road,",
        "address_2": "Silver Spring  MD  20910",
        "country": "US"
    },
    "00050E": {
        "oui_hex": "00-05-0E",
        "organization": "3ware, Inc.",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mt. View  CA  94043",
        "country": "US"
    },
    "0004D7": {
        "oui_hex": "00-04-D7",
        "organization": "Omitec Instrumentation Ltd.",
        "address_1": "Hopton Industrial Est.",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0004D4": {
        "oui_hex": "00-04-D4",
        "organization": "Proview Electronics Co., Ltd.",
        "address_1": "6F, No. 1, Pau-Sheng Road",
        "address_2": "",
        "country": "TW"
    },
    "0004DB": {
        "oui_hex": "00-04-DB",
        "organization": "Tellus Group Corp.",
        "address_1": "4F, No. 15 Industry E. Rd., IX",
        "address_2": "Hsinchu  Hsinchu  Taiwan",
        "country": "TW"
    },
    "0004E0": {
        "oui_hex": "00-04-E0",
        "organization": "Procket Networks",
        "address_1": "1100 Cadillac Court",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0004DD": {
        "oui_hex": "00-04-DD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "008086": {
        "oui_hex": "00-80-86",
        "organization": "COMPUTER GENERATION INC.",
        "address_1": "3855 PRESIDENTIAL PARKWAY",
        "address_2": "ATLANTA  GA  30340",
        "country": "US"
    },
    "000504": {
        "oui_hex": "00-05-04",
        "organization": "Naray Information & Communication Enterprise",
        "address_1": "3F San Woo Bldg., 1543-11",
        "address_2": "Seoul 137-070",
        "country": "KR"
    },
    "000509": {
        "oui_hex": "00-05-09",
        "organization": "AVOC Nishimura Ltd.",
        "address_1": "Jogasaki 4-16-14",
        "address_2": "",
        "country": "JP"
    },
    "0004FB": {
        "oui_hex": "00-04-FB",
        "organization": "Commtech, Inc.",
        "address_1": "9011 E. 37th Street",
        "address_2": "Wichita  KS  67226-2006",
        "country": "US"
    },
    "0004C0": {
        "oui_hex": "00-04-C0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0004BA": {
        "oui_hex": "00-04-BA",
        "organization": "KDD Media Will Corporation",
        "address_1": "2-1-23 Nakameguro",
        "address_2": "  153-0061",
        "country": "JP"
    },
    "0004B6": {
        "oui_hex": "00-04-B6",
        "organization": "Stratex Networks, Inc.",
        "address_1": "64 White Road",
        "address_2": "Cape Town    7945",
        "country": "ZA"
    },
    "0004CD": {
        "oui_hex": "00-04-CD",
        "organization": "Extenway Solutions Inc",
        "address_1": "500 boul. Morgan",
        "address_2": "Baie-d'Urfe  Quebec H9X 3V1",
        "country": "CA"
    },
    "0004E9": {
        "oui_hex": "00-04-E9",
        "organization": "Infiniswitch Corporation",
        "address_1": "134 Flanders Road",
        "address_2": "Westborough  MA  01581",
        "country": "US"
    },
    "0004E8": {
        "oui_hex": "00-04-E8",
        "organization": "IER, Inc.",
        "address_1": "4501 So. General Bruce Dr",
        "address_2": "Temple  TX  76502",
        "country": "US"
    },
    "0004B3": {
        "oui_hex": "00-04-B3",
        "organization": "Videotek, Inc.",
        "address_1": "243 Shoemaker Rd.",
        "address_2": "Pottstown  PA  19464",
        "country": "US"
    },
    "00044C": {
        "oui_hex": "00-04-4C",
        "organization": "JENOPTIK",
        "address_1": "Laser, Optik, Systeme GmbH",
        "address_2": "",
        "country": "DE"
    },
    "000444": {
        "oui_hex": "00-04-44",
        "organization": "Western Multiplex Corporation",
        "address_1": "1196 Borregas Avenue",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000439": {
        "oui_hex": "00-04-39",
        "organization": "Rosco Entertainment Technology, Inc.",
        "address_1": "2181 NW Front Ave.",
        "address_2": "Portland  OR  97209",
        "country": "US"
    },
    "00043A": {
        "oui_hex": "00-04-3A",
        "organization": "Intelligent Telecommunications, Inc.",
        "address_1": "1687-2, Sinil-dong",
        "address_2": "SOUTH  KOREA  306-230",
        "country": "KR"
    },
    "000492": {
        "oui_hex": "00-04-92",
        "organization": "Hive Internet, Ltd.",
        "address_1": "Unit 2, Church View Business Centre",
        "address_2": "Binbrook  Market Rasen, Lincolnshire  LN8 6BY",
        "country": "GB"
    },
    "00048C": {
        "oui_hex": "00-04-8C",
        "organization": "Nayna Networks, Inc.",
        "address_1": "157 Topaz St.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000491": {
        "oui_hex": "00-04-91",
        "organization": "Technovision, Inc.",
        "address_1": "5155 Spectrum Way, Unit #31",
        "address_2": "L4W  5A1",
        "country": "CA"
    },
    "000493": {
        "oui_hex": "00-04-93",
        "organization": "Tsinghua Unisplendour Co., Ltd.",
        "address_1": "Th-Unis Building Tsinghua",
        "address_2": "  P.R.",
        "country": "CN"
    },
    "000494": {
        "oui_hex": "00-04-94",
        "organization": "Breezecom, Ltd.",
        "address_1": "Atidim Technology Park",
        "address_2": "",
        "country": "IL"
    },
    "000489": {
        "oui_hex": "00-04-89",
        "organization": "YAFO Networks, Inc.",
        "address_1": "1340F Charwood Rd.",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "00048A": {
        "oui_hex": "00-04-8A",
        "organization": "Temia Vertriebs GmbH",
        "address_1": "Landsbergerstraße 320",
        "address_2": "",
        "country": "DE"
    },
    "000481": {
        "oui_hex": "00-04-81",
        "organization": "Econolite Control Products, Inc.",
        "address_1": "3360 E. La Palma Ave.",
        "address_2": "Anaheim  CA  92806",
        "country": "US"
    },
    "00046C": {
        "oui_hex": "00-04-6C",
        "organization": "Cyber Technology Co., Ltd.",
        "address_1": "1-45 Yeo Wol-Dong",
        "address_2": "Kyeong Gi-Do  Kyeong Gi-Do  KOREA",
        "country": "KR"
    },
    "000471": {
        "oui_hex": "00-04-71",
        "organization": "IPrad",
        "address_1": "24 Raoul Wallenberg St.",
        "address_2": "",
        "country": "IL"
    },
    "00046E": {
        "oui_hex": "00-04-6E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000474": {
        "oui_hex": "00-04-74",
        "organization": "LEGRAND",
        "address_1": "145 Avenue De Lattre",
        "address_2": "",
        "country": "FR"
    },
    "00042D": {
        "oui_hex": "00-04-2D",
        "organization": "Sarian Systems, Ltd.",
        "address_1": "Beacon House",
        "address_2": "West Yorkshire  ENGLAND  LS29 8JZ",
        "country": "GB"
    },
    "00042E": {
        "oui_hex": "00-04-2E",
        "organization": "Netous Technologies, Ltd.",
        "address_1": "1006, Block A,",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "000425": {
        "oui_hex": "00-04-25",
        "organization": "Atmel Corporation",
        "address_1": "Multimedia & Communications Group",
        "address_2": "Morrisville  NC  27560",
        "country": "US"
    },
    "00043F": {
        "oui_hex": "00-04-3F",
        "organization": "ESTeem Wireless Modems, Inc",
        "address_1": "415 N. Quay St., Suite 4",
        "address_2": "Kennewick  WA  99336",
        "country": "US"
    },
    "000433": {
        "oui_hex": "00-04-33",
        "organization": "Cyberboard A/S",
        "address_1": "Kloevermarken 120",
        "address_2": "",
        "country": "DK"
    },
    "000434": {
        "oui_hex": "00-04-34",
        "organization": "Accelent Systems, Inc.",
        "address_1": "2620 Ridgewood Rd.,",
        "address_2": "Akron  OH  44313",
        "country": "US"
    },
    "000477": {
        "oui_hex": "00-04-77",
        "organization": "Scalant Systems, Inc.",
        "address_1": "2040 Martin Avenue",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "000473": {
        "oui_hex": "00-04-73",
        "organization": "Photonex Corporation",
        "address_1": "8C Preston Court",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "000470": {
        "oui_hex": "00-04-70",
        "organization": "ipUnplugged AB",
        "address_1": "Box 10160",
        "address_2": "",
        "country": "SE"
    },
    "00045D": {
        "oui_hex": "00-04-5D",
        "organization": "BEKA Elektronik",
        "address_1": "Siemenstraße 29",
        "address_2": "  Erftstadt  50374",
        "country": "DE"
    },
    "000459": {
        "oui_hex": "00-04-59",
        "organization": "Veristar Corporation",
        "address_1": "727 Allston Way",
        "address_2": "Berkeley  CA  94710",
        "country": "US"
    },
    "0004A4": {
        "oui_hex": "00-04-A4",
        "organization": "NetEnabled, Inc.",
        "address_1": "1275 Kinnear Rd.",
        "address_2": "Columbus  OH  43212",
        "country": "US"
    },
    "000416": {
        "oui_hex": "00-04-16",
        "organization": "Parks S/A Comunicacoes Digitais",
        "address_1": "Av. Pernambuco, 1001",
        "address_2": "",
        "country": "BR"
    },
    "00040F": {
        "oui_hex": "00-04-0F",
        "organization": "Asus Network Technologies, Inc.",
        "address_1": "11-1, No. 675, Sec. 1, King-kuo Rd.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00040A": {
        "oui_hex": "00-04-0A",
        "organization": "Sage Systems",
        "address_1": "1420 Harbor Bay Parkway",
        "address_2": "Alameda  CA  94502",
        "country": "US"
    },
    "000404": {
        "oui_hex": "00-04-04",
        "organization": "Makino Milling Machine Co., Ltd.",
        "address_1": "4023 Nakatsu, Aikawa-machi",
        "address_2": "Aiko-gun  Kanagawa  243-0303",
        "country": "JP"
    },
    "0003D0": {
        "oui_hex": "00-03-D0",
        "organization": "KOANKEISO Co., Ltd.",
        "address_1": "Zip Code 791-8042",
        "address_2": "",
        "country": "JP"
    },
    "0003CF": {
        "oui_hex": "00-03-CF",
        "organization": "Muxcom, Inc.",
        "address_1": "D 602, Bundang Technopark #151",
        "address_2": "Kyungki Do  KOREA  463-070",
        "country": "KR"
    },
    "0003D1": {
        "oui_hex": "00-03-D1",
        "organization": "Takaya Corporation",
        "address_1": "Development Division",
        "address_2": "",
        "country": "JP"
    },
    "0003AD": {
        "oui_hex": "00-03-AD",
        "organization": "Emerson Energy Systems AB",
        "address_1": "PO Box 92113",
        "address_2": "",
        "country": "SE"
    },
    "0003A7": {
        "oui_hex": "00-03-A7",
        "organization": "Unixtar Technology, Inc.",
        "address_1": "13F No. 100 Ming Chuan Road",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "0003AE": {
        "oui_hex": "00-03-AE",
        "organization": "Allied Advanced Manufacturing Pte, Ltd.",
        "address_1": "7 International Business Park",
        "address_2": "  Singapore  609919",
        "country": "SG"
    },
    "0003A3": {
        "oui_hex": "00-03-A3",
        "organization": "MAVIX, Ltd.",
        "address_1": "POB 217, Yokneam Illit,",
        "address_2": "    20692",
        "country": "IL"
    },
    "0003B6": {
        "oui_hex": "00-03-B6",
        "organization": "QSI Corporation",
        "address_1": "2212 South West Temple #50",
        "address_2": "Salt Lake City  UT  84115",
        "country": "US"
    },
    "0003B1": {
        "oui_hex": "00-03-B1",
        "organization": "Hospira Inc.",
        "address_1": "755 Jarvis Drive",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "0003B3": {
        "oui_hex": "00-03-B3",
        "organization": "IA Link Systems Co., Ltd.",
        "address_1": "6F-4, No. 81 Hsin Tai",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0003EB": {
        "oui_hex": "00-03-EB",
        "organization": "Atrica",
        "address_1": "5 Shenkar St. P.O.B. 12231",
        "address_2": "46733  46733",
        "country": "IL"
    },
    "0003E7": {
        "oui_hex": "00-03-E7",
        "organization": "Logostek Co. Ltd.",
        "address_1": "19th 15 Sunusu-Academy Tower",
        "address_2": "Seoul  KOREA  133-123",
        "country": "KR"
    },
    "0003E3": {
        "oui_hex": "00-03-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0003F4": {
        "oui_hex": "00-03-F4",
        "organization": "NetBurner",
        "address_1": "5405 Morehouse Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0003F2": {
        "oui_hex": "00-03-F2",
        "organization": "Seneca Networks",
        "address_1": "30 West Gude Dr.",
        "address_2": "Rockville  MD  20850",
        "country": "US"
    },
    "0003F0": {
        "oui_hex": "00-03-F0",
        "organization": "Redfern Broadband Networks",
        "address_1": "Level 1, 1 Central Ave.,",
        "address_2": "",
        "country": "AU"
    },
    "0003DB": {
        "oui_hex": "00-03-DB",
        "organization": "Apogee Electronics Corp.",
        "address_1": "1715 Berkeley St.",
        "address_2": "Santa Monica  CA  90405-3210",
        "country": "US"
    },
    "0003D2": {
        "oui_hex": "00-03-D2",
        "organization": "Crossbeam Systems, Inc.",
        "address_1": "80 Central Street",
        "address_2": "Boxborough  MA  01719",
        "country": "US"
    },
    "000405": {
        "oui_hex": "00-04-05",
        "organization": "ACN Technologies",
        "address_1": "9F, HeyKang B/D, 157-36",
        "address_2": "Seoul  KOREA  #135-090",
        "country": "KR"
    },
    "000401": {
        "oui_hex": "00-04-01",
        "organization": "Osaki Electric Co., Ltd.",
        "address_1": "1131, Fujikubo, Miyoshimachi,",
        "address_2": "",
        "country": "JP"
    },
    "00041B": {
        "oui_hex": "00-04-1B",
        "organization": "Bridgeworks Ltd.",
        "address_1": "135 Somerford Road",
        "address_2": "Christchurch  DORSET  BH23 3PY",
        "country": "GB"
    },
    "0003A1": {
        "oui_hex": "00-03-A1",
        "organization": "HIPER Information & Communication, Inc.",
        "address_1": "1675-7, Sinil-dong,",
        "address_2": "306-230  South  Korea",
        "country": "KR"
    },
    "000396": {
        "oui_hex": "00-03-96",
        "organization": "EZ Cast Co., Ltd.",
        "address_1": "6th Floor, JungAng Building,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00039A": {
        "oui_hex": "00-03-9A",
        "organization": "SiConnect",
        "address_1": "Delta 100",
        "address_2": "Swindon    SN5 7XP",
        "country": "GB"
    },
    "000363": {
        "oui_hex": "00-03-63",
        "organization": "Miraesys Co., Ltd.",
        "address_1": "650-2 4 Fl. Daemyung Bldg.",
        "address_2": "    135-080",
        "country": "KR"
    },
    "00035F": {
        "oui_hex": "00-03-5F",
        "organization": "Prüftechnik Condition Monitoring GmbH & Co. KG",
        "address_1": "Franz-Bayer-Straße 14",
        "address_2": "",
        "country": "DE"
    },
    "000360": {
        "oui_hex": "00-03-60",
        "organization": "PAC Interactive Technology, Inc.",
        "address_1": "6F, No. 30, Alley 18, Lane 478",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000361": {
        "oui_hex": "00-03-61",
        "organization": "Widcomm, Inc.",
        "address_1": "9645 Scranton Road",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000394": {
        "oui_hex": "00-03-94",
        "organization": "Connect One",
        "address_1": "2 Hanagar Street",
        "address_2": "",
        "country": "IL"
    },
    "00038A": {
        "oui_hex": "00-03-8A",
        "organization": "America Online, Inc.",
        "address_1": "44900 Prentice Drive",
        "address_2": "Dulles  VA  20166",
        "country": "US"
    },
    "00038D": {
        "oui_hex": "00-03-8D",
        "organization": "PCS Revenue Control Systems, Inc.",
        "address_1": "560 Sylvan Ave.",
        "address_2": "Englewood Cliffs  NJ  07632",
        "country": "US"
    },
    "000388": {
        "oui_hex": "00-03-88",
        "organization": "Fastfame Technology Co., Ltd.",
        "address_1": "7F, No. 111, Hsing De Rd.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000359": {
        "oui_hex": "00-03-59",
        "organization": "DigitalSis",
        "address_1": "B-1405 Samho Bldg.",
        "address_2": "Seocho  Seoul,",
        "country": "KR"
    },
    "000352": {
        "oui_hex": "00-03-52",
        "organization": "Colubris Networks",
        "address_1": "440 Armand-Frappier",
        "address_2": "    H7V 4B4",
        "country": "CA"
    },
    "00034C": {
        "oui_hex": "00-03-4C",
        "organization": "Shanghai DigiVision Technology Co., Ltd.",
        "address_1": "11F, Heng Tong",
        "address_2": "  Shanghai  200050",
        "country": "CN"
    },
    "000378": {
        "oui_hex": "00-03-78",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "271-2, Suh-hyun-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "000374": {
        "oui_hex": "00-03-74",
        "organization": "Control Microsystems",
        "address_1": "48 Steacie Drive",
        "address_2": "Ottawa  Ontario  K2K 2A9",
        "country": "CA"
    },
    "000376": {
        "oui_hex": "00-03-76",
        "organization": "Graphtec Technology, Inc.",
        "address_1": "45 Parker, Suite A",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "00037E": {
        "oui_hex": "00-03-7E",
        "organization": "PORTech Communications, Inc.",
        "address_1": "150, Shiang-Shung N. Rd.,",
        "address_2": "Taichung  Taiwan  403, R.O.C.",
        "country": "TW"
    },
    "00036D": {
        "oui_hex": "00-03-6D",
        "organization": "Runtop, Inc.",
        "address_1": "1, Lane 21, Hsin Hua Road, Kueishan",
        "address_2": "",
        "country": "TW"
    },
    "00036E": {
        "oui_hex": "00-03-6E",
        "organization": "Nicon Systems (Pty) Limited",
        "address_1": "11 Termo Street",
        "address_2": "",
        "country": "ZA"
    },
    "000371": {
        "oui_hex": "00-03-71",
        "organization": "Acomz Networks Corp.",
        "address_1": "7th Fl., Wooseok Bldg., 1007-37",
        "address_2": "Seoul    156-09",
        "country": "KR"
    },
    "000349": {
        "oui_hex": "00-03-49",
        "organization": "Vidicode Datacommunicatie B.V.",
        "address_1": "Postbus 7164",
        "address_2": "",
        "country": "NL"
    },
    "00033E": {
        "oui_hex": "00-03-3E",
        "organization": "Tateyama System Laboratory Co., Ltd.",
        "address_1": "30 Shimonoban Oyama-cho",
        "address_2": "    930-1305",
        "country": "JP"
    },
    "00033C": {
        "oui_hex": "00-03-3C",
        "organization": "Daiden Co., Ltd.",
        "address_1": "2100-19 Tutumi, Kamimine-machi",
        "address_2": "",
        "country": "JP"
    },
    "000325": {
        "oui_hex": "00-03-25",
        "organization": "Arima Computer Corp.",
        "address_1": "6th Fl., No. 327,",
        "address_2": "",
        "country": "TW"
    },
    "00031F": {
        "oui_hex": "00-03-1F",
        "organization": "Condev Ltd.",
        "address_1": "200-1626 West 2nd Ave.",
        "address_2": "",
        "country": "CA"
    },
    "00029F": {
        "oui_hex": "00-02-9F",
        "organization": "L-3 Communication Aviation Recorders",
        "address_1": "P.O. Box 3041",
        "address_2": "Sarasota  FL  34230",
        "country": "US"
    },
    "00031B": {
        "oui_hex": "00-03-1B",
        "organization": "Cellvision Systems, Inc.",
        "address_1": "3F-1, 75, Hsin Taiwu Road, Sec. 1",
        "address_2": "",
        "country": "TW"
    },
    "00031C": {
        "oui_hex": "00-03-1C",
        "organization": "Svenska Hardvarufabriken AB",
        "address_1": "Ole Romersvag 16, Ideon",
        "address_2": "",
        "country": "SE"
    },
    "0001A8": {
        "oui_hex": "00-01-A8",
        "organization": "Welltech Computer Co., Ltd.",
        "address_1": "13F-4, no. 150, Jian Yi Road",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00030C": {
        "oui_hex": "00-03-0C",
        "organization": "Telesoft Technologies Ltd.",
        "address_1": "Observatory House, Stour Park,",
        "address_2": "",
        "country": "GB"
    },
    "000308": {
        "oui_hex": "00-03-08",
        "organization": "AM Communications, Inc.",
        "address_1": "100 Commerce Blvd.",
        "address_2": "Quakertown  PA  18951",
        "country": "US"
    },
    "000307": {
        "oui_hex": "00-03-07",
        "organization": "Secure Works, Inc.",
        "address_1": "11 Executive Drive",
        "address_2": "Atlanta  GA  30329",
        "country": "US"
    },
    "000306": {
        "oui_hex": "00-03-06",
        "organization": "Fusion In Tech Co., Ltd.",
        "address_1": "6Fl, Daeyoon Bldg. 1688-5, Seocho-dong",
        "address_2": "Seoul,",
        "country": "KR"
    },
    "0002FC": {
        "oui_hex": "00-02-FC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0002FA": {
        "oui_hex": "00-02-FA",
        "organization": "DX Antenna Co., Ltd.",
        "address_1": "2-15 Hamazaki-Dori,",
        "address_2": "",
        "country": "JP"
    },
    "0002FB": {
        "oui_hex": "00-02-FB",
        "organization": "Baumuller Aulugen-Systemtechnik GmbH",
        "address_1": "Ostendsts. 84",
        "address_2": "",
        "country": "DE"
    },
    "0002F6": {
        "oui_hex": "00-02-F6",
        "organization": "Equipe Communications",
        "address_1": "100 Nagog Park",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "000223": {
        "oui_hex": "00-02-23",
        "organization": "ClickTV",
        "address_1": "Kemong Bldg., 4th Fl.,",
        "address_2": "Seoul  Korea  135-010",
        "country": "KR"
    },
    "0002CB": {
        "oui_hex": "00-02-CB",
        "organization": "TriState Ltd.",
        "address_1": "Shinonaga Blg. 4-11-19 Hokko-cho",
        "address_2": "053-0852  053-0852",
        "country": "JP"
    },
    "0002CA": {
        "oui_hex": "00-02-CA",
        "organization": "EndPoints, Inc.",
        "address_1": "4 Preston Court",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "00032A": {
        "oui_hex": "00-03-2A",
        "organization": "UniData Communication Systems, Inc.",
        "address_1": "2F, OhSung-Bldg, 82-15,",
        "address_2": "",
        "country": "KR"
    },
    "000324": {
        "oui_hex": "00-03-24",
        "organization": "SANYO Consumer Electronics Co., Ltd.",
        "address_1": "7-101 Tachikawa-cho",
        "address_2": "Tottori City    680-8634",
        "country": "JP"
    },
    "0002BF": {
        "oui_hex": "00-02-BF",
        "organization": "dotRocket, Inc.",
        "address_1": "1901 S. Bascom, Suite 300",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "000317": {
        "oui_hex": "00-03-17",
        "organization": "Merlin Systems, Inc.",
        "address_1": "3900 New Park Mall Rd.",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "000318": {
        "oui_hex": "00-03-18",
        "organization": "Cyras Systems, Inc.",
        "address_1": "47100 Bayside Parkway",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0002E3": {
        "oui_hex": "00-02-E3",
        "organization": "LITE-ON Communications, Inc.",
        "address_1": "736 S. Hillview Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0002DD": {
        "oui_hex": "00-02-DD",
        "organization": "Bromax Communications, Ltd.",
        "address_1": "No. 20 Kuang Fu Road,",
        "address_2": "Hsin Chu 303",
        "country": "TW"
    },
    "000247": {
        "oui_hex": "00-02-47",
        "organization": "Great Dragon Information Technology (Group) Co., Ltd.",
        "address_1": "169 Beiyuan Rd.,",
        "address_2": "Beijing  100101,",
        "country": "CN"
    },
    "000243": {
        "oui_hex": "00-02-43",
        "organization": "Raysis Co., Ltd.",
        "address_1": "997-10, Daechi-Dong, Kangnam-Ku,",
        "address_2": "Seoul  135-280,  South Korea",
        "country": "KR"
    },
    "000231": {
        "oui_hex": "00-02-31",
        "organization": "Ingersoll-Rand",
        "address_1": "1467 Route 31 South",
        "address_2": "Annandale  NJ  08801",
        "country": "US"
    },
    "000266": {
        "oui_hex": "00-02-66",
        "organization": "Thermalogic Corporation",
        "address_1": "22 Kane Industrial Drive",
        "address_2": "Hudson  MA  01749",
        "country": "US"
    },
    "000268": {
        "oui_hex": "00-02-68",
        "organization": "Harris Government Communications",
        "address_1": "Systems Division",
        "address_2": "Melbourne  FL  32902",
        "country": "US"
    },
    "00025E": {
        "oui_hex": "00-02-5E",
        "organization": "High Technology Ltd",
        "address_1": "Chongqing Jinghong",
        "address_2": "People's Republic  of",
        "country": "CN"
    },
    "000260": {
        "oui_hex": "00-02-60",
        "organization": "Accordion Networks, Inc.",
        "address_1": "39899 Balentine Drive, #335",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "000283": {
        "oui_hex": "00-02-83",
        "organization": "Spectrum Controls, Inc.",
        "address_1": "PO Box 5533",
        "address_2": "Bellevue  WA  98006",
        "country": "US"
    },
    "000284": {
        "oui_hex": "00-02-84",
        "organization": "UK Grid Solutions Limited",
        "address_1": "St Leonards Building  Redhill Business Park",
        "address_2": "Stafford    ST16 1TW",
        "country": "GB"
    },
    "000280": {
        "oui_hex": "00-02-80",
        "organization": "Mu Net, Inc.",
        "address_1": "442 Marrett Road",
        "address_2": "Lexington  MA  02421",
        "country": "US"
    },
    "009064": {
        "oui_hex": "00-90-64",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290-1102",
        "country": "US"
    },
    "00027A": {
        "oui_hex": "00-02-7A",
        "organization": "IOI Technology Corporation",
        "address_1": "4F-3 No. 125 Lane 235,",
        "address_2": "Taipei  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "000274": {
        "oui_hex": "00-02-74",
        "organization": "Tommy Technologies Corp.",
        "address_1": "#407 Heehoon Bld",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "00029E": {
        "oui_hex": "00-02-9E",
        "organization": "Information Equipment Co., Ltd.",
        "address_1": "740-1 Eaho Bldg., Yeok Sam-Dong",
        "address_2": "Seoul  Korea  #135-080",
        "country": "KR"
    },
    "00029B": {
        "oui_hex": "00-02-9B",
        "organization": "Kreatel Communications AB",
        "address_1": "Teknikringen 4C",
        "address_2": "",
        "country": "SE"
    },
    "000295": {
        "oui_hex": "00-02-95",
        "organization": "IP.Access Limited",
        "address_1": "Melbourn Science Park",
        "address_2": "SG8 6EE  SG8 6EE  U.K.",
        "country": "GB"
    },
    "000272": {
        "oui_hex": "00-02-72",
        "organization": "CC&C Technologies, Inc.",
        "address_1": "8F, 150, Chien I Rd., Chung Ho City,",
        "address_2": "Taipei County 235  Taiwan  R.O.C.",
        "country": "TW"
    },
    "00026D": {
        "oui_hex": "00-02-6D",
        "organization": "Adept Telecom",
        "address_1": "Avenue de l'Europe",
        "address_2": "",
        "country": "FR"
    },
    "00026B": {
        "oui_hex": "00-02-6B",
        "organization": "BCM Computers Co., Ltd.",
        "address_1": "6F-6, No. 66, Sec 2,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000293": {
        "oui_hex": "00-02-93",
        "organization": "Solid Data Systems",
        "address_1": "2945 Oakmead Village Court",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "000289": {
        "oui_hex": "00-02-89",
        "organization": "DNE Technologies",
        "address_1": "50 Barnes Park N",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "00012F": {
        "oui_hex": "00-01-2F",
        "organization": "Twinhead International Corp",
        "address_1": "2FL, 2, Lane 235, Bao-Chiao Road",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0002A7": {
        "oui_hex": "00-02-A7",
        "organization": "Vivace Networks",
        "address_1": "2730 Orchard Parkway",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0001B2": {
        "oui_hex": "00-01-B2",
        "organization": "Digital Processing Systems, Inc.",
        "address_1": "70 Valleywood Drive",
        "address_2": "  L3R  4T5",
        "country": "CA"
    },
    "0001B8": {
        "oui_hex": "00-01-B8",
        "organization": "Netsensity, Inc.",
        "address_1": "PO Box 1060",
        "address_2": "Lake Forest  CA  92630",
        "country": "US"
    },
    "0001B9": {
        "oui_hex": "00-01-B9",
        "organization": "SKF (U.K.) Limited",
        "address_1": "2 Michaelson Square Kirkton Campus",
        "address_2": "Livingston    West Lothian  EH54 7DP",
        "country": "GB"
    },
    "0001B3": {
        "oui_hex": "00-01-B3",
        "organization": "Precision Electronic Manufacturing",
        "address_1": "P0187, P.O. 527948",
        "address_2": "Miami  FL  33152-7948",
        "country": "US"
    },
    "0001BD": {
        "oui_hex": "00-01-BD",
        "organization": "Peterson Electro-Musical Products, Inc.",
        "address_1": "11601 S. Mayfield Avenue",
        "address_2": "Alsip  IL  60803-2476",
        "country": "US"
    },
    "000209": {
        "oui_hex": "00-02-09",
        "organization": "Shenzhen SED Information Technology Co., Ltd.",
        "address_1": "4/F., West Block, Block 414, Zhenhua Rd.",
        "address_2": "",
        "country": "CN"
    },
    "000202": {
        "oui_hex": "00-02-02",
        "organization": "Amino Communications, Ltd.",
        "address_1": "Times House",
        "address_2": "UK  CB4  5LH",
        "country": "GB"
    },
    "000201": {
        "oui_hex": "00-02-01",
        "organization": "IFM Electronic gmbh",
        "address_1": "Bechlingen 34",
        "address_2": "",
        "country": "DE"
    },
    "000234": {
        "oui_hex": "00-02-34",
        "organization": "Imperial Technology, Inc.",
        "address_1": "2305 Utah Avenue",
        "address_2": "El Segundo  CA  90245",
        "country": "US"
    },
    "000236": {
        "oui_hex": "00-02-36",
        "organization": "INIT GmbH",
        "address_1": "Kaeppelestraße 6",
        "address_2": "",
        "country": "DE"
    },
    "00022B": {
        "oui_hex": "00-02-2B",
        "organization": "SAXA, Inc.",
        "address_1": "NBF Platinum Tower 1-17-3 Shirokane",
        "address_2": "Minato-ku  Tokyo  108-8050",
        "country": "JP"
    },
    "000224": {
        "oui_hex": "00-02-24",
        "organization": "C-COR",
        "address_1": "15 Sterling Drive",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "00021F": {
        "oui_hex": "00-02-1F",
        "organization": "Aculab PLC",
        "address_1": "Lakeside, Bramley Road",
        "address_2": "Milton Keynes    MK1 1PT",
        "country": "GB"
    },
    "00021A": {
        "oui_hex": "00-02-1A",
        "organization": "Zuma Networks",
        "address_1": "8403 Fallbrook Ave.",
        "address_2": "West Hills  CA  91304",
        "country": "US"
    },
    "0001CA": {
        "oui_hex": "00-01-CA",
        "organization": "Geocast Network Systems, Inc.",
        "address_1": "190 Independence Drive",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "0001D1": {
        "oui_hex": "00-01-D1",
        "organization": "CoNet Communications, Inc.",
        "address_1": "25 Mauchly, #320",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000222": {
        "oui_hex": "00-02-22",
        "organization": "Chromisys, Inc.",
        "address_1": "1012 Stewart Drive",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "000213": {
        "oui_hex": "00-02-13",
        "organization": "S.D.E.L.",
        "address_1": "Aeropole D2A",
        "address_2": "",
        "country": "FR"
    },
    "0001DB": {
        "oui_hex": "00-01-DB",
        "organization": "Freecom Technologies GmbH",
        "address_1": "Obentrautstraße 72",
        "address_2": "",
        "country": "DE"
    },
    "0001DF": {
        "oui_hex": "00-01-DF",
        "organization": "ISDN Communications, Ltd.",
        "address_1": "The Stable Block, Ronans",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0001EF": {
        "oui_hex": "00-01-EF",
        "organization": "Camtel Technology Corp.",
        "address_1": "No. 2, Wu-Kung 5 Rd., Wu-Ku",
        "address_2": "Taiwan  Taiwan  R.O.C.",
        "country": "TW"
    },
    "00020A": {
        "oui_hex": "00-02-0A",
        "organization": "Gefran Spa",
        "address_1": "Via Sebina, 74",
        "address_2": "",
        "country": "IT"
    },
    "000206": {
        "oui_hex": "00-02-06",
        "organization": "Telital R&D Denmark A/S",
        "address_1": "9530 Stouring",
        "address_2": "",
        "country": "DK"
    },
    "000179": {
        "oui_hex": "00-01-79",
        "organization": "WIRELESS TECHNOLOGY, INC.",
        "address_1": "Anam Bldg. 2Fl, 154-17",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "000160": {
        "oui_hex": "00-01-60",
        "organization": "ELMEX Co., LTD.",
        "address_1": "16-30 Kimachi",
        "address_2": "",
        "country": "JP"
    },
    "00014E": {
        "oui_hex": "00-01-4E",
        "organization": "WIN Enterprises, Inc.",
        "address_1": "300 Willow Street South",
        "address_2": "North Andover  MA  01845",
        "country": "US"
    },
    "003073": {
        "oui_hex": "00-30-73",
        "organization": "International Microsystems, In",
        "address_1": "521 Valley Way",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00303F": {
        "oui_hex": "00-30-3F",
        "organization": "TurboComm Tech Inc.",
        "address_1": "4F-2, No 171, Sung-Tch Road",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000184": {
        "oui_hex": "00-01-84",
        "organization": "SIEB & MEYER AG",
        "address_1": "Auf dem Schmaarkamp 21",
        "address_2": "",
        "country": "DE"
    },
    "000195": {
        "oui_hex": "00-01-95",
        "organization": "Sena Technologies, Inc.",
        "address_1": "116-23 Shinlim-dong",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001A4": {
        "oui_hex": "00-01-A4",
        "organization": "Microlink Corporation",
        "address_1": "11110 Ohio Ave., - Ste. #108",
        "address_2": "Los Angeles  CA  90034",
        "country": "US"
    },
    "00018E": {
        "oui_hex": "00-01-8E",
        "organization": "Logitec Corporation",
        "address_1": "8268 Rokudouhara, Misuzu",
        "address_2": "",
        "country": "JP"
    },
    "00016D": {
        "oui_hex": "00-01-6D",
        "organization": "CarrierComm Inc.",
        "address_1": "2231 Rutherford, Suite 110",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "00016F": {
        "oui_hex": "00-01-6F",
        "organization": "Inkel Corp.",
        "address_1": "CheongCheon-Dong, BuPyeong-Gu,",
        "address_2": "Incheon-Si",
        "country": "KR"
    },
    "000170": {
        "oui_hex": "00-01-70",
        "organization": "ESE Embedded System Engineer'g",
        "address_1": "Mühlbachstraße 20",
        "address_2": "",
        "country": "DE"
    },
    "00016A": {
        "oui_hex": "00-01-6A",
        "organization": "ALITEC",
        "address_1": "Laval Technopole B.P. 102",
        "address_2": "",
        "country": "FR"
    },
    "000153": {
        "oui_hex": "00-01-53",
        "organization": "ARCHTEK TELECOM CORPORATION",
        "address_1": "4F, No.9 Lane 130, Min-Chyuan Rd.",
        "address_2": "  231  TAIWAN",
        "country": "TW"
    },
    "000135": {
        "oui_hex": "00-01-35",
        "organization": "KDC Corp.",
        "address_1": "200-11 AnYang 7 dong",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "000141": {
        "oui_hex": "00-01-41",
        "organization": "CABLE PRINT",
        "address_1": "Jozef Cardynstraat 16",
        "address_2": "",
        "country": "BE"
    },
    "000165": {
        "oui_hex": "00-01-65",
        "organization": "AirSwitch Corporation",
        "address_1": "37East 200South",
        "address_2": "Springville  UT  84663",
        "country": "US"
    },
    "000156": {
        "oui_hex": "00-01-56",
        "organization": "FIREWIREDIRECT.COM, INC.",
        "address_1": "4132 Spicewood Springs Rd - #I-4",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0001B7": {
        "oui_hex": "00-01-B7",
        "organization": "Centos, Inc.",
        "address_1": "6F-1, NO. 15, LANE 360",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0001B5": {
        "oui_hex": "00-01-B5",
        "organization": "Turin Networks, Inc.",
        "address_1": "1415 North McDowell Blvd.",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "000183": {
        "oui_hex": "00-01-83",
        "organization": "ANITE TELECOMS",
        "address_1": "127 Fleet Road, Fleet",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00017E": {
        "oui_hex": "00-01-7E",
        "organization": "ADTEK System Science Co., Ltd.",
        "address_1": "YBP West Tower",
        "address_2": "  Hodogaya Yokohama",
        "country": "JP"
    },
    "00010C": {
        "oui_hex": "00-01-0C",
        "organization": "System Talks Inc.",
        "address_1": "4F, PrimeNihonbashi Bld.",
        "address_2": "Chuo-ku Tokyo",
        "country": "JP"
    },
    "000111": {
        "oui_hex": "00-01-11",
        "organization": "iDigm Inc.",
        "address_1": "7FL Sindo B/D 1604-22 Seocho-Dong",
        "address_2": "Seoul 137-070",
        "country": "KR"
    },
    "000107": {
        "oui_hex": "00-01-07",
        "organization": "Leiser GmbH",
        "address_1": "Ilmstr. 7",
        "address_2": "85579 Neubiberg",
        "country": "DE"
    },
    "000114": {
        "oui_hex": "00-01-14",
        "organization": "KANDA TSUSHIN KOGYO CO., LTD.",
        "address_1": "23-2, Nishi-Gotanda 2-chome,",
        "address_2": "Tokyo 141-8533",
        "country": "JP"
    },
    "00B0F5": {
        "oui_hex": "00-B0-F5",
        "organization": "NetWorth Technologies, Inc.",
        "address_1": "1000 Germantown Pike",
        "address_2": "Plymouth Metting  PA  19462",
        "country": "US"
    },
    "00B0DB": {
        "oui_hex": "00-B0-DB",
        "organization": "Nextcell, Inc.",
        "address_1": "651 East 18th Street",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "00B0AE": {
        "oui_hex": "00-B0-AE",
        "organization": "Symmetricom",
        "address_1": "2300 Orchard Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00B0E7": {
        "oui_hex": "00-B0-E7",
        "organization": "British Federal Ltd.",
        "address_1": "Castle Mill Works",
        "address_2": "Dudley DY1 4DA  England",
        "country": "GB"
    },
    "00B08E": {
        "oui_hex": "00-B0-8E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00305C": {
        "oui_hex": "00-30-5C",
        "organization": "SMAR Laboratories Corp.",
        "address_1": "10960 Millridge North - Ste. #107",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "003004": {
        "oui_hex": "00-30-04",
        "organization": "LEADTEK RESEARCH INC.",
        "address_1": "18F, No.166, Chien-Yi Road",
        "address_2": "Hsien",
        "country": "TW"
    },
    "0030F9": {
        "oui_hex": "00-30-F9",
        "organization": "Sollae Systems Co., Ltd.",
        "address_1": "607 Incheo IT Tower",
        "address_2": "Nam-gu  Incheon",
        "country": "KR"
    },
    "000118": {
        "oui_hex": "00-01-18",
        "organization": "EZ Digital Co., Ltd.",
        "address_1": "Bitville Bldg. Room 703",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00011C": {
        "oui_hex": "00-01-1C",
        "organization": "Universal Talkware Corporation",
        "address_1": "10 Second St. NE",
        "address_2": "Minneapolis  MN  55413",
        "country": "US"
    },
    "000128": {
        "oui_hex": "00-01-28",
        "organization": "EnjoyWeb, Inc.",
        "address_1": "3000 Scott Blvd. #107",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000146": {
        "oui_hex": "00-01-46",
        "organization": "Tesco Controls, Inc.",
        "address_1": "P.O. Box 239012",
        "address_2": "Sacramento  CA  95823-9012",
        "country": "US"
    },
    "000149": {
        "oui_hex": "00-01-49",
        "organization": "TDT AG",
        "address_1": "Siemensstraße 18",
        "address_2": "Essenbach    84051",
        "country": "DE"
    },
    "000131": {
        "oui_hex": "00-01-31",
        "organization": "Bosch Security Systems, Inc.",
        "address_1": "130 Perinton Parkway",
        "address_2": "Fairport  NY  14450",
        "country": "US"
    },
    "0030BE": {
        "oui_hex": "00-30-BE",
        "organization": "City-Net Technology, Inc.",
        "address_1": "135 E. Chesnut Ave., Ste.",
        "address_2": "Monrovia  CA  91016",
        "country": "US"
    },
    "003002": {
        "oui_hex": "00-30-02",
        "organization": "Expand Networks",
        "address_1": "Atidim Tech Park, Bldg. 4",
        "address_2": "Tel-Aviv 61580",
        "country": "IL"
    },
    "003078": {
        "oui_hex": "00-30-78",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00B0EC": {
        "oui_hex": "00-B0-EC",
        "organization": "EACEM",
        "address_1": "Avenue Louise 140, Bte 6",
        "address_2": "B-1050 BRUSSELS",
        "country": "BE"
    },
    "00B0DF": {
        "oui_hex": "00-B0-DF",
        "organization": "Starboard Storage Systems",
        "address_1": "12303 Airport Way",
        "address_2": "Broomfield  Co  80021",
        "country": "US"
    },
    "00010B": {
        "oui_hex": "00-01-0B",
        "organization": "Space CyberLink, Inc.",
        "address_1": "5th Fl. Guppyung Town B",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00309C": {
        "oui_hex": "00-30-9C",
        "organization": "Timing Applications, Inc.",
        "address_1": "4775 Walnut St.",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "00307E": {
        "oui_hex": "00-30-7E",
        "organization": "Redflex Communication Systems",
        "address_1": "11-29 Eastern Road",
        "address_2": "South Melbourne  Victoria 3205",
        "country": "AU"
    },
    "00304F": {
        "oui_hex": "00-30-4F",
        "organization": "PLANET Technology Corporation",
        "address_1": "11F, No. 96, Min-Chuan Road",
        "address_2": "Hsin-Tien Dist., New Taipei City",
        "country": "TW"
    },
    "003022": {
        "oui_hex": "00-30-22",
        "organization": "Fong Kai Industrial Co., Ltd.",
        "address_1": "4F-3, No. 13, Wu Chuan 1st Road",
        "address_2": "Hsin Chuang City, Taipei Hsien",
        "country": "TW"
    },
    "003070": {
        "oui_hex": "00-30-70",
        "organization": "1Net Corporation",
        "address_1": "347 Elizabeth Avenue - Ste. #100",
        "address_2": "Somerset  NJ  08873",
        "country": "US"
    },
    "0030F8": {
        "oui_hex": "00-30-F8",
        "organization": "Dynapro Systems, Inc.",
        "address_1": "800 Carleton Court",
        "address_2": "New Westminster  British Columbia V3M 6L3",
        "country": "CA"
    },
    "0030B7": {
        "oui_hex": "00-30-B7",
        "organization": "Teletrol Systems, Inc.",
        "address_1": "Technology Center",
        "address_2": "Manchester  NH  03101",
        "country": "US"
    },
    "0030B3": {
        "oui_hex": "00-30-B3",
        "organization": "San Valley Systems, Inc.",
        "address_1": "2105 S. Bascom Ave. - Ste. #390",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "003009": {
        "oui_hex": "00-30-09",
        "organization": "Tachion Networks, Inc.",
        "address_1": "2 Meridian Road",
        "address_2": "Eatontown  NJ  07724",
        "country": "US"
    },
    "00307A": {
        "oui_hex": "00-30-7A",
        "organization": "Advanced Technology & Systems",
        "address_1": "Yokohama Business Park East Tower 9F,",
        "address_2": "    240-0005",
        "country": "JP"
    },
    "003061": {
        "oui_hex": "00-30-61",
        "organization": "MobyTEL",
        "address_1": "4301 Connecticut Ave. NW",
        "address_2": "Washington  DC  20008",
        "country": "US"
    },
    "003054": {
        "oui_hex": "00-30-54",
        "organization": "CASTLENET TECHNOLOGY, INC.",
        "address_1": "NO. 130 WU-KUNG RD.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00300B": {
        "oui_hex": "00-30-0B",
        "organization": "mPHASE Technologies, Inc.",
        "address_1": "250 14th Street",
        "address_2": "Atlanta  GA  30318",
        "country": "US"
    },
    "00308F": {
        "oui_hex": "00-30-8F",
        "organization": "MICRILOR, Inc.",
        "address_1": "17 Lakeside Office Park",
        "address_2": "Wakefield  MA  01880",
        "country": "US"
    },
    "003050": {
        "oui_hex": "00-30-50",
        "organization": "Versa Technology",
        "address_1": "4430 E. Miraloma Ave., - Ste.",
        "address_2": "Anaheim  CA  92807",
        "country": "US"
    },
    "0030C0": {
        "oui_hex": "00-30-C0",
        "organization": "Lara Technology, Inc.",
        "address_1": "2345 North First Street",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "003005": {
        "oui_hex": "00-30-05",
        "organization": "Fujitsu Siemens Computers",
        "address_1": "Buergermeister ulrich 100",
        "address_2": "86199 Augsburg",
        "country": "DE"
    },
    "0030E0": {
        "oui_hex": "00-30-E0",
        "organization": "OXFORD SEMICONDUCTOR LTD.",
        "address_1": "25 MILTON PARK",
        "address_2": "Abingdon  Oxon  OX14 4SH",
        "country": "GB"
    },
    "003064": {
        "oui_hex": "00-30-64",
        "organization": "ADLINK TECHNOLOGY, INC.",
        "address_1": "9F, NO. 166, JIEN-YI R.D.",
        "address_2": "CHUNG-HO CITY TAIPEI",
        "country": "TW"
    },
    "0030DB": {
        "oui_hex": "00-30-DB",
        "organization": "Mindready Solutions, Inc.",
        "address_1": "2800 Marie-Curie Avenue",
        "address_2": "Quebec    H4S 2C2",
        "country": "CA"
    },
    "0030E7": {
        "oui_hex": "00-30-E7",
        "organization": "CNF MOBILE SOLUTIONS, INC.",
        "address_1": "7722 E. GRAY ROAD",
        "address_2": "SCOTTSDALE  AZ  85260",
        "country": "US"
    },
    "0030B4": {
        "oui_hex": "00-30-B4",
        "organization": "INTERSIL CORP.",
        "address_1": "P.O. BOX 883",
        "address_2": "MELBOURNE  FL  32902",
        "country": "US"
    },
    "0030B1": {
        "oui_hex": "00-30-B1",
        "organization": "TrunkNet",
        "address_1": "Aubergenviller Allee 51",
        "address_2": "Dieburg    D-64807",
        "country": "DE"
    },
    "003060": {
        "oui_hex": "00-30-60",
        "organization": "Powerfile, Inc.",
        "address_1": "3350 Thomas Road",
        "address_2": "Santa Clara  CA  95054-2062",
        "country": "US"
    },
    "0030A0": {
        "oui_hex": "00-30-A0",
        "organization": "TYCO SUBMARINE SYSTEMS, LTD.",
        "address_1": "250 INDUSTRIAL WAY WEST",
        "address_2": "EATONTOWN  NJ  07724",
        "country": "US"
    },
    "003015": {
        "oui_hex": "00-30-15",
        "organization": "CP CLARE CORP.",
        "address_1": "78 CHERRY HILL DRIVE",
        "address_2": "BEVERLY  MA  01915",
        "country": "US"
    },
    "00301F": {
        "oui_hex": "00-30-1F",
        "organization": "OPTICAL NETWORKS, INC.",
        "address_1": "166 BAYPOINTE PARKWAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0030FA": {
        "oui_hex": "00-30-FA",
        "organization": "TELICA, INC.",
        "address_1": "734 FOREST STREET, BLDG.",
        "address_2": "MARLBORO  MA  01752",
        "country": "US"
    },
    "00304B": {
        "oui_hex": "00-30-4B",
        "organization": "ORBACOM SYSTEMS, INC.",
        "address_1": "1704 TAYLORS LANE",
        "address_2": "CINNAMINSON  NJ  08077",
        "country": "US"
    },
    "0030E9": {
        "oui_hex": "00-30-E9",
        "organization": "GMA COMMUNICATION MANUFACT'G",
        "address_1": "MARKETING, (1991) LTD.",
        "address_2": "ISRAEL  ISRAEL  49130",
        "country": "IL"
    },
    "0030A5": {
        "oui_hex": "00-30-A5",
        "organization": "ACTIVE POWER",
        "address_1": "11525 STONEHOLLOW - STE.#255",
        "address_2": "AUSTIN  TX  78758",
        "country": "US"
    },
    "003084": {
        "oui_hex": "00-30-84",
        "organization": "ALLIED TELESYN INTERNAIONAL",
        "address_1": "CORPORATION",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "003043": {
        "oui_hex": "00-30-43",
        "organization": "IDREAM TECHNOLOGIES, PTE. LTD.",
        "address_1": "54 KALLANG BAHRU, #02-14",
        "address_2": "",
        "country": "SG"
    },
    "003000": {
        "oui_hex": "00-30-00",
        "organization": "ALLWELL TECHNOLOGY CORP.",
        "address_1": "4F, #15, LANE3, SEC.2",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "003011": {
        "oui_hex": "00-30-11",
        "organization": "HMS Industrial Networks",
        "address_1": "P O Box 4126",
        "address_2": "    SE-300 04",
        "country": "SE"
    },
    "003068": {
        "oui_hex": "00-30-68",
        "organization": "CYBERNETICS TECH. CO., LTD.",
        "address_1": "DAITOH BLDG. 4F 3-32-1",
        "address_2": "  JAPAN  171-0033",
        "country": "JP"
    },
    "003091": {
        "oui_hex": "00-30-91",
        "organization": "TAIWAN FIRST LINE ELEC. CORP.",
        "address_1": "40 Chung-Shan Road",
        "address_2": "Taipei County",
        "country": "TW"
    },
    "0030CD": {
        "oui_hex": "00-30-CD",
        "organization": "CONEXANT SYSTEMS, INC.",
        "address_1": "4311 JAMBOREE ROAD",
        "address_2": "NEWPORT BEACH  CA  92660",
        "country": "US"
    },
    "00301A": {
        "oui_hex": "00-30-1A",
        "organization": "SMARTBRIDGES PTE. LTD.",
        "address_1": "745 Toa Payoh Lorong 5",
        "address_2": "    319455",
        "country": "SG"
    },
    "003029": {
        "oui_hex": "00-30-29",
        "organization": "OPICOM",
        "address_1": "ROOM #302, STYLE FACTORY 151",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "003083": {
        "oui_hex": "00-30-83",
        "organization": "Ivron Systems",
        "address_1": "19-20 YORK ROAD",
        "address_2": "",
        "country": "IE"
    },
    "0030B6": {
        "oui_hex": "00-30-B6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0030C7": {
        "oui_hex": "00-30-C7",
        "organization": "Macromate Corp.",
        "address_1": "8F,Universal Center,Number 179",
        "address_2": "Taipei  Hsien",
        "country": "TW"
    },
    "0030E4": {
        "oui_hex": "00-30-E4",
        "organization": "CHIYODA SYSTEM RIKEN",
        "address_1": "2-7, KANDA-NISHIKI-CHO",
        "address_2": "",
        "country": "JP"
    },
    "003066": {
        "oui_hex": "00-30-66",
        "organization": "RFM",
        "address_1": "3079 Premiere Pkwy",
        "address_2": "Duluth  GA  30097",
        "country": "US"
    },
    "003031": {
        "oui_hex": "00-30-31",
        "organization": "LIGHTWAVE COMMUNICATIONS, INC.",
        "address_1": "261 PEPE'S FARM ROAD",
        "address_2": "MILFORD  CT  06460",
        "country": "US"
    },
    "00D007": {
        "oui_hex": "00-D0-07",
        "organization": "MIC ASSOCIATES, INC.",
        "address_1": "1510-1, KAIDOKI",
        "address_2": "JAPAN  JAPAN  206-0012",
        "country": "JP"
    },
    "00D0FF": {
        "oui_hex": "00-D0-FF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D028": {
        "oui_hex": "00-D0-28",
        "organization": "Harmonic, Inc",
        "address_1": "965 Stewart Drive",
        "address_2": "Sunnyvale  CA  94086-3913",
        "country": "US"
    },
    "00D025": {
        "oui_hex": "00-D0-25",
        "organization": "XROSSTECH, INC.",
        "address_1": "HABDONG B/D 5F 210-2",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00D044": {
        "oui_hex": "00-D0-44",
        "organization": "ALIDIAN NETWORKS, INC.",
        "address_1": "1330 W. MIDDLEFIELD ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00305B": {
        "oui_hex": "00-30-5B",
        "organization": "Toko Inc.",
        "address_1": "18 COMIGAYA, TSURUGASHIMA-SHI",
        "address_2": "  JAPAN  350-2281",
        "country": "JP"
    },
    "00D049": {
        "oui_hex": "00-D0-49",
        "organization": "IMPRESSTEK CO., LTD.",
        "address_1": "6F, SPECIALTY CONSTRUCTION CTR",
        "address_2": "302-120  KOREA  (REP.)",
        "country": "KR"
    },
    "00D05B": {
        "oui_hex": "00-D0-5B",
        "organization": "ACROLOOP MOTION CONTROL",
        "address_1": "SYSTEMS",
        "address_2": "CHASKA  MN  55318",
        "country": "US"
    },
    "00D042": {
        "oui_hex": "00-D0-42",
        "organization": "MAHLO GMBH & CO. UG",
        "address_1": "DONAUSTRASSE 12",
        "address_2": "",
        "country": "DE"
    },
    "00D031": {
        "oui_hex": "00-D0-31",
        "organization": "INDUSTRIAL LOGIC CORPORATION",
        "address_1": "15 PIEDMONT CENTER-STE #700",
        "address_2": "ATLANTA  GA  30305",
        "country": "US"
    },
    "00D038": {
        "oui_hex": "00-D0-38",
        "organization": "FIVEMERE, LTD.",
        "address_1": "UNIT 1-HERON INDUSTRIAL ESTATE",
        "address_2": "RG7  1PJ  ENGLAND",
        "country": "GB"
    },
    "00D0C6": {
        "oui_hex": "00-D0-C6",
        "organization": "THOMAS & BETTS CORP.",
        "address_1": "Thomas & Betts Aust. Pty. Ltd.",
        "address_2": "Lidcombe  New South Wales",
        "country": "AU"
    },
    "00D077": {
        "oui_hex": "00-D0-77",
        "organization": "LUCENT TECHNOLOGIES",
        "address_1": "CLIENT ACCESS BUSINESS UNIT",
        "address_2": "HOLMDEL  NJ  07733",
        "country": "US"
    },
    "00D03E": {
        "oui_hex": "00-D0-3E",
        "organization": "ROCKETCHIPS, INC.",
        "address_1": "7901 XERXES AVE. S.",
        "address_2": "MINNEAPOLIS  MN  55431",
        "country": "US"
    },
    "00D093": {
        "oui_hex": "00-D0-93",
        "organization": "TQ - COMPONENTS GMBH",
        "address_1": "GUT DELLING - MUHLSTR 2",
        "address_2": "",
        "country": "DE"
    },
    "00D03F": {
        "oui_hex": "00-D0-3F",
        "organization": "AMERICAN COMMUNICATION",
        "address_1": "TECHNOLIGIES INTERNATIONAL INC",
        "address_2": "ROHNERT PARK  CA  94928",
        "country": "US"
    },
    "00D0F7": {
        "oui_hex": "00-D0-F7",
        "organization": "NEXT NETS CORPORATION",
        "address_1": "MITA KOKUSAI BLDG. 17F",
        "address_2": "",
        "country": "JP"
    },
    "00D06F": {
        "oui_hex": "00-D0-6F",
        "organization": "KMC CONTROLS",
        "address_1": "P.O. BOX 497",
        "address_2": "NEW PARIS  IN  46553",
        "country": "US"
    },
    "00D0FC": {
        "oui_hex": "00-D0-FC",
        "organization": "GRANITE MICROSYSTEMS",
        "address_1": "10202 N. ENTERPRISE DRIVE",
        "address_2": "MEQUON  WI  53092",
        "country": "US"
    },
    "00D0A6": {
        "oui_hex": "00-D0-A6",
        "organization": "LANBIRD TECHNOLOGY CO., LTD.",
        "address_1": "ROOM A-211, S.B.I.",
        "address_2": "  KOREA  157-030",
        "country": "KR"
    },
    "00D003": {
        "oui_hex": "00-D0-03",
        "organization": "COMDA ENTERPRISES CORP.",
        "address_1": "2F, NO. 501-18, CHUNGCHEN ROAD",
        "address_2": "TAIWAN  TAIWAN  ROC",
        "country": "TW"
    },
    "00D0D2": {
        "oui_hex": "00-D0-D2",
        "organization": "EPILOG CORPORATION",
        "address_1": "500 CORPORATE CIRCLE - STE.",
        "address_2": "GOLDEN  CO  80401",
        "country": "US"
    },
    "00D0F9": {
        "oui_hex": "00-D0-F9",
        "organization": "ACUTE COMMUNICATIONS CORP.",
        "address_1": "NO. 1, CREATION ROAD III",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00D0CE": {
        "oui_hex": "00-D0-CE",
        "organization": "iSystem Labs",
        "address_1": "BRODISCE 7, 10C",
        "address_2": "Trzin    1236",
        "country": "SI"
    },
    "00D018": {
        "oui_hex": "00-D0-18",
        "organization": "QWES. COM, INC.",
        "address_1": "14742 NEWPORT AVE. - STE. #203",
        "address_2": "TUSTIN  CA  92780",
        "country": "US"
    },
    "0001A7": {
        "oui_hex": "00-01-A7",
        "organization": "UNEX TECHNOLOGY CORPORATION",
        "address_1": "8F-5, #130, SZE WEI RD.,",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "00D08C": {
        "oui_hex": "00-D0-8C",
        "organization": "GENOA TECHNOLOGY, INC.",
        "address_1": "5401 TECH CIRCLE",
        "address_2": "MOORPARK  CA  93021",
        "country": "US"
    },
    "00D059": {
        "oui_hex": "00-D0-59",
        "organization": "AMBIT MICROSYSTEMS CORP.",
        "address_1": "5F-1, 5 HSIN-AN ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00D0FD": {
        "oui_hex": "00-D0-FD",
        "organization": "OPTIMA TELE.COM, INC.",
        "address_1": "4-20 Cachet Woods Court",
        "address_2": "Markham  ON  L6C 3G1",
        "country": "CA"
    },
    "00D0A9": {
        "oui_hex": "00-D0-A9",
        "organization": "SHINANO KENSHI CO., LTD.",
        "address_1": "ELECTRONIC EQUIPMENT DIVISION",
        "address_2": "",
        "country": "JP"
    },
    "00D0DD": {
        "oui_hex": "00-D0-DD",
        "organization": "SUNRISE TELECOM, INC.",
        "address_1": "22 GREAT OAKS BLVD.",
        "address_2": "SAN JOSE  CA  95119",
        "country": "US"
    },
    "00D0E6": {
        "oui_hex": "00-D0-E6",
        "organization": "IBOND INC.",
        "address_1": "3160, DE LA CRUZ BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00D0D1": {
        "oui_hex": "00-D0-D1",
        "organization": "Sycamore Networks",
        "address_1": "220 Mill Rd",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "00D087": {
        "oui_hex": "00-D0-87",
        "organization": "MICROFIRST INC.",
        "address_1": "11 EAST OAK STREET",
        "address_2": "OAKLAND  NJ  07436",
        "country": "US"
    },
    "00D080": {
        "oui_hex": "00-D0-80",
        "organization": "EXABYTE CORPORATION",
        "address_1": "1685 38TH STREET",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00D091": {
        "oui_hex": "00-D0-91",
        "organization": "SMARTSAN SYSTEMS, INC.",
        "address_1": "4655 OLD IRONSIDES DR. #480",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00D04E": {
        "oui_hex": "00-D0-4E",
        "organization": "LOGIBAG",
        "address_1": "2, Rue de la Mandinière",
        "address_2": "",
        "country": "FR"
    },
    "00D027": {
        "oui_hex": "00-D0-27",
        "organization": "APPLIED AUTOMATION, INC.",
        "address_1": "P.O. BOX 9999",
        "address_2": "BARTLESVILLE  OK  74005-9999",
        "country": "US"
    },
    "00D072": {
        "oui_hex": "00-D0-72",
        "organization": "BROADLOGIC",
        "address_1": "463 S. MILPITAS BLVD.",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "00D0E2": {
        "oui_hex": "00-D0-E2",
        "organization": "MRT MICRO, INC.",
        "address_1": "14000 S. MILITARY TRAIL",
        "address_2": "DELRAY BEACH  FL  33484",
        "country": "US"
    },
    "00D06A": {
        "oui_hex": "00-D0-6A",
        "organization": "LINKUP SYSTEMS CORPORATION",
        "address_1": "1190 COLEMAN AVE.- STE #2C",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "00D089": {
        "oui_hex": "00-D0-89",
        "organization": "DYNACOLOR, INC.",
        "address_1": "No.116, Zhouzi St., Neihu Dist.",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "00D02C": {
        "oui_hex": "00-D0-2C",
        "organization": "CAMPBELL SCIENTIFIC, INC.",
        "address_1": "815 W. 1800 N.",
        "address_2": "LOGAN  UT  84321-1784",
        "country": "US"
    },
    "00D0CD": {
        "oui_hex": "00-D0-CD",
        "organization": "ATAN TECHNOLOGY INC.",
        "address_1": "#5, ALLEY 18, LANE 81,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00D040": {
        "oui_hex": "00-D0-40",
        "organization": "SYSMATE CO., LTD.",
        "address_1": "1091 WOLPYONG-DONG",
        "address_2": "  SOUTH  KOREA",
        "country": "KR"
    },
    "00D01A": {
        "oui_hex": "00-D0-1A",
        "organization": "URMET  TLC S.P.A.",
        "address_1": "VIA DI CASTEL ROMANO 167",
        "address_2": "",
        "country": "IT"
    },
    "0050FF": {
        "oui_hex": "00-50-FF",
        "organization": "HAKKO ELECTRONICS CO., LTD.",
        "address_1": "238, KAMIKASHIWANO-MACHI",
        "address_2": "MATTO-SHI, ISHIKAWA 924-0035",
        "country": "JP"
    },
    "0050D2": {
        "oui_hex": "00-50-D2",
        "organization": "CMC Electronics Inc",
        "address_1": "600 Dr.Frederik-Philips Blvd",
        "address_2": "Montreal    QC H4M 2S9",
        "country": "CA"
    },
    "0050F9": {
        "oui_hex": "00-50-F9",
        "organization": "Sensormatic Electronics LLC",
        "address_1": "1501 Yamato Rd",
        "address_2": "Boca Raton  FL  33431",
        "country": "US"
    },
    "005048": {
        "oui_hex": "00-50-48",
        "organization": "INFOLIBRIA",
        "address_1": "411 WAVERLY OAKS RD-STE #323",
        "address_2": "WALTHAM  MA  02154-8414",
        "country": "US"
    },
    "00504E": {
        "oui_hex": "00-50-4E",
        "organization": "SIERRA MONITOR CORP.",
        "address_1": "1991 TAROB COURT",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "0050F6": {
        "oui_hex": "00-50-F6",
        "organization": "PAN-INTERNATIONAL INDUSTRIAL CORP.",
        "address_1": "GF, NO. 176, CHANG CHUN RD.",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "00506C": {
        "oui_hex": "00-50-6C",
        "organization": "Beijer Electronics Products AB",
        "address_1": "Box 426",
        "address_2": "SE-201 24  Malmoe",
        "country": "SE"
    },
    "0050D7": {
        "oui_hex": "00-50-D7",
        "organization": "TELSTRAT",
        "address_1": "3600 AVENUE",
        "address_2": "PLANO  TX  75074",
        "country": "US"
    },
    "005044": {
        "oui_hex": "00-50-44",
        "organization": "ASACA CORPORATION",
        "address_1": "420 CORPORATE CIRCLE, Unit H",
        "address_2": "GOLDEN  CO  80401",
        "country": "US"
    },
    "0050E6": {
        "oui_hex": "00-50-E6",
        "organization": "HAKUSAN CORPORATION",
        "address_1": "J TOWER, 1-1, NIKKOU-CHO",
        "address_2": "",
        "country": "JP"
    },
    "00503C": {
        "oui_hex": "00-50-3C",
        "organization": "TSINGHUA NOVEL ELECTRONICS",
        "address_1": "CO., LTD.",
        "address_2": "100084  100084",
        "country": "CN"
    },
    "005060": {
        "oui_hex": "00-50-60",
        "organization": "TANDBERG TELECOM AS",
        "address_1": "Philip Pedersens vei 20",
        "address_2": "1361  Lysaker",
        "country": "NO"
    },
    "0050EE": {
        "oui_hex": "00-50-EE",
        "organization": "TEK DIGITEL CORPORATION",
        "address_1": "20010 CENTURY BLVD. #300",
        "address_2": "GERMANTOWN  MD  20874",
        "country": "US"
    },
    "005045": {
        "oui_hex": "00-50-45",
        "organization": "RIOWORKS SOLUTIONS, INC.",
        "address_1": "4F, NO.28, LANE 583",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00502B": {
        "oui_hex": "00-50-2B",
        "organization": "GENRAD LTD.",
        "address_1": "ORION BUSINESS PARK",
        "address_2": "UNITED KINGDOM  SK3  OXG",
        "country": "GB"
    },
    "00502E": {
        "oui_hex": "00-50-2E",
        "organization": "CAMBEX CORPORATION",
        "address_1": "115 Flanders Road",
        "address_2": "Westborough  MA  01581",
        "country": "US"
    },
    "00506E": {
        "oui_hex": "00-50-6E",
        "organization": "CORDER ENGINEERING CORPORATION",
        "address_1": "151 KALMUS DRIVE - STE #A103",
        "address_2": "COSTA MESA  CA  92626",
        "country": "US"
    },
    "00502C": {
        "oui_hex": "00-50-2C",
        "organization": "SOYO COMPUTER, INC.",
        "address_1": "NO. 21 WU-KUNG 5 RD.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "005077": {
        "oui_hex": "00-50-77",
        "organization": "PROLIFIC TECHNOLOGY, INC.",
        "address_1": "6F 1, LANE 51, SEC 1",
        "address_2": "    100",
        "country": "TW"
    },
    "005033": {
        "oui_hex": "00-50-33",
        "organization": "MAYAN NETWORKS",
        "address_1": "3350 SCOTT BLVD. - BLDG. #9",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00500E": {
        "oui_hex": "00-50-0E",
        "organization": "CHROMATIS NETWORKS, INC.",
        "address_1": "3 BETHESDA METRO CENTER",
        "address_2": "BETHESDA  MD  20814",
        "country": "US"
    },
    "00D0CC": {
        "oui_hex": "00-D0-CC",
        "organization": "TECHNOLOGIES LYRE INC.",
        "address_1": "1200 ST-JEAN-BAPTISTE,",
        "address_2": "CANADA  G2E  5E8",
        "country": "CA"
    },
    "0050EC": {
        "oui_hex": "00-50-EC",
        "organization": "OLICOM A/S",
        "address_1": "NYBROVEJ 114",
        "address_2": "",
        "country": "DK"
    },
    "0050C9": {
        "oui_hex": "00-50-C9",
        "organization": "MASPRO DENKOH CORP.",
        "address_1": "ASADA NISSHIN AICHI",
        "address_2": "",
        "country": "JP"
    },
    "0050BB": {
        "oui_hex": "00-50-BB",
        "organization": "CMS TECHNOLOGIES",
        "address_1": "13955 FARMINGTON RAOD",
        "address_2": "LIVONIA  MI  48154",
        "country": "US"
    },
    "005062": {
        "oui_hex": "00-50-62",
        "organization": "KOUWELL ELECTRONICS CORP.  **",
        "address_1": "7F, NO.99, NAN-KANG ROAD",
        "address_2": "",
        "country": "TW"
    },
    "0050D5": {
        "oui_hex": "00-50-D5",
        "organization": "AD SYSTEMS CORP.",
        "address_1": "1-4-1, NAKACHO, MUSASHINO CITY",
        "address_2": "TOKYO 180-0006",
        "country": "JP"
    },
    "0050F3": {
        "oui_hex": "00-50-F3",
        "organization": "GLOBAL NET INFORMATION CO., Ltd.",
        "address_1": "NORTH TOWER- RM 1305",
        "address_2": "GUANG ZHOU 510095",
        "country": "CN"
    },
    "0050BE": {
        "oui_hex": "00-50-BE",
        "organization": "FAST MULTIMEDIA AG",
        "address_1": "RUEDESHEIMERSTR. 11-13",
        "address_2": "80686 MUNICH",
        "country": "DE"
    },
    "00506F": {
        "oui_hex": "00-50-6F",
        "organization": "G-CONNECT",
        "address_1": "P.O. BOX 2200",
        "address_2": "HERZLIYA 46120",
        "country": "IL"
    },
    "0050F8": {
        "oui_hex": "00-50-F8",
        "organization": "ENTREGA TECHNOLOGIES, INC.",
        "address_1": "25691 ATLANTIC OCEAN DRIVE",
        "address_2": "LAKE FOREST  CA  92630",
        "country": "US"
    },
    "005042": {
        "oui_hex": "00-50-42",
        "organization": "SCI MANUFACTURING SINGAPORE PTE, LTD.",
        "address_1": "3 DEPOT CLOSE",
        "address_2": "  SINGAPORE 109840",
        "country": "SG"
    },
    "0050C0": {
        "oui_hex": "00-50-C0",
        "organization": "GATAN, INC.",
        "address_1": "5933 CORONADO LANE",
        "address_2": "PLEASANTON  CA  94588",
        "country": "US"
    },
    "005051": {
        "oui_hex": "00-50-51",
        "organization": "IWATSU ELECTRIC CO., LTD.",
        "address_1": "7-41, KUGAYAMA 1-CHOME",
        "address_2": "SUGINAMI-KU, TOKYO 168-8501",
        "country": "JP"
    },
    "00507D": {
        "oui_hex": "00-50-7D",
        "organization": "IFP",
        "address_1": "LESSINGSTR. 4",
        "address_2": "D-78315 RADOLFZELL",
        "country": "DE"
    },
    "005097": {
        "oui_hex": "00-50-97",
        "organization": "MMC-EMBEDDED COMPUTERTECHNIK GmbH",
        "address_1": "ULRICHSBERGERSTR. 17",
        "address_2": "D-94469 DEGGENDORF",
        "country": "DE"
    },
    "005010": {
        "oui_hex": "00-50-10",
        "organization": "NovaNET Learning, Inc.",
        "address_1": "125 W. CHURCH STREET-STE. #300",
        "address_2": "CHAMPAIGN  IL  61820",
        "country": "US"
    },
    "00509A": {
        "oui_hex": "00-50-9A",
        "organization": "TAG ELECTRONIC SYSTEMS",
        "address_1": "GENESIS BUSINESS PARK",
        "address_2": "WOKING, SURREY GU21 5RW",
        "country": "GB"
    },
    "005022": {
        "oui_hex": "00-50-22",
        "organization": "ZONET TECHNOLOGY, INC.",
        "address_1": "830 ROOM, BLDG. 53, 195, SEC.4",
        "address_2": "HSINCHA",
        "country": "TW"
    },
    "005007": {
        "oui_hex": "00-50-07",
        "organization": "SIEMENS TELECOMMUNICATION SYSTEMS LIMITED",
        "address_1": "NO. 90, SEC. 1, CHIEN KUO NORTH ROAD",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "005040": {
        "oui_hex": "00-50-40",
        "organization": "Panasonic Electric Works Co., Ltd.",
        "address_1": "Tsu-Factory, 1668, Fujikata",
        "address_2": "Tsu-shi  Mie-ken  514-8555",
        "country": "JP"
    },
    "00501C": {
        "oui_hex": "00-50-1C",
        "organization": "JATOM SYSTEMS, INC.",
        "address_1": "99 MICHAEL COWPLAND DRIVE",
        "address_2": "ONTARIO, K2M 1X3",
        "country": "CA"
    },
    "005092": {
        "oui_hex": "00-50-92",
        "organization": "Rigaku Corporation Osaka Plant",
        "address_1": "14-8 AKAOJI-CHO",
        "address_2": "TAKATSUKI-SHI, OSAKA 569-1146",
        "country": "JP"
    },
    "00507A": {
        "oui_hex": "00-50-7A",
        "organization": "XPEED, INC.",
        "address_1": "4699 OLD IRONSIDES DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "005069": {
        "oui_hex": "00-50-69",
        "organization": "PixStream Incorporated",
        "address_1": "180 COLUMBIA ST. W.",
        "address_2": "Ontario N2L 3L3",
        "country": "CA"
    },
    "005068": {
        "oui_hex": "00-50-68",
        "organization": "ELECTRONIC INDUSTRIES ASSOCIATION",
        "address_1": "2500 WILSON BLVD.",
        "address_2": "ARLINGTON  VA  22201",
        "country": "US"
    },
    "0050BC": {
        "oui_hex": "00-50-BC",
        "organization": "HAMMER STORAGE SOLUTIONS",
        "address_1": "8450 CENTRAL AVENUE",
        "address_2": "NEWARK  CA  94560",
        "country": "US"
    },
    "009071": {
        "oui_hex": "00-90-71",
        "organization": "Applied Innovation Inc.",
        "address_1": "5800 Innovation Drive",
        "address_2": "Dublin  OH  43016-3271",
        "country": "US"
    },
    "0050EB": {
        "oui_hex": "00-50-EB",
        "organization": "ALPHA-TOP CORPORATION",
        "address_1": "19F., NO. 2, LANE 150",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "0050EF": {
        "oui_hex": "00-50-EF",
        "organization": "SPE Systemhaus GmbH",
        "address_1": "WALDSTRASSE 7",
        "address_2": "63150 HEUSENSTAMM",
        "country": "DE"
    },
    "005098": {
        "oui_hex": "00-50-98",
        "organization": "GLOBALOOP, LTD.",
        "address_1": "12 HASHARON ROAD",
        "address_2": "KFAR SABA 44269",
        "country": "IL"
    },
    "00504F": {
        "oui_hex": "00-50-4F",
        "organization": "OLENCOM ELECTRONICS",
        "address_1": "SOLTAM INDUSTRIAL PARK",
        "address_2": "YOKNEAM 20692",
        "country": "IL"
    },
    "0090FF": {
        "oui_hex": "00-90-FF",
        "organization": "TELLUS TECHNOLOGY INC.",
        "address_1": "40990 ENCYCLOPEDIA CIR.",
        "address_2": "FREMONT  CA  94538-2470",
        "country": "US"
    },
    "00903E": {
        "oui_hex": "00-90-3E",
        "organization": "N.V. PHILIPS INDUSTRIAL ACTIVITIES",
        "address_1": "",
        "address_2": "B-3001 LEUVEN",
        "country": "BE"
    },
    "0090BA": {
        "oui_hex": "00-90-BA",
        "organization": "VALID NETWORKS, INC.",
        "address_1": "6 CROMWELL #102",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "009018": {
        "oui_hex": "00-90-18",
        "organization": "ITO ELECTRIC INDUSTRY CO, LTD.",
        "address_1": "4-26-12 MEIEKI NAKAMURA-KU",
        "address_2": "NAGOYA-CITY AICHI 450-0002",
        "country": "JP"
    },
    "0090CD": {
        "oui_hex": "00-90-CD",
        "organization": "ENT-EMPRESA NACIONAL DE TELECOMMUNICACOES, S.A.",
        "address_1": "R. ENG FREDERICO ULRICH -  APARTADO 3081",
        "address_2": "Guardeiras - 4470 Moreira Maia",
        "country": "PT"
    },
    "0090FB": {
        "oui_hex": "00-90-FB",
        "organization": "PORTWELL, INC.",
        "address_1": "7F-4, NO. 160, SEC. 6",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "009094": {
        "oui_hex": "00-90-94",
        "organization": "OSPREY TECHNOLOGIES, INC.",
        "address_1": "600 AIRPORT BLVD. - STE. #900",
        "address_2": "MORRISVILLE  NC  27560",
        "country": "US"
    },
    "0090B3": {
        "oui_hex": "00-90-B3",
        "organization": "AGRANAT SYSTEMS",
        "address_1": "1345 MAIN STREET",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "00903C": {
        "oui_hex": "00-90-3C",
        "organization": "ATLANTIC NETWORK SYSTEMS",
        "address_1": "IMMEUBLE Kennedy",
        "address_2": "  33700 MERIGNAC",
        "country": "FR"
    },
    "00905D": {
        "oui_hex": "00-90-5D",
        "organization": "NETCOM SICHERHEITSTECHNIK GMBH",
        "address_1": "BOPPSTRASSE 38",
        "address_2": "",
        "country": "DE"
    },
    "0090D1": {
        "oui_hex": "00-90-D1",
        "organization": "LEICHU ENTERPRISE CO., LTD.",
        "address_1": "8F, NO. 203, PA-TEH ROAD, SEC.2",
        "address_2": "",
        "country": "TW"
    },
    "009046": {
        "oui_hex": "00-90-46",
        "organization": "DEXDYNE, LTD.",
        "address_1": "15 MARKET PL.",
        "address_2": "GLOCESTERSHIRE GL7 2PB",
        "country": "GB"
    },
    "0090DA": {
        "oui_hex": "00-90-DA",
        "organization": "DYNARC, INC.",
        "address_1": "1887 LANDINGS DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "0090E0": {
        "oui_hex": "00-90-E0",
        "organization": "SYSTRAN CORP.",
        "address_1": "4126 LINDEN AVENUE",
        "address_2": "DAYTON  OH  45432",
        "country": "US"
    },
    "0090D0": {
        "oui_hex": "00-90-D0",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "B-2650 EDEGEM",
        "country": "BE"
    },
    "00909B": {
        "oui_hex": "00-90-9B",
        "organization": "MARKEM-IMAJE",
        "address_1": "Frihamnen 16A",
        "address_2": "Gothenburg    417 55",
        "country": "SE"
    },
    "009022": {
        "oui_hex": "00-90-22",
        "organization": "IVEX",
        "address_1": "4295 INTERNATIONAL BLVD.",
        "address_2": "NORCROSS  GA  30093",
        "country": "US"
    },
    "009016": {
        "oui_hex": "00-90-16",
        "organization": "ZAC",
        "address_1": "Stüvestraße 9",
        "address_2": "D-31141 Hildesheim",
        "country": "DE"
    },
    "0090A7": {
        "oui_hex": "00-90-A7",
        "organization": "CLIENTEC CORPORATION",
        "address_1": "8175 S. VIRGINIA ST.",
        "address_2": "RENO  NV  89511",
        "country": "US"
    },
    "009053": {
        "oui_hex": "00-90-53",
        "organization": "DAEWOO ELECTRONICS CO., LTD.",
        "address_1": "DIT RESEARCH CENTER",
        "address_2": "CHUNG-GU  SEOUL 100-714",
        "country": "KR"
    },
    "0090DC": {
        "oui_hex": "00-90-DC",
        "organization": "TECO INFORMATION SYSTEMS",
        "address_1": "CO., LTD.",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0090E2": {
        "oui_hex": "00-90-E2",
        "organization": "DISTRIBUTED PROCESSING TECHNOLOGY",
        "address_1": "140 CANDACE DRIVE",
        "address_2": "ORLANDO  FL  32751",
        "country": "US"
    },
    "009085": {
        "oui_hex": "00-90-85",
        "organization": "GOLDEN ENTERPRISES, INC.",
        "address_1": "4450 WEST EAU GALLIE BLVD.",
        "address_2": "MELBOURNE  FL  32934",
        "country": "US"
    },
    "0090C7": {
        "oui_hex": "00-90-C7",
        "organization": "ICOM INC.",
        "address_1": "6-9-16 KAMIHIGASHI",
        "address_2": "HIRANO-KU, OSAKA",
        "country": "JP"
    },
    "009035": {
        "oui_hex": "00-90-35",
        "organization": "ALPHA TELECOM, INC.",
        "address_1": "2F, NO.2, LI HSIN ROAD",
        "address_2": "HSIN-CHU",
        "country": "TW"
    },
    "00900F": {
        "oui_hex": "00-90-0F",
        "organization": "KAWASAKI HEAVY INDUSTRIES, LTD",
        "address_1": "ELEC. & CONTROL TECH CENTER",
        "address_2": "",
        "country": "JP"
    },
    "0090EA": {
        "oui_hex": "00-90-EA",
        "organization": "ALPHA TECHNOLOGIES, INC.",
        "address_1": "3767 ALPHA WAY",
        "address_2": "BELLINGHAM  WA  98226",
        "country": "US"
    },
    "009077": {
        "oui_hex": "00-90-77",
        "organization": "ADVANCED FIBRE COMMUNICATIONS",
        "address_1": "PO BOX #751239",
        "address_2": "PETALUMA  CA  94975",
        "country": "US"
    },
    "009099": {
        "oui_hex": "00-90-99",
        "organization": "ALLIED TELESIS, K.K.",
        "address_1": "NO. 2  TOC BUILDING, 7-21-11Nishi-Gotand",
        "address_2": "Shinagawa-Ku  Tokyo 141",
        "country": "JP"
    },
    "0010AD": {
        "oui_hex": "00-10-AD",
        "organization": "SOFTRONICS USB, INC.",
        "address_1": "5085 LIST DRIVE",
        "address_2": "COLORADO SPRINGS  CO  80919",
        "country": "US"
    },
    "0010A7": {
        "oui_hex": "00-10-A7",
        "organization": "UNEX TECHNOLOGY CORPORATION",
        "address_1": "8F-5, #130, SZE WEI RD.,",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "0010D5": {
        "oui_hex": "00-10-D5",
        "organization": "IMASDE CANARIAS, S.A.",
        "address_1": "URB. EL CEBADAL",
        "address_2": "35008 LAS PALMAS G.C.",
        "country": "ES"
    },
    "001055": {
        "oui_hex": "00-10-55",
        "organization": "FUJITSU MICROELECTRONICS, INC.",
        "address_1": "3545 NORTH FIRST STREET",
        "address_2": "SAN JOSE  CA  95134-1806",
        "country": "US"
    },
    "00907A": {
        "oui_hex": "00-90-7A",
        "organization": "Spectralink, Inc",
        "address_1": "2560 55th Street",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "0090F0": {
        "oui_hex": "00-90-F0",
        "organization": "Harmonic Video Systems Ltd.",
        "address_1": "19 ALON HATAVOR STREET",
        "address_2": "CAESAREA  Industrial Park    38900",
        "country": "IL"
    },
    "009020": {
        "oui_hex": "00-90-20",
        "organization": "PHILIPS ANALYTICAL X-RAY B.V.",
        "address_1": "LELYWEG 1",
        "address_2": "7602 EA ALMELO",
        "country": "NL"
    },
    "0010A3": {
        "oui_hex": "00-10-A3",
        "organization": "OMNITRONIX, INC.",
        "address_1": "760 HARRISON STREET",
        "address_2": "SEATTLE  WA  98109",
        "country": "US"
    },
    "00905C": {
        "oui_hex": "00-90-5C",
        "organization": "EDMI",
        "address_1": "626 OLD GYMPIE ROAD",
        "address_2": "NARANGBA  QLD 4504",
        "country": "AU"
    },
    "0090E3": {
        "oui_hex": "00-90-E3",
        "organization": "AVEX ELECTRONICS INC.",
        "address_1": "4807 BRADFORD DRIVE",
        "address_2": "HUNTSVILLE  AL  35805",
        "country": "US"
    },
    "0090A9": {
        "oui_hex": "00-90-A9",
        "organization": "WESTERN DIGITAL",
        "address_1": "1599 NORTH BROADWAY",
        "address_2": "ROCHESTER  MN  55906",
        "country": "US"
    },
    "0090F3": {
        "oui_hex": "00-90-F3",
        "organization": "ASPECT COMMUNICATIONS",
        "address_1": "1310 Ridder Park Drive",
        "address_2": "San Jose  CA  95131-2313",
        "country": "US"
    },
    "00904F": {
        "oui_hex": "00-90-4F",
        "organization": "ABB POWER T&D COMPANY, INC.",
        "address_1": "7036 SNOWDRIFT ROAD",
        "address_2": "ALLENTOWN  PA  18106",
        "country": "US"
    },
    "009060": {
        "oui_hex": "00-90-60",
        "organization": "SYSTEM CREATE CORP.",
        "address_1": "3-13-6 YOSHIKAWA BLD.",
        "address_2": "TOKYO",
        "country": "JP"
    },
    "009013": {
        "oui_hex": "00-90-13",
        "organization": "SAMSAN CORP.",
        "address_1": "ELECTRONICS & COMM DIVISION",
        "address_2": "Kangdong-Gu  Seoul 134-050",
        "country": "KR"
    },
    "001052": {
        "oui_hex": "00-10-52",
        "organization": "METTLER-TOLEDO (ALBSTADT) GMBH",
        "address_1": "P.O. BOX 2 50",
        "address_2": "D-72423 ALBSTADT",
        "country": "DE"
    },
    "00106B": {
        "oui_hex": "00-10-6B",
        "organization": "SONUS NETWORKS, INC.",
        "address_1": "5 CARLISLE ROAD",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "0010C3": {
        "oui_hex": "00-10-C3",
        "organization": "CSI-CONTROL SYSTEMS",
        "address_1": "INTERNATIONAL",
        "address_2": "DALLAS  TX  75229",
        "country": "US"
    },
    "009055": {
        "oui_hex": "00-90-55",
        "organization": "PARKER HANNIFIN CORPORATION COMPUMOTOR DIVISION",
        "address_1": "5500 BUSINESS PARK DRIVE",
        "address_2": "ROHNERT PARK  CA  94928",
        "country": "US"
    },
    "0010DD": {
        "oui_hex": "00-10-DD",
        "organization": "ENABLE SEMICONDUCTOR, INC.",
        "address_1": "1740 TECHNOLOGY DRIVE",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "00102D": {
        "oui_hex": "00-10-2D",
        "organization": "HITACHI SOFTWARE ENGINEERING",
        "address_1": "5-79, ONOECHO, NAKA-KU",
        "address_2": "YOKOHAMA 231",
        "country": "JP"
    },
    "001033": {
        "oui_hex": "00-10-33",
        "organization": "ACCESSLAN COMMUNICATIONS, INC.",
        "address_1": "44 AIRPORT PARKWAY",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "001012": {
        "oui_hex": "00-10-12",
        "organization": "PROCESSOR SYSTEMS (I) PVT LTD",
        "address_1": "24 RICHMOND ROAD",
        "address_2": "BANGALORE 560 025",
        "country": "IN"
    },
    "001015": {
        "oui_hex": "00-10-15",
        "organization": "OOmon Inc.",
        "address_1": "PO BOX 8241",
        "address_2": "COBURG  OR  97408",
        "country": "US"
    },
    "001078": {
        "oui_hex": "00-10-78",
        "organization": "NUERA COMMUNICATIONS, INC.",
        "address_1": "10445 PACIFIC CENTER COURT",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00104F": {
        "oui_hex": "00-10-4F",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "00107A": {
        "oui_hex": "00-10-7A",
        "organization": "AmbiCom, Inc.",
        "address_1": "2450 SCOTT BLVD., #305",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "0010B9": {
        "oui_hex": "00-10-B9",
        "organization": "MAXTOR CORP.",
        "address_1": "2190 MILLER DRIVE",
        "address_2": "LONGMONT  CO  80501-6744",
        "country": "US"
    },
    "00105D": {
        "oui_hex": "00-10-5D",
        "organization": "Draeger Medical",
        "address_1": "Moislinger Allee 53-55",
        "address_2": "Luebeck    D-23542",
        "country": "DE"
    },
    "001091": {
        "oui_hex": "00-10-91",
        "organization": "NO WIRES NEEDED BV",
        "address_1": "P.O. BOX 343",
        "address_2": "3720 AH BILTHOVEN",
        "country": "NL"
    },
    "00101B": {
        "oui_hex": "00-10-1B",
        "organization": "CORNET TECHNOLOGY, INC.",
        "address_1": "7F-4, NO. 46 CHUNG SHAN N.ROAD",
        "address_2": "SEC. 2, TAIPEI",
        "country": "TJ"
    },
    "0010DC": {
        "oui_hex": "00-10-DC",
        "organization": "MICRO-STAR INTERNATIONAL CO., LTD.",
        "address_1": "NO. 69, LI-DE ST., JUNG-HE CITY",
        "address_2": "Taipei Hsien",
        "country": "TW"
    },
    "00100A": {
        "oui_hex": "00-10-0A",
        "organization": "WILLIAMS COMMUNICATIONS GROUP",
        "address_1": "ADVANCED TECHNOLOGIES",
        "address_2": "TULSA  OK  74103",
        "country": "US"
    },
    "001032": {
        "oui_hex": "00-10-32",
        "organization": "ALTA TECHNOLOGY",
        "address_1": "9500 SOUTH 500 WEST - STE #212",
        "address_2": "SANDY  UT  84070",
        "country": "US"
    },
    "001080": {
        "oui_hex": "00-10-80",
        "organization": "METAWAVE COMMUNICATIONS",
        "address_1": "8700 148TH AVENUE N.E.",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "0010F4": {
        "oui_hex": "00-10-F4",
        "organization": "Vertical Communications",
        "address_1": "3979 Freedom Circle #400",
        "address_2": "Santa Clara  CA  95054-1247",
        "country": "US"
    },
    "001077": {
        "oui_hex": "00-10-77",
        "organization": "SAF DRIVE SYSTEMS, LTD.",
        "address_1": "88 ARDELT AVE.",
        "address_2": "KITCHENER, ONTARIO N2C 2C9",
        "country": "CA"
    },
    "0010B3": {
        "oui_hex": "00-10-B3",
        "organization": "NOKIA MULTIMEDIA TERMINALS",
        "address_1": "NOKIA HOME COMMUNICATIONS",
        "address_2": "SE-583 35 LINKOPING",
        "country": "SE"
    },
    "00101E": {
        "oui_hex": "00-10-1E",
        "organization": "MATSUSHITA ELECTRONIC INSTRUMENTS CORP.",
        "address_1": "23-9 KIYOHARA INDUSTRIAL PARK",
        "address_2": "UTSUNOMIYA Tochigi 321-32",
        "country": "JP"
    },
    "00104D": {
        "oui_hex": "00-10-4D",
        "organization": "SURTEC INDUSTRIES, INC.",
        "address_1": "NO.11, ALLEY 16, LANE 337",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "001051": {
        "oui_hex": "00-10-51",
        "organization": "CMICRO CORPORATION",
        "address_1": "17-20-2 KAMINO-CHO",
        "address_2": "TAKAMATSU-SHI, KAGAWA 761",
        "country": "JP"
    },
    "001037": {
        "oui_hex": "00-10-37",
        "organization": "CYQ've Technology Co., Ltd.",
        "address_1": "COSMO BLDG. 10F, NO.1-7",
        "address_2": "SHINJUKU-KU,  TOKYO 160",
        "country": "JP"
    },
    "00E0BB": {
        "oui_hex": "00-E0-BB",
        "organization": "NBX CORPORATION",
        "address_1": "100 BRICKSTONE SQUARE",
        "address_2": "ANDOVER  MA  01810",
        "country": "US"
    },
    "00E08A": {
        "oui_hex": "00-E0-8A",
        "organization": "GEC AVERY, LTD.",
        "address_1": "FOUNDRY LANE",
        "address_2": "WEST MIDLANDS, B66 2LP  England",
        "country": "GB"
    },
    "00E086": {
        "oui_hex": "00-E0-86",
        "organization": "Emerson Network Power, Avocent Division",
        "address_1": "4991 Corporate Drive",
        "address_2": "HUNTSVILLE  AL  35805",
        "country": "US"
    },
    "00E01B": {
        "oui_hex": "00-E0-1B",
        "organization": "SPHERE COMMUNICATIONS, INC.",
        "address_1": "2 ENERGY DRIVE",
        "address_2": "LAKE BLUFF  IL  60044",
        "country": "US"
    },
    "00E059": {
        "oui_hex": "00-E0-59",
        "organization": "CONTROLLED ENVIRONMENTS, LTD.",
        "address_1": "590 BERRY STREET",
        "address_2": "WINNEPEG R3H OR9",
        "country": "CA"
    },
    "00E0C5": {
        "oui_hex": "00-E0-C5",
        "organization": "BCOM ELECTRONICS INC.",
        "address_1": "8 FL, NO. 64, AN HO ROAD, SEC. 2",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "00E0EE": {
        "oui_hex": "00-E0-EE",
        "organization": "MAREL HF",
        "address_1": "Austurhraun 9",
        "address_2": "Gardabaer    210",
        "country": "IS"
    },
    "00E08E": {
        "oui_hex": "00-E0-8E",
        "organization": "UTSTARCOM",
        "address_1": "33 WOOD AVE. SOUTH",
        "address_2": "ISELIN  NJ  08830",
        "country": "US"
    },
    "00E03F": {
        "oui_hex": "00-E0-3F",
        "organization": "JATON CORPORATION",
        "address_1": "556 SOUTH MILPITAS BLVD.",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "00E0D4": {
        "oui_hex": "00-E0-D4",
        "organization": "EXCELLENT COMPUTER",
        "address_1": "551, M.K.N. ROAD",
        "address_2": "ALANDUR, CHENNAI 600016",
        "country": "IN"
    },
    "00E07F": {
        "oui_hex": "00-E0-7F",
        "organization": "LOGISTISTEM s.r.l.",
        "address_1": "VIA PANCIATICHI 94/18",
        "address_2": "50127 FIRENZE",
        "country": "IT"
    },
    "00E013": {
        "oui_hex": "00-E0-13",
        "organization": "EASTERN ELECTRONIC CO., LTD.",
        "address_1": "NO. 4, SHIN-LONG ROAD,",
        "address_2": "TAO-YUAN",
        "country": "TW"
    },
    "00E0FD": {
        "oui_hex": "00-E0-FD",
        "organization": "A-TREND TECHNOLOGY CO., LTD.",
        "address_1": "10F, NO. 75, HSIN TAI WU RD.,",
        "address_2": "TAIPEI HSIEN 221",
        "country": "TJ"
    },
    "00E0BD": {
        "oui_hex": "00-E0-BD",
        "organization": "INTERFACE SYSTEMS, INC.",
        "address_1": "5855 INTERFACE DRIVE",
        "address_2": "ANN ARBOR  MI  48103-9515",
        "country": "US"
    },
    "00E06E": {
        "oui_hex": "00-E0-6E",
        "organization": "FAR SYSTEMS S.p.A.",
        "address_1": "VIA F. ZENI 8",
        "address_2": "3868 ROVERETO (TN)",
        "country": "IT"
    },
    "00E06D": {
        "oui_hex": "00-E0-6D",
        "organization": "COMPUWARE CORPORATION",
        "address_1": "One Campus Martius",
        "address_2": "Detroit  MI  48226",
        "country": "US"
    },
    "00E0EA": {
        "oui_hex": "00-E0-EA",
        "organization": "INNOVAT COMMUNICATIONS, INC.",
        "address_1": "1257 N. PLANO ROAD",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "00E064": {
        "oui_hex": "00-E0-64",
        "organization": "SAMSUNG ELECTRONICS",
        "address_1": "99 W. TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00E0C9": {
        "oui_hex": "00-E0-C9",
        "organization": "AutomatedLogic Corporation",
        "address_1": "1150 ROBERTS BOULEVARD",
        "address_2": "KENNESAW  GA  30144-3618",
        "country": "US"
    },
    "00E038": {
        "oui_hex": "00-E0-38",
        "organization": "PROXIMA CORPORATION",
        "address_1": "9440 CARROLL PARK DRIVE",
        "address_2": "SAN DIEGO  CA  92121-2298",
        "country": "US"
    },
    "00E09C": {
        "oui_hex": "00-E0-9C",
        "organization": "MII",
        "address_1": "LE parc du MOULIN",
        "address_2": "F95650 PUISEUX-POTOISE",
        "country": "FR"
    },
    "00E0E9": {
        "oui_hex": "00-E0-E9",
        "organization": "DATA LABS, INC.",
        "address_1": "444 NORTH FREDERICK AVE.",
        "address_2": "GAITHERSBURG  MD  20877",
        "country": "US"
    },
    "00E00C": {
        "oui_hex": "00-E0-0C",
        "organization": "MOTOROLA",
        "address_1": "5401 N. BEACH ST.  S243",
        "address_2": "FT. WORTH  TX  76137",
        "country": "US"
    },
    "00E00A": {
        "oui_hex": "00-E0-0A",
        "organization": "DIBA, INC.",
        "address_1": "3355 EDISON WAY",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "00E0C4": {
        "oui_hex": "00-E0-C4",
        "organization": "HORNER ELECTRIC, INC.",
        "address_1": "1521 E. WASHINGTON ST.",
        "address_2": "INDIANAPOLIS  IN  46201",
        "country": "US"
    },
    "00E069": {
        "oui_hex": "00-E0-69",
        "organization": "JAYCOR",
        "address_1": "9775 TOWNE CENTRE DRIVE",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00E0A4": {
        "oui_hex": "00-E0-A4",
        "organization": "ESAOTE S.p.A.",
        "address_1": "via di CACIOLLE, 15",
        "address_2": "50127 FLORENCE",
        "country": "IT"
    },
    "00E0DE": {
        "oui_hex": "00-E0-DE",
        "organization": "DATAX NV",
        "address_1": "RINGLAAN 51",
        "address_2": "B-2600 BERCHEM",
        "country": "BE"
    },
    "00E0A5": {
        "oui_hex": "00-E0-A5",
        "organization": "ComCore Semiconductor, Inc.",
        "address_1": "4505 LAS VIRGENES, Suite 202",
        "address_2": "CALABASAS  CA  91302",
        "country": "US"
    },
    "00E015": {
        "oui_hex": "00-E0-15",
        "organization": "HEIWA CORPORATION",
        "address_1": "2-3014-8, HIROSAWA-CHO",
        "address_2": "GUNMA PREF. 376",
        "country": "JP"
    },
    "00E0E8": {
        "oui_hex": "00-E0-E8",
        "organization": "GRETACODER Data Systems AG",
        "address_1": "ALTHARDSTRASSE  150",
        "address_2": "CH-8105 REGENSDORF",
        "country": "CH"
    },
    "00E016": {
        "oui_hex": "00-E0-16",
        "organization": "RAPID CITY COMMUNICATIONS",
        "address_1": "555 CLYDE AVE.",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00E005": {
        "oui_hex": "00-E0-05",
        "organization": "TECHNICAL CORP.",
        "address_1": "22-6 MINAMI SENGENCHO",
        "address_2": "KANAGAWA",
        "country": "JP"
    },
    "00E0C1": {
        "oui_hex": "00-E0-C1",
        "organization": "MEMOREX TELEX JAPAN, LTD.",
        "address_1": "YAESUGUCHI KAIKAN, 1-7-20",
        "address_2": "TOKYO 103",
        "country": "JP"
    },
    "00E0A9": {
        "oui_hex": "00-E0-A9",
        "organization": "FUNAI ELECTRIC CO., LTD.",
        "address_1": "7-1, NAKAGAITO 7-CHOME, DAITO",
        "address_2": "OSAKA  574",
        "country": "JP"
    },
    "00E084": {
        "oui_hex": "00-E0-84",
        "organization": "COMPULITE R&D",
        "address_1": "3 HAROSHET STR. NEW IND. ZONE",
        "address_2": "RAMAT-HASHARON 47279",
        "country": "IL"
    },
    "00E096": {
        "oui_hex": "00-E0-96",
        "organization": "SHIMADZU CORPORATION",
        "address_1": "1, NISHINOKYO-KUWABARACHO",
        "address_2": "NAKAGYO-KU, KYOTO 604",
        "country": "US"
    },
    "00E017": {
        "oui_hex": "00-E0-17",
        "organization": "EXXACT GmbH",
        "address_1": "RHEINSTRASE 7",
        "address_2": "D-41836 HUCKELHOVEN",
        "country": "DE"
    },
    "00607F": {
        "oui_hex": "00-60-7F",
        "organization": "AURORA TECHNOLOGIES, INC.",
        "address_1": "176 SECOND AVENUE",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "00E029": {
        "oui_hex": "00-E0-29",
        "organization": "STANDARD MICROSYSTEMS CORP.",
        "address_1": "6 HUGHES",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "006074": {
        "oui_hex": "00-60-74",
        "organization": "QSC LLC",
        "address_1": "1675 MACARTHUR BLVD",
        "address_2": "COSTA MESA  CA  92626",
        "country": "US"
    },
    "006076": {
        "oui_hex": "00-60-76",
        "organization": "SCHLUMBERGER TECHNOLOGIES RETAIL PETROLEUM SYSTEMS",
        "address_1": "825-M GREENBRIER CIRCLE",
        "address_2": "CHESAPEAKE  VA  23320",
        "country": "US"
    },
    "0060A1": {
        "oui_hex": "00-60-A1",
        "organization": "VPNet, Inc.",
        "address_1": "555 N. MATHILDA AVE.,-STE #110",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "006027": {
        "oui_hex": "00-60-27",
        "organization": "Superior Modular Products",
        "address_1": "General Technology Division",
        "address_2": "MELBOURNE  FL  32940",
        "country": "US"
    },
    "0060BC": {
        "oui_hex": "00-60-BC",
        "organization": "KeunYoung Electronics & Communication Co., Ltd.",
        "address_1": "325-76, DAEHEUNG-DONG, MAPO-GU,",
        "address_2": "SEOUL",
        "country": "KR"
    },
    "0060A5": {
        "oui_hex": "00-60-A5",
        "organization": "PERFORMANCE TELECOM CORP.",
        "address_1": "10 CARLSON ROAD",
        "address_2": "ROCHESTER  NY  14610-1021",
        "country": "US"
    },
    "006005": {
        "oui_hex": "00-60-05",
        "organization": "FEEDBACK DATA LTD.",
        "address_1": "PARK ROAD",
        "address_2": "EAST SUSSEX, TN6 2QR",
        "country": "GB"
    },
    "00602E": {
        "oui_hex": "00-60-2E",
        "organization": "CYCLADES CORPORATION",
        "address_1": "41934 CHRISTY STREET",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "0060B6": {
        "oui_hex": "00-60-B6",
        "organization": "LAND COMPUTER CO., LTD.",
        "address_1": "7-4-17 NISHINAKAJIMA",
        "address_2": "YODOGAWAKU 532",
        "country": "JP"
    },
    "00606C": {
        "oui_hex": "00-60-6C",
        "organization": "ARESCOM",
        "address_1": "2833 JUNCTION AVE. - STE #206",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0060E3": {
        "oui_hex": "00-60-E3",
        "organization": "ARBIN INSTRUMENTS",
        "address_1": "3206 LONGMIRE DRIVE",
        "address_2": "COLLEGE STATION  TX  77845",
        "country": "US"
    },
    "006071": {
        "oui_hex": "00-60-71",
        "organization": "MIDAS LAB, INC.",
        "address_1": "4 KATAMACHI,",
        "address_2": "  TOKYO 160",
        "country": "JP"
    },
    "006061": {
        "oui_hex": "00-60-61",
        "organization": "WHISTLE COMMUNICATIONS CORP.",
        "address_1": "110 MARSH DRIVE-STE #100",
        "address_2": "FOSTER CITY  CA  94404",
        "country": "US"
    },
    "00601B": {
        "oui_hex": "00-60-1B",
        "organization": "MESA ELECTRONICS",
        "address_1": "1323 61ST STREET",
        "address_2": "EMERYVILLE  CA  94608-2117",
        "country": "US"
    },
    "0060C5": {
        "oui_hex": "00-60-C5",
        "organization": "ANCOT CORP.",
        "address_1": "115 CONSTITUTION DR.",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "0060A9": {
        "oui_hex": "00-60-A9",
        "organization": "GESYTEC MBH",
        "address_1": "PASCALSTRASSE 6",
        "address_2": "D 52076 AACHEN",
        "country": "DE"
    },
    "0060F2": {
        "oui_hex": "00-60-F2",
        "organization": "LASERGRAPHICS, INC.",
        "address_1": "20 ADA",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "0060C3": {
        "oui_hex": "00-60-C3",
        "organization": "NETVISION CORPORATION",
        "address_1": "MS# 1A",
        "address_2": "RONKONKOMA  NY  11779",
        "country": "US"
    },
    "006029": {
        "oui_hex": "00-60-29",
        "organization": "CARY PERIPHERALS INC.",
        "address_1": "190 COLONNADE ROAD S, UNIT 9",
        "address_2": "NEPEAN, ONTARIO K2E 7J5",
        "country": "CA"
    },
    "0060A8": {
        "oui_hex": "00-60-A8",
        "organization": "TIDOMAT AB",
        "address_1": "",
        "address_2": "S-12089 STOCKHOLM",
        "country": "SE"
    },
    "0060FC": {
        "oui_hex": "00-60-FC",
        "organization": "CONSERVATION THROUGH INNOVATION LTD.",
        "address_1": "1040 WHIPPLE ST.- STE. #225",
        "address_2": "PRESCOTT  AZ  86301",
        "country": "US"
    },
    "006018": {
        "oui_hex": "00-60-18",
        "organization": "STELLAR ONE CORPORATION",
        "address_1": "500 108TH AVE. NE--STE. #2200",
        "address_2": "BELLEVUE  WA  98004",
        "country": "US"
    },
    "00600A": {
        "oui_hex": "00-60-0A",
        "organization": "SORD COMPUTER CORPORATION",
        "address_1": "20-7, MASAGO 5-CHOME",
        "address_2": "CHIBA 261",
        "country": "JP"
    },
    "0060A4": {
        "oui_hex": "00-60-A4",
        "organization": "GEW Technologies (PTY)Ltd",
        "address_1": "BOX 912-561",
        "address_2": "SILVERTON  0127",
        "country": "ZA"
    },
    "006064": {
        "oui_hex": "00-60-64",
        "organization": "NETCOMM LIMITED",
        "address_1": "PO BOX 379",
        "address_2": "NORTH RYDE, NSW, 2113",
        "country": "AU"
    },
    "0060F9": {
        "oui_hex": "00-60-F9",
        "organization": "DIAMOND LANE COMMUNICATIONS",
        "address_1": "1310 REDWOOD WAY - STE.",
        "address_2": "PETALUMA  CA  94954",
        "country": "US"
    },
    "0060EA": {
        "oui_hex": "00-60-EA",
        "organization": "StreamLogic",
        "address_1": "21329 NORDHOFF STREET",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "006082": {
        "oui_hex": "00-60-82",
        "organization": "NOVALINK TECHNOLOGIES, INC.",
        "address_1": "48511 WARM SPRINGS BLVD. #208",
        "address_2": "FREMONT  CA  94539",
        "country": "US"
    },
    "0060E7": {
        "oui_hex": "00-60-E7",
        "organization": "RANDATA",
        "address_1": "PO BOX 209",
        "address_2": "HAWTHORN  VIC  3122",
        "country": "AU"
    },
    "0060D9": {
        "oui_hex": "00-60-D9",
        "organization": "TRANSYS NETWORKS INC.",
        "address_1": "3403 GRIFFITH",
        "address_2": "ST. LAURENT, QUEBEC H4T 1W5",
        "country": "CA"
    },
    "00601F": {
        "oui_hex": "00-60-1F",
        "organization": "STALLION TECHNOLOGIES",
        "address_1": "33 WOODSTOCK ROAD",
        "address_2": "TOOWONG Q-L-D- 4066",
        "country": "AU"
    },
    "006054": {
        "oui_hex": "00-60-54",
        "organization": "CONTROLWARE GMBH",
        "address_1": "WALDSTRASSE 92",
        "address_2": "63128 DIETZENBACH",
        "country": "DE"
    },
    "0060C2": {
        "oui_hex": "00-60-C2",
        "organization": "MPL AG",
        "address_1": "Taefernstrasse 20",
        "address_2": "CH-5405  Daettwil",
        "country": "CH"
    },
    "0060D4": {
        "oui_hex": "00-60-D4",
        "organization": "ELDAT COMMUNICATION LTD.",
        "address_1": "10 HAKISHON STREET",
        "address_2": "BNEI-BRAK  51203",
        "country": "IL"
    },
    "00A04E": {
        "oui_hex": "00-A0-4E",
        "organization": "VOELKER TECHNOLOGIES, INC.",
        "address_1": "22 NEW BOSTON COURT",
        "address_2": "DANVILLE  CA  94526",
        "country": "US"
    },
    "00A05A": {
        "oui_hex": "00-A0-5A",
        "organization": "KOFAX IMAGE PRODUCTS",
        "address_1": "3 JENNER STREET",
        "address_2": "IRVINE  CA  92718-3807",
        "country": "US"
    },
    "00A052": {
        "oui_hex": "00-A0-52",
        "organization": "STANILITE ELECTRONICS PTY. LTD",
        "address_1": "424, LANE COVE ROAD",
        "address_2": "NORTH RYDE NSW 2113",
        "country": "AU"
    },
    "00A05E": {
        "oui_hex": "00-A0-5E",
        "organization": "MYRIAD LOGIC INC.",
        "address_1": "1109 SPRING STREET",
        "address_2": "SILVER SPRING  MD  20910",
        "country": "US"
    },
    "00A095": {
        "oui_hex": "00-A0-95",
        "organization": "ACACIA NETWORKS, INC.",
        "address_1": "831 WOBURN STREET",
        "address_2": "WILMINGTON  MA  01887",
        "country": "US"
    },
    "00A053": {
        "oui_hex": "00-A0-53",
        "organization": "COMPACT DEVICES, INC.",
        "address_1": "16795 LARK AVENUE",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "00A069": {
        "oui_hex": "00-A0-69",
        "organization": "Symmetricom, Inc.",
        "address_1": "3750 Westwind Blvd.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "00A07A": {
        "oui_hex": "00-A0-7A",
        "organization": "ADVANCED PERIPHERALS TECHNOLOGIES, INC.",
        "address_1": "",
        "address_2": "FUJISAWA-SHI, KANAGAWA-KEN 251",
        "country": "JP"
    },
    "00609B": {
        "oui_hex": "00-60-9B",
        "organization": "AstroNova, Inc",
        "address_1": "600 EAST GREENWICH AVE.",
        "address_2": "WEST WARWICK  RI  02893",
        "country": "US"
    },
    "0060DB": {
        "oui_hex": "00-60-DB",
        "organization": "NTP ELEKTRONIK A/S",
        "address_1": "KNAPHOLM 7",
        "address_2": "DK-2730 HERLEV",
        "country": "DK"
    },
    "006052": {
        "oui_hex": "00-60-52",
        "organization": "PERIPHERALS ENTERPRISE CO., Ltd.",
        "address_1": "3F, NO.10, ALLEY 6, LANE 45",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "0060B2": {
        "oui_hex": "00-60-B2",
        "organization": "PROCESS CONTROL CORP.",
        "address_1": "6875 MIMMS DRIVE",
        "address_2": "ATLANTA  GA  30340",
        "country": "US"
    },
    "006081": {
        "oui_hex": "00-60-81",
        "organization": "TV/COM INTERNATIONAL",
        "address_1": "16516 VIA ESPRILLO",
        "address_2": "SAN DIEGO  CA  92127",
        "country": "US"
    },
    "00A005": {
        "oui_hex": "00-A0-05",
        "organization": "DANIEL INSTRUMENTS, LTD.",
        "address_1": "TROLLSTRASSE 33",
        "address_2": "CH-8400 WINTERTHUR",
        "country": "CH"
    },
    "00A0F2": {
        "oui_hex": "00-A0-F2",
        "organization": "INFOTEK COMMUNICATIONS, INC.",
        "address_1": "111 ANZA BLVD., #203",
        "address_2": "BURLINGAME  CA  94010",
        "country": "US"
    },
    "00A0DF": {
        "oui_hex": "00-A0-DF",
        "organization": "STS TECHNOLOGIES, INC.",
        "address_1": "13765 ST. CHARLES ROCK RD.",
        "address_2": "BRIDGETON  MO  63044",
        "country": "US"
    },
    "00A094": {
        "oui_hex": "00-A0-94",
        "organization": "COMSAT CORPORATION",
        "address_1": "22300 COMSAT DRIVE",
        "address_2": "CLARKSBURG  MD  20871-9475",
        "country": "US"
    },
    "00A0EF": {
        "oui_hex": "00-A0-EF",
        "organization": "LUCIDATA LTD.",
        "address_1": "LUCIDATA HOUSE",
        "address_2": "GREAT SHELFORD  CAMBBRIDGE CB2 5HA",
        "country": "GB"
    },
    "00A020": {
        "oui_hex": "00-A0-20",
        "organization": "CITICORP/TTI",
        "address_1": "3100 OCEAN PARK BLVD.",
        "address_2": "SANTA MONICA  CA  90405",
        "country": "US"
    },
    "00A0CE": {
        "oui_hex": "00-A0-CE",
        "organization": "Ecessa",
        "address_1": "2800 Campus Drive",
        "address_2": "Plymouth  MN  55441",
        "country": "US"
    },
    "00A028": {
        "oui_hex": "00-A0-28",
        "organization": "CONNER PERIPHERALS",
        "address_1": "3061 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95134-2128",
        "country": "US"
    },
    "00A09E": {
        "oui_hex": "00-A0-9E",
        "organization": "ICTV",
        "address_1": "14600 WINCHESTER BLVD.",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "00A099": {
        "oui_hex": "00-A0-99",
        "organization": "K-NET LTD.",
        "address_1": "SADDLERS HOUSE",
        "address_2": "YATELEY, SURREY GU17 7RX",
        "country": "GB"
    },
    "00A0EC": {
        "oui_hex": "00-A0-EC",
        "organization": "TRANSMITTON LTD.",
        "address_1": "SMISBY ROAD",
        "address_2": "LEICESTERSHIRE LE65 2UG",
        "country": "GB"
    },
    "00A067": {
        "oui_hex": "00-A0-67",
        "organization": "NETWORK SERVICES GROUP",
        "address_1": "3421 COMMISSION COURT-STE #202",
        "address_2": "WOODBRIDGE  VA  22192",
        "country": "US"
    },
    "00A0E0": {
        "oui_hex": "00-A0-E0",
        "organization": "TENNYSON TECHNOLOGIES PTY LTD",
        "address_1": "14 BUSINESS PARK DRIVE",
        "address_2": "VICTORIA - 3168",
        "country": "AU"
    },
    "00A0FD": {
        "oui_hex": "00-A0-FD",
        "organization": "SCITEX DIGITAL PRINTING, INC.",
        "address_1": "3100 RESEARCH BLVD.",
        "address_2": "DAYTON  OH  45420",
        "country": "US"
    },
    "00A00F": {
        "oui_hex": "00-A0-0F",
        "organization": "Broadband Technologies",
        "address_1": "P.O. Box 13737",
        "address_2": "Research Triangle Park,  NC  27709-3737",
        "country": "US"
    },
    "00A002": {
        "oui_hex": "00-A0-02",
        "organization": "LEEDS & NORTHRUP AUSTRALIA PTY LTD",
        "address_1": "PO BOX 4009",
        "address_2": "EIGHT MILE PLAINS  QLD 4113",
        "country": "AU"
    },
    "00A0E4": {
        "oui_hex": "00-A0-E4",
        "organization": "OPTIQUEST",
        "address_1": "20490 BUSINESS PARKWAY",
        "address_2": "WALNUT  CA  91789",
        "country": "US"
    },
    "00A0EE": {
        "oui_hex": "00-A0-EE",
        "organization": "NASHOBA NETWORKS",
        "address_1": "9-11 GOLDSMITH ST.",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "00A0C3": {
        "oui_hex": "00-A0-C3",
        "organization": "UNICOMPUTER GMBH",
        "address_1": "LIMBURGER STRASSE 48",
        "address_2": "",
        "country": "DE"
    },
    "00A00A": {
        "oui_hex": "00-A0-0A",
        "organization": "Airspan",
        "address_1": "Unitronics Building, Arava Street, Airport City",
        "address_2": "    70100",
        "country": "IL"
    },
    "00A0E7": {
        "oui_hex": "00-A0-E7",
        "organization": "CENTRAL DATA CORPORATION",
        "address_1": "1602 NEWTON DRIVE",
        "address_2": "CHAMPAIGN  IL  61821",
        "country": "US"
    },
    "00A080": {
        "oui_hex": "00-A0-80",
        "organization": "Tattile SRL",
        "address_1": "4000 Executive Parkway",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "00A02B": {
        "oui_hex": "00-A0-2B",
        "organization": "TRANSITIONS RESEARCH CORP.",
        "address_1": "SHELTER ROCK LANE",
        "address_2": "DANBURY  CT  06810",
        "country": "US"
    },
    "00A0E8": {
        "oui_hex": "00-A0-E8",
        "organization": "REUTERS HOLDINGS PLC",
        "address_1": "85, FLEET STREET",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00A008": {
        "oui_hex": "00-A0-08",
        "organization": "NETCORP",
        "address_1": "8 PLACE OF COMMERCE--STE #200",
        "address_2": "CANADA  J4W  3H2",
        "country": "CA"
    },
    "00A050": {
        "oui_hex": "00-A0-50",
        "organization": "CYPRESS SEMICONDUCTOR",
        "address_1": "198 Champion Ct",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00A0DD": {
        "oui_hex": "00-A0-DD",
        "organization": "AZONIX CORPORATION",
        "address_1": "900 MIDDLESEX TURNPIKE",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "00A075": {
        "oui_hex": "00-A0-75",
        "organization": "MICRON TECHNOLOGY, INC.",
        "address_1": "8000 S. Federal Way",
        "address_2": "Boise  ID  83707-0006",
        "country": "US"
    },
    "00A009": {
        "oui_hex": "00-A0-09",
        "organization": "WHITETREE NETWORK",
        "address_1": "TECHNOLOGIES, INC.",
        "address_2": "PALO ALTO  CA  94306",
        "country": "US"
    },
    "00A00C": {
        "oui_hex": "00-A0-0C",
        "organization": "KINGMAX TECHNOLOGY, INC.",
        "address_1": "2FL., NO. 4, LANE 902, SEC.2",
        "address_2": "",
        "country": "TW"
    },
    "00A066": {
        "oui_hex": "00-A0-66",
        "organization": "ISA CO., LTD.",
        "address_1": "SHINJUKU LAMBDAX BLDG. 5F.,",
        "address_2": "",
        "country": "JP"
    },
    "00A0AB": {
        "oui_hex": "00-A0-AB",
        "organization": "NETCS INFORMATIONSTECHNIK GMBH",
        "address_1": "KATHARINENSTRASSE 17-18",
        "address_2": "",
        "country": "DE"
    },
    "00A0D8": {
        "oui_hex": "00-A0-D8",
        "organization": "SPECTRA - TEK",
        "address_1": "OUTGANG LANE",
        "address_2": "ENGLAND  Y018  FJA",
        "country": "GB"
    },
    "00A0FA": {
        "oui_hex": "00-A0-FA",
        "organization": "Marconi Communication GmbH",
        "address_1": "Gerberstrasse 33",
        "address_2": "",
        "country": "DE"
    },
    "00A0CB": {
        "oui_hex": "00-A0-CB",
        "organization": "ARK TELECOMMUNICATIONS, INC.",
        "address_1": "124 CARMEN LANE--SUITE",
        "address_2": "SANTA MARIA  CA  93454",
        "country": "US"
    },
    "00A034": {
        "oui_hex": "00-A0-34",
        "organization": "AXEL",
        "address_1": "16, AVENUE DU QUEBEC",
        "address_2": "",
        "country": "FR"
    },
    "00A001": {
        "oui_hex": "00-A0-01",
        "organization": "DRS Signal Solutions",
        "address_1": "700 Quince Orchard Road",
        "address_2": "Gaithersburg  MD  20878-1794",
        "country": "US"
    },
    "0020B2": {
        "oui_hex": "00-20-B2",
        "organization": "GKD Gesellschaft Fur Kommunikation Und Datentechnik",
        "address_1": "SAARBURGER RING 10-12",
        "address_2": " 68229 MANNHEIM",
        "country": "DE"
    },
    "002052": {
        "oui_hex": "00-20-52",
        "organization": "RAGULA SYSTEMS",
        "address_1": "4540 S. JUPITER DRIVE",
        "address_2": "SALT LAKE CITY  UT  84124",
        "country": "US"
    },
    "0020FC": {
        "oui_hex": "00-20-FC",
        "organization": "MATROX",
        "address_1": "1055 ST. REGIS,",
        "address_2": "DORVAL, QUEBEC  H9P-2T4",
        "country": "CA"
    },
    "0020FE": {
        "oui_hex": "00-20-FE",
        "organization": "TOPWARE INC. / GRAND COMPUTER",
        "address_1": "CORPORATION",
        "address_2": "TAIPEI    R.O.C.",
        "country": "TW"
    },
    "002073": {
        "oui_hex": "00-20-73",
        "organization": "FUSION SYSTEMS CORPORATION",
        "address_1": "7600 STANDISH PLACE",
        "address_2": "ROCKVILLE  MD  20855",
        "country": "US"
    },
    "002035": {
        "oui_hex": "00-20-35",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "00A017": {
        "oui_hex": "00-A0-17",
        "organization": "J B M CORPORATION",
        "address_1": "10-1, ARAMOTOSHIN MACHI",
        "address_2": "    577",
        "country": "JP"
    },
    "00A025": {
        "oui_hex": "00-A0-25",
        "organization": "REDCOM LABS INC.",
        "address_1": "ONE REDCOM CENTER",
        "address_2": "VICTOR  NY  14564-0995",
        "country": "US"
    },
    "00A0BB": {
        "oui_hex": "00-A0-BB",
        "organization": "HILAN GMBH",
        "address_1": "HAID-UND-NEU-STRASSE 7",
        "address_2": "",
        "country": "DE"
    },
    "00A091": {
        "oui_hex": "00-A0-91",
        "organization": "APPLICOM INTERNATIONAL",
        "address_1": "43, RUE MAZAGRAN",
        "address_2": "",
        "country": "FR"
    },
    "00A0A5": {
        "oui_hex": "00-A0-A5",
        "organization": "TEKNOR MICROSYSTEME, INC.",
        "address_1": "616 CURE BOIVIN",
        "address_2": "    J7G 2A7",
        "country": "CA"
    },
    "0020B7": {
        "oui_hex": "00-20-B7",
        "organization": "NAMAQUA COMPUTERWARE",
        "address_1": "P.O. BOX 7155",
        "address_2": "",
        "country": "ZA"
    },
    "0020E3": {
        "oui_hex": "00-20-E3",
        "organization": "MCD KENCOM CORPORATION",
        "address_1": "20950 CASTLE ROCK ROAD",
        "address_2": "LAGUNA BEACH  CA  92651-1115",
        "country": "US"
    },
    "002013": {
        "oui_hex": "00-20-13",
        "organization": "DIVERSIFIED TECHNOLOGY, INC.",
        "address_1": "112 E. STATE STREET",
        "address_2": "RIDGELAND  MS  39157",
        "country": "US"
    },
    "0020AB": {
        "oui_hex": "00-20-AB",
        "organization": "MICRO INDUSTRIES CORP.",
        "address_1": "8399 GREEN MEADOWS DR. N.",
        "address_2": "WESTERVILLE  OH  43081",
        "country": "US"
    },
    "00208D": {
        "oui_hex": "00-20-8D",
        "organization": "CMD TECHNOLOGY",
        "address_1": "1 VANDERBILT",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "0020DD": {
        "oui_hex": "00-20-DD",
        "organization": "Cybertec Pty Ltd",
        "address_1": "Unit 11, 41 Higginbotham Road",
        "address_2": "Gladesville  NSW  2111",
        "country": "AU"
    },
    "0020E6": {
        "oui_hex": "00-20-E6",
        "organization": "LIDKOPING MACHINE TOOLS AB",
        "address_1": "BOX 910",
        "address_2": "",
        "country": "SE"
    },
    "00A0A2": {
        "oui_hex": "00-A0-A2",
        "organization": "DIGICOM S.P.A.",
        "address_1": "VIA VOLTA 39",
        "address_2": "",
        "country": "IT"
    },
    "002086": {
        "oui_hex": "00-20-86",
        "organization": "MICROTECH ELECTRONICS LIMITED",
        "address_1": "LANCASTER ROAD",
        "address_2": "    KINGDOM",
        "country": "GB"
    },
    "002023": {
        "oui_hex": "00-20-23",
        "organization": "T.C. TECHNOLOGIES PTY. LTD",
        "address_1": "6/60 FAIRFORD RD.",
        "address_2": "",
        "country": "AU"
    },
    "00A054": {
        "oui_hex": "00-A0-54",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "00205A": {
        "oui_hex": "00-20-5A",
        "organization": "COMPUTER IDENTICS",
        "address_1": "5 SHAWMUT ROAD",
        "address_2": "CANTON  MA  02021",
        "country": "US"
    },
    "002000": {
        "oui_hex": "00-20-00",
        "organization": "LEXMARK INTERNATIONAL, INC.",
        "address_1": "740 NEW CIRCLE ROAD",
        "address_2": "LEXINGTON  KY  40550",
        "country": "US"
    },
    "00201D": {
        "oui_hex": "00-20-1D",
        "organization": "KATANA PRODUCTS",
        "address_1": "THE STUDIO, QUARRY HILL BOX,",
        "address_2": "WILTSHIRE SN14 9HT",
        "country": "GB"
    },
    "002003": {
        "oui_hex": "00-20-03",
        "organization": "PIXEL POWER LTD.",
        "address_1": "Unit 5 College Business Park",
        "address_2": "CAMBRIDGE    CB1 3HD",
        "country": "GB"
    },
    "002046": {
        "oui_hex": "00-20-46",
        "organization": "CIPRICO, INC.",
        "address_1": "2800 CAMPUS DRIVE--SUITE #60",
        "address_2": "PLYMOUTH  MN  55441",
        "country": "US"
    },
    "00209B": {
        "oui_hex": "00-20-9B",
        "organization": "ERSAT ELECTRONIC GMBH",
        "address_1": "HAARBERGSTR. 61",
        "address_2": "",
        "country": "DE"
    },
    "00201C": {
        "oui_hex": "00-20-1C",
        "organization": "EXCEL, INC.",
        "address_1": "355 OLD PLYMOUTH ROAD",
        "address_2": "SAGAMORE BEACH  MA  02562",
        "country": "US"
    },
    "00207F": {
        "oui_hex": "00-20-7F",
        "organization": "KYOEI SANGYO CO., LTD.",
        "address_1": "DIR. & GEN'L MGR.IND. SYSTEMS",
        "address_2": "    TOKYO",
        "country": "JP"
    },
    "0020C9": {
        "oui_hex": "00-20-C9",
        "organization": "VICTRON BV",
        "address_1": "POB 31",
        "address_2": "  THE",
        "country": "NL"
    },
    "002077": {
        "oui_hex": "00-20-77",
        "organization": "KARDIOS SYSTEMS CORP.",
        "address_1": "26 N SUMMIT AVE.",
        "address_2": "GAITHERSBURG  MD  20877",
        "country": "US"
    },
    "00207A": {
        "oui_hex": "00-20-7A",
        "organization": "WiSE Communications, Inc.",
        "address_1": "130 KNOWLES DRIVE",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "00203E": {
        "oui_hex": "00-20-3E",
        "organization": "LogiCan Technologies, Inc.",
        "address_1": "150 KARL CLARK ROAD",
        "address_2": "EDMONTON, ALBERTA T6N 1E2",
        "country": "CA"
    },
    "002058": {
        "oui_hex": "00-20-58",
        "organization": "ALLIED SIGNAL INC.",
        "address_1": "ROUTE 46",
        "address_2": "TETERBORO  NJ  07608",
        "country": "US"
    },
    "0020E1": {
        "oui_hex": "00-20-E1",
        "organization": "ALAMAR ELECTRONICS",
        "address_1": "489 DIVISION STREET",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "002026": {
        "oui_hex": "00-20-26",
        "organization": "AMKLY SYSTEMS, INC.",
        "address_1": "15801 ROCKFIELD BLVD., #P",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "002065": {
        "oui_hex": "00-20-65",
        "organization": "SUPERNET NETWORKING INC.",
        "address_1": "16 TOZERET HA'ARETZ ST.",
        "address_2": "TEL-AVIV 67891",
        "country": "IL"
    },
    "00202A": {
        "oui_hex": "00-20-2A",
        "organization": "N.V. DZINE",
        "address_1": "KONING LEOPOLD III LAAN 2",
        "address_2": "",
        "country": "BE"
    },
    "002083": {
        "oui_hex": "00-20-83",
        "organization": "PRESTICOM INCORPORATED",
        "address_1": "3275, 1ST STREET, STE. #1",
        "address_2": "CANADA  J3Y  8Y6",
        "country": "CA"
    },
    "002019": {
        "oui_hex": "00-20-19",
        "organization": "OHLER GMBH",
        "address_1": "MAYBACHSTRASE 30",
        "address_2": "71332 WAIBLINGEN",
        "country": "DE"
    },
    "00209E": {
        "oui_hex": "00-20-9E",
        "organization": "BROWN'S OPERATING SYSTEM SERVICES, LTD.",
        "address_1": "ST. AGNES HOUSE, CRESSWELL PK,",
        "address_2": "BLACKHEATH, London SE3 9RD",
        "country": "GB"
    },
    "00208E": {
        "oui_hex": "00-20-8E",
        "organization": "CHEVIN SOFTWARE ENG. LTD.",
        "address_1": "2 BOROUGHGATE, OTLEY,",
        "address_2": "LS21 3AL  UNITED  KINGDOM",
        "country": "GB"
    },
    "002097": {
        "oui_hex": "00-20-97",
        "organization": "APPLIED SIGNAL TECHNOLOGY",
        "address_1": "160 SOBRANTE WAY",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00C00B": {
        "oui_hex": "00-C0-0B",
        "organization": "NORCONTROL A.S.",
        "address_1": "P.O. BOX 1024",
        "address_2": "",
        "country": "NO"
    },
    "0020B0": {
        "oui_hex": "00-20-B0",
        "organization": "GATEWAY DEVICES, INC.",
        "address_1": "2440 STANWELL DRIVE",
        "address_2": "CONCORD  CA  94520",
        "country": "US"
    },
    "00205B": {
        "oui_hex": "00-20-5B",
        "organization": "Kentrox, LLC",
        "address_1": "20010 NW Tanasbourne Dr.",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "0020F6": {
        "oui_hex": "00-20-F6",
        "organization": "NET TEK  AND KARLNET, INC.",
        "address_1": "LITTLE STREAMS",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0020C6": {
        "oui_hex": "00-20-C6",
        "organization": "NECTEC",
        "address_1": "RAMA VI ROAD",
        "address_2": "",
        "country": "TH"
    },
    "002008": {
        "oui_hex": "00-20-08",
        "organization": "CABLE & COMPUTER TECHNOLOGY",
        "address_1": "1555 SO. SINCLAIR STREET",
        "address_2": "ANAHEIM  CA  92806",
        "country": "US"
    },
    "0020D3": {
        "oui_hex": "00-20-D3",
        "organization": "OST (OUEST STANDARD TELEMATIQU",
        "address_1": "RUE DU BAS VILLAGE",
        "address_2": "",
        "country": "FR"
    },
    "00C00E": {
        "oui_hex": "00-C0-0E",
        "organization": "PSITECH, INC.",
        "address_1": "18368 BANDILIER CIRCLE",
        "address_2": "FOUNTAIN VALLEY  CA  92708",
        "country": "US"
    },
    "00C031": {
        "oui_hex": "00-C0-31",
        "organization": "DESIGN RESEARCH SYSTEMS, INC.",
        "address_1": "925 E. EXECUTIVE PARK DR.",
        "address_2": "SALT LAKE CITY  UT  84117",
        "country": "US"
    },
    "000701": {
        "oui_hex": "00-07-01",
        "organization": "RACAL-DATACOM",
        "address_1": "LAN INTERNETWORKING DIVISION",
        "address_2": "BOXBOROUGH  MA  01719",
        "country": "US"
    },
    "00C09C": {
        "oui_hex": "00-C0-9C",
        "organization": "HIOKI E.E. CORPORATION",
        "address_1": "81 Koizumi, Ueda, Nagano",
        "address_2": "Tokyo    386-1192",
        "country": "JP"
    },
    "00C0AA": {
        "oui_hex": "00-C0-AA",
        "organization": "SILICON VALLEY COMPUTER",
        "address_1": "441 N. WHISMAN RD., BLDG.#13",
        "address_2": "MT. VIEW  CA  94043",
        "country": "US"
    },
    "00C066": {
        "oui_hex": "00-C0-66",
        "organization": "DOCUPOINT, INC.",
        "address_1": "2701 BAYVIEW DRIVE",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C02D": {
        "oui_hex": "00-C0-2D",
        "organization": "FUJI PHOTO FILM CO., LTD.",
        "address_1": "798 MIYANODAI KAISEI-MACHI",
        "address_2": "",
        "country": "JP"
    },
    "00C0F2": {
        "oui_hex": "00-C0-F2",
        "organization": "TRANSITION NETWORKS",
        "address_1": "10900 Red Circle Dr.",
        "address_2": "MInnetonka  MN  55343",
        "country": "US"
    },
    "00C0BD": {
        "oui_hex": "00-C0-BD",
        "organization": "INEX TECHNOLOGIES, INC.",
        "address_1": "3350 SCOTT BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00C088": {
        "oui_hex": "00-C0-88",
        "organization": "EKF ELEKTRONIK GMBH",
        "address_1": "PHILIPP-REIS-STR. 4",
        "address_2": "",
        "country": "DE"
    },
    "00C011": {
        "oui_hex": "00-C0-11",
        "organization": "INTERACTIVE COMPUTING DEVICES",
        "address_1": "1735 TECHNOLOGY DRIVE-STE #720",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "00C03E": {
        "oui_hex": "00-C0-3E",
        "organization": "FA. GEBR. HELLER GMBH",
        "address_1": "P.O. BOX 1428, DEP. EE7",
        "address_2": "",
        "country": "DE"
    },
    "00C0FD": {
        "oui_hex": "00-C0-FD",
        "organization": "PROSUM",
        "address_1": "12 RUE SADI-CARNOT",
        "address_2": "",
        "country": "FR"
    },
    "00C014": {
        "oui_hex": "00-C0-14",
        "organization": "TELEMATICS CALABASAS INT'L,INC",
        "address_1": "26630 AGOURA ROAD",
        "address_2": "CALABASAS  CA  91302-1988",
        "country": "US"
    },
    "00AA3C": {
        "oui_hex": "00-AA-3C",
        "organization": "OLIVETTI TELECOM SPA (OLTECO)",
        "address_1": "10062 MILLER AVE.-STE.#204",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00C0C9": {
        "oui_hex": "00-C0-C9",
        "organization": "ELSAG BAILEY PROCESS",
        "address_1": "AUTOMATION",
        "address_2": "WICKLIFFE  OH  44092",
        "country": "US"
    },
    "00C048": {
        "oui_hex": "00-C0-48",
        "organization": "BAY TECHNICAL ASSOCIATES",
        "address_1": "200 N. SECOND STREET",
        "address_2": "BAY ST. LOUIS  MS  39520",
        "country": "US"
    },
    "00C076": {
        "oui_hex": "00-C0-76",
        "organization": "I-DATA INTERNATIONAL A-S",
        "address_1": "35-43 VADSTRUPVEJ",
        "address_2": "",
        "country": "DK"
    },
    "00C046": {
        "oui_hex": "00-C0-46",
        "organization": "Blue Chip Technology Ltd",
        "address_1": "Chowley Oak Lane",
        "address_2": "Chester  Cheshire  CH3 9EX",
        "country": "GB"
    },
    "00C097": {
        "oui_hex": "00-C0-97",
        "organization": "ARCHIPEL SA",
        "address_1": "1 RUE DU BULLOZ",
        "address_2": "",
        "country": "FR"
    },
    "00C004": {
        "oui_hex": "00-C0-04",
        "organization": "JAPAN BUSINESS COMPUTER CO.LTD",
        "address_1": "1368 FUTOO-CHO, KOHOKU-KU",
        "address_2": "  222",
        "country": "JP"
    },
    "00C060": {
        "oui_hex": "00-C0-60",
        "organization": "ID SCANDINAVIA AS",
        "address_1": "P.O. BOX 4227",
        "address_2": "",
        "country": "NO"
    },
    "0040CC": {
        "oui_hex": "00-40-CC",
        "organization": "SILCOM MANUF'G TECHNOLOGY INC.",
        "address_1": "5620 TIMBERLEA BOULEVARD",
        "address_2": "CANADA  L4W  4M6",
        "country": "CA"
    },
    "00C09E": {
        "oui_hex": "00-C0-9E",
        "organization": "CACHE COMPUTERS, INC.",
        "address_1": "46600 LANDING PARKWAY",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C0AC": {
        "oui_hex": "00-C0-AC",
        "organization": "GAMBIT COMPUTER COMMUNICATIONS",
        "address_1": "SOLTAM INDUSTRIAL PARK",
        "address_2": "",
        "country": "IL"
    },
    "00C034": {
        "oui_hex": "00-C0-34",
        "organization": "TRANSACTION NETWORK",
        "address_1": "SERVICES, INC.",
        "address_2": "LANSING  MI  48910-8356",
        "country": "US"
    },
    "00C093": {
        "oui_hex": "00-C0-93",
        "organization": "ALTA RESEARCH CORP.",
        "address_1": "614 SOUTH FEDERAL HIGHWAY",
        "address_2": "DEERFIELD BEACH  FL  33441",
        "country": "US"
    },
    "0040E7": {
        "oui_hex": "00-40-E7",
        "organization": "ARNOS INSTRUMENTS & COMPUTER",
        "address_1": "SYSTEMS (GROUP) CO., LTD.",
        "address_2": "TSUEN WAN  N.T.",
        "country": "HK"
    },
    "004087": {
        "oui_hex": "00-40-87",
        "organization": "UBITREX CORPORATION",
        "address_1": "19TH FLOOR, 155 CARLTON STREET",
        "address_2": "CANADA  R3C  3H8",
        "country": "CA"
    },
    "004007": {
        "oui_hex": "00-40-07",
        "organization": "TELMAT INFORMATIQUE",
        "address_1": "6 RUE DE L'INDUSTRIE",
        "address_2": "",
        "country": "FR"
    },
    "00407B": {
        "oui_hex": "00-40-7B",
        "organization": "SCIENTIFIC ATLANTA",
        "address_1": "Information Technology",
        "address_2": "Norcross  GA  30091-6850",
        "country": "US"
    },
    "00402C": {
        "oui_hex": "00-40-2C",
        "organization": "ISIS DISTRIBUTED SYSTEMS, INC.",
        "address_1": "111 SOUTH CAYUGA STREET",
        "address_2": "ITHACA  NY  14850",
        "country": "US"
    },
    "00C0DF": {
        "oui_hex": "00-C0-DF",
        "organization": "KYE Systems Corp.",
        "address_1": "No. 492 Sec 5, Chung Hsin Road",
        "address_2": "Taipei  Hsien  241",
        "country": "TW"
    },
    "00C0F5": {
        "oui_hex": "00-C0-F5",
        "organization": "METACOMP, INC.",
        "address_1": "10989 VIA FRONTERA",
        "address_2": "SAN DIEGO  CA  92127",
        "country": "US"
    },
    "00C091": {
        "oui_hex": "00-C0-91",
        "organization": "JABIL CIRCUIT, INC.",
        "address_1": "32275 MALLY ROAD",
        "address_2": "MADISON HEIGHTS  MI  48071",
        "country": "US"
    },
    "00C049": {
        "oui_hex": "00-C0-49",
        "organization": "U.S. ROBOTICS, INC.",
        "address_1": "8100 NORTH MCCORMICK BLVD.",
        "address_2": "SKOKIE  IL  60076-2999",
        "country": "US"
    },
    "00C09D": {
        "oui_hex": "00-C0-9D",
        "organization": "DISTRIBUTED SYSTEMS INT'L, INC",
        "address_1": "531 WEST ROOSEVLET RD, STE #2",
        "address_2": "WHEATON  IL  60187",
        "country": "US"
    },
    "00C0E9": {
        "oui_hex": "00-C0-E9",
        "organization": "OAK SOLUTIONS, LTD.",
        "address_1": "BROADWAY HOUSE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00C0C5": {
        "oui_hex": "00-C0-C5",
        "organization": "SID INFORMATICA",
        "address_1": "RUA DR. GERALDO CAMPOS MOREIRA",
        "address_2": "",
        "country": "BR"
    },
    "00C051": {
        "oui_hex": "00-C0-51",
        "organization": "ADVANCED INTEGRATION RESEARCH",
        "address_1": "2188 DEL FRANCO STREET",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00C085": {
        "oui_hex": "00-C0-85",
        "organization": "ELECTRONICS FOR IMAGING, INC.",
        "address_1": "2855 CAMPUS DRIVE",
        "address_2": "SAN MATEO  CA  94403",
        "country": "US"
    },
    "00C0B2": {
        "oui_hex": "00-C0-B2",
        "organization": "NORAND CORPORATION",
        "address_1": "550 2ND STREET SE",
        "address_2": "CEDAR RAPIDS  IA  52401",
        "country": "US"
    },
    "00C054": {
        "oui_hex": "00-C0-54",
        "organization": "NETWORK PERIPHERALS, LTD.",
        "address_1": "4TH FLOOR, 17 BOWATER RD.",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00C022": {
        "oui_hex": "00-C0-22",
        "organization": "LASERMASTER TECHNOLOGIES, INC.",
        "address_1": "7156 SHADY OAK ROAD",
        "address_2": "EDEN PRAIRIE  MN  55344",
        "country": "US"
    },
    "00C025": {
        "oui_hex": "00-C0-25",
        "organization": "DATAPRODUCTS CORPORATION",
        "address_1": "6219 DESOTO AVENUE",
        "address_2": "WOODLAND HILLS  CA  91365-0746",
        "country": "US"
    },
    "0040CF": {
        "oui_hex": "00-40-CF",
        "organization": "STRAWBERRY TREE, INC.",
        "address_1": "160 SOUTH WOLFE ROAD",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "004077": {
        "oui_hex": "00-40-77",
        "organization": "MAXTON TECHNOLOGY CORPORATION",
        "address_1": "4FK, 249, SEC. 3,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00C02C": {
        "oui_hex": "00-C0-2C",
        "organization": "CENTRUM COMMUNICATIONS, INC.",
        "address_1": "2880 ZANKER ROAD-STE #108",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00C0FB": {
        "oui_hex": "00-C0-FB",
        "organization": "ADVANCED TECHNOLOGY LABS",
        "address_1": "22100 BOTHELL HIGHWAY S.E.",
        "address_2": "BOTHELL  WA  98041-3003",
        "country": "US"
    },
    "00C02B": {
        "oui_hex": "00-C0-2B",
        "organization": "GERLOFF GESELLSCHAFT FUR",
        "address_1": "ELEKRONISCHE SYSTEMENTWICKLUNG",
        "address_2": "",
        "country": "DE"
    },
    "004074": {
        "oui_hex": "00-40-74",
        "organization": "CABLE AND WIRELESS",
        "address_1": "COMMUNICATIONS, INC.",
        "address_2": "VIENNA  VA  22182-3964",
        "country": "US"
    },
    "0040B8": {
        "oui_hex": "00-40-B8",
        "organization": "IDEA ASSOCIATES",
        "address_1": "29 DUNHAM ROAD",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "0040E8": {
        "oui_hex": "00-40-E8",
        "organization": "CHARLES RIVER DATA SYSTEMS,INC",
        "address_1": "983 CONCORD STREET",
        "address_2": "FRAMINGHAM  MA  01701",
        "country": "US"
    },
    "0040C0": {
        "oui_hex": "00-40-C0",
        "organization": "VISTA CONTROLS CORPORATION",
        "address_1": "27825 FREMONT COURT",
        "address_2": "VALENCIA  CA  91355",
        "country": "US"
    },
    "00C0A0": {
        "oui_hex": "00-C0-A0",
        "organization": "ADVANCE MICRO RESEARCH, INC.",
        "address_1": "2045 CORPORATE COURT",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00C010": {
        "oui_hex": "00-C0-10",
        "organization": "HIRAKAWA HEWTECH CORP.",
        "address_1": "7F, BLDG.B, OMORI BELLPORT",
        "address_2": "",
        "country": "JP"
    },
    "00C037": {
        "oui_hex": "00-C0-37",
        "organization": "DYNATEM",
        "address_1": "15795 ROCKFIELD BLVD.",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "004083": {
        "oui_hex": "00-40-83",
        "organization": "TDA INDUSTRIA DE PRODUTOS",
        "address_1": "ELETRONICOS S.A.",
        "address_2": "",
        "country": "BR"
    },
    "00405B": {
        "oui_hex": "00-40-5B",
        "organization": "FUNASSET LIMITED",
        "address_1": "ORCHARDS, 14 TOWNSEND",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "004073": {
        "oui_hex": "00-40-73",
        "organization": "BASS ASSOCIATES",
        "address_1": "435 TASSO STREET, STE. #325",
        "address_2": "PALO ALTO  CA  94301",
        "country": "US"
    },
    "00407D": {
        "oui_hex": "00-40-7D",
        "organization": "EXTENSION TECHNOLOGY CORP.",
        "address_1": "30 HOLLIS STREET",
        "address_2": "FRAMINGHAM  MA  01701",
        "country": "US"
    },
    "0080D7": {
        "oui_hex": "00-80-D7",
        "organization": "Fantum Engineering",
        "address_1": "",
        "address_2": "Rockwall  TX  75087",
        "country": "US"
    },
    "00807A": {
        "oui_hex": "00-80-7A",
        "organization": "AITECH SYSTEMS LTD.",
        "address_1": "3080 OLCOTT STREET",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0080DC": {
        "oui_hex": "00-80-DC",
        "organization": "PICKER INTERNATIONAL",
        "address_1": "595 MINER ROAD",
        "address_2": "CLEVELAND  OH  44143",
        "country": "US"
    },
    "00404D": {
        "oui_hex": "00-40-4D",
        "organization": "TELECOMMUNICATIONS TECHNIQUES",
        "address_1": "M/S",
        "address_2": "GERMANTOWN  MD  20876",
        "country": "US"
    },
    "00400D": {
        "oui_hex": "00-40-0D",
        "organization": "LANNET DATA COMMUNICATIONS,LTD",
        "address_1": "ATIDIM TECHNOLOG'L PARK, BG.#3",
        "address_2": "",
        "country": "IL"
    },
    "004019": {
        "oui_hex": "00-40-19",
        "organization": "AEON SYSTEMS, INC.",
        "address_1": "8401 WASHINGTON PLACE NE",
        "address_2": "ALBUQUERQUE  NM  87113",
        "country": "US"
    },
    "0040BE": {
        "oui_hex": "00-40-BE",
        "organization": "BOEING DEFENSE & SPACE",
        "address_1": "P.O. BOX 3999",
        "address_2": "SEATTLE  WA  98124-2499",
        "country": "US"
    },
    "00406E": {
        "oui_hex": "00-40-6E",
        "organization": "COROLLARY, INC.",
        "address_1": "2802 KELVIN",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "004076": {
        "oui_hex": "00-40-76",
        "organization": "Sun Conversion Technologies",
        "address_1": "100 Commerce Boulevard",
        "address_2": "Quakertown  PA  78951-2237",
        "country": "US"
    },
    "004022": {
        "oui_hex": "00-40-22",
        "organization": "KLEVER COMPUTERS, INC.",
        "address_1": "1028 W. MAUDE AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0040BF": {
        "oui_hex": "00-40-BF",
        "organization": "CHANNEL SYSTEMS INTERN'L INC.",
        "address_1": "93 SO. LA PATERA LANE",
        "address_2": "SANTA BARBARA  CA  93117",
        "country": "US"
    },
    "00401E": {
        "oui_hex": "00-40-1E",
        "organization": "ICC",
        "address_1": "8230 MONTGOMERY ROAD",
        "address_2": "CINCINNATI  OH  45236",
        "country": "US"
    },
    "00409A": {
        "oui_hex": "00-40-9A",
        "organization": "NETWORK EXPRESS, INC.",
        "address_1": "2200 GREEN ROAD - STE",
        "address_2": "ANN ARBOR  MI  48170",
        "country": "US"
    },
    "004094": {
        "oui_hex": "00-40-94",
        "organization": "SHOGRAPHICS, INC.",
        "address_1": "1890 N. SHORELINE BLVD.",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "004055": {
        "oui_hex": "00-40-55",
        "organization": "METRONIX GMBH",
        "address_1": "NEUE KNOCHENHAUERSTRAßE 5",
        "address_2": "  WEST",
        "country": "DE"
    },
    "004027": {
        "oui_hex": "00-40-27",
        "organization": "SMC MASSACHUSETTS, INC.",
        "address_1": "25 WALKERS BROOK DRIVE",
        "address_2": "READING  MA  01867",
        "country": "US"
    },
    "00408B": {
        "oui_hex": "00-40-8B",
        "organization": "RAYLAN CORPORATION",
        "address_1": "120 INDEPENDENCE DRIVE",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "0040EF": {
        "oui_hex": "00-40-EF",
        "organization": "HYPERCOM, INC.",
        "address_1": "2851 WEST KATHLEEN ROAD",
        "address_2": "PHOENIX  AZ  85023",
        "country": "US"
    },
    "004093": {
        "oui_hex": "00-40-93",
        "organization": "PAXDATA NETWORKS LTD.",
        "address_1": "COMMUNICATIONS HOUSE,",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "004085": {
        "oui_hex": "00-40-85",
        "organization": "SAAB INSTRUMENTS AB",
        "address_1": "P.O. BOX 1017",
        "address_2": "",
        "country": "SE"
    },
    "004023": {
        "oui_hex": "00-40-23",
        "organization": "LOGIC CORPORATION",
        "address_1": "3-14-10 MEIJI-SEIMEI BUILDING",
        "address_2": "",
        "country": "JP"
    },
    "0040A4": {
        "oui_hex": "00-40-A4",
        "organization": "ROSE ELECTRONICS",
        "address_1": "P.O. BOX 742571",
        "address_2": "HOUSTON  TX  77274-2571",
        "country": "US"
    },
    "004008": {
        "oui_hex": "00-40-08",
        "organization": "A PLUS INFO CORPORATION",
        "address_1": "5F, NO.2, LANE 235",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0040B5": {
        "oui_hex": "00-40-B5",
        "organization": "VIDEO TECHNOLOGY COMPUTERS LTD",
        "address_1": "33/F., BLOCK #1,",
        "address_2": "N.T.  HONG  KONG",
        "country": "HK"
    },
    "004012": {
        "oui_hex": "00-40-12",
        "organization": "WINDATA, INC.",
        "address_1": "10 BEARFOOT ROAD",
        "address_2": "NORTHBORO  MA  01532",
        "country": "US"
    },
    "0040D5": {
        "oui_hex": "00-40-D5",
        "organization": "Sartorius Mechatronics T&H GmbH",
        "address_1": "WEENDER LANDSTR: 94 - 108",
        "address_2": "",
        "country": "DE"
    },
    "004010": {
        "oui_hex": "00-40-10",
        "organization": "SONIC SYSTEMS, INC.",
        "address_1": "575 PASTORIA NORTH AVENUE",
        "address_2": "SUNNYVALE  CA  940867",
        "country": "US"
    },
    "0040CA": {
        "oui_hex": "00-40-CA",
        "organization": "FIRST INTERNAT'L COMPUTER, INC",
        "address_1": "FIC Building",
        "address_2": "Neihu  Taipei 114  Taipei 114",
        "country": "TW"
    },
    "0040C4": {
        "oui_hex": "00-40-C4",
        "organization": "KINKEI SYSTEM CORPORATION",
        "address_1": "1-22-17, KAMIKITA, HIRANOKU",
        "address_2": "",
        "country": "JP"
    },
    "00405D": {
        "oui_hex": "00-40-5D",
        "organization": "STAR-TEK, INC.",
        "address_1": "71 LYMAN STREET",
        "address_2": "NORTHBORO  MA  01532",
        "country": "US"
    },
    "0040E2": {
        "oui_hex": "00-40-E2",
        "organization": "MESA RIDGE TECHNOLOGIES, INC.",
        "address_1": "6725 MESA RIDGE ROAD-STE#100",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00408C": {
        "oui_hex": "00-40-8C",
        "organization": "AXIS COMMUNICATIONS AB",
        "address_1": "SCHEELEVAGEN 16",
        "address_2": "",
        "country": "SE"
    },
    "004045": {
        "oui_hex": "00-40-45",
        "organization": "TWINHEAD CORPORATION",
        "address_1": "1537 CENTRE POINTE DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "004028": {
        "oui_hex": "00-40-28",
        "organization": "NETCOMM LIMITED",
        "address_1": "3 OLYMPIC BUSINESS CENTRE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0040DD": {
        "oui_hex": "00-40-DD",
        "organization": "HONG TECHNOLOGIES",
        "address_1": "532 WEDDELL DRIVE",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "0040CB": {
        "oui_hex": "00-40-CB",
        "organization": "LANWAN TECHNOLOGIES",
        "address_1": "1566 LA PRADERA DRIVE",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "0040B2": {
        "oui_hex": "00-40-B2",
        "organization": "SYSTEMFORSCHUNG",
        "address_1": "KONIGSTRASSE 33A",
        "address_2": "",
        "country": "DE"
    },
    "0040E6": {
        "oui_hex": "00-40-E6",
        "organization": "C.A.E.N.",
        "address_1": "2, CHEMIN LATERAL",
        "address_2": "",
        "country": "FR"
    },
    "0040F0": {
        "oui_hex": "00-40-F0",
        "organization": "MicroBrain,Inc.",
        "address_1": "Yuzan Bldg. 4F,",
        "address_2": "Aichi-gun AICHI    480-1117",
        "country": "JP"
    },
    "004089": {
        "oui_hex": "00-40-89",
        "organization": "MEIDENSHA CORPORATION",
        "address_1": "FACTORY NO.4, 515 KAMINAKAMIZO",
        "address_2": "",
        "country": "JP"
    },
    "004015": {
        "oui_hex": "00-40-15",
        "organization": "ASCOM INFRASYS AG",
        "address_1": "DPT. EASO 3726",
        "address_2": "",
        "country": "CH"
    },
    "008095": {
        "oui_hex": "00-80-95",
        "organization": "BASIC MERTON HANDELSGES.M.B.H.",
        "address_1": "DURCHLASS-STRASSE 42",
        "address_2": "",
        "country": "AT"
    },
    "0080AE": {
        "oui_hex": "00-80-AE",
        "organization": "HUGHES NETWORK SYSTEMS",
        "address_1": "11717 EXPLORATION LANE",
        "address_2": "GERMANTOWN  MD  20876",
        "country": "US"
    },
    "00803A": {
        "oui_hex": "00-80-3A",
        "organization": "VARITYPER, INC.",
        "address_1": "900 MIDDLESEX TURNPIKE",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "00801C": {
        "oui_hex": "00-80-1C",
        "organization": "NEWPORT SYSTEMS SOLUTIONS",
        "address_1": "4019 WESTERLY AVENUE",
        "address_2": "NEWPORT BEACH  CA  92660",
        "country": "US"
    },
    "008056": {
        "oui_hex": "00-80-56",
        "organization": "SPHINX Electronics GmbH & Co KG",
        "address_1": "Tullastr. 3",
        "address_2": "",
        "country": "DE"
    },
    "008031": {
        "oui_hex": "00-80-31",
        "organization": "BASYS, CORP.",
        "address_1": "501 MACARA AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0080DB": {
        "oui_hex": "00-80-DB",
        "organization": "GRAPHON CORPORATION",
        "address_1": "1506 DELL AVE - #",
        "address_2": "CAMPBELL  CA  95008-6911",
        "country": "VE"
    },
    "008082": {
        "oui_hex": "00-80-82",
        "organization": "PEP MODULAR COMPUTERS GMBH",
        "address_1": "APFELSTRANGER STR. 16",
        "address_2": "  WEST",
        "country": "DE"
    },
    "008039": {
        "oui_hex": "00-80-39",
        "organization": "ALCATEL STC AUSTRALIA",
        "address_1": "252-280 BOTANY ROAD",
        "address_2": "",
        "country": "AU"
    },
    "008023": {
        "oui_hex": "00-80-23",
        "organization": "INTEGRATED BUSINESS NETWORKS",
        "address_1": "1BN THE SYSTEMS CENTRE",
        "address_2": "BUCKS HP19 3XN  -  ENGLAND",
        "country": "GB"
    },
    "00806B": {
        "oui_hex": "00-80-6B",
        "organization": "SCHMID TELECOMMUNICATION",
        "address_1": "BINZSTRASSE 35,",
        "address_2": "",
        "country": "CH"
    },
    "008059": {
        "oui_hex": "00-80-59",
        "organization": "STANLEY ELECTRIC CO., LTD",
        "address_1": "R&D LABORATORY",
        "address_2": "",
        "country": "JP"
    },
    "008041": {
        "oui_hex": "00-80-41",
        "organization": "VEB KOMBINAT ROBOTRON",
        "address_1": "GRUNAER STRAßE 2, DRESDEN 8010",
        "address_2": "GDR  EAST",
        "country": "DE"
    },
    "008080": {
        "oui_hex": "00-80-80",
        "organization": "DATAMEDIA CORPORATION",
        "address_1": "7401 CENTRAL HIGHWAY",
        "address_2": "PENNSAUKEN  NJ  08109",
        "country": "US"
    },
    "00803F": {
        "oui_hex": "00-80-3F",
        "organization": "TATUNG COMPANY",
        "address_1": "22 CHUNGSHANG N. RD. 3RD SEC.",
        "address_2": "TAIPEI  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0080E6": {
        "oui_hex": "00-80-E6",
        "organization": "PEER NETWORKS, INC.",
        "address_1": "3350 SCOTT BLVD. BLDG. 14",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0080E0": {
        "oui_hex": "00-80-E0",
        "organization": "XTP SYSTEMS, INC.",
        "address_1": "1900 STATE STREET , STE",
        "address_2": "SANTA BARBARA  CA  93101",
        "country": "US"
    },
    "008088": {
        "oui_hex": "00-80-88",
        "organization": "VICTOR COMPANY OF JAPAN, LTD.",
        "address_1": "58-7 SHINMEI-CHO, YOKOSUKA",
        "address_2": "",
        "country": "JP"
    },
    "0080D8": {
        "oui_hex": "00-80-D8",
        "organization": "NETWORK PERIPHERALS INC.",
        "address_1": "2890 ZONKER ROAD SUITE 209",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00809E": {
        "oui_hex": "00-80-9E",
        "organization": "DATUS GMBH",
        "address_1": "INDUSTRIESTR. 2",
        "address_2": "  WEST",
        "country": "DE"
    },
    "00802B": {
        "oui_hex": "00-80-2B",
        "organization": "INTEGRATED MARKETING CO",
        "address_1": "1360 BORDEAUX DRIVE",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "008001": {
        "oui_hex": "00-80-01",
        "organization": "PERIPHONICS CORPORATION",
        "address_1": "4000 VETERANS MEMORIAL HIGHWAY",
        "address_2": "BOHEMIA  NEW YORK  11716",
        "country": "US"
    },
    "008097": {
        "oui_hex": "00-80-97",
        "organization": "CENTRALP AUTOMATISMES",
        "address_1": "21, RUE MARCEL PAGNOL 69694",
        "address_2": "",
        "country": "FR"
    },
    "008071": {
        "oui_hex": "00-80-71",
        "organization": "SAI TECHNOLOGY",
        "address_1": "4224 CAMPUS POINT COURT",
        "address_2": "SAN DIEGO  CA  92121-1513",
        "country": "US"
    },
    "008098": {
        "oui_hex": "00-80-98",
        "organization": "TDK CORPORATION",
        "address_1": "CORP. R&D DEPT. TECH. HDQTERS.",
        "address_2": "CHIBA-KEN  272,",
        "country": "JP"
    },
    "0080CA": {
        "oui_hex": "00-80-CA",
        "organization": "NETCOM RESEARCH INCORPORATED",
        "address_1": "201 TECHNOLOGY DRIVE",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "0080D5": {
        "oui_hex": "00-80-D5",
        "organization": "CADRE TECHNOLOGIES",
        "address_1": "19545 NW VON NEUMANN DRIVE",
        "address_2": "BEAVERTON  OR  97006",
        "country": "VU"
    },
    "00801B": {
        "oui_hex": "00-80-1B",
        "organization": "KODIAK TECHNOLOGY",
        "address_1": "2340 HARRIS WAY",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0080D3": {
        "oui_hex": "00-80-D3",
        "organization": "SHIVA CORP.",
        "address_1": "205 BURLINGTON ROAD",
        "address_2": "BEDFORD  MA  01730",
        "country": "US"
    },
    "0080B3": {
        "oui_hex": "00-80-B3",
        "organization": "AVAL DATA CORPORATION",
        "address_1": "MACHIDA ENGINEERING CENTER",
        "address_2": "",
        "country": "JP"
    },
    "0080E7": {
        "oui_hex": "00-80-E7",
        "organization": "Leonardo Tactical Systems.",
        "address_1": "Silvertree, Coxbridge Business Park",
        "address_2": "Alton Road,   Farnham  GU10 5EH",
        "country": "GB"
    },
    "008020": {
        "oui_hex": "00-80-20",
        "organization": "NETWORK PRODUCTS",
        "address_1": "DIVISION OF ANDREW CORPORATION",
        "address_2": "TORRANCE  CA  90503",
        "country": "US"
    },
    "008070": {
        "oui_hex": "00-80-70",
        "organization": "COMPUTADORAS MICRON",
        "address_1": "GUERRERO 2001 - 19",
        "address_2": "",
        "country": "MX"
    },
    "008008": {
        "oui_hex": "00-80-08",
        "organization": "DYNATECH COMPUTER SYSTEMS",
        "address_1": "280 BERNARDO AVENUE",
        "address_2": "MOUNTAIN VIEW  CA  94039-7400",
        "country": "US"
    },
    "0000E4": {
        "oui_hex": "00-00-E4",
        "organization": "IN2 GROUPE INTERTECHNIQUE",
        "address_1": "IN2 - B.P.63",
        "address_2": "",
        "country": "FR"
    },
    "008013": {
        "oui_hex": "00-80-13",
        "organization": "THOMAS-CONRAD CORPORATION",
        "address_1": "1908-R KRAMER LANE",
        "address_2": "AUSTIN  TX  78758",
        "country": "US"
    },
    "00806E": {
        "oui_hex": "00-80-6E",
        "organization": "NIPPON STEEL CORPORATION",
        "address_1": "31-1 SHINKAWA 2-CHOUME",
        "address_2": "",
        "country": "JP"
    },
    "008010": {
        "oui_hex": "00-80-10",
        "organization": "COMMODORE INTERNATIONAL",
        "address_1": "1200 WILSON DRIVE",
        "address_2": "WEST CHESTER  PA  19380",
        "country": "US"
    },
    "008047": {
        "oui_hex": "00-80-47",
        "organization": "IN-NET CORP.",
        "address_1": "16720 WEST BERNARDO DRIVE",
        "address_2": "SAN DIEGO  CA  92127-1904",
        "country": "US"
    },
    "008067": {
        "oui_hex": "00-80-67",
        "organization": "SQUARE D COMPANY",
        "address_1": "4041 NORTH RICHARD STREET",
        "address_2": "MILWAUKEE  WI  53201",
        "country": "US"
    },
    "008045": {
        "oui_hex": "00-80-45",
        "organization": "MATSUSHITA ELECTRIC IND. CO",
        "address_1": "COMPUTER DIVISION",
        "address_2": "OSAKA  571",
        "country": "JP"
    },
    "0080BF": {
        "oui_hex": "00-80-BF",
        "organization": "TAKAOKA ELECTRIC MFG. CO. LTD.",
        "address_1": "KANDA BRANCH OFFICE TONEN",
        "address_2": "",
        "country": "JP"
    },
    "0080F9": {
        "oui_hex": "00-80-F9",
        "organization": "HEURIKON CORPORATION",
        "address_1": "8310 EXCELSIOR DRIVE",
        "address_2": "MADISON  WI  53717",
        "country": "US"
    },
    "0080A1": {
        "oui_hex": "00-80-A1",
        "organization": "MICROTEST, INC.",
        "address_1": "4747 N. 22ND STREET",
        "address_2": "PHOENIX  AZ  85016-4708",
        "country": "US"
    },
    "0080A9": {
        "oui_hex": "00-80-A9",
        "organization": "CLEARPOINT RESEARCH",
        "address_1": "190 NORTH MAIN STREET",
        "address_2": "  NATICK  MA",
        "country": "US"
    },
    "008017": {
        "oui_hex": "00-80-17",
        "organization": "PFU LIMITED",
        "address_1": "Nu 98-2 Unoke",
        "address_2": "Kahoku-shi, Ishikawa    929-1192",
        "country": "JP"
    },
    "0080F8": {
        "oui_hex": "00-80-F8",
        "organization": "MIZAR, INC.",
        "address_1": "1419 DUNN DRIVE",
        "address_2": "CARROLLTON  TX  75006",
        "country": "US"
    },
    "000014": {
        "oui_hex": "00-00-14",
        "organization": "NETRONIX",
        "address_1": "1372 MCDOWELL BLVD.",
        "address_2": "PETULAMA  CA  94952",
        "country": "US"
    },
    "000072": {
        "oui_hex": "00-00-72",
        "organization": "MINIWARE TECHNOLOGY",
        "address_1": "BEEMDENSTRAAT 38",
        "address_2": "  THE",
        "country": "NL"
    },
    "0000A1": {
        "oui_hex": "00-00-A1",
        "organization": "MARQUETTE ELECTRIC CO.",
        "address_1": "8200 WEST TOWER AVENUE",
        "address_2": "MILWAUKEE  WI  53223",
        "country": "US"
    },
    "0000F5": {
        "oui_hex": "00-00-F5",
        "organization": "DIAMOND SALES LIMITED",
        "address_1": "17, CHARTERHOUSE STREET",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00005C": {
        "oui_hex": "00-00-5C",
        "organization": "TELEMATICS INTERNATIONAL INC.",
        "address_1": "1201 CYPRESS CREEK RD",
        "address_2": "FT. LAUDERDALE  FL  33309",
        "country": "US"
    },
    "0000AC": {
        "oui_hex": "00-00-AC",
        "organization": "CONWARE COMPUTER CONSULTING",
        "address_1": "KILLISFELDSTRAßE 64",
        "address_2": "",
        "country": "DE"
    },
    "000094": {
        "oui_hex": "00-00-94",
        "organization": "ASANTE TECHNOLOGIES",
        "address_1": "821 FOX LANE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "000090": {
        "oui_hex": "00-00-90",
        "organization": "MICROCOM",
        "address_1": "500 RIVER RIDGE DRIVE",
        "address_2": "NORWOOD  MA  02062-5028",
        "country": "US"
    },
    "000047": {
        "oui_hex": "00-00-47",
        "organization": "NICOLET INSTRUMENTS CORP.",
        "address_1": "5225 VERONA ROAD",
        "address_2": "MADISON  WI  53711",
        "country": "US"
    },
    "000021": {
        "oui_hex": "00-00-21",
        "organization": "SUREMAN COMP. & COMMUN. CORP.",
        "address_1": "10F-5 NO. 7,  SEC. 3",
        "address_2": "TAIPEI  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "000030": {
        "oui_hex": "00-00-30",
        "organization": "VG LABORATORY SYSTEMS LTD",
        "address_1": "TRIBUNE AVENUE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "000035": {
        "oui_hex": "00-00-35",
        "organization": "SPECTRAGRAPHICS CORPORATION",
        "address_1": "    OR",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "000026": {
        "oui_hex": "00-00-26",
        "organization": "SHA-KEN CO., LTD.",
        "address_1": "MINAMI-OTSUKA",
        "address_2": "  TOKYO",
        "country": "JP"
    },
    "0000B6": {
        "oui_hex": "00-00-B6",
        "organization": "MICRO-MATIC RESEARCH",
        "address_1": "AMBACHTENLAAN  21 B5",
        "address_2": "",
        "country": "BE"
    },
    "000082": {
        "oui_hex": "00-00-82",
        "organization": "LECTRA SYSTEMES SA",
        "address_1": "CHEMIN DE MARTICOT",
        "address_2": "",
        "country": "FR"
    },
    "00002B": {
        "oui_hex": "00-00-2B",
        "organization": "CRISP AUTOMATION, INC",
        "address_1": "5160 BLAZER PARKWAY",
        "address_2": "DUBLIN  OH  43017",
        "country": "US"
    },
    "000051": {
        "oui_hex": "00-00-51",
        "organization": "HOB ELECTRONIC GMBH & CO. KG",
        "address_1": "BRANDSSTATTER-STR.2-10",
        "address_2": "",
        "country": "DE"
    },
    "0000A7": {
        "oui_hex": "00-00-A7",
        "organization": "NETWORK COMPUTING DEVICES INC.",
        "address_1": "350 NORTH BERNARDO",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "000098": {
        "oui_hex": "00-00-98",
        "organization": "CROSSCOMM CORPORATION",
        "address_1": "450 DONALD LYNCH BOULEVARD",
        "address_2": "MARLBOROUGH  MA  01752",
        "country": "US"
    },
    "0000C6": {
        "oui_hex": "00-00-C6",
        "organization": "EON SYSTEMS",
        "address_1": "10601 SOUTH DEANZA BLVD.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "000070": {
        "oui_hex": "00-00-70",
        "organization": "HCL LIMITED",
        "address_1": "RESEARCH & DEVELOPMENT UNIT",
        "address_2": "",
        "country": "IN"
    },
    "00008F": {
        "oui_hex": "00-00-8F",
        "organization": "Raytheon",
        "address_1": "M/S 1-1-1119",
        "address_2": "Marlboro  MA  01752",
        "country": "US"
    },
    "0000F1": {
        "oui_hex": "00-00-F1",
        "organization": "MAGNA COMPUTER CORPORATION",
        "address_1": "22 KEEWAYDIN DRIVE",
        "address_2": "SALEM  NH  03079",
        "country": "US"
    },
    "000054": {
        "oui_hex": "00-00-54",
        "organization": "Schneider Electric",
        "address_1": "35 rue Joseph Monier",
        "address_2": "",
        "country": "FR"
    },
    "000020": {
        "oui_hex": "00-00-20",
        "organization": "DATAINDUSTRIER DIAB AB",
        "address_1": "BOX 2029",
        "address_2": "",
        "country": "SE"
    },
    "00007A": {
        "oui_hex": "00-00-7A",
        "organization": "DANA COMPUTER INC.",
        "address_1": "550 DEL REY AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "000045": {
        "oui_hex": "00-00-45",
        "organization": "FORD AEROSPACE & COMM. CORP.",
        "address_1": "COLORADO SPRINGS OPERATION",
        "address_2": "COLORADO SPRINGS  CO  80908",
        "country": "US"
    },
    "00009C": {
        "oui_hex": "00-00-9C",
        "organization": "ROLM MIL-SPEC COMPUTERS",
        "address_1": "3151 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95148",
        "country": "US"
    },
    "00007C": {
        "oui_hex": "00-00-7C",
        "organization": "AMPERE INCORPORATED",
        "address_1": "SHINJUKU ASAHI BLDG.",
        "address_2": "  TOKYO",
        "country": "JP"
    },
    "000068": {
        "oui_hex": "00-00-68",
        "organization": "ROSEMOUNT CONTROLS",
        "address_1": "1300 E. LAMBERT ROAD",
        "address_2": "LA HABRA  CA  90632",
        "country": "US"
    },
    "0000E9": {
        "oui_hex": "00-00-E9",
        "organization": "ISICAD, INC.",
        "address_1": "1920 WEST CORPORATE WAY",
        "address_2": "ANAHEIM  CA  92803-6122",
        "country": "US"
    },
    "00009F": {
        "oui_hex": "00-00-9F",
        "organization": "AMERISTAR TECHNOLOGIES INC.",
        "address_1": "47 WHITTIER AVE.",
        "address_2": "MEDFORD  NY  11763",
        "country": "US"
    },
    "0000E3": {
        "oui_hex": "00-00-E3",
        "organization": "INTEGRATED MICRO PRODUCTS LTD",
        "address_1": "IMP, NO. 1 INDUSTRIAL ESTATE",
        "address_2": "ENGLAND  ENGLAND  DH86TJ",
        "country": "GB"
    },
    "0000AD": {
        "oui_hex": "00-00-AD",
        "organization": "BRUKER INSTRUMENTS INC.",
        "address_1": "MANNING PARK",
        "address_2": "BILLERICA  MA  01821",
        "country": "US"
    },
    "000074": {
        "oui_hex": "00-00-74",
        "organization": "RICOH COMPANY LTD.",
        "address_1": "2446 TODA, ATSUGI CITY",
        "address_2": "  243",
        "country": "JP"
    },
    "000046": {
        "oui_hex": "00-00-46",
        "organization": "OLIVETTI NORTH AMERICA",
        "address_1": "E 22425 APPLEWAY",
        "address_2": "LIBERTY LAKE  WA  99019",
        "country": "US"
    },
    "00008D": {
        "oui_hex": "00-00-8D",
        "organization": "Cryptek Inc.",
        "address_1": "1501 Moran Road",
        "address_2": "Sterling  VA  20166",
        "country": "US"
    },
    "00003B": {
        "oui_hex": "00-00-3B",
        "organization": "i Controls, Inc.",
        "address_1": "12F Doonsan building, 105-7",
        "address_2": "  KOREA  135-714",
        "country": "KR"
    },
    "0000B3": {
        "oui_hex": "00-00-B3",
        "organization": "CIMLINC INCORPORATED",
        "address_1": "1957 CROOKS ROAD",
        "address_2": "TROY  MI  48084",
        "country": "US"
    },
    "0000D3": {
        "oui_hex": "00-00-D3",
        "organization": "WANG LABORATORIES INC.",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0000D0": {
        "oui_hex": "00-00-D0",
        "organization": "DEVELCON ELECTRONICS LTD.",
        "address_1": "856-51ST STREET EAST",
        "address_2": "",
        "country": "CA"
    },
    "000093": {
        "oui_hex": "00-00-93",
        "organization": "PROTEON INC.",
        "address_1": "4 TECH CIRCLE",
        "address_2": "NATICK  MA  01760",
        "country": "US"
    },
    "00008B": {
        "oui_hex": "00-00-8B",
        "organization": "INFOTRON",
        "address_1": "9 NORTH OLNEY",
        "address_2": "CHERRY HILL  NJ  08003",
        "country": "US"
    },
    "080057": {
        "oui_hex": "08-00-57",
        "organization": "Evans & Sutherland",
        "address_1": "",
        "address_2": "Salt Lake City  UT",
        "country": "US"
    },
    "08005D": {
        "oui_hex": "08-00-5D",
        "organization": "GOULD INC.",
        "address_1": "6901 WEST SUNRISE BLVD.",
        "address_2": "FT. LAUDERDALE  FL  33310-9148",
        "country": "US"
    },
    "08005B": {
        "oui_hex": "08-00-5B",
        "organization": "VTA TECHNOLOGIES INC.",
        "address_1": "2040 SHERMAN STREET",
        "address_2": "HOLLYWOOD  FL  33020",
        "country": "US"
    },
    "080071": {
        "oui_hex": "08-00-71",
        "organization": "MATRA (DSIE)",
        "address_1": "PARC D'AFFAIRES - B.P. 262",
        "address_2": "",
        "country": "FR"
    },
    "08006C": {
        "oui_hex": "08-00-6C",
        "organization": "SUNTEK TECHNOLOGY INT'L",
        "address_1": "586 NO. FIRST STREET",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "080067": {
        "oui_hex": "08-00-67",
        "organization": "ComDesign",
        "address_1": "",
        "address_2": "Goleta  CA",
        "country": "US"
    },
    "08008C": {
        "oui_hex": "08-00-8C",
        "organization": "NETWORK RESEARCH CORPORATION",
        "address_1": "2380 N. ROSE AVENUE",
        "address_2": "OXNARD  CA  93010",
        "country": "US"
    },
    "080081": {
        "oui_hex": "08-00-81",
        "organization": "ASTECH INC.",
        "address_1": "670 NORTH COMMERCIAL STREET",
        "address_2": "MANCHESTER  NH  03101",
        "country": "US"
    },
    "08002D": {
        "oui_hex": "08-00-2D",
        "organization": "LAN-TEC INC.",
        "address_1": "2131 UNIVERSITY AVENUE",
        "address_2": "BERKELEY  CA  94704",
        "country": "US"
    },
    "00DD00": {
        "oui_hex": "00-DD-00",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0000AA": {
        "oui_hex": "00-00-AA",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "040AE0": {
        "oui_hex": "04-0A-E0",
        "organization": "XMIT AG COMPUTER NETWORKS",
        "address_1": "11 AVENUE DE BAUMETTES",
        "address_2": "",
        "country": "CH"
    },
    "080011": {
        "oui_hex": "08-00-11",
        "organization": "TEKTRONIX INC.",
        "address_1": "TECHNICAL STANDARDS",
        "address_2": "BEAVERTON  OR  97077",
        "country": "US"
    },
    "080026": {
        "oui_hex": "08-00-26",
        "organization": "NORSK DATA A.S.",
        "address_1": "P.O. BOX 25 BOGERUD",
        "address_2": "",
        "country": "NO"
    },
    "080025": {
        "oui_hex": "08-00-25",
        "organization": "CONTROL DATA",
        "address_1": "4201 LEXINGTON AVE NORTH",
        "address_2": "ARDEN HILLS  MN  55112",
        "country": "US"
    },
    "100000": {
        "oui_hex": "10-00-00",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0000D7": {
        "oui_hex": "00-00-D7",
        "organization": "DARTMOUTH COLLEGE",
        "address_1": "KIEWIT COMPUTER CENTER",
        "address_2": "HANOVER  NH  03755",
        "country": "US"
    },
    "AA0004": {
        "oui_hex": "AA-00-04",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "08000C": {
        "oui_hex": "08-00-0C",
        "organization": "MIKLYN DEVELOPMENT CO.",
        "address_1": "3613 ANDOVER DIVE",
        "address_2": "BEDFORD  TX  76021",
        "country": "US"
    },
    "00DD05": {
        "oui_hex": "00-DD-05",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "08001D": {
        "oui_hex": "08-00-1D",
        "organization": "ABLE COMMUNICATIONS INC.",
        "address_1": "17891 CARTWRIGHT ROAD",
        "address_2": "IRVINE  CA  92714-6216",
        "country": "US"
    },
    "00DD0B": {
        "oui_hex": "00-DD-0B",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "080003": {
        "oui_hex": "08-00-03",
        "organization": "ADVANCED COMPUTER COMM.",
        "address_1": "720 SANTA BARBARA ST.",
        "address_2": "SANTA BARBARA  CA  93101",
        "country": "US"
    },
    "00DD03": {
        "oui_hex": "00-DD-03",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00DD0F": {
        "oui_hex": "00-DD-0F",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "000001": {
        "oui_hex": "00-00-01",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "080017": {
        "oui_hex": "08-00-17",
        "organization": "NATIONAL SEMICONDUCTOR",
        "address_1": "2900 SEMICONDUCTOR DRIVE",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "542160": {
        "oui_hex": "54-21-60",
        "organization": "Alula",
        "address_1": "2340 Energy Park Drive",
        "address_2": "St. Paul  MN  55108",
        "country": "US"
    },
    "10B3C6": {
        "oui_hex": "10-B3-C6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "10B3D6": {
        "oui_hex": "10-B3-D6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "589630": {
        "oui_hex": "58-96-30",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "F854B8": {
        "oui_hex": "F8-54-B8",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "781735": {
        "oui_hex": "78-17-35",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai",
        "address_2": "Shanghai     201206",
        "country": "CN"
    },
    "3C894D": {
        "oui_hex": "3C-89-4D",
        "organization": "Dr. Ing. h.c. F. Porsche AG",
        "address_1": "Porscheplatz 1",
        "address_2": "Stuttgart    70435",
        "country": "DE"
    },
    "84C807": {
        "oui_hex": "84-C8-07",
        "organization": "ADVA Optical Networking Ltd.",
        "address_1": "ADVAntage House",
        "address_2": "York    YO30 4RY",
        "country": "GB"
    },
    "B43939": {
        "oui_hex": "B4-39-39",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "A0AB51": {
        "oui_hex": "A0-AB-51",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road, Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "64C901": {
        "oui_hex": "64-C9-01",
        "organization": "INVENTEC Corporation",
        "address_1": "No.66, Hougang St., Shilin Dist., Taipei City 111, Taiwan (R.O.C.)",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "749EF5": {
        "oui_hex": "74-9E-F5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "68BFC4": {
        "oui_hex": "68-BF-C4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A85E45": {
        "oui_hex": "A8-5E-45",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "04B1A1": {
        "oui_hex": "04-B1-A1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC464E": {
        "oui_hex": "CC-46-4E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F8893C": {
        "oui_hex": "F8-89-3C",
        "organization": "Inventec Appliances Corp.",
        "address_1": "37 Wugong 5th road, New Taipei Industrial Park,",
        "address_2": "New Taipei City  Wugu District  24890",
        "country": "TW"
    },
    "A0DF15": {
        "oui_hex": "A0-DF-15",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C4AD34": {
        "oui_hex": "C4-AD-34",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "306F07": {
        "oui_hex": "30-6F-07",
        "organization": "Nations Technologies Inc.",
        "address_1": "18F, Nations Tower, Nanshan District",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "2474F7": {
        "oui_hex": "24-74-F7",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "7CD566": {
        "oui_hex": "7C-D5-66",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "686350": {
        "oui_hex": "68-63-50",
        "organization": "Hella India Automotive Pvt Ltd",
        "address_1": "Unit no 201A to 201B  Nano Space Surveyno.5/1B/2 BanerBaner Pashan Link road",
        "address_2": "Pune  Maharastra  411045",
        "country": "IN"
    },
    "5CE50C": {
        "oui_hex": "5C-E5-0C",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "18703B": {
        "oui_hex": "18-70-3B",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "D89E61": {
        "oui_hex": "D8-9E-61",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "347E00": {
        "oui_hex": "34-7E-00",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "003092": {
        "oui_hex": "00-30-92",
        "organization": "Kontron Electronics AG",
        "address_1": "Riedstrasse 1",
        "address_2": "Rotkreuz    CH-6343",
        "country": "CH"
    },
    "80751F": {
        "oui_hex": "80-75-1F",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "E85A8B": {
        "oui_hex": "E8-5A-8B",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "442295": {
        "oui_hex": "44-22-95",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "5C710D": {
        "oui_hex": "5C-71-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00AB48": {
        "oui_hex": "00-AB-48",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "F855CD": {
        "oui_hex": "F8-55-CD",
        "organization": "Visteon Corporation",
        "address_1": "One Village Center Drive",
        "address_2": "Van Buren Twp  MI  48111",
        "country": "US"
    },
    "441847": {
        "oui_hex": "44-18-47",
        "organization": "HUNAN SCROWN ELECTRONIC INFORMATION TECH.CO.,LTD",
        "address_1": "Building No.4,Changsha Zhongdian Software Park No.39,Jianshan Road",
        "address_2": "Changsha  Hunan  410006",
        "country": "CN"
    },
    "1CC1BC": {
        "oui_hex": "1C-C1-BC",
        "organization": "Yichip Microelectronics (Hangzhou) Co.,Ltd",
        "address_1": "Room 401, Building 15, No.498 Guoshoujing Road, Pudong Software Park",
        "address_2": "Shanghai    200120",
        "country": "CN"
    },
    "AC61B9": {
        "oui_hex": "AC-61-B9",
        "organization": "WAMA Technology Limited",
        "address_1": "Room 2205, Westley Square, 48 Hoi Yuen Road, Kwun Tong, Kowloon",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "C4D8F3": {
        "oui_hex": "C4-D8-F3",
        "organization": "iZotope",
        "address_1": "60 Hampshire St",
        "address_2": "Cambridge  MA  02139",
        "country": "US"
    },
    "003056": {
        "oui_hex": "00-30-56",
        "organization": "HMS Industrial Networks",
        "address_1": "P O Box 4126",
        "address_2": "Halmstad  Halland  300 04",
        "country": "SE"
    },
    "680AE2": {
        "oui_hex": "68-0A-E2",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "AC8B9C": {
        "oui_hex": "AC-8B-9C",
        "organization": "Primera Technology, Inc.",
        "address_1": "2 Carlson Parkway N, Ste 375",
        "address_2": "Plymouth  MN  55447",
        "country": "US"
    },
    "2C3AFD": {
        "oui_hex": "2C-3A-FD",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "34495B": {
        "oui_hex": "34-49-5B",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "C8F319": {
        "oui_hex": "C8-F3-19",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "801609": {
        "oui_hex": "80-16-09",
        "organization": "Sleep Number",
        "address_1": "1001 Third Avenue South",
        "address_2": "Minneapolis  MN  55404",
        "country": "US"
    },
    "045EA4": {
        "oui_hex": "04-5E-A4",
        "organization": "SHENZHEN NETIS TECHNOLOGY CO.,LTD",
        "address_1": "Building 6, Baolong Plant, Able Technology Park, Longgang District",
        "address_2": "SHENZHEN    518116",
        "country": "CN"
    },
    "1CBFC0": {
        "oui_hex": "1C-BF-C0",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "78B46A": {
        "oui_hex": "78-B4-6A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "6CEBB6": {
        "oui_hex": "6C-EB-B6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4CF55B": {
        "oui_hex": "4C-F5-5B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E83F67": {
        "oui_hex": "E8-3F-67",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3446EC": {
        "oui_hex": "34-46-EC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "643139": {
        "oui_hex": "64-31-39",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A44BD5": {
        "oui_hex": "A4-4B-D5",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "64956C": {
        "oui_hex": "64-95-6C",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "14876A": {
        "oui_hex": "14-87-6A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0B55F": {
        "oui_hex": "E0-B5-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F8FFC2": {
        "oui_hex": "F8-FF-C2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0EB40": {
        "oui_hex": "E0-EB-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64694E": {
        "oui_hex": "64-69-4E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "94D6DB": {
        "oui_hex": "94-D6-DB",
        "organization": "NexFi",
        "address_1": "Room 417, Building 14, No. 498, Guoshoujing Road, Pudong New Area",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "B4ECF2": {
        "oui_hex": "B4-EC-F2",
        "organization": "Shanghai Listent Medical Tech Co., Ltd.",
        "address_1": "No. 668 Qingdai Road Pudong District",
        "address_2": "Shanghai  Shanghai  201318",
        "country": "CN"
    },
    "18E777": {
        "oui_hex": "18-E7-77",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "4077A9": {
        "oui_hex": "40-77-A9",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "F83331": {
        "oui_hex": "F8-33-31",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C4954D": {
        "oui_hex": "C4-95-4D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C49878": {
        "oui_hex": "C4-98-78",
        "organization": "SHANGHAI MOAAN INTELLIGENT TECHNOLOGY CO.,LTD",
        "address_1": "BLOCK B, 4TH FLOOR, BUILDING 2, NO. 401 CAOBAO ROAD, XUHUI DISTRICT, SHANGHAI",
        "address_2": "SHANGHAI    200030",
        "country": "CN"
    },
    "6C639C": {
        "oui_hex": "6C-63-9C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5C2AEF": {
        "oui_hex": "5C-2A-EF",
        "organization": "  r2p Asia-Pacific Pty Ltd",
        "address_1": "65 Epping Road",
        "address_2": "Sydney  NSW  2113",
        "country": "AU"
    },
    "A4BB6D": {
        "oui_hex": "A4-BB-6D",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "6C06D6": {
        "oui_hex": "6C-06-D6",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0C8E29": {
        "oui_hex": "0C-8E-29",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "A0224E": {
        "oui_hex": "A0-22-4E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "3027CF": {
        "oui_hex": "30-27-CF",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "3843E5": {
        "oui_hex": "38-43-E5",
        "organization": "Grotech Inc",
        "address_1": "19, Ojeongongeop-gil",
        "address_2": "Uiwang-si  Gyeonggi-do  16072",
        "country": "KR"
    },
    "CC593E": {
        "oui_hex": "CC-59-3E",
        "organization": "Sensium Healthcare Limited",
        "address_1": "115 MILTON PARK",
        "address_2": "ABINGDON  OXFORDSHIRE  OX14 4SA",
        "country": "GB"
    },
    "5C68D0": {
        "oui_hex": "5C-68-D0",
        "organization": "Aurora Innovation Inc.",
        "address_1": "1880 Embarcadero Rd.",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "10364A": {
        "oui_hex": "10-36-4A",
        "organization": "Boston Dynamics",
        "address_1": "78 4TH AVE",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "00B810": {
        "oui_hex": "00-B8-10",
        "organization": "Yichip Microelectronics (Hangzhou) Co.,Ltd",
        "address_1": "Room 401, Building 15, No.498 Guoshoujing Road, Pudong Software Park",
        "address_2": "Shanghai    200120",
        "country": "CN"
    },
    "A4B239": {
        "oui_hex": "A4-B2-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D8D5B9": {
        "oui_hex": "D8-D5-B9",
        "organization": "Rainforest Automation, Inc.",
        "address_1": "827 Cambie St.",
        "address_2": "Vancouver  British Columbia  V6B 2P4",
        "country": "CA"
    },
    "001BB0": {
        "oui_hex": "00-1B-B0",
        "organization": "Bharat Electronics Limited",
        "address_1": "JALAHALLI POST",
        "address_2": "BANGALORE  KARNATAKA  560013",
        "country": "IN"
    },
    "68AFFF": {
        "oui_hex": "68-AF-FF",
        "organization": "Shanghai Cambricon Information Technology Co., Ltd.",
        "address_1": "888 West Huanhu Road No.2, Nanhui New Town, Pudong New Area",
        "address_2": "Shanghai  Shanghai  200000",
        "country": "CN"
    },
    "DC21E2": {
        "oui_hex": "DC-21-E2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "FC1BD1": {
        "oui_hex": "FC-1B-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "582575": {
        "oui_hex": "58-25-75",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "28DEE5": {
        "oui_hex": "28-DE-E5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D01C3C": {
        "oui_hex": "D0-1C-3C",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "18C04D": {
        "oui_hex": "18-C0-4D",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "8CAAB5": {
        "oui_hex": "8C-AA-B5",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "402C76": {
        "oui_hex": "40-2C-76",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "44C7FC": {
        "oui_hex": "44-C7-FC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "7885F4": {
        "oui_hex": "78-85-F4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F44955": {
        "oui_hex": "F4-49-55",
        "organization": "MIMO TECH Co., Ltd.",
        "address_1": "21F.-6, No. 7, Sec. 3, New Taipei Blvd., Xinzhuang Dist.,",
        "address_2": "New Taipei City  Taiwan  24250",
        "country": "TW"
    },
    "0809C7": {
        "oui_hex": "08-09-C7",
        "organization": "Zhuhai Unitech Power Technology Co., Ltd.",
        "address_1": "102, Yinhua Road",
        "address_2": "Zhuhai  Guangdong  519000",
        "country": "CN"
    },
    "88541F": {
        "oui_hex": "88-54-1F",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "900CC8": {
        "oui_hex": "90-0C-C8",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "041DC7": {
        "oui_hex": "04-1D-C7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "68215F": {
        "oui_hex": "68-21-5F",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "3C28A6": {
        "oui_hex": "3C-28-A6",
        "organization": "Alcatel-Lucent Enterprise (China)",
        "address_1": "2/F, Building 1, No.60 Naxian Road,Pudong",
        "address_2": "Shanghai  Shanghai  201210",
        "country": "CN"
    },
    "5050A4": {
        "oui_hex": "50-50-A4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8086D9": {
        "oui_hex": "80-86-D9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F417B8": {
        "oui_hex": "F4-17-B8",
        "organization": "AirTies Wireless Networks",
        "address_1": "Esentepe Mah., Kore Şehitleri Cad.",
        "address_2": "Istanbul  Şişli  34360",
        "country": "TR"
    },
    "3CBF60": {
        "oui_hex": "3C-BF-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC15F4": {
        "oui_hex": "AC-15-F4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "386A77": {
        "oui_hex": "38-6A-77",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "141459": {
        "oui_hex": "14-14-59",
        "organization": "Vodafone Italia S.p.A.",
        "address_1": "Via Lorenteggio nr. 240",
        "address_2": "Milan  Italy  20147",
        "country": "IT"
    },
    "5043B9": {
        "oui_hex": "50-43-B9",
        "organization": "OktoInform RUS",
        "address_1": "Bolshoy Tishinskiy pereulok, d. 26, korp.13-14, ofis 4R",
        "address_2": "Moscow    123557",
        "country": "RU"
    },
    "5C27D4": {
        "oui_hex": "5C-27-D4",
        "organization": "Shenzhen Qihu Intelligent Technology Company Limited",
        "address_1": "Room 201, Block A, No.1, Qianwan Road 1,Qianhai Shenzhen HongKong Modern Service Industry Cooperation Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "88A479": {
        "oui_hex": "88-A4-79",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "047295": {
        "oui_hex": "04-72-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D446E1": {
        "oui_hex": "D4-46-E1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78D162": {
        "oui_hex": "78-D1-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "08F8BC": {
        "oui_hex": "08-F8-BC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90A25B": {
        "oui_hex": "90-A2-5B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18300C": {
        "oui_hex": "18-30-0C",
        "organization": "Hisense Electric Co.,Ltd",
        "address_1": "Qianwangang Roard 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "44A56E": {
        "oui_hex": "44-A5-6E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1C919D": {
        "oui_hex": "1C-91-9D",
        "organization": "Dongguan Liesheng Electronic Co., Ltd.",
        "address_1": "F5, Building B, North Block, Gaosheng Tech Park, No. 84 Zhongli Road, Nancheng District, Dongguan Ci",
        "address_2": "dongguan   guangdong  523000",
        "country": "CN"
    },
    "FCF29F": {
        "oui_hex": "FC-F2-9F",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "F81F32": {
        "oui_hex": "F8-1F-32",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "B00AD5": {
        "oui_hex": "B0-0A-D5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "20114E": {
        "oui_hex": "20-11-4E",
        "organization": "MeteRSit S.R.L.",
        "address_1": "Viale dell'Industria 31",
        "address_2": "Padova    35129",
        "country": "IT"
    },
    "2C5741": {
        "oui_hex": "2C-57-41",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A84D4A": {
        "oui_hex": "A8-4D-4A",
        "organization": "Audiowise Technology Inc.",
        "address_1": "2F, No 1-1, Innovation RD I, Hsinchu Science Park",
        "address_2": "Hsincu  Taiwan  30076",
        "country": "TW"
    },
    "7894E8": {
        "oui_hex": "78-94-E8",
        "organization": "Radio Bridge",
        "address_1": "8601 73rd Ave N, Suite 38",
        "address_2": "Brooklyn Park  MN  55428",
        "country": "US"
    },
    "484EFC": {
        "oui_hex": "48-4E-FC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "B0B353": {
        "oui_hex": "B0-B3-53",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "547FBC": {
        "oui_hex": "54-7F-BC",
        "organization": "iodyne",
        "address_1": "35 Miller Ave #175",
        "address_2": "Mill Valley  CA  94941",
        "country": "US"
    },
    "002674": {
        "oui_hex": "00-26-74",
        "organization": "Hunter Douglas",
        "address_1": "One Duette Way",
        "address_2": "Broomfield  CO  80020",
        "country": "US"
    },
    "FCE14F": {
        "oui_hex": "FC-E1-4F",
        "organization": "BRK Brands, Inc.",
        "address_1": "3901 Liberty Street",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "889655": {
        "oui_hex": "88-96-55",
        "organization": "Zitte corporation",
        "address_1": "4F Yokohama Kusunoki-cho Building,4-7 Kusunoki-cho,Nishi-ku",
        "address_2": "Yokohama  Kanagawa  2200003",
        "country": "JP"
    },
    "1C97C5": {
        "oui_hex": "1C-97-C5",
        "organization": "Ynomia Pty Ltd",
        "address_1": "153 Tooronga Rd",
        "address_2": "Glen Iris    3146",
        "country": "AU"
    },
    "5CC1D7": {
        "oui_hex": "5C-C1-D7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "380146": {
        "oui_hex": "38-01-46",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268? Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "98006A": {
        "oui_hex": "98-00-6A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "7CDFA1": {
        "oui_hex": "7C-DF-A1",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F4A4D6": {
        "oui_hex": "F4-A4-D6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "74B6B6": {
        "oui_hex": "74-B6-B6",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "842E14": {
        "oui_hex": "84-2E-14",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "4410FE": {
        "oui_hex": "44-10-FE",
        "organization": "Huizhou Foryou General Electronics Co., Ltd.",
        "address_1": "North Shangxia Road, Dongjiang Hi-tech Industry Park",
        "address_2": "Huizhou  Guangdong  516000",
        "country": "CN"
    },
    "EC316D": {
        "oui_hex": "EC-31-6D",
        "organization": "Hansgrohe",
        "address_1": "Auestraße 5-9",
        "address_2": "Schiltach    77761",
        "country": "DE"
    },
    "EC97B2": {
        "oui_hex": "EC-97-B2",
        "organization": "SUMEC Machinery & Electric Co.,Ltd.",
        "address_1": "198# ChangJiang Road, XuanWu District, 17F, SUMEC Building",
        "address_2": "Nanjing  JiangSu  210018",
        "country": "CN"
    },
    "28FA7A": {
        "oui_hex": "28-FA-7A",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "08F458": {
        "oui_hex": "08-F4-58",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "5CBA2C": {
        "oui_hex": "5C-BA-2C",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "343794": {
        "oui_hex": "34-37-94",
        "organization": "Hamee Corp.",
        "address_1": "Square O2 2-12-10 Sakae-cho",
        "address_2": "Odawara  Kanagawa  250-0011",
        "country": "JP"
    },
    "1005E1": {
        "oui_hex": "10-05-E1",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "6CD94C": {
        "oui_hex": "6C-D9-4C",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "AC1ED0": {
        "oui_hex": "AC-1E-D0",
        "organization": "Temic Automotive Philippines Inc.",
        "address_1": "Bagsakan Road, FTI estate",
        "address_2": "Taguig    1630",
        "country": "PH"
    },
    "7CAB60": {
        "oui_hex": "7C-AB-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "44C65D": {
        "oui_hex": "44-C6-5D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "187EB9": {
        "oui_hex": "18-7E-B9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4CA64D": {
        "oui_hex": "4C-A6-4D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "CC7F75": {
        "oui_hex": "CC-7F-75",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "20E874": {
        "oui_hex": "20-E8-74",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D03FAA": {
        "oui_hex": "D0-3F-AA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0CB937": {
        "oui_hex": "0C-B9-37",
        "organization": "Ubee Interactive Co., Limited",
        "address_1": "Flat/RM 1202, 12/F, AT Tower",
        "address_2": "North Point  Hong Kong  180",
        "country": "HK"
    },
    "DC35F1": {
        "oui_hex": "DC-35-F1",
        "organization": "Positivo Tecnologia S.A.",
        "address_1": "João Bettega, 5200",
        "address_2": "Curitiba  Paraná  81350-000",
        "country": "BR"
    },
    "D4DC09": {
        "oui_hex": "D4-DC-09",
        "organization": "Mist Systems, Inc.",
        "address_1": "1601 South De Anza Blvd, Suite 248",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E8E98E": {
        "oui_hex": "E8-E9-8E",
        "organization": "SOLAR controls s.r.o.",
        "address_1": "Brojova 25",
        "address_2": "Plzen    32600",
        "country": "CZ"
    },
    "0088BA": {
        "oui_hex": "00-88-BA",
        "organization": "NC&C",
        "address_1": "Gurogu",
        "address_2": "Seoul    08390",
        "country": "KR"
    },
    "402B69": {
        "oui_hex": "40-2B-69",
        "organization": "Kumho Electric Inc.",
        "address_1": "309, Bongmu-ro, Namsa-myeon, Cheoin-gu",
        "address_2": "Yongin-si  Gyeonggi-do  17118",
        "country": "KR"
    },
    "64F6BB": {
        "oui_hex": "64-F6-BB",
        "organization": "Fibocom Wireless Inc.",
        "address_1": "5/F,TowerA,Technology Building 2,1057 Nanhai Blvd, Nanshan",
        "address_2": "Shenzhen  518000  Guangdong",
        "country": "CN"
    },
    "F47335": {
        "oui_hex": "F4-73-35",
        "organization": "Logitech Far East",
        "address_1": "#2 Creation Rd. 4,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "90ADFC": {
        "oui_hex": "90-AD-FC",
        "organization": "Telechips, Inc.",
        "address_1": "19F~23F,Luther Bldg.42, Olympic-ro 35da-gil, Songpa-gu,",
        "address_2": "Seoul  Seoul  05510",
        "country": "KR"
    },
    "A4CFD2": {
        "oui_hex": "A4-CF-D2",
        "organization": "Ubee Interactive Co., Limited",
        "address_1": "Flat/RM 1202, 12/F, AT Tower, 180 Electric Road",
        "address_2": "North Point    00000",
        "country": "HK"
    },
    "A8A097": {
        "oui_hex": "A8-A0-97",
        "organization": "ScioTeq bvba",
        "address_1": "President Kennedypark 35A",
        "address_2": "Kortrijk    8500",
        "country": "BE"
    },
    "BC1695": {
        "oui_hex": "BC-16-95",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A40801": {
        "oui_hex": "A4-08-01",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "5CA62D": {
        "oui_hex": "5C-A6-2D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "345180": {
        "oui_hex": "34-51-80",
        "organization": "TCL King Electrical Appliances (Huizhou) Co., Ltd",
        "address_1": "10F, TCL Multimedia Building, TCL International E City, No.1001 Zhongshanyuan Rd., Nanshan District",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "B8E3B1": {
        "oui_hex": "B8-E3-B1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "980D51": {
        "oui_hex": "98-0D-51",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "00ADD5": {
        "oui_hex": "00-AD-D5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3CB53D": {
        "oui_hex": "3C-B5-3D",
        "organization": "HUNAN GOKE MICROELECTRONICS CO.,LTD",
        "address_1": "No.9, East 10th Road(South), Xingsha, Changsha",
        "address_2": "Changsha  HUNAN  410131",
        "country": "CN"
    },
    "2CEA7F": {
        "oui_hex": "2C-EA-7F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "086BD1": {
        "oui_hex": "08-6B-D1",
        "organization": "Shenzhen SuperElectron Technology Co.,Ltd.",
        "address_1": "1213-1214, haosheng business center, dongbin road, nanshan street, nanshan district, shenzhen city",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "AC3A67": {
        "oui_hex": "AC-3A-67",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "905D7C": {
        "oui_hex": "90-5D-7C",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "98FAA7": {
        "oui_hex": "98-FA-A7",
        "organization": "INNONET",
        "address_1": "C-417, Munjeong Hyundai Knowledge Industry Center, Beobwon-ro 11-gil-7",
        "address_2": "Songpa-gu  Seoul  05836",
        "country": "KR"
    },
    "487B5E": {
        "oui_hex": "48-7B-5E",
        "organization": "SMT TELECOMM HK",
        "address_1": "Unit C 8/F Charmhill Centre 50 Hillwood RD.",
        "address_2": "Tsim Sha Tsui  Kowloon  999077",
        "country": "HK"
    },
    "EC7949": {
        "oui_hex": "EC-79-49",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "00B7A8": {
        "oui_hex": "00-B7-A8",
        "organization": "Heinzinger electronic GmbH",
        "address_1": "Anton Jakob Str.4",
        "address_2": "Rosenheim  BY  83026",
        "country": "DE"
    },
    "30B216": {
        "oui_hex": "30-B2-16",
        "organization": "ABB Power Grids Germany AG – Grid Automation",
        "address_1": "Kallstadter Strasse 1",
        "address_2": "Mannheim    68309",
        "country": "DE"
    },
    "D4D2D6": {
        "oui_hex": "D4-D2-D6",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "105072": {
        "oui_hex": "10-50-72",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "285471": {
        "oui_hex": "28-54-71",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B88E82": {
        "oui_hex": "B8-8E-82",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "DC333D": {
        "oui_hex": "DC-33-3D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "900A84": {
        "oui_hex": "90-0A-84",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "AC4A67": {
        "oui_hex": "AC-4A-67",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "70CA97": {
        "oui_hex": "70-CA-97",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000991": {
        "oui_hex": "00-09-91",
        "organization": "Intelligent Platforms, LLC.",
        "address_1": "2500 Austin Drive",
        "address_2": "Charlottesville  VA  22911",
        "country": "US"
    },
    "D8787F": {
        "oui_hex": "D8-78-7F",
        "organization": "Ubee Interactive Co., Limited",
        "address_1": "Flat/RM 1202, 12/F, AT Tower, 180 Electric Road",
        "address_2": "North Point    00000",
        "country": "HK"
    },
    "BCF310": {
        "oui_hex": "BC-F3-10",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "C8665D": {
        "oui_hex": "C8-66-5D",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "E01C41": {
        "oui_hex": "E0-1C-41",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "D854A2": {
        "oui_hex": "D8-54-A2",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "D41D71": {
        "oui_hex": "D4-1D-71",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "08661F": {
        "oui_hex": "08-66-1F",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0887C6": {
        "oui_hex": "08-87-C6",
        "organization": "INGRAM MICRO SERVICES",
        "address_1": "100 CHEMIN DE BAILLOT",
        "address_2": "MONTAUBAN    82000",
        "country": "FR"
    },
    "785773": {
        "oui_hex": "78-57-73",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC6089": {
        "oui_hex": "AC-60-89",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "843E92": {
        "oui_hex": "84-3E-92",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "708CB6": {
        "oui_hex": "70-8C-B6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "50464A": {
        "oui_hex": "50-46-4A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C4A402": {
        "oui_hex": "C4-A4-02",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0015FF": {
        "oui_hex": "00-15-FF",
        "organization": "Novatel Wireless Solutions, Inc.",
        "address_1": "9710 Scranton Rd., Suite 200",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "2880A2": {
        "oui_hex": "28-80-A2",
        "organization": "Novatel Wireless Solutions, Inc.",
        "address_1": "9710 Scranton Rd., Suite 200",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "9CBD6E": {
        "oui_hex": "9C-BD-6E",
        "organization": "DERA Co., Ltd",
        "address_1": "Zhichun road NO7 Building B Room1203 Haidian District",
        "address_2": "Beijing    100191",
        "country": "CN"
    },
    "4C3329": {
        "oui_hex": "4C-33-29",
        "organization": "Sweroam",
        "address_1": "Stortorget 16",
        "address_2": "Orebro  N/A  70211",
        "country": "SE"
    },
    "488F5A": {
        "oui_hex": "48-8F-5A",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "100645": {
        "oui_hex": "10-06-45",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "68332C": {
        "oui_hex": "68-33-2C",
        "organization": "KENSTEL NETWORKS LIMITED",
        "address_1": "34D SECTOR 57 HSIIDC INDUSTRIAL AREA PHASE 4",
        "address_2": "KUNDLI  HARYANA  131028",
        "country": "IN"
    },
    "145E45": {
        "oui_hex": "14-5E-45",
        "organization": "Bamboo Systems Group",
        "address_1": "Sheraton House, Castle Park",
        "address_2": "Cambridge  CAMBRIDGESHIRE  CB3 0AX",
        "country": "GB"
    },
    "AC67B2": {
        "oui_hex": "AC-67-B2",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "70617B": {
        "oui_hex": "70-61-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "985949": {
        "oui_hex": "98-59-49",
        "organization": "LUXOTTICA GROUP S.P.A.",
        "address_1": "Piazzale Cadrona, 3",
        "address_2": "Milano  MI  20132",
        "country": "IT"
    },
    "C489ED": {
        "oui_hex": "C4-89-ED",
        "organization": "Solid Optics EU N.V.",
        "address_1": "De Huchtstraat 35",
        "address_2": "Almere  Flevoland  1327 EC",
        "country": "NL"
    },
    "58A87B": {
        "oui_hex": "58-A8-7B",
        "organization": "Fitbit, Inc.",
        "address_1": "199 Fremont Street, 14th Fl",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "64E172": {
        "oui_hex": "64-E1-72",
        "organization": "Shenzhen Qihoo Intelligent Technology Co.,Ltd",
        "address_1": "Room 201,Block A.No.1,Qianwan Road1 Qianhai Shenzhen-HONGKONG Cooperation Zone",
        "address_2": "Shenzhen  Guangdong  5181000",
        "country": "CN"
    },
    "002438": {
        "oui_hex": "00-24-38",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "748EF8": {
        "oui_hex": "74-8E-F8",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0027F8": {
        "oui_hex": "00-27-F8",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "50EB1A": {
        "oui_hex": "50-EB-1A",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "F84DFC": {
        "oui_hex": "F8-4D-FC",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "849A40": {
        "oui_hex": "84-9A-40",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "64E881": {
        "oui_hex": "64-E8-81",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "D81FCC": {
        "oui_hex": "D8-1F-CC",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "989D5D": {
        "oui_hex": "98-9D-5D",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "60F43A": {
        "oui_hex": "60-F4-3A",
        "organization": "Edifier International",
        "address_1": "Suit 2207, 22nd floor, Tower II, Lippo centre, 89 Queensway",
        "address_2": "Hong Kong    070",
        "country": "CN"
    },
    "0014C9": {
        "oui_hex": "00-14-C9",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "5C6BD7": {
        "oui_hex": "5C-6B-D7",
        "organization": "Foshan VIOMI Electric Appliance Technology Co. Ltd.",
        "address_1": "No.2 North Xinxi Fourth Road, Xiashi Village Committee,Lunjiao Sub-district Office, Shunde District",
        "address_2": "Foshan  Guandong  528308",
        "country": "CN"
    },
    "1848CA": {
        "oui_hex": "18-48-CA",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "8022A7": {
        "oui_hex": "80-22-A7",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "2-3 Kandatsukasamachi",
        "address_2": "Chiyodaku  Tokyo  101-8532",
        "country": "JP"
    },
    "5C2316": {
        "oui_hex": "5C-23-16",
        "organization": "Squirrels Research Labs LLC",
        "address_1": "8050 Freedom Ave NW Suite B",
        "address_2": "North Canton  OH  44720",
        "country": "US"
    },
    "042144": {
        "oui_hex": "04-21-44",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "9880EE": {
        "oui_hex": "98-80-EE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "90EEC7": {
        "oui_hex": "90-EE-C7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1029AB": {
        "oui_hex": "10-29-AB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "184ECB": {
        "oui_hex": "18-4E-CB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A027B6": {
        "oui_hex": "A0-27-B6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "103917": {
        "oui_hex": "10-39-17",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC0DF2": {
        "oui_hex": "CC-0D-F2",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "A84025": {
        "oui_hex": "A8-40-25",
        "organization": "Oxide Computer Company",
        "address_1": "1251 Park Avenue",
        "address_2": "Emeryville  CA  94608",
        "country": "US"
    },
    "94BF94": {
        "oui_hex": "94-BF-94",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "94434D": {
        "oui_hex": "94-43-4D",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "B8804F": {
        "oui_hex": "B8-80-4F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0012E3": {
        "oui_hex": "00-12-E3",
        "organization": "Agat Soft LLC",
        "address_1": "building 14, stroenie 15, room 7",
        "address_2": "Moscow  Serebryakova proezd  129343",
        "country": "RU"
    },
    "001351": {
        "oui_hex": "00-13-51",
        "organization": "Niles Audio Corporation",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "1065A3": {
        "oui_hex": "10-65-A3",
        "organization": "Panamax LLC",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad   CA  92010",
        "country": "US"
    },
    "FCA5D0": {
        "oui_hex": "FC-A5-D0",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "C85BA0": {
        "oui_hex": "C8-5B-A0",
        "organization": "Shenzhen Qihu Intelligent Technology Company Limited",
        "address_1": "Room 201, Block A, No.1, Qianwan Road 1,Qianhai Shenzhen HongKong Modern Service Industry Cooperation Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E0BE03": {
        "oui_hex": "E0-BE-03",
        "organization": "Lite-On Network Communication (Dongguan) Limited",
        "address_1": "30#Keji Rd,YinHu Industrial Area,Qingxi Town Dongguan City,Guang Dong China",
        "address_2": "Dongguan  Guang Dong  523648",
        "country": "CN"
    },
    "5C9012": {
        "oui_hex": "5C-90-12",
        "organization": "Owl Cyber Defense Solutions, LLC",
        "address_1": "38A Grove Street",
        "address_2": "Ridgefield  CT  06877",
        "country": "US"
    },
    "38F7CD": {
        "oui_hex": "38-F7-CD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "183CB7": {
        "oui_hex": "18-3C-B7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "98CBA4": {
        "oui_hex": "98-CB-A4",
        "organization": "Benchmark Electronics",
        "address_1": "Free Industrial Zone, Phase 1,",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "A48873": {
        "oui_hex": "A4-88-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "04CB88": {
        "oui_hex": "04-CB-88",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "241407": {
        "oui_hex": "24-14-07",
        "organization": "Xiamen Sigmastar Technology Ltd.",
        "address_1": "15th Floor ,Unit A,Chuangxin Building, Software Park, Xiamen Torch Hi-Tech Industrial Development Zone, Xiamen,China",
        "address_2": "Xiamen  Fujian  361005",
        "country": "CN"
    },
    "A06260": {
        "oui_hex": "A0-62-60",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "A4BDC4": {
        "oui_hex": "A4-BD-C4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5C9157": {
        "oui_hex": "5C-91-57",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "481693": {
        "oui_hex": "48-16-93",
        "organization": "Lear Corporation GmbH",
        "address_1": "Industriestrasse 48",
        "address_2": "Kronach  Bavaria  96317",
        "country": "DE"
    },
    "B47947": {
        "oui_hex": "B4-79-47",
        "organization": "Nutanix",
        "address_1": "1740 Technology Drive Ste #150",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "04F8F8": {
        "oui_hex": "04-F8-F8",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "5CFE9E": {
        "oui_hex": "5C-FE-9E",
        "organization": "Wiwynn Corporation Tainan Branch",
        "address_1": "4F, NO. 8, Beiyuan 3rd Rd., Anding Dist.,",
        "address_2": "Tainan    745",
        "country": "TW"
    },
    "881C95": {
        "oui_hex": "88-1C-95",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "F46942": {
        "oui_hex": "F4-69-42",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "08E9F6": {
        "oui_hex": "08-E9-F6",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "F02E51": {
        "oui_hex": "F0-2E-51",
        "organization": "Casa Systems",
        "address_1": "18-20 Orion Road Lane Cove West",
        "address_2": "LANE COVE  NSW  2066",
        "country": "AU"
    },
    "CCC261": {
        "oui_hex": "CC-C2-61",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "38F0C8": {
        "oui_hex": "38-F0-C8",
        "organization": "Mevo Inc.",
        "address_1": "19 Morris Avenue",
        "address_2": "Brooklyn  NY  11205",
        "country": "US"
    },
    "7C7635": {
        "oui_hex": "7C-76-35",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7470FD": {
        "oui_hex": "74-70-FD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7C2A31": {
        "oui_hex": "7C-2A-31",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B46BFC": {
        "oui_hex": "B4-6B-FC",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "144F8A": {
        "oui_hex": "14-4F-8A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C0B6F9": {
        "oui_hex": "C0-B6-F9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4456E2": {
        "oui_hex": "44-56-E2",
        "organization": "Sichuan Tianyi Comheart Telecom Co., Ltd.",
        "address_1": "No.198,First Section,Snow Mountain Avenue, Jinyuan Town, Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "CN"
    },
    "4CC95E": {
        "oui_hex": "4C-C9-5E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "68ECC5": {
        "oui_hex": "68-EC-C5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A8913D": {
        "oui_hex": "A8-91-3D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "640BD7": {
        "oui_hex": "64-0B-D7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C3B50": {
        "oui_hex": "0C-3B-50",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34CFF6": {
        "oui_hex": "34-CF-F6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "782B46": {
        "oui_hex": "78-2B-46",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "347DF6": {
        "oui_hex": "34-7D-F6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "CCD9AC": {
        "oui_hex": "CC-D9-AC",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "9C2976": {
        "oui_hex": "9C-29-76",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0C7A15": {
        "oui_hex": "0C-7A-15",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "548D5A": {
        "oui_hex": "54-8D-5A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B89A2A": {
        "oui_hex": "B8-9A-2A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "58961D": {
        "oui_hex": "58-96-1D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "74D83E": {
        "oui_hex": "74-D8-3E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "08D23E": {
        "oui_hex": "08-D2-3E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A87EEA": {
        "oui_hex": "A8-7E-EA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "40EC99": {
        "oui_hex": "40-EC-99",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "BC542F": {
        "oui_hex": "BC-54-2F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C87EA1": {
        "oui_hex": "C8-7E-A1",
        "organization": "TCL MOKA International Limited",
        "address_1": "7/F, Building 22E 22 Science Park East Avenue",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "642C0F": {
        "oui_hex": "64-2C-0F",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "D4A651": {
        "oui_hex": "D4-A6-51",
        "organization": "Tuya HK Limited",
        "address_1": "34/F.,ICBC Tower,3 Garden Road, Central, Hong Kong.",
        "address_2": "Hong Kong  Central Garden Road  510031",
        "country": "CN"
    },
    "A0510B": {
        "oui_hex": "A0-51-0B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DCFB48": {
        "oui_hex": "DC-FB-48",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "84FDD1": {
        "oui_hex": "84-FD-D1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4074E0": {
        "oui_hex": "40-74-E0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "087190": {
        "oui_hex": "08-71-90",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5CCD5B": {
        "oui_hex": "5C-CD-5B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "98AF65": {
        "oui_hex": "98-AF-65",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "40A6B7": {
        "oui_hex": "40-A6-B7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "48A472": {
        "oui_hex": "48-A4-72",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D8F2CA": {
        "oui_hex": "D8-F2-CA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "48F17F": {
        "oui_hex": "48-F1-7F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3066D0": {
        "oui_hex": "30-66-D0",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3CB233": {
        "oui_hex": "3C-B2-33",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "209E79": {
        "oui_hex": "20-9E-79",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "5CD5B5": {
        "oui_hex": "5C-D5-B5",
        "organization": "Shenzhen WiSiYiLink Technology Co.,Ltd",
        "address_1": "Building a 3, huafengzhigu Yuanshan hi tech Industrial Park, No.62, Yinhe Road, he'ao community, Yuanshan street, Longgang District",
        "address_2": "Shenzhen    518100",
        "country": "CN"
    },
    "AC5FEA": {
        "oui_hex": "AC-5F-EA",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "88948F": {
        "oui_hex": "88-94-8F",
        "organization": "Xi'an Zhisensor Technologies Co.,Ltd",
        "address_1": " No.52 Jinye 1st Road Xi'an,Shaanxi,China",
        "address_2": "Xi an  Xi an High-Tech Zone  710077",
        "country": "CN"
    },
    "044AC6": {
        "oui_hex": "04-4A-C6",
        "organization": "Aipon Electronics Co., Ltd",
        "address_1": "#78, Qiaojiao Dong road, Qiaolong, Tangxia Town",
        "address_2": "Dongguan City  Guangdong Province  523-710",
        "country": "CN"
    },
    "C0FFA8": {
        "oui_hex": "C0-FF-A8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C0517E": {
        "oui_hex": "C0-51-7E",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "FC1499": {
        "oui_hex": "FC-14-99",
        "organization": "Aimore Acoustics Incorporation",
        "address_1": "16F,Tianliao Building(New Material industrial Park), Xueyuan Avenue, Nanshan District",
        "address_2": "Shenzhen   Guangdong  518055",
        "country": "CN"
    },
    "189552": {
        "oui_hex": "18-95-52",
        "organization": "1MORE",
        "address_1": "TianliaoBuilding F14, New Materials Industrial Park, Xueyuan Blvd?Nanshan",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "98C7A4": {
        "oui_hex": "98-C7-A4",
        "organization": "Shenzhen HS Fiber Communication Equipment CO., LTD",
        "address_1": "6F, Bld#A, Dezhong Industrial Park, Yangmei Village, Bantian Town, Longgang District",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "0005C9": {
        "oui_hex": "00-05-C9",
        "organization": "LG Innotek",
        "address_1": "LG Component R&D Center",
        "address_2": "Ansan-si  Gyeonggi-do  426-791",
        "country": "KR"
    },
    "ACF108": {
        "oui_hex": "AC-F1-08",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "08ED9D": {
        "oui_hex": "08-ED-9D",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "00BED5": {
        "oui_hex": "00-BE-D5",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "E86DCB": {
        "oui_hex": "E8-6D-CB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "304950": {
        "oui_hex": "30-49-50",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0CDC7E": {
        "oui_hex": "0C-DC-7E",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "2098D8": {
        "oui_hex": "20-98-D8",
        "organization": "Shenzhen Yingdakang Technology CO., LTD",
        "address_1": "8004,Building 51,Block 2,Shangtang Songzi Park, MinZhi St., Longhua Dist",
        "address_2": "Shenzhen    518055",
        "country": "CN"
    },
    "6032B1": {
        "oui_hex": "60-32-B1",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "7CFD6B": {
        "oui_hex": "7C-FD-6B",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "7CC77E": {
        "oui_hex": "7C-C7-7E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "A0CFF5": {
        "oui_hex": "A0-CF-F5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1C012D": {
        "oui_hex": "1C-01-2D",
        "organization": "Ficer Technology",
        "address_1": "2F, No.138, Daye Rd., Beitou Dist.,",
        "address_2": "Taipei City    11268",
        "country": "TW"
    },
    "3CA62F": {
        "oui_hex": "3C-A6-2F",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "98B3EF": {
        "oui_hex": "98-B3-EF",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "50F958": {
        "oui_hex": "50-F9-58",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0002C4": {
        "oui_hex": "00-02-C4",
        "organization": "OPT Machine Vision Tech Co., Ltd",
        "address_1": "no. 8 JInSheng Road, JinXia Zone, Chang'An Town",
        "address_2": "Dongguan  Guangdong  523000",
        "country": "CN"
    },
    "E41F7B": {
        "oui_hex": "E4-1F-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C0A36E": {
        "oui_hex": "C0-A3-6E",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "8803E9": {
        "oui_hex": "88-03-E9",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "345840": {
        "oui_hex": "34-58-40",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5C647A": {
        "oui_hex": "5C-64-7A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC7F7B": {
        "oui_hex": "BC-7F-7B",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F0FAC7": {
        "oui_hex": "F0-FA-C7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "DCEF80": {
        "oui_hex": "DC-EF-80",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "182649": {
        "oui_hex": "18-26-49",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B46F2D": {
        "oui_hex": "B4-6F-2D",
        "organization": "Wahoo Fitness",
        "address_1": "90 W Wieuca Rd, Suite 110",
        "address_2": "Atlanta  GA  30342",
        "country": "US"
    },
    "5C857E": {
        "oui_hex": "5C-85-7E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "089E01": {
        "oui_hex": "08-9E-01",
        "organization": "Quanta Computer Inc.",
        "address_1": "No.211, Wen Hwa 2nd Rd",
        "address_2": "Taoyuan  Taiwan  33377",
        "country": "TW"
    },
    "A81E84": {
        "oui_hex": "A8-1E-84",
        "organization": "Quanta Computer Inc.",
        "address_1": "No.211, Wen Hwa 2nd Rd., Kuei Shan Hsiang",
        "address_2": "Tao Yuan    33377",
        "country": "TW"
    },
    "646C80": {
        "oui_hex": "64-6C-80",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C01850": {
        "oui_hex": "C0-18-50",
        "organization": "Quanta Computer Inc.",
        "address_1": "No. 211, Wen-Hwa 2nd Rd.,Kuei-Shan Dist.",
        "address_2": "Taoyuan City  Taiwan  33377",
        "country": "TW"
    },
    "30CC21": {
        "oui_hex": "30-CC-21",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4427F3": {
        "oui_hex": "44-27-F3",
        "organization": "70mai Co.,Ltd.",
        "address_1": "Room 2220, building 2, No. 588, Zixing road",
        "address_2": "Shanghai  MinHang District  201100",
        "country": "CN"
    },
    "047D7B": {
        "oui_hex": "04-7D-7B",
        "organization": "Quanta Computer Inc.",
        "address_1": "NO. 211, WEN HWA 2RD.,KUEI SHAN HSIANG, TAO YUAN SHIEN,",
        "address_2": "TAIPEI  TAIWAN  333",
        "country": "TW"
    },
    "0025DC": {
        "oui_hex": "00-25-DC",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "846B48": {
        "oui_hex": "84-6B-48",
        "organization": "ShenZhen EepuLink Co., Ltd.",
        "address_1": "4th Floor, Building 3, Nangang 1st industrial zone, Xili street, Nanshan district,",
        "address_2": "ShenZhen  Guangdong  518000",
        "country": "CN"
    },
    "B460ED": {
        "oui_hex": "B4-60-ED",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "8C941F": {
        "oui_hex": "8C-94-1F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "687DB4": {
        "oui_hex": "68-7D-B4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DC41A9": {
        "oui_hex": "DC-41-A9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "088F2C": {
        "oui_hex": "08-8F-2C",
        "organization": "Amber Technology Ltd.",
        "address_1": "Unit 1, 2 Daydream Street",
        "address_2": "Warriewood  New South Wales  2102",
        "country": "AU"
    },
    "C0B8E6": {
        "oui_hex": "C0-B8-E6",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "No. 2, 7th floor, xingwangruijie, haixi hi-tech industrial park, high-tech zone, fuzhou city",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "58E873": {
        "oui_hex": "58-E8-73",
        "organization": "HANGZHOU DANGBEI NETWORK TECH.Co.,Ltd",
        "address_1": "Build C,Wanfu Center,Binkang Road No.228,Binjiang Area",
        "address_2": "China    210051",
        "country": "CN"
    },
    "848094": {
        "oui_hex": "84-80-94",
        "organization": "Meter, Inc.",
        "address_1": "148 Townsend St",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "10B3D5": {
        "oui_hex": "10-B3-D5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "30A2C2": {
        "oui_hex": "30-A2-C2",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "DCDFD6": {
        "oui_hex": "DC-DF-D6",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "ACA88E": {
        "oui_hex": "AC-A8-8E",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "98415C": {
        "oui_hex": "98-41-5C",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "F04F7C": {
        "oui_hex": "F0-4F-7C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "705425": {
        "oui_hex": "70-54-25",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5C0BCA": {
        "oui_hex": "5C-0B-CA",
        "organization": "Tunstall Nordic AB",
        "address_1": "Agnesfridsvagen 113A",
        "address_2": "Malmo    21237",
        "country": "SE"
    },
    "283334": {
        "oui_hex": "28-33-34",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F0A225": {
        "oui_hex": "F0-A2-25",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "50A132": {
        "oui_hex": "50-A1-32",
        "organization": "Shenzhen MiaoMing  Intelligent Technology Co.,Ltd",
        "address_1": "Chudong science and technology park, 111 shaxin road, tangxia town,",
        "address_2": "dongguan city  guangdong province  523710",
        "country": "CN"
    },
    "807871": {
        "oui_hex": "80-78-71",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "4CB1CD": {
        "oui_hex": "4C-B1-CD",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F49C12": {
        "oui_hex": "F4-9C-12",
        "organization": "Structab AB",
        "address_1": "Slotsmöllan 14B",
        "address_2": "HALMSTAD    30231",
        "country": "SE"
    },
    "88517A": {
        "oui_hex": "88-51-7A",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "ACB3B5": {
        "oui_hex": "AC-B3-B5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "083A88": {
        "oui_hex": "08-3A-88",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Road, Sec.1,Tsao Tuen",
        "address_2": "Nan-Tou  Taiwan  54261",
        "country": "TW"
    },
    "08318B": {
        "oui_hex": "08-31-8B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4B688": {
        "oui_hex": "F4-B6-88",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "4C7A48": {
        "oui_hex": "4C-7A-48",
        "organization": "Nippon Seiki (Europe) B.V.",
        "address_1": "Antareslaan 27",
        "address_2": "Hoofddorp    2132",
        "country": "NL"
    },
    "84D15A": {
        "oui_hex": "84-D1-5A",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "047F0E": {
        "oui_hex": "04-7F-0E",
        "organization": "Barrot Technology Limited",
        "address_1": "C7-1-1,East Area, No.2,Shangdi Xinxi Road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "B8F653": {
        "oui_hex": "B8-F6-53",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "60AB14": {
        "oui_hex": "60-AB-14",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "BC62D2": {
        "oui_hex": "BC-62-D2",
        "organization": "Genexis International B.V.",
        "address_1": "Waldfeuchterbaan 124",
        "address_2": "Maria Hoop  Maria Hoop  6105 BP",
        "country": "NL"
    },
    "6C9E7C": {
        "oui_hex": "6C-9E-7C",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "44D5F2": {
        "oui_hex": "44-D5-F2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "000C86": {
        "oui_hex": "00-0C-86",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F83CBF": {
        "oui_hex": "F8-3C-BF",
        "organization": "BOTATO ELECTRONICS SDN BHD",
        "address_1": "c-1-2, JALAN BK5A/2B 47180,BANDAR KINRARA",
        "address_2": "PUCHONG  SELANGOR  47180",
        "country": "MY"
    },
    "FC589A": {
        "oui_hex": "FC-58-9A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F08620": {
        "oui_hex": "F0-86-20",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "DCCC8D": {
        "oui_hex": "DC-CC-8D",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "F05C77": {
        "oui_hex": "F0-5C-77",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "111111": {
        "oui_hex": "11-11-11",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "6CD71F": {
        "oui_hex": "6C-D7-1F",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "F06865": {
        "oui_hex": "F0-68-65",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "A463A1": {
        "oui_hex": "A4-63-A1",
        "organization": "Inventus Power Eletronica do Brasil LTDA",
        "address_1": "Av Buriti, 4285 Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075000",
        "country": "BR"
    },
    "3C9D56": {
        "oui_hex": "3C-9D-56",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "70FD45": {
        "oui_hex": "70-FD-45",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "446747": {
        "oui_hex": "44-67-47",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "884A70": {
        "oui_hex": "88-4A-70",
        "organization": "Wacom Co.,Ltd.",
        "address_1": "Sumitomo Fudosan Shinjuku Grand Tower 31F,8-17-1",
        "address_2": "Nishi-shinjuku,Shinjuku-ku  Tokyo  160-6131",
        "country": "JP"
    },
    "F4B5BB": {
        "oui_hex": "F4-B5-BB",
        "organization": "CERAGON NETWORKS",
        "address_1": "24 RAUEL WALLENBERG STREET",
        "address_2": "TEL-AVIV    96719",
        "country": "IL"
    },
    "507AC5": {
        "oui_hex": "50-7A-C5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C6BE8": {
        "oui_hex": "4C-6B-E8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C861E": {
        "oui_hex": "8C-86-1E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "542B8D": {
        "oui_hex": "54-2B-8D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001D29": {
        "oui_hex": "00-1D-29",
        "organization": "Doro AB",
        "address_1": "Magistratsvägen 10",
        "address_2": "Lund    226 43",
        "country": "SE"
    },
    "ECA5DE": {
        "oui_hex": "EC-A5-DE",
        "organization": "ONYX WIFI Inc",
        "address_1": "9891 Irvine Center Drive, Suite 200",
        "address_2": "Irvine    92618",
        "country": "US"
    },
    "8C4962": {
        "oui_hex": "8C-49-62",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "1033BF": {
        "oui_hex": "10-33-BF",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "347563": {
        "oui_hex": "34-75-63",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "142E5E": {
        "oui_hex": "14-2E-5E",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "0025CB": {
        "oui_hex": "00-25-CB",
        "organization": "Reiner SCT",
        "address_1": "Reiner Kartengeräte GmbH & Co. KG.",
        "address_2": "Furtwangen    78120",
        "country": "DE"
    },
    "44237C": {
        "oui_hex": "44-23-7C",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "C064E4": {
        "oui_hex": "C0-64-E4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "50804A": {
        "oui_hex": "50-80-4A",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "7th Floor, Hongye Building, No.1801 Hongmei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "309435": {
        "oui_hex": "30-94-35",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "D44BB6": {
        "oui_hex": "D4-4B-B6",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "38184C": {
        "oui_hex": "38-18-4C",
        "organization": "Sony Home Entertainment&Sound Products Inc",
        "address_1": "Sony City Osaki 2-10-1 Osaki Shinagawa-ku",
        "address_2": "Tokyo  Japan  141-8610",
        "country": "JP"
    },
    "D82FE6": {
        "oui_hex": "D8-2F-E6",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "140F42": {
        "oui_hex": "14-0F-42",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "006D61": {
        "oui_hex": "00-6D-61",
        "organization": "Guangzhou V-SOLUTION Electronic Technology Co., Ltd.",
        "address_1": "Room 601,Originality Building B2, NO.162 Science Avenue,Science Town",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "C4AC59": {
        "oui_hex": "C4-AC-59",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "5816D7": {
        "oui_hex": "58-16-D7",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "nishida  6-1",
        "address_2": "Kakuda-City  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "FCA47A": {
        "oui_hex": "FC-A4-7A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E419C1": {
        "oui_hex": "E4-19-C1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B86685": {
        "oui_hex": "B8-66-85",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "381A52": {
        "oui_hex": "38-1A-52",
        "organization": "Seiko Epson Corporation",
        "address_1": "2070 Kotobuki Koaka",
        "address_2": "Matsumoto-shi  Nagano-ken  399-8702",
        "country": "JP"
    },
    "000A17": {
        "oui_hex": "00-0A-17",
        "organization": "NESTAR COMMUNICATIONS, INC",
        "address_1": "No.6,19 Lane Bade Road",
        "address_2": "HSINCHU    300",
        "country": "TW"
    },
    "D8AF81": {
        "oui_hex": "D8-AF-81",
        "organization": "   ZAO NPK Rotek",
        "address_1": "Filippovskiy per., 8/1",
        "address_2": "Moscow    119019",
        "country": "RU"
    },
    "E4FDA1": {
        "oui_hex": "E4-FD-A1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B452A9": {
        "oui_hex": "B4-52-A9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "54EF44": {
        "oui_hex": "54-EF-44",
        "organization": "Lumi United Technology Co., Ltd",
        "address_1": "8th Floor, JinQi Wisdom Valley, No.1 TangLing Road, LinXian Ave, Taoyuan Residential District,Nanshan District",
        "address_2": "ShenZhen  GuangDong  518055",
        "country": "CN"
    },
    "402B50": {
        "oui_hex": "40-2B-50",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "78CC2B": {
        "oui_hex": "78-CC-2B",
        "organization": "SINEWY TECHNOLOGY CO., LTD",
        "address_1": "2F., No.179, Dongmin Rd.",
        "address_2": "Toufen City, Miaoli County    351",
        "country": "TW"
    },
    "B80756": {
        "oui_hex": "B8-07-56",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "D0C857": {
        "oui_hex": "D0-C8-57",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "FCBCD1": {
        "oui_hex": "FC-BC-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "7460FA": {
        "oui_hex": "74-60-FA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "CC3ADF": {
        "oui_hex": "CC-3A-DF",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "38EFE3": {
        "oui_hex": "38-EF-E3",
        "organization": " INGENICO TERMINALS SAS",
        "address_1": "28-32 BOULEVARD DE GRENELLE",
        "address_2": "PARIS    75015",
        "country": "FR"
    },
    "50D4F7": {
        "oui_hex": "50-D4-F7",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001F47": {
        "oui_hex": "00-1F-47",
        "organization": "MCS Logic Inc.",
        "address_1": "6F. Samho Center B Bldg., 275-6",
        "address_2": "Seoul    137-941",
        "country": "KR"
    },
    "8CFD18": {
        "oui_hex": "8C-FD-18",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "B45459": {
        "oui_hex": "B4-54-59",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "000970": {
        "oui_hex": "00-09-70",
        "organization": "Vibration Research Corporation",
        "address_1": "2385 Wilshere Drive",
        "address_2": "Jenison  MI  49428",
        "country": "US"
    },
    "14A2A0": {
        "oui_hex": "14-A2-A0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E4AB89": {
        "oui_hex": "E4-AB-89",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "78C313": {
        "oui_hex": "78-C3-13",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "7434AE": {
        "oui_hex": "74-34-AE",
        "organization": "this is engineering Inc.",
        "address_1": "352, 815 Daewangpangyo-ro, Sujeong-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13449",
        "country": "KR"
    },
    "74ADB7": {
        "oui_hex": "74-AD-B7",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "6095CE": {
        "oui_hex": "60-95-CE",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8CE5C0": {
        "oui_hex": "8C-E5-C0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F08A76": {
        "oui_hex": "F0-8A-76",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "ECAA25": {
        "oui_hex": "EC-AA-25",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "687D6B": {
        "oui_hex": "68-7D-6B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "485169": {
        "oui_hex": "48-51-69",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C40683": {
        "oui_hex": "C4-06-83",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "94D00D": {
        "oui_hex": "94-D0-0D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "C48A5A": {
        "oui_hex": "C4-8A-5A",
        "organization": "JFCONTROL",
        "address_1": "1449-37 Seoburo",
        "address_2": "Suwon  Gyunggi-do  16643",
        "country": "KR"
    },
    "B49A95": {
        "oui_hex": "B4-9A-95",
        "organization": "Shenzhen Boomtech Industrial Corporation",
        "address_1": "2F, Block E, Bao'an Intelligent Valley, Yingtian Road No.4 Xixiang Sub-District Office, Bao'an District",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "AC83E9": {
        "oui_hex": "AC-83-E9",
        "organization": "Beijing Zile Technology Co., Ltd",
        "address_1": "Tecent WeWork, Huilongguan East Avenue, Changping District",
        "address_2": "Beijing  Beijing  100096",
        "country": "CN"
    },
    "D8CA06": {
        "oui_hex": "D8-CA-06",
        "organization": "Titan DataCenters France",
        "address_1": "E.SpacePark 45 Allee des ormes",
        "address_2": "mougins    06250",
        "country": "FR"
    },
    "1C20DB": {
        "oui_hex": "1C-20-DB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D0C65B": {
        "oui_hex": "D0-C6-5B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9078B2": {
        "oui_hex": "90-78-B2",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "B4CFE0": {
        "oui_hex": "B4-CF-E0",
        "organization": "Sichuan tianyi kanghe communications co., LTD",
        "address_1": "No.198, section 1, xueshan avenue, jinyuan town, dayi county",
        "address_2": "chengdu  sichuan  611330",
        "country": "CN"
    },
    "BC7FA4": {
        "oui_hex": "BC-7F-A4",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "FC492D": {
        "oui_hex": "FC-49-2D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "74EE2A": {
        "oui_hex": "74-EE-2A",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "087E64": {
        "oui_hex": "08-7E-64",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "080039": {
        "oui_hex": "08-00-39",
        "organization": "SPIDER SYSTEMS LIMITED",
        "address_1": "SPIDER PARK",
        "address_2": "    SCOTLAND",
        "country": "GB"
    },
    "90473C": {
        "oui_hex": "90-47-3C",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "889E33": {
        "oui_hex": "88-9E-33",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "6C8AEC": {
        "oui_hex": "6C-8A-EC",
        "organization": "Nantong Coship Electronics Co., Ltd.",
        "address_1": "No.188 Xinsheng Road",
        "address_2": "Nantong  Jiangsu  226001",
        "country": "CN"
    },
    "84C2E4": {
        "oui_hex": "84-C2-E4",
        "organization": "Jiangsu Qinheng Co., Ltd.",
        "address_1": "No. 18, Ningshuang Road",
        "address_2": "Nanjing  Jiangsu  210012",
        "country": "CN"
    },
    "7C21D8": {
        "oui_hex": "7C-21-D8",
        "organization": "Shenzhen Think Will Communication Technology co., LTD.",
        "address_1": "16F,Block A,Central Plaza,No.2002,Baoyuan Rd.,Baoan District",
        "address_2": "Shenzhen    518101",
        "country": "CN"
    },
    "FCEA50": {
        "oui_hex": "FC-EA-50",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "00E06B": {
        "oui_hex": "00-E0-6B",
        "organization": "W&G SPECIAL PRODUCTS",
        "address_1": "SCEINCE PARK EINDHOVIN 5049",
        "address_2": "",
        "country": "NL"
    },
    "045C6C": {
        "oui_hex": "04-5C-6C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D8F15B": {
        "oui_hex": "D8-F1-5B",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "D4F057": {
        "oui_hex": "D4-F0-57",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "6CF17E": {
        "oui_hex": "6C-F1-7E",
        "organization": "Zhejiang Uniview Technologies Co.,Ltd.",
        "address_1": "No.88,Jiangling Road",
        "address_2": "Hangzhou  Zhejiang,P.R.China  310051",
        "country": "CN"
    },
    "083A2F": {
        "oui_hex": "08-3A-2F",
        "organization": "Guangzhou Juan Intelligent Tech Joint Stock Co.,Ltd",
        "address_1": "NO.9, street 3, HengLing industrial zone, Tangdong, tianhe district",
        "address_2": "Guangzhou  Guangdong  CN 510000",
        "country": "CN"
    },
    "1C3A60": {
        "oui_hex": "1C-3A-60",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D4351D": {
        "oui_hex": "D4-35-1D",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "6009C3": {
        "oui_hex": "60-09-C3",
        "organization": "u-blox AG",
        "address_1": "Zuercherstrasse 68",
        "address_2": "Thalwil    8800",
        "country": "CH"
    },
    "488764": {
        "oui_hex": "48-87-64",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "5C1CB9": {
        "oui_hex": "5C-1C-B9",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "C0FD84": {
        "oui_hex": "C0-FD-84",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "444B7E": {
        "oui_hex": "44-4B-7E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "DC8C37": {
        "oui_hex": "DC-8C-37",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E8D0FC": {
        "oui_hex": "E8-D0-FC",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "E8E8B7": {
        "oui_hex": "E8-E8-B7",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto   617-8555",
        "country": "JP"
    },
    "103D3E": {
        "oui_hex": "10-3D-3E",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "7C50DA": {
        "oui_hex": "7C-50-DA",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "64CC22": {
        "oui_hex": "64-CC-22",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "4C9157": {
        "oui_hex": "4C-91-57",
        "organization": "Fujian LANDI Commercial Equipment Co.,Ltd",
        "address_1": "Building 17,the 1st Section ,Fuzhou Software Park",
        "address_2": "No.89 Software Road   Fuzhou ,Fujian  350003",
        "country": "CN"
    },
    "9C25BE": {
        "oui_hex": "9C-25-BE",
        "organization": "Wildlife Acoustics, Inc.",
        "address_1": "3 Mill and Main Place, Suite 210",
        "address_2": "MAYNARD  MA  01754",
        "country": "US"
    },
    "D039EA": {
        "oui_hex": "D0-39-EA",
        "organization": "NetApp",
        "address_1": "1395 Crossman Ave",
        "address_2": "Sunnyvale,  CA  94089",
        "country": "US"
    },
    "F8DFE1": {
        "oui_hex": "F8-DF-E1",
        "organization": "MyLight Systems",
        "address_1": "290 rue Ferdinand Perrier",
        "address_2": "Saint Priest    69800",
        "country": "FR"
    },
    "60D2DD": {
        "oui_hex": "60-D2-DD",
        "organization": "Shenzhen Baitong Putian Technology Co.,Ltd.",
        "address_1": "501,5/F,Building 1,No.2,Lianwei Street,Hualian Community,Longhua Street Longhua District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "788C77": {
        "oui_hex": "78-8C-77",
        "organization": "LEXMARK INTERNATIONAL, INC.",
        "address_1": "740 NEW CIRCLE ROAD",
        "address_2": "LEXINGTON  KY  40550",
        "country": "US"
    },
    "3C0C7D": {
        "oui_hex": "3C-0C-7D",
        "organization": "Tiny Mesh AS",
        "address_1": "Elisabeth von Hübschs gate 6",
        "address_2": "MOSS    1534",
        "country": "NO"
    },
    "3476C5": {
        "oui_hex": "34-76-C5",
        "organization": "I-O DATA DEVICE,INC.",
        "address_1": "3-10, SAKURADA-MACHI",
        "address_2": "KANAZAWA  ISHIKAWA  920-8512",
        "country": "JP"
    },
    "24DA33": {
        "oui_hex": "24-DA-33",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "FCAB90": {
        "oui_hex": "FC-AB-90",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5893D8": {
        "oui_hex": "58-93-D8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "5051A9": {
        "oui_hex": "50-51-A9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A4975C": {
        "oui_hex": "A4-97-5C",
        "organization": "VTech Telecommunications Ltd.",
        "address_1": "23/F,Tai Ping Industrial Centre ,Block 1",
        "address_2": "Hong Kong    000000",
        "country": "CN"
    },
    "B02A1F": {
        "oui_hex": "B0-2A-1F",
        "organization": " Wingtech Group (HongKong）Limited",
        "address_1": " FLAT/RM 1903 19/F PODIUM PLAZA 5HANOI ROAD TSIM SHA TSUI",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "DC680C": {
        "oui_hex": "DC-68-0C",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F40270": {
        "oui_hex": "F4-02-70",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "1C2704": {
        "oui_hex": "1C-27-04",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5078B3": {
        "oui_hex": "50-78-B3",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F0D4F7": {
        "oui_hex": "F0-D4-F7",
        "organization": "varram system",
        "address_1": "57, TECHNO 11-RO,YUSEONG-GU, DAEJEON, KOREA",
        "address_2": "DAEJEON    34036",
        "country": "KR"
    },
    "E0CC7A": {
        "oui_hex": "E0-CC-7A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "6C23CB": {
        "oui_hex": "6C-23-CB",
        "organization": "Wattty Corporation",
        "address_1": "2-15-31 takaokanishi nakaku",
        "address_2": "hamamatsushi  shizuokaken  4338118",
        "country": "JP"
    },
    "60AB67": {
        "oui_hex": "60-AB-67",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "AC710C": {
        "oui_hex": "AC-71-0C",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "A8DB03": {
        "oui_hex": "A8-DB-03",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "308944": {
        "oui_hex": "30-89-44",
        "organization": "DEVA Broadcast Ltd.",
        "address_1": "Alexander Stamboliyski 65",
        "address_2": "Burgas  Burgas  8000",
        "country": "BG"
    },
    "F47960": {
        "oui_hex": "F4-79-60",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "145290": {
        "oui_hex": "14-52-90",
        "organization": "KNS Group LLC (YADRO Company)",
        "address_1": "Spartakovskaya sq., 14, bl. 1",
        "address_2": "Moscow    105082",
        "country": "RU"
    },
    "5C32C5": {
        "oui_hex": "5C-32-C5",
        "organization": "Teracom Ltd.",
        "address_1": "11 Vasil Levski blvd.",
        "address_2": "Ruse    7019",
        "country": "BG"
    },
    "ACEE70": {
        "oui_hex": "AC-EE-70",
        "organization": "Fontem Ventures BV",
        "address_1": "Motion Building 8F, Radarweg 60",
        "address_2": "Amsterdam  Noord-Holland  1043NT",
        "country": "NL"
    },
    "ACE2D3": {
        "oui_hex": "AC-E2-D3",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00FD22": {
        "oui_hex": "00-FD-22",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4418FD": {
        "oui_hex": "44-18-FD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00B600": {
        "oui_hex": "00-B6-00",
        "organization": "VOIM Co., Ltd.",
        "address_1": "70, Seotan-ro, Jinwi-myeon",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  17706",
        "country": "KR"
    },
    "98FA9B": {
        "oui_hex": "98-FA-9B",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "005B94": {
        "oui_hex": "00-5B-94",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0897E": {
        "oui_hex": "E0-89-7E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B00CD1": {
        "oui_hex": "B0-0C-D1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "4846C1": {
        "oui_hex": "48-46-C1",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "B4D0A9": {
        "oui_hex": "B4-D0-A9",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "FC29F3": {
        "oui_hex": "FC-29-F3",
        "organization": "McPay Co.,LTD.",
        "address_1": "No.801, 61, Digital-ro 31-gil, Guro-gu",
        "address_2": "Seoul    08375",
        "country": "KR"
    },
    "F8AFDB": {
        "oui_hex": "F8-AF-DB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "A0BD1D": {
        "oui_hex": "A0-BD-1D",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "E49F1E": {
        "oui_hex": "E4-9F-1E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002615": {
        "oui_hex": "00-26-15",
        "organization": "Teracom Limited",
        "address_1": "B-84",
        "address_2": "Noida  Uttar Pradesh  201301",
        "country": "IN"
    },
    "9C8EDC": {
        "oui_hex": "9C-8E-DC",
        "organization": "Teracom Limited",
        "address_1": "123456",
        "address_2": "Noida  Uttar Pradesh  201301",
        "country": "IN"
    },
    "000191": {
        "oui_hex": "00-01-91",
        "organization": "SYRED Data Systems",
        "address_1": "272 Lanes Mill Road",
        "address_2": "Howell  NJ  07731",
        "country": "US"
    },
    "ACD564": {
        "oui_hex": "AC-D5-64",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "94D075": {
        "oui_hex": "94-D0-75",
        "organization": "CIS Crypto",
        "address_1": "Nauchnyy proezd 6",
        "address_2": "Moscow    117246",
        "country": "RU"
    },
    "28B4FB": {
        "oui_hex": "28-B4-FB",
        "organization": "Sprocomm Technologies CO.,LTD.",
        "address_1": "5D F1.6 Block,Tianfa Building,Tianan Chegongmiao Industrial park,Futian Dist",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "40F9D5": {
        "oui_hex": "40-F9-D5",
        "organization": "Tecore Networks",
        "address_1": "7030 Hi Tech Drive",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "CC2C83": {
        "oui_hex": "CC-2C-83",
        "organization": "DarkMatter L.L.C",
        "address_1": "Level 15, Aldar HQ",
        "address_2": "Abu Dhabi    27655",
        "country": "AE"
    },
    "DCED84": {
        "oui_hex": "DC-ED-84",
        "organization": "Haverford Systems Inc",
        "address_1": "152 Robbins Road",
        "address_2": "Downingtown  PA  19335",
        "country": "US"
    },
    "7C573C": {
        "oui_hex": "7C-57-3C",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "2C01B5": {
        "oui_hex": "2C-01-B5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "28EF01": {
        "oui_hex": "28-EF-01",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "C05336": {
        "oui_hex": "C0-53-36",
        "organization": "Beijing National Railway Research & Design Institute of Signal & Communication Group Co..Ltd.",
        "address_1": "7 floor, No.1 Automobile Museum South Road, Fengtai Science and Technology Park,",
        "address_2": "Beijing  Beijing  100070",
        "country": "CN"
    },
    "606ED0": {
        "oui_hex": "60-6E-D0",
        "organization": "SEAL AG",
        "address_1": "Landstrasse 176",
        "address_2": "Wettingen    5430",
        "country": "CH"
    },
    "2CCCE6": {
        "oui_hex": "2C-CC-E6",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E44CC7": {
        "oui_hex": "E4-4C-C7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D4E880": {
        "oui_hex": "D4-E8-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A8346A": {
        "oui_hex": "A8-34-6A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3C20F6": {
        "oui_hex": "3C-20-F6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C38AD": {
        "oui_hex": "7C-38-AD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D49CDD": {
        "oui_hex": "D4-9C-DD",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "50F722": {
        "oui_hex": "50-F7-22",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9849E1": {
        "oui_hex": "98-49-E1",
        "organization": "Boeing Defence Australia",
        "address_1": "GPO Box 767",
        "address_2": "Brisbane  Queensland  4001",
        "country": "AU"
    },
    "04D7A5": {
        "oui_hex": "04-D7-A5",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "4C4D66": {
        "oui_hex": "4C-4D-66",
        "organization": "Nanjing Jiahao Technology Co., Ltd.",
        "address_1": "Moling Industrial Park, Development Zone, Jiangning, Nanjing",
        "address_2": "Nanjing  Jiangsu  211111",
        "country": "CN"
    },
    "A4817A": {
        "oui_hex": "A4-81-7A",
        "organization": "CIG SHANGHAI CO LTD",
        "address_1": "5th Floor, Building 8 No 2388 Chenhang Road",
        "address_2": "SHANGHAI    201114",
        "country": "CN"
    },
    "905851": {
        "oui_hex": "90-58-51",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "9809CF": {
        "oui_hex": "98-09-CF",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B8DE5E": {
        "oui_hex": "B8-DE-5E",
        "organization": "LONGCHEER TELECOMMUNICATION LIMITED",
        "address_1": "Building 1,No.401,Caobao Rd",
        "address_2": "Shanghai  Xuhui District  200233",
        "country": "CN"
    },
    "885A06": {
        "oui_hex": "88-5A-06",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "5447D3": {
        "oui_hex": "54-47-D3",
        "organization": "TSAT AS",
        "address_1": "Martin Linges v 25",
        "address_2": "Fornebu    1364",
        "country": "NO"
    },
    "CCEDDC": {
        "oui_hex": "CC-ED-DC",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "CCD81F": {
        "oui_hex": "CC-D8-1F",
        "organization": "Maipu Communication Technology Co.,Ltd.",
        "address_1": "Maipu Mansion, No.288 Tianfu 3rd Street, High-tech Zone",
        "address_2": "Chengdu  Sichuan  610094",
        "country": "CN"
    },
    "688B0F": {
        "oui_hex": "68-8B-0F",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "F82F6A": {
        "oui_hex": "F8-2F-6A",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "B068E6": {
        "oui_hex": "B0-68-E6",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A4E7E4": {
        "oui_hex": "A4-E7-E4",
        "organization": "Connex GmbH",
        "address_1": "Elbestrasse 12",
        "address_2": "Oldenburg    26135",
        "country": "DE"
    },
    "B8EF8B": {
        "oui_hex": "B8-EF-8B",
        "organization": "SHENZHEN CANNICE TECHNOLOGY CO.,LTD",
        "address_1": "F-20,7A,Baoneng Technology Park",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "B8186F": {
        "oui_hex": "B8-18-6F",
        "organization": "ORIENTAL MOTOR CO., LTD.",
        "address_1": "5-8-3 Tokodai",
        "address_2": "Tsukuba  Ibaraki  300-2635",
        "country": "JP"
    },
    "001A3F": {
        "oui_hex": "00-1A-3F",
        "organization": "Intelbras",
        "address_1": "BR 101, km 210, S/N°",
        "address_2": "São José  Santa Catarina  88104800",
        "country": "BR"
    },
    "C0D834": {
        "oui_hex": "C0-D8-34",
        "organization": "xvtec ltd",
        "address_1": "Ha'nagar 24",
        "address_2": "Hod Hasharon  Israel  4527713",
        "country": "IL"
    },
    "B8C253": {
        "oui_hex": "B8-C2-53",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F05C19": {
        "oui_hex": "F0-5C-19",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "04BD88": {
        "oui_hex": "04-BD-88",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "9C1C12": {
        "oui_hex": "9C-1C-12",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "18DFB4": {
        "oui_hex": "18-DF-B4",
        "organization": "BOSUNG POWERTEC CO.,LTD.",
        "address_1": "70, Daechang-gil, Judeok-eup",
        "address_2": "Chungju-si  Chungcheongbuk-do  27463",
        "country": "KR"
    },
    "000147": {
        "oui_hex": "00-01-47",
        "organization": "Zhone Technologies",
        "address_1": "7001 Oakport Street",
        "address_2": "Oakland  CA  94621",
        "country": "US"
    },
    "20B780": {
        "oui_hex": "20-B7-80",
        "organization": "Toshiba Visual Solutions Corporation Co.,Ltd",
        "address_1": "Shinkawasaki Mitsui Builing West Tower 19F, 1-1-2 Kashimada",
        "address_2": "Saiwai-ku, Kawasaki-shi  Kanagawa  212-0058",
        "country": "JP"
    },
    "E03717": {
        "oui_hex": "E0-37-17",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "14D4FE": {
        "oui_hex": "14-D4-FE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "304F75": {
        "oui_hex": "30-4F-75",
        "organization": "DASAN Network Solutions",
        "address_1": "DASAN Tower 8F, 49 Daewangpangyo-ro644beon-gil Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13493",
        "country": "KR"
    },
    "ECA9FA": {
        "oui_hex": "EC-A9-FA",
        "organization": "GUANGDONG GENIUS TECHNOLOGY CO., LTD.",
        "address_1": "#126,BBK Road,Wusha,Chang'An",
        "address_2": "Dong Guan  Guang Dong  523860",
        "country": "CN"
    },
    "0003A5": {
        "oui_hex": "00-03-A5",
        "organization": "Medea Corporation",
        "address_1": "5701 Lindero Canyon Rd.",
        "address_2": "Wetlake Village  CA  91362",
        "country": "US"
    },
    "BCE67C": {
        "oui_hex": "BC-E6-7C",
        "organization": "Cambium Networks Limited",
        "address_1": "Unit B2, Linhay Business Park,",
        "address_2": "Ashburton  Devon  TQ13 7UP",
        "country": "GB"
    },
    "7C1E06": {
        "oui_hex": "7C-1E-06",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "F0B31E": {
        "oui_hex": "F0-B3-1E",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "F89173": {
        "oui_hex": "F8-91-73",
        "organization": "AEDLE SAS",
        "address_1": "11 Rue Campagne Première, Cour Intérieure, Entresol, CODE 13B80",
        "address_2": "Paris  IDF  75014",
        "country": "FR"
    },
    "C84F86": {
        "oui_hex": "C8-4F-86",
        "organization": "Sophos Ltd",
        "address_1": "The Pentagon",
        "address_2": "Abingdon  Oxfordshire  OX14 3YP",
        "country": "GB"
    },
    "6429ED": {
        "oui_hex": "64-29-ED",
        "organization": "AO PKK Milandr",
        "address_1": "Gergievsky prospekt, 5",
        "address_2": "Zelenograd  Moscow  124498",
        "country": "RU"
    },
    "443C88": {
        "oui_hex": "44-3C-88",
        "organization": "FICOSA MAROC INTERNATIONAL",
        "address_1": "Zone Franche Technopolis Rocade Rabat-Salé 11103 Sala Al Jadida - Salé",
        "address_2": "Salé    11103",
        "country": "MA"
    },
    "841C70": {
        "oui_hex": "84-1C-70",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "544741": {
        "oui_hex": "54-47-41",
        "organization": "XCHENG HOLDING",
        "address_1": "ROOM 401F, Building 5, No.3000 LONG DONG Avenue, Pudong New District",
        "address_2": " Shanghai    201203",
        "country": "CN"
    },
    "CCF735": {
        "oui_hex": "CC-F7-35",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "C4F839": {
        "oui_hex": "C4-F8-39",
        "organization": "Actia Automotive",
        "address_1": "5 rue Jorge Semprun",
        "address_2": "TOULOUSE    31400",
        "country": "FR"
    },
    "C8F742": {
        "oui_hex": "C8-F7-42",
        "organization": "HangZhou Gubei Electronics Technology Co.,Ltd",
        "address_1": "Room 106, No.611 Jianghong Road, Binjiang District, Hangzhou, Zhejiang, China",
        "address_2": "Hangzhou  ZheJiang  310052",
        "country": "CN"
    },
    "006FF2": {
        "oui_hex": "00-6F-F2",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "30DF8D": {
        "oui_hex": "30-DF-8D",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "D4C93C": {
        "oui_hex": "D4-C9-3C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "78DD12": {
        "oui_hex": "78-DD-12",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "2C5D34": {
        "oui_hex": "2C-5D-34",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "9C1463": {
        "oui_hex": "9C-14-63",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "002433": {
        "oui_hex": "00-24-33",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "002306": {
        "oui_hex": "00-23-06",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "B4EC02": {
        "oui_hex": "B4-EC-02",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "646038": {
        "oui_hex": "64-60-38",
        "organization": "Hirschmann Automation and Control GmbH",
        "address_1": "Stuttgarter Straße 45-51",
        "address_2": "Neckartenzlingen    D-72654",
        "country": "DE"
    },
    "7018A7": {
        "oui_hex": "70-18-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "CCD39D": {
        "oui_hex": "CC-D3-9D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E0750A": {
        "oui_hex": "E0-75-0A",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "kakuda-City    981-1595",
        "country": "US"
    },
    "0019C1": {
        "oui_hex": "00-19-C1",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "0016FE": {
        "oui_hex": "00-16-FE",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "9C8D7C": {
        "oui_hex": "9C-8D-7C",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "D425CC": {
        "oui_hex": "D4-25-CC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8C6DC4": {
        "oui_hex": "8C-6D-C4",
        "organization": "Megapixel VR",
        "address_1": "340 S. Lemon Ave",
        "address_2": "Walnut  CA  91789",
        "country": "US"
    },
    "BC7536": {
        "oui_hex": "BC-75-36",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "nishida  6-1",
        "address_2": "Kakuda-City  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "E0AE5E": {
        "oui_hex": "E0-AE-5E",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-3-36 Furukawanakazato,",
        "address_2": "Osaki  Miyagi-pref  989-6181",
        "country": "JP"
    },
    "D4B761": {
        "oui_hex": "D4-B7-61",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "7C035E": {
        "oui_hex": "7C-03-5E",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "44FE3B": {
        "oui_hex": "44-FE-3B",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "D83AF5": {
        "oui_hex": "D8-3A-F5",
        "organization": "Wideband Labs LLC",
        "address_1": "1027 S Main Street, STE 330",
        "address_2": "Joplin  MO  64801",
        "country": "US"
    },
    "38D9A5": {
        "oui_hex": "38-D9-A5",
        "organization": "Mikotek Information Inc.",
        "address_1": "3F, No. 20, Aly. 18, Ln. 478, Ruiguang Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "4C875D": {
        "oui_hex": "4C-87-5D",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "B0E7DE": {
        "oui_hex": "B0-E7-DE",
        "organization": "Homa Technologies JSC",
        "address_1": "Building 5, Quang Trung Software City, District 12",
        "address_2": "Ho Chi Minh    729226",
        "country": "VN"
    },
    "649D99": {
        "oui_hex": "64-9D-99",
        "organization": "FS COM INC",
        "address_1": "380 Centerpoint Blvd New Castle",
        "address_2": "New Castle  DE  19720",
        "country": "US"
    },
    "00169D": {
        "oui_hex": "00-16-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4C962D": {
        "oui_hex": "4C-96-2D",
        "organization": "Fresh AB",
        "address_1": "Gransholmsvägen 136",
        "address_2": "Gemla    35599",
        "country": "SE"
    },
    "00D279": {
        "oui_hex": "00-D2-79",
        "organization": "VINGROUP JOINT STOCK COMPANY",
        "address_1": "Number 7, Bang Lang 1 street, Long Bien district",
        "address_2": "Ha Noi  Ha Noi  100000",
        "country": "VN"
    },
    "484A30": {
        "oui_hex": "48-4A-30",
        "organization": "George Robotics Limited",
        "address_1": "Salisbury House, Station Road",
        "address_2": "Cambridge    CB1 2LA",
        "country": "GB"
    },
    "4861A3": {
        "oui_hex": "48-61-A3",
        "organization": "Concern Axion JSC",
        "address_1": "90, M. Gorkogo St.",
        "address_2": "Izhevsk  Udmurt Republic  426000",
        "country": "RU"
    },
    "304A26": {
        "oui_hex": "30-4A-26",
        "organization": "Shenzhen Trolink Technology CO, LTD",
        "address_1": "201 B building 4 shijie, Chashu industry 505 block, Baoan airport Sanwei community, Hangcheng street Baoan area.",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "4CE5AE": {
        "oui_hex": "4C-E5-AE",
        "organization": "Tianjin Beebox Intelligent Technology Co.,Ltd.",
        "address_1": "Room 103，NO.1 of the 2nd Street",
        "address_2": "Tianjin Pilot Free Trade Zone Airport EconomicArea  Airport International Logistics Zone, Tianjin  300300",
        "country": "CN"
    },
    "E4D3AA": {
        "oui_hex": "E4-D3-AA",
        "organization": "FUJITSU CONNECTED TECHNOLOGIES LIMITED",
        "address_1": "4-1-1, Kamikodanaka, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  2118588",
        "country": "JP"
    },
    "D467D3": {
        "oui_hex": "D4-67-D3",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "A41232": {
        "oui_hex": "A4-12-32",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "48E3C3": {
        "oui_hex": "48-E3-C3",
        "organization": "JENOPTIK Advanced Systems GmbH",
        "address_1": "Feldstrasse 155",
        "address_2": "Wedel  Schleswig-Holstein  22880",
        "country": "DE"
    },
    "CC355A": {
        "oui_hex": "CC-35-5A",
        "organization": "SecuGen Corporation",
        "address_1": "2065 Martin Ave, Suite 108",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "80546A": {
        "oui_hex": "80-54-6A",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "B447F5": {
        "oui_hex": "B4-47-F5",
        "organization": "Earda Technologies co Ltd",
        "address_1": "Block A,Lianfeng Creative Park, #2 Jisheng Rd., Nansha District",
        "address_2": "Guangzhou  Guangdong  511455",
        "country": "CN"
    },
    "F4C7C8": {
        "oui_hex": "F4-C7-C8",
        "organization": "Kelvin Inc.",
        "address_1": "400 Centennial Parkway, Suite 190",
        "address_2": "Louisville  CO  80027",
        "country": "US"
    },
    "A89CA4": {
        "oui_hex": "A8-9C-A4",
        "organization": "Furrion Limited",
        "address_1": "Units 503C & 505-508, Level 5, Core D, Cyberport 3, 100 Cyberport Road",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "00004C": {
        "oui_hex": "00-00-4C",
        "organization": "NEC Corporation",
        "address_1": "7-1 SHIBA  5-CHOME",
        "address_2": "TOKYO 108-01    0000",
        "country": "JP"
    },
    "8CCF8F": {
        "oui_hex": "8C-CF-8F",
        "organization": "ITC Systems",
        "address_1": "800 Fee Fee Road",
        "address_2": "St Louis  MO  63043",
        "country": "US"
    },
    "2875D8": {
        "oui_hex": "28-75-D8",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building, Star-net Science Plaza, Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "90E202": {
        "oui_hex": "90-E2-02",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "302478": {
        "oui_hex": "30-24-78",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "7C89C1": {
        "oui_hex": "7C-89-C1",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "84A93E": {
        "oui_hex": "84-A9-3E",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "B0C387": {
        "oui_hex": "B0-C3-87",
        "organization": "GOEFER, Inc.",
        "address_1": "118 N. Market St.",
        "address_2": "Frederick  MD  21701",
        "country": "US"
    },
    "086BD7": {
        "oui_hex": "08-6B-D7",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "349342": {
        "oui_hex": "34-93-42",
        "organization": "TTE Corporation",
        "address_1": "7/F, Building 22E 22 Science Park East Avenue Hong Kong Science Park Shatin, N.T.",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "589EC6": {
        "oui_hex": "58-9E-C6",
        "organization": "Gigaset Communications GmbH",
        "address_1": "Frankenstrasse 2",
        "address_2": "Bocholt  NRW  46395",
        "country": "DE"
    },
    "64C753": {
        "oui_hex": "64-C7-53",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6458AD": {
        "oui_hex": "64-58-AD",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "1CF29A": {
        "oui_hex": "1C-F2-9A",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "748A0D": {
        "oui_hex": "74-8A-0D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "CC75E2": {
        "oui_hex": "CC-75-E2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A0A3B8": {
        "oui_hex": "A0-A3-B8",
        "organization": "WISCLOUD",
        "address_1": "Tech Park Xia Sha",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "38F9D3": {
        "oui_hex": "38-F9-D3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FC183C": {
        "oui_hex": "FC-18-3C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A40C66": {
        "oui_hex": "A4-0C-66",
        "organization": "Shenzhen Colorful Yugong Technology and Development Co., Ltd.",
        "address_1": "13F, Central Business Tower, No.88 Fuhua First Rd., Futian District, Shenzhen, Guangdong, China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4455B1": {
        "oui_hex": "44-55-B1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "98F9C7": {
        "oui_hex": "98-F9-C7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "700B4F": {
        "oui_hex": "70-0B-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E4388C": {
        "oui_hex": "E4-38-8C",
        "organization": "Digital Products Limited",
        "address_1": "53 Clark Road",
        "address_2": "Rothesay  New Brunswick  E2E 2K9",
        "country": "CA"
    },
    "184BDF": {
        "oui_hex": "18-4B-DF",
        "organization": "Caavo Inc",
        "address_1": "1525 McCarthy Blvd., #1182",
        "address_2": "Milpitas    95035",
        "country": "US"
    },
    "B89A9A": {
        "oui_hex": "B8-9A-9A",
        "organization": "Xin Shi Jia Technology (Beijing) Co.,Ltd",
        "address_1": "Room 1002, A Tower, Zhongguancun E World Wealth Center, No.11, Zhongguancun Street, Haidian District, Beijing City",
        "address_2": "Beijing  Beijing  100190",
        "country": "CN"
    },
    "8C7BF0": {
        "oui_hex": "8C-7B-F0",
        "organization": "Xufeng Development Limited",
        "address_1": "FLAT/RM1616 16F INTERATIONAL TRADE CENTRE 11-19 SHA TSUI RD TSUEN WAN",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "E0A509": {
        "oui_hex": "E0-A5-09",
        "organization": "Bitmain Technologies Inc",
        "address_1": "Building 25, North Olympic Science & Technology Park, Baosheng South Road, Haidian District, Beijing, China",
        "address_2": "Beijing  BEIJING  CHINA",
        "country": "CN"
    },
    "3C5CC4": {
        "oui_hex": "3C-5C-C4",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "D8A756": {
        "oui_hex": "D8-A7-56",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "D8D6F3": {
        "oui_hex": "D8-D6-F3",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "6C2CDC": {
        "oui_hex": "6C-2C-DC",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "7835A0": {
        "oui_hex": "78-35-A0",
        "organization": "Zurn Industries LLC",
        "address_1": "1747 Commerce Way",
        "address_2": "Paso Robles  CA  93446",
        "country": "US"
    },
    "F43909": {
        "oui_hex": "F4-39-09",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "201F31": {
        "oui_hex": "20-1F-31",
        "organization": "Inteno Broadband Technology AB",
        "address_1": "Stensätravägen 13",
        "address_2": "Skärholmen  SE  127 39",
        "country": "SE"
    },
    "2CCC44": {
        "oui_hex": "2C-CC-44",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "F47DEF": {
        "oui_hex": "F4-7D-EF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C8BB5": {
        "oui_hex": "7C-8B-B5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54833A": {
        "oui_hex": "54-83-3A",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "787052": {
        "oui_hex": "78-70-52",
        "organization": "Welotec GmbH",
        "address_1": "zum Hagenbach 7",
        "address_2": "Laer  NRW  48366",
        "country": "DE"
    },
    "D8A98B": {
        "oui_hex": "D8-A9-8B",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "00116C": {
        "oui_hex": "00-11-6C",
        "organization": "Nanwang Multimedia Inc.,Ltd",
        "address_1": "Floor 12,Tianyuan Bldg,Wensan Rd#508",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "10B9F7": {
        "oui_hex": "10-B9-F7",
        "organization": "Niko-Servodan",
        "address_1": "Stenager 5",
        "address_2": "Sønderborg    6400",
        "country": "DK"
    },
    "14EFCF": {
        "oui_hex": "14-EF-CF",
        "organization": "SCHREDER",
        "address_1": "Rue Lusambo 67",
        "address_2": "Brussels    1190",
        "country": "BE"
    },
    "3830F9": {
        "oui_hex": "38-30-F9",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "A83FA1": {
        "oui_hex": "A8-3F-A1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "7847E3": {
        "oui_hex": "78-47-E3",
        "organization": "SICHUAN TIANYI COMHEART TELECOM CO.,LTD",
        "address_1": "NO.198 FIRST SECTION,SNOW MOUNTAIN AVENUE, JINYUAN TOWN, DAYI COUNTY,",
        "address_2": "CHENGDU  SICHUAN  611330",
        "country": "CN"
    },
    "6C9BC0": {
        "oui_hex": "6C-9B-C0",
        "organization": "Chemoptics Inc.",
        "address_1": "261, Techno 2-ro, Yuseong-gu",
        "address_2": "Daejeon    34026",
        "country": "KR"
    },
    "F4DBE6": {
        "oui_hex": "F4-DB-E6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "248498": {
        "oui_hex": "24-84-98",
        "organization": "Beijing Jiaoda Microunion Tech.Co.,Ltd.",
        "address_1": "4-5/F,89 Building, First Section No.44 Gaoliangqiao Xie Street, Haidian District, Beijing, China",
        "address_2": "Beijing  Beijing  100044",
        "country": "CN"
    },
    "C074AD": {
        "oui_hex": "C0-74-AD",
        "organization": "Grandstream Networks, Inc.",
        "address_1": "1297 Beacon Street",
        "address_2": "Brookline  MA  02446",
        "country": "US"
    },
    "F095F1": {
        "oui_hex": "F0-95-F1",
        "organization": "Carl Zeiss AG",
        "address_1": "Carl-Zeiss-Straße 22",
        "address_2": "Oberkochen    73447",
        "country": "DE"
    },
    "00F48D": {
        "oui_hex": "00-F4-8D",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "702ED9": {
        "oui_hex": "70-2E-D9",
        "organization": "Guangzhou Shiyuan Electronics Co., Ltd.",
        "address_1": "No.6, 4th Yunpu Road, Yunpu industry District",
        "address_2": "Gunagzhou  Guangdong  510530",
        "country": "CN"
    },
    "70192F": {
        "oui_hex": "70-19-2F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "10C22F": {
        "oui_hex": "10-C2-2F",
        "organization": "China Entropy Co., Ltd.",
        "address_1": "Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "BC3865": {
        "oui_hex": "BC-38-65",
        "organization": "JWCNETWORKS",
        "address_1": "114, Gasan digital 2-ro, Geumcheon-gu,",
        "address_2": "Seoul    08506",
        "country": "KR"
    },
    "04EB40": {
        "oui_hex": "04-EB-40",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18A7F1": {
        "oui_hex": "18-A7-F1",
        "organization": "Qingdao Haier Technology Co.,Ltd",
        "address_1": "Building A01,Haier Information Park, No.1 Haier Road,",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "90E17B": {
        "oui_hex": "90-E1-7B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D81C79": {
        "oui_hex": "D8-1C-79",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "58E6BA": {
        "oui_hex": "58-E6-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "44E4EE": {
        "oui_hex": "44-E4-EE",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "DC41E5": {
        "oui_hex": "DC-41-E5",
        "organization": "Shenzhen Zhixin Data Service Co., Ltd.",
        "address_1": " Baoyuan Road F518 Fashion Creative Park F3 Blg208",
        "address_2": "Baoan District, Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "00A5BF": {
        "oui_hex": "00-A5-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C8BAE9": {
        "oui_hex": "C8-BA-E9",
        "organization": "QDIS",
        "address_1": "#512, Buliding B, 168 GaSanDigital 1st, GeumChun-Gu",
        "address_2": "SEOUL    08507",
        "country": "KR"
    },
    "1801F1": {
        "oui_hex": "18-01-F1",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C44F33": {
        "oui_hex": "C4-4F-33",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "546AD8": {
        "oui_hex": "54-6A-D8",
        "organization": "Elster Water Metering",
        "address_1": "Mas des Cavaliers II, 471 Rue Charles Nungesser",
        "address_2": "Mauguio    34130",
        "country": "FR"
    },
    "C0847D": {
        "oui_hex": "C0-84-7D",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "0409A5": {
        "oui_hex": "04-09-A5",
        "organization": "HFR, Inc.",
        "address_1": "5F, Hana EZ Tower",
        "address_2": "Sungnam-si  Kyunggi-do  463-870",
        "country": "KR"
    },
    "94917F": {
        "oui_hex": "94-91-7F",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "9C0CDF": {
        "oui_hex": "9C-0C-DF",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "242124": {
        "oui_hex": "24-21-24",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "949B2C": {
        "oui_hex": "94-9B-2C",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose    95119",
        "country": "US"
    },
    "7CD30A": {
        "oui_hex": "7C-D3-0A",
        "organization": "INVENTEC CORPORATION",
        "address_1": "Inventec Building, 66 Hou-Kang Street",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "001E33": {
        "oui_hex": "00-1E-33",
        "organization": "INVENTEC CORPORATION",
        "address_1": "Inventec Building, 66 Hou-Kang Street",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "FC1D84": {
        "oui_hex": "FC-1D-84",
        "organization": "Autobase",
        "address_1": "1201, Biz Center, SKnTechno Park, 124, Sagimakgol-ro, Jungwon-gu, Seongnam-si, Gyeonggi-do",
        "address_2": "Seongnam  Gyeonggi  462-721",
        "country": "KR"
    },
    "18AC9E": {
        "oui_hex": "18-AC-9E",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "EC84B4": {
        "oui_hex": "EC-84-B4",
        "organization": "CIG SHANGHAI CO LTD",
        "address_1": "5th Floor, Building 8 No 2388 Chenhang Road",
        "address_2": "SHANGHAI    201114",
        "country": "CN"
    },
    "00D096": {
        "oui_hex": "00-D0-96",
        "organization": "3COM EUROPE LTD",
        "address_1": "BOUNDARY WAY",
        "address_2": "vvvvv  UNITED  KINGDOM",
        "country": "GB"
    },
    "002654": {
        "oui_hex": "00-26-54",
        "organization": "3COM",
        "address_1": "5353 Betsy Ross Drive",
        "address_2": "Santa Clara    95054-1162",
        "country": "US"
    },
    "0050DA": {
        "oui_hex": "00-50-DA",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "000476": {
        "oui_hex": "00-04-76",
        "organization": "3COM",
        "address_1": "5400 Bayfront Plaza",
        "address_2": "Santa Clara  CA  95052",
        "country": "US"
    },
    "000475": {
        "oui_hex": "00-04-75",
        "organization": "3COM",
        "address_1": "5400 Bayfront Plaza",
        "address_2": "Santa Clara  CA  95052",
        "country": "US"
    },
    "4422F1": {
        "oui_hex": "44-22-F1",
        "organization": "S.FAC, INC",
        "address_1": "Bldg A203  Techno2 ro 187",
        "address_2": "Yuseong-Gu  Daejeon  34025",
        "country": "KR"
    },
    "3009F9": {
        "oui_hex": "30-09-F9",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B4DDD0": {
        "oui_hex": "B4-DD-D0",
        "organization": "Continental Automotive Hungary Kft",
        "address_1": "Napmátka u. 6.",
        "address_2": "Budapest  Pest  H-1106",
        "country": "HU"
    },
    "48F027": {
        "oui_hex": "48-F0-27",
        "organization": "Chengdu newifi Co.,Ltd",
        "address_1": "C11 Building 2001,No.219 ,2nd Tianhua Road,Hi-tech zone",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "14C697": {
        "oui_hex": "14-C6-97",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "7C03AB": {
        "oui_hex": "7C-03-AB",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "DC16B2": {
        "oui_hex": "DC-16-B2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "24FB65": {
        "oui_hex": "24-FB-65",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0CB527": {
        "oui_hex": "0C-B5-27",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B42E99": {
        "oui_hex": "B4-2E-99",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "342CC4": {
        "oui_hex": "34-2C-C4",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "14E9B2": {
        "oui_hex": "14-E9-B2",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "C8544B": {
        "oui_hex": "C8-54-4B",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "D07FA0": {
        "oui_hex": "D0-7F-A0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "009093": {
        "oui_hex": "00-90-93",
        "organization": "EIZO Corporation",
        "address_1": "153 Shimokashiwano",
        "address_2": "Hakusan  Ishikawa  924-8856",
        "country": "JP"
    },
    "4C1159": {
        "oui_hex": "4C-11-59",
        "organization": "Vision Information & Communications",
        "address_1": "151, Ulseong-gil",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  17823",
        "country": "KR"
    },
    "00049F": {
        "oui_hex": "00-04-9F",
        "organization": "Freescale Semiconductor",
        "address_1": "2100 East  Elliot",
        "address_2": "Tempe  AZ  85284",
        "country": "US"
    },
    "00D07B": {
        "oui_hex": "00-D0-7B",
        "organization": "COMCAM INTERNATIONAL INC",
        "address_1": "1140 McDermott Drive Suite 200",
        "address_2": "WEST CHESTER  PA  19380",
        "country": "US"
    },
    "78524A": {
        "oui_hex": "78-52-4A",
        "organization": "Ensenso GmbH",
        "address_1": "Gundelfingerstr. 2",
        "address_2": "Freiburg    79108",
        "country": "DE"
    },
    "E4FC82": {
        "oui_hex": "E4-FC-82",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00B5D0": {
        "oui_hex": "00-B5-D0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1496E5": {
        "oui_hex": "14-96-E5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C46E7B": {
        "oui_hex": "C4-6E-7B",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C048FB": {
        "oui_hex": "C0-48-FB",
        "organization": "Shenzhen JingHanDa Electronics Co.Ltd",
        "address_1": "5th Floor,No 4 ,Road 1,ShangXue Technology industrial Park,LongGang district,ShenZhen,GuangDong,China",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "20E882": {
        "oui_hex": "20-E8-82",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F09FFC": {
        "oui_hex": "F0-9F-FC",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "0CB5DE": {
        "oui_hex": "0C-B5-DE",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "000B3B": {
        "oui_hex": "00-0B-3B",
        "organization": "devolo AG",
        "address_1": "Charlottenburger Allee 67",
        "address_2": "Aachen  NRW  52068",
        "country": "DE"
    },
    "240588": {
        "oui_hex": "24-05-88",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "50DCFC": {
        "oui_hex": "50-DC-FC",
        "organization": "ECOCOM",
        "address_1": "15ST,Block A,Fortune Plaza, No.7002 ShenNan Avenue, Futian District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "700B01": {
        "oui_hex": "70-0B-01",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "5C2623": {
        "oui_hex": "5C-26-23",
        "organization": "WaveLynx Technologies Corporation",
        "address_1": "100 Technology Drive, Building B, Ste 150",
        "address_2": "Broomfield  CO  80021",
        "country": "US"
    },
    "303855": {
        "oui_hex": "30-38-55",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "00B670": {
        "oui_hex": "00-B6-70",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "AC6417": {
        "oui_hex": "AC-64-17",
        "organization": "Siemens AG",
        "address_1": "Werner-von-Siemens Strasse 50",
        "address_2": "Amberg    92224",
        "country": "DE"
    },
    "347916": {
        "oui_hex": "34-79-16",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3466EA": {
        "oui_hex": "34-66-EA",
        "organization": "VERTU INTERNATIONAL CORPORATION LIMITED",
        "address_1": "25 St Thomas Street, Winchester, Hampshire, United Kingdom",
        "address_2": "Winchester  Hampshire  SO23 9HJ",
        "country": "GB"
    },
    "28385C": {
        "oui_hex": "28-38-5C",
        "organization": "FLEXTRONICS",
        "address_1": "Carretera Base Aerea 5850 int 4",
        "address_2": "Zapopan  Jalisco  45136",
        "country": "MX"
    },
    "0C1C57": {
        "oui_hex": "0C-1C-57",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "806FB0": {
        "oui_hex": "80-6F-B0",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "883F99": {
        "oui_hex": "88-3F-99",
        "organization": "Siemens AG",
        "address_1": "Werner-von-Siemens-Str. 48",
        "address_2": "Amberg    92224",
        "country": "DE"
    },
    "EC6F0B": {
        "oui_hex": "EC-6F-0B",
        "organization": "FADU, Inc.",
        "address_1": "4th FL, 8, Bongeunsa-ro 68-gil, Gangnam-gu",
        "address_2": "Seoul    06153",
        "country": "KR"
    },
    "0006EC": {
        "oui_hex": "00-06-EC",
        "organization": "Harris Corporation",
        "address_1": "1025 West NASA Blvd",
        "address_2": "Melbourne  FL  32919",
        "country": "US"
    },
    "7C6DA6": {
        "oui_hex": "7C-6D-A6",
        "organization": "Superwave Group LLC",
        "address_1": "poselok Krasnaya Zarya, dom 15",
        "address_2": "Vsevolozhskiy raiyon  Leningradskaya oblast  193149",
        "country": "RU"
    },
    "D016B4": {
        "oui_hex": "D0-16-B4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "20A8B9": {
        "oui_hex": "20-A8-B9",
        "organization": "SIEMENS AG",
        "address_1": "Oestliche Rheinbrueckenstrasse 50",
        "address_2": "Karlsruhe  Baden Wuerttemberg  76187",
        "country": "DE"
    },
    "F0F08F": {
        "oui_hex": "F0-F0-8F",
        "organization": "Nextek Solutions Pte Ltd",
        "address_1": "105 Cecil Street, #06-01 The Octagon",
        "address_2": "Singapore  Singapore  069534",
        "country": "SG"
    },
    "8CB0E9": {
        "oui_hex": "8C-B0-E9",
        "organization": "Samsung Electronics.,LTD",
        "address_1": "129, Samsung-ro, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-Do  443-742",
        "country": "KR"
    },
    "1C3947": {
        "oui_hex": "1C-39-47",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 15, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "342792": {
        "oui_hex": "34-27-92",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "40A108": {
        "oui_hex": "40-A1-08",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "705AB6": {
        "oui_hex": "70-5A-B6",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 15, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "201A06": {
        "oui_hex": "20-1A-06",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 15, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "F8A963": {
        "oui_hex": "F8-A9-63",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 15, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "DC0EA1": {
        "oui_hex": "DC-0E-A1",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "No.25, Third Avenue, A Zone, Kunshan Comprehensive Free Trade Zone,, Jiangsu,",
        "address_2": "KUNSHAN   SUZHOU  215300",
        "country": "CN"
    },
    "B870F4": {
        "oui_hex": "B8-70-F4",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "009D6B": {
        "oui_hex": "00-9D-6B",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "745933": {
        "oui_hex": "74-59-33",
        "organization": "Danal Entertainment",
        "address_1": "9th Fl. Bundang First Tower, 55 Bundang-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13591",
        "country": "KR"
    },
    "EC58EA": {
        "oui_hex": "EC-58-EA",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "7C9A54": {
        "oui_hex": "7C-9A-54",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "388B59": {
        "oui_hex": "38-8B-59",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "880118": {
        "oui_hex": "88-01-18",
        "organization": "BLT Co",
        "address_1": "Dongan-gu Burim-ro 170beon-gil 44",
        "address_2": "Anyangsi  Kyunggido  14055",
        "country": "KR"
    },
    "A42618": {
        "oui_hex": "A4-26-18",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "A46191": {
        "oui_hex": "A4-61-91",
        "organization": "NamJunSa",
        "address_1": "12, Gimhae-daero 2635 beon-gil",
        "address_2": "Gimhae-si  Gyeongsangnam-do  50932",
        "country": "KR"
    },
    "84A24D": {
        "oui_hex": "84-A2-4D",
        "organization": "Birds Eye Systems Private Limited",
        "address_1": "123-126, B Wing First Floor, Chintanmani Plaza, Mohan Studio Compound, Andheri-Kurla Road, Andheri East",
        "address_2": "Mumbai  Maharashtra   400099",
        "country": "IN"
    },
    "7C6B9C": {
        "oui_hex": "7C-6B-9C",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "0017B6": {
        "oui_hex": "00-17-B6",
        "organization": "Aquantia Corporation",
        "address_1": "700 Tasman Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "105917": {
        "oui_hex": "10-59-17",
        "organization": "Tonal",
        "address_1": "1074 Folsom St",
        "address_2": "San Francisco    94103",
        "country": "US"
    },
    "D0EFC1": {
        "oui_hex": "D0-EF-C1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D45251": {
        "oui_hex": "D4-52-51",
        "organization": "IBT Ingenieurbureau Broennimann Thun",
        "address_1": "Kasernenstrasse 5",
        "address_2": "Thun  Bern  3600",
        "country": "CH"
    },
    "0018B5": {
        "oui_hex": "00-18-B5",
        "organization": "Magna Carta",
        "address_1": "Naritaweg 126",
        "address_2": "Amsterdam  Noord Holland  1043 CA",
        "country": "NL"
    },
    "D87EB1": {
        "oui_hex": "D8-7E-B1",
        "organization": "x.o.ware, inc.",
        "address_1": "114 E. Haley St., Ste N",
        "address_2": "Santa Barbara  California  93101",
        "country": "US"
    },
    "485702": {
        "oui_hex": "48-57-02",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "644F42": {
        "oui_hex": "64-4F-42",
        "organization": "JETTER CO., Ltd.",
        "address_1": "265-40 Emukaecho Tanomoto",
        "address_2": "Sasebo-shi  Nagasaki  859-6134",
        "country": "JP"
    },
    "DCAF68": {
        "oui_hex": "DC-AF-68",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road, Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "24EC51": {
        "oui_hex": "24-EC-51",
        "organization": "ADF Technologies Sdn Bhd",
        "address_1": "Plot 88F, Lintang Bayan Lepas 10, Bayan Lepas Industrial Park Phase IV",
        "address_2": "Bayan Lepas  Pulau Pinang  11900",
        "country": "MY"
    },
    "7089CC": {
        "oui_hex": "70-89-CC",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "2C5BE1": {
        "oui_hex": "2C-5B-E1",
        "organization": "Centripetal Networks, Inc",
        "address_1": "2251 Corporate Park Drive, Suite 150",
        "address_2": "Herndon  VA  201715806",
        "country": "US"
    },
    "DCEFCA": {
        "oui_hex": "DC-EF-CA",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "00BC60": {
        "oui_hex": "00-BC-60",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "CC7B61": {
        "oui_hex": "CC-7B-61",
        "organization": "NIKKISO CO., LTD.",
        "address_1": "Yebisu Garden Place Tower 22nd Floor, 20-3, Ebisu 4-Chome",
        "address_2": "Shibuya-ku  Tokyo  150-6022",
        "country": "JP"
    },
    "9C713A": {
        "oui_hex": "9C-71-3A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2C97B1": {
        "oui_hex": "2C-97-B1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A89969": {
        "oui_hex": "A8-99-69",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "A4EA8E": {
        "oui_hex": "A4-EA-8E",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "882D53": {
        "oui_hex": "88-2D-53",
        "organization": "Baidu Online Network Technology (Beijing) Co., Ltd.",
        "address_1": "Baidu Campus, No.10 Shangdi 10th Street, Haidian District Beijing 100085 CN",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "00D0B5": {
        "oui_hex": "00-D0-B5",
        "organization": "IPricot formerly DotCom",
        "address_1": "10-12, avenue de Verdun",
        "address_2": "La-Garenne-Colombes    F-92250",
        "country": "FR"
    },
    "746BAB": {
        "oui_hex": "74-6B-AB",
        "organization": "GUANGDONG ENOK COMMUNICATION CO., LTD",
        "address_1": "NO.139 Lixiang road, Songmushan Dalang Town",
        "address_2": "Dongguan, Guangdong    523770",
        "country": "CN"
    },
    "0CB6D2": {
        "oui_hex": "0C-B6-D2",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "7829ED": {
        "oui_hex": "78-29-ED",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "5061BF": {
        "oui_hex": "50-61-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0009DF": {
        "oui_hex": "00-09-DF",
        "organization": "Vestel Elektronik San ve Tic. A.Ş.",
        "address_1": "Organize san",
        "address_2": "Manisa  Turket  45030",
        "country": "TR"
    },
    "F4032F": {
        "oui_hex": "F4-03-2F",
        "organization": "Reduxio Systems",
        "address_1": "2 Granit St",
        "address_2": "Petach Tikvah    4951446",
        "country": "IL"
    },
    "944A0C": {
        "oui_hex": "94-4A-0C",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "000FA2": {
        "oui_hex": "00-0F-A2",
        "organization": "2xWireless",
        "address_1": "1065 Maurader st",
        "address_2": "Chico  CA  95973",
        "country": "US"
    },
    "108EE0": {
        "oui_hex": "10-8E-E0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCA621": {
        "oui_hex": "FC-A6-21",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8CF228": {
        "oui_hex": "8C-F2-28",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "700F6A": {
        "oui_hex": "70-0F-6A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BB2": {
        "oui_hex": "00-0B-B2",
        "organization": "SMALLBIG TECHNOLOGY",
        "address_1": "3F Dongsung Bldg. 720-9 Yoksamdong",
        "address_2": "Gangnamgu  Seoul  135-080",
        "country": "KR"
    },
    "00305E": {
        "oui_hex": "00-30-5E",
        "organization": "Abelko Innovation",
        "address_1": "Box 808",
        "address_2": "Lulea    97125",
        "country": "SE"
    },
    "FC6BF0": {
        "oui_hex": "FC-6B-F0",
        "organization": "TOPWELL INTERNATIONAL HOLDINDS LIMITED",
        "address_1": "Room 1301-5,Buliding China Youshe,NO.6013,ShenNan Road,CheGong Temple,FuTian District,ShenZhen,GuangDong province,China",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "001477": {
        "oui_hex": "00-14-77",
        "organization": "Trilliant",
        "address_1": "950 Cowie st.",
        "address_2": "Granby  Quebec  J2J 1P2",
        "country": "CA"
    },
    "00079B": {
        "oui_hex": "00-07-9B",
        "organization": "Aurora Networks",
        "address_1": "2803 Mission College Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "544810": {
        "oui_hex": "54-48-10",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "54B203": {
        "oui_hex": "54-B2-03",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "3868DD": {
        "oui_hex": "38-68-DD",
        "organization": "INVENTEC CORPORATION",
        "address_1": "NO.88, DAZHI RD.",
        "address_2": "TAOYUAN    33068",
        "country": "TW"
    },
    "B8B7F1": {
        "oui_hex": "B8-B7-F1",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "8050F6": {
        "oui_hex": "80-50-F6",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "A8CAB9": {
        "oui_hex": "A8-CA-B9",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "SUWON  KYUNGGI-DO  443-743",
        "country": "KR"
    },
    "203956": {
        "oui_hex": "20-39-56",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "78AFE4": {
        "oui_hex": "78-AF-E4",
        "organization": "Comau S.p.A",
        "address_1": "via Rivalta 30",
        "address_2": "Grugliasco  (TO)  10095",
        "country": "IT"
    },
    "90A137": {
        "oui_hex": "90-A1-37",
        "organization": "Beijing Splendidtel Communication Technology Co,. Ltd",
        "address_1": "4 Floor,Taixing Tower,No.11 Huayuan East Road. Haidian District",
        "address_2": "Beijing  Beijing  100191",
        "country": "CN"
    },
    "80029C": {
        "oui_hex": "80-02-9C",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No.15-1 Zhonghua Road",
        "address_2": "Hukou  Hsinchu  30352",
        "country": "TW"
    },
    "D0C5D3": {
        "oui_hex": "D0-C5-D3",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "14169E": {
        "oui_hex": "14-16-9E",
        "organization": " Wingtech Group (HongKong）Limited",
        "address_1": " FLAT/RM 1903 19/F PODIUM PLAZA 5HANOI ROAD TSIM SHA TSUI",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "F8C39E": {
        "oui_hex": "F8-C3-9E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8D099": {
        "oui_hex": "E8-D0-99",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "107BA4": {
        "oui_hex": "10-7B-A4",
        "organization": "Olive & Dove Co.,Ltd.",
        "address_1": "803 Polaris bldg., 381, Seongnam-daero, Bundang-gu",
        "address_2": "Gyeonggi-do  Seongnam-si  13555",
        "country": "KR"
    },
    "7C41A2": {
        "oui_hex": "7C-41-A2",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "BC325F": {
        "oui_hex": "BC-32-5F",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "505BC2": {
        "oui_hex": "50-5B-C2",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "6C21A2": {
        "oui_hex": "6C-21-A2",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "9C2F73": {
        "oui_hex": "9C-2F-73",
        "organization": "Universal Tiancheng Technology (Beijing) Co., Ltd.",
        "address_1": "13 floor,Changxin Building,Anding Road No.39,Chaoyang District,Beijing",
        "address_2": "Beijing  Beijing  100029",
        "country": "CN"
    },
    "D832E3": {
        "oui_hex": "D8-32-E3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "9487E0": {
        "oui_hex": "94-87-E0",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "38AF29": {
        "oui_hex": "38-AF-29",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "C88629": {
        "oui_hex": "C8-86-29",
        "organization": "Shenzhen Duubee Intelligent Technologies Co.,LTD.",
        "address_1": "9F, Block B, Unicenter, Xin’an Sub district, Bao’an District",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "CCC2E0": {
        "oui_hex": "CC-C2-E0",
        "organization": "Raisecom Technology CO., LTD",
        "address_1": "No. 11, East Area, No. 10 Block, East Xibeiwang Road",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "300AC5": {
        "oui_hex": "30-0A-C5",
        "organization": "Ruio telecommunication technologies Co., Limited",
        "address_1": "Room 2501, Broadegate Software Building, No,1003 Keyuan Road,",
        "address_2": "Shenzhen  guangdong  518000",
        "country": "CN"
    },
    "00E065": {
        "oui_hex": "00-E0-65",
        "organization": "OPTICAL ACCESS INTERNATIONAL",
        "address_1": "500 WEST CUMMINGS PL. #3400",
        "address_2": "WOBURN  MA  01801",
        "country": "US"
    },
    "4466FC": {
        "oui_hex": "44-66-FC",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "A028ED": {
        "oui_hex": "A0-28-ED",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "AC5474": {
        "oui_hex": "AC-54-74",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "8C1CDA": {
        "oui_hex": "8C-1C-DA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0007A8": {
        "oui_hex": "00-07-A8",
        "organization": "Haier Group Technologies Ltd",
        "address_1": "No. 1 Haier Road, Hi-tech Zone",
        "address_2": "00000    00000",
        "country": "CN"
    },
    "9814D2": {
        "oui_hex": "98-14-D2",
        "organization": "Avonic",
        "address_1": "Distributieweg 60",
        "address_2": "Delfgauw    2645EJ",
        "country": "NL"
    },
    "1409DC": {
        "oui_hex": "14-09-DC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC9365": {
        "oui_hex": "EC-93-65",
        "organization": "Mapper.ai, Inc.",
        "address_1": "400 Treat Ave, Suite G",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "C4BAA3": {
        "oui_hex": "C4-BA-A3",
        "organization": "Beijing Winicssec Technologies Co., Ltd.",
        "address_1": "F block 9th floor 907 of Jiahua Building, No.9 Shangdi 3rd Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "9CFEA1": {
        "oui_hex": "9C-FE-A1",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D88A3B": {
        "oui_hex": "D8-8A-3B",
        "organization": "UNIT-EM",
        "address_1": "167 Merchants Street",
        "address_2": "Valletta    VLT 1174",
        "country": "MT"
    },
    "EC5A86": {
        "oui_hex": "EC-5A-86",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "Road NO2, West of Industrial Park,North of Science & Technology Park",
        "address_2": "Dongguan  Guangdong  518057",
        "country": "CN"
    },
    "C0EEB5": {
        "oui_hex": "C0-EE-B5",
        "organization": "Enice Network.",
        "address_1": "NO.30, Shuige Rd, JiangNing Economic Development Zone, Nanjing",
        "address_2": "Nanjing    211106",
        "country": "CN"
    },
    "60DEF3": {
        "oui_hex": "60-DE-F3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "50A009": {
        "oui_hex": "50-A0-09",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "88964E": {
        "oui_hex": "88-96-4E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "883F4A": {
        "oui_hex": "88-3F-4A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "9CA615": {
        "oui_hex": "9C-A6-15",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E44E76": {
        "oui_hex": "E4-4E-76",
        "organization": "CHAMPIONTECH  ENTERPRISE (SHENZHEN) INC",
        "address_1": "Against Office of Dong-Zhou Residential Committee Guang Ming",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "004098": {
        "oui_hex": "00-40-98",
        "organization": "DRESSLER GMBH & CO.",
        "address_1": "KACKERTSTRASSE 10",
        "address_2": "",
        "country": "DE"
    },
    "001DFA": {
        "oui_hex": "00-1D-FA",
        "organization": "Fujian LANDI Commercial Equipment Co.,Ltd",
        "address_1": "Building 17,the 1st Section ,Fuzhou Software Park",
        "address_2": "No.89 Software Road   Fuzhou ,Fujian  350003",
        "country": "CN"
    },
    "9CE65E": {
        "oui_hex": "9C-E6-5E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C49880": {
        "oui_hex": "C4-98-80",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0338E": {
        "oui_hex": "E0-33-8E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "08F69C": {
        "oui_hex": "08-F6-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04FA83": {
        "oui_hex": "04-FA-83",
        "organization": "Qingdao Haier Technology Co.,Ltd",
        "address_1": "Building A01,Haier Information Park, No.1 Haier Road,",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "78F9B4": {
        "oui_hex": "78-F9-B4",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "D076E7": {
        "oui_hex": "D0-76-E7",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "50A67F": {
        "oui_hex": "50-A6-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D461DA": {
        "oui_hex": "D4-61-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F01898": {
        "oui_hex": "F0-18-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "881908": {
        "oui_hex": "88-19-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C0947": {
        "oui_hex": "5C-09-47",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "14205E": {
        "oui_hex": "14-20-5E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B841A4": {
        "oui_hex": "B8-41-A4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00165C": {
        "oui_hex": "00-16-5C",
        "organization": "Trackflow Ltd.",
        "address_1": "167-169 Kensington High Street",
        "address_2": "London  England  W86SH",
        "country": "GB"
    },
    "641CAE": {
        "oui_hex": "64-1C-AE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "F8E44E": {
        "oui_hex": "F8-E4-4E",
        "organization": "MCOT INC.",
        "address_1": "Yogohigashi 1-5-12",
        "address_2": "Matsuyama  Ehime  790-0044",
        "country": "JP"
    },
    "40CD7A": {
        "oui_hex": "40-CD-7A",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "DC4EF4": {
        "oui_hex": "DC-4E-F4",
        "organization": "Shenzhen MTN Electronics CO., Ltd",
        "address_1": "MTN Industrial Park, No. 5, 9 South Futai Road, Pingxi Community, Pingdi Street, Longgang District",
        "address_2": "Shenzhen  Guangdong  518117",
        "country": "CN"
    },
    "F08173": {
        "oui_hex": "F0-81-73",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno    89507",
        "country": "US"
    },
    "EC65CC": {
        "oui_hex": "EC-65-CC",
        "organization": "Panasonic Automotive Systems Company of America",
        "address_1": "776 Highway 74 South",
        "address_2": "Peachtree City  null  30269",
        "country": "US"
    },
    "949990": {
        "oui_hex": "94-99-90",
        "organization": "VTC Telecommunications",
        "address_1": "750 (3rd Floor) Dien Bien Phu, District 10",
        "address_2": "Ho Chi Minh  Ho Chi Minh  70000",
        "country": "VN"
    },
    "F4BC97": {
        "oui_hex": "F4-BC-97",
        "organization": "Shenzhen Crave Communication Co., LTD",
        "address_1": "F3,8Building, DongFangMing IndustryZone, No.83 DabaoRD., 33 District BaoAn",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "28FEDE": {
        "oui_hex": "28-FE-DE",
        "organization": "COMESTA, Inc.",
        "address_1": "Techno1-ro 61-7, Yuseong-gu,",
        "address_2": "Daejeon    34014",
        "country": "KR"
    },
    "907910": {
        "oui_hex": "90-79-10",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "003DE8": {
        "oui_hex": "00-3D-E8",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "68FEDA": {
        "oui_hex": "68-FE-DA",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E8986D": {
        "oui_hex": "E8-98-6D",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "144E34": {
        "oui_hex": "14-4E-34",
        "organization": "Remote Solution",
        "address_1": "92, Chogokri, Nammyun",
        "address_2": "Kimcheon city  Kyungbuk  740-871",
        "country": "KR"
    },
    "00508B": {
        "oui_hex": "00-50-8B",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "146B9C": {
        "oui_hex": "14-6B-9C",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "948DEF": {
        "oui_hex": "94-8D-EF",
        "organization": "Oetiker Schweiz AG",
        "address_1": "Spätzstrasse 11",
        "address_2": "Horgen    8810",
        "country": "CH"
    },
    "2CD974": {
        "oui_hex": "2C-D9-74",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "D4F786": {
        "oui_hex": "D4-F7-86",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "3403DE": {
        "oui_hex": "34-03-DE",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "240A63": {
        "oui_hex": "24-0A-63",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F88B37": {
        "oui_hex": "F8-8B-37",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "20677C": {
        "oui_hex": "20-67-7C",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "34D712": {
        "oui_hex": "34-D7-12",
        "organization": "Smartisan Digital Co., Ltd",
        "address_1": "4F, China Digital Kingdom, No.1 Wangjing North Road, Chaoyang District",
        "address_2": "Beijing  Beijing  100012",
        "country": "CN"
    },
    "A06610": {
        "oui_hex": "A0-66-10",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "44FFBA": {
        "oui_hex": "44-FF-BA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E0E62E": {
        "oui_hex": "E0-E6-2E",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "387862": {
        "oui_hex": "38-78-62",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "E42D7B": {
        "oui_hex": "E4-2D-7B",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "C464E3": {
        "oui_hex": "C4-64-E3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "8817A3": {
        "oui_hex": "88-17-A3",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "88A9A7": {
        "oui_hex": "88-A9-A7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "EC8914": {
        "oui_hex": "EC-89-14",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B89436": {
        "oui_hex": "B8-94-36",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "501479": {
        "oui_hex": "50-14-79",
        "organization": "iRobot Corporation",
        "address_1": "8 Crosby Drive",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "6084BD": {
        "oui_hex": "60-84-BD",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "347ECA": {
        "oui_hex": "34-7E-CA",
        "organization": "NEXTWILL",
        "address_1": "JJ-Building, 20, Deongmyeong-ro 71beon-gil1, Yuseong-gu",
        "address_2": "Daejeon    34155",
        "country": "KR"
    },
    "B42EF8": {
        "oui_hex": "B4-2E-F8",
        "organization": "Eline Technology co.Ltd",
        "address_1": "kangcheng Road, Pharmaceutical Industrical Park, Yuanzhou District",
        "address_2": "Yichun  Jiangxi  336000",
        "country": "CN"
    },
    "A4D4B2": {
        "oui_hex": "A4-D4-B2",
        "organization": "Shenzhen MeiG Smart Technology Co.,Ltd",
        "address_1": "#88 Qinjiang Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "8CF773": {
        "oui_hex": "8C-F7-73",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "DCDD24": {
        "oui_hex": "DC-DD-24",
        "organization": "Energica Motor Company SpA",
        "address_1": "Via Cesare della Chiesa, 150",
        "address_2": "MODENA (MO)  Mo  41126",
        "country": "IT"
    },
    "641CB0": {
        "oui_hex": "64-1C-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "903A72": {
        "oui_hex": "90-3A-72",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "CC3B58": {
        "oui_hex": "CC-3B-58",
        "organization": "Curiouser Products Inc",
        "address_1": "712 Broadway #4",
        "address_2": "New York  NY  10003",
        "country": "US"
    },
    "4CEFC0": {
        "oui_hex": "4C-EF-C0",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "8C5973": {
        "oui_hex": "8C-59-73",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "24181D": {
        "oui_hex": "24-18-1D",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "58D759": {
        "oui_hex": "58-D7-59",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F89066": {
        "oui_hex": "F8-90-66",
        "organization": "Nain Inc.",
        "address_1": "Aoyamadai building 902, Shibuya 2-9-10, Shibuya-ku",
        "address_2": "Tokyo    150-0002",
        "country": "JP"
    },
    "7006AC": {
        "oui_hex": "70-06-AC",
        "organization": "Eastcompeace Technology Co., Ltd",
        "address_1": "Number 8 Pinggong Zhong Road,Nanping S&T Industry Community,Zhuhai,Guangdong,519060 China",
        "address_2": "Zhuhai  Guangdong  519060",
        "country": "CN"
    },
    "2802D8": {
        "oui_hex": "28-02-D8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DCE533": {
        "oui_hex": "DC-E5-33",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D8445C": {
        "oui_hex": "D8-44-5C",
        "organization": "DEV Tecnologia Ind Com Man Eq LTDA",
        "address_1": "Av Prof Lineu Prestes 2242 SL 23",
        "address_2": "Sao Paulo  SP  05508000",
        "country": "BR"
    },
    "509551": {
        "oui_hex": "50-95-51",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "804126": {
        "oui_hex": "80-41-26",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ACF970": {
        "oui_hex": "AC-F9-70",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C3953": {
        "oui_hex": "7C-39-53",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "38E1AA": {
        "oui_hex": "38-E1-AA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "48C796": {
        "oui_hex": "48-C7-96",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F4C248": {
        "oui_hex": "F4-C2-48",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F47190": {
        "oui_hex": "F4-71-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C4FFBC": {
        "oui_hex": "C4-FF-BC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0C2369": {
        "oui_hex": "0C-23-69",
        "organization": "Honeywell SPS",
        "address_1": "700 Visions Dr.",
        "address_2": "Skaneateles Falls  NY  13153",
        "country": "US"
    },
    "04C9D9": {
        "oui_hex": "04-C9-D9",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "7055F8": {
        "oui_hex": "70-55-F8",
        "organization": "Cerebras Systems Inc",
        "address_1": "175 S San Antonio Rd #100",
        "address_2": "Los Altos  CA  94022",
        "country": "US"
    },
    "6C54CD": {
        "oui_hex": "6C-54-CD",
        "organization": "LAMPEX ELECTRONICS LIMITED",
        "address_1": "6-2/231/B, Kukatpally,",
        "address_2": "Hyderabad  Telangana  500072",
        "country": "IN"
    },
    "000889": {
        "oui_hex": "00-08-89",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "F0B5B7": {
        "oui_hex": "F0-B5-B7",
        "organization": "Disruptive Technologies Research AS",
        "address_1": "Ytrebygdsvegen 215",
        "address_2": "Blomsterdalen  Hordaland  5258",
        "country": "NO"
    },
    "B4DEDF": {
        "oui_hex": "B4-DE-DF",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "283B82": {
        "oui_hex": "28-3B-82",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "D4909C": {
        "oui_hex": "D4-90-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E4E0A6": {
        "oui_hex": "E4-E0-A6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "580454": {
        "oui_hex": "58-04-54",
        "organization": "ICOMM HK LIMITED",
        "address_1": "SUITES 2302-6, 23/F GREAT EAGLE CTR 23 HARBOUR RD",
        "address_2": "WANCHAI    NA",
        "country": "HK"
    },
    "3C9A77": {
        "oui_hex": "3C-9A-77",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "C477AF": {
        "oui_hex": "C4-77-AF",
        "organization": "Advanced Digital Broadcast SA",
        "address_1": "Route de Crassier 21, B2",
        "address_2": "Eysins    CH-1262",
        "country": "CH"
    },
    "94290C": {
        "oui_hex": "94-29-0C",
        "organization": "Shenyang wisdom Foundation Technology Development Co., Ltd.",
        "address_1": "No. 262 North Main Street, Huanggu District, the Yellow River",
        "address_2": "shenyang    110000",
        "country": "CN"
    },
    "9C32CE": {
        "oui_hex": "9C-32-CE",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "20E09C": {
        "oui_hex": "20-E0-9C",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "2CFDA1": {
        "oui_hex": "2C-FD-A1",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "3807D4": {
        "oui_hex": "38-07-D4",
        "organization": "Zeppelin Systems GmbH",
        "address_1": "Messenhäuser Str. 37-45",
        "address_2": "Rödermark  Hessen  63322",
        "country": "DE"
    },
    "04197F": {
        "oui_hex": "04-19-7F",
        "organization": "Grasphere Japan",
        "address_1": "3-1-11 NNT build.",
        "address_2": "Tokyo    1030013",
        "country": "JP"
    },
    "5C0038": {
        "oui_hex": "5C-00-38",
        "organization": "Viasat Group S.p.A.",
        "address_1": "Via Aosta 23",
        "address_2": "Venaria Reale   Torino  10078",
        "country": "IT"
    },
    "8CEC4B": {
        "oui_hex": "8C-EC-4B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "005091": {
        "oui_hex": "00-50-91",
        "organization": "NETACCESS, INC.",
        "address_1": "18 KEEWAYDIN DRIVE",
        "address_2": "SALEM  NH  03079",
        "country": "US"
    },
    "B85001": {
        "oui_hex": "B8-50-01",
        "organization": "Extreme Networks, Inc.",
        "address_1": "ONE ZEBRA PLAZA",
        "address_2": "HOLTSVILLE  NY  11742",
        "country": "US"
    },
    "802BF9": {
        "oui_hex": "80-2B-F9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "54B802": {
        "oui_hex": "54-B8-02",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "10CEA9": {
        "oui_hex": "10-CE-A9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "805E0C": {
        "oui_hex": "80-5E-0C",
        "organization": "YEALINK(XIAMEN) NETWORK TECHNOLOGY CO.,LTD.",
        "address_1": "309, 3th Floor, No.16, Yun Ding North Road, Huli District",
        "address_2": "xiamen  Fujian  361015",
        "country": "CN"
    },
    "6C49C1": {
        "oui_hex": "6C-49-C1",
        "organization": "o2ones Co., Ltd.",
        "address_1": "503 Glory Tower, 3-10, Gumi-ro 9beon-gil, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13637",
        "country": "KR"
    },
    "70EEA3": {
        "oui_hex": "70-EE-A3",
        "organization": "Eoptolink Technology Inc. Ltd,",
        "address_1": "No.127 West Wulian Street",
        "address_2": "Chengdu  China/Sichuan  610213",
        "country": "CN"
    },
    "7047E9": {
        "oui_hex": "70-47-E9",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "5C521E": {
        "oui_hex": "5C-52-1E",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "14444A": {
        "oui_hex": "14-44-4A",
        "organization": "Apollo Seiko Ltd.",
        "address_1": "2271-7 Jinba",
        "address_2": "Gotenba  Shizuoka  412-0047",
        "country": "JP"
    },
    "3C2C99": {
        "oui_hex": "3C-2C-99",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "88D039": {
        "oui_hex": "88-D0-39",
        "organization": "TCL Technoly Electronics(Huizhou).,Ltd",
        "address_1": "Section 37, Zhongkai Hi-Tech Development Zone",
        "address_2": "Huizhou  Guangdong  516006",
        "country": "CN"
    },
    "683E02": {
        "oui_hex": "68-3E-02",
        "organization": "SIEMENS AG, Digital Factory, Motion Control System",
        "address_1": "Varey Road",
        "address_2": "Congleton  Cheshire  CW12 1PH",
        "country": "GB"
    },
    "000261": {
        "oui_hex": "00-02-61",
        "organization": "Tilgin AB",
        "address_1": "Finlandsgatan 40",
        "address_2": "kista    12345",
        "country": "SE"
    },
    "0014C3": {
        "oui_hex": "00-14-C3",
        "organization": "Seagate Technology",
        "address_1": "M/S NW1F01",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "0004CF": {
        "oui_hex": "00-04-CF",
        "organization": "Seagate Technology",
        "address_1": "M/S NW1F01",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "002037": {
        "oui_hex": "00-20-37",
        "organization": "Seagate Technology",
        "address_1": "8001 E. BLOOMINGTON FWY",
        "address_2": "BLOOMINGTON  MN  55420",
        "country": "US"
    },
    "5C81A7": {
        "oui_hex": "5C-81-A7",
        "organization": "Network Devices Pty Ltd",
        "address_1": "16 Dickson Ave",
        "address_2": "Artarmon  NSW  2064",
        "country": "AU"
    },
    "5C0C0E": {
        "oui_hex": "5C-0C-0E",
        "organization": "Guizhou Huaxintong Semiconductor Technology Co Ltd",
        "address_1": "Sitelin Park",
        "address_2": "Intersection between Jin ma Ave and Qianzhong Ave  Gui An New Area, Guizhou Prov  550003",
        "country": "CN"
    },
    "503CEA": {
        "oui_hex": "50-3C-EA",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D096FB": {
        "oui_hex": "D0-96-FB",
        "organization": "DASAN Network Solutions",
        "address_1": "DASAN Tower 8F, 49 Daewangpangyo-ro644beon-gil Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13493",
        "country": "KR"
    },
    "00E091": {
        "oui_hex": "00-E0-91",
        "organization": "LG Electronics",
        "address_1": "16, Woomyeon-dong, Seocho-gu",
        "address_2": "Seoul    137-724",
        "country": "KR"
    },
    "38437D": {
        "oui_hex": "38-43-7D",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "506F98": {
        "oui_hex": "50-6F-98",
        "organization": "Sehaj Synergy Technologies Private Limited",
        "address_1": "E-112A, Kataria Colony, Ramanagar Extension, New Sanganer Road, Sodala, Jaipur-302019",
        "address_2": "Jaipur  Rajasthan  302019",
        "country": "IN"
    },
    "4CAE1C": {
        "oui_hex": "4C-AE-1C",
        "organization": "SaiNXT Technologies LLP",
        "address_1": "Shop No. 7, Sonawala Building, 1st Floor, Proctor Road, Grant Road (E)",
        "address_2": "Mumbai  Maharashtra  400007",
        "country": "IN"
    },
    "142882": {
        "oui_hex": "14-28-82",
        "organization": "MIDICOM ELECTRONICS CO.LTD",
        "address_1": "Bucheon Techno Park 303-404,345",
        "address_2": "Seokcheon-ro,Bucheon-si  Gyeonggi-do   1501",
        "country": "KR"
    },
    "EC8193": {
        "oui_hex": "EC-81-93",
        "organization": "Logitech, Inc",
        "address_1": "4700 NW Camas Meadows Drive",
        "address_2": "Camas  WA  98607",
        "country": "US"
    },
    "6CDD30": {
        "oui_hex": "6C-DD-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6C4E86": {
        "oui_hex": "6C-4E-86",
        "organization": "Third Millennium Systems Ltd.",
        "address_1": "18/19 Torfaen Business Centre, Panteg Way",
        "address_2": "New Inn, Pontypool  Torfaen  NP4 0LS",
        "country": "GB"
    },
    "5C86C1": {
        "oui_hex": "5C-86-C1",
        "organization": "DONGGUAN SOLUM ELECTRONICS CO.,LTD",
        "address_1": "NO.157,13 Coastal Way TPFTZ",
        "address_2": "TIANJIN    300461",
        "country": "CN"
    },
    "5C7776": {
        "oui_hex": "5C-77-76",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "70E56E": {
        "oui_hex": "70-E5-6E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "547DCD": {
        "oui_hex": "54-7D-CD",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "00AECD": {
        "oui_hex": "00-AE-CD",
        "organization": "Pensando Systems",
        "address_1": "1730 Technology Drive, Suite 202",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "FC9DD8": {
        "oui_hex": "FC-9D-D8",
        "organization": "Beijing TongTongYiLian Science and Technology Ltd.",
        "address_1": " Room 301,Zone 3,Building 9,No.8 Dongbeiwang West Road,Haidian District,Beijing",
        "address_2": "BEIJING  BEIJING  100193",
        "country": "CN"
    },
    "DC2834": {
        "oui_hex": "DC-28-34",
        "organization": "HAKKO Corporation",
        "address_1": "4-5, Shiokusa 2-chome, Naniwaku",
        "address_2": "Osaka  Osaka  556-0024",
        "country": "JP"
    },
    "84509A": {
        "oui_hex": "84-50-9A",
        "organization": "Easy Soft TV Co., Ltd",
        "address_1": "#1613, Heungduk U-Tower, Heungduk Jung ang-ro 120",
        "address_2": "Yongin-si  Gyeounggi-do  16950",
        "country": "KR"
    },
    "001730": {
        "oui_hex": "00-17-30",
        "organization": "Automation Electronics",
        "address_1": "111 Big Horn Rd.",
        "address_2": "Casper  Wy  82601",
        "country": "US"
    },
    "30E48E": {
        "oui_hex": "30-E4-8E",
        "organization": "Vodafone UK",
        "address_1": "Vodafone House",
        "address_2": "Newbury   Berkshire   RG142FN",
        "country": "GB"
    },
    "449160": {
        "oui_hex": "44-91-60",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "B4F1DA": {
        "oui_hex": "B4-F1-DA",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "C863F1": {
        "oui_hex": "C8-63-F1",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "DCE1AD": {
        "oui_hex": "DC-E1-AD",
        "organization": "Shenzhen Wintop Photoelectric Technology Co., Ltd",
        "address_1": "6th Floor, 1st Building, Zone 3, South Area, Zhongguan& Honghualing Industrial Zone, No. 1213, Liuxian Avenue, Taoyuan Street, Nanshan District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "948854": {
        "oui_hex": "94-88-54",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001D0D": {
        "oui_hex": "00-1D-0D",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "B0FC36": {
        "oui_hex": "B0-FC-36",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "001DF4": {
        "oui_hex": "00-1D-F4",
        "organization": "Magellan Technology Pty Limited",
        "address_1": "65 Johnston Street",
        "address_2": "Annandale  NSW  2000",
        "country": "AU"
    },
    "6C05D5": {
        "oui_hex": "6C-05-D5",
        "organization": "Ethertronics Inc",
        "address_1": "5501 Oberlin Drive, Suite 100",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "0019C2": {
        "oui_hex": "00-19-C2",
        "organization": "Equustek Solutions, Inc.",
        "address_1": "#286 - 5489 Byrne Road,",
        "address_2": "Burnaby  BC  V5J 3J1",
        "country": "CA"
    },
    "ECB0E1": {
        "oui_hex": "EC-B0-E1",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "78DDD9": {
        "oui_hex": "78-DD-D9",
        "organization": "Guangzhou Shiyuan Electronics Co., Ltd.",
        "address_1": "No.6, 4th Yunpu Road, Yunpu Industry District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "F8B7E2": {
        "oui_hex": "F8-B7-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F82055": {
        "oui_hex": "F8-20-55",
        "organization": "Green Information System",
        "address_1": "#202(Shopping center), Woldong-ro 28, Buk-gu",
        "address_2": "Gwangju    61153",
        "country": "KR"
    },
    "74E19A": {
        "oui_hex": "74-E1-9A",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "000097": {
        "oui_hex": "00-00-97",
        "organization": "Dell EMC",
        "address_1": "176 South Street",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "8CCF09": {
        "oui_hex": "8C-CF-09",
        "organization": "Dell EMC",
        "address_1": "228 South St",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "8C839D": {
        "oui_hex": "8C-83-9D",
        "organization": "SHENZHEN XINYUPENG ELECTRONIC TECHNOLOGY CO., LTD",
        "address_1": "ROOM 1505,BIT INNOVATION BUILDING,SCIENCE AND TECHNOLOGY PARK,NANSHAN DISTRICT",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "B0C19E": {
        "oui_hex": "B0-C1-9E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0C3747": {
        "oui_hex": "0C-37-47",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "ACA667": {
        "oui_hex": "AC-A6-67",
        "organization": "Electronic Systems Protection, Inc.",
        "address_1": "8001 Knightdale Blvd.",
        "address_2": "Knightdale  NC  27545",
        "country": "US"
    },
    "0081F9": {
        "oui_hex": "00-81-F9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "ECB5FA": {
        "oui_hex": "EC-B5-FA",
        "organization": "Philips Lighting BV",
        "address_1": "High Tech Campus 45",
        "address_2": "Eindhoven  Noord Brabant  5656 AE",
        "country": "NL"
    },
    "44CD0E": {
        "oui_hex": "44-CD-0E",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "E8825B": {
        "oui_hex": "E8-82-5B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "70991C": {
        "oui_hex": "70-99-1C",
        "organization": "Shenzhen Honesty Electronics Co.,Ltd",
        "address_1": "5/F,Zone B,Chitat Industrial Park,West Longping Road",
        "address_2": "Shenzhen City  Longgang District, Guangdong  518172",
        "country": "CN"
    },
    "80B03D": {
        "oui_hex": "80-B0-3D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E49ADC": {
        "oui_hex": "E4-9A-DC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "ACE4B5": {
        "oui_hex": "AC-E4-B5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0D2B0": {
        "oui_hex": "D0-D2-B0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001CAE": {
        "oui_hex": "00-1C-AE",
        "organization": "WiChorus, Inc.",
        "address_1": "3590 N 1st Street, Suite 300",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7CDD76": {
        "oui_hex": "7C-DD-76",
        "organization": "Suzhou Hanming Technologies Co., Ltd.",
        "address_1": "Suite 407, No. 166, Ren Ai Road",
        "address_2": "Suzhou  Jiangsu  215123",
        "country": "CN"
    },
    "246880": {
        "oui_hex": "24-68-80",
        "organization": "Braveridge.co.,ltd.",
        "address_1": "3-27-2, Susenji",
        "address_2": "Nishi-ku, Fukuoka-shi  Fukuoka  819-0373",
        "country": "JP"
    },
    "F092B4": {
        "oui_hex": "F0-92-B4",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "E8DF70": {
        "oui_hex": "E8-DF-70",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "28AD3E": {
        "oui_hex": "28-AD-3E",
        "organization": "Shenzhen TONG BO WEI Technology CO.,LTD",
        "address_1": "Longhua District, Dalang street Langkou community Huarong Road Peng Tengda Industrial Park 4 5 floor",
        "address_2": "SHENZHEN  guangdong  518109",
        "country": "CN"
    },
    "001C56": {
        "oui_hex": "00-1C-56",
        "organization": "Pado Systems, Inc.",
        "address_1": "#706 Loadland EZ Tower 153",
        "address_2": "SungNam  Gyung gi-Do  463-810",
        "country": "KR"
    },
    "F06D78": {
        "oui_hex": "F0-6D-78",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "7844FD": {
        "oui_hex": "78-44-FD",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "ECF8EB": {
        "oui_hex": "EC-F8-EB",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "707D95": {
        "oui_hex": "70-7D-95",
        "organization": "Shenzhen City LinwlanTechnology Co. Ltd.",
        "address_1": "106 village road , manhole street Baoan district .",
        "address_2": "Shenzhen  Guangdong  518125",
        "country": "CN"
    },
    "2C431A": {
        "oui_hex": "2C-43-1A",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "A8D3C8": {
        "oui_hex": "A8-D3-C8",
        "organization": "Topcon Electronics GmbH & Co. KG",
        "address_1": "Industriestraße 7",
        "address_2": "Geisenheim    65366",
        "country": "DE"
    },
    "D05995": {
        "oui_hex": "D0-59-95",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "18CC88": {
        "oui_hex": "18-CC-88",
        "organization": "Hitachi Johnson Controls Air",
        "address_1": "390 Number",
        "address_2": " Shimizu Village Village  Shizuoka Prefecture  424-0926",
        "country": "JP"
    },
    "80C755": {
        "oui_hex": "80-C7-55",
        "organization": "Panasonic Appliances Company",
        "address_1": "2-3-1-2 Noji-higashi",
        "address_2": "Kusatsu City  Shiga  525-8555",
        "country": "JP"
    },
    "F0BD2E": {
        "oui_hex": "F0-BD-2E",
        "organization": "H+S Polatis Ltd",
        "address_1": "332/2 Cambridge Science Park",
        "address_2": "Cambridge    CB4 0WN",
        "country": "GB"
    },
    "746EE4": {
        "oui_hex": "74-6E-E4",
        "organization": "Asia Vital Components Co.,Ltd.",
        "address_1": "Rm. 3, 7F., No.24, Wuquan 2nd Rd., Xinzhuang Dist.,",
        "address_2": " New Taipei   Taiwan  24892",
        "country": "TW"
    },
    "0040E4": {
        "oui_hex": "00-40-E4",
        "organization": "E-M TECHNOLOGY, INC.",
        "address_1": "9245 SOUTHWEST NIMBUS AVE.",
        "address_2": "BEAVERTON  OR  97005",
        "country": "US"
    },
    "984B4A": {
        "oui_hex": "98-4B-4A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E084F3": {
        "oui_hex": "E0-84-F3",
        "organization": "High Grade Controls Corporation",
        "address_1": "87 Magill Street",
        "address_2": "Sudbury  Ontario  P3Y1K6",
        "country": "CA"
    },
    "38A6CE": {
        "oui_hex": "38-A6-CE",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "3456FE": {
        "oui_hex": "34-56-FE",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "70708B": {
        "oui_hex": "70-70-8B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "389F5A": {
        "oui_hex": "38-9F-5A",
        "organization": "C-Kur TV Inc.",
        "address_1": "A-1902, 583, Yangcheon-ro, Gangseo-gu",
        "address_2": "Seoul    07547",
        "country": "KR"
    },
    "D843ED": {
        "oui_hex": "D8-43-ED",
        "organization": "Suzuken",
        "address_1": "8, Higashikatahamachi, Higashiku",
        "address_2": "Nagoya  Aich  4610015",
        "country": "JP"
    },
    "BC4101": {
        "oui_hex": "BC-41-01",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "043A0D": {
        "oui_hex": "04-3A-0D",
        "organization": "SM Optics S.r.l.",
        "address_1": "via Michelangelo Buonarroti, 1",
        "address_2": "Cologno Monzese  Milan  I-20093",
        "country": "IT"
    },
    "448F17": {
        "oui_hex": "44-8F-17",
        "organization": "Samsung Electronics Co., Ltd. ARTIK",
        "address_1": "1-1, Samsungjeonja-ro",
        "address_2": "Hwaseong-si  Gyeonggi-do  18448",
        "country": "KR"
    },
    "00FC8B": {
        "oui_hex": "00-FC-8B",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0076B1": {
        "oui_hex": "00-76-B1",
        "organization": "Somfy-Protect By Myfox SAS",
        "address_1": "Regent Park II, Bât I, 2460 l'Occitane",
        "address_2": "Labège    31670",
        "country": "FR"
    },
    "6CC147": {
        "oui_hex": "6C-C1-47",
        "organization": "Xiamen Hanin Electronic Technology Co., Ltd",
        "address_1": "#8 building, Gaoqi Nan Shi'er Road, Huli Distric",
        "address_2": "Xiamen  Fujian  361000",
        "country": "CN"
    },
    "A072E4": {
        "oui_hex": "A0-72-E4",
        "organization": "NJ SYSTEM CO.,LTD",
        "address_1": "Urim lions valley 5cha, A-1701, 144-3, Sangdaewon-dong, Jungwon-gu",
        "address_2": "Seongnam  Gyeonggido  13201",
        "country": "KR"
    },
    "4C1365": {
        "oui_hex": "4C-13-65",
        "organization": "Emplus Technologies",
        "address_1": "Bld B, 10F, No.209, Sec.1, Nangang Rd",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "CCF957": {
        "oui_hex": "CC-F9-57",
        "organization": "u-blox AG",
        "address_1": "Zuercherstrasse 68",
        "address_2": "Thalwil    8800",
        "country": "CH"
    },
    "0C62A6": {
        "oui_hex": "0C-62-A6",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "18132D": {
        "oui_hex": "18-13-2D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "74D21D": {
        "oui_hex": "74-D2-1D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1878D4": {
        "oui_hex": "18-78-D4",
        "organization": "Verizon",
        "address_1": "One Verizon Way",
        "address_2": "Basking Ridge  NJ  07920",
        "country": "US"
    },
    "B8D94D": {
        "oui_hex": "B8-D9-4D",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "3890A5": {
        "oui_hex": "38-90-A5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C0742B": {
        "oui_hex": "C0-74-2B",
        "organization": "SHENZHEN XUNLONG SOFTWARE CO.,LIMITED",
        "address_1": "Room 532, Block A, Huameiju Business Center, Xinhu Road, Baoan 82 Area",
        "address_2": "Shenzhen  Guangdong  518133",
        "country": "CN"
    },
    "5C6776": {
        "oui_hex": "5C-67-76",
        "organization": "IDS Imaging Development Systems GmbH",
        "address_1": "Dimbacher Str. 6",
        "address_2": "Obersulm  BW  74182",
        "country": "DE"
    },
    "44EAD8": {
        "oui_hex": "44-EA-D8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "189BA5": {
        "oui_hex": "18-9B-A5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A491B1": {
        "oui_hex": "A4-91-B1",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "1C7022": {
        "oui_hex": "1C-70-22",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "CC9891": {
        "oui_hex": "CC-98-91",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "28BF89": {
        "oui_hex": "28-BF-89",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "903DBD": {
        "oui_hex": "90-3D-BD",
        "organization": "SECURE METERS LIMITED",
        "address_1": "E CLASS, PRATAP NAGAR INDUSTRIAL AREA",
        "address_2": "UDAIPUR  RAJASTHAN  313003",
        "country": "IN"
    },
    "002294": {
        "oui_hex": "00-22-94",
        "organization": "KYOCERA CORPORATION",
        "address_1": "2-1-1,Kagahara",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "3889DC": {
        "oui_hex": "38-89-DC",
        "organization": "Opticon Sensors Europe B.V.",
        "address_1": "Opaallaan 35",
        "address_2": "Hoofddorp  Noord Holland  2132 XV",
        "country": "NL"
    },
    "8C4500": {
        "oui_hex": "8C-45-00",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "1CDDEA": {
        "oui_hex": "1C-DD-EA",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "940006": {
        "oui_hex": "94-00-06",
        "organization": "jinyoung",
        "address_1": "1000 Dongil-ro Nowon-gu Seoul",
        "address_2": "Seoul    01849",
        "country": "KR"
    },
    "20040F": {
        "oui_hex": "20-04-0F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "A43412": {
        "oui_hex": "A4-34-12",
        "organization": "Thales Alenia Space",
        "address_1": "26 av JF Champollion",
        "address_2": "Toulouse    31037",
        "country": "FR"
    },
    "8C8590": {
        "oui_hex": "8C-85-90",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC88C3": {
        "oui_hex": "BC-88-C3",
        "organization": "Ningbo Dooya Mechanic & Electronic Technology Co., Ltd",
        "address_1": "No.168 Shengguang road Luotuo street Zhenhai district",
        "address_2": "Ningbo  Zhejiang  315202",
        "country": "CN"
    },
    "38CD07": {
        "oui_hex": "38-CD-07",
        "organization": "Beijing FaceCam Technology Co., Ltd.",
        "address_1": "Room C115, DongSheng Building, No 8, East Road, Zhongguan Town, Haidian District",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "00D060": {
        "oui_hex": "00-D0-60",
        "organization": "Panasonic Europe Ltd.",
        "address_1": "LABORATORIES GMBH",
        "address_2": "",
        "country": "DE"
    },
    "ECFA03": {
        "oui_hex": "EC-FA-03",
        "organization": "FCA",
        "address_1": "800 Chrylser Dr",
        "address_2": "Auburn Hills  MI  48326",
        "country": "US"
    },
    "6C96CF": {
        "oui_hex": "6C-96-CF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "681F40": {
        "oui_hex": "68-1F-40",
        "organization": "Blu Wireless Technology Ltd",
        "address_1": "Bluwireless Technology, 5th Floor, 1 Temple Way",
        "address_2": "Bristol  Bristol, City of  BS2 0BY",
        "country": "GB"
    },
    "90ADF7": {
        "oui_hex": "90-AD-F7",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "40CE24": {
        "oui_hex": "40-CE-24",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3432E6": {
        "oui_hex": "34-32-E6",
        "organization": "Panasonic Industrial Devices Europe GmbH",
        "address_1": "Zeppelinstraße 19",
        "address_2": "Lüneburg    21337",
        "country": "DE"
    },
    "40017A": {
        "oui_hex": "40-01-7A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "78886D": {
        "oui_hex": "78-88-6D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "20EE28": {
        "oui_hex": "20-EE-28",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B4F61C": {
        "oui_hex": "B4-F6-1C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "08F4AB": {
        "oui_hex": "08-F4-AB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FC017C": {
        "oui_hex": "FC-01-7C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "90324B": {
        "oui_hex": "90-32-4B",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "602E20": {
        "oui_hex": "60-2E-20",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E472E2": {
        "oui_hex": "E4-72-E2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00127D": {
        "oui_hex": "00-12-7D",
        "organization": "MobileAria",
        "address_1": "800 W El Camino Real #240",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "F86465": {
        "oui_hex": "F8-64-65",
        "organization": "Anova Applied Electronics, Inc.",
        "address_1": "580 Howard Street, #403",
        "address_2": "san francisco  CA  94105",
        "country": "US"
    },
    "002060": {
        "oui_hex": "00-20-60",
        "organization": "ALCATEL ITALIA S.p.A.",
        "address_1": "VIA TRENTO, 30",
        "address_2": "20059 VIMERCATE (MI)",
        "country": "IT"
    },
    "508F4C": {
        "oui_hex": "50-8F-4C",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "A47758": {
        "oui_hex": "A4-77-58",
        "organization": "Ningbo Freewings Technologies Co.,Ltd",
        "address_1": "No.502 Wenshui Road, Shounan Street, Yinzhou District",
        "address_2": "Ningbo  Zhejiang  315192",
        "country": "CN"
    },
    "58A0CB": {
        "oui_hex": "58-A0-CB",
        "organization": "TrackNet, Inc",
        "address_1": "900 Lafayette Street #329",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "000CEC": {
        "oui_hex": "00-0C-EC",
        "organization": "Spectracom Corp.",
        "address_1": "95 Methodist Hill Drive",
        "address_2": "Rochester  NY  14623",
        "country": "US"
    },
    "E06089": {
        "oui_hex": "E0-60-89",
        "organization": "Cloudleaf, Inc.",
        "address_1": "860 Hillview Court, Suite 350",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "783690": {
        "oui_hex": "78-36-90",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "Road NO2, West of Industrial Park,North of Science & Technology Park",
        "address_2": "Dongguan  Guangdong  518057",
        "country": "CN"
    },
    "BC54FC": {
        "oui_hex": "BC-54-FC",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0C4B54": {
        "oui_hex": "0C-4B-54",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E4F004": {
        "oui_hex": "E4-F0-04",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "94E36D": {
        "oui_hex": "94-E3-6D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F0F8F2": {
        "oui_hex": "F0-F8-F2",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "341513": {
        "oui_hex": "34-15-13",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "74819A": {
        "oui_hex": "74-81-9A",
        "organization": "PT. Hartono Istana Teknologi",
        "address_1": "KHR Asnawi",
        "address_2": "Kudus  Jawa Tengah  59332",
        "country": "ID"
    },
    "283545": {
        "oui_hex": "28-35-45",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "044F4C": {
        "oui_hex": "04-4F-4C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "18B81F": {
        "oui_hex": "18-B8-1F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1C151F": {
        "oui_hex": "1C-15-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "008BFC": {
        "oui_hex": "00-8B-FC",
        "organization": "mixi,Inc.",
        "address_1": "Sumitomo Shibuya First Tower 7F, 1-2-20 Higashi",
        "address_2": "Shibuya-ku  Tokyo  150-0011",
        "country": "JP"
    },
    "A82BB5": {
        "oui_hex": "A8-2B-B5",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "E8E1E2": {
        "oui_hex": "E8-E1-E2",
        "organization": "Energotest",
        "address_1": "Chorzowska 44B",
        "address_2": "Gliwice  Slask  44-100",
        "country": "PL"
    },
    "7811DC": {
        "oui_hex": "78-11-DC",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "D463C6": {
        "oui_hex": "D4-63-C6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "F844E3": {
        "oui_hex": "F8-44-E3",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "24A534": {
        "oui_hex": "24-A5-34",
        "organization": "SynTrust Tech International Ltd.",
        "address_1": "10F-1, No. 125, Songde Road,",
        "address_2": "Taipei  Taiwan  110",
        "country": "TW"
    },
    "C444A0": {
        "oui_hex": "C4-44-A0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18742E": {
        "oui_hex": "18-74-2E",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno    89507",
        "country": "US"
    },
    "90A365": {
        "oui_hex": "90-A3-65",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "DC44B6": {
        "oui_hex": "DC-44-B6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1007B6": {
        "oui_hex": "10-07-B6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "342D0D": {
        "oui_hex": "34-2D-0D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A44CC8": {
        "oui_hex": "A4-4C-C8",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "D837BE": {
        "oui_hex": "D8-37-BE",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "#1905 Mei Hong Road",
        "address_2": "Shanghai  Shanghai  200000",
        "country": "CN"
    },
    "D4684D": {
        "oui_hex": "D4-68-4D",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "8C0C90": {
        "oui_hex": "8C-0C-90",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "6CAAB3": {
        "oui_hex": "6C-AA-B3",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001392": {
        "oui_hex": "00-13-92",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "085114": {
        "oui_hex": "08-51-14",
        "organization": "QINGDAO TOPSCOMM COMMUNICATION CO., LTD",
        "address_1": "7/F, Building 6, NO.288, Ningxia Road",
        "address_2": "Qingdao   Shandong  266024",
        "country": "CN"
    },
    "D05A00": {
        "oui_hex": "D0-5A-00",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "70788B": {
        "oui_hex": "70-78-8B",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "4859A4": {
        "oui_hex": "48-59-A4",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "54BD79": {
        "oui_hex": "54-BD-79",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "A0423F": {
        "oui_hex": "A0-42-3F",
        "organization": "Tyan Computer Corp",
        "address_1": "3288 Larurelview Court",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "70F11C": {
        "oui_hex": "70-F1-1C",
        "organization": "Shenzhen Ogemray Technology Co.,Ltd",
        "address_1": "4/F,5Bldg,Dongwu Industrial Park, Donghuan 1st Rd, Longhua District.",
        "address_2": "Shenzhen    518059",
        "country": "CN"
    },
    "7065A3": {
        "oui_hex": "70-65-A3",
        "organization": "Kandao lightforge Co., Ltd.",
        "address_1": "5th Floor, M7 Steel Building, the second way in Technology Road , Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "14144B": {
        "oui_hex": "14-14-4B",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "19-22# Building,Star-net Science Plaza,Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "74D0DC": {
        "oui_hex": "74-D0-DC",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 48",
        "address_2": "STOCKHOLM    164 83",
        "country": "SE"
    },
    "C08ADE": {
        "oui_hex": "C0-8A-DE",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001D2E": {
        "oui_hex": "00-1D-2E",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B4E62A": {
        "oui_hex": "B4-E6-2A",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "A0C5F2": {
        "oui_hex": "A0-C5-F2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A86B7C": {
        "oui_hex": "A8-6B-7C",
        "organization": "SHENZHEN FENGLIAN TECHNOLOGY CO., LTD.",
        "address_1": "ORIENTAL CYBERPORT, HIGHTECH 6 ROAD",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "B03956": {
        "oui_hex": "B0-39-56",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3C0CDB": {
        "oui_hex": "3C-0C-DB",
        "organization": "UNIONMAN TECHNOLOGY CO.,LTD",
        "address_1": "18F, HUAYANG TOWER,YANDAYI ROAD",
        "address_2": "Huizhou  Guangdong  516007",
        "country": "CN"
    },
    "EC42B4": {
        "oui_hex": "EC-42-B4",
        "organization": "ADC Corporation",
        "address_1": "77-1, Miyako",
        "address_2": "Namegawa-machi, Hiki-gun  Saitama Pref.  355-0812",
        "country": "JP"
    },
    "60DA83": {
        "oui_hex": "60-DA-83",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "2C5731": {
        "oui_hex": "2C-57-31",
        "organization": " Wingtech Group (HongKong）Limited",
        "address_1": " FLAT/RM 1903 19/F PODIUM PLAZA 5HANOI ROAD TSIM SHA TSUI",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "CC4639": {
        "oui_hex": "CC-46-39",
        "organization": "WAAV, Inc.",
        "address_1": "151 PEARL ST FL 4",
        "address_2": "BOSTON  MA  02110",
        "country": "US"
    },
    "AC9E17": {
        "oui_hex": "AC-9E-17",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "641666": {
        "oui_hex": "64-16-66",
        "organization": "Nest Labs Inc.",
        "address_1": "3400 Hillview Ave.",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "D8DF7A": {
        "oui_hex": "D8-DF-7A",
        "organization": "Quest Software, Inc.",
        "address_1": "4 Polaris Way",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "145BE1": {
        "oui_hex": "14-5B-E1",
        "organization": "nyantec GmbH",
        "address_1": "Europaplatz 2",
        "address_2": "Berlin    10557",
        "country": "DE"
    },
    "A0239F": {
        "oui_hex": "A0-23-9F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "70F35A": {
        "oui_hex": "70-F3-5A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A0341B": {
        "oui_hex": "A0-34-1B",
        "organization": "Adero Inc",
        "address_1": "7410 HOllister Ave",
        "address_2": "Goleta  CA  93117",
        "country": "US"
    },
    "A0AFBD": {
        "oui_hex": "A0-AF-BD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7C8BCA": {
        "oui_hex": "7C-8B-CA",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B04E26": {
        "oui_hex": "B0-4E-26",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B089C2": {
        "oui_hex": "B0-89-C2",
        "organization": "Zyptonite",
        "address_1": "1460 Broadway, 12 fl.",
        "address_2": "New York  NY  10036",
        "country": "US"
    },
    "F023B9": {
        "oui_hex": "F0-23-B9",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "FC4DD4": {
        "oui_hex": "FC-4D-D4",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Rd. Sec. 1, Tsao Tuen,",
        "address_2": "Nan-Tou Hsien,     542",
        "country": "TW"
    },
    "A4F4C2": {
        "oui_hex": "A4-F4-C2",
        "organization": "VNPT TECHNOLOGY",
        "address_1": "HoaLac Hi-Tech Park",
        "address_2": "HANOI  HANOI  10000",
        "country": "VN"
    },
    "8C147D": {
        "oui_hex": "8C-14-7D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "30074D": {
        "oui_hex": "30-07-4D",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "1C1FD4": {
        "oui_hex": "1C-1F-D4",
        "organization": "LifeBEAM Technologies LTD",
        "address_1": "150 Greenwich st 4WTC - 29th floor",
        "address_2": "New York  NY  10007",
        "country": "US"
    },
    "009AD2": {
        "oui_hex": "00-9A-D2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "447F77": {
        "oui_hex": "44-7F-77",
        "organization": "Connected Home",
        "address_1": "19-22, Rathbone Place",
        "address_2": "London    W1T 1HY",
        "country": "GB"
    },
    "E8B6C2": {
        "oui_hex": "E8-B6-C2",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "947BE7": {
        "oui_hex": "94-7B-E7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5092B9": {
        "oui_hex": "50-92-B9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DC74A8": {
        "oui_hex": "DC-74-A8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E83935": {
        "oui_hex": "E8-39-35",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "00180A": {
        "oui_hex": "00-18-0A",
        "organization": "Cisco Meraki",
        "address_1": "99 Rhode Island St.",
        "address_2": "San Francisco,  CA  94103",
        "country": "US"
    },
    "5C6A80": {
        "oui_hex": "5C-6A-80",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "D860B3": {
        "oui_hex": "D8-60-B3",
        "organization": "Guangdong Global Electronic Technology CO.，LTD",
        "address_1": " Floor4 East side,build#6,Huangzhou industry Park, chebei Road, Tianhe District",
        "address_2": "GuangZhou  GuangDong  510660",
        "country": "CN"
    },
    "64351C": {
        "oui_hex": "64-35-1C",
        "organization": "e-CON SYSTEMS INDIA PVT LTD",
        "address_1": "RR Tower 4, 7th Floor, TVK IND Estate, Guindy",
        "address_2": "Chennai  Other  600032",
        "country": "IN"
    },
    "60BA18": {
        "oui_hex": "60-BA-18",
        "organization": "nextLAP GmbH",
        "address_1": "Hofmannstr. 61",
        "address_2": "München    81379",
        "country": "DE"
    },
    "44AA50": {
        "oui_hex": "44-AA-50",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "84CD62": {
        "oui_hex": "84-CD-62",
        "organization": "ShenZhen IDWELL Technology CO.,Ltd",
        "address_1": "4F,Building 20 Changxing Industrial Park,Shayi,Shajing,BaoAn",
        "address_2": "ShenZhen    518000",
        "country": "CN"
    },
    "A8D579": {
        "oui_hex": "A8-D5-79",
        "organization": "Beijing Chushang Science and Technology Co.,Ltd",
        "address_1": "3A285 room,3 layer,1 building,No 11 of yongwai song zhuang road,Fengtai district,Beijing",
        "address_2": "Beijing  Beijing  518000",
        "country": "CN"
    },
    "4448C1": {
        "oui_hex": "44-48-C1",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "481063": {
        "oui_hex": "48-10-63",
        "organization": "NTT Innovation Institute, Inc.",
        "address_1": "1950 University Avenue, Suite 600",
        "address_2": "East Palo Alto  CA  94303",
        "country": "US"
    },
    "A08E78": {
        "oui_hex": "A0-8E-78",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "88D50C": {
        "oui_hex": "88-D5-0C",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D428D5": {
        "oui_hex": "D4-28-D5",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "9CAF6F": {
        "oui_hex": "9C-AF-6F",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "FC539E": {
        "oui_hex": "FC-53-9E",
        "organization": "Shanghai Wind Technologies Co.,Ltd",
        "address_1": "Floor 8,East Building,Guilin Technology Mansion,No.650,Caobao Road,XuHui District,Shanghai,P.R.China",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "605317": {
        "oui_hex": "60-53-17",
        "organization": "Sandstone Technologies",
        "address_1": "1920 lyell ave",
        "address_2": "Rochester  NY  14606",
        "country": "US"
    },
    "907065": {
        "oui_hex": "90-70-65",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "18A958": {
        "oui_hex": "18-A9-58",
        "organization": "PROVISION THAI CO., LTD.",
        "address_1": "155/7-10 Rachadapisek Rd.,",
        "address_2": "Thonburi  Bangkok  10600",
        "country": "TH"
    },
    "74C9A3": {
        "oui_hex": "74-C9-A3",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "EC8A4C": {
        "oui_hex": "EC-8A-4C",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D45F25": {
        "oui_hex": "D4-5F-25",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "40C8CB": {
        "oui_hex": "40-C8-CB",
        "organization": "AM Telecom co., Ltd.",
        "address_1": "#608,YatapLeaders B/D, Jangmi-ro 42, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-828",
        "country": "KR"
    },
    "2CABEB": {
        "oui_hex": "2C-AB-EB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C83A6B": {
        "oui_hex": "C8-3A-6B",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "B4C6F8": {
        "oui_hex": "B4-C6-F8",
        "organization": "Axilspot Communication",
        "address_1": "A302 Han's Innovation Building, No.9018 Beihuan Ave., Nanshan District",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "9CE951": {
        "oui_hex": "9C-E9-51",
        "organization": "Shenzhen Sang Fei Consumer Communications Ltd., Co.",
        "address_1": "11,Science And Technology Road, Shenzhen Hi-tech Industrial Park, Nanshan District",
        "address_2": " Shenzhen City  Guangdong  518057",
        "country": "CN"
    },
    "B8D50B": {
        "oui_hex": "B8-D5-0B",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "BC66DE": {
        "oui_hex": "BC-66-DE",
        "organization": "Shadow Creator Information Technology Co.,Ltd.",
        "address_1": "Shanghai City, Pudong New Area Zhangjiang road 368, Building 29, room 611",
        "address_2": "Shanghai  Shanghai  200120",
        "country": "CN"
    },
    "1868CB": {
        "oui_hex": "18-68-CB",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "C4AE12": {
        "oui_hex": "C4-AE-12",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "001FA4": {
        "oui_hex": "00-1F-A4",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "4F,Baiying Building, No.1019,Nanhai RD,Shekou,",
        "address_2": "ShenZhen  GuangDong  518067",
        "country": "CN"
    },
    "D4DCCD": {
        "oui_hex": "D4-DC-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "484BAA": {
        "oui_hex": "48-4B-AA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DCA904": {
        "oui_hex": "DC-A9-04",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6CAB31": {
        "oui_hex": "6C-AB-31",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C74BF": {
        "oui_hex": "4C-74-BF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04946B": {
        "oui_hex": "04-94-6B",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "A04C5B": {
        "oui_hex": "A0-4C-5B",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "488803": {
        "oui_hex": "48-88-03",
        "organization": "ManTechnology Inc.",
        "address_1": "12th Fl, 308-4 Seongsoodong 2ga, Seongdonggu",
        "address_2": "Seoul    04781",
        "country": "KR"
    },
    "B436E3": {
        "oui_hex": "B4-36-E3",
        "organization": "KBVISION GROUP",
        "address_1": "337 N. Vineyard Avenue,  4th Floor,  San Jose, CA 91764",
        "address_2": "San Jose  CA  90847",
        "country": "US"
    },
    "94D299": {
        "oui_hex": "94-D2-99",
        "organization": "Techmation Co.,Ltd.",
        "address_1": "9F., No.529, Zhongzheng Rd., Xindian Dist., New Taipei City 231, Taiwan",
        "address_2": "New Taipei City     231",
        "country": "TW"
    },
    "341A35": {
        "oui_hex": "34-1A-35",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "2C029F": {
        "oui_hex": "2C-02-9F",
        "organization": "3ALogics",
        "address_1": "#704, Hyundai office B'd, Sunae-dong, Bundang-gu",
        "address_2": "Seongnam-si    13601",
        "country": "KR"
    },
    "64D154": {
        "oui_hex": "64-D1-54",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "58D9D5": {
        "oui_hex": "58-D9-D5",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "6C4B90": {
        "oui_hex": "6C-4B-90",
        "organization": "LiteON",
        "address_1": "5F, No.90, Rd. Chien 1, ChungHo",
        "address_2": "New Taipei  Taiwan  23505",
        "country": "TW"
    },
    "00050F": {
        "oui_hex": "00-05-0F",
        "organization": "Tanaka S/S Ltd.",
        "address_1": "1942 Nomura Hirooka",
        "address_2": "Nagano  399-0702",
        "country": "JP"
    },
    "989E63": {
        "oui_hex": "98-9E-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "886B6E": {
        "oui_hex": "88-6B-6E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F4E4AD": {
        "oui_hex": "F4-E4-AD",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "28FF3E": {
        "oui_hex": "28-FF-3E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B8D7AF": {
        "oui_hex": "B8-D7-AF",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "D4AE05": {
        "oui_hex": "D4-AE-05",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E048AF": {
        "oui_hex": "E0-48-AF",
        "organization": "Premietech Limited",
        "address_1": "Unit 805, Tower 3, Enterprise Square I",
        "address_2": "No. 9 Sheung Yuet Road  Kowloon Bay  HongKong  00000",
        "country": "HK"
    },
    "2C3311": {
        "oui_hex": "2C-33-11",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5082D5": {
        "oui_hex": "50-82-D5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0EE10": {
        "oui_hex": "F0-EE-10",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C4700B": {
        "oui_hex": "C4-70-0B",
        "organization": "GUANGZHOU CHIP TECHNOLOGIES CO.,LTD",
        "address_1": "4th floor, Building J of JiTang Industrial Zone, No. 8 NanYun fifth road, HuangPu District",
        "address_2": "Guangzhou  Guangdong  510700",
        "country": "CN"
    },
    "3CA067": {
        "oui_hex": "3C-A0-67",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "BC024A": {
        "oui_hex": "BC-02-4A",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "949901": {
        "oui_hex": "94-99-01",
        "organization": "Shenzhen YITOA Digital Appliance CO.,LTD",
        "address_1": "5/F,Yitoa Building,Keji South Road 5th,Hi-tech Industrial Park,Nanshan District,",
        "address_2": "shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F85971": {
        "oui_hex": "F8-59-71",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1005CA": {
        "oui_hex": "10-05-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7894B4": {
        "oui_hex": "78-94-B4",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "443708": {
        "oui_hex": "44-37-08",
        "organization": "MRV Comunications",
        "address_1": "Hayetzira",
        "address_2": "Yokneam    614",
        "country": "IL"
    },
    "285F2F": {
        "oui_hex": "28-5F-2F",
        "organization": "RNware Co.,Ltd.",
        "address_1": "#202 ICT Park Bldg, 205, Songhyun-ro, Dalseo-gu",
        "address_2": "Daegu    42734",
        "country": "KR"
    },
    "500FF5": {
        "oui_hex": "50-0F-F5",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "BC452E": {
        "oui_hex": "BC-45-2E",
        "organization": "Knowledge Development for POF S.L.",
        "address_1": "Ronda de Poniente 14, 2-C,D",
        "address_2": "Tres Cantos  Madrid  28760",
        "country": "ES"
    },
    "DCC64B": {
        "oui_hex": "DC-C6-4B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "043389": {
        "oui_hex": "04-33-89",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00A068": {
        "oui_hex": "00-A0-68",
        "organization": "BHP LIMITED",
        "address_1": "1500 Post Oak Boulevard #11.08 B",
        "address_2": "Houston  TX  77056-3030",
        "country": "US"
    },
    "703ACB": {
        "oui_hex": "70-3A-CB",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "706DEC": {
        "oui_hex": "70-6D-EC",
        "organization": "Wifi-soft LLC",
        "address_1": "616, West Monroe",
        "address_2": "Austin  TX  78704",
        "country": "US"
    },
    "B0C205": {
        "oui_hex": "B0-C2-05",
        "organization": "BIONIME",
        "address_1": "No.100, Sec.2, Daqing St., South Dist.,",
        "address_2": "Taichung  Taiwan  40242",
        "country": "TW"
    },
    "94F551": {
        "oui_hex": "94-F5-51",
        "organization": "Cadi Scientific Pte Ltd",
        "address_1": "31 Ubi Road 1, Aztech Building, #07-01A",
        "address_2": "Singapore    408694",
        "country": "SG"
    },
    "105AF7": {
        "oui_hex": "10-5A-F7",
        "organization": "ADB Italia",
        "address_1": "Viale Sarca 222",
        "address_2": "Milan  Italy  20126",
        "country": "IT"
    },
    "B81DAA": {
        "oui_hex": "B8-1D-AA",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "00E400": {
        "oui_hex": "00-E4-00",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "2C55D3": {
        "oui_hex": "2C-55-D3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00C024": {
        "oui_hex": "00-C0-24",
        "organization": "EDEN SISTEMAS DE COMPUTACAO SA",
        "address_1": "RUA DO OUVIDOR 121 5 ANDAR",
        "address_2": "",
        "country": "BR"
    },
    "7C4685": {
        "oui_hex": "7C-46-85",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "1C1EE3": {
        "oui_hex": "1C-1E-E3",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "44032C": {
        "oui_hex": "44-03-2C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "7868F7": {
        "oui_hex": "78-68-F7",
        "organization": "YSTen Technology Co.,Ltd",
        "address_1": "Room 1715,17/F North Star Times Tower,Chaoyang District,Beijing.",
        "address_2": "Beijing    100101",
        "country": "CN"
    },
    "004BF3": {
        "oui_hex": "00-4B-F3",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "08CCA7": {
        "oui_hex": "08-CC-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0896AD": {
        "oui_hex": "08-96-AD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0823B2": {
        "oui_hex": "08-23-B2",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "88C3B3": {
        "oui_hex": "88-C3-B3",
        "organization": "SOVICO",
        "address_1": "2271-5 Nambusunhwan-ro, Seocho-gu",
        "address_2": "Seoul    06703",
        "country": "KR"
    },
    "E05124": {
        "oui_hex": "E0-51-24",
        "organization": "NXP Semiconductors",
        "address_1": "411 E. Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001DA3": {
        "oui_hex": "00-1D-A3",
        "organization": "SabiOso",
        "address_1": "189 S State Suite #250",
        "address_2": "Clearfield  Utah  84015",
        "country": "US"
    },
    "542F8A": {
        "oui_hex": "54-2F-8A",
        "organization": "TELLESCOM INDUSTRIA E COMERCIO EM TELECOMUNICACAO",
        "address_1": "Av. Buriti, 1900 – Setor B – Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075-000",
        "country": "BR"
    },
    "6014B3": {
        "oui_hex": "60-14-B3",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "105611": {
        "oui_hex": "10-56-11",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "347877": {
        "oui_hex": "34-78-77",
        "organization": "O-Net Communications (Shenzhen) Limited",
        "address_1": "#10-1 South,Maqueling Industrial Park,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0020CC": {
        "oui_hex": "00-20-CC",
        "organization": "DIGITAL SERVICES, LTD.",
        "address_1": "9 WAYTE STREET",
        "address_2": "ENGLAND  PO6  3BS",
        "country": "GB"
    },
    "689FF0": {
        "oui_hex": "68-9F-F0",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5CAF06": {
        "oui_hex": "5C-AF-06",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "00179B": {
        "oui_hex": "00-17-9B",
        "organization": "CHANT SINCERE CO.,LTD",
        "address_1": "7F-2,NO.188,Sec 3,Ta Tung Rood,",
        "address_2": "Hsi Chih City  Taipei Hsien  221",
        "country": "TW"
    },
    "1C398A": {
        "oui_hex": "1C-39-8A",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E865D4": {
        "oui_hex": "E8-65-D4",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "24D51C": {
        "oui_hex": "24-D5-1C",
        "organization": "Zhongtian broadband technology co., LTD",
        "address_1": "Rudong hekou town Zhongtian industrial park",
        "address_2": "Nantong  jiangsu Province  226463",
        "country": "CN"
    },
    "EC43F6": {
        "oui_hex": "EC-43-F6",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "60C658": {
        "oui_hex": "60-C6-58",
        "organization": "PHYTRONIX Co.,Ltd.",
        "address_1": "1877-3 Ootashimo-machi",
        "address_2": "Takamatsu  Kagawa  761-8073",
        "country": "JP"
    },
    "FCB58A": {
        "oui_hex": "FC-B5-8A",
        "organization": "Wapice Ltd.",
        "address_1": "Yliopistonranta 5",
        "address_2": "Vaasa    65200",
        "country": "FI"
    },
    "A462DF": {
        "oui_hex": "A4-62-DF",
        "organization": "DS Global. Co., LTD",
        "address_1": "3F, 107, Gasan digital 2-ro, Geumcheon-gu",
        "address_2": "Seoul    08505",
        "country": "KR"
    },
    "4C1694": {
        "oui_hex": "4C-16-94",
        "organization": "shenzhen sibituo Technology Co., Ltd",
        "address_1": "15C Yuehua Park Nanshan Road Nanshan District",
        "address_2": "SHENZHEN  guangdong  518000",
        "country": "CN"
    },
    "C81451": {
        "oui_hex": "C8-14-51",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "44D437": {
        "oui_hex": "44-D4-37",
        "organization": "Inteno Broadband Technology AB",
        "address_1": "Stensätravägen 13",
        "address_2": "Skärholmen  SE  127 39",
        "country": "SE"
    },
    "ECE154": {
        "oui_hex": "EC-E1-54",
        "organization": "Beijing Unisound Information Technology Co.,Ltd.",
        "address_1": "Rm406,keyan Building,Tsinghua Hi-tech Park,High-tech Industrial Park North Area,Nanshan",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "6C160E": {
        "oui_hex": "6C-16-0E",
        "organization": "ShotTracker",
        "address_1": "7220 W Frontage Rd",
        "address_2": "Merriam  KS  66203",
        "country": "US"
    },
    "803A0A": {
        "oui_hex": "80-3A-0A",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "0C73BE": {
        "oui_hex": "0C-73-BE",
        "organization": "Dongguan Haimai Electronie Technology Co.,Ltd",
        "address_1": "Room 701，Yifeng Building7, No.8 Industrial Zone, Xianbian Road, Changan Town Xiaobian edge",
        "address_2": "Dongguan  Guangdong  518000",
        "country": "CN"
    },
    "286F7F": {
        "oui_hex": "28-6F-7F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F0C850": {
        "oui_hex": "F0-C8-50",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00014F": {
        "oui_hex": "00-01-4F",
        "organization": "Adtran Inc",
        "address_1": "901 Explorer Blvd.",
        "address_2": "Huntsville  AL  35806-2807",
        "country": "US"
    },
    "285261": {
        "oui_hex": "28-52-61",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C8AA55": {
        "oui_hex": "C8-AA-55",
        "organization": "Hunan Comtom Electronic Incorporated Co.,Ltd",
        "address_1": "6 -7 Floor, Jindan Building B,Xiongtian Road, Furong District",
        "address_2": "changsha  Hunan  410126",
        "country": "CN"
    },
    "20780B": {
        "oui_hex": "20-78-0B",
        "organization": "Delta Faucet Company",
        "address_1": "55 East 111th Street",
        "address_2": "Indianapolis  IN  46280",
        "country": "US"
    },
    "8809AF": {
        "oui_hex": "88-09-AF",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine    92618",
        "country": "US"
    },
    "2CD02D": {
        "oui_hex": "2C-D0-2D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9CCC83": {
        "oui_hex": "9C-CC-83",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2C6373": {
        "oui_hex": "2C-63-73",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "24A7DC": {
        "oui_hex": "24-A7-DC",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "64DBA0": {
        "oui_hex": "64-DB-A0",
        "organization": "Select Comfort",
        "address_1": "9800 59th Ave N",
        "address_2": "Minneapolis  MN  55442",
        "country": "US"
    },
    "F8983A": {
        "oui_hex": "F8-98-3A",
        "organization": "Leeman International (HongKong) Limited",
        "address_1": "Number 13 first floor Y1 cultural creative park bantian",
        "address_2": "shen zhen     51800",
        "country": "CN"
    },
    "4CECEF": {
        "oui_hex": "4C-EC-EF",
        "organization": "Soraa, Inc.",
        "address_1": "6500 Kaiser Dr Suite 110",
        "address_2": "Fremont  CA  94555",
        "country": "US"
    },
    "1CEFCE": {
        "oui_hex": "1C-EF-CE",
        "organization": "bebro electronic GmbH",
        "address_1": "MAx-Planck-Str. 6-8",
        "address_2": "Frickenhausen    72636",
        "country": "DE"
    },
    "98B6E9": {
        "oui_hex": "98-B6-E9",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "F015B9": {
        "oui_hex": "F0-15-B9",
        "organization": "PlayFusion Limited",
        "address_1": "St  Johns Innovation Centre",
        "address_2": "Cambridge    CB4 0WS",
        "country": "GB"
    },
    "64B0A6": {
        "oui_hex": "64-B0-A6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7C04D0": {
        "oui_hex": "7C-04-D0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84FCAC": {
        "oui_hex": "84-FC-AC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC0C5C": {
        "oui_hex": "DC-0C-5C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70700D": {
        "oui_hex": "70-70-0D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "30E171": {
        "oui_hex": "30-E1-71",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "186590": {
        "oui_hex": "18-65-90",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F86214": {
        "oui_hex": "F8-62-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "784F43": {
        "oui_hex": "78-4F-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "404D7F": {
        "oui_hex": "40-4D-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001D72": {
        "oui_hex": "00-1D-72",
        "organization": "Wistron Corporation",
        "address_1": "21F, 88, Sec.1, Hsin Tai Wu Rd., Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "D8197A": {
        "oui_hex": "D8-19-7A",
        "organization": "Nuheara Ltd",
        "address_1": "Unit 5, 28 John St",
        "address_2": "Northbridge  WA  6003",
        "country": "AU"
    },
    "4C38D5": {
        "oui_hex": "4C-38-D5",
        "organization": "MITAC COMPUTING TECHNOLOGY CORPORATION",
        "address_1": "3F., NO.1, R&D ROAD 2, HSINCHU SCIENCE PARK",
        "address_2": "HSINCHU    30076",
        "country": "TW"
    },
    "54B56C": {
        "oui_hex": "54-B5-6C",
        "organization": "Xi'an NovaStar Tech Co., Ltd",
        "address_1": "4F, Block D, Qinfeng Pavilion, Xi'an Software Park, No.68 Keji 2nd Rd.,",
        "address_2": " Xi'an  Shanxi  710075",
        "country": "CN"
    },
    "344CC8": {
        "oui_hex": "34-4C-C8",
        "organization": "Echodyne Corp",
        "address_1": "2380 116th Ave NE",
        "address_2": "Bellevue   WA  98004",
        "country": "US"
    },
    "64136C": {
        "oui_hex": "64-13-6C",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "04B648": {
        "oui_hex": "04-B6-48",
        "organization": "ZENNER",
        "address_1": "Roemerstadt 6",
        "address_2": "Saarbruecken    66121",
        "country": "DE"
    },
    "98F199": {
        "oui_hex": "98-F1-99",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "2-3 Kandatsukasamachi",
        "address_2": "Chiyodaku  Tokyo  101-8532",
        "country": "JP"
    },
    "1840A4": {
        "oui_hex": "18-40-A4",
        "organization": "Shenzhen Trylong Smart Science and Technology Co., Ltd.",
        "address_1": "15E, qingdian building, No#6007, Binhe road, futian district",
        "address_2": "Shenzhen city  Guangdong Province  518100",
        "country": "CN"
    },
    "1C48CE": {
        "oui_hex": "1C-48-CE",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "C80CC8": {
        "oui_hex": "C8-0C-C8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0425C5": {
        "oui_hex": "04-25-C5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "603E7B": {
        "oui_hex": "60-3E-7B",
        "organization": "Gafachi, Inc.",
        "address_1": "1 W Main St., STE 650",
        "address_2": "Rochester  NY  14614",
        "country": "US"
    },
    "4C7487": {
        "oui_hex": "4C-74-87",
        "organization": "Leader Phone Communication Technology Co., Ltd.",
        "address_1": "121 Room (Park) No.1 Building, No.10 Xinghuo Road  Science City Feng-tai District, Beijing, China",
        "address_2": "Beijing    100070",
        "country": "CN"
    },
    "AC83F3": {
        "oui_hex": "AC-83-F3",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "CC8CDA": {
        "oui_hex": "CC-8C-DA",
        "organization": "Shenzhen Wei Da Intelligent Technology Go.,Ltd",
        "address_1": "5K, Block B,Yueshang Center Cultural Square Jianshe East Rd Longhua New District",
        "address_2": "Shenzhen    518109",
        "country": "CN"
    },
    "D436DB": {
        "oui_hex": "D4-36-DB",
        "organization": "Jiangsu Toppower Automotive Electronics Co., Ltd",
        "address_1": "No. 2 Tuolanshan Road",
        "address_2": "Xuzhou  Jiangsu  221004",
        "country": "CN"
    },
    "2CDCAD": {
        "oui_hex": "2C-DC-AD",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "6C5C14": {
        "oui_hex": "6C-5C-14",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "E80945": {
        "oui_hex": "E8-09-45",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "B0A2E7": {
        "oui_hex": "B0-A2-E7",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "7C2587": {
        "oui_hex": "7C-25-87",
        "organization": "chaowifi.com",
        "address_1": "No. 502 1th Building TaiHe Square",
        "address_2": "HangZhou  QianJiangRoad  310002",
        "country": "CN"
    },
    "2C2131": {
        "oui_hex": "2C-21-31",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00501E": {
        "oui_hex": "00-50-1E",
        "organization": "Grass Valley, A Belden Brand",
        "address_1": "3499, Douglas B. Floreani",
        "address_2": "Montreal  Quebec  H4S 2C6",
        "country": "CA"
    },
    "EC0D9A": {
        "oui_hex": "EC-0D-9A",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "90D7BE": {
        "oui_hex": "90-D7-BE",
        "organization": "Wavelab Global Inc.",
        "address_1": "12007 Sunrise Valley Drive, Suite 450",
        "address_2": "Reston  VA  20191",
        "country": "US"
    },
    "244E7B": {
        "oui_hex": "24-4E-7B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "30AEA4": {
        "oui_hex": "30-AE-A4",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "3CFA43": {
        "oui_hex": "3C-FA-43",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "145F94": {
        "oui_hex": "14-5F-94",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "001F82": {
        "oui_hex": "00-1F-82",
        "organization": "Cal-Comp Electronics & Communications Company Ltd.",
        "address_1": "No.147, Sec. 3, Beishen Rd",
        "address_2": "Shenkeng Dist  New Taipei City  ---",
        "country": "TW"
    },
    "883C1C": {
        "oui_hex": "88-3C-1C",
        "organization": "MERCURY CORPORATION",
        "address_1": "90, Gajaeul-ro, Seo-gu",
        "address_2": "INCHEON    22830",
        "country": "KR"
    },
    "002144": {
        "oui_hex": "00-21-44",
        "organization": "SS Telecoms",
        "address_1": "23 Botha Avenue",
        "address_2": "Centurion  Gauteng  0140",
        "country": "ZA"
    },
    "006BF1": {
        "oui_hex": "00-6B-F1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2834A2": {
        "oui_hex": "28-34-A2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7823AE": {
        "oui_hex": "78-23-AE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "20719E": {
        "oui_hex": "20-71-9E",
        "organization": "SF Technology Co.,Ltd",
        "address_1": "1/F,Block B,Building 1,ShenzhenSoftware Industry Base,Hi-Tech Industrial Park South",
        "address_2": "Shenzhen  Guangdong Province  518054",
        "country": "CN"
    },
    "2CC260": {
        "oui_hex": "2C-C2-60",
        "organization": "Oracle Corporation",
        "address_1": "Zarhin 13",
        "address_2": "Raanana    4366241",
        "country": "IL"
    },
    "3C3F51": {
        "oui_hex": "3C-3F-51",
        "organization": "2CRSI",
        "address_1": "32 rue Jacobi-Netter",
        "address_2": "STRASBOURG  France  67200",
        "country": "FR"
    },
    "3C2AF4": {
        "oui_hex": "3C-2A-F4",
        "organization": "Brother Industries, LTD.",
        "address_1": "15-1, Naeshirocho, Mizuho-ku",
        "address_2": "NAGOYA    4678561",
        "country": "JP"
    },
    "C0854C": {
        "oui_hex": "C0-85-4C",
        "organization": "Ragentek Technology Group",
        "address_1": "D10/D11，No.3188, Xiupu Road, PuDong District, Shanghai",
        "address_2": "Shanghai    201315",
        "country": "CN"
    },
    "0024AC": {
        "oui_hex": "00-24-AC",
        "organization": "Hangzhou DPtech Technologies Co., Ltd.",
        "address_1": "Huarong Shidai Bld., NO.3880,Jiang-Nan Avenue, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "50584F": {
        "oui_hex": "50-58-4F",
        "organization": "waytotec,Inc.",
        "address_1": "#604-4,B-Dong,Bundang Technopark,148,Yatap-dong,Bundang-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  13511",
        "country": "KR"
    },
    "085DDD": {
        "oui_hex": "08-5D-DD",
        "organization": "MERCURY CORPORATION",
        "address_1": "90, Gajaeul-ro, Seo-gu",
        "address_2": "INCHEON    22830",
        "country": "KR"
    },
    "8C60E7": {
        "oui_hex": "8C-60-E7",
        "organization": "MPGIO CO.,LTD",
        "address_1": "MPGIO Bldg., 98 Uijeong St.,",
        "address_2": "Uijeongbu  Korea / Gyeonggi  11623",
        "country": "KR"
    },
    "CC9470": {
        "oui_hex": "CC-94-70",
        "organization": "Kinestral Technologies, Inc.",
        "address_1": "400 E Jamie Ct., Ste. 201",
        "address_2": "South San Francisco  CA  94080",
        "country": "US"
    },
    "B439D6": {
        "oui_hex": "B4-39-D6",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "34F39A": {
        "oui_hex": "34-F3-9A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D816C1": {
        "oui_hex": "D8-16-C1",
        "organization": "DEWAV (HK) ELECTRONICS LIMITED",
        "address_1": "UNIT NO.1-2, 06/F., PERFECT INDUSTRIAL BUILDING,NO. 31 TAI YAU STREET, SAN PO KONG",
        "address_2": "KOWLOON, HONG KONG    510610",
        "country": "CN"
    },
    "CC61E5": {
        "oui_hex": "CC-61-E5",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "8C8ABB": {
        "oui_hex": "8C-8A-BB",
        "organization": "Beijing Orient View Technology Co., Ltd.",
        "address_1": "Building NO.1, LiYe Road 7",
        "address_2": "Huilongguan Town  Changping District, Beijing  102206",
        "country": "CN"
    },
    "00039B": {
        "oui_hex": "00-03-9B",
        "organization": "NetChip Technology, Inc.",
        "address_1": "335 Pioneer Way",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "44D9E7": {
        "oui_hex": "44-D9-E7",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "24A43C": {
        "oui_hex": "24-A4-3C",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "91 E. Tasman Dr.",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "9C8BA0": {
        "oui_hex": "9C-8B-A0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC088D": {
        "oui_hex": "CC-08-8D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38A4ED": {
        "oui_hex": "38-A4-ED",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "B89919": {
        "oui_hex": "B8-99-19",
        "organization": "7signal Solutions, Inc",
        "address_1": "526 S. Main Street",
        "address_2": "Akron  OH  44311",
        "country": "US"
    },
    "40FE0D": {
        "oui_hex": "40-FE-0D",
        "organization": "MAXIO",
        "address_1": "1101-1 digital empire A, 387 simin-daero dongan-gu",
        "address_2": "anyang-si  kyunggi-do  14057",
        "country": "KR"
    },
    "AC64DD": {
        "oui_hex": "AC-64-DD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "94B819": {
        "oui_hex": "94-B8-19",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "787D48": {
        "oui_hex": "78-7D-48",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "8871E5": {
        "oui_hex": "88-71-E5",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "BC39D9": {
        "oui_hex": "BC-39-D9",
        "organization": "Z-TEC",
        "address_1": "Donyu 1 Ro",
        "address_2": "Paju  Kyeongkido  10832",
        "country": "KR"
    },
    "609AC1": {
        "oui_hex": "60-9A-C1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "748D08": {
        "oui_hex": "74-8D-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00B0EE": {
        "oui_hex": "00-B0-EE",
        "organization": "Ajile Systems, Inc.",
        "address_1": "920 Saratoga Ave.",
        "address_2": "San Jose  CA  95129",
        "country": "US"
    },
    "0418D6": {
        "oui_hex": "04-18-D6",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "91 E. Tasman Dr.",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "20DBAB": {
        "oui_hex": "20-DB-AB",
        "organization": "Samsung Electronics Co., Ltd.",
        "address_1": "416, Maetan-3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi-Do  443-742",
        "country": "KR"
    },
    "383A21": {
        "oui_hex": "38-3A-21",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D8380D": {
        "oui_hex": "D8-38-0D",
        "organization": "SHENZHEN IP-COM Network Co.,Ltd",
        "address_1": "No.1001,Zhongshangyuan Road,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "88AD43": {
        "oui_hex": "88-AD-43",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "B4EFFA": {
        "oui_hex": "B4-EF-FA",
        "organization": "Lemobile Information Technology (Beijing) Co., Ltd.",
        "address_1": "5/F LeEco Building, 105 Yaojiayuan Road, Chaoyang District",
        "address_2": "Beijing  Beijing  100025",
        "country": "CN"
    },
    "6C71BD": {
        "oui_hex": "6C-71-BD",
        "organization": "EZELINK TELECOM",
        "address_1": "Bay Square Building 06 - Office No 105",
        "address_2": "Dubai  Dubai  111581",
        "country": "AE"
    },
    "60EFC6": {
        "oui_hex": "60-EF-C6",
        "organization": "Shenzhen Chima Technologies Co Limited",
        "address_1": "5F, TongXin Technology Park,HengGang,LongGang,Shenzhen,China",
        "address_2": "Shenzhen  GuangDong  518115",
        "country": "CN"
    },
    "001FC6": {
        "oui_hex": "00-1F-C6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "B0C128": {
        "oui_hex": "B0-C1-28",
        "organization": "Adler ELREHA GmbH",
        "address_1": "Schwetzinger Str. 103",
        "address_2": "Hockenheim  Baden-Württemberg  D-68766",
        "country": "DE"
    },
    "3087D9": {
        "oui_hex": "30-87-D9",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "FCCAC4": {
        "oui_hex": "FC-CA-C4",
        "organization": "LifeHealth, LLC",
        "address_1": "2656 Patton Rd",
        "address_2": "Roseville  MN  55113",
        "country": "US"
    },
    "F0D9B2": {
        "oui_hex": "F0-D9-B2",
        "organization": "EXO S.A.",
        "address_1": "Av. Chiclana 3444",
        "address_2": "Buenos Aires    1260",
        "country": "AR"
    },
    "E4C801": {
        "oui_hex": "E4-C8-01",
        "organization": "BLU Products Inc",
        "address_1": "10814 NW 33rd Street",
        "address_2": "Miami  FL  33172",
        "country": "US"
    },
    "F09838": {
        "oui_hex": "F0-98-38",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C80E14": {
        "oui_hex": "C8-0E-14",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "AC63BE": {
        "oui_hex": "AC-63-BE",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "F81D78": {
        "oui_hex": "F8-1D-78",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "38F7B2": {
        "oui_hex": "38-F7-B2",
        "organization": "SEOJUN ELECTRIC",
        "address_1": "468 Gangseo-ro, 07573, SEOJUN ELECTRIC Ace Techno Tower 805",
        "address_2": "Seoul    07573",
        "country": "KR"
    },
    "101250": {
        "oui_hex": "10-12-50",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "7802B7": {
        "oui_hex": "78-02-B7",
        "organization": "ShenZhen Ultra Easy Technology CO.,LTD",
        "address_1": "608,Building 2,Guangxingyuan Industrial Park A District,",
        "address_2": "Baoyuan Rd  ShenZhen,Guangdong  518102",
        "country": "CN"
    },
    "646184": {
        "oui_hex": "64-61-84",
        "organization": "VELUX",
        "address_1": "Baekgaardsvej 40",
        "address_2": "Skjern    6900",
        "country": "DK"
    },
    "E8E5D6": {
        "oui_hex": "E8-E5-D6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C87E75": {
        "oui_hex": "C8-7E-75",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00265F": {
        "oui_hex": "00-26-5F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00233A": {
        "oui_hex": "00-23-3A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "086A0A": {
        "oui_hex": "08-6A-0A",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "98E7F4": {
        "oui_hex": "98-E7-F4",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0007AB": {
        "oui_hex": "00-07-AB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002486": {
        "oui_hex": "00-24-86",
        "organization": "DesignArt Networks",
        "address_1": "4 Ha'haroshet St",
        "address_2": "Ra'anana    43101",
        "country": "IL"
    },
    "002478": {
        "oui_hex": "00-24-78",
        "organization": "Mag Tech Electronics Co Limited",
        "address_1": "Flat / Room T78 GOF Bangkok Building",
        "address_2": "Sheung Wan  HK",
        "country": "HK"
    },
    "382DD1": {
        "oui_hex": "38-2D-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001B2C": {
        "oui_hex": "00-1B-2C",
        "organization": "ATRON electronic GmbH",
        "address_1": "Am Ziegelstadel 12 + 14",
        "address_2": "Markt Schwaben    85570",
        "country": "DE"
    },
    "9034FC": {
        "oui_hex": "90-34-FC",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "001427": {
        "oui_hex": "00-14-27",
        "organization": "JazzMutant",
        "address_1": "2 allee du Doyen Georges Brus",
        "address_2": "Pessac    33600",
        "country": "FR"
    },
    "001E84": {
        "oui_hex": "00-1E-84",
        "organization": "Pika Technologies Inc.",
        "address_1": "535 Legget Drive",
        "address_2": "Ottawa  Ontario  K2K 3B8",
        "country": "CA"
    },
    "10DDB1": {
        "oui_hex": "10-DD-B1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002329": {
        "oui_hex": "00-23-29",
        "organization": "DDRdrive LLC",
        "address_1": "384 Madeline CT",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "0026AD": {
        "oui_hex": "00-26-AD",
        "organization": "Arada Systems, Inc.",
        "address_1": "1024 Morse Avenue",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "FC1F19": {
        "oui_hex": "FC-1F-19",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon    443-743",
        "country": "US"
    },
    "840B2D": {
        "oui_hex": "84-0B-2D",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "SUWON  KYUNGGI-DO  443-743",
        "country": "KR"
    },
    "206432": {
        "oui_hex": "20-64-32",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyunggi-Do  443-743",
        "country": "KR"
    },
    "B407F9": {
        "oui_hex": "B4-07-F9",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "Suwon-Si, Gyeonggi_Do, Korea",
        "address_2": "Suwon  Gyeonggi_Do  443-743",
        "country": "KR"
    },
    "889FFA": {
        "oui_hex": "88-9F-FA",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "8C7CB5": {
        "oui_hex": "8C-7C-B5",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C44619": {
        "oui_hex": "C4-46-19",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "506313": {
        "oui_hex": "50-63-13",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "60D819": {
        "oui_hex": "60-D8-19",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "F82FA8": {
        "oui_hex": "F8-2F-A8",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0C84DC": {
        "oui_hex": "0C-84-DC",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00166C": {
        "oui_hex": "00-16-6C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3Dong,Yeongtong-Gu",
        "address_2": "Suwon  Gyeonggi-Do  443-742",
        "country": "KR"
    },
    "181EB0": {
        "oui_hex": "18-1E-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "247F20": {
        "oui_hex": "24-7F-20",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "E8039A": {
        "oui_hex": "E8-03-9A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi  443742",
        "country": "KR"
    },
    "30CDA7": {
        "oui_hex": "30-CD-A7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416 MAETAN 3-DONG",
        "address_2": "SUWON- SI    443-742",
        "country": "US"
    },
    "001247": {
        "oui_hex": "00-12-47",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "001599": {
        "oui_hex": "00-15-99",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3Dong, Yeongtong-Gu",
        "address_2": "Suwon  AL  443-742",
        "country": "US"
    },
    "0012FB": {
        "oui_hex": "00-12-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3Dong, Yeongtong-Gu",
        "address_2": "Suwon-City  Gyeonggi-Do  443-742",
        "country": "KR"
    },
    "D0667B": {
        "oui_hex": "D0-66-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-do  443742",
        "country": "KR"
    },
    "B85E7B": {
        "oui_hex": "B8-5E-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E492FB": {
        "oui_hex": "E4-92-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "6CB7F4": {
        "oui_hex": "6C-B7-F4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2C4401": {
        "oui_hex": "2C-44-01",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B8D9CE": {
        "oui_hex": "B8-D9-CE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1C66AA": {
        "oui_hex": "1C-66-AA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3C8BFE": {
        "oui_hex": "3C-8B-FE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D4E8B2": {
        "oui_hex": "D4-E8-B2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1489FD": {
        "oui_hex": "14-89-FD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC851F": {
        "oui_hex": "BC-85-1F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0015B9": {
        "oui_hex": "00-15-B9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "002491": {
        "oui_hex": "00-24-91",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002339": {
        "oui_hex": "00-23-39",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5001BB": {
        "oui_hex": "50-01-BB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C40142": {
        "oui_hex": "C4-01-42",
        "organization": "MaxMedia Technology Limited",
        "address_1": "5F, No. 113, Jian 2nd Rd. Jhonghe District.",
        "address_2": "New Taipei City    23585",
        "country": "TW"
    },
    "8430E5": {
        "oui_hex": "84-30-E5",
        "organization": "SkyHawke Technologies, LLC",
        "address_1": "274 Commerce Park Dr, Ste M",
        "address_2": "Ridgeland  MS  39157",
        "country": "US"
    },
    "1C77F6": {
        "oui_hex": "1C-77-F6",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "58E326": {
        "oui_hex": "58-E3-26",
        "organization": "Compass Technologies Inc.",
        "address_1": "Unit 1012 C-dong, Woolim Lion's Valley",
        "address_2": "Seoul  Seoul  153-786",
        "country": "KR"
    },
    "001B2A": {
        "oui_hex": "00-1B-2A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "749DDC": {
        "oui_hex": "74-9D-DC",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "14DDE5": {
        "oui_hex": "14-DD-E5",
        "organization": "MPMKVVCL",
        "address_1": "NISHTHA PARISAR, GOVINDPURA",
        "address_2": "BHOPAL  MADHYA PRADESH  462023",
        "country": "IN"
    },
    "001A09": {
        "oui_hex": "00-1A-09",
        "organization": "Wayfarer Transit Systems Ltd",
        "address_1": "10 Willis Way",
        "address_2": "Poole  Dorset  BH15 3SS",
        "country": "GB"
    },
    "742344": {
        "oui_hex": "74-23-44",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "54880E": {
        "oui_hex": "54-88-0E",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "F025B7": {
        "oui_hex": "F0-25-B7",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "F04347": {
        "oui_hex": "F0-43-47",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9CB2B2": {
        "oui_hex": "9C-B2-B2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8C83A": {
        "oui_hex": "A8-C8-3A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC72B1": {
        "oui_hex": "BC-72-B1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "78F7BE": {
        "oui_hex": "78-F7-BE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "684898": {
        "oui_hex": "68-48-98",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3423BA": {
        "oui_hex": "34-23-BA",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "003676": {
        "oui_hex": "00-36-76",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FC8E7E": {
        "oui_hex": "FC-8E-7E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FC6FB7": {
        "oui_hex": "FC-6F-B7",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D42C0F": {
        "oui_hex": "D4-2C-0F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "400E85": {
        "oui_hex": "40-0E-85",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "C8BA94": {
        "oui_hex": "C8-BA-94",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "843838": {
        "oui_hex": "84-38-38",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "A055DE": {
        "oui_hex": "A0-55-DE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "80F503": {
        "oui_hex": "80-F5-03",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "44AAF5": {
        "oui_hex": "44-AA-F5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E09DFA": {
        "oui_hex": "E0-9D-FA",
        "organization": "Wanan Hongsheng Electronic Co.Ltd",
        "address_1": "1st section of industrial pack,Wan'An County,Ji'An City,jiangxi province",
        "address_2": "Wanan  China/jiangxi  343800",
        "country": "CN"
    },
    "5C3C27": {
        "oui_hex": "5C-3C-27",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "70A84C": {
        "oui_hex": "70-A8-4C",
        "organization": "MONAD., Inc.",
        "address_1": "702, Hanlla Sigma Vally, 545, Dunchon-daero, Jungwon-gu",
        "address_2": "Seongnam-Shi    13215",
        "country": "KR"
    },
    "84C7EA": {
        "oui_hex": "84-C7-EA",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "24E43F": {
        "oui_hex": "24-E4-3F",
        "organization": "Wenzhou Kunmei Communication Technology Co.,Ltd.",
        "address_1": "Baitawang industrial zone,Yueqing,Zhejiang",
        "address_2": "Yueqing  Zhejiang  310025",
        "country": "CN"
    },
    "287AEE": {
        "oui_hex": "28-7A-EE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "88797E": {
        "oui_hex": "88-79-7E",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "305890": {
        "oui_hex": "30-58-90",
        "organization": "Frontier Silicon Ltd",
        "address_1": "137 Euston Road",
        "address_2": "London    NW12AA",
        "country": "GB"
    },
    "708BCD": {
        "oui_hex": "70-8B-CD",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "00258B": {
        "oui_hex": "00-25-8B",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00562B": {
        "oui_hex": "00-56-2B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E8FD90": {
        "oui_hex": "E8-FD-90",
        "organization": "Turbostor",
        "address_1": "47800 Westinghouse Drive",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "2CAC44": {
        "oui_hex": "2C-AC-44",
        "organization": "CONEXTOP",
        "address_1": "Room 608, 6/F, Electric Building , High-tech Park , Nanshan",
        "address_2": "Shenzhen    51800",
        "country": "CN"
    },
    "D013FD": {
        "oui_hex": "D0-13-FD",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "BC644B": {
        "oui_hex": "BC-64-4B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "606405": {
        "oui_hex": "60-64-05",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "1899F5": {
        "oui_hex": "18-99-F5",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "0025C3": {
        "oui_hex": "00-25-C3",
        "organization": "21168",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "000F57": {
        "oui_hex": "00-0F-57",
        "organization": "CABLELOGIC Co., Ltd.",
        "address_1": "3F., Hwain Bldg., 1559-12 Seocho 3-dong,",
        "address_2": "Seoul    137-873",
        "country": "KR"
    },
    "000342": {
        "oui_hex": "00-03-42",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "A48269": {
        "oui_hex": "A4-82-69",
        "organization": "Datrium, Inc.",
        "address_1": "385 Moffett Park Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "10E68F": {
        "oui_hex": "10-E6-8F",
        "organization": "KWANGSUNG ELECTRONICS KOREA CO.,LTD.",
        "address_1": "356-3, Gongdan-ro",
        "address_2": "Gunpo-si  Gyeonggi-do  15808",
        "country": "KR"
    },
    "4CFACA": {
        "oui_hex": "4C-FA-CA",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "5/F,Building 8, 2388 ChenHang Road, MinHang District",
        "address_2": "shanghai    201114",
        "country": "CN"
    },
    "18ABF5": {
        "oui_hex": "18-AB-F5",
        "organization": "Ultra Electronics Electrics",
        "address_1": "Kingsditch Lane",
        "address_2": "Cheltenham  Gloucestershire  GL51 9PG",
        "country": "GB"
    },
    "B03EB0": {
        "oui_hex": "B0-3E-B0",
        "organization": "MICRODIA Ltd.",
        "address_1": "Suites 1608-1610, 16/F., Prosperity Centre, 25 Chong Yip Street,",
        "address_2": "Kwun Tong  Kowloon,  000000",
        "country": "HK"
    },
    "001591": {
        "oui_hex": "00-15-91",
        "organization": "RLW Inc.",
        "address_1": "2029 Cato Ave.",
        "address_2": "State College  PA  16801",
        "country": "US"
    },
    "00182E": {
        "oui_hex": "00-18-2E",
        "organization": "XStreamHD",
        "address_1": "7900B Westpark Drive",
        "address_2": "McLean  VA  22102",
        "country": "US"
    },
    "001283": {
        "oui_hex": "00-12-83",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0011F9": {
        "oui_hex": "00-11-F9",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001158": {
        "oui_hex": "00-11-58",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000F6A": {
        "oui_hex": "00-0F-6A",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000E62": {
        "oui_hex": "00-0E-62",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000CF8": {
        "oui_hex": "00-0C-F8",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0026F1": {
        "oui_hex": "00-26-F1",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "0000    118502",
        "country": "SG"
    },
    "380DD4": {
        "oui_hex": "38-0D-D4",
        "organization": "Primax Electronics Ltd.",
        "address_1": "8F,No. 669, Ruey Kuang Road, Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "98FDB4": {
        "oui_hex": "98-FD-B4",
        "organization": "Primax Electronics Ltd.",
        "address_1": "No. 669, Ruey Kuang Road, Neihu",
        "address_2": "Taipei  Taiwan,  R.O.C.",
        "country": "TW"
    },
    "D8C46A": {
        "oui_hex": "D8-C4-6A",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "D8FB68": {
        "oui_hex": "D8-FB-68",
        "organization": "Cloud Corner Ltd.",
        "address_1": "Cloud Corner Smart Bldg, Mei Ju Center NO.39 Dongcheng South Road",
        "address_2": "Dong Guan  Guang Dong  523129",
        "country": "CN"
    },
    "685388": {
        "oui_hex": "68-53-88",
        "organization": "P&S Technology",
        "address_1": "216 Deajiro",
        "address_2": "Yongin-si  Gyeonggi-do  448-813",
        "country": "KR"
    },
    "982F3C": {
        "oui_hex": "98-2F-3C",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "35 East Mianxing Road,High-Tech Park,",
        "address_2": "MianYang  SiChuan  621000",
        "country": "CN"
    },
    "14C1FF": {
        "oui_hex": "14-C1-FF",
        "organization": "ShenZhen QianHai Comlan communication Co.,LTD",
        "address_1": "Shenzhen Nanshan district keyuan road Dongfang science and technology building,  room 2407.",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "000417": {
        "oui_hex": "00-04-17",
        "organization": "ELAU AG",
        "address_1": "Dillberg 12",
        "address_2": "",
        "country": "DE"
    },
    "ECFAAA": {
        "oui_hex": "EC-FA-AA",
        "organization": "The IMS Company",
        "address_1": "2929 E. Imperial Highway",
        "address_2": "Brea  CA  92821",
        "country": "US"
    },
    "F00786": {
        "oui_hex": "F0-07-86",
        "organization": "Shandong Bittel Electronics Co., Ltd",
        "address_1": "No.1 Rizhao North Road",
        "address_2": "Rizhao  Shandong  276800",
        "country": "CN"
    },
    "00D0F6": {
        "oui_hex": "00-D0-F6",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "54A619": {
        "oui_hex": "54-A6-19",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "000997": {
        "oui_hex": "00-09-97",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001CEB": {
        "oui_hex": "00-1C-EB",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001C17": {
        "oui_hex": "00-1C-17",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001A8F": {
        "oui_hex": "00-1A-8F",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0017D1": {
        "oui_hex": "00-17-D1",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "888322": {
        "oui_hex": "88-83-22",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E89309": {
        "oui_hex": "E8-93-09",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0014C7": {
        "oui_hex": "00-14-C7",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001DAF": {
        "oui_hex": "00-1D-AF",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "88A6C6": {
        "oui_hex": "88-A6-C6",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "94D469": {
        "oui_hex": "94-D4-69",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "882BD7": {
        "oui_hex": "88-2B-D7",
        "organization": "ADDÉNERGIE  TECHNOLOGIES",
        "address_1": "533 avenue de la montagne LOCAL 121",
        "address_2": "Shawinigan  Quebec  G9N 0A3",
        "country": "CA"
    },
    "0090CC": {
        "oui_hex": "00-90-CC",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "2F FENISSAY Ebisu Bldg",
        "address_2": "Shibuya-ku,  Tokyo  150-0011",
        "country": "JP"
    },
    "2057AF": {
        "oui_hex": "20-57-AF",
        "organization": "Shenzhen FH-NET OPTOELECTRONICS CO.,LTD",
        "address_1": "5/F Building D1 TCL International E City NO.1001 Zhong  shan  yuan Rd,  Nanshan District Shenzhen china",
        "address_2": "Shenzhen  GuangDong  518055",
        "country": "CN"
    },
    "54DC1D": {
        "oui_hex": "54-DC-1D",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "Road NO2, West of Industrial Park,North of Science & Technology Park",
        "address_2": "Dongguan  Guangdong  518057",
        "country": "CN"
    },
    "ACA213": {
        "oui_hex": "AC-A2-13",
        "organization": "Shenzhen Bilian electronic CO.,LTD",
        "address_1": "NO 268，Fuqian Rd,Jutang Community",
        "address_2": "shenzhen  guangdong  518110",
        "country": "CN"
    },
    "3C3300": {
        "oui_hex": "3C-33-00",
        "organization": "Shenzhen Bilian electronic CO.,LTD",
        "address_1": "NO 268，Fuqian Rd,Jutang Community,Guanlan town , LongHua new district",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "6CD032": {
        "oui_hex": "6C-D0-32",
        "organization": "LG Electronics",
        "address_1": "16, Woomyeon-dong, Seocho-gu",
        "address_2": "Seoul    137-724",
        "country": "KR"
    },
    "3CBDD8": {
        "oui_hex": "3C-BD-D8",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1, CHEONGHO-RI, JINWI-MYEON",
        "address_2": "PYEONGTAEK  GYEONGGI-DO  451-713",
        "country": "KR"
    },
    "344DF7": {
        "oui_hex": "34-4D-F7",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "583F54": {
        "oui_hex": "58-3F-54",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0022CF": {
        "oui_hex": "00-22-CF",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "2F F ・ NISSAY Ebisu Bldg3-16-3",
        "address_2": "Shibuya-ku  Tokyo  150-0011",
        "country": "JP"
    },
    "E417D8": {
        "oui_hex": "E4-17-D8",
        "organization": "8BITDO TECHNOLOGY HK LIMITED",
        "address_1": "Rooms 1318-19, 13/F, Hollywood Plaza, 610 Nathan Road, Mongkok, Kowloon, Hong Kong",
        "address_2": "Hong Kong  Hong Kong  000000",
        "country": "CN"
    },
    "9CD332": {
        "oui_hex": "9C-D3-32",
        "organization": "PLC Technology Ltd",
        "address_1": "Nauchny proezd, 17",
        "address_2": "Moscow  Select State  117246",
        "country": "RU"
    },
    "38F8CA": {
        "oui_hex": "38-F8-CA",
        "organization": "OWIN Inc.",
        "address_1": "Chosunref 5fl,577,Seolleung-ro,Gangnam-gu",
        "address_2": "Seoul    682-20",
        "country": "KR"
    },
    "44334C": {
        "oui_hex": "44-33-4C",
        "organization": "Shenzhen Bilian electronic CO.,LTD",
        "address_1": "NO 268",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "64899A": {
        "oui_hex": "64-89-9A",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "002105": {
        "oui_hex": "00-21-05",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001BC5": {
        "oui_hex": "00-1B-C5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "48DF37": {
        "oui_hex": "48-DF-37",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "C0E42D": {
        "oui_hex": "C0-E4-2D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "8CA6DF": {
        "oui_hex": "8C-A6-DF",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "8416F9": {
        "oui_hex": "84-16-F9",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "18D6C7": {
        "oui_hex": "18-D6-C7",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78C3E9": {
        "oui_hex": "78-C3-E9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8C1ABF": {
        "oui_hex": "8C-1A-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "30CBF8": {
        "oui_hex": "30-CB-F8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A0CBFD": {
        "oui_hex": "A0-CB-FD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E45D75": {
        "oui_hex": "E4-5D-75",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00E04D": {
        "oui_hex": "00-E0-4D",
        "organization": "INTERNET INITIATIVE JAPAN, INC",
        "address_1": "1-4, SANBAN-CHO, CHIYODA-KU",
        "address_2": "  TOKYO 102",
        "country": "JP"
    },
    "F8A9D0": {
        "oui_hex": "F8-A9-D0",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "CCFA00": {
        "oui_hex": "CC-FA-00",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "74A722": {
        "oui_hex": "74-A7-22",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F01C13": {
        "oui_hex": "F0-1C-13",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "58FCDB": {
        "oui_hex": "58-FC-DB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B0C5CA": {
        "oui_hex": "B0-C5-CA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "7419F8": {
        "oui_hex": "74-19-F8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A816B2": {
        "oui_hex": "A8-16-B2",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "64BC0C": {
        "oui_hex": "64-BC-0C",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "90C682": {
        "oui_hex": "90-C6-82",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C01ADA": {
        "oui_hex": "C0-1A-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000031": {
        "oui_hex": "00-00-31",
        "organization": "QPSX COMMUNICATIONS, LTD.",
        "address_1": "33 RICHARDSON STREET",
        "address_2": "Western    00000",
        "country": "AU"
    },
    "000E1E": {
        "oui_hex": "00-0E-1E",
        "organization": "QLogic Corporation",
        "address_1": "26650 Aliso Viejo Parkway",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "0014D1": {
        "oui_hex": "00-14-D1",
        "organization": "TRENDnet, Inc.",
        "address_1": "20675 Manhattan Place",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "CC52AF": {
        "oui_hex": "CC-52-AF",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351, TAIPING RD.",
        "address_2": "nan tou  NAN-TOU  542",
        "country": "TW"
    },
    "001C14": {
        "oui_hex": "00-1C-14",
        "organization": "VMware, Inc.",
        "address_1": "3401 Hillview Avenue",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "005056": {
        "oui_hex": "00-50-56",
        "organization": "VMware, Inc.",
        "address_1": "3401 Hillview Avenue",
        "address_2": "PALO ALTO  CA  94304",
        "country": "US"
    },
    "00121C": {
        "oui_hex": "00-12-1C",
        "organization": "PARROT SA",
        "address_1": "174 Quai de Jemmapes",
        "address_2": "Paris    75010",
        "country": "FR"
    },
    "9003B7": {
        "oui_hex": "90-03-B7",
        "organization": "PARROT SA",
        "address_1": "174 Quai de Jemmapes",
        "address_2": "Paris    75010",
        "country": "FR"
    },
    "208756": {
        "oui_hex": "20-87-56",
        "organization": "SIEMENS AG",
        "address_1": "Oestliche Rheinbrueckenstrasse 50",
        "address_2": "Karlsruhe  Baden-Württemberg  76187",
        "country": "DE"
    },
    "74B472": {
        "oui_hex": "74-B4-72",
        "organization": "CIESSE",
        "address_1": "Via G. di Vittorio, 66",
        "address_2": "Rignano Sull'Arno  Florence  50067",
        "country": "IT"
    },
    "FCF152": {
        "oui_hex": "FC-F1-52",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "483C0C": {
        "oui_hex": "48-3C-0C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "309BAD": {
        "oui_hex": "30-9B-AD",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "001BB1": {
        "oui_hex": "00-1B-B1",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No. 10-1, Li-hsin Road I, Hsinchu Science Park,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0080F7": {
        "oui_hex": "00-80-F7",
        "organization": "Zenith Electronics Corporation",
        "address_1": "1000 MILWAUKEE AVENUE",
        "address_2": "GLENVIEW  IL  60025",
        "country": "US"
    },
    "BC307D": {
        "oui_hex": "BC-30-7D",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsin Science Park, Hsinchu 308, Taiwan",
        "address_2": "HsinChu  Taiwan  308",
        "country": "TW"
    },
    "48A9D2": {
        "oui_hex": "48-A9-D2",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsin Science Park, Hsinchu 308, Taiwan",
        "address_2": "HsinChu  Taiwan  308",
        "country": "TW"
    },
    "80EA23": {
        "oui_hex": "80-EA-23",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsin Science Park, Hsinchu 308, Taiwan",
        "address_2": "HsinChu  Taiwan  308",
        "country": "TW"
    },
    "002713": {
        "oui_hex": "00-27-13",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "BC307E": {
        "oui_hex": "BC-30-7E",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II.",
        "address_2": "Hsinchu    30808854",
        "country": "TW"
    },
    "08952A": {
        "oui_hex": "08-95-2A",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "4432C8": {
        "oui_hex": "44-32-C8",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "38A28C": {
        "oui_hex": "38-A2-8C",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B4A5EF": {
        "oui_hex": "B4-A5-EF",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "849D64": {
        "oui_hex": "84-9D-64",
        "organization": "SMC Corporation",
        "address_1": "4-2-2, Kinunodai",
        "address_2": "Tsukuba Mirai-shi  Ibaraki-ken  300-2493",
        "country": "JP"
    },
    "0010C1": {
        "oui_hex": "00-10-C1",
        "organization": "OI ELECTRIC CO.,LTD",
        "address_1": "7-3-16 KIKUNA",
        "address_2": "YOKOHAMA  KANAGAWA-KEN  222-0011",
        "country": "JP"
    },
    "28BE9B": {
        "oui_hex": "28-BE-9B",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "FC528D": {
        "oui_hex": "FC-52-8D",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "506583": {
        "oui_hex": "50-65-83",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B09122": {
        "oui_hex": "B0-91-22",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "FC51A4": {
        "oui_hex": "FC-51-A4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "9857D3": {
        "oui_hex": "98-57-D3",
        "organization": "HON HAI-CCPBG  PRECISION IND.CO.,LTD.",
        "address_1": "5F, No.9,Li-Hsin Road V,Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "FCF528": {
        "oui_hex": "FC-F5-28",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "00A0C5": {
        "oui_hex": "00-A0-C5",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "A09E1A": {
        "oui_hex": "A0-9E-1A",
        "organization": "Polar Electro Oy",
        "address_1": "Professorintie 5",
        "address_2": "Kempele  Oulu  90440",
        "country": "FI"
    },
    "1CD6BD": {
        "oui_hex": "1C-D6-BD",
        "organization": "LEEDARSON LIGHTING CO., LTD.",
        "address_1": "No. 1511, 2nd Fanghu North Rd., Huli District",
        "address_2": "Xiamen  Fugian  361010",
        "country": "CN"
    },
    "D0D94F": {
        "oui_hex": "D0-D9-4F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "001E04": {
        "oui_hex": "00-1E-04",
        "organization": "Hanson Research Corporation",
        "address_1": "9810 Variel Ave.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "60C0BF": {
        "oui_hex": "60-C0-BF",
        "organization": "ON Semiconductor",
        "address_1": "5005 East McDowell Road",
        "address_2": "Phoenix  AZ  85008",
        "country": "US"
    },
    "AC0481": {
        "oui_hex": "AC-04-81",
        "organization": "Jiangsu Huaxing Electronics Co., Ltd.",
        "address_1": "the Industrial concentration zone, Zhiqian town,Jintan distric",
        "address_2": "Changzhou City  Jiangsu Province  213234",
        "country": "CN"
    },
    "68B35E": {
        "oui_hex": "68-B3-5E",
        "organization": "Shenzhen Neostra Technology Co.Ltd",
        "address_1": "7th Building,Huaide Cuihai Industrial Park,Fuyong,Shenzhen China",
        "address_2": "shenzhen    518100",
        "country": "CN"
    },
    "408805": {
        "oui_hex": "40-88-05",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "24E271": {
        "oui_hex": "24-E2-71",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "BC6010": {
        "oui_hex": "BC-60-10",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "D0FCCC": {
        "oui_hex": "D0-FC-CC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "98398E": {
        "oui_hex": "98-39-8E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44D1FA": {
        "oui_hex": "44-D1-FA",
        "organization": "Shenzhen Yunlink Technology Co., Ltd",
        "address_1": "Gushu, Xixiang Town, Bao'an District,",
        "address_2": "Shenzhen City  Guangdong Province  518100",
        "country": "CN"
    },
    "F0F644": {
        "oui_hex": "F0-F6-44",
        "organization": "Whitesky Science & Technology Co.,Ltd.",
        "address_1": "Room301,Building7,NO.6,Lane365",
        "address_2": "  Shanghai  200052",
        "country": "CN"
    },
    "20F17C": {
        "oui_hex": "20-F1-7C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "346AC2": {
        "oui_hex": "34-6A-C2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C41CFF": {
        "oui_hex": "C4-1C-FF",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "C09727": {
        "oui_hex": "C0-97-27",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "DC293A": {
        "oui_hex": "DC-29-3A",
        "organization": "Shenzhen Nuoshi Technology Co., LTD.",
        "address_1": "Room 7020 of Tian Xia IC  Industry Park, Majialong Industrial Zone, YiYuan Road",
        "address_2": "Nanshan District, Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "7C6AF3": {
        "oui_hex": "7C-6A-F3",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "E46251": {
        "oui_hex": "E4-62-51",
        "organization": "HAO CHENG GROUP LIMITED",
        "address_1": " FLAT/RM C, 06/F, BEST-TO-BEST COMMERCIAL CENTRE 32-36 FERRY STREET JORDAN KL",
        "address_2": "Hong KOng    999077",
        "country": "HK"
    },
    "40562D": {
        "oui_hex": "40-56-2D",
        "organization": "Smartron India Pvt ltd",
        "address_1": "1st Floor,  Kapil Tower,  Gachibowli",
        "address_2": "Hyderabad  Telangana  500032",
        "country": "IN"
    },
    "3876D1": {
        "oui_hex": "38-76-D1",
        "organization": "Euronda SpA",
        "address_1": "Via dell'artigianato, 7",
        "address_2": "Montecchio Precalcino  Italia/Vicenza  36030",
        "country": "IT"
    },
    "C4693E": {
        "oui_hex": "C4-69-3E",
        "organization": "Turbulence Design Inc.",
        "address_1": "1-3-14",
        "address_2": "Koshigaya-City  Saitama  343-0813",
        "country": "JP"
    },
    "009569": {
        "oui_hex": "00-95-69",
        "organization": "LSD Science and Technology Co.,Ltd.",
        "address_1": "Lierda Building,No.425 Dengyun Rd.",
        "address_2": "Hangzhou  Zhijiang  310011",
        "country": "CN"
    },
    "B0CF4D": {
        "oui_hex": "B0-CF-4D",
        "organization": "MI-Zone Technology Ireland",
        "address_1": "2nd floor,block 10 unit 3",
        "address_2": "dublin  Blanchardstown  15",
        "country": "IE"
    },
    "289AFA": {
        "oui_hex": "28-9A-FA",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "001A34": {
        "oui_hex": "00-1A-34",
        "organization": "Konka Group Co., Ltd.",
        "address_1": "Shenzhen Konka R & D Building, 28th floor 15-24",
        "address_2": "Nanshan District  Guangdong  00000",
        "country": "CN"
    },
    "0011FC": {
        "oui_hex": "00-11-FC",
        "organization": "HARTING Electronics GmbH",
        "address_1": "Wilhelm Harting Str. 1",
        "address_2": "Espelkamp  Nordrhein Westfalen  D-32339",
        "country": "DE"
    },
    "002389": {
        "oui_hex": "00-23-89",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "Oriental Electronics Bldg., #2, Chuangye RoadÃ‚Â£Ã‚Â¬Shangdi Information Industry Base,",
        "address_2": "Beijing    100085",
        "country": "US"
    },
    "3CE5A6": {
        "oui_hex": "3C-E5-A6",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "Oriental Electronic Bld., NO.2,Chuangye Road",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "5CDD70": {
        "oui_hex": "5C-DD-70",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "3C8C40": {
        "oui_hex": "3C-8C-40",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District,",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "A067BE": {
        "oui_hex": "A0-67-BE",
        "organization": "Sicon srl",
        "address_1": "Via Sila 1/3",
        "address_2": "Isola Vicentina  Vicenza  36033",
        "country": "IT"
    },
    "D8209F": {
        "oui_hex": "D8-20-9F",
        "organization": "Cubro Acronet GesmbH",
        "address_1": "Geiselberstraße 17 / 6 Floor",
        "address_2": "Vienna  Vienna  1110",
        "country": "AT"
    },
    "8C7716": {
        "oui_hex": "8C-77-16",
        "organization": "LONGCHEER TELECOMMUNICATION LIMITED",
        "address_1": "Building 1,No.401,Caobao Rd",
        "address_2": "Shanghai  Xuhui District  200233",
        "country": "CN"
    },
    "68FB7E": {
        "oui_hex": "68-FB-7E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84A134": {
        "oui_hex": "84-A1-34",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0D385": {
        "oui_hex": "A0-D3-85",
        "organization": "AUMA Riester GmbH & Co. KG",
        "address_1": "Aumastr. 1",
        "address_2": "Muellheim  Baden-Württemberg  79379",
        "country": "DE"
    },
    "1414E6": {
        "oui_hex": "14-14-E6",
        "organization": "Ningbo Sanhe Digital Co.,Ltd",
        "address_1": "No.1177 Lingyun Road",
        "address_2": "ningbo  zhejiang  315048",
        "country": "CN"
    },
    "002582": {
        "oui_hex": "00-25-82",
        "organization": "Maksat Technologies (P) Ltd",
        "address_1": "D-10/6, Okhla, Phase-I",
        "address_2": "New Delhi    110020",
        "country": "IN"
    },
    "0C5101": {
        "oui_hex": "0C-51-01",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2CF0A2": {
        "oui_hex": "2C-F0-A2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48C049": {
        "oui_hex": "48-C0-49",
        "organization": "Broad Telecom SA",
        "address_1": "c/ Margarita Salas, 22",
        "address_2": "Leganes  Madrid  28918",
        "country": "ES"
    },
    "AC6FBB": {
        "oui_hex": "AC-6F-BB",
        "organization": "TATUNG Technology Inc.",
        "address_1": "22, Chungshan N. Rd., 3rd Sec.,",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "001C41": {
        "oui_hex": "00-1C-41",
        "organization": "scemtec Transponder Technology GmbH",
        "address_1": "Wehrstr. 1",
        "address_2": "Gummersbach  NRW  51645",
        "country": "DE"
    },
    "146308": {
        "oui_hex": "14-63-08",
        "organization": "JABIL CIRCUIT (SHANGHAI) LTD.",
        "address_1": "FL5-UNIT A2 NO. 1528 GUMEI ROAD",
        "address_2": "SHANGHAI    200233",
        "country": "CN"
    },
    "001E25": {
        "oui_hex": "00-1E-25",
        "organization": "INTEK DIGITAL",
        "address_1": "1101, 11th Fl., Anyang K-center building, 1591-9",
        "address_2": "Anyang  Gyeonggi-do  431-815",
        "country": "KR"
    },
    "00E0CF": {
        "oui_hex": "00-E0-CF",
        "organization": "INTEGRATED DEVICE",
        "address_1": "6024 Silver Creek Valley Road",
        "address_2": "San Jose  CA  95138",
        "country": "US"
    },
    "904D4A": {
        "oui_hex": "90-4D-4A",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "044E5A": {
        "oui_hex": "04-4E-5A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0060B1": {
        "oui_hex": "00-60-B1",
        "organization": "Input/Output, Inc.",
        "address_1": "12300 PARC CREST DRIVE",
        "address_2": "STAFFORD  TX  77477-2416",
        "country": "US"
    },
    "547F54": {
        "oui_hex": "54-7F-54",
        "organization": "INGENICO",
        "address_1": "9, avenue de la gare - BP 25156",
        "address_2": "Valence cedex 9    26958",
        "country": "FR"
    },
    "6C2483": {
        "oui_hex": "6C-24-83",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "6891D0": {
        "oui_hex": "68-91-D0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E04F43": {
        "oui_hex": "E0-4F-43",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Road, Sec.1,Tsao Tuen",
        "address_2": "Nan-Tou  Taiwan  54261",
        "country": "TW"
    },
    "38700C": {
        "oui_hex": "38-70-0C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000E2E": {
        "oui_hex": "00-0E-2E",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "00065F": {
        "oui_hex": "00-06-5F",
        "organization": "ECI Telecom Ltd.",
        "address_1": "30 Hasivim St.",
        "address_2": "hasivivm    53188",
        "country": "IL"
    },
    "00208F": {
        "oui_hex": "00-20-8F",
        "organization": "ECI Telecom Ltd.",
        "address_1": "HASIVIM ST. 30,",
        "address_2": "PETACH-TIKVA 49133    49133",
        "country": "IL"
    },
    "844076": {
        "oui_hex": "84-40-76",
        "organization": "Drivenets",
        "address_1": "4 ashizaf",
        "address_2": "Raanana    4366411",
        "country": "IL"
    },
    "001CD7": {
        "oui_hex": "00-1C-D7",
        "organization": "Harman/Becker Automotive Systems GmbH",
        "address_1": "Becker-Göring-Straße 16",
        "address_2": "Karlsbad  Baden-Württemberg  76307",
        "country": "DE"
    },
    "003A7D": {
        "oui_hex": "00-3A-7D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "90C7D8": {
        "oui_hex": "90-C7-D8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00185C": {
        "oui_hex": "00-18-5C",
        "organization": "EDSLAB Technologies",
        "address_1": "20 Ayer Rajah Crescent",
        "address_2": "Crescent    139964",
        "country": "SG"
    },
    "001A45": {
        "oui_hex": "00-1A-45",
        "organization": "GN Netcom A/S",
        "address_1": "Metalbuen 66",
        "address_2": "Ballerup  Skovlunde  DK - 2750",
        "country": "DK"
    },
    "002088": {
        "oui_hex": "00-20-88",
        "organization": "GLOBAL VILLAGE COMMUNICATION",
        "address_1": "1144 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "541379": {
        "oui_hex": "54-13-79",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "001921": {
        "oui_hex": "00-19-21",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22,Alley 38,Lane 91, Sec. 1,Nei Hu Road.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0016EC": {
        "oui_hex": "00-16-EC",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No. 22, Alley 38, Lane 91, Sec. 1, Nei Hu Road,",
        "address_2": "Taipei    11441",
        "country": "TW"
    },
    "000795": {
        "oui_hex": "00-07-95",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No. 22, Alley 38, Lane 91,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "FC0F4B": {
        "oui_hex": "FC-0F-4B",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D4883F": {
        "oui_hex": "D4-88-3F",
        "organization": "HDPRO CO., LTD.",
        "address_1": "HDPRO Bldg. 23, 362 Beon-gil, Shinheung-ro, Ojeong-gu",
        "address_2": "Bucheon-City  Gyunggi-Do  14491",
        "country": "KR"
    },
    "1088CE": {
        "oui_hex": "10-88-CE",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "60B617": {
        "oui_hex": "60-B6-17",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "DC9C9F": {
        "oui_hex": "DC-9C-9F",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "74DFBF": {
        "oui_hex": "74-DF-BF",
        "organization": "Liteon Technology Corporation",
        "address_1": "7F, Bldg, C, 90, Chien 1 Road",
        "address_2": "Taipei  Taiwan  23585",
        "country": "TW"
    },
    "F03E90": {
        "oui_hex": "F0-3E-90",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D8D723": {
        "oui_hex": "D8-D7-23",
        "organization": "IDS, Inc",
        "address_1": "6801 15 Mile Rd.",
        "address_2": "Sterling Heights  MI  48312",
        "country": "US"
    },
    "84AD58": {
        "oui_hex": "84-AD-58",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "58605F": {
        "oui_hex": "58-60-5F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00A0F4": {
        "oui_hex": "00-A0-F4",
        "organization": "GE",
        "address_1": "W-657",
        "address_2": "WAUKESHA  WI  53188",
        "country": "US"
    },
    "AC0D1B": {
        "oui_hex": "AC-0D-1B",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F0D1B8": {
        "oui_hex": "F0-D1-B8",
        "organization": "LEDVANCE",
        "address_1": "200 Ballardvale St",
        "address_2": "Wilmington  MA  01887",
        "country": "US"
    },
    "986D35": {
        "oui_hex": "98-6D-35",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "88795B": {
        "oui_hex": "88-79-5B",
        "organization": "Konka Group Co., Ltd.",
        "address_1": "Shenzhen Konka R & D Building, 28th floor 15-24",
        "address_2": "Nanshan District  Guangdong  00000",
        "country": "CN"
    },
    "081F71": {
        "oui_hex": "08-1F-71",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5CCA1A": {
        "oui_hex": "5C-CA-1A",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "FC2FAA": {
        "oui_hex": "FC-2F-AA",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "B07E70": {
        "oui_hex": "B0-7E-70",
        "organization": "Zadara Storage Ltd.",
        "address_1": "6 Venture, Suite 140",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0080B1": {
        "oui_hex": "00-80-B1",
        "organization": "SOFTCOM A/S",
        "address_1": "STUDIESTRAEDE 21",
        "address_2": "",
        "country": "DK"
    },
    "202DF8": {
        "oui_hex": "20-2D-F8",
        "organization": "Digital Media Cartridge Ltd.",
        "address_1": "5F-3, No. 9, Ln 3, Jihu Rd, Neihu",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "10D0AB": {
        "oui_hex": "10-D0-AB",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0004C6": {
        "oui_hex": "00-04-C6",
        "organization": "YAMAHA MOTOR CO.,LTD",
        "address_1": "Information System Division",
        "address_2": "Japan  Zip:  438-8501",
        "country": "JP"
    },
    "18A3E8": {
        "oui_hex": "18-A3-E8",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "741E93": {
        "oui_hex": "74-1E-93",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "202D07": {
        "oui_hex": "20-2D-07",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D8803C": {
        "oui_hex": "D8-80-3C",
        "organization": "Anhui Huami Information Technology Company Limited",
        "address_1": "Building A4, 12th Floor, No. 800, Wangjiang Road",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "0034DA": {
        "oui_hex": "00-34-DA",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "3810D5": {
        "oui_hex": "38-10-D5",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "18C501": {
        "oui_hex": "18-C5-01",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "00A0B8": {
        "oui_hex": "00-A0-B8",
        "organization": "NetApp",
        "address_1": "1395 Crossman Ave",
        "address_2": "Sunnyvale,  CA  94089",
        "country": "US"
    },
    "00C88B": {
        "oui_hex": "00-C8-8B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "24C3F9": {
        "oui_hex": "24-C3-F9",
        "organization": "Securitas Direct AB",
        "address_1": "Angbatsbron 1",
        "address_2": "Malmö    21120",
        "country": "SE"
    },
    "2C21D7": {
        "oui_hex": "2C-21-D7",
        "organization": "IMAX Corporation",
        "address_1": "2525 Speakman Drive",
        "address_2": "Mississauga  Ontario  L5K 1B1",
        "country": "CA"
    },
    "0009D2": {
        "oui_hex": "00-09-D2",
        "organization": "Mai Logic Inc.",
        "address_1": "47697 Westinghouse Dr., Suite 200",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "006016": {
        "oui_hex": "00-60-16",
        "organization": "CLARIION",
        "address_1": "COSLIN DRIVE",
        "address_2": "SOUTHBORO  MA  01772",
        "country": "US"
    },
    "981FB1": {
        "oui_hex": "98-1F-B1",
        "organization": "Shenzhen Lemon Network Technology Co.,Ltd",
        "address_1": "Changhong Technology Building 1710-11,South NO.12 Road,Nanshan Technology Park,Nanshan District,Shenzhen,China.",
        "address_2": "shenzhen    518100",
        "country": "CN"
    },
    "0C5A9E": {
        "oui_hex": "0C-5A-9E",
        "organization": "Wi-SUN Alliance",
        "address_1": "275 Tennant Avenue, Suite 202",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "B44BD2": {
        "oui_hex": "B4-4B-D2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC415F": {
        "oui_hex": "DC-41-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "641225": {
        "oui_hex": "64-12-25",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7864E6": {
        "oui_hex": "78-64-E6",
        "organization": "Green Motive Technology Limited",
        "address_1": "Room 1106,11 Floor，The XinYuan Square, No 418 Gui ping Road",
        "address_2": "shanghai  shanghai  20233",
        "country": "CN"
    },
    "3CBEE1": {
        "oui_hex": "3C-BE-E1",
        "organization": "NIKON CORPORATION",
        "address_1": "Shinagawa Intercity Tower C, 2-15-3, Konan",
        "address_2": "Minato-ku  Tokyo  108-6290",
        "country": "JP"
    },
    "102AB3": {
        "oui_hex": "10-2A-B3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "40D357": {
        "oui_hex": "40-D3-57",
        "organization": "Ison Technology Co., Ltd.",
        "address_1": "Room 6, 20F, No. 77, section 1, Xintai 5th Rd. Xizhi District",
        "address_2": "New Taipei City  Taiwan  22101",
        "country": "TW"
    },
    "A41588": {
        "oui_hex": "A4-15-88",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F45C89": {
        "oui_hex": "F4-5C-89",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "20768F": {
        "oui_hex": "20-76-8F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C5CF9": {
        "oui_hex": "9C-5C-F9",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0011D1": {
        "oui_hex": "00-11-D1",
        "organization": "Soft Imaging System GmbH",
        "address_1": "Johann-Krane-Weg 39",
        "address_2": "Muenster    48149",
        "country": "DE"
    },
    "98D686": {
        "oui_hex": "98-D6-86",
        "organization": "Chyi Lee industry Co., ltd.",
        "address_1": "No.25, Wufu Rd., Xinying Dist.",
        "address_2": "Tainan city    73054",
        "country": "TW"
    },
    "8CC661": {
        "oui_hex": "8C-C6-61",
        "organization": "Current, powered by GE",
        "address_1": "1975 Noble Road B335C",
        "address_2": "East Cleveland  OH  44112",
        "country": "US"
    },
    "88A084": {
        "oui_hex": "88-A0-84",
        "organization": "Formation Data Systems",
        "address_1": "39141 Civic Center Drive, Suite 410",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "E8B2AC": {
        "oui_hex": "E8-B2-AC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E49A79": {
        "oui_hex": "E4-9A-79",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "30A9DE": {
        "oui_hex": "30-A9-DE",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "F01B6C": {
        "oui_hex": "F0-1B-6C",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "A0B9ED": {
        "oui_hex": "A0-B9-ED",
        "organization": "Skytap",
        "address_1": "710 2nd Ave Suite 1130",
        "address_2": "Seattle  WA  98104",
        "country": "US"
    },
    "94C960": {
        "oui_hex": "94-C9-60",
        "organization": "Zhongshan B&T technology.co.,ltd",
        "address_1": "Floor3-4,Block A,Dong Fang Industrial park,Da che country,Nan Lang District",
        "address_2": "Zhong Shan City  Guang Dong Province  528451",
        "country": "CN"
    },
    "74C330": {
        "oui_hex": "74-C3-30",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "403F8C": {
        "oui_hex": "40-3F-8C",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "DCB3B4": {
        "oui_hex": "DC-B3-B4",
        "organization": "Honeywell Environmental & Combustion Controls (Tianjin) Co., Ltd.",
        "address_1": "158 Nan Hai Road, TEDA",
        "address_2": "Tianjin    300457",
        "country": "CN"
    },
    "001D3B": {
        "oui_hex": "00-1D-3B",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001DFD": {
        "oui_hex": "00-1D-FD",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001E3B": {
        "oui_hex": "00-1E-3B",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001EA4": {
        "oui_hex": "00-1E-A4",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0026CC": {
        "oui_hex": "00-26-CC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "000EED": {
        "oui_hex": "00-0E-ED",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "4C2578": {
        "oui_hex": "4C-25-78",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  NA  24101",
        "country": "FI"
    },
    "BCC6DB": {
        "oui_hex": "BC-C6-DB",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  NA  24101",
        "country": "FI"
    },
    "60A8FE": {
        "oui_hex": "60-A8-FE",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo    02610",
        "country": "FI"
    },
    "00119F": {
        "oui_hex": "00-11-9F",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001A16": {
        "oui_hex": "00-1A-16",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001A89": {
        "oui_hex": "00-1A-89",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001ADC": {
        "oui_hex": "00-1A-DC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0025CF": {
        "oui_hex": "00-25-CF",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0021AB": {
        "oui_hex": "00-21-AB",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001FDE": {
        "oui_hex": "00-1F-DE",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001FDF": {
        "oui_hex": "00-1F-DF",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "547975": {
        "oui_hex": "54-79-75",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7E",
        "address_2": "Salo    24101",
        "country": "FI"
    },
    "A87B39": {
        "oui_hex": "A8-7B-39",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "00247C": {
        "oui_hex": "00-24-7C",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002266": {
        "oui_hex": "00-22-66",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0021FE": {
        "oui_hex": "00-21-FE",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "C477AB": {
        "oui_hex": "C4-77-AB",
        "organization": "Beijing ASU Tech Co.,Ltd",
        "address_1": "15/F, Global Trade Center Tower, No.36, North 3rd Ring Road, Dongcheng District, Beijing, 100013, China",
        "address_2": "BEI JING  BEI JING  100013",
        "country": "CN"
    },
    "000BCA": {
        "oui_hex": "00-0B-CA",
        "organization": "DATAVAN TC",
        "address_1": "4FL,#120-12,Chung Shan Rd, Sec.3",
        "address_2": "Chung Ho City, Taipei Hsien    235",
        "country": "TW"
    },
    "702559": {
        "oui_hex": "70-25-59",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99, Park Avenue III, Science-Based Industrial Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "607EDD": {
        "oui_hex": "60-7E-DD",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "ESPOO    02150",
        "country": "FI"
    },
    "A8A089": {
        "oui_hex": "A8-A0-89",
        "organization": "Tactical Communications",
        "address_1": "473 Post Street",
        "address_2": "Camarillo  CA  93010",
        "country": "US"
    },
    "48365F": {
        "oui_hex": "48-36-5F",
        "organization": "Wintecronics Ltd.",
        "address_1": "Rm. 3, 11F., No.716, Zhongzheng Rd., Zhonghe Dist., New Taipei City 23552, Taiwan (R.O.C.)",
        "address_2": "New Taipei City    23552",
        "country": "TW"
    },
    "001D20": {
        "oui_hex": "00-1D-20",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "08373D": {
        "oui_hex": "08-37-3D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0C75BD": {
        "oui_hex": "0C-75-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "300D43": {
        "oui_hex": "30-0D-43",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 2-4",
        "address_2": "Espoo  N.A.  02150",
        "country": "FI"
    },
    "00000E": {
        "oui_hex": "00-00-0E",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "000B5D": {
        "oui_hex": "00-0B-5D",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "C488E5": {
        "oui_hex": "C4-88-E5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "080581": {
        "oui_hex": "08-05-81",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "000DF3": {
        "oui_hex": "00-0D-F3",
        "organization": "Asmax Solutions",
        "address_1": "Tatarska 5",
        "address_2": "Cracow    30-103",
        "country": "PL"
    },
    "80ACAC": {
        "oui_hex": "80-AC-AC",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000DB6": {
        "oui_hex": "00-0D-B6",
        "organization": "Broadcom",
        "address_1": "1363 Redwood Way",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "000AF7": {
        "oui_hex": "00-0A-F7",
        "organization": "Broadcom",
        "address_1": "16215 Alton Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "D40129": {
        "oui_hex": "D4-01-29",
        "organization": "Broadcom",
        "address_1": "5300 California Ave.",
        "address_2": "Irvine  CA  92617",
        "country": "US"
    },
    "001D00": {
        "oui_hex": "00-1D-00",
        "organization": "Brivo Systems, LLC",
        "address_1": "4330 East West Highway",
        "address_2": "Bethesda  MD  20814",
        "country": "US"
    },
    "0020D6": {
        "oui_hex": "00-20-D6",
        "organization": "Breezecom, Ltd.",
        "address_1": "ATIDIM TECHNOLOGICAL PK-BLDG.3",
        "address_2": "Tel-aviv    12345",
        "country": "IL"
    },
    "00E063": {
        "oui_hex": "00-E0-63",
        "organization": "Cabletron Systems, Inc.",
        "address_1": "35 INDUSTRIAL WAY",
        "address_2": "ROCHESTER  NH  03866-5005",
        "country": "US"
    },
    "FCC734": {
        "oui_hex": "FC-C7-34",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8425DB": {
        "oui_hex": "84-25-DB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0EC71": {
        "oui_hex": "B0-EC-71",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E458B8": {
        "oui_hex": "E4-58-B8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "088C2C": {
        "oui_hex": "08-8C-2C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "64B853": {
        "oui_hex": "64-B8-53",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "389496": {
        "oui_hex": "38-94-96",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5056BF": {
        "oui_hex": "50-56-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "90F1AA": {
        "oui_hex": "90-F1-AA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "1077B1": {
        "oui_hex": "10-77-B1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "001FC7": {
        "oui_hex": "00-1F-C7",
        "organization": "Casio Hitachi Mobile Communications Co., Ltd.",
        "address_1": "2-229-1, Sakuragaoka",
        "address_2": "Higashiyamato-shi  Tokyo  207-8501",
        "country": "JP"
    },
    "A49A58": {
        "oui_hex": "A4-9A-58",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "08EE8B": {
        "oui_hex": "08-EE-8B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CA42A": {
        "oui_hex": "0C-A4-2A",
        "organization": "OB Telecom Electronic Technology Co., Ltd",
        "address_1": "17/F, Jiangong Building",
        "address_2": "Hangzhou  ZheJiang  310012",
        "country": "CN"
    },
    "74458A": {
        "oui_hex": "74-45-8A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5CDC96": {
        "oui_hex": "5C-DC-96",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.,",
        "address_2": "Hsinchu City 30071,    12345",
        "country": "TW"
    },
    "743170": {
        "oui_hex": "74-31-70",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F. , No. 9 , Park Avenue II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001A2A": {
        "oui_hex": "00-1A-2A",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F., No. 9 , Park Avenue II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "88252C": {
        "oui_hex": "88-25-2C",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F., NO.9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "40BA61": {
        "oui_hex": "40-BA-61",
        "organization": "ARIMA Communications Corp.",
        "address_1": "6F., No.866, Jhongjheng Rd., Jhonghe Dist.",
        "address_2": "New Taipei City    23586",
        "country": "TW"
    },
    "0011F5": {
        "oui_hex": "00-11-F5",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F, NO.119, CHIENKANG  RD.,",
        "address_2": "CHUNG-HO, TAIPEI    235",
        "country": "TW"
    },
    "0016E3": {
        "oui_hex": "00-16-E3",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F, NO.119, CHIENKANG RD.,",
        "address_2": "CHUNG-HO, TAIPEI    235",
        "country": "TW"
    },
    "E839DF": {
        "oui_hex": "E8-39-DF",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,CHUNG-HO,TAIPEI,",
        "address_2": "TAIWAN  TAIPEI  235",
        "country": "TW"
    },
    "1CC63C": {
        "oui_hex": "1C-C6-3C",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "1883BF": {
        "oui_hex": "18-83-BF",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "68ED43": {
        "oui_hex": "68-ED-43",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "70AAB2": {
        "oui_hex": "70-AA-B2",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "00146C": {
        "oui_hex": "00-14-6C",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001E2A": {
        "oui_hex": "00-1E-2A",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00184D": {
        "oui_hex": "00-18-4D",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00040E": {
        "oui_hex": "00-04-0E",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "berlin    12345",
        "country": "DE"
    },
    "9CC7A6": {
        "oui_hex": "9C-C7-A6",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "berlin  Berlin  10559",
        "country": "DE"
    },
    "A06391": {
        "oui_hex": "A0-63-91",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "20E52A": {
        "oui_hex": "20-E5-2A",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "4494FC": {
        "oui_hex": "44-94-FC",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "200CC8": {
        "oui_hex": "20-0C-C8",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C4473F": {
        "oui_hex": "C4-47-3F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "744401": {
        "oui_hex": "74-44-01",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E091F5": {
        "oui_hex": "E0-91-F5",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000F86": {
        "oui_hex": "00-0F-86",
        "organization": "BlackBerry RTS",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "0024D2": {
        "oui_hex": "00-24-D2",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,CHUNG-HO,TAIPEI,",
        "address_2": "TAIWAN  TAIPEI  235",
        "country": "TW"
    },
    "B4EEB4": {
        "oui_hex": "B4-EE-B4",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,NO.119,CHIENKANG RD,ZHONGHE DIST NEW TAIPEI CITY",
        "address_2": "TAIWAN  TAIPEI  23585",
        "country": "TW"
    },
    "E46449": {
        "oui_hex": "E4-64-49",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "40FC89": {
        "oui_hex": "40-FC-89",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "2C9E5F": {
        "oui_hex": "2C-9E-5F",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002636": {
        "oui_hex": "00-26-36",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001CC1": {
        "oui_hex": "00-1C-C1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001E5A": {
        "oui_hex": "00-1E-5A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001371": {
        "oui_hex": "00-13-71",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0023EE": {
        "oui_hex": "00-23-EE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001ADE": {
        "oui_hex": "00-1A-DE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "745612": {
        "oui_hex": "74-56-12",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0050E3": {
        "oui_hex": "00-50-E3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002136": {
        "oui_hex": "00-21-36",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001626": {
        "oui_hex": "00-16-26",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0019A6": {
        "oui_hex": "00-19-A6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E8C74F": {
        "oui_hex": "E8-C7-4F",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, No. 90, Chien 1 Road,",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "D05349": {
        "oui_hex": "D0-53-49",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road ChungHo",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "E8F724": {
        "oui_hex": "E8-F7-24",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "5CB524": {
        "oui_hex": "5C-B5-24",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "90C115": {
        "oui_hex": "90-C1-15",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "D05162": {
        "oui_hex": "D0-51-62",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "18002D": {
        "oui_hex": "18-00-2D",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "280DFC": {
        "oui_hex": "28-0D-FC",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "001311": {
        "oui_hex": "00-13-11",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D0DF9A": {
        "oui_hex": "D0-DF-9A",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "1C659D": {
        "oui_hex": "1C-65-9D",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "3010B3": {
        "oui_hex": "30-10-B3",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road, ChungHo, TaiPei Hsien",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "701A04": {
        "oui_hex": "70-1A-04",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F 90 Chien 1 Rd.ChungHo",
        "address_2": "Taipei    23585",
        "country": "TW"
    },
    "48D224": {
        "oui_hex": "48-D2-24",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "20689D": {
        "oui_hex": "20-68-9D",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "0024EF": {
        "oui_hex": "00-24-EF",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0025E7": {
        "oui_hex": "00-25-E7",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "58170C": {
        "oui_hex": "58-17-0C",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0016B8": {
        "oui_hex": "00-16-B8",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "7CBFB1": {
        "oui_hex": "7C-BF-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "080046": {
        "oui_hex": "08-00-46",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec, 5-1-2 Kitashinagawa",
        "address_2": "Tokyo    141-0001",
        "country": "JP"
    },
    "ECF00E": {
        "oui_hex": "EC-F0-0E",
        "organization": "AboCom",
        "address_1": "1F , No. 21, Yanfa 2nd Rd., SBIP",
        "address_2": "Hsinchu City  300    886",
        "country": "TW"
    },
    "00E098": {
        "oui_hex": "00-E0-98",
        "organization": "AboCom",
        "address_1": "12F-3, NO. 333, SEC. 1",
        "address_2": "HSIN-CHU    12345",
        "country": "TW"
    },
    "74DAEA": {
        "oui_hex": "74-DA-EA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "948815": {
        "oui_hex": "94-88-15",
        "organization": "Infinique Worldwide Inc",
        "address_1": "513, 4185 Shipp Drive",
        "address_2": "Mississauga  Ontario  L4Z2Y8",
        "country": "CA"
    },
    "D0E44A": {
        "oui_hex": "D0-E4-4A",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "384FF0": {
        "oui_hex": "38-4F-F0",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd",
        "address_2": ". New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "E874E6": {
        "oui_hex": "E8-74-E6",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "0020E0": {
        "oui_hex": "00-20-E0",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002662": {
        "oui_hex": "00-26-62",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002553": {
        "oui_hex": "00-25-53",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "00193E": {
        "oui_hex": "00-19-3E",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "000827": {
        "oui_hex": "00-08-27",
        "organization": "ADB Broadband Italia",
        "address_1": "Viale Sarca 222",
        "address_2": "pisacataway  Milano  20126",
        "country": "IT"
    },
    "742F68": {
        "oui_hex": "74-2F-68",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd., Xindian",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "4C14A3": {
        "oui_hex": "4C-14-A3",
        "organization": "TCL Technoly Electronics (Huizhou) Co., Ltd.",
        "address_1": "19th Zhongkai Hi-tech Development Zone",
        "address_2": "Huizhou  Guangdong  516006",
        "country": "CN"
    },
    "4CB0E8": {
        "oui_hex": "4C-B0-E8",
        "organization": "Beijing RongZhi xinghua technology co., LTD",
        "address_1": "Beijing haidian district zhongguancun east road No. 18 smartfortune international building, room 909",
        "address_2": "beijing  beijing  100000",
        "country": "CN"
    },
    "D887D5": {
        "oui_hex": "D8-87-D5",
        "organization": "Leadcore Technology CO.,LTD",
        "address_1": "1258 Mingyue Road,Shanghai.China",
        "address_2": "shanghai  shanghai  201206",
        "country": "CN"
    },
    "00F28B": {
        "oui_hex": "00-F2-8B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "34E6AD": {
        "oui_hex": "34-E6-AD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "081196": {
        "oui_hex": "08-11-96",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "183DA2": {
        "oui_hex": "18-3D-A2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "809B20": {
        "oui_hex": "80-9B-20",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "002314": {
        "oui_hex": "00-23-14",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "340286": {
        "oui_hex": "34-02-86",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001CBF": {
        "oui_hex": "00-1C-BF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B4B676": {
        "oui_hex": "B4-B6-76",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3CA9F4": {
        "oui_hex": "3C-A9-F4",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B88A60": {
        "oui_hex": "B8-8A-60",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "78FF57": {
        "oui_hex": "78-FF-57",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "9C4E36": {
        "oui_hex": "9C-4E-36",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3413E8": {
        "oui_hex": "34-13-E8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "002710": {
        "oui_hex": "00-27-10",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A48E0A": {
        "oui_hex": "A4-8E-0A",
        "organization": "DeLaval International AB",
        "address_1": "Gustaf De Lavals väg 15",
        "address_2": "TUMBA    14721",
        "country": "SE"
    },
    "AC2B6E": {
        "oui_hex": "AC-2B-6E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "9C3583": {
        "oui_hex": "9C-35-83",
        "organization": "Nipro Diagnostics, Inc",
        "address_1": "2400 N.W. 55th Court.",
        "address_2": "Ft. Lauderdale  FL  33309",
        "country": "US"
    },
    "C06118": {
        "oui_hex": "C0-61-18",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B82A72": {
        "oui_hex": "B8-2A-72",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "F8E079": {
        "oui_hex": "F8-E0-79",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "CCC3EA": {
        "oui_hex": "CC-C3-EA",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "40786A": {
        "oui_hex": "40-78-6A",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "0019D1": {
        "oui_hex": "00-19-D1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0019D2": {
        "oui_hex": "00-19-D2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001B21": {
        "oui_hex": "00-1B-21",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "18FF0F": {
        "oui_hex": "18-FF-0F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "34DE1A": {
        "oui_hex": "34-DE-1A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E8B1FC": {
        "oui_hex": "E8-B1-FC",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "CC3D82": {
        "oui_hex": "CC-3D-82",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001F3C": {
        "oui_hex": "00-1F-3C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "002315": {
        "oui_hex": "00-23-15",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00166F": {
        "oui_hex": "00-16-6F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "000A8A": {
        "oui_hex": "00-0A-8A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D09": {
        "oui_hex": "00-1D-09",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "0023AE": {
        "oui_hex": "00-23-AE",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "BC305B": {
        "oui_hex": "BC-30-5B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "388602": {
        "oui_hex": "38-86-02",
        "organization": "Flexoptix GmbH",
        "address_1": "Muehltalstr. 153",
        "address_2": "Darmstadt    64297",
        "country": "DE"
    },
    "4065A3": {
        "oui_hex": "40-65-A3",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "D02212": {
        "oui_hex": "D0-22-12",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "100723": {
        "oui_hex": "10-07-23",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A44F29": {
        "oui_hex": "A4-4F-29",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "74F8DB": {
        "oui_hex": "74-F8-DB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A43BFA": {
        "oui_hex": "A4-3B-FA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B8CA3A": {
        "oui_hex": "B8-CA-3A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "ECF4BB": {
        "oui_hex": "EC-F4-BB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "D4BED9": {
        "oui_hex": "D4-BE-D9",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00194B": {
        "oui_hex": "00-19-4B",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "001E74": {
        "oui_hex": "00-1E-74",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "383BC8": {
        "oui_hex": "38-3B-C8",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "60FE20": {
        "oui_hex": "60-FE-20",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation ParkWay",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "002456": {
        "oui_hex": "00-24-56",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "C0830A": {
        "oui_hex": "C0-83-0A",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00183F": {
        "oui_hex": "00-18-3F",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  94538",
        "country": "US"
    },
    "000D56": {
        "oui_hex": "00-0D-56",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "181E78": {
        "oui_hex": "18-1E-78",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "0037B7": {
        "oui_hex": "00-37-B7",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "0054BD": {
        "oui_hex": "00-54-BD",
        "organization": "Swelaser AB",
        "address_1": "Tullgårdsgatan 8",
        "address_2": "Stockholm    11668",
        "country": "SE"
    },
    "001E4C": {
        "oui_hex": "00-1E-4C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "20BB76": {
        "oui_hex": "20-BB-76",
        "organization": "COL GIOVANNI PAOLO SpA",
        "address_1": "Via F.lli Ceirano n. 20",
        "address_2": "Moncalieri  TORINO  10024",
        "country": "IT"
    },
    "3CDD89": {
        "oui_hex": "3C-DD-89",
        "organization": "SOMO HOLDINGS & TECH. CO.,LTD.",
        "address_1": "6, Mujeonggonddan-Gil",
        "address_2": "Damyang-Gun  Jellanam-Do  57360",
        "country": "KR"
    },
    "1801E3": {
        "oui_hex": "18-01-E3",
        "organization": "Bittium Wireless Ltd",
        "address_1": "Tutkijantie 8",
        "address_2": "Oulu    50590",
        "country": "FI"
    },
    "149182": {
        "oui_hex": "14-91-82",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "18622C": {
        "oui_hex": "18-62-2C",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "3C81D8": {
        "oui_hex": "3C-81-D8",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "40F201": {
        "oui_hex": "40-F2-01",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "D084B0": {
        "oui_hex": "D0-84-B0",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison  HAUTS DE SEINE  92848",
        "country": "FR"
    },
    "D8543A": {
        "oui_hex": "D8-54-3A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "649C8E": {
        "oui_hex": "64-9C-8E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "102EAF": {
        "oui_hex": "10-2E-AF",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "7C8EE4": {
        "oui_hex": "7C-8E-E4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B4EED4": {
        "oui_hex": "B4-EE-D4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D03761": {
        "oui_hex": "D0-37-61",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C83E99": {
        "oui_hex": "C8-3E-99",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "40984E": {
        "oui_hex": "40-98-4E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017EB": {
        "oui_hex": "00-17-EB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017E6": {
        "oui_hex": "00-17-E6",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C4EDBA": {
        "oui_hex": "C4-ED-BA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001832": {
        "oui_hex": "00-18-32",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3C2DB7": {
        "oui_hex": "3C-2D-B7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "5464D9": {
        "oui_hex": "54-64-D9",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "00195B": {
        "oui_hex": "00-19-5B",
        "organization": "D-Link Corporation",
        "address_1": "NO.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "000F3D": {
        "oui_hex": "00-0F-3D",
        "organization": "D-Link Corporation",
        "address_1": "No.8,Li-shing Seventh Road,Science-based Industrial Park,Hsimchu,",
        "address_2": "Hsimchu    300",
        "country": "TW"
    },
    "24DA11": {
        "oui_hex": "24-DA-11",
        "organization": "NO NDA Inc",
        "address_1": "828 Bryant St",
        "address_2": "Palo Alto  IA  94301",
        "country": "US"
    },
    "EC2280": {
        "oui_hex": "EC-22-80",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,",
        "address_2": "SINGAPORE  Singapore  609917",
        "country": "SG"
    },
    "9C8E99": {
        "oui_hex": "9C-8E-99",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "9059AF": {
        "oui_hex": "90-59-AF",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "BC6A29": {
        "oui_hex": "BC-6A-29",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "847E40": {
        "oui_hex": "84-7E-40",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001735": {
        "oui_hex": "00-17-35",
        "organization": "Intel Wireless Network Group",
        "address_1": "2111 NE 25th Ave",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "74AC5F": {
        "oui_hex": "74-AC-5F",
        "organization": "Qiku Internet Network Scientific (Shenzhen) Co., Ltd.",
        "address_1": "Cyber Harbor, 2nd Mengxi Road, Hi-Tech Industrial Park (North), NanShan District",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "38CADA": {
        "oui_hex": "38-CA-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0B33F": {
        "oui_hex": "D0-B3-3F",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park. NO.1 XiangShan East Road.,",
        "address_2": "GUANGDONG  SHENZHEN  518053",
        "country": "CN"
    },
    "BCD1D3": {
        "oui_hex": "BC-D1-D3",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park.",
        "address_2": "Nanshan, Shenzhen  GUANGDONG  518053",
        "country": "CN"
    },
    "D83C69": {
        "oui_hex": "D8-3C-69",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park. NO.1 XiangShan East Road",
        "address_2": "SHENZHEN  GUANGDONG  518053",
        "country": "CN"
    },
    "F4F5D8": {
        "oui_hex": "F4-F5-D8",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "8C579B": {
        "oui_hex": "8C-57-9B",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "0059AC": {
        "oui_hex": "00-59-AC",
        "organization": "KPN. B.V.",
        "address_1": "Maanplein 55",
        "address_2": "Den Haag  Zuid holland  2516 CK",
        "country": "NL"
    },
    "40D855": {
        "oui_hex": "40-D8-55",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "34AB37": {
        "oui_hex": "34-AB-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2400BA": {
        "oui_hex": "24-00-BA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "24DF6A": {
        "oui_hex": "24-DF-6A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "788B77": {
        "oui_hex": "78-8B-77",
        "organization": "Standar Telecom",
        "address_1": "Sadovnicheskaya 44 s.4",
        "address_2": "Moscow    115035",
        "country": "RU"
    },
    "B0C090": {
        "oui_hex": "B0-C0-90",
        "organization": "Chicony Electronics Co., Ltd.",
        "address_1": "No.25, Wugong 6th Rd., Wugu Dist.,",
        "address_2": "New Taipei City 248,  TAIWAN, REPUBLIC OF CHINA  248",
        "country": "TW"
    },
    "907F61": {
        "oui_hex": "90-7F-61",
        "organization": "Chicony Electronics Co., Ltd.",
        "address_1": "No.25, Wu-Gong 6th Rd., Wu Ku Industrial Park,",
        "address_2": "New Taipei City,    248",
        "country": "TW"
    },
    "0C0535": {
        "oui_hex": "0C-05-35",
        "organization": "Juniper Systems",
        "address_1": "1132 W. 1700 N.",
        "address_2": "Logan  UT  84321",
        "country": "US"
    },
    "BC83A7": {
        "oui_hex": "BC-83-A7",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit A 13-16/F,Skyworth Bldg., Gaoxin Ave.1.S.,Nanshan District",
        "address_2": "Shenzhen  GuangDong   518057",
        "country": "CN"
    },
    "BCEC23": {
        "oui_hex": "BC-EC-23",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit A13-16/F,Skyworth Bldg., Gaoxin Ave.1.S.,Nanshan District,Shenzhen,China",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "18AF61": {
        "oui_hex": "18-AF-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5CF938": {
        "oui_hex": "5C-F9-38",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "009069": {
        "oui_hex": "00-90-69",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "64649B": {
        "oui_hex": "64-64-9B",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F01C2D": {
        "oui_hex": "F0-1C-2D",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "307C5E": {
        "oui_hex": "30-7C-5E",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "AC06C7": {
        "oui_hex": "AC-06-C7",
        "organization": "ServerNet S.r.l.",
        "address_1": "Località Padriciano 99",
        "address_2": "Trieste  Trieste  34149",
        "country": "IT"
    },
    "E83EFC": {
        "oui_hex": "E8-3E-FC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "900DCB": {
        "oui_hex": "90-0D-CB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DCD": {
        "oui_hex": "00-1D-CD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DD2": {
        "oui_hex": "00-1D-D2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8C09F4": {
        "oui_hex": "8C-09-F4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8857EE": {
        "oui_hex": "88-57-EE",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "101F74": {
        "oui_hex": "10-1F-74",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "009C02": {
        "oui_hex": "00-9C-02",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "F4CE46": {
        "oui_hex": "F4-CE-46",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "DCFB02": {
        "oui_hex": "DC-FB-02",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg.,30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref  460-8315",
        "country": "JP"
    },
    "001635": {
        "oui_hex": "00-16-35",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0008C7": {
        "oui_hex": "00-08-C7",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0010E3": {
        "oui_hex": "00-10-E3",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000883": {
        "oui_hex": "00-08-83",
        "organization": "Hewlett Packard",
        "address_1": "MAIL STOP 42LE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "A02BB8": {
        "oui_hex": "A0-2B-B8",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "0019BB": {
        "oui_hex": "00-19-BB",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001F29": {
        "oui_hex": "00-1F-29",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00215A": {
        "oui_hex": "00-21-5A",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00237D": {
        "oui_hex": "00-23-7D",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "E8ED05": {
        "oui_hex": "E8-ED-05",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "789684": {
        "oui_hex": "78-96-84",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "CC65AD": {
        "oui_hex": "CC-65-AD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002655": {
        "oui_hex": "00-26-55",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000D9D": {
        "oui_hex": "00-0D-9D",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001560": {
        "oui_hex": "00-15-60",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00207B": {
        "oui_hex": "00-20-7B",
        "organization": "Intel Corporation",
        "address_1": "2111 NE 25th Avenue",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "001175": {
        "oui_hex": "00-11-75",
        "organization": "Intel Corporation",
        "address_1": " 5200 NE ELAM YOUNG PARKWAY",
        "address_2": "HIllsboro  OR  97124",
        "country": "US"
    },
    "780CB8": {
        "oui_hex": "78-0C-B8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "185E0F": {
        "oui_hex": "18-5E-0F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2C8158": {
        "oui_hex": "2C-81-58",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "8002DF": {
        "oui_hex": "80-02-DF",
        "organization": "ORA Inc.",
        "address_1": "No.1 Anjialou, Xiaoliangmaqiao Ave., Chaoyang Dist.",
        "address_2": "BeiJing    100125",
        "country": "CN"
    },
    "00306E": {
        "oui_hex": "00-30-6E",
        "organization": "Hewlett Packard",
        "address_1": "ENTERPRISE SYSTEMS TECH.CENTER",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "3C4A92": {
        "oui_hex": "3C-4A-92",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "7C7D3D": {
        "oui_hex": "7C-7D-3D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "4482E5": {
        "oui_hex": "44-82-E5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00234E": {
        "oui_hex": "00-23-4E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "2C233A": {
        "oui_hex": "2C-23-3A",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "000A57": {
        "oui_hex": "00-0A-57",
        "organization": "Hewlett Packard",
        "address_1": "10955 Tantau Avenue",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0001E7": {
        "oui_hex": "00-01-E7",
        "organization": "Hewlett Packard",
        "address_1": "11000 Wolfe Road, Mailstop 42LE",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0001E6": {
        "oui_hex": "00-01-E6",
        "organization": "Hewlett Packard",
        "address_1": "11000 Wolfe Road, Mailstop 42LE",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002376": {
        "oui_hex": "00-23-76",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "38E7D8": {
        "oui_hex": "38-E7-D8",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "188796": {
        "oui_hex": "18-87-96",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "B4CEF6": {
        "oui_hex": "B4-CE-F6",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "8CDCD4": {
        "oui_hex": "8C-DC-D4",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D4C9EF": {
        "oui_hex": "D4-C9-EF",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "FC15B4": {
        "oui_hex": "FC-15-B4",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "3CA82A": {
        "oui_hex": "3C-A8-2A",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "EC5F23": {
        "oui_hex": "EC-5F-23",
        "organization": "Qinghai Kimascend Electronics Technology Co. Ltd.",
        "address_1": "2F,Building 6,J6 Science&Tech Park, No.6 Jiangjun Rd., Jiangning District",
        "address_2": "Nanjing  Jiangsu  211100",
        "country": "CN"
    },
    "047D50": {
        "oui_hex": "04-7D-50",
        "organization": "Shenzhen Kang Ying Technology Co.Ltd.",
        "address_1": "Units 608,Saiba Electronic tower,NO.6, Langshan 2 Rd., Hi-Tech Industrial Park North , Nanshan, Shenzhen City",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "54EFFE": {
        "oui_hex": "54-EF-FE",
        "organization": "Fullpower Technologies, Inc.",
        "address_1": "1200 Pacific Avenue",
        "address_2": "Santa Cruz  CA  95060",
        "country": "US"
    },
    "940937": {
        "oui_hex": "94-09-37",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bundang-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "E84DD0": {
        "oui_hex": "E8-4D-D0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0C45BA": {
        "oui_hex": "0C-45-BA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "20906F": {
        "oui_hex": "20-90-6F",
        "organization": "Shenzhen Tencent Computer System Co., Ltd.",
        "address_1": "5-10 Building High-tech Zone, Nanshan District,",
        "address_2": "Shenzhen  Guangdong Province  518057",
        "country": "CN"
    },
    "6CE3B6": {
        "oui_hex": "6C-E3-B6",
        "organization": "Nera Telecommunications Ltd.",
        "address_1": "109 Defu Lane 10",
        "address_2": "Singapore  Singapore  539225",
        "country": "SG"
    },
    "DCD321": {
        "oui_hex": "DC-D3-21",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 11-4, Sunae-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-825",
        "country": "KR"
    },
    "6C72E7": {
        "oui_hex": "6C-72-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "741BB2": {
        "oui_hex": "74-1B-B2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6CE873": {
        "oui_hex": "6C-E8-73",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C46E1F": {
        "oui_hex": "C4-6E-1F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "50FA84": {
        "oui_hex": "50-FA-84",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "44B32D": {
        "oui_hex": "44-B3-2D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "CC4463": {
        "oui_hex": "CC-44-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "882593": {
        "oui_hex": "88-25-93",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "001FE1": {
        "oui_hex": "00-1F-E1",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D85D4C": {
        "oui_hex": "D8-5D-4C",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A0F3C1": {
        "oui_hex": "A0-F3-C1",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "001D0F": {
        "oui_hex": "00-1D-0F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Bldg. R1-B,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0023CD": {
        "oui_hex": "00-23-CD",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "South Building, No.5 Keyuan Road, Central Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "90489A": {
        "oui_hex": "90-48-9A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0071CC": {
        "oui_hex": "00-71-CC",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B05B67": {
        "oui_hex": "B0-5B-67",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CCA223": {
        "oui_hex": "CC-A2-23",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "786A89": {
        "oui_hex": "78-6A-89",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "384608": {
        "oui_hex": "38-46-08",
        "organization": "zte corporation",
        "address_1": "12/F,ZTE R&D Building,Kejinan Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4CAC0A": {
        "oui_hex": "4C-AC-0A",
        "organization": "zte corporation",
        "address_1": "12/F,ZTE R&D Building,Kejinan Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B4B362": {
        "oui_hex": "B4-B3-62",
        "organization": "zte corporation",
        "address_1": "12/F,ZTE R&D Building,Kejinan Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B075D5": {
        "oui_hex": "B0-75-D5",
        "organization": "zte corporation",
        "address_1": "12/F,ZTE R&D Building,Kejinan Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D0154A": {
        "oui_hex": "D0-15-4A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0026ED": {
        "oui_hex": "00-26-ED",
        "organization": "zte corporation",
        "address_1": "12/F ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  GUANGDONG  518057",
        "country": "CN"
    },
    "006057": {
        "oui_hex": "00-60-57",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-18-1 HAKUSAN MIDORI-KU",
        "address_2": "YOKOHAMA  226    12345",
        "country": "JP"
    },
    "783E53": {
        "oui_hex": "78-3E-53",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "0019FB": {
        "oui_hex": "00-19-FB",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "14B968": {
        "oui_hex": "14-B9-68",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5CF96A": {
        "oui_hex": "5C-F9-6A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "083E8E": {
        "oui_hex": "08-3E-8E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "002293": {
        "oui_hex": "00-22-93",
        "organization": "zte corporation",
        "address_1": "12/F ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  GUANGDONG  518057",
        "country": "CN"
    },
    "10A5D0": {
        "oui_hex": "10-A5-D0",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1,Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "50A72B": {
        "oui_hex": "50-A7-2B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0CD6BD": {
        "oui_hex": "0C-D6-BD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00F81C": {
        "oui_hex": "00-F8-1C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "087A4C": {
        "oui_hex": "08-7A-4C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "ACE215": {
        "oui_hex": "AC-E2-15",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "346BD3": {
        "oui_hex": "34-6B-D3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "70723C": {
        "oui_hex": "70-72-3C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "ACE87B": {
        "oui_hex": "AC-E8-7B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F83DFF": {
        "oui_hex": "F8-3D-FF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "285FDB": {
        "oui_hex": "28-5F-DB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "404D8E": {
        "oui_hex": "40-4D-8E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "4C5499": {
        "oui_hex": "4C-54-99",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "F49FF3": {
        "oui_hex": "F4-9F-F3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "240995": {
        "oui_hex": "24-09-95",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "84DBAC": {
        "oui_hex": "84-DB-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94772B": {
        "oui_hex": "94-77-2B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D440F0": {
        "oui_hex": "D4-40-F0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "04021F": {
        "oui_hex": "04-02-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "10CDAE": {
        "oui_hex": "10-CD-AE",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "048A15": {
        "oui_hex": "04-8A-15",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "B4B017": {
        "oui_hex": "B4-B0-17",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "90FB5B": {
        "oui_hex": "90-FB-5B",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "C8F406": {
        "oui_hex": "C8-F4-06",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "7052C5": {
        "oui_hex": "70-52-C5",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "F81547": {
        "oui_hex": "F8-15-47",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "506184": {
        "oui_hex": "50-61-84",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "185936": {
        "oui_hex": "18-59-36",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "20A783": {
        "oui_hex": "20-A7-83",
        "organization": "miControl GmbH",
        "address_1": "Blankenfelder Chaussee 1",
        "address_2": "Großbeeren  Brandenburg  15831",
        "country": "DE"
    },
    "200BC7": {
        "oui_hex": "20-0B-C7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "F84ABF": {
        "oui_hex": "F8-4A-BF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "78D752": {
        "oui_hex": "78-D7-52",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "104780": {
        "oui_hex": "10-47-80",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "548998": {
        "oui_hex": "54-89-98",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "00040D": {
        "oui_hex": "00-04-0D",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "70A8E3": {
        "oui_hex": "70-A8-E3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen    518129",
        "country": "CN"
    },
    "F8E811": {
        "oui_hex": "F8-E8-11",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "F8A45F": {
        "oui_hex": "F8-A4-5F",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "640980": {
        "oui_hex": "64-09-80",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "94049C": {
        "oui_hex": "94-04-9C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "688F84": {
        "oui_hex": "68-8F-84",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "SHENZHEN  GUANGDONG  518129",
        "country": "CN"
    },
    "30D17E": {
        "oui_hex": "30-D1-7E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "0050BD": {
        "oui_hex": "00-50-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00906F": {
        "oui_hex": "00-90-6F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "74D6EA": {
        "oui_hex": "74-D6-EA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "209148": {
        "oui_hex": "20-91-48",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "544A16": {
        "oui_hex": "54-4A-16",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "E02F6D": {
        "oui_hex": "E0-2F-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "58971E": {
        "oui_hex": "58-97-1E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B4E9B0": {
        "oui_hex": "B4-E9-B0",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000832": {
        "oui_hex": "00-08-32",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "189C5D": {
        "oui_hex": "18-9C-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "5CA48A": {
        "oui_hex": "5C-A4-8A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1C1D86": {
        "oui_hex": "1C-1D-86",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "60735C": {
        "oui_hex": "60-73-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "34A84E": {
        "oui_hex": "34-A8-4E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "54781A": {
        "oui_hex": "54-78-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00605C": {
        "oui_hex": "00-60-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0006C1": {
        "oui_hex": "00-06-C1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E014": {
        "oui_hex": "00-E0-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "DCA5F4": {
        "oui_hex": "DC-A5-F4",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "5017FF": {
        "oui_hex": "50-17-FF",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "70105C": {
        "oui_hex": "70-10-5C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "10F311": {
        "oui_hex": "10-F3-11",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0050F0": {
        "oui_hex": "00-50-F0",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "005014": {
        "oui_hex": "00-50-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0090F2": {
        "oui_hex": "00-90-F2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0CE0E4": {
        "oui_hex": "0C-E0-E4",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "74A2E6": {
        "oui_hex": "74-A2-E6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "BCF1F2": {
        "oui_hex": "BC-F1-F2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C80084": {
        "oui_hex": "C8-00-84",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "40A6E8": {
        "oui_hex": "40-A6-E8",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3085A9": {
        "oui_hex": "30-85-A9",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou",
        "address_2": "Taipei    112",
        "country": "US"
    },
    "B83861": {
        "oui_hex": "B8-38-61",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "580A20": {
        "oui_hex": "58-0A-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "2C3ECF": {
        "oui_hex": "2C-3E-CF",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B05947": {
        "oui_hex": "B0-59-47",
        "organization": "Shenzhen Qihu Intelligent Technology Company Limited",
        "address_1": "Room 201, Block A, No.1, Qianwan Road 1,Qianhai Shenzhen HongKong Modern Service Industry Cooperation Zone",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "346288": {
        "oui_hex": "34-62-88",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CCD8C1": {
        "oui_hex": "CC-D8-C1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7C0ECE": {
        "oui_hex": "7C-0E-CE",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A0ECF9": {
        "oui_hex": "A0-EC-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "508789": {
        "oui_hex": "50-87-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "381C1A": {
        "oui_hex": "38-1C-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "BC671C": {
        "oui_hex": "BC-67-1C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001947": {
        "oui_hex": "00-19-47",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001839": {
        "oui_hex": "00-18-39",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "002215": {
        "oui_hex": "00-22-15",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "E0CB4E": {
        "oui_hex": "E0-CB-4E",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "547C69": {
        "oui_hex": "54-7C-69",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001731": {
        "oui_hex": "00-17-31",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "No.5 Shing Yeh Street,Kwei Shan Hsiang,Taoyuan",
        "address_2": "Taipei    333",
        "country": "TW"
    },
    "DCCEC1": {
        "oui_hex": "DC-CE-C1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "9C57AD": {
        "oui_hex": "9C-57-AD",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "60FEC5": {
        "oui_hex": "60-FE-C5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E425E7": {
        "oui_hex": "E4-25-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC926B": {
        "oui_hex": "BC-92-6B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "101C0C": {
        "oui_hex": "10-1C-0C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "080007": {
        "oui_hex": "08-00-07",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "004096": {
        "oui_hex": "00-40-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "30F70D": {
        "oui_hex": "30-F7-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E86549": {
        "oui_hex": "E8-65-49",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B07D47": {
        "oui_hex": "B0-7D-47",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "38ED18": {
        "oui_hex": "38-ED-18",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "382056": {
        "oui_hex": "38-20-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "40D32D": {
        "oui_hex": "40-D3-2D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C42C03": {
        "oui_hex": "C4-2C-03",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9027E4": {
        "oui_hex": "90-27-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "109ADD": {
        "oui_hex": "10-9A-DD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "581FAA": {
        "oui_hex": "58-1F-AA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88C663": {
        "oui_hex": "88-C6-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001F5B": {
        "oui_hex": "00-1F-5B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002436": {
        "oui_hex": "00-24-36",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00254B": {
        "oui_hex": "00-25-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0016CB": {
        "oui_hex": "00-16-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0017F2": {
        "oui_hex": "00-17-F2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7C6D62": {
        "oui_hex": "7C-6D-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "20C9D0": {
        "oui_hex": "20-C9-D0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68967B": {
        "oui_hex": "68-96-7B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84FCFE": {
        "oui_hex": "84-FC-FE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E48B7F": {
        "oui_hex": "E4-8B-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "008865": {
        "oui_hex": "00-88-65",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC3BAF": {
        "oui_hex": "BC-3B-AF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CE072": {
        "oui_hex": "3C-E0-72",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38484C": {
        "oui_hex": "38-48-4C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A46706": {
        "oui_hex": "A4-67-06",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C5877": {
        "oui_hex": "8C-58-77",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CF05F": {
        "oui_hex": "7C-F0-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "804971": {
        "oui_hex": "80-49-71",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C3E6D": {
        "oui_hex": "6C-3E-6D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC6778": {
        "oui_hex": "BC-67-78",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D8D1CB": {
        "oui_hex": "D8-D1-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A8FAD8": {
        "oui_hex": "A8-FA-D8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B817C2": {
        "oui_hex": "B8-17-C2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7C11BE": {
        "oui_hex": "7C-11-BE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "283737": {
        "oui_hex": "28-37-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "50EAD6": {
        "oui_hex": "50-EA-D6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98D6BB": {
        "oui_hex": "98-D6-BB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "189EFC": {
        "oui_hex": "18-9E-FC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "ACCF5C": {
        "oui_hex": "AC-CF-5C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80006E": {
        "oui_hex": "80-00-6E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "848E0C": {
        "oui_hex": "84-8E-0C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C15C2": {
        "oui_hex": "3C-15-C2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C709F": {
        "oui_hex": "6C-70-9F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0F2FB": {
        "oui_hex": "C0-F2-FB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24E314": {
        "oui_hex": "24-E3-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80E650": {
        "oui_hex": "80-E6-50",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90FD61": {
        "oui_hex": "90-FD-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "087045": {
        "oui_hex": "08-70-45",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A88808": {
        "oui_hex": "A8-88-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A4C361": {
        "oui_hex": "A4-C3-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2CF0EE": {
        "oui_hex": "2C-F0-EE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C97F3": {
        "oui_hex": "5C-97-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D4F46F": {
        "oui_hex": "D4-F4-6F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6476BA": {
        "oui_hex": "64-76-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34E2FD": {
        "oui_hex": "34-E2-FD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04489A": {
        "oui_hex": "04-48-9A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0F61C": {
        "oui_hex": "F0-F6-1C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C2937": {
        "oui_hex": "8C-29-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B09FBA": {
        "oui_hex": "B0-9F-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C4DE9": {
        "oui_hex": "0C-4D-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0F5C6": {
        "oui_hex": "E0-F5-C6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0EDCD": {
        "oui_hex": "A0-ED-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0F249": {
        "oui_hex": "F0-F2-49",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "2857BE": {
        "oui_hex": "28-57-BE",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "5CF5DA": {
        "oui_hex": "5C-F5-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18EE69": {
        "oui_hex": "18-EE-69",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "649ABE": {
        "oui_hex": "64-9A-BE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F099BF": {
        "oui_hex": "F0-99-BF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "94E96A": {
        "oui_hex": "94-E9-6A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC293A": {
        "oui_hex": "AC-29-3A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9CFC01": {
        "oui_hex": "9C-FC-01",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C35EB": {
        "oui_hex": "9C-35-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48437C": {
        "oui_hex": "48-43-7C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34A395": {
        "oui_hex": "34-A3-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "787E61": {
        "oui_hex": "78-7E-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60F81D": {
        "oui_hex": "60-F8-1D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38C986": {
        "oui_hex": "38-C9-86",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D03311": {
        "oui_hex": "D0-33-11",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "507A55": {
        "oui_hex": "50-7A-55",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C8C2C6": {
        "oui_hex": "C8-C2-C6",
        "organization": "Shanghai Airm2m Communication Technology Co., Ltd",
        "address_1": "Rm.816,Building C,No.668,East Beijing Road,Huangpu District,Shanghai,China",
        "address_2": "Shang hai  Shang hai  200001",
        "country": "CN"
    },
    "789C85": {
        "oui_hex": "78-9C-85",
        "organization": "August Home, Inc.",
        "address_1": "657 Bryant Street",
        "address_2": "San Francisco  California  94107",
        "country": "US"
    },
    "74D7CA": {
        "oui_hex": "74-D7-CA",
        "organization": "Panasonic Corporation Automotive",
        "address_1": "5652",
        "address_2": "Matsumoto City  Nagano  399-8730",
        "country": "JP"
    },
    "5882A8": {
        "oui_hex": "58-82-A8",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "58685D": {
        "oui_hex": "58-68-5D",
        "organization": "Tempo Australia Pty Ltd",
        "address_1": "8/14 Rodborough Rd",
        "address_2": "Frenchs Forest  NSW  2086",
        "country": "AU"
    },
    "544B8C": {
        "oui_hex": "54-4B-8C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "DCFE07": {
        "oui_hex": "DC-FE-07",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "707938": {
        "oui_hex": "70-79-38",
        "organization": "Wuxi Zhanrui Electronic Technology Co.,LTD",
        "address_1": "Wuxi,Taihu West Road No.1188 Runhua International Building 1604",
        "address_2": "Wuxi  Jiangsu  214072",
        "country": "CN"
    },
    "243184": {
        "oui_hex": "24-31-84",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-Cho",
        "address_2": "Osaka-City  Osaka-Prefecture  545-8522",
        "country": "JP"
    },
    "582BDB": {
        "oui_hex": "58-2B-DB",
        "organization": "Pax AB",
        "address_1": "Box 72",
        "address_2": "Hälleforsnäs    64806",
        "country": "SE"
    },
    "E03676": {
        "oui_hex": "E0-36-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC388F": {
        "oui_hex": "EC-38-8F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D03E5C": {
        "oui_hex": "D0-3E-5C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C49E41": {
        "oui_hex": "C4-9E-41",
        "organization": "G24 Power Limited",
        "address_1": "South Lake Drive",
        "address_2": "Newport  Gwent  NP10 8AS",
        "country": "GB"
    },
    "B813E9": {
        "oui_hex": "B8-13-E9",
        "organization": "Trace Live Network",
        "address_1": "#200, 5970 Centre St SE",
        "address_2": "Calgary  Alberta  T2H0C1",
        "country": "CA"
    },
    "80B709": {
        "oui_hex": "80-B7-09",
        "organization": "Viptela, Inc",
        "address_1": "1740 Technology Drive, Ste#500",
        "address_2": "San Jose  California  95110",
        "country": "US"
    },
    "F00D5C": {
        "oui_hex": "F0-0D-5C",
        "organization": "JinQianMao  Technology Co.,Ltd.",
        "address_1": "58#,Jiangbin Road,Taijiang District",
        "address_2": "Fuzhou  Fujian  350009",
        "country": "CN"
    },
    "54BE53": {
        "oui_hex": "54-BE-53",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "280E8B": {
        "oui_hex": "28-0E-8B",
        "organization": "Beijing Spirit Technology Development Co., Ltd.",
        "address_1": "No. 26 Ave. 4 Chuangye Middle Road",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "F44D30": {
        "oui_hex": "F4-4D-30",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.239,Sec.2,Ti Ding Blvd.,",
        "address_2": "Taipei  Taipei",
        "country": "TW"
    },
    "0C8610": {
        "oui_hex": "0C-86-10",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "38D40B": {
        "oui_hex": "38-D4-0B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E83A12": {
        "oui_hex": "E8-3A-12",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "24DA9B": {
        "oui_hex": "24-DA-9B",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "30E090": {
        "oui_hex": "30-E0-90",
        "organization": "Linctronix Ltd,",
        "address_1": "​9F-1, No.66, Chongqing Rd.,",
        "address_2": "Banqiao Dist.,  China  22063",
        "country": "TW"
    },
    "A4DCBE": {
        "oui_hex": "A4-DC-BE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ECB870": {
        "oui_hex": "EC-B8-70",
        "organization": "Beijing Heweinet Technology Co.,Ltd.",
        "address_1": "1514 Room,15F,No.2 Building",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "94BBAE": {
        "oui_hex": "94-BB-AE",
        "organization": "Husqvarna AB",
        "address_1": "Drottninggatan 2",
        "address_2": "Huskvarna  Sweden  56131",
        "country": "SE"
    },
    "D40AA9": {
        "oui_hex": "D4-0A-A9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "203D66": {
        "oui_hex": "20-3D-66",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D494E8": {
        "oui_hex": "D4-94-E8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B078F0": {
        "oui_hex": "B0-78-F0",
        "organization": "Beijing HuaqinWorld Technology Co.,Ltd.",
        "address_1": "Beijing City, Chaoyang District Wangjing Garden Department Youle A District No. 3 building 308 room",
        "address_2": "Bejjing  Bejjing  100102",
        "country": "CN"
    },
    "209BCD": {
        "oui_hex": "20-9B-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3095E3": {
        "oui_hex": "30-95-E3",
        "organization": "SHANGHAI SIMCOM LIMITED",
        "address_1": "Building A,SIM Technology Building,No.633, Jinzhong Road,Changning District , Shanghai, P.R.China",
        "address_2": "Shanghai  /  200355",
        "country": "CN"
    },
    "80656D": {
        "oui_hex": "80-65-6D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCF136": {
        "oui_hex": "FC-F1-36",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "B88687": {
        "oui_hex": "B8-86-87",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "18895B": {
        "oui_hex": "18-89-5B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "584925": {
        "oui_hex": "58-49-25",
        "organization": "E3 Enterprise",
        "address_1": "32F, Shinjuku Nomura Building",
        "address_2": "  Tokyo  163-0532",
        "country": "JP"
    },
    "94F278": {
        "oui_hex": "94-F2-78",
        "organization": "Elma Electronic",
        "address_1": "44350 S. Grimmer Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "283713": {
        "oui_hex": "28-37-13",
        "organization": "Shenzhen 3Nod Digital Technology Co., Ltd.",
        "address_1": "Building D, No.8 Langhui Road, Tangxiayong Community, Songgang Street, Baoan District, Shenzhen City, Guangdong Province, P.R. China",
        "address_2": "Shenzhen  Guangdong  518105",
        "country": "CN"
    },
    "0894EF": {
        "oui_hex": "08-94-EF",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "No.38,East Keji Road,Zhongshan Torch Development Zone,Zhongshan City,Guangdong,China",
        "address_2": "Zhongshan  Guangdong  528437",
        "country": "CN"
    },
    "E0319E": {
        "oui_hex": "E0-31-9E",
        "organization": "Valve Corporation",
        "address_1": "10900 NE 4th ST",
        "address_2": "Bellevue  Washington  98004",
        "country": "US"
    },
    "3C5CC3": {
        "oui_hex": "3C-5C-C3",
        "organization": "Shenzhen First Blue Chip Technology Ltd",
        "address_1": "3Nod Smart Building,11Floor,No.3012,Binhai Avenue, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C49FF3": {
        "oui_hex": "C4-9F-F3",
        "organization": "Mciao Technologies, Inc.",
        "address_1": "Room304, Building 1, No.288 Qiuyi Rd., Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "788E33": {
        "oui_hex": "78-8E-33",
        "organization": "Jiangsu SEUIC Technology Co.,Ltd",
        "address_1": "NO23.Wenzhu Road.Yuhuatai Distrct.",
        "address_2": "Nanjing  Jiangsu Province  210012",
        "country": "CN"
    },
    "ECEED8": {
        "oui_hex": "EC-EE-D8",
        "organization": "ZTLX Network Technology Co.,Ltd",
        "address_1": "Unit 703,No 77,CuShaHuan",
        "address_2": "ZhuHai  GuangDong  519000",
        "country": "CN"
    },
    "80EB77": {
        "oui_hex": "80-EB-77",
        "organization": "Wistron Corporation",
        "address_1": "No. 158, SingShan Rd., Neihu, Taipei 11469, Taiwan, R.O.C.",
        "address_2": "Neihu  Taipei  11469",
        "country": ""
    },
    "483974": {
        "oui_hex": "48-39-74",
        "organization": "Proware Technologies Co., Ltd.",
        "address_1": "2nd F1 East Wing,South Section,Factory Building 24,Science&Technology Park, Shennan Rd, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "30FFF6": {
        "oui_hex": "30-FF-F6",
        "organization": "HangZhou KuoHeng Technology Co.,ltd",
        "address_1": "No.368,Wangjiali,Chang'ancun Industrial Park,Wenyan Town, Xiaoshan District, Hangzhou, CHina",
        "address_2": "HangZhou  ZheJiang  311258",
        "country": "CN"
    },
    "D8EFCD": {
        "oui_hex": "D8-EF-CD",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "4CC681": {
        "oui_hex": "4C-C6-81",
        "organization": "Shenzhen Aisat Electronic Co., Ltd.",
        "address_1": "Golden Building 419#, Design Park,",
        "address_2": "Shenzhen  Guangdong  518056",
        "country": "CN"
    },
    "48E244": {
        "oui_hex": "48-E2-44",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "7CAB25": {
        "oui_hex": "7C-AB-25",
        "organization": "MESMO TECHNOLOGY INC.",
        "address_1": "3F., No.181, ZHOUZI ST., NEIHU DIST.,",
        "address_2": "TAIPEI  TAIPEI  11493",
        "country": "TW"
    },
    "B0411D": {
        "oui_hex": "B0-41-1D",
        "organization": "ITTIM Technologies",
        "address_1": "B1606, No.6, Zhongguancun South Street,",
        "address_2": "Beijing  Beijing  100086",
        "country": "CN"
    },
    "F8BF09": {
        "oui_hex": "F8-BF-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CB25C": {
        "oui_hex": "7C-B2-5C",
        "organization": "Acacia Communications",
        "address_1": "3 Clock Tower Place",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "DCDB70": {
        "oui_hex": "DC-DB-70",
        "organization": "Tonfunk Systementwicklung und Service GmbH",
        "address_1": "Anger20",
        "address_2": "Falkenstein / Harz OT Ermsleben  Sachsen-Anhalt  06463",
        "country": "DE"
    },
    "800B51": {
        "oui_hex": "80-0B-51",
        "organization": "Chengdu XGimi Technology Co.,Ltd",
        "address_1": "5F Building A7,Tianfu Software Park,Tianfu",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "F80D60": {
        "oui_hex": "F8-0D-60",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "F0182B": {
        "oui_hex": "F0-18-2B",
        "organization": "LG Chem",
        "address_1": "128, Yeoui-daero, Yeongdeungpo-gu,",
        "address_2": "Seoul  Seoul  150-721",
        "country": "KR"
    },
    "3481F4": {
        "oui_hex": "34-81-F4",
        "organization": "SST Taiwan Ltd.",
        "address_1": "5F, No. 5, Industry E Rd. VII,",
        "address_2": "Hsin Chu,  Taiwan  30077",
        "country": "TW"
    },
    "7CA237": {
        "oui_hex": "7C-A2-37",
        "organization": "King Slide Technology CO., LTD.",
        "address_1": "No. 6, Luke 9th Rd.,",
        "address_2": "Kaohsiung  Taiwan  82151",
        "country": "TW"
    },
    "D404CD": {
        "oui_hex": "D4-04-CD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "584822": {
        "oui_hex": "58-48-22",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "747336": {
        "oui_hex": "74-73-36",
        "organization": "MICRODIGTAL Inc",
        "address_1": "10F, Ace High-End Tower 9th,",
        "address_2": "  Seoul  153-803",
        "country": "KR"
    },
    "382B78": {
        "oui_hex": "38-2B-78",
        "organization": "ECO PLUGS ENTERPRISE CO., LTD",
        "address_1": "10F,-6, No.117, Sec.2, Zhongbei Rd., Zhongli Dist.,",
        "address_2": "Taoyuan  Taiwan  32097",
        "country": "TW"
    },
    "A47B2C": {
        "oui_hex": "A4-7B-2C",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "24E5AA": {
        "oui_hex": "24-E5-AA",
        "organization": "Philips Oral Healthcare, Inc.",
        "address_1": "22100 Bothell Everett Hwy",
        "address_2": "Bothell  WA  98021",
        "country": "US"
    },
    "78BDBC": {
        "oui_hex": "78-BD-BC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "349B5B": {
        "oui_hex": "34-9B-5B",
        "organization": "Maquet GmbH",
        "address_1": "Kehler Strasse 31",
        "address_2": "Rastatt  Baden-Württemberg  76437",
        "country": "DE"
    },
    "884157": {
        "oui_hex": "88-41-57",
        "organization": "Shenzhen Atsmart Technology Co.,Ltd.",
        "address_1": "East 3F ,2 Building, Meijing Industry Park, Qiaoxiang Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "D89A34": {
        "oui_hex": "D8-9A-34",
        "organization": "Beijing SHENQI Technology Co., Ltd.",
        "address_1": "No.6 Shang Di West Road",
        "address_2": " Haidian District  Beijing  100085",
        "country": "CN"
    },
    "A0A65C": {
        "oui_hex": "A0-A6-5C",
        "organization": "Supercomputing Systems AG",
        "address_1": "Technoparkstrasse 1",
        "address_2": "Zurich  ZH  8005",
        "country": "CH"
    },
    "485073": {
        "oui_hex": "48-50-73",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "E8377A": {
        "oui_hex": "E8-37-7A",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "803B2A": {
        "oui_hex": "80-3B-2A",
        "organization": "ABB Xiamen Low Voltage Equipment Co.,Ltd.",
        "address_1": "No.12-20,3rd Chuang Xin Road",
        "address_2": "Xiamen SEZ  Fujian  361006",
        "country": "CN"
    },
    "C4EA1D": {
        "oui_hex": "C4-EA-1D",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "7CF90E": {
        "oui_hex": "7C-F9-0E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "50F0D3": {
        "oui_hex": "50-F0-D3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00A784": {
        "oui_hex": "00-A7-84",
        "organization": "ITX security",
        "address_1": "9F Kolon Digital Tower Aston Bldg",
        "address_2": "SEOUL  (Outside US/Canada/China)  441-813",
        "country": "KR"
    },
    "84119E": {
        "oui_hex": "84-11-9E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "149A10": {
        "oui_hex": "14-9A-10",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "38FACA": {
        "oui_hex": "38-FA-CA",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5CB43E": {
        "oui_hex": "5C-B4-3E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "707781": {
        "oui_hex": "70-77-81",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "54E140": {
        "oui_hex": "54-E1-40",
        "organization": "INGENICO",
        "address_1": "9 AVENUE DE LA GARE",
        "address_2": "VALENCE  DROME  26958",
        "country": "FR"
    },
    "E4907E": {
        "oui_hex": "E4-90-7E",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "746A3A": {
        "oui_hex": "74-6A-3A",
        "organization": "Aperi Corporation",
        "address_1": "360 Mobil Avenue",
        "address_2": "Camarillo  CA  93010",
        "country": "US"
    },
    "94A7B7": {
        "oui_hex": "94-A7-B7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1844E6": {
        "oui_hex": "18-44-E6",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "3CCE15": {
        "oui_hex": "3C-CE-15",
        "organization": "Mercedes-Benz USA, LLC",
        "address_1": "One Mercedes Drive",
        "address_2": "Montvale  NJ  07645",
        "country": "US"
    },
    "287610": {
        "oui_hex": "28-76-10",
        "organization": "IgniteNet",
        "address_1": "1, Creation 3rd Rd.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "20D75A": {
        "oui_hex": "20-D7-5A",
        "organization": "Posh Mobile Limited",
        "address_1": "1011A 10/F Harbour Centre Tower 1, 1 Hok Cheung Street",
        "address_2": "HungHom  Kowloon  00000",
        "country": "HK"
    },
    "F41563": {
        "oui_hex": "F4-15-63",
        "organization": "F5 Networks, Inc.",
        "address_1": "1322 North Whitman Lane",
        "address_2": "Liberty Lake  WA  99019",
        "country": "US"
    },
    "8C8B83": {
        "oui_hex": "8C-8B-83",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "4011DC": {
        "oui_hex": "40-11-DC",
        "organization": "Sonance",
        "address_1": "212 Avenida Fabricante",
        "address_2": "San Clemente  California  92672",
        "country": "US"
    },
    "1C8341": {
        "oui_hex": "1C-83-41",
        "organization": "Hefei Bitland Information Technology Co.Ltd",
        "address_1": "C1# Building, Bitland Industrial Park, No#4088, Jinxiu RD,Economic Development Zone, Hefei, Anhui, China",
        "address_2": "Hefei  Anhui  230061",
        "country": "CN"
    },
    "081FEB": {
        "oui_hex": "08-1F-EB",
        "organization": "BinCube",
        "address_1": "Si Ming Shan Road 116, Beilun",
        "address_2": "Ningbo  Zhejiang  315800",
        "country": "CN"
    },
    "785F4C": {
        "oui_hex": "78-5F-4C",
        "organization": "Argox Information Co., Ltd.",
        "address_1": "7F, No.126, Lane 235, Baoqiao Rd., Xindian Dist.",
        "address_2": "New Taipei City  Taipei  231",
        "country": "TW"
    },
    "34CC28": {
        "oui_hex": "34-CC-28",
        "organization": "Nexpring Co. LTD.,",
        "address_1": "3rd Floor, Building C, PDC Tower",
        "address_2": "Sungnam City  Kyungki-do  463400",
        "country": "KR"
    },
    "54E2C8": {
        "oui_hex": "54-E2-C8",
        "organization": "Dongguan Aoyuan Electronics Technology Co., Ltd",
        "address_1": "Factory A7 Zhen'an Sci-Tech Industrial Park, Chang'an Town, Dongguan City, Guangdong Province, China",
        "address_2": "Dongguan City  Guangdong Province  523863",
        "country": "CN"
    },
    "6C1E70": {
        "oui_hex": "6C-1E-70",
        "organization": "Guangzhou YBDS IT Co.,Ltd",
        "address_1": "Room 318,3/F,970 Kang Wang Bei Lu,Liwan District,Guangzhou,PRC",
        "address_2": "Guangzhou City  Guangdong Province  510170",
        "country": "CN"
    },
    "54B80A": {
        "oui_hex": "54-B8-0A",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "D8ADDD": {
        "oui_hex": "D8-AD-DD",
        "organization": "Sonavation, Inc.",
        "address_1": "3970 RCA Blvd.",
        "address_2": "Palm Beach Gardens  Florida  33410",
        "country": "US"
    },
    "8833BE": {
        "oui_hex": "88-33-BE",
        "organization": "Ivenix, Inc.",
        "address_1": "21 Water Street",
        "address_2": "Amesbury  MA  01913",
        "country": "US"
    },
    "E48D8C": {
        "oui_hex": "E4-8D-8C",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "706879": {
        "oui_hex": "70-68-79",
        "organization": "Saijo Denki International Co., Ltd.",
        "address_1": "39/9 Moo 9 Soi Duangmanee",
        "address_2": "Muang  Nonthaburi  11000",
        "country": "TH"
    },
    "10AF78": {
        "oui_hex": "10-AF-78",
        "organization": "Shenzhen ATUE Technology Co., Ltd",
        "address_1": "3/F,Building 2nd, Xintang Industry Zone,Fuyong Town,Bao'an District",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "CC19A8": {
        "oui_hex": "CC-19-A8",
        "organization": "PT Inovação e Sistemas SA",
        "address_1": "Rua Eng. José Ferreira Pinto Basto",
        "address_2": "Aveiro  Aveiro  3810-106",
        "country": "PT"
    },
    "B4B265": {
        "oui_hex": "B4-B2-65",
        "organization": "DAEHO I&T",
        "address_1": "211, Jayumuyeok 3-gil, MasanHoewon-gu",
        "address_2": "Changwon-si  Gyeongsangnam-do  630-812",
        "country": "KR"
    },
    "E03560": {
        "oui_hex": "E0-35-60",
        "organization": "Challenger Supply Holdings, LLC",
        "address_1": "4500 Mercantile Plaza Dr.",
        "address_2": "Fort Worth  TX  76137",
        "country": "US"
    },
    "3CCB7C": {
        "oui_hex": "3C-CB-7C",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "249EAB": {
        "oui_hex": "24-9E-AB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "244B03": {
        "oui_hex": "24-4B-03",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "E4CE70": {
        "oui_hex": "E4-CE-70",
        "organization": "Health & Life co., Ltd.",
        "address_1": "9F, No. 186, Jian Yi Road",
        "address_2": "New Taipei City  Taiwan  23553",
        "country": "TW"
    },
    "7C11CD": {
        "oui_hex": "7C-11-CD",
        "organization": "QianTang Technology",
        "address_1": "36 Landmark Palace",
        "address_2": "Beijing  Beijing  100125",
        "country": ""
    },
    "CCA4AF": {
        "oui_hex": "CC-A4-AF",
        "organization": "Shenzhen Sowell Technology Co., LTD",
        "address_1": "7F, Yizhe Building. Yuquan Road.",
        "address_2": "Shen Zhen  Guang Dong  518052",
        "country": "CN"
    },
    "102C83": {
        "oui_hex": "10-2C-83",
        "organization": "XIMEA",
        "address_1": "Lesna 52",
        "address_2": "Marianka  SK  90033",
        "country": "SK"
    },
    "6CA75F": {
        "oui_hex": "6C-A7-5F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "8C7967": {
        "oui_hex": "8C-79-67",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "7858F3": {
        "oui_hex": "78-58-F3",
        "organization": "Vachen Co.,Ltd",
        "address_1": "Rm1206, Hanyang Bldg, 18, Gukhoe-daero 70-gil, Yeongdeungpo-gu",
        "address_2": "Seoul  Seoul  150-748",
        "country": "KR"
    },
    "709C8F": {
        "oui_hex": "70-9C-8F",
        "organization": "Nero AG",
        "address_1": "Rueppurrer Str. 1A",
        "address_2": "Karlsruhe  BW  76137",
        "country": "DE"
    },
    "007E56": {
        "oui_hex": "00-7E-56",
        "organization": "China Dragon Technology Limited",
        "address_1": "B4 Bldg.Haoshan 1st Industry Park,",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "74E28C": {
        "oui_hex": "74-E2-8C",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "0071C2": {
        "oui_hex": "00-71-C2",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "7C8274": {
        "oui_hex": "7C-82-74",
        "organization": "Shenzhen Hikeen Technology CO.,LTD",
        "address_1": "15rd floor,unit1,Building A of Kexing Science Park",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "94D417": {
        "oui_hex": "94-D4-17",
        "organization": "GPI KOREA INC.",
        "address_1": "Daebang Triplaon B-Dong 201",
        "address_2": "Goyang-Si  Kyeonggi-Do  410-704",
        "country": "KR"
    },
    "244B81": {
        "oui_hex": "24-4B-81",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "704E66": {
        "oui_hex": "70-4E-66",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D855A3": {
        "oui_hex": "D8-55-A3",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "38D82F": {
        "oui_hex": "38-D8-2F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F07959": {
        "oui_hex": "F0-79-59",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "E08E3C": {
        "oui_hex": "E0-8E-3C",
        "organization": "Aztech Electronics Pte Ltd",
        "address_1": "31, Ubi Road 1",
        "address_2": "Singapore  Singapore  408694",
        "country": "SG"
    },
    "844BB7": {
        "oui_hex": "84-4B-B7",
        "organization": "Beijing Sankuai Online Technology Co.,Ltd",
        "address_1": "Block F&G, Wangjing International R & D Park,",
        "address_2": "Chaoyang District  BEIJING  100102",
        "country": "CN"
    },
    "68F0BC": {
        "oui_hex": "68-F0-BC",
        "organization": "Shenzhen LiWiFi Technology Co., Ltd",
        "address_1": "No.7, Xinxi Road, Hi-Tech Park (North Zone)",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "300EE3": {
        "oui_hex": "30-0E-E3",
        "organization": "Aquantia Corporation",
        "address_1": "700 Tasman Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "18F145": {
        "oui_hex": "18-F1-45",
        "organization": "NetComm Wireless Limited",
        "address_1": "Level 2, 18-20 Orion Road",
        "address_2": "Lane Cove  Sydney  2066",
        "country": "AU"
    },
    "ACABBF": {
        "oui_hex": "AC-AB-BF",
        "organization": "AthenTek Inc.",
        "address_1": "8F., No.356, Sec. 1, Neihu Rd., Neihu Dist.,",
        "address_2": "Taipei City  Taiwan  114",
        "country": "TW"
    },
    "2884FA": {
        "oui_hex": "28-84-FA",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "60AF6D": {
        "oui_hex": "60-AF-6D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B85A73": {
        "oui_hex": "B8-5A-73",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3C1E04": {
        "oui_hex": "3C-1E-04",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "60D9A0": {
        "oui_hex": "60-D9-A0",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information & Optoelectronics Park,",
        "address_2": "Xiamen  Fujian  361006",
        "country": ""
    },
    "68B983": {
        "oui_hex": "68-B9-83",
        "organization": "b-plus GmbH",
        "address_1": "Ulrichsberger Str. 17",
        "address_2": "Deggendorf  Bavaria  94469",
        "country": "DE"
    },
    "78B3B9": {
        "oui_hex": "78-B3-B9",
        "organization": "ShangHai sunup lighting CO.,LTD",
        "address_1": "RM2508,Building 2,1077# Zu Chong Zhi Rd,Zhang Jiang Hi-Tech Park,Pudong New Area,ShangHai,China",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "04C09C": {
        "oui_hex": "04-C0-9C",
        "organization": "Tellabs Inc.",
        "address_1": "1415 W. Diehl Road",
        "address_2": "Naperville  Illinois  60563",
        "country": "US"
    },
    "981DFA": {
        "oui_hex": "98-1D-FA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "186882": {
        "oui_hex": "18-68-82",
        "organization": "Beward R&D Co., Ltd.",
        "address_1": "Molokova street 16, apt.355",
        "address_2": "Krasnoyarsk  Krasnoyarsk region  660118",
        "country": "RU"
    },
    "EC8009": {
        "oui_hex": "EC-80-09",
        "organization": "NovaSparks",
        "address_1": "12 rue de Chatillon",
        "address_2": "Paris  Ile de France  75014",
        "country": "FR"
    },
    "50ADD5": {
        "oui_hex": "50-AD-D5",
        "organization": "Dynalec Corporation",
        "address_1": "87 West Main Street",
        "address_2": "Sodus  NY  14551",
        "country": "US"
    },
    "B04519": {
        "oui_hex": "B0-45-19",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "D88D5C": {
        "oui_hex": "D8-8D-5C",
        "organization": "Elentec",
        "address_1": "Dongtangiheung-ro 64-3",
        "address_2": "Gyeonggi-do  Hwaseong-si/Dongtan-myeon  445-812",
        "country": "KR"
    },
    "7429AF": {
        "oui_hex": "74-29-AF",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "3C1A0F": {
        "oui_hex": "3C-1A-0F",
        "organization": "ClearSky Data",
        "address_1": "99 Summer Street",
        "address_2": "Boston  MA  02110",
        "country": "US"
    },
    "E8CC18": {
        "oui_hex": "E8-CC-18",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "B09137": {
        "oui_hex": "B0-91-37",
        "organization": "ISis ImageStream Internet Solutions, Inc",
        "address_1": "4374 FM 1518",
        "address_2": "Selma  TX  78154",
        "country": "US"
    },
    "8C0551": {
        "oui_hex": "8C-05-51",
        "organization": "Koubachi AG",
        "address_1": "Technoparkstrasse 1",
        "address_2": "Zurich  Zurich  8005",
        "country": "CH"
    },
    "D897BA": {
        "oui_hex": "D8-97-BA",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "A8D88A": {
        "oui_hex": "A8-D8-8A",
        "organization": "Wyconn",
        "address_1": "Rennweg 97-99",
        "address_2": "Vienna    1030",
        "country": "AT"
    },
    "40EACE": {
        "oui_hex": "40-EA-CE",
        "organization": "FOUNDER BROADBAND NETWORK SERVICE CO.,LTD",
        "address_1": "5F,Tower B,Beifa Plaza,No.16 Building",
        "address_2": "Haisdian District  Beijing  100088",
        "country": "CN"
    },
    "848EDF": {
        "oui_hex": "84-8E-DF",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "A49D49": {
        "oui_hex": "A4-9D-49",
        "organization": "Ketra, Inc.",
        "address_1": "3815 S. Capital of Texas Hwy",
        "address_2": "Austin  TX  78704",
        "country": "US"
    },
    "C03896": {
        "oui_hex": "C0-38-96",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "2C5089": {
        "oui_hex": "2C-50-89",
        "organization": "Shenzhen Kaixuan Visual Technology Co.,Limited",
        "address_1": "No.19th Xifu Road, Hongxing Community",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "948E89": {
        "oui_hex": "94-8E-89",
        "organization": "INDUSTRIAS UNIDAS SA DE CV",
        "address_1": "CARRETERA PANAMERICANA",
        "address_2": "PASTEJE JOCOTITLAN  ESTADO DE MEXICO  50700",
        "country": "MX"
    },
    "00AEFA": {
        "oui_hex": "00-AE-FA",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "841826": {
        "oui_hex": "84-18-26",
        "organization": "Osram GmbH",
        "address_1": "Marcel Breuer Str. 6",
        "address_2": "Munich  Bavaria  80807",
        "country": "DE"
    },
    "F8E903": {
        "oui_hex": "F8-E9-03",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "E89606": {
        "oui_hex": "E8-96-06",
        "organization": "testo Instruments (Shenzhen) Co., Ltd.",
        "address_1": "China Merchants Guangming Science & Technology Park,",
        "address_2": "Guangming New District, Shenzhen  Guangdong  518107",
        "country": "CN"
    },
    "1C7E51": {
        "oui_hex": "1C-7E-51",
        "organization": "3bumen.com",
        "address_1": "11/F FRONT BLK HANG LOK BLDG",
        "address_2": "HONG KONG  KONG KONG  N/A",
        "country": "HK"
    },
    "6872DC": {
        "oui_hex": "68-72-DC",
        "organization": "CETORY.TV Company Limited",
        "address_1": "Building C-1601, Tiley Central Plaza",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "3077CB": {
        "oui_hex": "30-77-CB",
        "organization": "Maike Industry(Shenzhen)CO.,LTD",
        "address_1": "Maike Industrial Garden, Sanwei village,",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "2497ED": {
        "oui_hex": "24-97-ED",
        "organization": "Techvision Intelligent Technology Limited",
        "address_1": "Room 7006B, Tianxia IC Industry Building,",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "909F33": {
        "oui_hex": "90-9F-33",
        "organization": "EFM Networks",
        "address_1": "6F, Benposra II 1197-1 Bojeong Giheung Gu",
        "address_2": "Yong In  Kyunggi do  446913",
        "country": "KR"
    },
    "600417": {
        "oui_hex": "60-04-17",
        "organization": "POSBANK CO.,LTD",
        "address_1": "Room 805-808, New T Castle B/D, 429-1",
        "address_2": "  Seoul  153-803",
        "country": "KR"
    },
    "207693": {
        "oui_hex": "20-76-93",
        "organization": "Lenovo (Beijing) Limited.",
        "address_1": "No.6 Chuang Ye Road Shangdi Information Industry Base,",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "084656": {
        "oui_hex": "08-46-56",
        "organization": "VEO-LABS",
        "address_1": "14 rue du Patis Tatelin",
        "address_2": "RENNES  Bretagne  35700",
        "country": "FR"
    },
    "EC3C5A": {
        "oui_hex": "EC-3C-5A",
        "organization": "SHEN ZHEN HENG SHENG HUI DIGITAL TECHNOLOGY CO.,LTD",
        "address_1": "5A 6FLOOR, BLOCK C12, FUYUAN INDUSTRIAL AREA, ZHOU SHI ROAD,",
        "address_2": "SHENZHEN  GUANGDONG  518102",
        "country": "CN"
    },
    "4488CB": {
        "oui_hex": "44-88-CB",
        "organization": "Camco Technologies NV",
        "address_1": "Technologielaan 13",
        "address_2": "Heverlee  VB  3001",
        "country": "BE"
    },
    "6CBFB5": {
        "oui_hex": "6C-BF-B5",
        "organization": "Noon Technology Co., Ltd",
        "address_1": "Building C, Zhangkeng Industrial Park, Minzhi",
        "address_2": "Shenzhen  GuangDong  518131",
        "country": "CN"
    },
    "50294D": {
        "oui_hex": "50-29-4D",
        "organization": "NANJING IOT SENSOR TECHNOLOGY CO,LTD",
        "address_1": "ROOM 422 NO.420 ZHONGHUA ROAD QINHUAI DISTRICT NANJING CITY",
        "address_2": "Nangjing  jiangsu  210000",
        "country": "CN"
    },
    "0CCFD1": {
        "oui_hex": "0C-CF-D1",
        "organization": "SPRINGWAVE Co., Ltd",
        "address_1": "#B-703,U-space 1-danji,670 Sampyeong-dong Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "74BADB": {
        "oui_hex": "74-BA-DB",
        "organization": "Longconn Electornics(shenzhen)Co.,Ltd",
        "address_1": "Building D12,n 30,Xingye One Road,Fenghuang First Industrial Zone,Fuyong Street,Bao an District,Shenzhen,Guangdong Province.",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "B8F317": {
        "oui_hex": "B8-F3-17",
        "organization": "iSun Smasher Communications Private Limited",
        "address_1": "No. 826, Ferns Paradise, 2nd Street,",
        "address_2": "Bangalore  Karnataka  560037",
        "country": "IN"
    },
    "8CF813": {
        "oui_hex": "8C-F8-13",
        "organization": "ORANGE POLSKA",
        "address_1": "AL.JEROZOLIMSKIE 160",
        "address_2": "WARSAW  MASOVIA  02-326",
        "country": "PL"
    },
    "549F35": {
        "oui_hex": "54-9F-35",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "2442BC": {
        "oui_hex": "24-42-BC",
        "organization": "Alinco,incorporated",
        "address_1": "Yodoyabashi Dai-Bldg 13F,",
        "address_2": "Osaka  Osaka pref.  541-0043",
        "country": "JP"
    },
    "F82441": {
        "oui_hex": "F8-24-41",
        "organization": "Yeelink",
        "address_1": "F10-B4, Bldg. B, International Innovation Park",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "108A1B": {
        "oui_hex": "10-8A-1B",
        "organization": "RAONIX Inc.",
        "address_1": "Changeop-Center 710, Shin-Gu Univ. Gwangmyeong-ro 377, Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  462-743",
        "country": "KR"
    },
    "102F6B": {
        "oui_hex": "10-2F-6B",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "8CB094": {
        "oui_hex": "8C-B0-94",
        "organization": "Airtech I&C Co., Ltd",
        "address_1": "33B-9L #613-9, Namchon-dong",
        "address_2": "Namdong-gu  Incheon  405-846",
        "country": "KR"
    },
    "945493": {
        "oui_hex": "94-54-93",
        "organization": "Rigado, LLC",
        "address_1": "2601 25th ST SE, STE 200",
        "address_2": "Salem  OR  97302",
        "country": "US"
    },
    "68F06D": {
        "oui_hex": "68-F0-6D",
        "organization": "ALONG INDUSTRIAL CO., LIMITED",
        "address_1": "FLAT/RM,3 11/F, HUNG TO INDUSTRIAL BUILDING",
        "address_2": "  HONG KONG",
        "country": "HK"
    },
    "F42853": {
        "oui_hex": "F4-28-53",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "A1&A2 Building,Lantian Technology Park, Xinyu Road, Xingqiao Henggang Block, Shajing Street, Baoan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "D4EC86": {
        "oui_hex": "D4-EC-86",
        "organization": "LinkedHope Intelligent Technologies Co., Ltd",
        "address_1": "2nd Floor,Building 1, Science Park,",
        "address_2": "Beijing  Beijing  100070",
        "country": "CN"
    },
    "1C9C26": {
        "oui_hex": "1C-9C-26",
        "organization": "Zoovel Technologies",
        "address_1": "Paseo de la Castellana 259C",
        "address_2": "  Madrid  28046",
        "country": "ES"
    },
    "046785": {
        "oui_hex": "04-67-85",
        "organization": "scemtec Hard- und Software fuer Mess- und Steuerungstechnik GmbH",
        "address_1": "Gewerbeparkstr. 20",
        "address_2": "Reichshof-Wehnrath  NRW  51580",
        "country": ""
    },
    "D0FA1D": {
        "oui_hex": "D0-FA-1D",
        "organization": "Qihoo  360  Technology Co.,Ltd",
        "address_1": "Building 2，6 Haoyuan",
        "address_2": "Chaoyang District  Beijing  100015",
        "country": "CN"
    },
    "AC11D3": {
        "oui_hex": "AC-11-D3",
        "organization": "Suzhou HOTEK  Video Technology Co. Ltd",
        "address_1": "No.78,Keling Road,Suzhou National new and hi-tech industrial Development zone",
        "address_2": "Suzhou  Jiangsu  215200",
        "country": "CN"
    },
    "8432EA": {
        "oui_hex": "84-32-EA",
        "organization": "ANHUI WANZTEN P&T CO., LTD",
        "address_1": "9F Building B1 HUAYI science Park",
        "address_2": "Hefei  Anhui Province  230088",
        "country": "CN"
    },
    "E01D38": {
        "oui_hex": "E0-1D-38",
        "organization": "Beijing HuaqinWorld Technology Co.,Ltd",
        "address_1": "30F,Beijing Silver Tower",
        "address_2": "Chao Yang Dist  Beijing  100027",
        "country": "CN"
    },
    "E47FB2": {
        "oui_hex": "E4-7F-B2",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "FC6DC0": {
        "oui_hex": "FC-6D-C0",
        "organization": "BME CORPORATION",
        "address_1": "147-2",
        "address_2": "Kawagoe-shi  Saitama  350-0845",
        "country": "JP"
    },
    "24D13F": {
        "oui_hex": "24-D1-3F",
        "organization": "MEXUS CO.,LTD",
        "address_1": "1512, Seoulsup IT Valley,",
        "address_2": "Seoul  Seoul  133-822",
        "country": "KR"
    },
    "7824AF": {
        "oui_hex": "78-24-AF",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "FC9FE1": {
        "oui_hex": "FC-9F-E1",
        "organization": "CONWIN.Tech. Ltd",
        "address_1": "4D,Tianxia IC Bldg,115 Yiyuan road, Nanshan District,Shenzhen,Guangdong,P.P.China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B89BE4": {
        "oui_hex": "B8-9B-E4",
        "organization": "ABB Power Systems Power Generation",
        "address_1": "29801 Euclid Ave",
        "address_2": "Wickliffe  Ohio  44092",
        "country": "US"
    },
    "A81B5D": {
        "oui_hex": "A8-1B-5D",
        "organization": "Foxtel Management Pty Ltd",
        "address_1": "Building 3, Level 3",
        "address_2": "NORTH RYDE  NSW  2113",
        "country": "AU"
    },
    "505065": {
        "oui_hex": "50-50-65",
        "organization": "TAKT Corporation",
        "address_1": "2762-8",
        "address_2": "Chino-City  Nagano-Pref.  391-0001",
        "country": "JP"
    },
    "40C62A": {
        "oui_hex": "40-C6-2A",
        "organization": "Shanghai Jing Ren Electronic Technology Co., Ltd.",
        "address_1": "GUI Qing Road 7 No. 3 building G7 software base A District 208 room",
        "address_2": "Xuhui District  Shanghai City  200233",
        "country": "CN"
    },
    "E8150E": {
        "oui_hex": "E8-15-0E",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "C44202": {
        "oui_hex": "C4-42-02",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B4AE6F": {
        "oui_hex": "B4-AE-6F",
        "organization": "Circle Reliance, Inc DBA Cranberry Networks",
        "address_1": "921 Rose Avenue",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "90DA6A": {
        "oui_hex": "90-DA-6A",
        "organization": "FOCUS H&S Co., Ltd.",
        "address_1": "#113, Doosan Venture Digm, 126-1",
        "address_2": "Anyang  Gyeonggi-Do  431-755",
        "country": "KR"
    },
    "DC537C": {
        "oui_hex": "DC-53-7C",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "44A6E5": {
        "oui_hex": "44-A6-E5",
        "organization": "THINKING TECHNOLOGY CO.,LTD",
        "address_1": "The 6th Floor,Gate No. 3 of Huaqiang Logistics Building",
        "address_2": "Nanshan, Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "A45DA1": {
        "oui_hex": "A4-5D-A1",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO  ITALY  20126",
        "country": ""
    },
    "0CAC05": {
        "oui_hex": "0C-AC-05",
        "organization": "Unitend Technologies Inc.",
        "address_1": "No.6 Nanda'an Hutong, Xizhimeng st",
        "address_2": "Zicheng District  Beijing  100035",
        "country": "CN"
    },
    "4C6E6E": {
        "oui_hex": "4C-6E-6E",
        "organization": "Comnect Technology CO.,LTD",
        "address_1": "7-402, Xinyuan Industrial Park, No.61",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "8C3357": {
        "oui_hex": "8C-33-57",
        "organization": "HiteVision Digital Media Technology Co.,Ltd.",
        "address_1": "1st building,Honghui Industrial Park,LiuXian",
        "address_2": "Shenzhen  Guangdong  510008",
        "country": "CN"
    },
    "3CAA3F": {
        "oui_hex": "3C-AA-3F",
        "organization": "iKey, Ltd.",
        "address_1": "2621 Ridgepoint Drive",
        "address_2": "Austin  Texas  78754",
        "country": "US"
    },
    "0C383E": {
        "oui_hex": "0C-38-3E",
        "organization": "Fanvil Technology Co., Ltd.",
        "address_1": "3F, Block A, Gaoxinqi Building, Anhua Industrial Park",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "60CDA9": {
        "oui_hex": "60-CD-A9",
        "organization": "Abloomy",
        "address_1": "Room 501 ,CTS Building,No 1 Beishatan Chaoyang District",
        "address_2": "BeiJing    100083",
        "country": "CN"
    },
    "B8AD3E": {
        "oui_hex": "B8-AD-3E",
        "organization": "BLUECOM",
        "address_1": "116, Venture-ro, Yeonsu-gu,",
        "address_2": "Incheon    406-840",
        "country": "KR"
    },
    "183009": {
        "oui_hex": "18-30-09",
        "organization": "Woojin Industrial Systems Co., Ltd.",
        "address_1": "95, Sari-ro, Sari-myeon",
        "address_2": "Goesan-gun  Chungcheongbuk-do  367-822",
        "country": "KR"
    },
    "74DBD1": {
        "oui_hex": "74-DB-D1",
        "organization": "Ebay Inc",
        "address_1": "2211 N. First St",
        "address_2": "San Jose  Ca  95131",
        "country": "US"
    },
    "30B5F1": {
        "oui_hex": "30-B5-F1",
        "organization": "Aitexin Technology Co., Ltd",
        "address_1": "1210 PDAY research center streer 2",
        "address_2": "Peiking    100190",
        "country": "CN"
    },
    "B01041": {
        "oui_hex": "B0-10-41",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "80AD67": {
        "oui_hex": "80-AD-67",
        "organization": "Kasda Networks Inc",
        "address_1": "B-31 Building, Tanglang Industry Zone, Xili, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "18D5B6": {
        "oui_hex": "18-D5-B6",
        "organization": "SMG Holdings LLC",
        "address_1": "205 N Michigan Ave",
        "address_2": "Chicago  IL  60601",
        "country": "US"
    },
    "5C2E59": {
        "oui_hex": "5C-2E-59",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A8E539": {
        "oui_hex": "A8-E5-39",
        "organization": "Moimstone Co.,Ltd",
        "address_1": "4F, 954-9 Gwanyang-dong",
        "address_2": "Anyang-Si  Gyeonggi-do  431-060",
        "country": "KR"
    },
    "54B753": {
        "oui_hex": "54-B7-53",
        "organization": "Hunan Fenghui Yinjia Science And Technology Co.,Ltd",
        "address_1": "No.15 Lutian Road",
        "address_2": "Changsha  Hunan  410205",
        "country": "CN"
    },
    "103047": {
        "oui_hex": "10-30-47",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F884F2": {
        "oui_hex": "F8-84-F2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0754D": {
        "oui_hex": "B0-75-4D",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "E0CBEE": {
        "oui_hex": "E0-CB-EE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4C3909": {
        "oui_hex": "4C-39-09",
        "organization": "HPL Electric & Power Private Limited",
        "address_1": "133, Pace City-1, Sec-37",
        "address_2": "Gurgaon  Haryana  122001",
        "country": "IN"
    },
    "907EBA": {
        "oui_hex": "90-7E-BA",
        "organization": "UTEK TECHNOLOGY (SHENZHEN) CO.,LTD",
        "address_1": "6F, C Building JiaAn Industrial Zone, 72# district of Baoan, ShenZhen, China",
        "address_2": "SHENZHEN  Guangdong Province  518101",
        "country": "CN"
    },
    "A002DC": {
        "oui_hex": "A0-02-DC",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "542AA2": {
        "oui_hex": "54-2A-A2",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing 7th Rd., Science-based Industrial Park, Hsinchu, Taiwan, R.O.C",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "84948C": {
        "oui_hex": "84-94-8C",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "A8F7E0": {
        "oui_hex": "A8-F7-E0",
        "organization": "PLANET Technology Corporation",
        "address_1": "11F, No. 96, Min Quan Road,",
        "address_2": "New Taipei City    22341",
        "country": "TW"
    },
    "4486C1": {
        "oui_hex": "44-86-C1",
        "organization": "Siemens Low Voltage & Products",
        "address_1": "5400 Triangle Parkway",
        "address_2": "Norcross  GA  30092",
        "country": "US"
    },
    "4045DA": {
        "oui_hex": "40-45-DA",
        "organization": "Spreadtrum Communications (Shanghai) Co., Ltd.",
        "address_1": "Building 1, Spreadtrum Center, No.2288, Zuchongzhi Rd",
        "address_2": "  Shanghai  201203",
        "country": ""
    },
    "3451AA": {
        "oui_hex": "34-51-AA",
        "organization": "JID GLOBAL",
        "address_1": "211, Biz Plus Suwon 2F Chungho Bldg, 17 363Road, Susung-ro",
        "address_2": "SUWON  Gyeonggi-do  440-846",
        "country": "KR"
    },
    "98BE94": {
        "oui_hex": "98-BE-94",
        "organization": "IBM",
        "address_1": "3039 E Cornwallis Rd",
        "address_2": "Research Triangle Park  NC  27709",
        "country": "US"
    },
    "6C198F": {
        "oui_hex": "6C-19-8F",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "C8FF77": {
        "oui_hex": "C8-FF-77",
        "organization": "Dyson Limited",
        "address_1": "Tetbury Hill",
        "address_2": "Malmesbury  Wiltshire  SN16 0RP",
        "country": "GB"
    },
    "B49EAC": {
        "oui_hex": "B4-9E-AC",
        "organization": "Imagik Int'l Corp",
        "address_1": "2299 SW 37 th Ave",
        "address_2": "Miami  Florida  33145",
        "country": "US"
    },
    "CC07E4": {
        "oui_hex": "CC-07-E4",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information &amp; Optoelectronics Park, Torch Hi-tech Industry Development Zone, Xiamen, P.R.China",
        "address_2": "Xiamen  Fujian  361006",
        "country": "US"
    },
    "C46BB4": {
        "oui_hex": "C4-6B-B4",
        "organization": "myIDkey",
        "address_1": "65 Enterprise",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "0C63FC": {
        "oui_hex": "0C-63-FC",
        "organization": "Nanjing Signway Technology Co., Ltd",
        "address_1": "Rm 1001,10/F,28 Ningshuang Rd,",
        "address_2": "Nanjing  Jiangsu  210012",
        "country": "CN"
    },
    "D4E08E": {
        "oui_hex": "D4-E0-8E",
        "organization": "ValueHD Corporation",
        "address_1": "Xinwei Xili, Nanshan District, Shenzhen City Industrial Zone, Shiling 8, 3rd Floor, North",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "C89F1D": {
        "oui_hex": "C8-9F-1D",
        "organization": "SHENZHEN COMMUNICATION TECHNOLOGIES CO.,LTD",
        "address_1": "NO.6 QINGNING ROAD,CAIHUANG INDUSTRY PARK,",
        "address_2": "SHENZHEN  GUANGDONG  518109",
        "country": "CN"
    },
    "143DF2": {
        "oui_hex": "14-3D-F2",
        "organization": "Beijing Shidai Hongyuan Network Communication Co.,Ltd",
        "address_1": "#505, 5F, Tower 3",
        "address_2": "  Beijing  100000",
        "country": "CN"
    },
    "2C39C1": {
        "oui_hex": "2C-39-C1",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "54EE75": {
        "oui_hex": "54-EE-75",
        "organization": "Wistron InfoComm(Kunshan)Co.,Ltd.",
        "address_1": "168# First Avenue,Kunshan Integrated Free Trade Zone,Kunshan,Jiangsu,China",
        "address_2": "Kunshan  Jiangsu  215300",
        "country": "CN"
    },
    "0874F6": {
        "oui_hex": "08-74-F6",
        "organization": "Winterhalter Gastronom GmbH",
        "address_1": "Tettnanger Straße 72",
        "address_2": "Meckenbeuren  Baden-Württemberg  88074",
        "country": "DE"
    },
    "D8492F": {
        "oui_hex": "D8-49-2F",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "800E24": {
        "oui_hex": "80-0E-24",
        "organization": "ForgetBox",
        "address_1": "61 rue de Sèvres",
        "address_2": "Ville d'Avray  IDF  92140",
        "country": "FR"
    },
    "3C25D7": {
        "oui_hex": "3C-25-D7",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "30A8DB": {
        "oui_hex": "30-A8-DB",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "18FF2E": {
        "oui_hex": "18-FF-2E",
        "organization": "Shenzhen Rui Ying Da Technology Co., Ltd",
        "address_1": "KaiXinda Electronic Science and Technology Park, Zhoushi Road 49,Shiyan Street,Baoan  District,ShenZhen,China",
        "address_2": "shenzhen  guangdong  518108",
        "country": "CN"
    },
    "847207": {
        "oui_hex": "84-72-07",
        "organization": "I&C Technology",
        "address_1": "24,Pangyo-ro 255beon-gil, Bundang-gu, Seongnam-si, Gyeonggi-do, 463-400,Korea",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400,Korea",
        "country": "US"
    },
    "CCA614": {
        "oui_hex": "CC-A6-14",
        "organization": "AIFA TECHNOLOGY CORP.",
        "address_1": "1F., No.230, Sec. 2, Bade Rd., Fongshan Dist.",
        "address_2": "Kaohsiung City  Taiwan  83053",
        "country": "TW"
    },
    "90F1B0": {
        "oui_hex": "90-F1-B0",
        "organization": "Hangzhou Anheng Info&Tech CO.,LTD",
        "address_1": "15F Zhongcai Bldg,#68 Tonghe Rd",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "4C8B30": {
        "oui_hex": "4C-8B-30",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0805CD": {
        "oui_hex": "08-05-CD",
        "organization": "DongGuang EnMai Electronic Product Co.Ltd.",
        "address_1": "701 7th Floor,YiFeng Building,",
        "address_2": "DongGuang  GuangDong Province  523843",
        "country": "CN"
    },
    "54D163": {
        "oui_hex": "54-D1-63",
        "organization": "MAX-TECH,INC",
        "address_1": "2F, 26, 2gil, Dujeonggongdan",
        "address_2": "Cheonan  Chungnam  331957",
        "country": "KR"
    },
    "48B5A7": {
        "oui_hex": "48-B5-A7",
        "organization": "Glory Horse Industries Ltd.",
        "address_1": "Woekshop 8, 4/F., World Wide Industrial Centre,",
        "address_2": "Shatin, N.T.    HKG",
        "country": "HK"
    },
    "0C4F5A": {
        "oui_hex": "0C-4F-5A",
        "organization": "ASA-RT s.r.l.",
        "address_1": "Strada del Lionetto 16/a",
        "address_2": "Torino  To  10146",
        "country": "IT"
    },
    "D4224E": {
        "oui_hex": "D4-22-4E",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "9C86DA": {
        "oui_hex": "9C-86-DA",
        "organization": "Phoenix Geophysics Ltd.",
        "address_1": "3781 Victoria Park Ave.",
        "address_2": "Toronto  ON  M1W 3K5",
        "country": "CA"
    },
    "2C073C": {
        "oui_hex": "2C-07-3C",
        "organization": "DEVLINE LIMITED",
        "address_1": "FLAT/RM A9,9/F SILVERCORP INT TOWER",
        "address_2": "  HONGKONG  999077",
        "country": "CN"
    },
    "7C1A03": {
        "oui_hex": "7C-1A-03",
        "organization": "8Locations Co., Ltd.",
        "address_1": "1F, No. 123, Chenggong 2rd Street",
        "address_2": "Zhube City  Hsinchu  302",
        "country": "TW"
    },
    "ACB859": {
        "oui_hex": "AC-B8-59",
        "organization": "Uniband Electronic Corp,",
        "address_1": "6F-1 No. Dongguang Rd.,",
        "address_2": "Hsinchu  300  300",
        "country": "TW"
    },
    "2C9AA4": {
        "oui_hex": "2C-9A-A4",
        "organization": "Eolo SpA",
        "address_1": "via Gran San Bernardo 12",
        "address_2": "Busto Arsizio  VA  21052",
        "country": "IT"
    },
    "88B1E1": {
        "oui_hex": "88-B1-E1",
        "organization": " Mojo Networks, Inc.",
        "address_1": "339 N.Bernardo Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "90DB46": {
        "oui_hex": "90-DB-46",
        "organization": "E-LEAD ELECTRONIC CO., LTD",
        "address_1": "NO.37, GUNGDUNG 1ST RD.",
        "address_2": "SHENGANG SHIANG  CHANGHUA  50971",
        "country": "TW"
    },
    "344F5C": {
        "oui_hex": "34-4F-5C",
        "organization": "R&amp;M AG",
        "address_1": "Binzstrasse 32",
        "address_2": "Wetzikon  Zurich  8620",
        "country": "CH"
    },
    "6047D4": {
        "oui_hex": "60-47-D4",
        "organization": "FORICS Electronic Technology Co., Ltd.",
        "address_1": "BLD 2A, No 1588, Lianhang Rd",
        "address_2": "  Shanghai  201112",
        "country": "CN"
    },
    "FCF8B7": {
        "oui_hex": "FC-F8-B7",
        "organization": "TRONTEQ Electronic",
        "address_1": "Siemensstrasse 22",
        "address_2": "Reutlingen  Baden Wuerttemberg  72766",
        "country": "DE"
    },
    "30F42F": {
        "oui_hex": "30-F4-2F",
        "organization": "ESP",
        "address_1": "126-1 Pyeongchon-dong, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  431-755",
        "country": "KR"
    },
    "704E01": {
        "oui_hex": "70-4E-01",
        "organization": "KWANGWON TECH CO., LTD.",
        "address_1": "D-401, Digital-Empire Bldg., 980-3",
        "address_2": "Suwon  Gyeonggi-Do  443-702",
        "country": "KR"
    },
    "746A8F": {
        "oui_hex": "74-6A-8F",
        "organization": "VS Vision Systems GmbH",
        "address_1": "Aspelohe 27A",
        "address_2": "Norderstedt  Schleswig-Holstein  22848",
        "country": "DE"
    },
    "54A31B": {
        "oui_hex": "54-A3-1B",
        "organization": "Shenzhen Linkworld Technology Co,.LTD",
        "address_1": "Room 667-675 , sixth floor ,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "CC398C": {
        "oui_hex": "CC-39-8C",
        "organization": "Shiningtek",
        "address_1": "No. 53, Nankeng 3 St",
        "address_2": "  Hsinchu  30841",
        "country": "TW"
    },
    "1820A6": {
        "oui_hex": "18-20-A6",
        "organization": "Sage Co., Ltd.",
        "address_1": "2-24 Sumiyoshicho, Naka-ku",
        "address_2": "Yokohama-shi  Kanagawa  231-0013",
        "country": "JP"
    },
    "20EAC7": {
        "oui_hex": "20-EA-C7",
        "organization": "SHENZHEN RIOPINE ELECTRONICS CO., LTD",
        "address_1": "ROOM1002~1004, BaoYuan HuaFeng Headquarters' Business Building, Xixiang Avenue (west) , Bao'an District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "64B370": {
        "oui_hex": "64-B3-70",
        "organization": "PowerComm Solutions LLC",
        "address_1": "15 Minneakoning Rd. Suite 311",
        "address_2": "Flemington  NJ  08822",
        "country": "US"
    },
    "5CF50D": {
        "oui_hex": "5C-F5-0D",
        "organization": "Institute of microelectronic applications",
        "address_1": "Na Valentince 1003/1",
        "address_2": "Praha    15000",
        "country": "CZ"
    },
    "749C52": {
        "oui_hex": "74-9C-52",
        "organization": "Huizhou Desay SV Automotive Co., Ltd.",
        "address_1": "103, Hechang 5th Road West,",
        "address_2": "Huizhou  Guangdong  516006",
        "country": "CN"
    },
    "C4291D": {
        "oui_hex": "C4-29-1D",
        "organization": "KLEMSAN ELEKTRIK ELEKTRONIK SAN.VE TIC.AS.",
        "address_1": "kemalpaşa yolu 3.km KEMALPASA 35170",
        "address_2": "izmir  TÜRKİYE --  35170",
        "country": "TR"
    },
    "6C5F1C": {
        "oui_hex": "6C-5F-1C",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": " No.999, Qishan North 2nd Road,",
        "address_2": "Xiamen  361000  Fujian",
        "country": "US"
    },
    "7CE4AA": {
        "oui_hex": "7C-E4-AA",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "083F3E": {
        "oui_hex": "08-3F-3E",
        "organization": "WSH GmbH",
        "address_1": "Koelner Str. 58a",
        "address_2": "Gummersbach  NRW  51645",
        "country": "DE"
    },
    "2C957F": {
        "oui_hex": "2C-95-7F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "3C0C48": {
        "oui_hex": "3C-0C-48",
        "organization": "Servergy, Inc.",
        "address_1": "1700 N. Redbud",
        "address_2": "McKinney  TEXAS  75069",
        "country": "US"
    },
    "10DEE4": {
        "oui_hex": "10-DE-E4",
        "organization": "automationNEXT GmbH",
        "address_1": "Millennium Park 4",
        "address_2": "Lustenau  Vorarlberg  6890",
        "country": "AT"
    },
    "F03A4B": {
        "oui_hex": "F0-3A-4B",
        "organization": "Bloombase, Inc.",
        "address_1": "955 Benecia Ave",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "A0E453": {
        "oui_hex": "A0-E4-53",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "404A18": {
        "oui_hex": "40-4A-18",
        "organization": "Addrek Smart Solutions",
        "address_1": "Al Gharrafa Thani Bin Jassim St",
        "address_2": "Doha",
        "country": "QA"
    },
    "C0C569": {
        "oui_hex": "C0-C5-69",
        "organization": "SHANGHAI LYNUC CNC TECHNOLOGY CO.,LTD",
        "address_1": "Building 3,No.25 Cangwu Rd",
        "address_2": "  Shanghai  200233",
        "country": "CN"
    },
    "C4C0AE": {
        "oui_hex": "C4-C0-AE",
        "organization": "MIDORI ELECTRONIC CO., LTD.",
        "address_1": "397",
        "address_2": "Chikuma  Nagano  389-0804",
        "country": "JP"
    },
    "ACC595": {
        "oui_hex": "AC-C5-95",
        "organization": "Graphite Systems",
        "address_1": "2037 Landings Drive",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "7CE1FF": {
        "oui_hex": "7C-E1-FF",
        "organization": "Computer Performance, Inc. DBA Digital Loggers, Inc.",
        "address_1": "2695 Walsh Avenue",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "D8150D": {
        "oui_hex": "D8-15-0D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5850AB": {
        "oui_hex": "58-50-AB",
        "organization": "TLS Corporation",
        "address_1": "1241 Superior Ave.",
        "address_2": "Cleveland  OH  44114",
        "country": "US"
    },
    "7CCD11": {
        "oui_hex": "7C-CD-11",
        "organization": "MS-Magnet",
        "address_1": "Parchevich 42",
        "address_2": "  Sofia  1000",
        "country": "BG"
    },
    "98FF6A": {
        "oui_hex": "98-FF-6A",
        "organization": "OTEC(Shanghai)Technology Co.,Ltd.",
        "address_1": "13th Floor,Building 2",
        "address_2": "  Shanghai  200235",
        "country": "CN"
    },
    "BC1A67": {
        "oui_hex": "BC-1A-67",
        "organization": "YF Technology Co., Ltd",
        "address_1": "No.62,South Fumin Road,",
        "address_2": "Dongguang  Guangdong  523773",
        "country": "CN"
    },
    "4CD7B6": {
        "oui_hex": "4C-D7-B6",
        "organization": "Helmer Scientific",
        "address_1": "14400 Bergen Boulevard",
        "address_2": "Noblesville  Indiana  46060",
        "country": "US"
    },
    "8425A4": {
        "oui_hex": "84-25-A4",
        "organization": "Tariox Limited",
        "address_1": "173 Highway 53",
        "address_2": "Cathcart  Ontario  N0E 1B0",
        "country": "CA"
    },
    "483D32": {
        "oui_hex": "48-3D-32",
        "organization": "Syscor Controls &amp; Automation",
        "address_1": "201-60 Bastion Sq",
        "address_2": "Victoria  BC  V8W 1J2",
        "country": "CA"
    },
    "CC856C": {
        "oui_hex": "CC-85-6C",
        "organization": "SHENZHEN MDK DIGITAL TECHNOLOGY CO.,LTD",
        "address_1": "Xin fengze industrial park,shangnan east road",
        "address_2": "SHENZHEN  GUANGDONG  518101",
        "country": "CN"
    },
    "AC6BAC": {
        "oui_hex": "AC-6B-AC",
        "organization": "Jenny Science AG",
        "address_1": "Sandblatte 7a",
        "address_2": "Rain  Luzern  6026",
        "country": "CH"
    },
    "D8EE78": {
        "oui_hex": "D8-EE-78",
        "organization": "Moog Protokraft",
        "address_1": "4545 W Stone Dr Bldg 135",
        "address_2": "Kingsport  TN  37660",
        "country": "US"
    },
    "241148": {
        "oui_hex": "24-11-48",
        "organization": "Entropix, LLC",
        "address_1": "100 Rawson Road",
        "address_2": "Victor  New York  14564",
        "country": "US"
    },
    "C445EC": {
        "oui_hex": "C4-45-EC",
        "organization": "Shanghai Yali Electron Co.,LTD",
        "address_1": "Room 1-607",
        "address_2": "Shanghai  Shanghai  201100",
        "country": "US"
    },
    "E0E631": {
        "oui_hex": "E0-E6-31",
        "organization": "SNB TECHNOLOGIES LIMITED",
        "address_1": "Rm 303, Building #13,",
        "address_2": "Long Gang district, ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "78B5D2": {
        "oui_hex": "78-B5-D2",
        "organization": "Ever Treasure Industrial Limited",
        "address_1": "15A Tung Lee Commercial Building",
        "address_2": "Sheung Wan    852",
        "country": "HK"
    },
    "50ED78": {
        "oui_hex": "50-ED-78",
        "organization": "Changzhou Yongse Infotech Co.,Ltd",
        "address_1": "No.128 Zhengzhong Rd, Xixiashua Town",
        "address_2": "Changzhou  Jiangsu  213135",
        "country": "CN"
    },
    "90028A": {
        "oui_hex": "90-02-8A",
        "organization": "Shenzhen Shidean Legrand Electronic Products Co.,Ltd",
        "address_1": "Block39,Shahe Industrial Zone Baishizhou",
        "address_2": "  Guangdong  518053",
        "country": "CN"
    },
    "1CC11A": {
        "oui_hex": "1C-C1-1A",
        "organization": "Wavetronix",
        "address_1": "78 East 1700 South",
        "address_2": "Provo  UT  84606",
        "country": "US"
    },
    "FC09D8": {
        "oui_hex": "FC-09-D8",
        "organization": "ACTEON Group",
        "address_1": "ZAC Athelia IV",
        "address_2": "La Ciotat  France  13705",
        "country": "FR"
    },
    "743ECB": {
        "oui_hex": "74-3E-CB",
        "organization": "Gentrice tech",
        "address_1": "15F No.738-5 JhengJhong Rd",
        "address_2": "New Taipei city    235",
        "country": "TW"
    },
    "7C444C": {
        "oui_hex": "7C-44-4C",
        "organization": "Entertainment Solutions, S.L.",
        "address_1": "Parque Empresarial Miraflores, nave 3",
        "address_2": "  Zaragoza  50720",
        "country": "ES"
    },
    "0444A1": {
        "oui_hex": "04-44-A1",
        "organization": "TELECON GALICIA,S.A.",
        "address_1": "AVENIDA DE NOSTIAN",
        "address_2": "A CORUNA 15008",
        "country": "ES"
    },
    "20C60D": {
        "oui_hex": "20-C6-0D",
        "organization": "Shanghai annijie Information technology Co.,LTD",
        "address_1": "Room605,NO.9,Lane 777",
        "address_2": "Shanghai    200070",
        "country": "CN"
    },
    "38CA97": {
        "oui_hex": "38-CA-97",
        "organization": "Contour Design LLC",
        "address_1": "10 Industrial Drive",
        "address_2": "Windham  NH  03087",
        "country": "US"
    },
    "BC2D98": {
        "oui_hex": "BC-2D-98",
        "organization": "ThinGlobal LLC",
        "address_1": "703 wildflower RD",
        "address_2": "Davenport  FL  33837",
        "country": "US"
    },
    "1879A2": {
        "oui_hex": "18-79-A2",
        "organization": "GMJ ELECTRIC LIMITED",
        "address_1": "RM 1405, 14/F, C C WU BUILDING",
        "address_2": "    999077",
        "country": "HK"
    },
    "E0C86A": {
        "oui_hex": "E0-C8-6A",
        "organization": "SHENZHEN TW-SCIE Co., Ltd",
        "address_1": "816# DongMing Building MinKang Road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "BCEE7B": {
        "oui_hex": "BC-EE-7B",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "3413A8": {
        "oui_hex": "34-13-A8",
        "organization": "Mediplan Limited",
        "address_1": "245 Sheffield Road",
        "address_2": "Sheffield  South Yorkshire  S13 9ZD",
        "country": "GB"
    },
    "7C9763": {
        "oui_hex": "7C-97-63",
        "organization": "Openmatics s.r.o.",
        "address_1": "Poděbradova 2842/1",
        "address_2": "Pilsen  Tschechien  30100",
        "country": "CZ"
    },
    "48A2B7": {
        "oui_hex": "48-A2-B7",
        "organization": "Kodofon JSC",
        "address_1": "97 Moskovskyi pr.",
        "address_2": "Voronezh    394077",
        "country": "RU"
    },
    "CC7498": {
        "oui_hex": "CC-74-98",
        "organization": "Filmetrics Inc.",
        "address_1": "3560 Dunhill Street, #100",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "085AE0": {
        "oui_hex": "08-5A-E0",
        "organization": "Recovision Technology Co., Ltd.",
        "address_1": "1709，No.5 Wanghai Road,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "20E791": {
        "oui_hex": "20-E7-91",
        "organization": "Siemens Healthcare Diagnostics, Inc",
        "address_1": "2 Edgewater Drive",
        "address_2": "Norwood  MA  02062",
        "country": "US"
    },
    "089758": {
        "oui_hex": "08-97-58",
        "organization": "Shenzhen Strong Rising Electronics Co.,Ltd DongGuan Subsidiary",
        "address_1": "QingPing Road 2,Qinghutou village",
        "address_2": "DongGuan  GuangDong  523711",
        "country": "CN"
    },
    "FC19D0": {
        "oui_hex": "FC-19-D0",
        "organization": "Cloud Vision Networks Technology Co.,Ltd.",
        "address_1": "F/9,Hechuan Building 2016",
        "address_2": "Shanghai    201103",
        "country": "CN"
    },
    "9486D4": {
        "oui_hex": "94-86-D4",
        "organization": "Surveillance Pro Corporation",
        "address_1": "12F., No.4, Ln. 609, Sec. 5, Chongxin Rd., Sanchong Dist.",
        "address_2": "New Taipei City    241",
        "country": "US"
    },
    "9CD643": {
        "oui_hex": "9C-D6-43",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "3C18A0": {
        "oui_hex": "3C-18-A0",
        "organization": "Luxshare Precision Industry Company Limited",
        "address_1": "Floor 2, Block A, Sanyo New Industrial Area",
        "address_2": "West Haoyi Community, Shajing Subdistrict Office  Bao'an District, Shenzhen, Guangdong  523000",
        "country": "CN"
    },
    "8CAE89": {
        "oui_hex": "8C-AE-89",
        "organization": "Y-cam Solutions Ltd",
        "address_1": "3 dee road",
        "address_2": "Richmond  Surrey  TW9 2JN",
        "country": "GB"
    },
    "94E98C": {
        "oui_hex": "94-E9-8C",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "FCE1D9": {
        "oui_hex": "FC-E1-D9",
        "organization": "Stable Imaging Solutions LLC",
        "address_1": "3709 Old Conejo Rd",
        "address_2": "Newbury Park  CA  91320",
        "country": "US"
    },
    "50206B": {
        "oui_hex": "50-20-6B",
        "organization": "Emerson Climate Technologies Transportation Solutions",
        "address_1": "Axel Kiers Vej  5A",
        "address_2": "Hoejbjerg    8270",
        "country": "DK"
    },
    "7CBF88": {
        "oui_hex": "7C-BF-88",
        "organization": "Mobilicom LTD",
        "address_1": "Hametzoda 31",
        "address_2": "Azor    5800174",
        "country": "IL"
    },
    "60DB2A": {
        "oui_hex": "60-DB-2A",
        "organization": "HNS",
        "address_1": "345-50, Gasan-dong, Geumcheon-gu, Seoul, Korea[153-707]",
        "address_2": "Seoul  The Seoul Metropolis  82",
        "country": "KR"
    },
    "B04545": {
        "oui_hex": "B0-45-45",
        "organization": "YACOUB Automation GmbH",
        "address_1": "Gustav Meyer Allee 25",
        "address_2": "Berlin    13355",
        "country": "DE"
    },
    "C8EE75": {
        "oui_hex": "C8-EE-75",
        "organization": "Pishion International Co. Ltd",
        "address_1": "3F,NO,15-2,Beihuan Rd",
        "address_2": "Taichung City    42760",
        "country": "TW"
    },
    "CC3429": {
        "oui_hex": "CC-34-29",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "64BABD": {
        "oui_hex": "64-BA-BD",
        "organization": "SDJ Technologies, Inc.",
        "address_1": "2125-B Madera Road",
        "address_2": "Simi Valley  CA  93065",
        "country": "US"
    },
    "24C848": {
        "oui_hex": "24-C8-48",
        "organization": "mywerk Portal GmbH",
        "address_1": "Fabrikstr. 3",
        "address_2": "Gronau     48599",
        "country": "DE"
    },
    "CCFB65": {
        "oui_hex": "CC-FB-65",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "A0A23C": {
        "oui_hex": "A0-A2-3C",
        "organization": "GPMS",
        "address_1": "40 Ridge Rd",
        "address_2": "Cornwall  VT  05753",
        "country": "US"
    },
    "68FCB3": {
        "oui_hex": "68-FC-B3",
        "organization": "Next Level Security Systems, Inc.",
        "address_1": "6353 Corte Del Abeto",
        "address_2": "Carlsbad  CA  92011",
        "country": "US"
    },
    "94C3E4": {
        "oui_hex": "94-C3-E4",
        "organization": "Atlas Copco IAS GmbH",
        "address_1": "Gewerbestr. 52",
        "address_2": "Bretten-Goelshausen    75015",
        "country": "DE"
    },
    "34885D": {
        "oui_hex": "34-88-5D",
        "organization": "Logitech Far East",
        "address_1": "#2 Creation Rd. 4,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "88576D": {
        "oui_hex": "88-57-6D",
        "organization": "XTA Electronics Ltd",
        "address_1": "The Design House",
        "address_2": "Stourport-on-Severn  Worcestershire  DY13 9BZ",
        "country": "GB"
    },
    "BC4100": {
        "oui_hex": "BC-41-00",
        "organization": "CODACO ELECTRONIC s.r.o.",
        "address_1": "Hemy 825",
        "address_2": "Valasske Mezirici    75701",
        "country": "CZ"
    },
    "FCD817": {
        "oui_hex": "FC-D8-17",
        "organization": "Beijing Hesun Technologies Co.Ltd.",
        "address_1": "Room 1811, 18th floor, Building No. 4, Courtyard 1, Shangdi tenth Street",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "682DDC": {
        "oui_hex": "68-2D-DC",
        "organization": "Wuhan Changjiang Electro-Communication Equipment CO.,LTD",
        "address_1": "No.8,Yinghu Sience&Technology industrial park",
        "address_2": "Wuhan  Hubei  430040",
        "country": "CN"
    },
    "E8611F": {
        "oui_hex": "E8-61-1F",
        "organization": "Dawning Information Industry Co.,Ltd",
        "address_1": "NO.15 Huake Street,Hi-Tech Zone",
        "address_2": "   Tianjin  300384",
        "country": "CN"
    },
    "2847AA": {
        "oui_hex": "28-47-AA",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "5CD61F": {
        "oui_hex": "5C-D6-1F",
        "organization": "Qardio, Inc",
        "address_1": "340 S Lemon Ave #1104F",
        "address_2": "Walnut  California  91789",
        "country": "US"
    },
    "705957": {
        "oui_hex": "70-59-57",
        "organization": "Medallion Instrumentation Systems",
        "address_1": "17150 Hickory St",
        "address_2": "Spring Lake  MI  49456",
        "country": "US"
    },
    "9C443D": {
        "oui_hex": "9C-44-3D",
        "organization": "CHENGDU XUGUANG TECHNOLOGY CO, LTD",
        "address_1": "2ND SECTION,PARK ROAD",
        "address_2": "CHENGDU  SICHUAN  610100",
        "country": "CN"
    },
    "B424E7": {
        "oui_hex": "B4-24-E7",
        "organization": "Codetek Technology Co.,Ltd",
        "address_1": "4F.-1, No.55, Dongguang Rd., East Dist.,",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "542F89": {
        "oui_hex": "54-2F-89",
        "organization": "Euclid Laboratories, Inc.",
        "address_1": "9151 Arvida Ln",
        "address_2": "Coral Gables  Florida  33156",
        "country": "US"
    },
    "909916": {
        "oui_hex": "90-99-16",
        "organization": "ELVEES NeoTek OJSC",
        "address_1": "Proezd 4922, dom 4, stroenie 2",
        "address_2": "Moscow  Zelenograd  124498",
        "country": "RU"
    },
    "00A2FF": {
        "oui_hex": "00-A2-FF",
        "organization": "abatec group AG",
        "address_1": "Oberregauerstraße 48",
        "address_2": "Regau    4844",
        "country": "AT"
    },
    "6024C1": {
        "oui_hex": "60-24-C1",
        "organization": "Jiangsu Zhongxun Electronic Technology Co., Ltd",
        "address_1": "tangshu road #8",
        "address_2": "yixing  jiangsu  214221",
        "country": "CN"
    },
    "A0143D": {
        "oui_hex": "A0-14-3D",
        "organization": "PARROT SA",
        "address_1": "174 Quai de Jemmapes",
        "address_2": "Paris    75010",
        "country": "FR"
    },
    "FC1BFF": {
        "oui_hex": "FC-1B-FF",
        "organization": "V-ZUG AG",
        "address_1": "Industriestrasse 66",
        "address_2": "  Zug  6301",
        "country": "CH"
    },
    "F42896": {
        "oui_hex": "F4-28-96",
        "organization": "SPECTO PAINEIS ELETRONICOS LTDA",
        "address_1": "RUA WALTER JOSE CORREA, AREA 12",
        "address_2": "SAO JOSE  SANTA CATARINA  88122-035",
        "country": "BR"
    },
    "78CB33": {
        "oui_hex": "78-CB-33",
        "organization": "DHC Software Co.,Ltd",
        "address_1": "16/F,DHC Mansion No.3 Zijin",
        "address_2": "Beijing    100190",
        "country": "CN"
    },
    "60A9B0": {
        "oui_hex": "60-A9-B0",
        "organization": "Merchandising Technologies, Inc",
        "address_1": "1050 NW 229th Avenue",
        "address_2": "HIllsboro  OR  97124",
        "country": "US"
    },
    "5027C7": {
        "oui_hex": "50-27-C7",
        "organization": "TECHNART Co.,Ltd",
        "address_1": "2-21 Nishiohjicho",
        "address_2": "Kusatsu  Shiga  525-0037",
        "country": "JP"
    },
    "6C5AB5": {
        "oui_hex": "6C-5A-B5",
        "organization": "TCL Technoly Electronics (Huizhou) Co., Ltd.",
        "address_1": "19th Zhongkai Hi-tech Development Zone",
        "address_2": "Huizhou  Guangdong  516006",
        "country": "CN"
    },
    "385AA8": {
        "oui_hex": "38-5A-A8",
        "organization": "Beijing Zhongdun Security Technology Development Co.",
        "address_1": "No.1 Capital Gymnasium South Road",
        "address_2": "  Beijing  100048",
        "country": "CN"
    },
    "F4A294": {
        "oui_hex": "F4-A2-94",
        "organization": "EAGLE WORLD DEVELOPMENT CO., LIMITED",
        "address_1": "1F, CMA Bldg., 64 Connaught Road Central",
        "address_2": "  Hong Kong  00852",
        "country": "HK"
    },
    "EC3E09": {
        "oui_hex": "EC-3E-09",
        "organization": "PERFORMANCE DESIGNED PRODUCTS, LLC",
        "address_1": "14144 Ventura Blvd",
        "address_2": "Sherman Oaks  California  91423",
        "country": "US"
    },
    "947C3E": {
        "oui_hex": "94-7C-3E",
        "organization": "Polewall Norge AS",
        "address_1": "Vige Havnevei 78",
        "address_2": "Kristiansand  Vest-Agder  4633",
        "country": "NO"
    },
    "34A3BF": {
        "oui_hex": "34-A3-BF",
        "organization": "Terewave. Inc.",
        "address_1": "Room 217, Ssangyong Research Center",
        "address_2": "Yuseong-gu  Daejeon-city  305804",
        "country": "KR"
    },
    "8C088B": {
        "oui_hex": "8C-08-8B",
        "organization": "Remote Solution",
        "address_1": "92, Chogokri, Nammyun",
        "address_2": "Kimcheon city  Kyungbuk  740-871",
        "country": "KR"
    },
    "B43E3B": {
        "oui_hex": "B4-3E-3B",
        "organization": "Viableware, Inc",
        "address_1": "12220 113th Ave NE",
        "address_2": "Kirkland  WA  98034",
        "country": "US"
    },
    "0C5CD8": {
        "oui_hex": "0C-5C-D8",
        "organization": "DOLI Elektronik GmbH",
        "address_1": "Adi-Maislinger-Str. 7",
        "address_2": "Munich    81373",
        "country": "DE"
    },
    "3C15EA": {
        "oui_hex": "3C-15-EA",
        "organization": "TESCOM CO., LTD.",
        "address_1": "#928 UTV, 1141-2 Baeksuk Ilsandong",
        "address_2": "Goyang  Gyeonggi  410-722",
        "country": "KR"
    },
    "E80410": {
        "oui_hex": "E8-04-10",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "F4BD7C": {
        "oui_hex": "F4-BD-7C",
        "organization": "Chengdu jinshi communication Co., LTD",
        "address_1": "No. 108 #1-2-505, Eastern 5 Section, First Ring Road, JinJiang District,",
        "address_2": "Chengdu  Chongqing  610000",
        "country": "CN"
    },
    "DCC422": {
        "oui_hex": "DC-C4-22",
        "organization": "Systembase Limited",
        "address_1": "Jupes Field House, Pettridge Lane",
        "address_2": "Warminster  Wiltshire  BA12 6DG",
        "country": "GB"
    },
    "C8F36B": {
        "oui_hex": "C8-F3-6B",
        "organization": "Yamato Scale Co.,Ltd.",
        "address_1": "5-22",
        "address_2": "Akashi  Hyogo  673-8688",
        "country": "JP"
    },
    "98F8C1": {
        "oui_hex": "98-F8-C1",
        "organization": "IDT Technology Limited",
        "address_1": "Block C, 9/F.,Kaiser Estate, Phase 1,",
        "address_2": "Kowloon  Hong Kong",
        "country": "HK"
    },
    "6CD1B0": {
        "oui_hex": "6C-D1-B0",
        "organization": "WING SING ELECTRONICS HONG KONG LIMITED",
        "address_1": "No. 1, Guoyuan Industrial Zone",
        "address_2": "Guangzhou  Guang Dong  510385",
        "country": "CN"
    },
    "A4F522": {
        "oui_hex": "A4-F5-22",
        "organization": "CHOFU SEISAKUSHO CO.,LTD",
        "address_1": "2-1",
        "address_2": "Shimonoseki-shi  Yamaguchi  752-8555",
        "country": "JP"
    },
    "845C93": {
        "oui_hex": "84-5C-93",
        "organization": "Chabrier Services",
        "address_1": "354 Chemin de la Pinatte",
        "address_2": "Saint-Peray    07130",
        "country": "FR"
    },
    "68E166": {
        "oui_hex": "68-E1-66",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "BC2BD7": {
        "oui_hex": "BC-2B-D7",
        "organization": "Revogi Innovation Co., Ltd.",
        "address_1": "2018, Anhui Building, No. 6007,",
        "address_2": "Shenzhen,  Guangdong  518113",
        "country": "CN"
    },
    "286D97": {
        "oui_hex": "28-6D-97",
        "organization": "SAMJIN Co., Ltd.",
        "address_1": "199-6, Anyang 7-dong, Manan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  430-817",
        "country": "KR"
    },
    "24ECD6": {
        "oui_hex": "24-EC-D6",
        "organization": "CSG Science & Technology Co.,Ltd.Hefei",
        "address_1": "No.612-1,Huangshan Road,Gaoxin District",
        "address_2": "Hefei  Anhui Province  230088",
        "country": "CN"
    },
    "CC2A80": {
        "oui_hex": "CC-2A-80",
        "organization": "Micro-Biz intelligence solutions Co.,Ltd",
        "address_1": "Room 611,Sunshine Building",
        "address_2": "Zhuhai City  Guangdong Province  519000",
        "country": "CN"
    },
    "60FEF9": {
        "oui_hex": "60-FE-F9",
        "organization": "Thomas & Betts",
        "address_1": "5900 Eastport Blvd",
        "address_2": "Richmond  VA  23231",
        "country": "US"
    },
    "B8DC87": {
        "oui_hex": "B8-DC-87",
        "organization": "IAI Corporation",
        "address_1": "577-1 Obane",
        "address_2": "Shizuoka-City  Shizuoka  424-0103",
        "country": "JP"
    },
    "7C6FF8": {
        "oui_hex": "7C-6F-F8",
        "organization": "ShenZhen ACTO Digital Video Technology Co.,Ltd.",
        "address_1": "3/F,Building 7,Software Park",
        "address_2": "ShenZhen  GuangDong  518055",
        "country": "CN"
    },
    "DCF755": {
        "oui_hex": "DC-F7-55",
        "organization": "SITRONIK",
        "address_1": "22 MARISCHAL GARDENS",
        "address_2": "ABERDEEN  ABERDEENSHIRE  AB21 9BY",
        "country": "GB"
    },
    "5C026A": {
        "oui_hex": "5C-02-6A",
        "organization": "Applied Vision Corporation",
        "address_1": "2020 Vision Lane",
        "address_2": "Cuyahoga Falls  OH  44223",
        "country": "US"
    },
    "0C9301": {
        "oui_hex": "0C-93-01",
        "organization": "PT. Prasimax Inovasi Teknologi",
        "address_1": "Jl. Margonda Raya 494D",
        "address_2": "Depok  Jawa Barat  16424",
        "country": "ID"
    },
    "746630": {
        "oui_hex": "74-66-30",
        "organization": "T:mi Ytti",
        "address_1": "Messitytonkatu 8 C 39",
        "address_2": "Helsinki  n/a  00180",
        "country": "FI"
    },
    "6CB350": {
        "oui_hex": "6C-B3-50",
        "organization": "Anhui comhigher tech co.,ltd",
        "address_1": "B6,717 Zhongshan South Road",
        "address_2": "Wuhu  Anhui  241000",
        "country": "CN"
    },
    "3859F8": {
        "oui_hex": "38-59-F8",
        "organization": "MindMade Sp. z o.o.",
        "address_1": "Sniadeckich 10",
        "address_2": "Warsaw    00-656",
        "country": "PL"
    },
    "4CDF3D": {
        "oui_hex": "4C-DF-3D",
        "organization": "TEAM ENGINEERS ADVANCE TECHNOLOGIES INDIA PVT LTD",
        "address_1": "A-1/2/A,IDA UPPAL,",
        "address_2": "HYDERABAD  AP  500039",
        "country": "IN"
    },
    "E89218": {
        "oui_hex": "E8-92-18",
        "organization": "Arcontia International AB",
        "address_1": "Gruvgatan 35A",
        "address_2": "Vastra Frolunda    421 30",
        "country": "SE"
    },
    "0075E1": {
        "oui_hex": "00-75-E1",
        "organization": "Ampt, LLC",
        "address_1": "4850 Innovation Drive",
        "address_2": "Fort Collins  Colorado  80525",
        "country": "US"
    },
    "D46A91": {
        "oui_hex": "D4-6A-91",
        "organization": "Snap AV",
        "address_1": "1800 Continental Blvd",
        "address_2": "Charlotte  North Carolina  28273",
        "country": "US"
    },
    "98CDB4": {
        "oui_hex": "98-CD-B4",
        "organization": "Virident Systems, Inc.",
        "address_1": "500 Yosemite Dr.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "A42305": {
        "oui_hex": "A4-23-05",
        "organization": "Open Networking Laboratory",
        "address_1": "1000 El Camino Real",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "1C48F9": {
        "oui_hex": "1C-48-F9",
        "organization": "GN Netcom A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup  Ballerup  DK-2750",
        "country": "DK"
    },
    "B0FEBD": {
        "oui_hex": "B0-FE-BD",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "60699B": {
        "oui_hex": "60-69-9B",
        "organization": "isepos GmbH",
        "address_1": "Wannweiler Str. 12",
        "address_2": "Kirchentellinsfurt    72138",
        "country": "US"
    },
    "D4D50D": {
        "oui_hex": "D4-D5-0D",
        "organization": "Southwest Microwave, Inc",
        "address_1": "9055 S McKemy St",
        "address_2": "Tempe  AZ  85284",
        "country": "US"
    },
    "34CD6D": {
        "oui_hex": "34-CD-6D",
        "organization": "CommSky Technologies",
        "address_1": "4655 Old Ironsides Dr",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "E4F3E3": {
        "oui_hex": "E4-F3-E3",
        "organization": "Shanghai iComhome Co.,Ltd.",
        "address_1": "Small second floor of No.773 Siping Road",
        "address_2": "  Shanghai  200092",
        "country": "CN"
    },
    "9046B7": {
        "oui_hex": "90-46-B7",
        "organization": "Vadaro Pte Ltd",
        "address_1": "71 Ayer Rajah Crescent",
        "address_2": "    139951",
        "country": "SG"
    },
    "04CF25": {
        "oui_hex": "04-CF-25",
        "organization": "MANYCOLORS, INC.",
        "address_1": "3F, 4-1-18 Jinnoharu",
        "address_2": "Kitakyushu  Fukuoka  8070821",
        "country": "JP"
    },
    "80BBEB": {
        "oui_hex": "80-BB-EB",
        "organization": "Satmap Systems Ltd",
        "address_1": "4 Fountain House",
        "address_2": "Leatherhead  Surrey  KT22 7LX",
        "country": "GB"
    },
    "00B78D": {
        "oui_hex": "00-B7-8D",
        "organization": "Nanjing Shining Electric Automation Co., Ltd",
        "address_1": "NO.699,Laiyinda Road",
        "address_2": "Nanjing  Jiangsu  211100",
        "country": "CN"
    },
    "60FE1E": {
        "oui_hex": "60-FE-1E",
        "organization": "China Palms Telecom.Ltd",
        "address_1": "2nd Floor of Building 1",
        "address_2": "PuDong District  Shanghai  201203",
        "country": "US"
    },
    "B050BC": {
        "oui_hex": "B0-50-BC",
        "organization": "SHENZHEN BASICOM ELECTRONIC CO.,LTD.",
        "address_1": "Basicom industry park, Baolong Avenue 3rd Road, Baolong industry town",
        "address_2": "Shenzhen  Guangdong  518116",
        "country": "CN"
    },
    "841E26": {
        "oui_hex": "84-1E-26",
        "organization": "KERNEL-I Co.,LTD",
        "address_1": "#606,ACE Techno Tower 10,470-5",
        "address_2": "Gasan-Dong, Geumcheon-gu, Seoul  Korea  153-789",
        "country": "KR"
    },
    "B4346C": {
        "oui_hex": "B4-34-6C",
        "organization": "MATSUNICHI DIGITAL TECHNOLOGY (HONG KONG) LIMITED",
        "address_1": "22/F. TWO INTERNATIONAL FINANCE CTR",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "0086A0": {
        "oui_hex": "00-86-A0",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "A05B21": {
        "oui_hex": "A0-5B-21",
        "organization": "ENVINET GmbH",
        "address_1": "Hans-Pinsel-Str. 4",
        "address_2": "Haar    85540",
        "country": "DE"
    },
    "50B8A2": {
        "oui_hex": "50-B8-A2",
        "organization": "ImTech Technologies LLC,",
        "address_1": "2101 NE Jack London St",
        "address_2": "Corvallis  Oregon  97330",
        "country": "US"
    },
    "B04C05": {
        "oui_hex": "B0-4C-05",
        "organization": "Fresenius Medical Care Deutschland GmbH",
        "address_1": "Hafenstr. 9",
        "address_2": "Schweinfurt    97424",
        "country": "DE"
    },
    "B0793C": {
        "oui_hex": "B0-79-3C",
        "organization": "Revolv Inc",
        "address_1": "2060 Broadway #380",
        "address_2": "Boulder  CO  80302",
        "country": "US"
    },
    "9C4EBF": {
        "oui_hex": "9C-4E-BF",
        "organization": "BoxCast",
        "address_1": "14538 Grapeland Ave",
        "address_2": "Cleveland  Ohio  44111",
        "country": "US"
    },
    "34A843": {
        "oui_hex": "34-A8-43",
        "organization": "KYOCERA Display Corporation",
        "address_1": "5-7-18 Higashinippori",
        "address_2": "Arakawa-ku  Tokyo  116-0014",
        "country": "JP"
    },
    "74CA25": {
        "oui_hex": "74-CA-25",
        "organization": "Calxeda, Inc.",
        "address_1": "7000 North Mopac Expressway",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "5CA3EB": {
        "oui_hex": "5C-A3-EB",
        "organization": "Lokel s.r.o.",
        "address_1": "Moravska 797/85",
        "address_2": "Ostrava  Moravskoslezsky  700 30",
        "country": "CZ"
    },
    "C8B373": {
        "oui_hex": "C8-B3-73",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "0C2AE7": {
        "oui_hex": "0C-2A-E7",
        "organization": "Beijing General Research Institute of Mining and Metallurgy",
        "address_1": "Building 23, Zone 18 of ABP, No. 188",
        "address_2": "  Beijing  100160",
        "country": "CN"
    },
    "983071": {
        "oui_hex": "98-30-71",
        "organization": "DAIKYUNG VASCOM",
        "address_1": "DAIKYUNG Bldg.#1164-15,Gaepo-dong",
        "address_2": "Gangnam-gu  Seoul  135-960",
        "country": "KR"
    },
    "D49524": {
        "oui_hex": "D4-95-24",
        "organization": "Clover Network, Inc.",
        "address_1": "415 N Mathilda Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "945047": {
        "oui_hex": "94-50-47",
        "organization": "Rechnerbetriebsgruppe",
        "address_1": "Werner von Siemens Str. 64",
        "address_2": "Würzburg  Bayern  97076",
        "country": "DE"
    },
    "E031D0": {
        "oui_hex": "E0-31-D0",
        "organization": "SZ Telstar CO., LTD",
        "address_1": "Telstar Technology Park No.12&14, Longtong Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518172",
        "country": "CN"
    },
    "54112F": {
        "oui_hex": "54-11-2F",
        "organization": "Sulzer Pump Solutions Finland Oy",
        "address_1": "Lentokentaentie 44",
        "address_2": "Lappeenranta    FI-53600",
        "country": "FI"
    },
    "4C55B8": {
        "oui_hex": "4C-55-B8",
        "organization": "Turkcell Teknoloji",
        "address_1": "TUBITAK MAM Teknoloji Serbest Bolgesi Gebze",
        "address_2": "Kocaeli    41470",
        "country": "TR"
    },
    "088039": {
        "oui_hex": "08-80-39",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "E438F2": {
        "oui_hex": "E4-38-F2",
        "organization": "Advantage Controls",
        "address_1": "4700 Harold Abitz Dr.",
        "address_2": "Muskogee  OK  74403",
        "country": "US"
    },
    "C4C755": {
        "oui_hex": "C4-C7-55",
        "organization": "Beijing HuaqinWorld Technology Co.,Ltd",
        "address_1": "30F,Beijing Silver Tower,No.2 North Road,",
        "address_2": "  Beijing  100027",
        "country": "CN"
    },
    "0C2D89": {
        "oui_hex": "0C-2D-89",
        "organization": "QiiQ Communications Inc.",
        "address_1": "30 East Beaver Creek Road",
        "address_2": "Richmond Hill  Ontario  L4B 1J2",
        "country": "CA"
    },
    "A8D236": {
        "oui_hex": "A8-D2-36",
        "organization": "Lightware Visual Engineering",
        "address_1": "Peterdy utca 15.",
        "address_2": "  Budapest  H-1071",
        "country": "HU"
    },
    "981094": {
        "oui_hex": "98-10-94",
        "organization": "Shenzhen Vsun communication technology Co.,ltd",
        "address_1": "Room 1903, Block A,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A4F3C1": {
        "oui_hex": "A4-F3-C1",
        "organization": "Open Source Robotics Foundation, Inc.",
        "address_1": "419 N Shoreline Blvd",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "141330": {
        "oui_hex": "14-13-30",
        "organization": "Anakreon UK LLP",
        "address_1": "5-th Floor",
        "address_2": "  London  EC3V 0EH",
        "country": "GB"
    },
    "0CF405": {
        "oui_hex": "0C-F4-05",
        "organization": "Beijing Signalway Technologies Co.,Ltd",
        "address_1": "Room B 1905,Tri-tower",
        "address_2": "Haidian District  Beijing  100190",
        "country": "CN"
    },
    "5061D6": {
        "oui_hex": "50-61-D6",
        "organization": "Indu-Sol GmbH",
        "address_1": "Blumenstr. 3",
        "address_2": "Schmölln  Thüringen  04626",
        "country": "DE"
    },
    "DC7014": {
        "oui_hex": "DC-70-14",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "788DF7": {
        "oui_hex": "78-8D-F7",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "2C245F": {
        "oui_hex": "2C-24-5F",
        "organization": "Babolat VS",
        "address_1": "93 rue Andre Bollier",
        "address_2": "  Lyon  69007",
        "country": "FR"
    },
    "905692": {
        "oui_hex": "90-56-92",
        "organization": "Autotalks Ltd.",
        "address_1": "Kfar Netter",
        "address_2": "  Israel  40593",
        "country": "IL"
    },
    "04BFA8": {
        "oui_hex": "04-BF-A8",
        "organization": "ISB Corporation",
        "address_1": "1-2-1 Shinyokohama, Kohoku-ku",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "8CC7D0": {
        "oui_hex": "8C-C7-D0",
        "organization": "zhejiang ebang communication co.,ltd",
        "address_1": "1418-36#,Moganshan Road",
        "address_2": "hangzhou  zhejiang  310013",
        "country": "CN"
    },
    "B8AE6E": {
        "oui_hex": "B8-AE-6E",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "D0EB03": {
        "oui_hex": "D0-EB-03",
        "organization": "Zhehua technology limited",
        "address_1": "Room 2206,No 1079,A,ZhanTao Technology Building, MinZhi Street, Longhua District",
        "address_2": "Tortoal British Virgin Island,Hong Kong  Shenzhen,Guang Dong  518131",
        "country": "CN"
    },
    "683EEC": {
        "oui_hex": "68-3E-EC",
        "organization": "ERECA",
        "address_1": "75, Rue d&#39;Orgemont",
        "address_2": "Saint GRATIEN    95210",
        "country": "FR"
    },
    "C42628": {
        "oui_hex": "C4-26-28",
        "organization": "Airo Wireless",
        "address_1": "12 Piedmont Center",
        "address_2": "Atlanta  GA  30305",
        "country": "US"
    },
    "30AABD": {
        "oui_hex": "30-AA-BD",
        "organization": "Shanghai Reallytek Information Technology Co.,Ltd",
        "address_1": "Building No.1-906, No.3000 Long Dong Avenue",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "A4B818": {
        "oui_hex": "A4-B8-18",
        "organization": "PENTA Gesellschaft für elektronische Industriedatenverarbeitung mbH",
        "address_1": "Ulrichsberger Str. 17",
        "address_2": "Deggendorf    94469",
        "country": "DE"
    },
    "C04DF7": {
        "oui_hex": "C0-4D-F7",
        "organization": "SERELEC",
        "address_1": "2, Chemin du Génie",
        "address_2": "VENISSIEUX CEDEX    69633",
        "country": "FR"
    },
    "0C8484": {
        "oui_hex": "0C-84-84",
        "organization": "Zenovia Electronics Inc.",
        "address_1": "#206, 506B St. Albert Rd.",
        "address_2": "St. Albert  AB  T8N 5Z1",
        "country": "CA"
    },
    "005907": {
        "oui_hex": "00-59-07",
        "organization": "LenovoEMC Products USA, LLC",
        "address_1": "22 South St",
        "address_2": "Hopinkton  MA  01748",
        "country": "US"
    },
    "50A715": {
        "oui_hex": "50-A7-15",
        "organization": "Aboundi, Inc.",
        "address_1": "4 Bud Way, Unit 10",
        "address_2": "Nashua  NH  03063",
        "country": "US"
    },
    "0C0400": {
        "oui_hex": "0C-04-00",
        "organization": "Jantar d.o.o.",
        "address_1": "Kranjska cesta 24",
        "address_2": "Naklo  Slovenia  4202",
        "country": "SI"
    },
    "687CD5": {
        "oui_hex": "68-7C-D5",
        "organization": "Y Soft Corporation, a.s.",
        "address_1": "Technicka 2948/13",
        "address_2": "Brno  Czech Republic  616 00",
        "country": "CZ"
    },
    "907AF1": {
        "oui_hex": "90-7A-F1",
        "organization": "Wally",
        "address_1": "1415 NE 45th St",
        "address_2": "Seattle  WA  98105",
        "country": "US"
    },
    "2CB693": {
        "oui_hex": "2C-B6-93",
        "organization": "Radware",
        "address_1": "22 Raoul Wallenberg St.",
        "address_2": "Tel-Aviv    69710",
        "country": "IL"
    },
    "A861AA": {
        "oui_hex": "A8-61-AA",
        "organization": "Cloudview Limited",
        "address_1": "Kingsway House",
        "address_2": "St Peter Port  Guernsey  GY1 2QE",
        "country": "GB"
    },
    "FC1186": {
        "oui_hex": "FC-11-86",
        "organization": "Logic3 plc",
        "address_1": "Rhodes Way",
        "address_2": "Watford  Hertfordshire  WD24 4YW",
        "country": "GB"
    },
    "E01877": {
        "oui_hex": "E0-18-77",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "E457A8": {
        "oui_hex": "E4-57-A8",
        "organization": "Stuart Manufacturing, Inc.",
        "address_1": "1615 East Wallace Street",
        "address_2": "Fort Wayne  Indiana  46803",
        "country": "US"
    },
    "789966": {
        "oui_hex": "78-99-66",
        "organization": "Musilab Electronics (DongGuan)Co.,Ltd.",
        "address_1": "A2, LinDong 3 Road, LinCun",
        "address_2": "DongGuan  Guangdong  523710",
        "country": "CN"
    },
    "28CBEB": {
        "oui_hex": "28-CB-EB",
        "organization": "One",
        "address_1": "Mechelsesteenweg 326",
        "address_2": "Edegem  Antwerpen  2650",
        "country": "BE"
    },
    "7CA15D": {
        "oui_hex": "7C-A1-5D",
        "organization": "GN ReSound A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup  DK-CPH  2750",
        "country": "DK"
    },
    "3C081E": {
        "oui_hex": "3C-08-1E",
        "organization": "Beijing Yupont Electric Power Technology Co.,Ltd",
        "address_1": "No.1,Dizang-an Nanxiang",
        "address_2": "  Beijing  100045",
        "country": "CN"
    },
    "FC58FA": {
        "oui_hex": "FC-58-FA",
        "organization": "Shen Zhen Shi Xin Zhong Xin Technology Co.,Ltd.",
        "address_1": "Block 3, Dong Huan Industrial Zone, Sha Jing Town",
        "address_2": "Shen Zhen  Guang Dong  518000",
        "country": "CN"
    },
    "4CCC34": {
        "oui_hex": "4C-CC-34",
        "organization": "Motorola Solutions Inc.",
        "address_1": "One Motorola Plaza",
        "address_2": "Holtsville  NY  11742",
        "country": "US"
    },
    "D0D471": {
        "oui_hex": "D0-D4-71",
        "organization": "MVTECH co., Ltd",
        "address_1": "#1004, Hanshin IT Tower, 235, Guro 3-dong, Guro-Gu",
        "address_2": "SEOUL    152-768",
        "country": "KR"
    },
    "0868D0": {
        "oui_hex": "08-68-D0",
        "organization": "Japan System Design",
        "address_1": "Skyhills Deshio 3F",
        "address_2": "  Hiroshima  734-0001",
        "country": "JP"
    },
    "D4223F": {
        "oui_hex": "D4-22-3F",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,Torch Hi-tech Industry Development Zone,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "US"
    },
    "C8EEA6": {
        "oui_hex": "C8-EE-A6",
        "organization": "Shenzhen SHX Technology Co., Ltd",
        "address_1": "6F,No.10 buliding,JiuXiangling Industial Zone,Xili,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "2481AA": {
        "oui_hex": "24-81-AA",
        "organization": "KSH International Co., Ltd.",
        "address_1": "2F, No.17 Minsheng Rd, Xindian Dist.,",
        "address_2": "New Taipei City    23150",
        "country": "US"
    },
    "AC4122": {
        "oui_hex": "AC-41-22",
        "organization": "Eclipse Electronic Systems Inc.",
        "address_1": "17111 Waterview Parkway",
        "address_2": "Dallas  TX  75252",
        "country": "US"
    },
    "6897E8": {
        "oui_hex": "68-97-E8",
        "organization": "Society of Motion Picture &amp; Television Engineers",
        "address_1": "3 Barker Ave. FL5",
        "address_2": "White Plains  NY  10601",
        "country": "US"
    },
    "E8E875": {
        "oui_hex": "E8-E8-75",
        "organization": "iS5 Communications Inc.",
        "address_1": "#1-1815 Meyerside Drive",
        "address_2": "Mississauga  Ontario  L5T 1G3",
        "country": "CA"
    },
    "C80E95": {
        "oui_hex": "C8-0E-95",
        "organization": "OmniLync Inc.",
        "address_1": "51a Bennington St.",
        "address_2": "Newton  MA  02458",
        "country": "US"
    },
    "30055C": {
        "oui_hex": "30-05-5C",
        "organization": "Brother industries, LTD.",
        "address_1": "1-1-1, Kawagishi, Mizuho-ku,",
        "address_2": "Nagoya  Aichi  467-8562",
        "country": "JP"
    },
    "080EA8": {
        "oui_hex": "08-0E-A8",
        "organization": "Velex s.r.l.",
        "address_1": "Via Dell&#39;Artigianato 56",
        "address_2": "Vigodarzere  Padova  35010",
        "country": "IT"
    },
    "B8C46F": {
        "oui_hex": "B8-C4-6F",
        "organization": "PRIMMCON INDUSTRIES INC",
        "address_1": "137 MinQuan Rd, 5th Floor,",
        "address_2": "New Taipei    23141",
        "country": "TW"
    },
    "D8B02E": {
        "oui_hex": "D8-B0-2E",
        "organization": "Guangzhou Zonerich Business Machine Co., LTD.",
        "address_1": "North Gate, No.17 Yunjun Road, Luogang District",
        "address_2": " Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "C4E032": {
        "oui_hex": "C4-E0-32",
        "organization": "IEEE 1904.1 Working Group",
        "address_1": "1351 Redwood Way,",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "58EB14": {
        "oui_hex": "58-EB-14",
        "organization": "Proteus Digital Health",
        "address_1": "2600 Bridge Parkway, Ste 101",
        "address_2": "Redwood City  California  94065",
        "country": "US"
    },
    "C458C2": {
        "oui_hex": "C4-58-C2",
        "organization": "Shenzhen TATFOOK Technology Co., Ltd.",
        "address_1": "3rd Industrial Area of Shajing Industrial Company, Haoxiang Road",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "D0CDE1": {
        "oui_hex": "D0-CD-E1",
        "organization": "Scientech Electronics",
        "address_1": "4F, No.501-17, Zhong Zheng Rd,",
        "address_2": "New Taipei City    23148",
        "country": "TW"
    },
    "5CE0CA": {
        "oui_hex": "5C-E0-CA",
        "organization": "FeiTian United (Beijing) System Technology Co., Ltd.",
        "address_1": "3 Floor, Tower B, Huizhi Tower",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "E08177": {
        "oui_hex": "E0-81-77",
        "organization": "GreenBytes, Inc.",
        "address_1": "15 Gray Lane, Suite 301",
        "address_2": "Ashaway  RI  02804",
        "country": "US"
    },
    "9C9811": {
        "oui_hex": "9C-98-11",
        "organization": "Guangzhou Sunrise Electronics Development Co., Ltd",
        "address_1": "12th Floor,368 GuangZhou Avenue South",
        "address_2": "Guangzhou  Guangdong  510300",
        "country": "CN"
    },
    "B86091": {
        "oui_hex": "B8-60-91",
        "organization": "Onnet Technologies and Innovations LLC",
        "address_1": "1, 82/83 Street, New Industrial Area -II",
        "address_2": "Ajman  Ajman  52141",
        "country": "AE"
    },
    "8C76C1": {
        "oui_hex": "8C-76-C1",
        "organization": "Goden Tech Limited",
        "address_1": "ROOM 510-511C2 NAN FUNG TOWER.,",
        "address_2": "    999077",
        "country": "HK"
    },
    "8C078C": {
        "oui_hex": "8C-07-8C",
        "organization": "FLOW DATA INC",
        "address_1": "2309 GRAND PARK DRIVE",
        "address_2": "GRAND JUNCTION  CO  81505",
        "country": "US"
    },
    "F8DFA8": {
        "oui_hex": "F8-DF-A8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A895B0": {
        "oui_hex": "A8-95-B0",
        "organization": "Aker Subsea Ltd",
        "address_1": "Kiekhill Industrial Estate",
        "address_2": "  Aberdeen  AB51 3XA",
        "country": "GB"
    },
    "104D77": {
        "oui_hex": "10-4D-77",
        "organization": "Innovative Computer Engineering",
        "address_1": "10302 Eaton Place STE 100",
        "address_2": "Fairfax  VA  22030",
        "country": "US"
    },
    "C45DD8": {
        "oui_hex": "C4-5D-D8",
        "organization": "HDMI Forum",
        "address_1": "1140 East Arques Avenue, Suite 900",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "C4EBE3": {
        "oui_hex": "C4-EB-E3",
        "organization": "RRCN SAS",
        "address_1": "23 chemin du vieux chene",
        "address_2": "Meylan  Isere  38246",
        "country": "FR"
    },
    "94756E": {
        "oui_hex": "94-75-6E",
        "organization": "QinetiQ North America",
        "address_1": "137 Delta Drive",
        "address_2": "Pittsburgh  PA  15238",
        "country": "US"
    },
    "4C1A95": {
        "oui_hex": "4C-1A-95",
        "organization": "Novakon Co., Ltd.",
        "address_1": "6F., No. 120, Lane 235, Pao Chiao Road",
        "address_2": "New Taipei City    23145",
        "country": "TW"
    },
    "60BB0C": {
        "oui_hex": "60-BB-0C",
        "organization": "Beijing HuaqinWorld Technology Co,Ltd",
        "address_1": "30F,Beijing Silver Tower,No.2 North Road",
        "address_2": "Chao Yang District  Beijing  100027",
        "country": "CN"
    },
    "A42C08": {
        "oui_hex": "A4-2C-08",
        "organization": "Masterwork Automodules",
        "address_1": "11F-3, 3,PARK ST., NAN GANG",
        "address_2": "TAIPEI    11503",
        "country": "TW"
    },
    "10B9FE": {
        "oui_hex": "10-B9-FE",
        "organization": "Lika srl",
        "address_1": "Via San Lorenzo 25",
        "address_2": "Carrè  Vicenza  36010",
        "country": "IT"
    },
    "301518": {
        "oui_hex": "30-15-18",
        "organization": "Ubiquitous Communication Co. ltd.",
        "address_1": "JEI Platz RM No.410-1",
        "address_2": "  Seoul  153-792",
        "country": "KR"
    },
    "841715": {
        "oui_hex": "84-17-15",
        "organization": "GP Electronics (HK) Ltd.",
        "address_1": "Gold Peak Industrial Building, 6F",
        "address_2": "Kwai Chung  NT",
        "country": "HK"
    },
    "848E96": {
        "oui_hex": "84-8E-96",
        "organization": "Embertec Pty Ltd",
        "address_1": "182 Fullarton Road",
        "address_2": "Dulwich, Adelaide  South Australia  5065",
        "country": "AU"
    },
    "6499A0": {
        "oui_hex": "64-99-A0",
        "organization": "AG Elektronik AB",
        "address_1": "Smidesv 12",
        "address_2": "Staffanstorp    24534",
        "country": "SE"
    },
    "08F1B7": {
        "oui_hex": "08-F1-B7",
        "organization": "Towerstream Corpration",
        "address_1": "55 Hammerlund Way",
        "address_2": "Middletown  RI  02842",
        "country": "US"
    },
    "C044E3": {
        "oui_hex": "C0-44-E3",
        "organization": "Shenzhen Sinkna Electronics Co., LTD",
        "address_1": "9 Building, XinXin Tian Industry Area,",
        "address_2": "Shenzhen  Guangdong  5180000",
        "country": "CN"
    },
    "18550F": {
        "oui_hex": "18-55-0F",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "187A93": {
        "oui_hex": "18-7A-93",
        "organization": "AMICCOM Electronics Corporation",
        "address_1": "Room A3, 1F., No.1, Lixing 1st Rd",
        "address_2": "Hsinchu    30078",
        "country": "TW"
    },
    "8887DD": {
        "oui_hex": "88-87-DD",
        "organization": "DarbeeVision Inc.",
        "address_1": "401 N. Cotswolds Lane #C",
        "address_2": "Orange  California  92869",
        "country": "US"
    },
    "30C82A": {
        "oui_hex": "30-C8-2A",
        "organization": "WI-BIZ srl",
        "address_1": "Via Carlo Ferrero 10",
        "address_2": "Cascine Vica Rivoli  Torino  10098",
        "country": "IT"
    },
    "88A3CC": {
        "oui_hex": "88-A3-CC",
        "organization": "Amatis Controls",
        "address_1": " 210 Aspen Airport Business Center, Suite A",
        "address_2": "Aspen  CO  81611",
        "country": "US"
    },
    "C0A0C7": {
        "oui_hex": "C0-A0-C7",
        "organization": "FAIRFIELD INDUSTRIES",
        "address_1": "1111 GILLINGHAM LANE",
        "address_2": "SUGAR LAND  TEXAS  77478",
        "country": "US"
    },
    "DCA989": {
        "oui_hex": "DC-A9-89",
        "organization": "MACANDC",
        "address_1": "2-nd Filevskaya str.7/6",
        "address_2": "Moscow    121096",
        "country": "RU"
    },
    "A00363": {
        "oui_hex": "A0-03-63",
        "organization": "Robert Bosch Healthcare GmbH",
        "address_1": "Stuttgarter Stra",
        "address_2": "Waiblingen  Baden-Württemberg  71332",
        "country": "DE"
    },
    "D0B498": {
        "oui_hex": "D0-B4-98",
        "organization": "Robert Bosch LLC Automotive Electronics",
        "address_1": "15000 N Haggerty",
        "address_2": "Plymouth  Michigan  48170",
        "country": "US"
    },
    "E05597": {
        "oui_hex": "E0-55-97",
        "organization": "Emergent Vision Technologies Inc.",
        "address_1": "SUITE# 239 - 552A CLARKE ROAD",
        "address_2": "COQUITLAM  British Columbia  V3J 0A3",
        "country": "CA"
    },
    "7C438F": {
        "oui_hex": "7C-43-8F",
        "organization": "E-Band Communications Corp.",
        "address_1": "10095 Scripps Ranch Ct.  Ste A",
        "address_2": "San Diego  CA  92131",
        "country": "US"
    },
    "A0E25A": {
        "oui_hex": "A0-E2-5A",
        "organization": "Amicus SK, s.r.o.",
        "address_1": "Koreszkova 9",
        "address_2": "Skalica  Trnavsky kraj  90901",
        "country": "SK"
    },
    "D40FB2": {
        "oui_hex": "D4-0F-B2",
        "organization": "Applied Micro Electronics AME bv",
        "address_1": "Esp 100",
        "address_2": "Eindhoven  NB  5633 AA",
        "country": "NL"
    },
    "449B78": {
        "oui_hex": "44-9B-78",
        "organization": "The Now Factory",
        "address_1": "Arkle Road",
        "address_2": "Dublin 18",
        "country": "IE"
    },
    "F0F669": {
        "oui_hex": "F0-F6-69",
        "organization": "Motion Analysis Corporation",
        "address_1": "3617 Westwind Blvd.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "78995C": {
        "oui_hex": "78-99-5C",
        "organization": "Nationz Technologies Inc",
        "address_1": "12F,Tower Building #3,China Academy of Science and Technology Development,Gaoxin South Ave.1",
        "address_2": "Shen Zhen  GuangDong  518057",
        "country": "CN"
    },
    "849DC5": {
        "oui_hex": "84-9D-C5",
        "organization": "Centera Photonics Inc.",
        "address_1": "3F, No 6-3 Dusing Rd.",
        "address_2": "Hsinchu  Taiwan  30078",
        "country": "TW"
    },
    "580943": {
        "oui_hex": "58-09-43",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "ECFC55": {
        "oui_hex": "EC-FC-55",
        "organization": "A. Eberle GmbH & Co. KG",
        "address_1": "Frankenstrasse 160",
        "address_2": "Nuernberg  Bavaria  90461",
        "country": "DE"
    },
    "182A7B": {
        "oui_hex": "18-2A-7B",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "68FB95": {
        "oui_hex": "68-FB-95",
        "organization": "Generalplus Technology Inc.",
        "address_1": "3F, No.8, Dusing Rd., Hsinchu Science Park",
        "address_2": "Hsinchu City    30077",
        "country": "TW"
    },
    "F8F082": {
        "oui_hex": "F8-F0-82",
        "organization": "NAG LLC",
        "address_1": "Predelnaya st 57/2",
        "address_2": "Ekaterinburg  Sverdlovskaya oblast   620161",
        "country": "RU"
    },
    "5C89D4": {
        "oui_hex": "5C-89-D4",
        "organization": "Beijing Banner Electric Co.,Ltd",
        "address_1": "Mail Box 1033,Long cheng Garden",
        "address_2": "Chang Ping District  beijing  102208",
        "country": "CN"
    },
    "54115F": {
        "oui_hex": "54-11-5F",
        "organization": "Atamo Pty Ltd",
        "address_1": "21 River Road",
        "address_2": "Bayswater  WA  6156",
        "country": "AU"
    },
    "8CAE4C": {
        "oui_hex": "8C-AE-4C",
        "organization": "Plugable Technologies",
        "address_1": "40 Lake Bellevue Dr.",
        "address_2": "Bellevue  WA  98005",
        "country": "US"
    },
    "0CC655": {
        "oui_hex": "0C-C6-55",
        "organization": "Wuxi YSTen Technology Co.,Ltd.",
        "address_1": "Room 1801,18F, North Star Times Tower,",
        "address_2": "Chaoyang District  Beijing  100101",
        "country": "CN"
    },
    "242FFA": {
        "oui_hex": "24-2F-FA",
        "organization": "Toshiba Global Commerce Solutions",
        "address_1": "B307/D121F",
        "address_2": "RTP  NC  27709",
        "country": "US"
    },
    "E496AE": {
        "oui_hex": "E4-96-AE",
        "organization": "ALTOGRAPHICS Inc.",
        "address_1": "Daegu Venture Center 13F",
        "address_2": "  Daegu  701-020",
        "country": "KR"
    },
    "4C2258": {
        "oui_hex": "4C-22-58",
        "organization": "cozybit, Inc.",
        "address_1": "605 Market Street",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "F49466": {
        "oui_hex": "F4-94-66",
        "organization": "CountMax,  ltd",
        "address_1": "11 Titova str.",
        "address_2": "poselok Lesnoy  Moscowskaya oblast  141231",
        "country": "RU"
    },
    "F45214": {
        "oui_hex": "F4-52-14",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "1C959F": {
        "oui_hex": "1C-95-9F",
        "organization": "Veethree Electronics And Marine LLC",
        "address_1": "2050 47th Terrace East",
        "address_2": "Bradenton  Florida  34203",
        "country": "US"
    },
    "0881F4": {
        "oui_hex": "08-81-F4",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "10F49A": {
        "oui_hex": "10-F4-9A",
        "organization": "T3 Innovation",
        "address_1": "808 Calle Plano",
        "address_2": "Camarillo  CA  93012",
        "country": "US"
    },
    "3C57BD": {
        "oui_hex": "3C-57-BD",
        "organization": "Kessler Crane Inc.",
        "address_1": "602 East Jefferson St",
        "address_2": "Plymouth  Indidana  46563",
        "country": "US"
    },
    "04E9E5": {
        "oui_hex": "04-E9-E5",
        "organization": "PJRC.COM, LLC",
        "address_1": "14723 SW Brooke Ct",
        "address_2": "Sherwood  Oregon  97140",
        "country": "US"
    },
    "60BD91": {
        "oui_hex": "60-BD-91",
        "organization": "Move Innovation",
        "address_1": "Generatorvej 8B,st",
        "address_2": "Herlev  DK  2730",
        "country": "DK"
    },
    "CC4BFB": {
        "oui_hex": "CC-4B-FB",
        "organization": "Hellberg Safety AB",
        "address_1": "Stakebergsvagen 2",
        "address_2": "Stenkullen    44361",
        "country": "SE"
    },
    "6CADEF": {
        "oui_hex": "6C-AD-EF",
        "organization": "KZ Broadband Technologies, Ltd.",
        "address_1": "1601 Tower C",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "745FAE": {
        "oui_hex": "74-5F-AE",
        "organization": "TSL PPL",
        "address_1": "Units 1-2, First Avenue",
        "address_2": "Marlow  Buckinghamshire  SL7 1YA",
        "country": "GB"
    },
    "6851B7": {
        "oui_hex": "68-51-B7",
        "organization": "PowerCloud Systems, Inc.",
        "address_1": "3333 Coyote Hill Rd",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "742D0A": {
        "oui_hex": "74-2D-0A",
        "organization": "Norfolk Elektronik AG",
        "address_1": "Luzernstrasse 12",
        "address_2": "Eschenbach  LU  6274",
        "country": "CH"
    },
    "70F1E5": {
        "oui_hex": "70-F1-E5",
        "organization": "Xetawave LLC",
        "address_1": "1668 Valtec Lane",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "C0AA68": {
        "oui_hex": "C0-AA-68",
        "organization": "OSASI Technos Inc.",
        "address_1": "65-3, Hongu-cho,",
        "address_2": "Kochi-shi, Kochi-ken     780-0945",
        "country": "JP"
    },
    "88D7BC": {
        "oui_hex": "88-D7-BC",
        "organization": "DEP Company",
        "address_1": "Poryadkovy pereulok,21",
        "address_2": "Moscow    127055",
        "country": "RU"
    },
    "485A3F": {
        "oui_hex": "48-5A-3F",
        "organization": "WISOL",
        "address_1": "373-7, Gajang-dong",
        "address_2": "Osan-si  Gyeonggi-do  447-210",
        "country": "KR"
    },
    "60BC4C": {
        "oui_hex": "60-BC-4C",
        "organization": "EWM Hightec Welding GmbH",
        "address_1": "Dr.Günter-Henle-Str. 8",
        "address_2": "Mündersbach  Rheinland Pfalz  56271",
        "country": "DE"
    },
    "1C11E1": {
        "oui_hex": "1C-11-E1",
        "organization": "Wartsila Finland Oy",
        "address_1": "Jarvikatu 2-4",
        "address_2": "Vaasa  Western Finland  65101",
        "country": "FI"
    },
    "50465D": {
        "oui_hex": "50-46-5D",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "74BFA1": {
        "oui_hex": "74-BF-A1",
        "organization": "HYUNTECK",
        "address_1": "#603 107-Dong, Jugong Apt., Changhyeon-ri, Hwado-eup",
        "address_2": "Namyangju-si  Gyeonggi-do  472-779",
        "country": "KR"
    },
    "CC262D": {
        "oui_hex": "CC-26-2D",
        "organization": "Verifi, LLC",
        "address_1": "9466 Meridian Way",
        "address_2": "West Chester   OH  45069",
        "country": "US"
    },
    "3C8AE5": {
        "oui_hex": "3C-8A-E5",
        "organization": "Tensun Information Technology(Hangzhou) Co.,LTD",
        "address_1": "Room 207,Building 5,Wensan Road",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "2C5AA3": {
        "oui_hex": "2C-5A-A3",
        "organization": "PROMATE ELECTRONIC CO.LTD",
        "address_1": "4F 32,SEC.1 HUAN SHAN RD.,NEI HU,",
        "address_2": "TAIPEI    114",
        "country": "TW"
    },
    "34E0CF": {
        "oui_hex": "34-E0-CF",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "08B738": {
        "oui_hex": "08-B7-38",
        "organization": "Lite-On Technogy Corp.",
        "address_1": "18F, 392, RueyKuang Road, Neihu,",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "F8AA8A": {
        "oui_hex": "F8-AA-8A",
        "organization": "Axview Technology (Shenzhen) Co.,Ltd",
        "address_1": "NO 1, Mei Zhong Road, Futian District",
        "address_2": "SHENZHEN  GUANGDONG  518049",
        "country": "CN"
    },
    "7C0187": {
        "oui_hex": "7C-01-87",
        "organization": "Curtis Instruments, Inc.",
        "address_1": "200 Kisco Avenue",
        "address_2": "Mt Kisco  NY  10549",
        "country": "US"
    },
    "54F666": {
        "oui_hex": "54-F6-66",
        "organization": "Berthold Technologies GmbH and Co.KG",
        "address_1": "Calmbacher Strasse 22",
        "address_2": "Bad Wildbad    75323",
        "country": "DE"
    },
    "34C803": {
        "oui_hex": "34-C8-03",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "F05F5A": {
        "oui_hex": "F0-5F-5A",
        "organization": "Getriebebau NORD GmbH and Co. KG",
        "address_1": "Rudolf-Diesel-Strasse 1",
        "address_2": "Bargteheide  Schleswig-Holstein  22941",
        "country": "DE"
    },
    "801DAA": {
        "oui_hex": "80-1D-AA",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "7C092B": {
        "oui_hex": "7C-09-2B",
        "organization": "Bekey A/S",
        "address_1": "Bredebjergvej 6",
        "address_2": "Taastrup    2630",
        "country": "DK"
    },
    "842BBC": {
        "oui_hex": "84-2B-BC",
        "organization": "Modelleisenbahn GmbH",
        "address_1": "Plainbachstrasse 4",
        "address_2": "Bergheim    5101",
        "country": "AT"
    },
    "B4009C": {
        "oui_hex": "B4-00-9C",
        "organization": "CableWorld Ltd.",
        "address_1": "Kondorfa u. 6/B",
        "address_2": "Budapest    1112",
        "country": "HU"
    },
    "289EDF": {
        "oui_hex": "28-9E-DF",
        "organization": "Danfoss Turbocor Compressors, Inc",
        "address_1": "1769 E. Paul Dirac Ave.",
        "address_2": "Tallahassee  Florida  32310",
        "country": "US"
    },
    "803FD6": {
        "oui_hex": "80-3F-D6",
        "organization": "bytes at work AG",
        "address_1": "Konradstrasse 15",
        "address_2": "Winterthur  ZH  8400",
        "country": "CH"
    },
    "784405": {
        "oui_hex": "78-44-05",
        "organization": "FUJITU(HONG KONG) ELECTRONIC Co.,LTD.",
        "address_1": "8/F,QingHai Building,Xiang Mei Road,Futian District",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "044A50": {
        "oui_hex": "04-4A-50",
        "organization": "Ramaxel Technology (Shenzhen) limited company",
        "address_1": "2-5/F,North Block Southeast Industrial and Commercial Building Houhai Road,Shekou Shenzhen",
        "address_2": "shenzhen  guangdong  518067",
        "country": "CN"
    },
    "0CD9C1": {
        "oui_hex": "0C-D9-C1",
        "organization": "Visteon Corporation",
        "address_1": "One Village Center Drive",
        "address_2": "Van Buren Twp  MI  48111",
        "country": "US"
    },
    "38A5B6": {
        "oui_hex": "38-A5-B6",
        "organization": "SHENZHEN MEGMEET ELECTRICAL CO.,LTD",
        "address_1": "5th Floor,Building B, Ziguang Information Harbor",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "68AB8A": {
        "oui_hex": "68-AB-8A",
        "organization": "RF IDeas",
        "address_1": "4020 Winnetka Ave",
        "address_2": "Rolling Meadows  IL  60008",
        "country": "US"
    },
    "24EE3A": {
        "oui_hex": "24-EE-3A",
        "organization": "Chengdu Yingji Electronic Hi-tech Co Ltd",
        "address_1": "No.3 South Herui Road Hi-tech Zone",
        "address_2": "Chengdu City  Sichuan  611731",
        "country": "CN"
    },
    "0CC66A": {
        "oui_hex": "0C-C6-6A",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "74273C": {
        "oui_hex": "74-27-3C",
        "organization": "ChangYang Technology (Nanjing) Co., LTD",
        "address_1": "NO.9 KaiCheng Road,QiLinTown",
        "address_2": "NanJing  JiangSu  211100",
        "country": "CN"
    },
    "087CBE": {
        "oui_hex": "08-7C-BE",
        "organization": "Quintic Corp.",
        "address_1": "1600 Wyatt Dr., #8",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "E804F3": {
        "oui_hex": "E8-04-F3",
        "organization": "Throughtek Co., Ltd.",
        "address_1": "4F, no. 221, Chong-yang Rd.",
        "address_2": "Taipei    11573",
        "country": "TW"
    },
    "0868EA": {
        "oui_hex": "08-68-EA",
        "organization": "EITO ELECTRONICS CO., LTD.",
        "address_1": "1-34-1 Shinmeidai",
        "address_2": "Hamura-shi  Tokyo  205-0023",
        "country": "JP"
    },
    "F82285": {
        "oui_hex": "F8-22-85",
        "organization": "Cypress Technology CO., LTD.",
        "address_1": "6F-5, NO., 130 Jiankang Rd.,",
        "address_2": "Zhonghe Dist.  New Taipei City  23585",
        "country": "TW"
    },
    "C4AD21": {
        "oui_hex": "C4-AD-21",
        "organization": "MEDIAEDGE Corporation",
        "address_1": "23F Kobe Commerce, Industry and Trade Center Bldg.",
        "address_2": "Kobe  Hyogo  651-0083",
        "country": "JP"
    },
    "E85BF0": {
        "oui_hex": "E8-5B-F0",
        "organization": "Imaging Diagnostics",
        "address_1": "POB 698",
        "address_2": "Nes Ziona  N/A  74106",
        "country": "IL"
    },
    "A40BED": {
        "oui_hex": "A4-0B-ED",
        "organization": "Carry Technology Co.,Ltd",
        "address_1": "4F, No.119, JianKang Road",
        "address_2": "Jhonghe Dist.  New Taipei City  23585",
        "country": "TW"
    },
    "702393": {
        "oui_hex": "70-23-93",
        "organization": "fos4X GmbH",
        "address_1": "Thalkirchner Str. 210, Geb. 6",
        "address_2": "81371 München",
        "country": "DE"
    },
    "64D814": {
        "oui_hex": "64-D8-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F85F2A": {
        "oui_hex": "F8-5F-2A",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "C438D3": {
        "oui_hex": "C4-38-D3",
        "organization": "TAGATEC CO.,LTD",
        "address_1": "#604, Dongmoon Goodmorning Tower 2,",
        "address_2": "Goyang-si  Kyunggi-do  410-704",
        "country": "KR"
    },
    "502ECE": {
        "oui_hex": "50-2E-CE",
        "organization": "Asahi Electronics Co.,Ltd",
        "address_1": "29-25 Kariyado",
        "address_2": "  Kanagawa-ken  211-0022",
        "country": "JP"
    },
    "AC14D2": {
        "oui_hex": "AC-14-D2",
        "organization": "wi-daq, inc.",
        "address_1": "850 NW Federal Hwy",
        "address_2": "Stuart  Florida  34994",
        "country": "US"
    },
    "9C4CAE": {
        "oui_hex": "9C-4C-AE",
        "organization": "Mesa Labs",
        "address_1": "10 Evergreen Dr",
        "address_2": "Bozeman  MT  59715",
        "country": "US"
    },
    "20C1AF": {
        "oui_hex": "20-C1-AF",
        "organization": "i Wit Digital Co., Limited",
        "address_1": "303,Buiding1,Nanhai Ecool Innovation Park,",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "US"
    },
    "80AAA4": {
        "oui_hex": "80-AA-A4",
        "organization": "USAG",
        "address_1": "301 Goolsby Blvd",
        "address_2": "Deerfield Beach  FL  33442",
        "country": "US"
    },
    "30AEF6": {
        "oui_hex": "30-AE-F6",
        "organization": "Radio Mobile Access",
        "address_1": "1 Elm Sq",
        "address_2": "Andover  MA  01870",
        "country": "US"
    },
    "085B0E": {
        "oui_hex": "08-5B-0E",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  California  94086",
        "country": "US"
    },
    "EC42F0": {
        "oui_hex": "EC-42-F0",
        "organization": "ADL Embedded Solutions, Inc.",
        "address_1": "4411 Morena Blvd.",
        "address_2": "San Diego  CA  92117",
        "country": "US"
    },
    "E8CBA1": {
        "oui_hex": "E8-CB-A1",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "6CE4CE": {
        "oui_hex": "6C-E4-CE",
        "organization": "Villiger Security Solutions AG",
        "address_1": "Giessenmatt 2",
        "address_2": "Sins    5643",
        "country": "CH"
    },
    "649FF7": {
        "oui_hex": "64-9F-F7",
        "organization": "Kone OYj",
        "address_1": "Myllykatu 3",
        "address_2": "Hyvinkaa  Hyvinkaa  05830",
        "country": "FI"
    },
    "CC912B": {
        "oui_hex": "CC-91-2B",
        "organization": "TE Connectivity Touch Solutions",
        "address_1": "2245 Brighton Henrietta Town Line Road",
        "address_2": "Rochester  New York  14623",
        "country": "US"
    },
    "C05E79": {
        "oui_hex": "C0-5E-79",
        "organization": "SHENZHEN HUAXUN ARK TECHNOLOGIES CO.,LTD",
        "address_1": "3F,C4 Building,Yintian Industrial Zone,Xixiang,Baoan District",
        "address_2": "shenzhen  guangdong  518102",
        "country": "CN"
    },
    "58BFEA": {
        "oui_hex": "58-BF-EA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C401B1": {
        "oui_hex": "C4-01-B1",
        "organization": "SeekTech INC",
        "address_1": "3855 Ruffin Road",
        "address_2": "San Diego  California  92123",
        "country": "US"
    },
    "C0C946": {
        "oui_hex": "C0-C9-46",
        "organization": "MITSUYA LABORATORIES INC.",
        "address_1": "6-31-18",
        "address_2": "KAWASAKI-CITY  KANAGAWA  215-0021",
        "country": "JP"
    },
    "F4600D": {
        "oui_hex": "F4-60-0D",
        "organization": "Panoptic Technology, Inc",
        "address_1": "587 W Eau Gallie Blvd",
        "address_2": "Melbourne  FL  32935",
        "country": "US"
    },
    "A82BD6": {
        "oui_hex": "A8-2B-D6",
        "organization": "Shina System Co., Ltd",
        "address_1": "3305, O'BizTower, 126, Beolmal-ro,",
        "address_2": "Anyang-Si  Gyeounggi-Do  431-763",
        "country": "KR"
    },
    "ACCF23": {
        "oui_hex": "AC-CF-23",
        "organization": "Hi-flying electronics technology Co.,Ltd",
        "address_1": "Room B101,456 BiBo Raod,PuDong",
        "address_2": "  Shanghai  201200",
        "country": "CN"
    },
    "609084": {
        "oui_hex": "60-90-84",
        "organization": "DSSD Inc",
        "address_1": "4025 Bohannon Dr",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "FC1D59": {
        "oui_hex": "FC-1D-59",
        "organization": "I Smart Cities HK Ltd",
        "address_1": "Unit G,10/F,Phase 2,Yip Fat IND",
        "address_2": "    73-75",
        "country": "HK"
    },
    "78C4AB": {
        "oui_hex": "78-C4-AB",
        "organization": "Shenzhen Runsil Technology Co.,Ltd",
        "address_1": "4/F., Yuhua Building A, Yangmen Industrial Park,",
        "address_2": "Shenzhen  GuangDong  518055",
        "country": "CN"
    },
    "B0A86E": {
        "oui_hex": "B0-A8-6E",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "802AFA": {
        "oui_hex": "80-2A-FA",
        "organization": "Germaneers GmbH",
        "address_1": "Dr.-Kurt-Schumacher-Ring 3",
        "address_2": "Wettstetten  Bayern  85139",
        "country": "DE"
    },
    "18421D": {
        "oui_hex": "18-42-1D",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "28C914": {
        "oui_hex": "28-C9-14",
        "organization": "Taimag Corporation",
        "address_1": "NO. 1, West 2nd St. N.E.P.Z",
        "address_2": "Kaohsiung    811",
        "country": "TW"
    },
    "7493A4": {
        "oui_hex": "74-93-A4",
        "organization": "Zebra Technologies Corp.",
        "address_1": "20314 Seneca Meadows Parkway",
        "address_2": "Germantown  Maryland  21771",
        "country": "US"
    },
    "E47185": {
        "oui_hex": "E4-71-85",
        "organization": "Securifi Ltd",
        "address_1": "16F-3, #482 Zhongxiao E Rd, Sec 5",
        "address_2": "Taipei    11083",
        "country": "TW"
    },
    "080CC9": {
        "oui_hex": "08-0C-C9",
        "organization": "Mission Technology Group, dba Magma",
        "address_1": "9918 Via Pasar",
        "address_2": "San Diego  CA  92126",
        "country": "US"
    },
    "640E94": {
        "oui_hex": "64-0E-94",
        "organization": "Pluribus Networks, Inc.",
        "address_1": "1808 Embarcadero Rd Suite B",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "0CB4EF": {
        "oui_hex": "0C-B4-EF",
        "organization": "Digience Co.,Ltd.",
        "address_1": "204 Building for Growth, Gumi Electronics&Information Technology Research Institute, 17 Cheomdangieop-1ro,",
        "address_2": "Gumi  Gyeongbuk",
        "country": "KR"
    },
    "146A0B": {
        "oui_hex": "14-6A-0B",
        "organization": "Cypress Electronics Limited",
        "address_1": "11/F., Block G, East Sun Industrial Centre, 16 Shing Yip Street,",
        "address_2": "Hong Kong  nil  nil",
        "country": "HK"
    },
    "F490EA": {
        "oui_hex": "F4-90-EA",
        "organization": "Deciso B.V.",
        "address_1": "Burgemeester Mijslaan 2",
        "address_2": "Middelharnis  Zuid Holland  3241 XA",
        "country": "NL"
    },
    "5CEE79": {
        "oui_hex": "5C-EE-79",
        "organization": "Global Digitech Co LTD",
        "address_1": "1F., No.25, Aly.56, Ln. 245, Sec. 4, Bade Rd.,",
        "address_2": "Taipei  Taiwan  105",
        "country": "TW"
    },
    "4CAA16": {
        "oui_hex": "4C-AA-16",
        "organization": "AzureWave Technologies (Shanghai) Inc.",
        "address_1": "No.8 Lane 66, Chenbao Road, Malu Town Jiading District",
        "address_2": "Shanghai    201801",
        "country": "CN"
    },
    "AC40EA": {
        "oui_hex": "AC-40-EA",
        "organization": "C&T Solution Inc.",
        "address_1": "12F-1, No.700, Zhongzheng Rd., Zhonghe Dist.",
        "address_2": "New Taipei City  Taiwan   235",
        "country": "TW"
    },
    "002AAF": {
        "oui_hex": "00-2A-AF",
        "organization": "LARsys-Automation GmbH",
        "address_1": "Sinzinger Str. 3",
        "address_2": "Hochburg-Ach    5122",
        "country": "AT"
    },
    "1CE165": {
        "oui_hex": "1C-E1-65",
        "organization": "Marshal Corporation",
        "address_1": "Field Three Sotokanda Bldg.",
        "address_2": "5-3-6, Sotokanda, Chiyodaku  Tokyo  101-0021",
        "country": "JP"
    },
    "4016FA": {
        "oui_hex": "40-16-FA",
        "organization": "EKM Metering",
        "address_1": "363 Berkeley Way",
        "address_2": "Santa Cruz  CA  95062",
        "country": "US"
    },
    "0C130B": {
        "oui_hex": "0C-13-0B",
        "organization": "Uniqoteq Ltd.",
        "address_1": "Lemminkaisenkatu 14-18 A",
        "address_2": "Turku    20520",
        "country": "FI"
    },
    "2C542D": {
        "oui_hex": "2C-54-2D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BC1401": {
        "oui_hex": "BC-14-01",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "94CA0F": {
        "oui_hex": "94-CA-0F",
        "organization": "Honeywell Analytics",
        "address_1": "2840 2nd Ave SE",
        "address_2": "Calgary  Alberta  T2A7X9",
        "country": "CA"
    },
    "782544": {
        "oui_hex": "78-25-44",
        "organization": "Omnima Limited",
        "address_1": "Oxford Science Park",
        "address_2": "Oxford  Oxfordshire  OX4 4GP",
        "country": "GB"
    },
    "A41875": {
        "oui_hex": "A4-18-75",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C8AE9C": {
        "oui_hex": "C8-AE-9C",
        "organization": "Shanghai TYD Elecronic Technology Co. Ltd",
        "address_1": "21F, BLKB, NO.391 GuiPing Rd,",
        "address_2": "  Shanghai  200233",
        "country": "CN"
    },
    "AC3FA4": {
        "oui_hex": "AC-3F-A4",
        "organization": "TAIYO YUDEN CO.,LTD",
        "address_1": "8-1, Sakae-cho",
        "address_2": "Takasaki-shi  Gunma  370-8522",
        "country": "JP"
    },
    "6CAE8B": {
        "oui_hex": "6C-AE-8B",
        "organization": "IBM Corporation",
        "address_1": "4400 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "40AC8D": {
        "oui_hex": "40-AC-8D",
        "organization": "Data Management, Inc.",
        "address_1": "3322 Loop 306",
        "address_2": "San Angelo  Texas  76904",
        "country": "US"
    },
    "80CEB1": {
        "oui_hex": "80-CE-B1",
        "organization": "Theissen Training Systems GmbH",
        "address_1": "Schuchardstrasse 3",
        "address_2": "Duesseldorf  NRW  40595",
        "country": "DE"
    },
    "FC2A54": {
        "oui_hex": "FC-2A-54",
        "organization": "Connected Data, Inc.",
        "address_1": "2905 Stender Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "045C06": {
        "oui_hex": "04-5C-06",
        "organization": "Zmodo Technology Corporation",
        "address_1": "1401 Interstate Dr",
        "address_2": "Champaign  IL  61822",
        "country": "US"
    },
    "747B7A": {
        "oui_hex": "74-7B-7A",
        "organization": "ETH Inc.",
        "address_1": "#202 Mazium BLG, 545-6, Dangjung-dong,",
        "address_2": "Gunpo-si  Gyeonggi-do  435-833",
        "country": "KR"
    },
    "48EA63": {
        "oui_hex": "48-EA-63",
        "organization": "Zhejiang Uniview Technologies Co., Ltd.",
        "address_1": "Eastcom Building C,Eastcom Avenue",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "E88DF5": {
        "oui_hex": "E8-8D-F5",
        "organization": "ZNYX Networks, Inc.",
        "address_1": "48421 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "90F72F": {
        "oui_hex": "90-F7-2F",
        "organization": "Phillips Machine & Welding Co., Inc.",
        "address_1": "16125 E. Gale Ave.",
        "address_2": "Industry  CA  91745",
        "country": "US"
    },
    "D05785": {
        "oui_hex": "D0-57-85",
        "organization": "Pantech Co., Ltd.",
        "address_1": "110-1 Ongjeong-Ri, Tongjin-Eup",
        "address_2": "Gimpo-Si  Gyounggi-Do  415-865",
        "country": "KR"
    },
    "408B07": {
        "oui_hex": "40-8B-07",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "284121": {
        "oui_hex": "28-41-21",
        "organization": "OptiSense Network, LLC",
        "address_1": "1308 10th Street",
        "address_2": "Bridgeport  TX  76426",
        "country": "US"
    },
    "38458C": {
        "oui_hex": "38-45-8C",
        "organization": "MyCloud Technology corporation",
        "address_1": "Room 705£¬Building F, Jiahua Building£¬",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "10E4AF": {
        "oui_hex": "10-E4-AF",
        "organization": "APR, LLC",
        "address_1": "4800 US HWY 280 West",
        "address_2": "Opelika  AL  36801",
        "country": "US"
    },
    "F4EA67": {
        "oui_hex": "F4-EA-67",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2C2D48": {
        "oui_hex": "2C-2D-48",
        "organization": "bct electronic GesmbH",
        "address_1": "Saalachstraße 86a",
        "address_2": "Salzburg    5020",
        "country": "AT"
    },
    "28BA18": {
        "oui_hex": "28-BA-18",
        "organization": "NextNav, LLC",
        "address_1": "484 Oakmead Parkway",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "AC3D75": {
        "oui_hex": "AC-3D-75",
        "organization": "HANGZHOU ZHIWAY TECHNOLOGIES CO.,LTD.",
        "address_1": "FLOOR12B,BUILDING E,PARADISE SOFTWARE PARK,NO.3 XIDOUMEN ROAD,",
        "address_2": "HANGZHOU  ZHEJIANG  310012",
        "country": "CN"
    },
    "A090DE": {
        "oui_hex": "A0-90-DE",
        "organization": "VEEDIMS,LLC",
        "address_1": "49 N. Federal Highway #397",
        "address_2": "Pompano Beach  Florida  33062",
        "country": "US"
    },
    "642DB7": {
        "oui_hex": "64-2D-B7",
        "organization": "SEUNGIL ELECTRONICS",
        "address_1": "#16-8, Dodang-dong",
        "address_2": "Buchon  Gyuonggi-do  420-801",
        "country": "KR"
    },
    "002A6A": {
        "oui_hex": "00-2A-6A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F436E1": {
        "oui_hex": "F4-36-E1",
        "organization": "Abilis Systems SARL",
        "address_1": "3, chemin Pré Fleuri",
        "address_2": "Plan-Les-Ouates  Geneva  1228",
        "country": "CH"
    },
    "781C5A": {
        "oui_hex": "78-1C-5A",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "E80C75": {
        "oui_hex": "E8-0C-75",
        "organization": "Syncbak, Inc.",
        "address_1": "5 Research Center",
        "address_2": "Marion  IA  52302",
        "country": "US"
    },
    "800A06": {
        "oui_hex": "80-0A-06",
        "organization": "COMTEC co.,ltd",
        "address_1": "60 shimoishida,azabu-cho,",
        "address_2": "Miyoshi-shi  Aichi-ken  470-0206",
        "country": "JP"
    },
    "608C2B": {
        "oui_hex": "60-8C-2B",
        "organization": "Hanson Technology",
        "address_1": "Room 1503, Zhao Jia Bang Road",
        "address_2": "Shanghai    200030",
        "country": "CN"
    },
    "940070": {
        "oui_hex": "94-00-70",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "BC2C55": {
        "oui_hex": "BC-2C-55",
        "organization": "Bear Flag Design, Inc.",
        "address_1": "1 Thayer Road",
        "address_2": "Santa Cruz  CA  95060",
        "country": "US"
    },
    "0C7523": {
        "oui_hex": "0C-75-23",
        "organization": "BEIJING GEHUA CATV NETWORK CO.,LTD",
        "address_1": "No.35,N.Huayuan RD.,Haidian District",
        "address_2": "BEIJING    100083",
        "country": "CN"
    },
    "04F021": {
        "oui_hex": "04-F0-21",
        "organization": "Compex Systems Pte Ltd",
        "address_1": "135 Joo Seng Road,",
        "address_2": "    368363",
        "country": "SG"
    },
    "2818FD": {
        "oui_hex": "28-18-FD",
        "organization": "Aditya Infotech Ltd.",
        "address_1": "Khemka Square, A-12, Sector-4,",
        "address_2": "Noida  Uttar Pradesh  201301",
        "country": "IN"
    },
    "D8B90E": {
        "oui_hex": "D8-B9-0E",
        "organization": "Triple Domain Vision Co.,Ltd.",
        "address_1": "No.9, Aly. 1, Ln. 585, Sec.3, Fulin Rd.,",
        "address_2": "Hsinchu Conuty    307",
        "country": "TW"
    },
    "342F6E": {
        "oui_hex": "34-2F-6E",
        "organization": "Anywire corporation",
        "address_1": "1 Zusyo, Baba",
        "address_2": "Nagaokakyo  Kyoto pref.  617-8550",
        "country": "JP"
    },
    "CCEED9": {
        "oui_hex": "CC-EE-D9",
        "organization": "VAHLE Automation GmbH",
        "address_1": "Egerbach 12a",
        "address_2": "Kufstein   Schwoich Tirol  6334",
        "country": "AT"
    },
    "005CB1": {
        "oui_hex": "00-5C-B1",
        "organization": "Gospell DIGITAL TECHNOLOGY CO., LTD",
        "address_1": "Block F10-F13Â¡Â¢F518 Idea land Â¡Â¢Bao Yuan Road",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "B08E1A": {
        "oui_hex": "B0-8E-1A",
        "organization": "URadio Systems Co., Ltd",
        "address_1": "Phase II D202-2, 1355 JinJiHu Blvd",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "D8E952": {
        "oui_hex": "D8-E9-52",
        "organization": "KEOPSYS",
        "address_1": "21 RUE LOUIS DE BROGLIE",
        "address_2": "LANNION  BRITANY  22300",
        "country": "FR"
    },
    "BCA4E1": {
        "oui_hex": "BC-A4-E1",
        "organization": "Nabto",
        "address_1": "Aabogade 15",
        "address_2": "Aarhus  Jutland  8200",
        "country": "DK"
    },
    "908FCF": {
        "oui_hex": "90-8F-CF",
        "organization": "UNO System Co., Ltd",
        "address_1": "#402 Kolon Science Valley °., 187-10, Guro-dong, Guro-gu",
        "address_2": "Seoul    152-848",
        "country": "KR"
    },
    "40E793": {
        "oui_hex": "40-E7-93",
        "organization": "Shenzhen Siviton Technology Co.,Ltd",
        "address_1": "4F,Block6,Coolpad Business Centre,North of Keyuan Road,Hi-technology Zone,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "000831": {
        "oui_hex": "00-08-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "34D09B": {
        "oui_hex": "34-D0-9B",
        "organization": "MobilMAX Technology Inc.",
        "address_1": "2F-5, No.28, Tai-Yuan St.",
        "address_2": "Chupei City, Hsinchu Country    302",
        "country": "TW"
    },
    "F0007F": {
        "oui_hex": "F0-00-7F",
        "organization": "Janz - Contadores de Energia, SA",
        "address_1": "Avenida Infante D. Henrique",
        "address_2": "Lisbon    1800-223",
        "country": "PT"
    },
    "30B3A2": {
        "oui_hex": "30-B3-A2",
        "organization": "Shenzhen Heguang Measurement & Control Technology Co.,Ltd",
        "address_1": "3/F, Tower A, Xiangnian Plaza, 6060 Qiaoxiang Road,",
        "address_2": "Shenzhen  Guangdong  518053",
        "country": "CN"
    },
    "506028": {
        "oui_hex": "50-60-28",
        "organization": "Xirrus Inc.",
        "address_1": "2101 CORPORATE CENTER DR",
        "address_2": "Thousand Oaks  CALIFORNIA  91320",
        "country": "US"
    },
    "0091FA": {
        "oui_hex": "00-91-FA",
        "organization": "Synapse Product Development",
        "address_1": "1511 6th Ave",
        "address_2": "Seattle  WA  98101",
        "country": "US"
    },
    "A05AA4": {
        "oui_hex": "A0-5A-A4",
        "organization": "Grand Products Nevada, Inc.",
        "address_1": "751 Pilot Rd.",
        "address_2": "Las Vegas  Nevada  89119",
        "country": "US"
    },
    "F0EEBB": {
        "oui_hex": "F0-EE-BB",
        "organization": "VIPAR GmbH",
        "address_1": "Lichtenbergstrasse 8",
        "address_2": "Garching bei Muenchen  Bavaria  85748",
        "country": "DE"
    },
    "6CE907": {
        "oui_hex": "6C-E9-07",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "E4FA1D": {
        "oui_hex": "E4-FA-1D",
        "organization": "PAD Peripheral Advanced Design Inc.",
        "address_1": "1400 Hocquart",
        "address_2": "Saint-Bruno  QC  J3V 6E1",
        "country": "CA"
    },
    "1C5C55": {
        "oui_hex": "1C-5C-55",
        "organization": "PRIMA Cinema, Inc",
        "address_1": "1903 Wright Place, Suite 320",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "34BA9A": {
        "oui_hex": "34-BA-9A",
        "organization": "Asiatelco Technologies Co.",
        "address_1": "301,#8 Building,#289 Bisheng Road",
        "address_2": "Shanghai    201204",
        "country": "CN"
    },
    "506441": {
        "oui_hex": "50-64-41",
        "organization": "Greenlee",
        "address_1": "219 S Main St",
        "address_2": "Dallas  TX  76104",
        "country": "US"
    },
    "9C1FDD": {
        "oui_hex": "9C-1F-DD",
        "organization": "Accupix Inc.",
        "address_1": "3F Gaeyang BLDG, 548-1,",
        "address_2": "Anyang  Kyeonggi-Do  430-730",
        "country": "KR"
    },
    "7CDD11": {
        "oui_hex": "7C-DD-11",
        "organization": "Chongqing MAS SCI&TECH.Co.,Ltd",
        "address_1": " 6th Floor, Zone C2,Hi-tech Venture Park, No.105 Erlang Venture Road",
        "address_2": "Chongqing City    400039",
        "country": "CN"
    },
    "B8FD32": {
        "oui_hex": "B8-FD-32",
        "organization": "Zhejiang ROICX Microelectronics",
        "address_1": "22 Floor, 1888 Jianghui Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "70EE50": {
        "oui_hex": "70-EE-50",
        "organization": "Netatmo",
        "address_1": "17 route de la reine",
        "address_2": "Boulogne-Billancourt    92100",
        "country": "FR"
    },
    "984A47": {
        "oui_hex": "98-4A-47",
        "organization": "CHG Hospital Beds",
        "address_1": "1020 Adelaide St S",
        "address_2": "London  ON  N6E 1R6",
        "country": "CA"
    },
    "144978": {
        "oui_hex": "14-49-78",
        "organization": "Digital Control Incorporated",
        "address_1": "19625 62nd Ave S",
        "address_2": "Kent  WA  98032",
        "country": "US"
    },
    "2C10C1": {
        "oui_hex": "2C-10-C1",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "8CD17B": {
        "oui_hex": "8C-D1-7B",
        "organization": "CG Mobile",
        "address_1": "3F Caohejing Software Building, No.461 Hongcao Rd.,XuHui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "502267": {
        "oui_hex": "50-22-67",
        "organization": "PixeLINK",
        "address_1": "3030 Conroy Road",
        "address_2": "Ottawa  Ontario  K1G 6C2",
        "country": "CA"
    },
    "3C6A7D": {
        "oui_hex": "3C-6A-7D",
        "organization": "Niigata Power Systems Co., Ltd.",
        "address_1": "7-26,Tatsumi 3-Chome",
        "address_2": "Koto-ku  TOKYO  135-0053",
        "country": "JP"
    },
    "3C7059": {
        "oui_hex": "3C-70-59",
        "organization": "MakerBot Industries",
        "address_1": "87 3rd Avenue",
        "address_2": "Brooklyn  NY  11217",
        "country": "US"
    },
    "502690": {
        "oui_hex": "50-26-90",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "24B657": {
        "oui_hex": "24-B6-57",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C8AF40": {
        "oui_hex": "C8-AF-40",
        "organization": "marco Systemanalyse und Entwicklung GmbH",
        "address_1": "Hans-Böckler-Straße 2",
        "address_2": "Dachau  Bavaria  85221",
        "country": "DE"
    },
    "40984C": {
        "oui_hex": "40-98-4C",
        "organization": "Casacom Solutions AG",
        "address_1": "Badenerstarsse 551",
        "address_2": "Zuerich    8046",
        "country": "CH"
    },
    "5C18B5": {
        "oui_hex": "5C-18-B5",
        "organization": "Talon Communications",
        "address_1": "10636 Scripps Summit Ct.",
        "address_2": "San Diego  CA  92131",
        "country": "US"
    },
    "64E161": {
        "oui_hex": "64-E1-61",
        "organization": "DEP Corp.",
        "address_1": "Nishi-shinjuku 6-12-7",
        "address_2": "Shinjuku  Tokyo  160-0023",
        "country": "JP"
    },
    "8823FE": {
        "oui_hex": "88-23-FE",
        "organization": "TTTech Computertechnik AG",
        "address_1": "Schoenbrunnerstrasse 7",
        "address_2": "Vienna    1040",
        "country": "AT"
    },
    "B89AED": {
        "oui_hex": "B8-9A-ED",
        "organization": "OceanServer Technology, Inc",
        "address_1": "151 Martine St",
        "address_2": "Fall River  MA  02723",
        "country": "US"
    },
    "C87D77": {
        "oui_hex": "C8-7D-77",
        "organization": "Shenzhen Kingtech Communication Equipment Co.,Ltd",
        "address_1": "Floor3.Building A,NO.3,Road 1 of shangxue Dengxinkeng Industry Park,Bantian Street,",
        "address_2": "Shenzhen City  Guangdong  518112",
        "country": "CN"
    },
    "94AE61": {
        "oui_hex": "94-AE-61",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "5CCEAD": {
        "oui_hex": "5C-CE-AD",
        "organization": "CDYNE Corporation",
        "address_1": "505 Independence Pkwy Ste 300",
        "address_2": "Chesapeake  VA  23320",
        "country": "US"
    },
    "AC54EC": {
        "oui_hex": "AC-54-EC",
        "organization": "IEEE P1823 Standards Working Group",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "709756": {
        "oui_hex": "70-97-56",
        "organization": "Happyelectronics Co.,Ltd",
        "address_1": "#A-805, Bundang Technopark,",
        "address_2": "Seongnam-Si    463-816",
        "country": "KR"
    },
    "B820E7": {
        "oui_hex": "B8-20-E7",
        "organization": "Guangzhou Horizontal Information & Network Integration Co. Ltd",
        "address_1": "Floor 10¬Golden Star Building¬Wushan Hanjing Road¬Tianhe District¬Guangzhou City",
        "address_2": "Guangzhou  Guangdong Province  510630",
        "country": "CN"
    },
    "00CD90": {
        "oui_hex": "00-CD-90",
        "organization": "MAS Elektronik AG",
        "address_1": "Pollhornbogen 19",
        "address_2": "Hamburg    21107",
        "country": "DE"
    },
    "7C6B52": {
        "oui_hex": "7C-6B-52",
        "organization": "Tigaro Wireless",
        "address_1": "Shen A'ari 7",
        "address_2": "Even Yehuda    40500",
        "country": "IL"
    },
    "0064A6": {
        "oui_hex": "00-64-A6",
        "organization": "Maquet CardioVascular",
        "address_1": "1300 MacArthur Blvd",
        "address_2": "Mahwah  NJ  07430",
        "country": "US"
    },
    "988BAD": {
        "oui_hex": "98-8B-AD",
        "organization": "Corintech Ltd.",
        "address_1": "Ashford Mill",
        "address_2": "Fordingbridge  Hampshire  SP6 1DZ",
        "country": "GB"
    },
    "D44B5E": {
        "oui_hex": "D4-4B-5E",
        "organization": "TAIYO YUDEN CO., LTD.",
        "address_1": "8-1, Sakae-cho",
        "address_2": "Takasaki-shi  Gunma  370-8522",
        "country": "JP"
    },
    "640E36": {
        "oui_hex": "64-0E-36",
        "organization": "TAZTAG",
        "address_1": "Cicea 1",
        "address_2": "Bruz    35170",
        "country": "FR"
    },
    "941D1C": {
        "oui_hex": "94-1D-1C",
        "organization": "TLab West Systems AB",
        "address_1": "Ebbe Lieberathsgatan 23B",
        "address_2": "Gothenburg    41265",
        "country": "SE"
    },
    "E455EA": {
        "oui_hex": "E4-55-EA",
        "organization": "Dedicated Computing",
        "address_1": "N26 W23880 Commerce Circle",
        "address_2": "Waukesha  Wisconsin  53188",
        "country": "US"
    },
    "B05CE5": {
        "oui_hex": "B0-5C-E5",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "3482DE": {
        "oui_hex": "34-82-DE",
        "organization": "Kiio Inc",
        "address_1": "404 Holtzman Rd",
        "address_2": "Madison  WI  53713",
        "country": "US"
    },
    "4C5FD2": {
        "oui_hex": "4C-5F-D2",
        "organization": "Alcatel-Lucent",
        "address_1": "777 East Middlefield Road",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "28C718": {
        "oui_hex": "28-C7-18",
        "organization": "Altierre",
        "address_1": "1980 Concourse Drive",
        "address_2": "San Jose  United States  95131",
        "country": "US"
    },
    "7C4C58": {
        "oui_hex": "7C-4C-58",
        "organization": "Scale Computing, Inc.",
        "address_1": "2121 El Camino Real",
        "address_2": "San Mateo  UNITED STATES  94403",
        "country": "US"
    },
    "1013EE": {
        "oui_hex": "10-13-EE",
        "organization": "Justec International Technology INC.",
        "address_1": "7F-2 No 113 Zihyou Road",
        "address_2": "Hsinchu City    30041",
        "country": "TW"
    },
    "8C271D": {
        "oui_hex": "8C-27-1D",
        "organization": "QuantHouse",
        "address_1": "52 Rue de la Victoire",
        "address_2": "Paris    75009",
        "country": "FR"
    },
    "386077": {
        "oui_hex": "38-60-77",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "708105": {
        "oui_hex": "70-81-05",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0ED1A": {
        "oui_hex": "E0-ED-1A",
        "organization": "vastriver Technology Co., Ltd",
        "address_1": "A-6A Keshi Building,No.28,Xinxi Road,Haidian,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "D4F63F": {
        "oui_hex": "D4-F6-3F",
        "organization": "IEA S.R.L.",
        "address_1": "Eva Peron 4468",
        "address_2": "Rosario  Santa Fe  S2002LBQ",
        "country": "AR"
    },
    "58B0D4": {
        "oui_hex": "58-B0-D4",
        "organization": "ZuniData Systems Inc.",
        "address_1": "4F-7,  No.65,  Gaotia 7th Rd,  Zhubei City",
        "address_2": "Hsinchu    302",
        "country": "TW"
    },
    "64557F": {
        "oui_hex": "64-55-7F",
        "organization": "NSFOCUS Information Technology Co., Ltd.",
        "address_1": "3/F,Ether Building, No.4 Beiwa Rd.,Haidian District",
        "address_2": "Beijing    100089",
        "country": "CN"
    },
    "00082F": {
        "oui_hex": "00-08-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9CC7D1": {
        "oui_hex": "9C-C7-D1",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "149090": {
        "oui_hex": "14-90-90",
        "organization": "KongTop industrial(shen zhen)CO.,LTD",
        "address_1": "xinwuyuan,gushu,Xixiang,Baoan,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "38DE60": {
        "oui_hex": "38-DE-60",
        "organization": "Mohlenhoff GmbH",
        "address_1": "Museumstraße 54a",
        "address_2": "Salzgitter  Niedersachsen  38229",
        "country": "DE"
    },
    "2839E7": {
        "oui_hex": "28-39-E7",
        "organization": "Preceno Technology Pte.Ltd.",
        "address_1": "11F, No.207-2, Sec. 3, Beixin Rd., Xindian Dist.",
        "address_2": "New Taipei City    23143",
        "country": "TW"
    },
    "685E6B": {
        "oui_hex": "68-5E-6B",
        "organization": "PowerRay Co., Ltd.",
        "address_1": "7F-1, No 190, Sec 2, Chung Hsing Road, Sindian District",
        "address_2": "New Taipei City    231",
        "country": "TW"
    },
    "20C8B3": {
        "oui_hex": "20-C8-B3",
        "organization": "SHENZHEN BUL-TECH CO.,LTD.",
        "address_1": "Area C,4/F,NO.59,Longjing 2nd Road,",
        "address_2": "SHENZHEN   GuangDong  518101",
        "country": "CN"
    },
    "F8E7B5": {
        "oui_hex": "F8-E7-B5",
        "organization": "µTech Tecnologia LTDA",
        "address_1": "Rua Lauro Linhares, 598",
        "address_2": "Florianopolis  Santa Catarina  88036-200",
        "country": "BR"
    },
    "D4CEB8": {
        "oui_hex": "D4-CE-B8",
        "organization": "Enatel LTD",
        "address_1": "66 Treffers Road",
        "address_2": "Christchurch  Canterbury  8042",
        "country": "NZ"
    },
    "807A7F": {
        "oui_hex": "80-7A-7F",
        "organization": "ABB Genway Xiamen Electrical Equipment CO., LTD",
        "address_1": "7F,No.23 Wanghai Road,Software Park 2, Lvling Road,",
        "address_2": "Xiamen  Fujian Province  361008",
        "country": "CN"
    },
    "24DAB6": {
        "oui_hex": "24-DA-B6",
        "organization": "Sistemas de Gestión Energética S.A. de C.V",
        "address_1": "Calzada de los Fresnos 70-A",
        "address_2": "Zapopan  Jalisoc  45010",
        "country": "MX"
    },
    "B07D62": {
        "oui_hex": "B0-7D-62",
        "organization": "Dipl.-Ing. H. Horstmann GmbH",
        "address_1": "Humboldtstraße 2",
        "address_2": "Heiligenhaus    42579",
        "country": "DE"
    },
    "B8F5E7": {
        "oui_hex": "B8-F5-E7",
        "organization": "WayTools, LLC",
        "address_1": "401 Wilshire Blvd.",
        "address_2": "Santa Monica  CA  90401",
        "country": "US"
    },
    "B81999": {
        "oui_hex": "B8-19-99",
        "organization": "Nesys",
        "address_1": "Energeticheskaya, 1",
        "address_2": "Moscow    111116",
        "country": "RU"
    },
    "34255D": {
        "oui_hex": "34-25-5D",
        "organization": "Shenzhen Loadcom Technology Co.,Ltd",
        "address_1": "Yuehai Building A-13CD,Nanhai Road,Nanshan Area",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "4CA74B": {
        "oui_hex": "4C-A7-4B",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "D03110": {
        "oui_hex": "D0-31-10",
        "organization": "Ingenic Semiconductor Co.,Ltd",
        "address_1": "Room 108,Building A,Information Center Zhongguancun Software Park 8 Dongbeiwang West Road,Haidain District",
        "address_2": "Beijing    100193",
        "country": "CN"
    },
    "1CE192": {
        "oui_hex": "1C-E1-92",
        "organization": "Qisda Corporation",
        "address_1": "157 Shan-Ying Road",
        "address_2": "Gueishan  Taoyuan  333",
        "country": "TW"
    },
    "706F81": {
        "oui_hex": "70-6F-81",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "FC0012": {
        "oui_hex": "FC-00-12",
        "organization": "Toshiba Samsung Storage Technolgoy Korea Corporation",
        "address_1": "14 Floor, Bldg. No. 102, Digital Empire2, 486, Sin-dong, Yeongtong-gu, Suwon-si,",
        "address_2": "Su-won   Gyeonggi   443-734",
        "country": "KR"
    },
    "181420": {
        "oui_hex": "18-14-20",
        "organization": "TEB SAS",
        "address_1": "RD294 - Corpeau",
        "address_2": "Meursault  Burgundy  21190",
        "country": "FR"
    },
    "AC81F3": {
        "oui_hex": "AC-81-F3",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "30688C": {
        "oui_hex": "30-68-8C",
        "organization": "Reach Technology Inc.",
        "address_1": "4575 Cushing Parkway",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "10EED9": {
        "oui_hex": "10-EE-D9",
        "organization": "Canoga Perkins Corporation",
        "address_1": "20600 Prairie Street",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "94DE0E": {
        "oui_hex": "94-DE-0E",
        "organization": "SmartOptics AS",
        "address_1": "Stalfjaera 9",
        "address_2": "Oslo    N-0975",
        "country": "NO"
    },
    "C029F3": {
        "oui_hex": "C0-29-F3",
        "organization": "XySystem",
        "address_1": "#1304 Daerung Post Tower 5",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "AC4AFE": {
        "oui_hex": "AC-4A-FE",
        "organization": "Hisense Broadband Multimedia Technology Co.,Ltd.",
        "address_1": "No.11 Jiangxi Road,Shinan District",
        "address_2": "Qingdao City  Shandong Province  266071",
        "country": "CN"
    },
    "54F5B6": {
        "oui_hex": "54-F5-B6",
        "organization": "ORIENTAL PACIFIC INTERNATIONAL LIMITED",
        "address_1": "5 ARGUS PLACE",
        "address_2": "NORTH SHORE CITY  AUCKLAND  0627",
        "country": "NZ"
    },
    "90342B": {
        "oui_hex": "90-34-2B",
        "organization": "Gatekeeper Systems, Inc.",
        "address_1": "8 Studebaker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "8CB82C": {
        "oui_hex": "8C-B8-2C",
        "organization": "IPitomy Communications",
        "address_1": "1940 Northgate Boulevard",
        "address_2": "Sarasota  Florida  34234",
        "country": "US"
    },
    "807DE3": {
        "oui_hex": "80-7D-E3",
        "organization": "Chongqing Sichuan Instrument Microcircuit Co.LTD.",
        "address_1": "Jinhua Road No.309, Beibei,",
        "address_2": "Chongqing    400700",
        "country": "CN"
    },
    "DC175A": {
        "oui_hex": "DC-17-5A",
        "organization": "Hitachi High-Technologies Corporation",
        "address_1": "794, Higashitoyoi,",
        "address_2": "Kudamatsu City,  Yamaguchi Pref.,  744-0002,",
        "country": "JP"
    },
    "C8A1BA": {
        "oui_hex": "C8-A1-BA",
        "organization": "Neul Ltd",
        "address_1": "Suite 42 Innovation Centre",
        "address_2": "Cambridge  Cambs  CB4 0EY",
        "country": "GB"
    },
    "C43A9F": {
        "oui_hex": "C4-3A-9F",
        "organization": "Siconix Inc.",
        "address_1": "#28, 2333 18th Ave NE",
        "address_2": "Calgary  Alberta  T2E 8T6",
        "country": "CA"
    },
    "686E23": {
        "oui_hex": "68-6E-23",
        "organization": "Wi3 Inc.",
        "address_1": "P.O. Box 1123",
        "address_2": "Pittsford  NY  14534",
        "country": "US"
    },
    "DCF05D": {
        "oui_hex": "DC-F0-5D",
        "organization": "Letta Teknoloji",
        "address_1": "TUBITAK Teknoloji Gelistirme Bolgesi",
        "address_2": "KOCAELI    41455",
        "country": "TR"
    },
    "5C16C7": {
        "oui_hex": "5C-16-C7",
        "organization": "Big Switch Networks",
        "address_1": "100 W Evelyn",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "848F69": {
        "oui_hex": "84-8F-69",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "3C096D": {
        "oui_hex": "3C-09-6D",
        "organization": "Powerhouse Dynamics",
        "address_1": "1 Bridge Street",
        "address_2": "Newton  MA  02458",
        "country": "US"
    },
    "900D66": {
        "oui_hex": "90-0D-66",
        "organization": "Digimore Electronics Co., Ltd",
        "address_1": "10 FL., No. 61, Yan-Ping South Road",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "0C924E": {
        "oui_hex": "0C-92-4E",
        "organization": "Rice Lake Weighing Systems",
        "address_1": "230 West Coleman St",
        "address_2": "Rice Lake  WI  54868",
        "country": "US"
    },
    "F49461": {
        "oui_hex": "F4-94-61",
        "organization": "NexGen Storage",
        "address_1": "400 Centennial Blvd.",
        "address_2": "Louisville  CO  80027",
        "country": "US"
    },
    "B8CDA7": {
        "oui_hex": "B8-CD-A7",
        "organization": "Maxeler Technologies Ltd.",
        "address_1": "1 Down Place",
        "address_2": "London  UK  W6 9JH",
        "country": "GB"
    },
    "5435DF": {
        "oui_hex": "54-35-DF",
        "organization": "Symeo GmbH",
        "address_1": "Prof.-Messerschmitt-Str. 3",
        "address_2": "Neubiberg  Bavaria  85579",
        "country": "DE"
    },
    "F43D80": {
        "oui_hex": "F4-3D-80",
        "organization": "FAG Industrial Services GmbH",
        "address_1": "Kaiserstrasse 100",
        "address_2": "Herzogenrath  NRW  52134",
        "country": "DE"
    },
    "F0DB30": {
        "oui_hex": "F0-DB-30",
        "organization": "Yottabyte",
        "address_1": "1750 S. Telegraph Road",
        "address_2": "Bloomfield Twp.  MI  48302",
        "country": "US"
    },
    "9C31B6": {
        "oui_hex": "9C-31-B6",
        "organization": "Kulite Semiconductor Products Inc",
        "address_1": "1 Willow Tree Rd",
        "address_2": "Leonia  NJ  07605",
        "country": "US"
    },
    "A4B36A": {
        "oui_hex": "A4-B3-6A",
        "organization": "JSC SDO Chromatec",
        "address_1": "94, Stroiteley street",
        "address_2": "Yoshkar-Ola  Mari El republic  424000",
        "country": "RU"
    },
    "E4DD79": {
        "oui_hex": "E4-DD-79",
        "organization": "En-Vision America, Inc.",
        "address_1": "1845 Hovey Ave",
        "address_2": "Normal  IL  61761",
        "country": "US"
    },
    "E8CC32": {
        "oui_hex": "E8-CC-32",
        "organization": "Micronet  LTD",
        "address_1": "Hametzuda 27",
        "address_2": "Azor    58001",
        "country": "IL"
    },
    "D43AE9": {
        "oui_hex": "D4-3A-E9",
        "organization": "DONGGUAN ipt INDUSTRIAL CO., LTD",
        "address_1": "No.66-1.Ist New Area, Nanshe Dist., Chigang,Humen,",
        "address_2": "Dongguan  Guangdong  52390",
        "country": "CN"
    },
    "589835": {
        "oui_hex": "58-98-35",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "8C5CA1": {
        "oui_hex": "8C-5C-A1",
        "organization": "d-broad,INC",
        "address_1": "3-17-5 ShinYokohama Kouhoku-Ku",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "18F650": {
        "oui_hex": "18-F6-50",
        "organization": "Multimedia Pacific Limited",
        "address_1": "1 Matheson Street, Shell Tower 29F/12",
        "address_2": "    000000",
        "country": "HK"
    },
    "688470": {
        "oui_hex": "68-84-70",
        "organization": "eSSys Co.,Ltd",
        "address_1": "Daerung Post Tower 5 15F, 60-3",
        "address_2": "Seoul  Geumcheon-gu  153-702",
        "country": "KR"
    },
    "48DCFB": {
        "oui_hex": "48-DC-FB",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "20B7C0": {
        "oui_hex": "20-B7-C0",
        "organization": "OMICRON electronics GmbH",
        "address_1": "Oberes Ried 1",
        "address_2": "Klaus    6833",
        "country": "AT"
    },
    "8058C5": {
        "oui_hex": "80-58-C5",
        "organization": "NovaTec Kommunikationstechnik GmbH",
        "address_1": "Technologiepark 9",
        "address_2": "Paderborn  NRW  33100",
        "country": "DE"
    },
    "B8C716": {
        "oui_hex": "B8-C7-16",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D42C3D": {
        "oui_hex": "D4-2C-3D",
        "organization": "Sky Light Digital Limited",
        "address_1": "Rm. 1009 Kwong Sang Hong Centre, 151-153 Hoi Bun Road, Kwun Tong, Kowloon,",
        "address_2": "Hong Kong    999077",
        "country": "CN"
    },
    "A45A1C": {
        "oui_hex": "A4-5A-1C",
        "organization": "smart-electronic GmbH",
        "address_1": "Industriestrasse 29",
        "address_2": "St. Georgen  Baden-Württemberg  78122",
        "country": "DE"
    },
    "806459": {
        "oui_hex": "80-64-59",
        "organization": "Nimbus Inc.",
        "address_1": "1359 Gwanpyeong-dong, Yuseong-gu",
        "address_2": "Daejeon    305-509",
        "country": "KR"
    },
    "8C89A5": {
        "oui_hex": "8C-89-A5",
        "organization": "Micro-Star INT'L CO., LTD",
        "address_1": "No.69, Lide st.",
        "address_2": "Taipei County    235",
        "country": "TW"
    },
    "B4A5A9": {
        "oui_hex": "B4-A5-A9",
        "organization": "MODI GmbH",
        "address_1": "Kapellenweg 21",
        "address_2": "REICHSHOF-Sinspert    51580",
        "country": "DE"
    },
    "E8C320": {
        "oui_hex": "E8-C3-20",
        "organization": "Austco Communication Systems Pty Ltd",
        "address_1": "40 O'Malley Street",
        "address_2": "Osborne Park  Western Australia  6017",
        "country": "AU"
    },
    "C436DA": {
        "oui_hex": "C4-36-DA",
        "organization": "Rusteletech Ltd.",
        "address_1": "Ordzhonikidze Str. 11, Bldg. 40, Off. 15",
        "address_2": "Moscow    115419",
        "country": "RU"
    },
    "0432F4": {
        "oui_hex": "04-32-F4",
        "organization": "Partron",
        "address_1": "22-6, Seokwoo-dong",
        "address_2": "Hwaseong-si  Gyeonggi-do  445-170",
        "country": "KR"
    },
    "1C184A": {
        "oui_hex": "1C-18-4A",
        "organization": "ShenZhen RicherLink Technologies Co.,LTD",
        "address_1": "703,Building W1-A,High-Tech Industrial Park,KeJiNan 1st Road,NanShan,",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "0C3956": {
        "oui_hex": "0C-39-56",
        "organization": "Observator instruments",
        "address_1": "Rietdekkerstraat 6",
        "address_2": "Ridderkerk  Zuid Holland  2984 BM",
        "country": "NL"
    },
    "DCA6BD": {
        "oui_hex": "DC-A6-BD",
        "organization": "Beijing Lanbo Technology Co., Ltd.",
        "address_1": "Room.301.Bidg.4NO.8 Shangdi West Road, Haidian  District,",
        "address_2": "Beijing City    100085",
        "country": "CN"
    },
    "10C586": {
        "oui_hex": "10-C5-86",
        "organization": "BIO SOUND LAB CO., LTD.",
        "address_1": "Suite 311, 312 SKn Techno Park",
        "address_2": "Seongnam-si  Gyeonggi-do,  462-721",
        "country": "KR"
    },
    "10768A": {
        "oui_hex": "10-76-8A",
        "organization": "EoCell",
        "address_1": "149 Beaconsfield Street",
        "address_2": "Silverwater  NSW  2128",
        "country": "AU"
    },
    "F44EFD": {
        "oui_hex": "F4-4E-FD",
        "organization": "Actions Semiconductor Co.,Ltd.(Cayman Islands)",
        "address_1": "Po Box 309GT,Ugland House,South Church Street,",
        "address_2": "George Town  Grand Cayman",
        "country": "KY"
    },
    "24B8D2": {
        "oui_hex": "24-B8-D2",
        "organization": "Opzoon Technology Co.,Ltd.",
        "address_1": "11th floor, Tower BÂ£Â¬Yintai Center 2 Jianguomenwai St,.",
        "address_2": "Beijing  Asia  100022",
        "country": "CN"
    },
    "A49981": {
        "oui_hex": "A4-99-81",
        "organization": "FuJian Elite Power Tech CO.,LTD.",
        "address_1": "8th FloorÂ£Â¬56 GuanRi Road",
        "address_2": "Xiamen  Fujian  361009",
        "country": "CN"
    },
    "B83A7B": {
        "oui_hex": "B8-3A-7B",
        "organization": "Worldplay (Canada) Inc.",
        "address_1": "803 - 24th Ave SE, Unit 200",
        "address_2": "Calgary  Alberta  T2G 1P5",
        "country": "CA"
    },
    "1407E0": {
        "oui_hex": "14-07-E0",
        "organization": "Abrantix AG",
        "address_1": "Foerrlibuckstrasse 66",
        "address_2": "Zuerich  ZH  8005",
        "country": "CH"
    },
    "DCCF94": {
        "oui_hex": "DC-CF-94",
        "organization": "Beijing Rongcheng Hutong Technology Co., Ltd.",
        "address_1": "Room 401A,Building No.4,Yard No.5,",
        "address_2": "  Beijing  100024",
        "country": "CN"
    },
    "A4DB2E": {
        "oui_hex": "A4-DB-2E",
        "organization": "Kingspan Environmental Ltd",
        "address_1": "180 Gilford Road",
        "address_2": "Portadown  Armagh  BT63 5LF",
        "country": "GB"
    },
    "C8FE30": {
        "oui_hex": "C8-FE-30",
        "organization": "Bejing DAYO Mobile Communication Technology Ltd.",
        "address_1": "Room 712, ULO Park Building No. 601E",
        "address_2": "Beijing    100102",
        "country": "CN"
    },
    "E4D71D": {
        "oui_hex": "E4-D7-1D",
        "organization": "Oraya Therapeutics",
        "address_1": "8000 Jarvis Avenue  Ste. 200",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "24C9DE": {
        "oui_hex": "24-C9-DE",
        "organization": "Genoray",
        "address_1": "#812 Byucksan Technopia 434-6 Sangdaewon 1-Dong",
        "address_2": "Seongnam-City  Gyeonggi-Do  462-716",
        "country": "KR"
    },
    "54055F": {
        "oui_hex": "54-05-5F",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "6C5D63": {
        "oui_hex": "6C-5D-63",
        "organization": "ShenZhen Rapoo Technology Co., Ltd.",
        "address_1": "Block A1,B1,B2,1st second stage, 1st Industrial Park, 3rd Industrial Zone ,Fenghuang Fuyong, BaoAn",
        "address_2": "ShenZhen    518103",
        "country": "CN"
    },
    "941673": {
        "oui_hex": "94-16-73",
        "organization": "Point Core SARL",
        "address_1": "29/31 Rue du Bois Galon",
        "address_2": "FONTENAY SOUS BOIS  Ile de France  94120",
        "country": "FR"
    },
    "5C56ED": {
        "oui_hex": "5C-56-ED",
        "organization": "3pleplay Electronics Private Limited",
        "address_1": "Plot No 54, Eshwarapuri Colony",
        "address_2": "Hyderabad  Andhra Pradesh  500083",
        "country": "IN"
    },
    "78028F": {
        "oui_hex": "78-02-8F",
        "organization": "Adaptive Spectrum and Signal Alignment (ASSIA), Inc.",
        "address_1": "333 Twin Dolphin Drive",
        "address_2": "Redwood City  CA  94065",
        "country": "US"
    },
    "DC16A2": {
        "oui_hex": "DC-16-A2",
        "organization": "Medtronic Diabetes",
        "address_1": "18000 Devonshire St",
        "address_2": "Northridge  CA  91325",
        "country": "US"
    },
    "308CFB": {
        "oui_hex": "30-8C-FB",
        "organization": "Dropcam",
        "address_1": "160 Spear Street",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "D0EB9E": {
        "oui_hex": "D0-EB-9E",
        "organization": "Seowoo Inc.",
        "address_1": "#B101 Seojung B/D, 590-9 Guui-dong, Gwangjin-gu,",
        "address_2": "Seoul    143-831",
        "country": "KR"
    },
    "BCCD45": {
        "oui_hex": "BC-CD-45",
        "organization": "VOISMART",
        "address_1": "VIA BENIGNO CRESPI 12",
        "address_2": "MILANO    20159",
        "country": "IT"
    },
    "143E60": {
        "oui_hex": "14-3E-60",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "7032D5": {
        "oui_hex": "70-32-D5",
        "organization": "Athena Wireless Communications Inc",
        "address_1": "12425 W Bell Rd",
        "address_2": "Surprise  AZ  85378",
        "country": "US"
    },
    "78510C": {
        "oui_hex": "78-51-0C",
        "organization": "LiveU Ltd.",
        "address_1": "5 Hagavish St.",
        "address_2": "Kfar-Saba    44641",
        "country": "IL"
    },
    "44AAE8": {
        "oui_hex": "44-AA-E8",
        "organization": "Nanotec Electronic GmbH & Co. KG",
        "address_1": "Gewerbestrasse 11",
        "address_2": "Landsham  Bavaria  85652",
        "country": "DE"
    },
    "D428B2": {
        "oui_hex": "D4-28-B2",
        "organization": "ioBridge, Inc.",
        "address_1": "225 Cedar Hill Street",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "8427CE": {
        "oui_hex": "84-27-CE",
        "organization": "Corporation of the Presiding Bishop of The Church of Jesus Christ of Latter-day Saints",
        "address_1": "Audiovisual Engineering - 2LL",
        "address_2": "Salt Lake City  UT  84150",
        "country": "US"
    },
    "48D8FE": {
        "oui_hex": "48-D8-FE",
        "organization": "ClarIDy Solutions, Inc.",
        "address_1": "7F, No.9, ParkAvenue II Rd., Hsinchu Science Park,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "D4945A": {
        "oui_hex": "D4-94-5A",
        "organization": "COSMO CO., LTD",
        "address_1": "1-12, Higashi-Gotanda 2-chome",
        "address_2": "Shinagawa-ku  Tokyo  141-0022",
        "country": "JP"
    },
    "304C7E": {
        "oui_hex": "30-4C-7E",
        "organization": "Panasonic Electric Works Automation Controls Techno Co.,Ltd.",
        "address_1": "2-9-18 Chidori",
        "address_2": "Oota-ku  Tokyo  146-8540",
        "country": "JP"
    },
    "5CF207": {
        "oui_hex": "5C-F2-07",
        "organization": "Speco Technologies",
        "address_1": "200 New Highway",
        "address_2": "Amityville  New York  11701",
        "country": "US"
    },
    "B42A39": {
        "oui_hex": "B4-2A-39",
        "organization": "ORBIT MERRET, spol. s r. o.",
        "address_1": "Vodnanska 675/30",
        "address_2": "Praha    198 00",
        "country": "CZ"
    },
    "70E843": {
        "oui_hex": "70-E8-43",
        "organization": "Beijing C&W Optical Communication Technology Co.,Ltd.",
        "address_1": "2/F Yufa Plaza, No.19 Xiaoying Beilu, Chaoyang District,",
        "address_2": "Beijing    100101",
        "country": "CN"
    },
    "2C7ECF": {
        "oui_hex": "2C-7E-CF",
        "organization": "Onzo Ltd",
        "address_1": "6 Great Newport Street",
        "address_2": "London    WC2H 7JB",
        "country": "GB"
    },
    "103711": {
        "oui_hex": "10-37-11",
        "organization": "Simlink AS",
        "address_1": "Otto Nielsens Veg 12",
        "address_2": "Trondheim    N-7004",
        "country": "NO"
    },
    "50E549": {
        "oui_hex": "50-E5-49",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "B4B88D": {
        "oui_hex": "B4-B8-8D",
        "organization": "Thuh Company",
        "address_1": "605  Territorial Dr",
        "address_2": "Bolingbrook  IL  60440",
        "country": "US"
    },
    "4C73A5": {
        "oui_hex": "4C-73-A5",
        "organization": "KOVE",
        "address_1": "14 N. Peoria Street",
        "address_2": "Chicago  IL  60607",
        "country": "US"
    },
    "70A41C": {
        "oui_hex": "70-A4-1C",
        "organization": "Advanced Wireless Dynamics S.L.",
        "address_1": "Centro de Empresas UPM oficina 3",
        "address_2": "Pozuelo de Alarcon  Madrid  28223",
        "country": "ES"
    },
    "BCBBC9": {
        "oui_hex": "BC-BB-C9",
        "organization": "Kellendonk Elektronik GmbH",
        "address_1": "Butzweilerhof Allee 4",
        "address_2": "Cologne  NRW  50829",
        "country": "DE"
    },
    "E42AD3": {
        "oui_hex": "E4-2A-D3",
        "organization": "Magneti Marelli S.p.A. Powertrain",
        "address_1": "Via del Timavo 33",
        "address_2": "Bologna    40128",
        "country": "IT"
    },
    "E83EB6": {
        "oui_hex": "E8-3E-B6",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "BC35E5": {
        "oui_hex": "BC-35-E5",
        "organization": "Hydro Systems Company",
        "address_1": "3798 Round Bottom Road",
        "address_2": "Cincinnati  Ohio  45244",
        "country": "US"
    },
    "9C5D95": {
        "oui_hex": "9C-5D-95",
        "organization": "VTC Electronics Corp.",
        "address_1": "5F,No.21,Sec.6,Zhongxiao E.Rd.,Nangang District",
        "address_2": "Taipei    11575",
        "country": "TW"
    },
    "B8A8AF": {
        "oui_hex": "B8-A8-AF",
        "organization": "Logic S.p.A.",
        "address_1": "Via Galilei 5",
        "address_2": "Cassina de' Pecchi  MI  20060",
        "country": "IT"
    },
    "60F673": {
        "oui_hex": "60-F6-73",
        "organization": "TERUMO CORPORATION",
        "address_1": "1500,Inokuchi,Nakai-machi",
        "address_2": "Ashigarakami-gun  Kanagawa  259-0151",
        "country": "JP"
    },
    "28CCFF": {
        "oui_hex": "28-CC-FF",
        "organization": "Corporacion Empresarial Altra SL",
        "address_1": "Marie Curie 21",
        "address_2": "Malaga    29590",
        "country": "ES"
    },
    "94FD1D": {
        "oui_hex": "94-FD-1D",
        "organization": "WhereWhen Corp",
        "address_1": "96A Flynn Avenue",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "4C07C9": {
        "oui_hex": "4C-07-C9",
        "organization": "COMPUTER OFFICE Co.,Ltd.",
        "address_1": "1368-10 Muramatsu-cho",
        "address_2": "Ise-shi  Mie-ken  515-0507",
        "country": "JP"
    },
    "F8769B": {
        "oui_hex": "F8-76-9B",
        "organization": "Neopis Co., Ltd.",
        "address_1": "#401 Neo bd., 196-44 Anyang7-Dong",
        "address_2": "Anyang  Kyonggi-Do  430-857",
        "country": "KR"
    },
    "74B00C": {
        "oui_hex": "74-B0-0C",
        "organization": "Network Video Technologies, Inc",
        "address_1": "4005 Bohannon Drive",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "E84040": {
        "oui_hex": "E8-40-40",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D89DB9": {
        "oui_hex": "D8-9D-B9",
        "organization": "eMegatech International Corp.",
        "address_1": "Room 403, No.24 Wucyuan 2nd Rd.,",
        "address_2": "Sinjhuang City, Taipei County,    238",
        "country": "TW"
    },
    "405A9B": {
        "oui_hex": "40-5A-9B",
        "organization": "ANOVO",
        "address_1": "ZI de Bracheux",
        "address_2": "BEAUVAIS    60000",
        "country": "FR"
    },
    "E06995": {
        "oui_hex": "E0-69-95",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "84DE3D": {
        "oui_hex": "84-DE-3D",
        "organization": "Crystal Vision Ltd",
        "address_1": "Lion Technology park",
        "address_2": "Whittlesford/ Cambridge  Cambs  CB22 4WL",
        "country": "GB"
    },
    "D075BE": {
        "oui_hex": "D0-75-BE",
        "organization": "Reno A&E",
        "address_1": "4655 Aircenter Circle",
        "address_2": "Reno  Nevada  89502",
        "country": "US"
    },
    "BC6E76": {
        "oui_hex": "BC-6E-76",
        "organization": "Green Energy Options Ltd",
        "address_1": "3 St. Mary's Court, Main Street",
        "address_2": "Cambridge  Cambridgeshire  CB23 7QS",
        "country": "GB"
    },
    "E828D5": {
        "oui_hex": "E8-28-D5",
        "organization": "Cots Technology",
        "address_1": "C-702, Bundang Techno Park, 145,",
        "address_2": "Sungnam-City  Kyounggi-do  463-760",
        "country": "KR"
    },
    "F8DAF4": {
        "oui_hex": "F8-DA-F4",
        "organization": "Taishan Online Technology Co., Ltd.",
        "address_1": "4/F Fangda Building, South Area, Hi-tech Industial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "08D5C0": {
        "oui_hex": "08-D5-C0",
        "organization": "Seers Technology Co., Ltd",
        "address_1": "1210 Techcenter, SKnTechnopark, 190-1",
        "address_2": "Seongnam-si  Gyeonggi-do  462-721",
        "country": "KR"
    },
    "6C33A9": {
        "oui_hex": "6C-33-A9",
        "organization": "Magicjack LP",
        "address_1": "5700 Georgia Avenue",
        "address_2": "West Palm Beach  FL  33405",
        "country": "US"
    },
    "108CCF": {
        "oui_hex": "10-8C-CF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D8E3AE": {
        "oui_hex": "D8-E3-AE",
        "organization": "CIRTEC MEDICAL SYSTEMS",
        "address_1": "101B Cooper Court",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "08B7EC": {
        "oui_hex": "08-B7-EC",
        "organization": "Wireless Seismic",
        "address_1": "13100 SW Freeway",
        "address_2": "Sugar Land  TX  77478",
        "country": "US"
    },
    "18AF9F": {
        "oui_hex": "18-AF-9F",
        "organization": "DIGITRONIC Automationsanlagen GmbH",
        "address_1": "Auf der Langwies 1",
        "address_2": "Wallbach  Hessen  65510",
        "country": "DE"
    },
    "00B342": {
        "oui_hex": "00-B3-42",
        "organization": "MacroSAN Technologies Co., Ltd.",
        "address_1": "Room 102, No.2 Building",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "1CF5E7": {
        "oui_hex": "1C-F5-E7",
        "organization": "Turtle Industry Co., Ltd.",
        "address_1": "1-12-4 Nishineminami",
        "address_2": "Tsutiura  Ibaraki  300-0842",
        "country": "JP"
    },
    "980EE4": {
        "oui_hex": "98-0E-E4",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "447DA5": {
        "oui_hex": "44-7D-A5",
        "organization": "VTION INFORMATION TECHNOLOGY (FUJIAN) CO.,LTD",
        "address_1": "Room 502, Wing A, World Trade Center",
        "address_2": " Beijing,",
        "country": "CN"
    },
    "0CCDD3": {
        "oui_hex": "0C-CD-D3",
        "organization": "EASTRIVER TECHNOLOGY CO., LTD.",
        "address_1": "30 JINNIU XINCUN",
        "address_2": "DONGGUAN  GUANGDONG  523010",
        "country": "CN"
    },
    "E46C21": {
        "oui_hex": "E4-6C-21",
        "organization": "messMa GmbH",
        "address_1": "Am Stadtfeld 8",
        "address_2": "Ixleben  Sachsen-Anhalt  39167",
        "country": "DE"
    },
    "00B033": {
        "oui_hex": "00-B0-33",
        "organization": "OAO Izhevskiy radiozavod",
        "address_1": "19 Bazisnaya street",
        "address_2": "Izhevsk  Udmurt Republic  426034",
        "country": "RU"
    },
    "081735": {
        "oui_hex": "08-17-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C89C1D": {
        "oui_hex": "C8-9C-1D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E437D7": {
        "oui_hex": "E4-37-D7",
        "organization": "HENRI DEPAEPE S.A.S.",
        "address_1": "75/77 RUE DU PRE BROCHET",
        "address_2": "SANNOIS    95112",
        "country": "FR"
    },
    "E0A1D7": {
        "oui_hex": "E0-A1-D7",
        "organization": "SFR",
        "address_1": "40/42 Quai du point du jour",
        "address_2": "Boulogne Billancourt  Hauts de Seine  92659",
        "country": "FR"
    },
    "9481A4": {
        "oui_hex": "94-81-A4",
        "organization": "Azuray Technologies",
        "address_1": "7470 SW Bridgeport Rd",
        "address_2": "Durham  OR  97224",
        "country": "US"
    },
    "BCE09D": {
        "oui_hex": "BC-E0-9D",
        "organization": "Eoslink",
        "address_1": "#602, 900-1",
        "address_2": "Anyang-City  Kyonggi-Do  431-060",
        "country": "KR"
    },
    "9C220E": {
        "oui_hex": "9C-22-0E",
        "organization": "TASCAN Systems GmbH",
        "address_1": "Max-Planck-Str. 38",
        "address_2": "Cologne  Köln  50858",
        "country": "DE"
    },
    "7CDD90": {
        "oui_hex": "7C-DD-90",
        "organization": "Shenzhen Ogemray Technology Co., Ltd.",
        "address_1": "3 Floor, 9 Building, Minxing Industrial Zone,",
        "address_2": "Shenzhen  Guangdong  518131",
        "country": "CN"
    },
    "0C3C65": {
        "oui_hex": "0C-3C-65",
        "organization": "Dome Imaging Inc",
        "address_1": "400 Fifth Av",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "C8DF7C": {
        "oui_hex": "C8-DF-7C",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "B44CC2": {
        "oui_hex": "B4-4C-C2",
        "organization": "NR ELECTRIC CO., LTD",
        "address_1": "69,Suyuan Avenue",
        "address_2": "Nanjing  Jiangsu  211102",
        "country": "CN"
    },
    "48CB6E": {
        "oui_hex": "48-CB-6E",
        "organization": "Cello Electronics (UK) Ltd",
        "address_1": "Cliff Lodge",
        "address_2": "Leyburn  North Yorkshire  DL8 5NS",
        "country": "GB"
    },
    "BC4377": {
        "oui_hex": "BC-43-77",
        "organization": "Hang Zhou Huite Technology Co.,ltd.",
        "address_1": "Rm1338,Block A¬FuLi Technology Building ,No.328,WenEr Rd",
        "address_2": "Hang Zhou  Zhe Jiang  310012",
        "country": "CN"
    },
    "CC7669": {
        "oui_hex": "CC-76-69",
        "organization": "SEETECH",
        "address_1": "19-15, Seoku-dong",
        "address_2": "Hwasung-si  Gyeonggi-do  445-170",
        "country": "KR"
    },
    "AC20AA": {
        "oui_hex": "AC-20-AA",
        "organization": "DMATEK Co., Ltd.",
        "address_1": "11F.-2, No.386, Shizheng Rd., Xitun Dist.,",
        "address_2": "Taichung    40757",
        "country": "TW"
    },
    "FCAF6A": {
        "oui_hex": "FC-AF-6A",
        "organization": "Qulsar Inc",
        "address_1": "Torshamnsgatan 35",
        "address_2": "Kista    SE-16440",
        "country": "SE"
    },
    "346F92": {
        "oui_hex": "34-6F-92",
        "organization": "White Rodgers Division",
        "address_1": "8100 West Florissant",
        "address_2": "St. Louis  MO  63136",
        "country": "US"
    },
    "34BDF9": {
        "oui_hex": "34-BD-F9",
        "organization": "Shanghai WDK Industrial Co.,Ltd.",
        "address_1": "No.2100,Songzhen Road,Songjiang District",
        "address_2": "Shanghai    201606",
        "country": "CN"
    },
    "CCBE71": {
        "oui_hex": "CC-BE-71",
        "organization": "OptiLogix BV",
        "address_1": "Joop Geesinkweg 999",
        "address_2": "Amsterdam  NH  1096AZ",
        "country": "NL"
    },
    "0C469D": {
        "oui_hex": "0C-46-9D",
        "organization": "MS Sedco",
        "address_1": "8701 Castle Park Drive",
        "address_2": "Indianapolis    46256",
        "country": "US"
    },
    "B09AE2": {
        "oui_hex": "B0-9A-E2",
        "organization": "STEMMER IMAGING GmbH",
        "address_1": "Gutenbergstraße 11",
        "address_2": "Puchheim  By  82178",
        "country": "DE"
    },
    "14EE9D": {
        "oui_hex": "14-EE-9D",
        "organization": "AirNav Systems LLC",
        "address_1": "4660 La Jolla Village Dr. - Suite 500",
        "address_2": "San Diego  California  CA 92122",
        "country": "US"
    },
    "78D004": {
        "oui_hex": "78-D0-04",
        "organization": "Neousys Technology Inc.",
        "address_1": "13F.-1, NO.1, BAOSHENG RD.,",
        "address_2": "YONGHE CITY  TAIPEI COUNTY   23444",
        "country": "TW"
    },
    "8895B9": {
        "oui_hex": "88-95-B9",
        "organization": "Unified Packet Systems Crop",
        "address_1": "1F., No32,Lane 15,SEC 6, MinQuan E Rd.,",
        "address_2": "Taipei  Neihu  114",
        "country": "TW"
    },
    "D8FE8F": {
        "oui_hex": "D8-FE-8F",
        "organization": "IDFone Co., Ltd.",
        "address_1": "7F Ace techno tower 5th B/D, 197-22",
        "address_2": "Guro-dong, Guro-gu  Seoul  152-766",
        "country": "KR"
    },
    "888C19": {
        "oui_hex": "88-8C-19",
        "organization": "Brady Corp Asia Pacific Ltd",
        "address_1": "1, Kaki Bukit Crescent",
        "address_2": "    416236",
        "country": "SG"
    },
    "448C52": {
        "oui_hex": "44-8C-52",
        "organization": "KTIS CO., Ltd",
        "address_1": "1208ho-103dong",
        "address_2": "Ojung-Gu, Bucheon-si  Gyeonggi-do  421-808",
        "country": "KR"
    },
    "006DFB": {
        "oui_hex": "00-6D-FB",
        "organization": "Vutrix Technologies Ltd",
        "address_1": "Unit 1 Red Lodge Business Park",
        "address_2": "Weston-super-mare  North Somerset  BS24 7TN",
        "country": "GB"
    },
    "841888": {
        "oui_hex": "84-18-88",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "9067B5": {
        "oui_hex": "90-67-B5",
        "organization": "Alcatel-Lucent",
        "address_1": "600-700 Mountain Ave.",
        "address_2": "Murray Hiill  NJ  07974-0636",
        "country": "US"
    },
    "E0F379": {
        "oui_hex": "E0-F3-79",
        "organization": "Vaddio",
        "address_1": "9433 Science Center Drive",
        "address_2": "New Hope  MN  55428",
        "country": "US"
    },
    "78B6C1": {
        "oui_hex": "78-B6-C1",
        "organization": "AOBO Telecom Co.,Ltd",
        "address_1": "Room1508,Jiangong Building",
        "address_2": "Hangzhou  ZheJiang   310012",
        "country": "CN"
    },
    "08D29A": {
        "oui_hex": "08-D2-9A",
        "organization": "Proformatique",
        "address_1": "10 bis rue Lucien Voilin",
        "address_2": "Puteaux    92800",
        "country": "FR"
    },
    "C89383": {
        "oui_hex": "C8-93-83",
        "organization": "Embedded Automation, Inc.",
        "address_1": "17345 Abbey Drive",
        "address_2": "Surrey  BC  V4N 4M3",
        "country": "CA"
    },
    "78A051": {
        "oui_hex": "78-A0-51",
        "organization": "iiNet Labs Pty Ltd",
        "address_1": "Level 1",
        "address_2": "Subiaco  WA  6008",
        "country": "AU"
    },
    "804F58": {
        "oui_hex": "80-4F-58",
        "organization": "ThinkEco, Inc.",
        "address_1": "303 Fifth Avenue",
        "address_2": "New York  NY  10016",
        "country": "US"
    },
    "0475F5": {
        "oui_hex": "04-75-F5",
        "organization": "CSST",
        "address_1": "Building 6, CSST industrial park, Tong fuyu Industrial zone",
        "address_2": "Shenzhen  Guangdong  518107",
        "country": "CN"
    },
    "8C4DEA": {
        "oui_hex": "8C-4D-EA",
        "organization": "Cerio Corporation",
        "address_1": "5F., No.88, Mincyuan Rd., Sindian City",
        "address_2": "Taipei County    23141",
        "country": "TW"
    },
    "24BA30": {
        "oui_hex": "24-BA-30",
        "organization": "Technical Consumer Products, Inc.",
        "address_1": "325 Campus Drive",
        "address_2": "Aurora  OH  44202",
        "country": "US"
    },
    "188ED5": {
        "oui_hex": "18-8E-D5",
        "organization": "TP Vision Belgium N.V. - innovation site Brugge",
        "address_1": "Pathoekeweg 11",
        "address_2": "Bruges  West Flanders  8000",
        "country": "BE"
    },
    "E80C38": {
        "oui_hex": "E8-0C-38",
        "organization": "DAEYOUNG INFORMATION SYSTEM CO., LTD",
        "address_1": "#826 TAMNIP-DONG, YUSEONG-GO,",
        "address_2": "DAEJON    305-510",
        "country": "KR"
    },
    "E08A7E": {
        "oui_hex": "E0-8A-7E",
        "organization": "Exponent",
        "address_1": "149 Commonwealth Drive",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "A8B0AE": {
        "oui_hex": "A8-B0-AE",
        "organization": "LEONI",
        "address_1": "3945 Freedom Circle",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "E42771": {
        "oui_hex": "E4-27-71",
        "organization": "Smartlabs",
        "address_1": "72, Oktyabrskaya Street",
        "address_2": "Moscow    127521",
        "country": "RU"
    },
    "34DF2A": {
        "oui_hex": "34-DF-2A",
        "organization": "Fujikon Industrial Co.,Limited",
        "address_1": "16/F., Tower 1, Grand Central Plaza,138 Shatin Rural",
        "address_2": "    523930",
        "country": "HK"
    },
    "2CDD0C": {
        "oui_hex": "2C-DD-0C",
        "organization": "Discovergy GmbH",
        "address_1": "Pascalstraße 15",
        "address_2": "Aachen  NRW  52076",
        "country": "DE"
    },
    "40B2C8": {
        "oui_hex": "40-B2-C8",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "70A191": {
        "oui_hex": "70-A1-91",
        "organization": "Trendsetter Medical, LLC",
        "address_1": "2030 Ardmore BLVD",
        "address_2": "Pittsburgh  PA  15221",
        "country": "US"
    },
    "708B78": {
        "oui_hex": "70-8B-78",
        "organization": "citygrow technology co., ltd",
        "address_1": "rm1404, blk A, ,5 - 21 Pak Tin Par Street",
        "address_2": "Tsuen Wan",
        "country": "HK"
    },
    "64317E": {
        "oui_hex": "64-31-7E",
        "organization": "Dexin Corporation",
        "address_1": "14F-8, No. 258, Lian Cheng Rd.",
        "address_2": "Chung Ho City, Taipei Hsien    235",
        "country": "TW"
    },
    "3C99F7": {
        "oui_hex": "3C-99-F7",
        "organization": "Lansentechnology AB",
        "address_1": "Rörkullsvägen 4",
        "address_2": "Halmstad    30241",
        "country": "SE"
    },
    "507D02": {
        "oui_hex": "50-7D-02",
        "organization": "BIODIT",
        "address_1": "Calle Gustave Eiffel 3",
        "address_2": "Paterna  Valencia  46980",
        "country": "ES"
    },
    "B4A4E3": {
        "oui_hex": "B4-A4-E3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "8C1F94": {
        "oui_hex": "8C-1F-94",
        "organization": "RF Surgical System Inc.",
        "address_1": "9740 Appaloosa Road",
        "address_2": "San Diego   CA  92131",
        "country": "US"
    },
    "4491DB": {
        "oui_hex": "44-91-DB",
        "organization": "Shanghai Huaqin Telecom Technology Co.,Ltd",
        "address_1": "No.1 Building,399 Keyuan Road, Zhangjian Hi-Tech Park,",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "14D76E": {
        "oui_hex": "14-D7-6E",
        "organization": "CONCH ELECTRONIC Co.,Ltd",
        "address_1": "No.3 Keji 1st Load.",
        "address_2": "Tainan    70955",
        "country": "TW"
    },
    "AC83F0": {
        "oui_hex": "AC-83-F0",
        "organization": "ImmediaTV Corporation",
        "address_1": "2005 De La Cruz Blvd",
        "address_2": "Santa Clara  California  95050",
        "country": "US"
    },
    "CC6B98": {
        "oui_hex": "CC-6B-98",
        "organization": "Minetec Wireless Technologies",
        "address_1": "10 Kembla Way",
        "address_2": "Willetton  WA  6155",
        "country": "AU"
    },
    "3C04BF": {
        "oui_hex": "3C-04-BF",
        "organization": "PRAVIS SYSTEMS Co.Ltd.,",
        "address_1": "4F, 5F Jaeyoon Bld, 75-3 Yangjae-Dong,",
        "address_2": "Seoul  Seocho-Gu  137-889",
        "country": "KR"
    },
    "94DD3F": {
        "oui_hex": "94-DD-3F",
        "organization": "A+V Link Technologies, Corp.",
        "address_1": "5F., No.550, Xianzheng 2nd Rd.",
        "address_2": "Zhubei City  Hsinchu Country  30268",
        "country": "TW"
    },
    "F44227": {
        "oui_hex": "F4-42-27",
        "organization": "S & S Research Inc.",
        "address_1": "89 Access Rd #10",
        "address_2": "Norwood  MA  02062",
        "country": "US"
    },
    "C8A729": {
        "oui_hex": "C8-A7-29",
        "organization": "SYStronics Co., Ltd.",
        "address_1": "#301-1404, Buchun Techno-Park II",
        "address_2": "Buchun City  Kyung gi-do  421-741",
        "country": "KR"
    },
    "4454C0": {
        "oui_hex": "44-54-C0",
        "organization": "Thompson Aerospace",
        "address_1": "18 Technology",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "C4F464": {
        "oui_hex": "C4-F4-64",
        "organization": "Spica international",
        "address_1": "Pot k sejmiscu 33",
        "address_2": "Ljubljana    1000",
        "country": "SI"
    },
    "602A54": {
        "oui_hex": "60-2A-54",
        "organization": "CardioTek B.V.",
        "address_1": "Amerikalaan 70",
        "address_2": "Maastricht Airport  Limburg  6199AE",
        "country": "NL"
    },
    "BCFFAC": {
        "oui_hex": "BC-FF-AC",
        "organization": "TOPCON CORPORATION",
        "address_1": "75-1, Hasunuma-cho",
        "address_2": "Itabashi-ku  TOKYO  174-8580",
        "country": "JP"
    },
    "445EF3": {
        "oui_hex": "44-5E-F3",
        "organization": "Tonalite Holding B.V.",
        "address_1": "Nieuw Amsterdamsestraat 40",
        "address_2": "Emmen  Drenthe  7814 VA",
        "country": "NL"
    },
    "68DB96": {
        "oui_hex": "68-DB-96",
        "organization": "OPWILL Technologies CO .,LTD",
        "address_1": "Room 415,Digital Media Building,NO.7 Shangdi Information Road,HaiDian District,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "7C55E7": {
        "oui_hex": "7C-55-E7",
        "organization": "YSI, Inc.",
        "address_1": "1725 Brannum Lane",
        "address_2": "Yellow Springs  Ohio  45387",
        "country": "US"
    },
    "70B08C": {
        "oui_hex": "70-B0-8C",
        "organization": "Shenou Communication Equipment Co.,Ltd",
        "address_1": "No.118 Middle Juguang Road, High & New Industrial Zone",
        "address_2": "Wenzhou  Zhejiang  325029",
        "country": "CN"
    },
    "C03B8F": {
        "oui_hex": "C0-3B-8F",
        "organization": "Minicom Digital Signage",
        "address_1": "24 Hebron Road",
        "address_2": "Jerusalem    93542",
        "country": "IL"
    },
    "20FEDB": {
        "oui_hex": "20-FE-DB",
        "organization": "M2M Solution S.A.S.",
        "address_1": "Centre d'Affaires Regus Bat.D",
        "address_2": "Mougins     06254",
        "country": "FR"
    },
    "0C8D98": {
        "oui_hex": "0C-8D-98",
        "organization": "TOP EIGHT IND CORP",
        "address_1": "8F.,No79-1 Zhouzi St., Neihu District, Taipei City  (Neihu Technology Park)",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "40C7C9": {
        "oui_hex": "40-C7-C9",
        "organization": "Naviit Inc.",
        "address_1": "3058A Scott Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "7CBB6F": {
        "oui_hex": "7C-BB-6F",
        "organization": "Cosco Electronics Co., Ltd.",
        "address_1": "#1101, ENC Dream tower, 327-27",
        "address_2": "Seoul    153-793",
        "country": "KR"
    },
    "94A7BC": {
        "oui_hex": "94-A7-BC",
        "organization": "BodyMedia, Inc.",
        "address_1": "420 Fort Duquesne Blvd",
        "address_2": "Pittsburgh  PA  15222",
        "country": "US"
    },
    "C8A1B6": {
        "oui_hex": "C8-A1-B6",
        "organization": "Shenzhen Longway Technologies Co., Ltd",
        "address_1": "Suite 707,Incubation Building, China Academy of Science&Tech Development, South area",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A8556A": {
        "oui_hex": "A8-55-6A",
        "organization": "Pocketnet Technology Inc.",
        "address_1": "Suite B, 7F., No. 550, Ruie Kwang Rd., Neihu District,",
        "address_2": "Taipei    11429",
        "country": "TW"
    },
    "B4C810": {
        "oui_hex": "B4-C8-10",
        "organization": "UMPI Elettronica",
        "address_1": "Via Respighi, 15",
        "address_2": "Cattolica    47841",
        "country": "IT"
    },
    "64A232": {
        "oui_hex": "64-A2-32",
        "organization": "OOO Samlight",
        "address_1": "44A, Dubninskaya str.,",
        "address_2": "Moscow    127591",
        "country": "RU"
    },
    "64FC8C": {
        "oui_hex": "64-FC-8C",
        "organization": "Zonar Systems",
        "address_1": "18200 Cascade Ave South",
        "address_2": "Seattle  WA  98118",
        "country": "US"
    },
    "D0574C": {
        "oui_hex": "D0-57-4C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F8DAE2": {
        "oui_hex": "F8-DA-E2",
        "organization": "NDC Technologies",
        "address_1": "8001 Technology Blvd",
        "address_2": "Dayton  OH  45424",
        "country": "US"
    },
    "705EAA": {
        "oui_hex": "70-5E-AA",
        "organization": "Action Target, Inc.",
        "address_1": "PO Box 636",
        "address_2": "Provo  UT  84603",
        "country": "US"
    },
    "34F968": {
        "oui_hex": "34-F9-68",
        "organization": "ATEK Products, LLC",
        "address_1": "210 NE 10th Avenue",
        "address_2": "Brainerd  MN  56401",
        "country": "US"
    },
    "20B0F7": {
        "oui_hex": "20-B0-F7",
        "organization": "Enclustra GmbH",
        "address_1": "Technoparkstrasse 1",
        "address_2": "Zurich  ZH  CH-8005",
        "country": "CH"
    },
    "543131": {
        "oui_hex": "54-31-31",
        "organization": "Raster Vision Ltd",
        "address_1": "Unit 1, Crundalls",
        "address_2": "Tonbridge   Kent  TN12 7EA",
        "country": "GB"
    },
    "D0E347": {
        "oui_hex": "D0-E3-47",
        "organization": "Yoga",
        "address_1": "Tammsaare tee 47",
        "address_2": "Tallinn  Harjumaa  11316",
        "country": "EE"
    },
    "F0ED1E": {
        "oui_hex": "F0-ED-1E",
        "organization": "Bilkon Bilgisayar Kontrollu Cih. Im.Ltd.",
        "address_1": "Gersan Sanayi Sitesi 658.Sokak No:16",
        "address_2": "ANKARA    06370",
        "country": "TR"
    },
    "C416FA": {
        "oui_hex": "C4-16-FA",
        "organization": "Prysm Inc",
        "address_1": "180 Baytech Drive",
        "address_2": "San Jose  California  95134",
        "country": "US"
    },
    "506F9A": {
        "oui_hex": "50-6F-9A",
        "organization": "Wi-Fi Alliance",
        "address_1": "3925 W. Braker Lane",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "842914": {
        "oui_hex": "84-29-14",
        "organization": "EMPORIA TELECOM Produktions- und VertriebsgesmbH & Co KG",
        "address_1": "Industriezeile 36,",
        "address_2": "Linz    4020",
        "country": "AT"
    },
    "BC7DD1": {
        "oui_hex": "BC-7D-D1",
        "organization": "Radio Data Comms",
        "address_1": "5/20-30 Stubbs Street",
        "address_2": "Silverwater   New South Wales (NSW)  2128",
        "country": "AU"
    },
    "585076": {
        "oui_hex": "58-50-76",
        "organization": "Linear Equipamentos Eletronicos SA",
        "address_1": "Praca Linear 100",
        "address_2": "Santa Rita do Sapucai  MG  37540000",
        "country": "BR"
    },
    "F0F9F7": {
        "oui_hex": "F0-F9-F7",
        "organization": "IES GmbH & Co. KG",
        "address_1": "Darmcher Grund 22",
        "address_2": "Meinerzhagen    58540",
        "country": "DE"
    },
    "38580C": {
        "oui_hex": "38-58-0C",
        "organization": "Panaccess Systems GmbH",
        "address_1": "Gutenbergstr. 8",
        "address_2": "Ismaning  BY  85737",
        "country": "DE"
    },
    "4451DB": {
        "oui_hex": "44-51-DB",
        "organization": "Raytheon BBN Technologies",
        "address_1": "10 Moulton Street",
        "address_2": "Cambridge  MA  02138",
        "country": "US"
    },
    "DCFAD5": {
        "oui_hex": "DC-FA-D5",
        "organization": "STRONG Ges.m.b.H.",
        "address_1": "Franz-Josefs-Kai 1",
        "address_2": "Vienna    1010",
        "country": "AT"
    },
    "6C8D65": {
        "oui_hex": "6C-8D-65",
        "organization": "Wireless Glue Networks, Inc.",
        "address_1": "1601 N. Main Street, Suite 202",
        "address_2": "Walnut Creek  CA  94596",
        "country": "US"
    },
    "9803A0": {
        "oui_hex": "98-03-A0",
        "organization": "ABB n.v. Power Quality Products",
        "address_1": "10 allée centrale",
        "address_2": "Jumet    6040",
        "country": "BE"
    },
    "CC43E3": {
        "oui_hex": "CC-43-E3",
        "organization": "Trump s.a.",
        "address_1": "rue de la Maitrise 9",
        "address_2": "Nivelles    1400",
        "country": "BE"
    },
    "F8C091": {
        "oui_hex": "F8-C0-91",
        "organization": "Highgates Technology",
        "address_1": "1415 Highgates Ave",
        "address_2": "Los Angeles  CA  90042",
        "country": "US"
    },
    "AC9B84": {
        "oui_hex": "AC-9B-84",
        "organization": "Smak Tecnologia e Automacao",
        "address_1": "Av. Sto. Antonio, 201 - Bela Vista",
        "address_2": "Osasco  São Paulo  CEP 06086-075",
        "country": "BR"
    },
    "90F278": {
        "oui_hex": "90-F2-78",
        "organization": "Radius Gateway",
        "address_1": "520 E. Montford Ave",
        "address_2": "Ada  OH  45810",
        "country": "US"
    },
    "806629": {
        "oui_hex": "80-66-29",
        "organization": "Prescope Technologies CO.,LTD.",
        "address_1": "12F-1,No.192,Sec 2,Chung Hsin Road",
        "address_2": "Hsin Tien City  Taipei County  23146",
        "country": "TW"
    },
    "241F2C": {
        "oui_hex": "24-1F-2C",
        "organization": "Calsys, Inc.",
        "address_1": "2700 Augustine drive, Ste145",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "F0BDF1": {
        "oui_hex": "F0-BD-F1",
        "organization": "Sipod Inc.",
        "address_1": "4633 Old Ironsides Drive, #400",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "646707": {
        "oui_hex": "64-67-07",
        "organization": "Beijing Omnific Technology, Ltd.",
        "address_1": "Rm. 402, Building 1, Shui Mu Qing Hua Community",
        "address_2": "Beijing    100190",
        "country": "CN"
    },
    "58FD20": {
        "oui_hex": "58-FD-20",
        "organization": "Bravida Sakerhet AB",
        "address_1": "Mikrofonvagen 28",
        "address_2": "STOCKHOLM    126 81",
        "country": "SE"
    },
    "ACA016": {
        "oui_hex": "AC-A0-16",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "58E747": {
        "oui_hex": "58-E7-47",
        "organization": "Deltanet AG",
        "address_1": "Riedstrasse 8",
        "address_2": "Dietikon  Zurich  8953",
        "country": "CH"
    },
    "404022": {
        "oui_hex": "40-40-22",
        "organization": "ZIV",
        "address_1": "Polígono Parque Tecnológico, 210",
        "address_2": "ZAMUDIO  VIZCAYA  48170",
        "country": "ES"
    },
    "A85BB0": {
        "oui_hex": "A8-5B-B0",
        "organization": "Shenzhen Dehoo Technology Co.,Ltd",
        "address_1": "5C,Tianzhan Building Tianan Cyberpark,",
        "address_2": "ShenZhen  Guang Dong  518040",
        "country": "CN"
    },
    "44A689": {
        "oui_hex": "44-A6-89",
        "organization": "PROMAX ELECTRONICA SA",
        "address_1": "FRANCESC MORAGAS 71-75",
        "address_2": "HOSPITALET DE LLOBREGAT  BARCELONA  08907",
        "country": "ES"
    },
    "40618E": {
        "oui_hex": "40-61-8E",
        "organization": "Stella-Green Co",
        "address_1": "1-5-16 Edobori, Nishi-ku",
        "address_2": "Osaka    550-0002",
        "country": "JP"
    },
    "68E41F": {
        "oui_hex": "68-E4-1F",
        "organization": "Unglaube Identech GmbH",
        "address_1": "An der Moosach 3a",
        "address_2": "Massenhausen  Bayern  85376",
        "country": "DE"
    },
    "4C60D5": {
        "oui_hex": "4C-60-D5",
        "organization": "airPointe of New Hampshire",
        "address_1": "35E Industrial Way",
        "address_2": "Rochester  NH  03867",
        "country": "US"
    },
    "888717": {
        "oui_hex": "88-87-17",
        "organization": "CANON INC.",
        "address_1": "3-30-2",
        "address_2": "Ohta-Ku  Tokyo  146-8501",
        "country": "JP"
    },
    "6CDC6A": {
        "oui_hex": "6C-DC-6A",
        "organization": "Promethean Limited",
        "address_1": "Activlab",
        "address_2": "Blackburn  Lancashire  BB1 5SN",
        "country": "GB"
    },
    "9055AE": {
        "oui_hex": "90-55-AE",
        "organization": "Ericsson, EAB/RWI/K",
        "address_1": "Skolgången 17",
        "address_2": "Gävle    SE-800 06",
        "country": "SE"
    },
    "1010B6": {
        "oui_hex": "10-10-B6",
        "organization": "McCain Inc",
        "address_1": "2365 Oak Ridge Way",
        "address_2": "Vista  CA  92081",
        "country": "US"
    },
    "009363": {
        "oui_hex": "00-93-63",
        "organization": "Uni-Link Technology Co., Ltd.",
        "address_1": "7-5, No.66, Sec.2, Nan-Kan Rd., Lu-Chu Hsiang,Taoyuan,Taiwan",
        "address_2": "Taoyuan  Taiwan  338",
        "country": "TW"
    },
    "D4823E": {
        "oui_hex": "D4-82-3E",
        "organization": "Argosy Technologies, Ltd.",
        "address_1": "73-221 Haystack Road",
        "address_2": "Palm Desert  CA  92260",
        "country": "US"
    },
    "003532": {
        "oui_hex": "00-35-32",
        "organization": "Electro-Metrics Corporation",
        "address_1": "231 Enterprise Road",
        "address_2": "Johnstown  New York  12095",
        "country": "US"
    },
    "081FF3": {
        "oui_hex": "08-1F-F3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "44376F": {
        "oui_hex": "44-37-6F",
        "organization": "Young Electric Sign Co",
        "address_1": "1651 N 1000 W",
        "address_2": "Logan  UT  84321",
        "country": "US"
    },
    "389F83": {
        "oui_hex": "38-9F-83",
        "organization": "OTN Systems N.V.",
        "address_1": "Industrielaan 17b",
        "address_2": "Olen    2250",
        "country": "BE"
    },
    "BC6A16": {
        "oui_hex": "BC-6A-16",
        "organization": "tdvine",
        "address_1": "301 Maison Maru Building",
        "address_2": "Seoul    135-010",
        "country": "KR"
    },
    "003A9D": {
        "oui_hex": "00-3A-9D",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "28CD4C": {
        "oui_hex": "28-CD-4C",
        "organization": "Individual Computers GmbH",
        "address_1": "Im Zemmer 6",
        "address_2": "Woffelsbach  NRW  52152",
        "country": "DE"
    },
    "8C53F7": {
        "oui_hex": "8C-53-F7",
        "organization": "A&D ENGINEERING CO., LTD.",
        "address_1": "336-6 Dangsandong 6-ga, Yeongdeungpo-gu",
        "address_2": "Seoul    150-810",
        "country": "KR"
    },
    "7C7673": {
        "oui_hex": "7C-76-73",
        "organization": "ENMAS GmbH",
        "address_1": "Holzkoppelweg 23",
        "address_2": "Kiel  Schleswig-Holstein  24251",
        "country": "DE"
    },
    "6C6F18": {
        "oui_hex": "6C-6F-18",
        "organization": "Stereotaxis, Inc.",
        "address_1": "4320 Forest Park Ave",
        "address_2": "St. Louis  MO  63108",
        "country": "US"
    },
    "84C727": {
        "oui_hex": "84-C7-27",
        "organization": "Gnodal Ltd",
        "address_1": "178 - 180 Hotwell Road",
        "address_2": "Bristol    BS8 4RP",
        "country": "GB"
    },
    "087695": {
        "oui_hex": "08-76-95",
        "organization": "Auto Industrial Co., Ltd.",
        "address_1": "14Floor, #235 Hanshin IT Tower,",
        "address_2": "Seoul    152-768",
        "country": "KR"
    },
    "ACCE8F": {
        "oui_hex": "AC-CE-8F",
        "organization": "HWA YAO TECHNOLOGIES CO., LTD",
        "address_1": "NO. 6, LN. 48, NANSING RD.,",
        "address_2": "YONGKANG CITY, TAINAN COUNTY     710",
        "country": "TW"
    },
    "8C9236": {
        "oui_hex": "8C-92-36",
        "organization": "Aus.Linx Technology Co., Ltd.",
        "address_1": "6F-2, No. 190, Sec. 2, Zhongxing Rd., Xindian Dist.,",
        "address_2": "New Taipei City    23146",
        "country": "TW"
    },
    "10C73F": {
        "oui_hex": "10-C7-3F",
        "organization": "Midas Klark Teknik Ltd",
        "address_1": "Klark Teknik Building",
        "address_2": "Kidderminster  Worcestershire  DY11 7HJ",
        "country": "GB"
    },
    "F8912A": {
        "oui_hex": "F8-91-2A",
        "organization": "GLP German Light Products GmbH",
        "address_1": "Im Stöckmädle 13",
        "address_2": "Karlsbad  BW  76307",
        "country": "DE"
    },
    "44E49A": {
        "oui_hex": "44-E4-9A",
        "organization": "OMNITRONICS PTY LTD",
        "address_1": "27 SARICH CRT",
        "address_2": "OSBORNE PARK  WA  6017",
        "country": "AU"
    },
    "08F2F4": {
        "oui_hex": "08-F2-F4",
        "organization": "Net One Partners Co.,Ltd.",
        "address_1": "2-8 Higashi Shinagawa 2-chome,",
        "address_2": "Tokyo    1400002",
        "country": "JP"
    },
    "0C7D7C": {
        "oui_hex": "0C-7D-7C",
        "organization": "Kexiang Information Technology Co, Ltd.",
        "address_1": "Room 1502, Longxi Hotel No.3788 Jiangnan Avenue.",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "3037A6": {
        "oui_hex": "30-37-A6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DC1D9F": {
        "oui_hex": "DC-1D-9F",
        "organization": "U & B tech",
        "address_1": "2F, Daeyoung buliding, 1423-6, Kwanyang-1Dong,",
        "address_2": "Anyang-Si  Gyeonggi-Do  431-061",
        "country": "KR"
    },
    "D8E72B": {
        "oui_hex": "D8-E7-2B",
        "organization": "NetAlly",
        "address_1": "310 Littleton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "785C72": {
        "oui_hex": "78-5C-72",
        "organization": "Hioso Technology Co., Ltd.",
        "address_1": "6th Floor, 12th Building, Wangtang Industrial Zone,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "580556": {
        "oui_hex": "58-05-56",
        "organization": "Elettronica GF S.r.L.",
        "address_1": "Via Vittori, 63",
        "address_2": "FAENZA  RA  48018",
        "country": "IT"
    },
    "B09074": {
        "oui_hex": "B0-90-74",
        "organization": "Fulan Electronics Limited",
        "address_1": "Flat B&C,3/F,A1 Block, Gaoxin Cyber-Tech Zone,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "94F692": {
        "oui_hex": "94-F6-92",
        "organization": "Geminico co.,Ltd.",
        "address_1": "#102-1112, Chunui-Technopark, 200-1,",
        "address_2": "Bucheon-city  Kyunggi-do  420-857",
        "country": "KR"
    },
    "68EFBD": {
        "oui_hex": "68-EF-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F02408": {
        "oui_hex": "F0-24-08",
        "organization": "Talaris (Sweden) AB",
        "address_1": "Taljs Sodra Industriomrade",
        "address_2": "Flen    64284",
        "country": "SE"
    },
    "8081A5": {
        "oui_hex": "80-81-A5",
        "organization": "TONGQING COMMUNICATION EQUIPMENT (SHENZHEN) Co.,Ltd",
        "address_1": "Tongqing Industry Park,jiuwei,xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518126",
        "country": "CN"
    },
    "B482FE": {
        "oui_hex": "B4-82-FE",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "307C30": {
        "oui_hex": "30-7C-30",
        "organization": "RIM",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "BC4E3C": {
        "oui_hex": "BC-4E-3C",
        "organization": "CORE STAFF CO., LTD.",
        "address_1": "Shin-osaka Oriental Bldg. 14F, 7-1-26 Nishinakajima",
        "address_2": "Yodogawa-ku  Osaka  532-0011",
        "country": "JP"
    },
    "502A8B": {
        "oui_hex": "50-2A-8B",
        "organization": "Telekom Research and Development Sdn Bhd",
        "address_1": "TMRND Innovation Centre",
        "address_2": "Cyberjaya  Selangor  63000",
        "country": "MY"
    },
    "EC43E6": {
        "oui_hex": "EC-43-E6",
        "organization": "AWCER Ltd.",
        "address_1": "100-413 Bucheon Technopark",
        "address_2": "Bucheon-city  Gyeonggi-do  421-741",
        "country": "KR"
    },
    "7812B8": {
        "oui_hex": "78-12-B8",
        "organization": "ORANTEK LIMITED",
        "address_1": "5/F, Building E, Dakan Tech Park, Dakan village, Xili Town, Nanshan District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "98BC99": {
        "oui_hex": "98-BC-99",
        "organization": "Edeltech Co.,Ltd.",
        "address_1": "#302 Jamae Bldg, 1010-28, Sadang-dong, Dongjak=gu",
        "address_2": "Seoul    156-824",
        "country": "KR"
    },
    "F02FD8": {
        "oui_hex": "F0-2F-D8",
        "organization": "Bi2-Vision",
        "address_1": "16-504, 21-ban, Shimomaruko 4-chome, Oota-ku",
        "address_2": "Tokyo    146-0092",
        "country": "JP"
    },
    "544249": {
        "oui_hex": "54-42-49",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec 5-1-2",
        "address_2": "Tokyo  Shinagawa-ku  141-0001",
        "country": "JP"
    },
    "904716": {
        "oui_hex": "90-47-16",
        "organization": "RORZE CORPORATION",
        "address_1": "1588-2 Michinoue, Kannabe-cho",
        "address_2": "Fukuyama  Hiroshima  720-2104",
        "country": "JP"
    },
    "10445A": {
        "oui_hex": "10-44-5A",
        "organization": "Shaanxi Hitech Electronic Co., LTD",
        "address_1": "35 Tuanjienan Rode,",
        "address_2": "Xian  Shaanxi  710075",
        "country": "CN"
    },
    "F47626": {
        "oui_hex": "F4-76-26",
        "organization": "Viltechmeda UAB",
        "address_1": "Kalvariju 125",
        "address_2": "Vilnius    LT-08221",
        "country": "LT"
    },
    "0C17F1": {
        "oui_hex": "0C-17-F1",
        "organization": "TELECSYS",
        "address_1": "31 chemin du fief aux pretres",
        "address_2": "L'ORBRIE    85200",
        "country": "FR"
    },
    "003A9B": {
        "oui_hex": "00-3A-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2C3427": {
        "oui_hex": "2C-34-27",
        "organization": "ERCO & GENER",
        "address_1": "ZI de SAINT LAMBERT DES LEVEES",
        "address_2": "SAUMUR    49412",
        "country": "FR"
    },
    "80912A": {
        "oui_hex": "80-91-2A",
        "organization": "Lih Rong electronic Enterprise Co., Ltd.",
        "address_1": "2F, No. 2, Lane 387, Hsin Shu Road",
        "address_2": "Hsin Chuang  Taipei  242",
        "country": "TW"
    },
    "7C2F80": {
        "oui_hex": "7C-2F-80",
        "organization": "Gigaset Communications GmbH",
        "address_1": "SCM PE 2",
        "address_2": "Bocholt    46395",
        "country": "DE"
    },
    "10B7F6": {
        "oui_hex": "10-B7-F6",
        "organization": "Plastoform Industries Ltd.",
        "address_1": "Units 1506A - 1512, Mita Centre,",
        "address_2": "Kwai Chung,",
        "country": "HK"
    },
    "448E81": {
        "oui_hex": "44-8E-81",
        "organization": "VIG",
        "address_1": "705 Hanshin IT Tower, 60-18, Kasan-dong, Geumcheon-gu",
        "address_2": "Seoul    KSXX0022",
        "country": "KR"
    },
    "8894F9": {
        "oui_hex": "88-94-F9",
        "organization": "Gemicom Technology, Inc.",
        "address_1": "16F, Building B, No. 98, Sec 1, Hsin-Tai-Wu Rd.",
        "address_2": "Hsi-Chih city  Taipei  22102",
        "country": "TW"
    },
    "502A7E": {
        "oui_hex": "50-2A-7E",
        "organization": "Smart electronic GmbH",
        "address_1": "Industrie Str. 29",
        "address_2": "St. Georgen    78112",
        "country": "DE"
    },
    "5C8778": {
        "oui_hex": "5C-87-78",
        "organization": "Cybertelbridge co.,ltd",
        "address_1": "#901 Acehighend tower 2",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "38BB23": {
        "oui_hex": "38-BB-23",
        "organization": "OzVision America LLC",
        "address_1": "400 West Cummings Park",
        "address_2": "Woburn  MA  01801",
        "country": "US"
    },
    "0C8411": {
        "oui_hex": "0C-84-11",
        "organization": "A.O. Smith Water Products",
        "address_1": "25589 Hwy 1",
        "address_2": "McBee  SC  29101",
        "country": "US"
    },
    "E0ABFE": {
        "oui_hex": "E0-AB-FE",
        "organization": "Orb Networks, Inc.",
        "address_1": "428 13th Street",
        "address_2": "Oakland  CA  94612",
        "country": "US"
    },
    "448312": {
        "oui_hex": "44-83-12",
        "organization": "Star-Net",
        "address_1": "Egoz 64",
        "address_2": "Kiryat Byalik  Israel  27000",
        "country": "IL"
    },
    "A05DE7": {
        "oui_hex": "A0-5D-E7",
        "organization": "DIRECTV, Inc.",
        "address_1": "2230 E. Imperial Hwy",
        "address_2": "El Segundo  CA  90245",
        "country": "US"
    },
    "087618": {
        "oui_hex": "08-76-18",
        "organization": "ViE Technologies Sdn. Bhd.",
        "address_1": "no. 85-A, Lintang Bayan Lepas 11,",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "D0E40B": {
        "oui_hex": "D0-E4-0B",
        "organization": "Wearable Inc.",
        "address_1": "3825 Charles Dr.",
        "address_2": "Northbrook  IL  60062",
        "country": "US"
    },
    "747E1A": {
        "oui_hex": "74-7E-1A",
        "organization": "Red Embedded Design Limited",
        "address_1": "The Wave",
        "address_2": "Shipley  West Yorkshire  BD17 7Du",
        "country": "GB"
    },
    "14A86B": {
        "oui_hex": "14-A8-6B",
        "organization": "ShenZhen Telacom Science&Technology Co., Ltd",
        "address_1": "B1701/1705 Pavilion, Hua Qiang Bei RD4002, Futian District",
        "address_2": "ShenZhen  GuangDong  518028",
        "country": "CN"
    },
    "0CC3A7": {
        "oui_hex": "0C-C3-A7",
        "organization": "Meritec",
        "address_1": "P.O. Box 8003",
        "address_2": "Painesville  Ohio  44077",
        "country": "US"
    },
    "DCE2AC": {
        "oui_hex": "DC-E2-AC",
        "organization": "Lumens Digital Optics Inc.",
        "address_1": "5F, No.35, Sintai Rd., Jhubei City",
        "address_2": "Jhubei   HsinChu  302",
        "country": "TW"
    },
    "98D88C": {
        "oui_hex": "98-D8-8C",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "78192E": {
        "oui_hex": "78-19-2E",
        "organization": "NASCENT Technology",
        "address_1": "2744 Yorkmont RD",
        "address_2": "Charlotte  NC  28208",
        "country": "US"
    },
    "48EB30": {
        "oui_hex": "48-EB-30",
        "organization": "ETERNA TECHNOLOGY, INC.",
        "address_1": "3939 veselich ave",
        "address_2": "los angeles  california  90039",
        "country": "US"
    },
    "4C322D": {
        "oui_hex": "4C-32-2D",
        "organization": "TELEDATA NETWORKS",
        "address_1": "10 Hasadnaot Street",
        "address_2": "HERZLIYA    46120",
        "country": "IL"
    },
    "AC867E": {
        "oui_hex": "AC-86-7E",
        "organization": "Create New Technology (HK) Limited Company",
        "address_1": "Rm B 10/F JinFeng Building,1001 ShangBu South Road,FuTian District",
        "address_2": "Shen Zhen  Guang Dong  518031",
        "country": "CN"
    },
    "8C598B": {
        "oui_hex": "8C-59-8B",
        "organization": "C Technologies AB",
        "address_1": "Traktorvägen 11",
        "address_2": "Lund  Skåne  226 60",
        "country": "SE"
    },
    "D44CA7": {
        "oui_hex": "D4-4C-A7",
        "organization": "Informtekhnika & Communication, LLC",
        "address_1": "1, build. 2/1, Verhnaya",
        "address_2": "Moscow    107140",
        "country": "RU"
    },
    "A8C222": {
        "oui_hex": "A8-C2-22",
        "organization": "TM-Research Inc.",
        "address_1": "Hiyoshi Honcho 1-15-4",
        "address_2": "Yokohama  Kanagawa  223-0062",
        "country": "JP"
    },
    "003D41": {
        "oui_hex": "00-3D-41",
        "organization": "Hatteland Computer AS",
        "address_1": "Aamsosen",
        "address_2": "Nedre Vats  Rogaland  5578",
        "country": "NO"
    },
    "CC5076": {
        "oui_hex": "CC-50-76",
        "organization": "Ocom Communications, Inc.",
        "address_1": "13F-6, No. 1, Bao Sheng Rd.,",
        "address_2": "Yong Ho City    234",
        "country": "TW"
    },
    "4CC452": {
        "oui_hex": "4C-C4-52",
        "organization": "Shang Hai Tyd. Electon Technology Ltd.",
        "address_1": "Room No.5,N0.396,GuiLin Road,",
        "address_2": "Shang Hai    200233",
        "country": "US"
    },
    "7CCB0D": {
        "oui_hex": "7C-CB-0D",
        "organization": "Antaira Technologies, LLC",
        "address_1": "445 Capricorn St.",
        "address_2": "Brea  California  92821",
        "country": "US"
    },
    "C01E9B": {
        "oui_hex": "C0-1E-9B",
        "organization": "Pixavi AS",
        "address_1": "Dusavikveien 39",
        "address_2": "Stavanger    4003",
        "country": "NO"
    },
    "803B9A": {
        "oui_hex": "80-3B-9A",
        "organization": "ghe-ces electronic ag",
        "address_1": "Hoemelstraße 17",
        "address_2": "Wald  ZH  8636",
        "country": "CH"
    },
    "743256": {
        "oui_hex": "74-32-56",
        "organization": "NT-ware Systemprg GmbH",
        "address_1": "Niedersachsenstrasse 6",
        "address_2": "Bad Iburg  NDS  49186",
        "country": "DE"
    },
    "C4E17C": {
        "oui_hex": "C4-E1-7C",
        "organization": "U2S co.",
        "address_1": "104-706, SK Ventium Building, 522, Dangjeong-Dong",
        "address_2": "Gunpo-si  Geonggi-do  435-776",
        "country": "KR"
    },
    "20BFDB": {
        "oui_hex": "20-BF-DB",
        "organization": "DVL",
        "address_1": "21 Gradinilor Str",
        "address_2": "Chisinau    MD2001",
        "country": "MD"
    },
    "20415A": {
        "oui_hex": "20-41-5A",
        "organization": "Smarteh d.o.o.",
        "address_1": "Trg tigrovcev 1",
        "address_2": "Tolmin    5220",
        "country": "SI"
    },
    "A4DA3F": {
        "oui_hex": "A4-DA-3F",
        "organization": "Bionics Corp.",
        "address_1": "1406 Masters Tower",
        "address_2": "Seoul    121-748",
        "country": "KR"
    },
    "A04025": {
        "oui_hex": "A0-40-25",
        "organization": "Actioncable, Inc.",
        "address_1": "998 Westlynn Way",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C4B68": {
        "oui_hex": "4C-4B-68",
        "organization": "Mobile Device, Inc.",
        "address_1": " 8F-1, No. 145, Sianjheng 9th Rd.,",
        "address_2": "Jhubei City,   Hsinchu County   30251",
        "country": "TW"
    },
    "201257": {
        "oui_hex": "20-12-57",
        "organization": "Most Lucky Trading Ltd",
        "address_1": "Room403 No.506 Zhongshan South 2nd Road,Xuhui District",
        "address_2": "Shanghai    200032",
        "country": "CN"
    },
    "E8DAAA": {
        "oui_hex": "E8-DA-AA",
        "organization": "VideoHome Technology Corp.",
        "address_1": "4F-1, No. 192, Da Tung Rd., Sec. 3, Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "647D81": {
        "oui_hex": "64-7D-81",
        "organization": "YOKOTA INDUSTRIAL CO,.LTD",
        "address_1": "5-55 NISHIIWATA",
        "address_2": "HIGASHI OSAKA-CITY  OSAKA  578-0947",
        "country": "JP"
    },
    "7CCFCF": {
        "oui_hex": "7C-CF-CF",
        "organization": "Shanghai SEARI Intelligent System Co., Ltd",
        "address_1": "No.505 Wuning Road, Putuo District",
        "address_2": "Shanghai    200063",
        "country": "CN"
    },
    "68AAD2": {
        "oui_hex": "68-AA-D2",
        "organization": "DATECS LTD.,",
        "address_1": "BUL. TSARIGRADSKO SHOSSE 115A",
        "address_2": "SOFIA    1784",
        "country": "BG"
    },
    "A4DE50": {
        "oui_hex": "A4-DE-50",
        "organization": "Total Walther GmbH",
        "address_1": "Frankfurter Ring 17",
        "address_2": "Munich    80807",
        "country": "DE"
    },
    "1CF061": {
        "oui_hex": "1C-F0-61",
        "organization": "SCAPS GmbH",
        "address_1": "Bahnhofstraße 17",
        "address_2": "Deisenhofen  Bavaria  82041",
        "country": "DE"
    },
    "A893E6": {
        "oui_hex": "A8-93-E6",
        "organization": "JIANGXI JINGGANGSHAN CKING COMMUNICATION TECHNOLOGY CO.,LTD",
        "address_1": "5F,301building,Tairan High-tech park, Chegongmiao,Futian zone,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "C4AAA1": {
        "oui_hex": "C4-AA-A1",
        "organization": "SUMMIT DEVELOPMENT, spol.s r.o.",
        "address_1": "K Vodoteci 197",
        "address_2": "Orech  Praha-zapad  252 25",
        "country": "CZ"
    },
    "3032D4": {
        "oui_hex": "30-32-D4",
        "organization": "Hanilstm Co., Ltd.",
        "address_1": "138-6, Sangdaewon-dong Jungwon-gu",
        "address_2": "Seongnam  Kyonggi-do  462-120",
        "country": "KR"
    },
    "E064BB": {
        "oui_hex": "E0-64-BB",
        "organization": "DigiView S.r.l.",
        "address_1": "Via Senigallia 18/2",
        "address_2": "Milano    20161",
        "country": "IT"
    },
    "DC3350": {
        "oui_hex": "DC-33-50",
        "organization": "TechSAT GmbH",
        "address_1": "Gruber Str. 46c",
        "address_2": "Poing  BY  85586",
        "country": "DE"
    },
    "F0BCC8": {
        "oui_hex": "F0-BC-C8",
        "organization": "MaxID (Pty) Ltd",
        "address_1": "43 Homestead Road",
        "address_2": "Johannesburg  Gauteng  2128",
        "country": "ZA"
    },
    "24828A": {
        "oui_hex": "24-82-8A",
        "organization": "Prowave Technologies Ltd.",
        "address_1": "2F,No.879-16,Zhongjiang Road",
        "address_2": "Shanghai    200333",
        "country": "CN"
    },
    "68CC9C": {
        "oui_hex": "68-CC-9C",
        "organization": "Mine Site Technologies",
        "address_1": "113 Wicks Road",
        "address_2": "North Ryde  NSW  2113",
        "country": "AU"
    },
    "146E0A": {
        "oui_hex": "14-6E-0A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0CE709": {
        "oui_hex": "0C-E7-09",
        "organization": "Fox Crypto B.V.",
        "address_1": "P.O. box 638",
        "address_2": "Delft  ZH  2600 AP",
        "country": "NL"
    },
    "B4B5AF": {
        "oui_hex": "B4-B5-AF",
        "organization": "Minsung Electronics",
        "address_1": "Mega-valley #620",
        "address_2": "Anyang-si  Kyeonggi-do  431-767",
        "country": "KR"
    },
    "04B3B6": {
        "oui_hex": "04-B3-B6",
        "organization": "Seamap (UK) Ltd",
        "address_1": "Unit 34, The Maltings",
        "address_2": "Shepton Mallet  Somerset  BA4 5QE",
        "country": "GB"
    },
    "00270B": {
        "oui_hex": "00-27-0B",
        "organization": "Adura Technologies",
        "address_1": "28 Second Street",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "00270D": {
        "oui_hex": "00-27-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00271B": {
        "oui_hex": "00-27-1B",
        "organization": "Alec Sicherheitssysteme GmbH",
        "address_1": "Friedrich-Hoelscher-Strasse 367",
        "address_2": "Dortmund    44328",
        "country": "DE"
    },
    "002718": {
        "oui_hex": "00-27-18",
        "organization": "Suzhou NEW SEAUNION Video Technology Co.,Ltd",
        "address_1": "383 Jingmao Road, Industry Park",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "6C0F6A": {
        "oui_hex": "6C-0F-6A",
        "organization": "JDC Tech Co., Ltd.",
        "address_1": "370-12 Daemyung-ri Daegot-myun",
        "address_2": "Kimpo-si  Kyunggi-do  410-853",
        "country": "KR"
    },
    "04B466": {
        "oui_hex": "04-B4-66",
        "organization": "BSP Co., Ltd.",
        "address_1": "162-10",
        "address_2": "Gumi  Gyeungsangbuk Do  730-902",
        "country": "KR"
    },
    "D8D67E": {
        "oui_hex": "D8-D6-7E",
        "organization": "GSK CNC EQUIPMENT CO.,LTD",
        "address_1": "No.7,1st Street,Luochong North Road,Luochongwei,No.7,1st Street,Luochong North Road,Luochongwei,No.7,1st Street,Luochong North Road,Luochongwei,",
        "address_2": "Guangzhou  Guangdong  510165",
        "country": "CN"
    },
    "0026AE": {
        "oui_hex": "00-26-AE",
        "organization": "Wireless Measurement Ltd",
        "address_1": "The Crescent",
        "address_2": "EMSWORTH    PO10 8JS",
        "country": "GB"
    },
    "0026B1": {
        "oui_hex": "00-26-B1",
        "organization": "Navis Auto Motive Systems, Inc.",
        "address_1": "Busan, Centumjungang-ro 78, Centum Greentower 8th floor",
        "address_2": "BUSAN    612-822",
        "country": "KR"
    },
    "0026AA": {
        "oui_hex": "00-26-AA",
        "organization": "Kenmec Mechanical Engineering Co., Ltd.",
        "address_1": "3F, No. 97, Sec.2 Nan-Kang Rd.,",
        "address_2": "Taipei    11578",
        "country": "TW"
    },
    "0026D2": {
        "oui_hex": "00-26-D2",
        "organization": "Pcube Systems, Inc.",
        "address_1": "1857 O'Toole Lane",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0026CD": {
        "oui_hex": "00-26-CD",
        "organization": "PurpleComm, Inc.",
        "address_1": "2620 Augustine Dr., Ste. 100",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002707": {
        "oui_hex": "00-27-07",
        "organization": "Lift Complex DS, JSC",
        "address_1": "mikrorayon Gorsky, 6",
        "address_2": "Novosibirsk    630073",
        "country": "RU"
    },
    "0026D7": {
        "oui_hex": "00-26-D7",
        "organization": "KM Electornic Technology Co., Ltd.",
        "address_1": "5F, NO.3 Building, NO.118 Rd. Baoan District, Shenzhen China",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "0026D0": {
        "oui_hex": "00-26-D0",
        "organization": "Semihalf",
        "address_1": "ul. Wadowicka 8A",
        "address_2": "Krakow  ...  30-415",
        "country": "PL"
    },
    "0026FE": {
        "oui_hex": "00-26-FE",
        "organization": "MKD Technology Inc.",
        "address_1": " R.B8, No.1 Lising 1st  Rd.,",
        "address_2": "Hsinchu    30078",
        "country": "TW"
    },
    "0026A0": {
        "oui_hex": "00-26-A0",
        "organization": "moblic",
        "address_1": "7F, 271-1, Seohyeon-dong, Bundang-gu",
        "address_2": "Seongnam-si  Kyeonggi-do  463-824",
        "country": "KR"
    },
    "0026E5": {
        "oui_hex": "00-26-E5",
        "organization": "AEG Power Solutions",
        "address_1": "Emil Siepmannstraße 32",
        "address_2": "Warstein  NRW  59581",
        "country": "DE"
    },
    "0026E3": {
        "oui_hex": "00-26-E3",
        "organization": "DTI",
        "address_1": "Rue de la gare, 35",
        "address_2": "NANINNE  NAMUR  5100",
        "country": "BE"
    },
    "0026BC": {
        "oui_hex": "00-26-BC",
        "organization": "General Jack Technology Ltd.",
        "address_1": "The Area of Administration of Lian Bei,",
        "address_2": "Dong Guan  Guang Dong  523580",
        "country": "CN"
    },
    "002696": {
        "oui_hex": "00-26-96",
        "organization": "NOOLIX Co., Ltd",
        "address_1": "DAECHANG B/D 3F, 8-2 SUNAE-DONG",
        "address_2": "SUNGNAM-SI  KYUNGGI-DO  463-825",
        "country": "KR"
    },
    "00269A": {
        "oui_hex": "00-26-9A",
        "organization": "Carina System Co., Ltd.",
        "address_1": "2-2-11 Kotonoo-cho",
        "address_2": "Kobe  Hyogo  651-0094",
        "country": "JP"
    },
    "002695": {
        "oui_hex": "00-26-95",
        "organization": "ZT Group Int'l Inc",
        "address_1": "350 Meadowlands Parkway",
        "address_2": "Secaucus  NJ  07094",
        "country": "US"
    },
    "002693": {
        "oui_hex": "00-26-93",
        "organization": "QVidium Technologies, Inc.",
        "address_1": "12989 Chaparral Ridge Rd",
        "address_2": "San Diego  CA  92130",
        "country": "US"
    },
    "002665": {
        "oui_hex": "00-26-65",
        "organization": "ProtectedLogic Corporation",
        "address_1": "PO Box 67707",
        "address_2": "Albuquerque  NM  87193",
        "country": "US"
    },
    "002660": {
        "oui_hex": "00-26-60",
        "organization": "Logiways",
        "address_1": "24/26 rue Louis ARMAND",
        "address_2": "PARIS    75015",
        "country": "FR"
    },
    "002670": {
        "oui_hex": "00-26-70",
        "organization": "Cinch Connectors",
        "address_1": "1700 Finley Road",
        "address_2": "Lombard  IL  60148",
        "country": "US"
    },
    "002671": {
        "oui_hex": "00-26-71",
        "organization": "AUTOVISION Co., Ltd",
        "address_1": "Shinsegae YBS Bldg. 102",
        "address_2": "Seongdong-gu  Seoul  133-847",
        "country": "KR"
    },
    "002648": {
        "oui_hex": "00-26-48",
        "organization": "Emitech Corp.",
        "address_1": "No. 156-5A, ChengGong 1st St.,",
        "address_2": "Jhubei City  Hsinchu County  302",
        "country": "TW"
    },
    "002645": {
        "oui_hex": "00-26-45",
        "organization": "Circontrol S.A.",
        "address_1": "Lepant 43",
        "address_2": "Terrassa  Barcelona  08223",
        "country": "ES"
    },
    "00263E": {
        "oui_hex": "00-26-3E",
        "organization": "Trapeze Networks",
        "address_1": "5753 West Las Positas Blvd.",
        "address_2": "Pleasanton  California  94588",
        "country": "US"
    },
    "00263C": {
        "oui_hex": "00-26-3C",
        "organization": "Bachmann Technology GmbH & Co. KG",
        "address_1": "Ernsthaldenstrasse 33",
        "address_2": "Stuttgart  BW  70565",
        "country": "DE"
    },
    "00263D": {
        "oui_hex": "00-26-3D",
        "organization": "MIA Corporation",
        "address_1": "1-3-15 Yoshino-cho, Minami-ku",
        "address_2": "Yokohama  Kanagawa  232-0014",
        "country": "JP"
    },
    "002678": {
        "oui_hex": "00-26-78",
        "organization": "Logic Instrument SA",
        "address_1": "43, Avenue de l'Europe",
        "address_2": "Domont    95330",
        "country": "FR"
    },
    "002677": {
        "oui_hex": "00-26-77",
        "organization": "DEIF A/S",
        "address_1": "Frisenborgvej 33",
        "address_2": "Skive    7800",
        "country": "DK"
    },
    "00268E": {
        "oui_hex": "00-26-8E",
        "organization": "Alta Solutions, Inc.",
        "address_1": "11305 Rancho Bernardo Road",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "002688": {
        "oui_hex": "00-26-88",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0025DA": {
        "oui_hex": "00-25-DA",
        "organization": "Secura Key",
        "address_1": "20301 Nordhoff St.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "0025DB": {
        "oui_hex": "00-25-DB",
        "organization": "ATI Electronics(Shenzhen) Co., LTD",
        "address_1": "2F,1st Buliding,Tangyanshan Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "0025D5": {
        "oui_hex": "00-25-D5",
        "organization": "Robonica (Pty) Ltd",
        "address_1": "41 Park Avenue North",
        "address_2": "Centurion  Gauteng  0046",
        "country": "ZA"
    },
    "0025E2": {
        "oui_hex": "00-25-E2",
        "organization": "Everspring Industry Co., Ltd.",
        "address_1": "7F., No. 609, Sec 1, Wanshou Rd.,",
        "address_2": "Gueishan Township  Taoyuan County  333",
        "country": "TW"
    },
    "0025E1": {
        "oui_hex": "00-25-E1",
        "organization": "SHANGHAI SEEYOO ELECTRONIC & TECHNOLOGY CO., LTD",
        "address_1": "RM701,XIN'AN BUILDING,99 TIANZHOU RD,XUHUI DISTRICT,SHANGHAI",
        "address_2": "SHANGHAI    200233",
        "country": "CN"
    },
    "00260E": {
        "oui_hex": "00-26-0E",
        "organization": "Ablaze Systems, LLC",
        "address_1": "523 West Valley Road",
        "address_2": "Wayne  Pennsylvania  19087",
        "country": "US"
    },
    "002610": {
        "oui_hex": "00-26-10",
        "organization": "Apacewave Technologies",
        "address_1": "48389 Fremont Blvd, STE#100",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00260D": {
        "oui_hex": "00-26-0D",
        "organization": "Mercury Systems, Inc.",
        "address_1": "26 Hampshire Dr",
        "address_2": "Hudson  NH  03051",
        "country": "US"
    },
    "00260A": {
        "oui_hex": "00-26-0A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002632": {
        "oui_hex": "00-26-32",
        "organization": "Instrumentation Technologies d.d.",
        "address_1": "Velika pot 22",
        "address_2": "Solkan  Nova Gorica  5250",
        "country": "SI"
    },
    "00262E": {
        "oui_hex": "00-26-2E",
        "organization": "Chengdu Jiuzhou Electronic Technology Inc",
        "address_1": "A2 Building,Tianfu Software Park",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "00262C": {
        "oui_hex": "00-26-2C",
        "organization": "IKT Advanced Technologies s.r.o.",
        "address_1": "Piseckeho 334/19",
        "address_2": "Praha 5    15000",
        "country": "CZ"
    },
    "002629": {
        "oui_hex": "00-26-29",
        "organization": "Juphoon System Software Inc.",
        "address_1": "Room 910,Building 2",
        "address_2": "Ningbo  Zhejiang  315041",
        "country": "CN"
    },
    "002625": {
        "oui_hex": "00-26-25",
        "organization": "MediaSputnik",
        "address_1": "Yaroslavskoe shosse, 19,",
        "address_2": "Moscow    129337",
        "country": "RU"
    },
    "002626": {
        "oui_hex": "00-26-26",
        "organization": "Geophysical Survey Systems, Inc.",
        "address_1": "12 Industrial Way",
        "address_2": "Salem  NH  03079",
        "country": "US"
    },
    "0025CC": {
        "oui_hex": "00-25-CC",
        "organization": "Mobile Communications Korea Incorporated",
        "address_1": "1011-1012, Suwon High Venture Valley,",
        "address_2": "Suwon-si,  Gyeonggi-do,  441-360",
        "country": "KR"
    },
    "0025F9": {
        "oui_hex": "00-25-F9",
        "organization": "GMK electronic design GmbH",
        "address_1": "Daimlerstraße 8",
        "address_2": "Wernberg-Koeblitz  Bavaria  D-92533",
        "country": "DE"
    },
    "0025F7": {
        "oui_hex": "00-25-F7",
        "organization": "Ansaldo STS USA",
        "address_1": "1000 Technology Drive",
        "address_2": "Pittsburgh  PA  15219",
        "country": "US"
    },
    "00261B": {
        "oui_hex": "00-26-1B",
        "organization": "LAUREL BANK MACHINES CO., LTD.",
        "address_1": "12-6",
        "address_2": "Kita-Ku  Tokyo  114-0013",
        "country": "JP"
    },
    "002614": {
        "oui_hex": "00-26-14",
        "organization": "KTNF",
        "address_1": "204,Daeryungtechnotown1,327,Gasan-Dong,",
        "address_2": "Seoul    153-771",
        "country": "KR"
    },
    "002603": {
        "oui_hex": "00-26-03",
        "organization": "Shenzhen Wistar Technology Co., Ltd",
        "address_1": "Rm919, Science &Technology Service Center",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0025A6": {
        "oui_hex": "00-25-A6",
        "organization": "Central Network Solution Co., Ltd.",
        "address_1": "584-1, Pajang-Dong, JangAn-Gu",
        "address_2": "Suwon-Si,  Kyunggi-Do  440-854",
        "country": "KR"
    },
    "0025AA": {
        "oui_hex": "00-25-AA",
        "organization": "Beijing Soul Technology Co.,Ltd.",
        "address_1": "Room 606,Xinzheng Office Building",
        "address_2": "BEIJING    100089",
        "country": "CN"
    },
    "002588": {
        "oui_hex": "00-25-88",
        "organization": "Genie Industries, Inc.",
        "address_1": "18620 NE 67th Ct",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "002580": {
        "oui_hex": "00-25-80",
        "organization": "Equipson S.A.",
        "address_1": "Poligono Ind. L´Alteró",
        "address_2": "Silla  Valencia  46460",
        "country": "ES"
    },
    "0025BD": {
        "oui_hex": "00-25-BD",
        "organization": "Italdata Ingegneria dell'Idea S.p.A.",
        "address_1": "viale Eroi di Cefalonia 123",
        "address_2": "Roma    00128",
        "country": "IT"
    },
    "0025B7": {
        "oui_hex": "00-25-B7",
        "organization": "Costar  electronics, inc.,",
        "address_1": "3fl,-1 no 13,lane 120,nei-hu road sec.1,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00257D": {
        "oui_hex": "00-25-7D",
        "organization": "PointRed Telecom Private Ltd.",
        "address_1": "15F - 5., No. 1071, Zhongzheng Road,",
        "address_2": "Taoyuan City 330    330",
        "country": "TW"
    },
    "0025A2": {
        "oui_hex": "00-25-A2",
        "organization": "Alta Definicion LINCEO S.L.",
        "address_1": "Maria de Luna 11, nave 4",
        "address_2": "Zaragoza    Es-50018",
        "country": "ES"
    },
    "00256D": {
        "oui_hex": "00-25-6D",
        "organization": "Broadband Forum",
        "address_1": "48377 Fremont Boulevard",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00256C": {
        "oui_hex": "00-25-6C",
        "organization": "Azimut Production Association JSC",
        "address_1": "2-B Ataeva Street",
        "address_2": "Makhachkala  Dagestan  367005",
        "country": "RU"
    },
    "002563": {
        "oui_hex": "00-25-63",
        "organization": "Luxtera Inc",
        "address_1": "2320. Camino Vida Roble",
        "address_2": "Carlsbad  CA  92011",
        "country": "US"
    },
    "002593": {
        "oui_hex": "00-25-93",
        "organization": "DatNet Informatikai Kft.",
        "address_1": "Hétvezér u. 5.",
        "address_2": "Szigetszentmiklós  Pest megye  2310",
        "country": "HU"
    },
    "00258E": {
        "oui_hex": "00-25-8E",
        "organization": "The Weather Channel",
        "address_1": "Mail Stop 500",
        "address_2": "Atlanta  GA  30339",
        "country": "US"
    },
    "0025A3": {
        "oui_hex": "00-25-A3",
        "organization": "Trimax Wireless, Inc.",
        "address_1": "2675 S Horseshoe Dr",
        "address_2": "Naples  FL  34104",
        "country": "US"
    },
    "00259C": {
        "oui_hex": "00-25-9C",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "0025C8": {
        "oui_hex": "00-25-C8",
        "organization": "S-Access GmbH",
        "address_1": "Oberhausenstrasse 47",
        "address_2": "Wettswil a/A  Zuerich  8907",
        "country": "CH"
    },
    "0025C0": {
        "oui_hex": "00-25-C0",
        "organization": "ZillionTV Corporation",
        "address_1": "1170 Kifer Road",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "00251B": {
        "oui_hex": "00-25-1B",
        "organization": "Philips CareServant",
        "address_1": "High Tech Campus 27",
        "address_2": "Eindhoven  Noord-Brabant  5656 AE",
        "country": "NL"
    },
    "002518": {
        "oui_hex": "00-25-18",
        "organization": "Power PLUS Communications AG",
        "address_1": "Am Exerzierplatz 2",
        "address_2": "Mannheim  Baden Wuerttemberg  68167",
        "country": "DE"
    },
    "002515": {
        "oui_hex": "00-25-15",
        "organization": "SFR",
        "address_1": "42 Quai du point du jour",
        "address_2": "Boulogne billancourt  .  92659",
        "country": "FR"
    },
    "00250D": {
        "oui_hex": "00-25-0D",
        "organization": "GZT Telkom-Telmor sp. z o.o.",
        "address_1": "Mickiewicza 5/7",
        "address_2": "Gdansk  pomorskie  80-425",
        "country": "PL"
    },
    "00250E": {
        "oui_hex": "00-25-0E",
        "organization": "gt german telematics gmbh",
        "address_1": "Rankestrasse 26",
        "address_2": "Berlin    D-10789",
        "country": "DE"
    },
    "002531": {
        "oui_hex": "00-25-31",
        "organization": "Cloud Engines, Inc.",
        "address_1": "857 Montgomery Street",
        "address_2": "San Francisco  CA  94133",
        "country": "US"
    },
    "00252D": {
        "oui_hex": "00-25-2D",
        "organization": "Kiryung Electronics",
        "address_1": "Kiryung Bldg. 686-70, Sindaebang-dong",
        "address_2": "Seoul    156-010",
        "country": "KR"
    },
    "002545": {
        "oui_hex": "00-25-45",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002542": {
        "oui_hex": "00-25-42",
        "organization": "Pittasoft",
        "address_1": "#913 Daeryung Techno Town 8th 481-11ga",
        "address_2": "Geumcheon-gu  Seoul  153-775",
        "country": "KR"
    },
    "002536": {
        "oui_hex": "00-25-36",
        "organization": "Oki Electric Industry Co., Ltd.",
        "address_1": "1-16-8 Chuou",
        "address_2": "Warabi-shi  Saitama  335-8510",
        "country": "JP"
    },
    "002541": {
        "oui_hex": "00-25-41",
        "organization": "Maquet Critical Care AB",
        "address_1": "Röntgenvägen 2",
        "address_2": "Solna    SE-171 95",
        "country": "SE"
    },
    "00252B": {
        "oui_hex": "00-25-2B",
        "organization": "Stirling Energy Systems",
        "address_1": "Sandia National Labs - NSTTF",
        "address_2": "Albuquerque  NM  87185-1127",
        "country": "US"
    },
    "002524": {
        "oui_hex": "00-25-24",
        "organization": "Lightcomm Technology Co., Ltd",
        "address_1": "9/F.,Hi-Tech Venture Park Tower A,",
        "address_2": "ShenZhen  GuangDong  518040",
        "country": "CN"
    },
    "00254E": {
        "oui_hex": "00-25-4E",
        "organization": "Vertex Wireless Co., Ltd.",
        "address_1": "5F, Seohyeon Plaza, 254-5, Seohyeon-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-824",
        "country": "KR"
    },
    "002546": {
        "oui_hex": "00-25-46",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002522": {
        "oui_hex": "00-25-22",
        "organization": "ASRock Incorporation",
        "address_1": "2F., No. 37, Sec. 2, Jhongyang S. Rd., Beitou District,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "002560": {
        "oui_hex": "00-25-60",
        "organization": "Ibridge Networks & Communications Ltd.",
        "address_1": "28,Bedford Road East Ham",
        "address_2": "London    E6 2NN",
        "country": "GB"
    },
    "0024B8": {
        "oui_hex": "00-24-B8",
        "organization": "free alliance sdn bhd",
        "address_1": "B-3-2 Plaza Damas",
        "address_2": "Kuala Lumpur  WP  50480",
        "country": "MY"
    },
    "0024B3": {
        "oui_hex": "00-24-B3",
        "organization": "Graf-Syteco GmbH & Co. KG",
        "address_1": "Kaiserstraße 18",
        "address_2": "Tuningen  Baden-Württemberg  78609",
        "country": "DE"
    },
    "0024F6": {
        "oui_hex": "00-24-F6",
        "organization": "MIYOSHI ELECTRONICS CORPORATION",
        "address_1": "3-13-21 KUSHIRO",
        "address_2": "KAWANISHI-CITY  HYOGO-PREF.  666-0024",
        "country": "JP"
    },
    "0024F0": {
        "oui_hex": "00-24-F0",
        "organization": "Seanodes",
        "address_1": "Batiment Platon",
        "address_2": "Colomiers    31770",
        "country": "FR"
    },
    "0024CB": {
        "oui_hex": "00-24-CB",
        "organization": "Autonet Mobile",
        "address_1": "2235 Mercury Way Ste. 145",
        "address_2": "Santa Rosa  CA  95407",
        "country": "US"
    },
    "0024D1": {
        "oui_hex": "00-24-D1",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290",
        "country": "US"
    },
    "0024C9": {
        "oui_hex": "00-24-C9",
        "organization": "Broadband Solutions Group",
        "address_1": "1101 Marina Village Parkway",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "0024CA": {
        "oui_hex": "00-24-CA",
        "organization": "Tobii Technology AB",
        "address_1": "Karlsrovägen 2D",
        "address_2": "Danderyd    18253",
        "country": "SE"
    },
    "002508": {
        "oui_hex": "00-25-08",
        "organization": "Maquet Cardiopulmonary AG",
        "address_1": "Hechinger Strasse 38",
        "address_2": "Hirrlingen    72145",
        "country": "DE"
    },
    "0024FC": {
        "oui_hex": "00-24-FC",
        "organization": "QuoPin Co., Ltd.",
        "address_1": "#109, R&D Center for Advanced Technology 68 Yatap-dong Bundang-gu",
        "address_2": "Seongnam  Kyungki-do  463-816",
        "country": "KR"
    },
    "0024FB": {
        "oui_hex": "00-24-FB",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0024FA": {
        "oui_hex": "00-24-FA",
        "organization": "Hilger u. Kern GMBH",
        "address_1": "Kaefertaler Strasse 253-255",
        "address_2": "Mannheim  Baden-Württemberg  68167",
        "country": "DE"
    },
    "0024D0": {
        "oui_hex": "00-24-D0",
        "organization": "Shenzhen SOGOOD Industry CO.,LTD.",
        "address_1": "SOGOOD Science Park,Aviation Road,XiXiang Town,Bao'an District,",
        "address_2": "Shenzhen  Guangzhou  518102",
        "country": "CN"
    },
    "0024CC": {
        "oui_hex": "00-24-CC",
        "organization": "Fascinations Toys and Gifts, Inc.",
        "address_1": "19224 Des Moines Way S",
        "address_2": "Seattle  Washington  98148",
        "country": "US"
    },
    "0024C7": {
        "oui_hex": "00-24-C7",
        "organization": "Mobilarm Ltd",
        "address_1": "768 Canning Highway",
        "address_2": "  Western Australia  6153",
        "country": "AU"
    },
    "0024DF": {
        "oui_hex": "00-24-DF",
        "organization": "Digitalbox Europe GmbH",
        "address_1": "Sandstraße 65",
        "address_2": "Ratingen    40878",
        "country": "DE"
    },
    "002445": {
        "oui_hex": "00-24-45",
        "organization": "Adtran Inc",
        "address_1": "901 Explorer Blvd.",
        "address_2": "Huntsville  AL  35806-2807",
        "country": "US"
    },
    "00243F": {
        "oui_hex": "00-24-3F",
        "organization": "Storwize, Inc.",
        "address_1": "11 Alatlef St.",
        "address_2": "Yehud    56216",
        "country": "IL"
    },
    "002497": {
        "oui_hex": "00-24-97",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0024A3": {
        "oui_hex": "00-24-A3",
        "organization": "Sonim Technologies Inc",
        "address_1": "1875 S.Grant Street",
        "address_2": "Sanmateo  CA  94402",
        "country": "US"
    },
    "0024AA": {
        "oui_hex": "00-24-AA",
        "organization": "Dycor Technologies Ltd.",
        "address_1": "1851 94 Street",
        "address_2": "Edmonton  Alberta  T6N 1E6",
        "country": "CA"
    },
    "0024A9": {
        "oui_hex": "00-24-A9",
        "organization": "Ag Leader Technology",
        "address_1": "2202 S Riverside Dr.",
        "address_2": "Ames  IA  50010",
        "country": "US"
    },
    "0024A6": {
        "oui_hex": "00-24-A6",
        "organization": "TELESTAR DIGITAL GmbH",
        "address_1": "Vulkanhöhe / B410",
        "address_2": "Dreis-Brück    54552",
        "country": "DE"
    },
    "00249B": {
        "oui_hex": "00-24-9B",
        "organization": "Action Star Enterprise Co., Ltd.",
        "address_1": "10F, No.159, Sec.2, Datong Rd.",
        "address_2": "Xizhi Dist.  New Taipei City  221",
        "country": "TW"
    },
    "002471": {
        "oui_hex": "00-24-71",
        "organization": "Fusion MultiSystems dba Fusion-io",
        "address_1": "6350 S. 3000 E., 6th floor",
        "address_2": "Salt lake City  UT  84121",
        "country": "US"
    },
    "002474": {
        "oui_hex": "00-24-74",
        "organization": "Autronica Fire And Securirty",
        "address_1": "Haakon VII's g.4",
        "address_2": "  Trondheim  N-7483",
        "country": "NO"
    },
    "002446": {
        "oui_hex": "00-24-46",
        "organization": "MMB Research Inc.",
        "address_1": "35 Prince Arthur Ave.",
        "address_2": "Toronto  Ontario  M5R 1B2",
        "country": "CA"
    },
    "002463": {
        "oui_hex": "00-24-63",
        "organization": "Phybridge Inc",
        "address_1": "3495 Laird Rd",
        "address_2": "Mississauga  Ontario  L5L5S5",
        "country": "CA"
    },
    "002472": {
        "oui_hex": "00-24-72",
        "organization": "ReDriven Power Inc.",
        "address_1": "24A Bath Rd.",
        "address_2": "Iroquois  Ontario  K0E 1K0",
        "country": "CA"
    },
    "00241C": {
        "oui_hex": "00-24-1C",
        "organization": "FuGang Electronic (DG) Co.,Ltd",
        "address_1": "Industry Street, Dong-Keng",
        "address_2": "Dong Guan City    523448",
        "country": "CN"
    },
    "002419": {
        "oui_hex": "00-24-19",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002415": {
        "oui_hex": "00-24-15",
        "organization": "Magnetic Autocontrol GmbH",
        "address_1": "Grienmatt 20",
        "address_2": "Schopfheim    D-79650",
        "country": "DE"
    },
    "0023E7": {
        "oui_hex": "00-23-E7",
        "organization": "Hinke A/S",
        "address_1": "Tingbjergvej 2",
        "address_2": "Bjaeverskov    DK-4632",
        "country": "DK"
    },
    "0023E2": {
        "oui_hex": "00-23-E2",
        "organization": "SEA Signalisation",
        "address_1": "20-22 Rue Pierre Mendès France",
        "address_2": "Vaulx en Velin CEDEX    69515",
        "country": "FR"
    },
    "002425": {
        "oui_hex": "00-24-25",
        "organization": "Shenzhenshi chuangzhicheng Technology Co.,Ltd",
        "address_1": "5th Floor,Block2,25th Building,Industrial Zone West Keyuan Sci-tech Garden Nanshan Districh,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002427": {
        "oui_hex": "00-24-27",
        "organization": "SSI COMPUTER CORP",
        "address_1": "4F, NO4, LANE 235, BAO CHIAO ROAD",
        "address_2": "HSIN TIEN  TAIPEI  231",
        "country": "TW"
    },
    "002411": {
        "oui_hex": "00-24-11",
        "organization": "PharmaSmart LLC",
        "address_1": "3495 Winton Place",
        "address_2": "Rochester  NY  14623",
        "country": "US"
    },
    "00240F": {
        "oui_hex": "00-24-0F",
        "organization": "Ishii Tool & Engineering Corporation",
        "address_1": "2-5-60 Higashi-Omichi",
        "address_2": "Oita    870-0823",
        "country": "JP"
    },
    "0023FA": {
        "oui_hex": "00-23-FA",
        "organization": "RG Nets, Inc.",
        "address_1": "316 California Ave.",
        "address_2": "Reno  NV  89501",
        "country": "US"
    },
    "0023F2": {
        "oui_hex": "00-23-F2",
        "organization": "TVLogic",
        "address_1": "suite 914 ACE Techno Tower-9th",
        "address_2": "Geumcheon-gu  SEOUL  153-782",
        "country": "KR"
    },
    "00240A": {
        "oui_hex": "00-24-0A",
        "organization": "US Beverage Net",
        "address_1": "1001 W. Fayette Street",
        "address_2": "Syracuse  NY  13204",
        "country": "US"
    },
    "002407": {
        "oui_hex": "00-24-07",
        "organization": "TELEM SAS",
        "address_1": "16, RUE DE L'ETANG",
        "address_2": "GIERES  RHONE ALPES  38610",
        "country": "FR"
    },
    "002440": {
        "oui_hex": "00-24-40",
        "organization": "Halo Monitoring, Inc.",
        "address_1": "515 Sparkman Dr.",
        "address_2": "Huntsville  AL  35816",
        "country": "US"
    },
    "0023CF": {
        "oui_hex": "00-23-CF",
        "organization": "CUMMINS-ALLISON CORP.",
        "address_1": "891 FEEHANVILLE DRIVE",
        "address_2": "MT. PROSPECT  IL  60056",
        "country": "US"
    },
    "0023C2": {
        "oui_hex": "00-23-C2",
        "organization": "SAMSUNG Electronics. Co. LTD",
        "address_1": "19th Fl., Korea Life Bldg. 1338-12",
        "address_2": "Seoul    137-860",
        "country": "KR"
    },
    "0023C4": {
        "oui_hex": "00-23-C4",
        "organization": "Lux Lumen",
        "address_1": "Kernenergiestraat 53A",
        "address_2": "Wilrijk  Antwerp  2610",
        "country": "BE"
    },
    "0023C5": {
        "oui_hex": "00-23-C5",
        "organization": "Radiation Safety and Control Services Inc",
        "address_1": "91 Portsmouth Ave",
        "address_2": "Stratham  New Hampshire  03885",
        "country": "US"
    },
    "0023C6": {
        "oui_hex": "00-23-C6",
        "organization": "SMC Corporation",
        "address_1": "4-2-2, Kinunodai",
        "address_2": "Tsukuba Mirai-shi  Ibaraki-ken  300-2493",
        "country": "JP"
    },
    "002388": {
        "oui_hex": "00-23-88",
        "organization": "V.T. Telematica S.p.a.",
        "address_1": "Via Gorky, 21",
        "address_2": "San Giuliano Milanese  Milano  20098",
        "country": "IT"
    },
    "002386": {
        "oui_hex": "00-23-86",
        "organization": "Tour & Andersson AB",
        "address_1": "Annelund",
        "address_2": "Ljung    524 80",
        "country": "US"
    },
    "002383": {
        "oui_hex": "00-23-83",
        "organization": "InMage Systems Inc",
        "address_1": "3255-1 Scott Blvd, #104",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002381": {
        "oui_hex": "00-23-81",
        "organization": "Lengda Technology(Xiamen) Co.,Ltd.",
        "address_1": "5/F, 47 Haijing South 2nd Road,Xiamen Export Processing Zone, Haicang District,",
        "address_2": "Xiamen  Fujian  361026",
        "country": "CN"
    },
    "0023BF": {
        "oui_hex": "00-23-BF",
        "organization": "Mainpine, Inc.",
        "address_1": "PO Box 241",
        "address_2": "Wilsonville  Oregon  97070-0241",
        "country": "US"
    },
    "0023B2": {
        "oui_hex": "00-23-B2",
        "organization": "Intelligent Mechatronic Systems Inc",
        "address_1": "161 Roger Street",
        "address_2": "Waterloo  Ontario  N2J 1B1",
        "country": "CA"
    },
    "0023B5": {
        "oui_hex": "00-23-B5",
        "organization": "ORTANA LTD",
        "address_1": "OSTIM KOCASINAN SANAYI SITESI",
        "address_2": "ANKARA    06370",
        "country": "TR"
    },
    "0023B9": {
        "oui_hex": "00-23-B9",
        "organization": " Airbus Defence and Space Deutschland GmbH",
        "address_1": "Willy-Messerschmitt-Strasse 1,",
        "address_2": "Taufkirchen    82024",
        "country": "DE"
    },
    "0023BD": {
        "oui_hex": "00-23-BD",
        "organization": "Digital Ally, Inc.",
        "address_1": "1218 Valley Ridge Drive",
        "address_2": "Grain Valley  MO  64029",
        "country": "US"
    },
    "0023D5": {
        "oui_hex": "00-23-D5",
        "organization": "WAREMA electronic GmbH",
        "address_1": "Dillberg 33",
        "address_2": "Marktheidenfeld  Bavaria  97828",
        "country": "DE"
    },
    "0023C9": {
        "oui_hex": "00-23-C9",
        "organization": "Sichuan Tianyi Information Science & Technology Stock CO.,LTD",
        "address_1": "No.1,Hot Spring Highway,Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "US"
    },
    "0023CE": {
        "oui_hex": "00-23-CE",
        "organization": "KITA DENSHI CORPORATION",
        "address_1": "12F TOKYO-NISHIIKEBUKURO Bilg.,",
        "address_2": "Toshima-ku,  Tokyo  171-0021",
        "country": "JP"
    },
    "0023A9": {
        "oui_hex": "00-23-A9",
        "organization": "Beijing Detianquan Electromechanical Equipment Co., Ltd",
        "address_1": "No. 2 Chapeng Road, Haidian District,",
        "address_2": "Beijing    100091",
        "country": "CN"
    },
    "0023A7": {
        "oui_hex": "00-23-A7",
        "organization": "Redpine Signals, Inc.",
        "address_1": "Plot 87, Sagar Society",
        "address_2": "Hyderabad  AP  500034",
        "country": "IN"
    },
    "00239B": {
        "oui_hex": "00-23-9B",
        "organization": "Elster Solutions, LLC",
        "address_1": "208 South Rogers Lane",
        "address_2": "Raleigh  North Carolina  27610",
        "country": "US"
    },
    "00237B": {
        "oui_hex": "00-23-7B",
        "organization": "WHDI LLC",
        "address_1": "2350 Mission College Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002324": {
        "oui_hex": "00-23-24",
        "organization": "G-PRO COMPUTER",
        "address_1": "first arrange C, YingHu industrial estate",
        "address_2": "DongGuan City  GuangDong Province  523648",
        "country": "CN"
    },
    "0023E0": {
        "oui_hex": "00-23-E0",
        "organization": "INO Therapeutics LLC",
        "address_1": "2902 Dairy Drive",
        "address_2": "Madison  WI  53718",
        "country": "US"
    },
    "002390": {
        "oui_hex": "00-23-90",
        "organization": "Algolware Corporation",
        "address_1": "13F-5, No. 77, Sec. 1, Sintai 5th Rd.,",
        "address_2": "Taipei County  Taiwan  221",
        "country": "TW"
    },
    "002311": {
        "oui_hex": "00-23-11",
        "organization": "Gloscom Co., Ltd.",
        "address_1": "#507 Changhyun Bldg.",
        "address_2": "Anyang City  Kyunggo-do  431-080",
        "country": "KR"
    },
    "002309": {
        "oui_hex": "00-23-09",
        "organization": "Janam Technologies LLC",
        "address_1": "100 Crossways Park West",
        "address_2": "Woodbury  NY  11797",
        "country": "US"
    },
    "002304": {
        "oui_hex": "00-23-04",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00235D": {
        "oui_hex": "00-23-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00235C": {
        "oui_hex": "00-23-5C",
        "organization": "Aprius, Inc.",
        "address_1": "440 N. Wolfe Rd",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "002352": {
        "oui_hex": "00-23-52",
        "organization": "DATASENSOR S.p.A.",
        "address_1": "Via Lavino, 265",
        "address_2": "Monte San Pietro (BO)    40050",
        "country": "IT"
    },
    "00232F": {
        "oui_hex": "00-23-2F",
        "organization": "Advanced Card Systems Ltd.",
        "address_1": "Unit 2010-13, Chevalier Commercial Centre,",
        "address_2": "Kowloon Bay,  SAR",
        "country": "HK"
    },
    "002353": {
        "oui_hex": "00-23-53",
        "organization": "F E T Elettronica snc",
        "address_1": "Via Alessandro Manzoni 14/a",
        "address_2": "Poggibonsi  Siena  53036",
        "country": "IT"
    },
    "002342": {
        "oui_hex": "00-23-42",
        "organization": "Coffee Equipment Company",
        "address_1": "4216 6th Ave NW",
        "address_2": "Seattle  WA  98107",
        "country": "US"
    },
    "002337": {
        "oui_hex": "00-23-37",
        "organization": "Global Star Solutions ULC",
        "address_1": "4600 Jacombs Road",
        "address_2": "Richmond  BC  V6V 3B1",
        "country": "CA"
    },
    "002319": {
        "oui_hex": "00-23-19",
        "organization": "Sielox LLC",
        "address_1": "170 East Ninth Ave.",
        "address_2": "Runnemede  NJ  08078",
        "country": "US"
    },
    "00236A": {
        "oui_hex": "00-23-6A",
        "organization": "SmartRG Inc",
        "address_1": "501 SE Columbia Shores Blvd",
        "address_2": "Vancouver  WA  98661",
        "country": "US"
    },
    "002331": {
        "oui_hex": "00-23-31",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002335": {
        "oui_hex": "00-23-35",
        "organization": "Linkflex Co.,Ltd",
        "address_1": "5F. Min Young Bldg. 175-2",
        "address_2": "Seoul    135-010",
        "country": "KR"
    },
    "002325": {
        "oui_hex": "00-23-25",
        "organization": "IOLAN Holding",
        "address_1": "Mon Plaisir 26",
        "address_2": "Etten Leur    4879AN",
        "country": "NL"
    },
    "002321": {
        "oui_hex": "00-23-21",
        "organization": "Avitech International Corp",
        "address_1": "15333 NE 90th Street",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "002370": {
        "oui_hex": "00-23-70",
        "organization": "Snell",
        "address_1": "Hartman House",
        "address_2": "Reading  Berks  RG6 4PB",
        "country": "GB"
    },
    "0022B9": {
        "oui_hex": "00-22-B9",
        "organization": "Analogix Seminconductor, Inc",
        "address_1": "3211 Scott Blvd., Suite 100",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0022B8": {
        "oui_hex": "00-22-B8",
        "organization": "Norcott",
        "address_1": "Brookfield House, Grimsditch Lane off Tarporley Road",
        "address_2": "Cheshire    WA4 4EA",
        "country": "GB"
    },
    "0022B7": {
        "oui_hex": "00-22-B7",
        "organization": "GSS Grundig SAT-Systems GmbH",
        "address_1": "Beutherner Strasse 43",
        "address_2": "Nuernberg  Bayern  90471",
        "country": "DE"
    },
    "0022B3": {
        "oui_hex": "00-22-B3",
        "organization": "Sei S.p.A.",
        "address_1": "Via Ruffilli, 1",
        "address_2": "Curno  Bergamo  24035",
        "country": "IT"
    },
    "00229C": {
        "oui_hex": "00-22-9C",
        "organization": "Verismo Networks Inc",
        "address_1": "295 Bernando Avenue",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "00229A": {
        "oui_hex": "00-22-9A",
        "organization": "Lastar, Inc.",
        "address_1": "3555 Kettering BLVD.",
        "address_2": "Moraine  Ohio  45439",
        "country": "US"
    },
    "0022EE": {
        "oui_hex": "00-22-EE",
        "organization": "Algo Communication Products Ltd",
        "address_1": "4500 Beedie Street",
        "address_2": "Burnaby  BC  V5J 5L2",
        "country": "CA"
    },
    "0022EA": {
        "oui_hex": "00-22-EA",
        "organization": "Rustelcom Inc.",
        "address_1": "Garagniy proezd, 1",
        "address_2": "St.-Petersburg    192288",
        "country": "RU"
    },
    "0022F0": {
        "oui_hex": "00-22-F0",
        "organization": "3 Greens Aviation Limited",
        "address_1": "10 Hedingham Close",
        "address_2": "Macclesfield    SK10 3LZ",
        "country": "GB"
    },
    "0022EC": {
        "oui_hex": "00-22-EC",
        "organization": "IDEALBT TECHNOLOGY CORPORATION",
        "address_1": "6F., NO.8, LANE 345, YANGGUANG ST., NEIHU DISTRICT",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0022DD": {
        "oui_hex": "00-22-DD",
        "organization": "Protecta Electronics Ltd",
        "address_1": "Kesmark str 7/A",
        "address_2": "Budapest  Hungary  1158",
        "country": "HU"
    },
    "0022AB": {
        "oui_hex": "00-22-AB",
        "organization": "Shenzhen Turbosight Technology Ltd",
        "address_1": "Unit C-8A,Shennan Garden Bldg,Hightech Park,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00229B": {
        "oui_hex": "00-22-9B",
        "organization": "AverLogic Technologies, Inc.",
        "address_1": "7F-2, No.2, Lane 258, Rui Guang Rd., Nei-Hu Dist.,",
        "address_2": "Taipei  Taiwan  114",
        "country": "TW"
    },
    "0022BE": {
        "oui_hex": "00-22-BE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0022BF": {
        "oui_hex": "00-22-BF",
        "organization": "SieAmp Group of Companies",
        "address_1": "2 Ang Mo Kio Street 64",
        "address_2": "Singapore    569084",
        "country": "US"
    },
    "0022DB": {
        "oui_hex": "00-22-DB",
        "organization": "Translogic Corporation",
        "address_1": "10825 E. 47th Avenue",
        "address_2": "Denver  Colorado  80239",
        "country": "US"
    },
    "0022DA": {
        "oui_hex": "00-22-DA",
        "organization": "ANATEK, LLC",
        "address_1": "3219 East Camelback Road",
        "address_2": "Phoenix  AZ  85018",
        "country": "US"
    },
    "0022F9": {
        "oui_hex": "00-22-F9",
        "organization": "Pollin Electronic GmbH",
        "address_1": "Max-Pollin-Str. 1",
        "address_2": "Pfoerring    85104",
        "country": "DE"
    },
    "0022C5": {
        "oui_hex": "00-22-C5",
        "organization": "INFORSON Co,Ltd.",
        "address_1": "Room 704,Tower B1, ChangYuanTianDi Plaza",
        "address_2": "BeiJing City    100080",
        "country": "CN"
    },
    "002262": {
        "oui_hex": "00-22-62",
        "organization": "BEP Marine",
        "address_1": "13 Tarndale Grove Albany",
        "address_2": "Auckland    0632",
        "country": "NZ"
    },
    "00226A": {
        "oui_hex": "00-22-6A",
        "organization": "Honeywell",
        "address_1": "8840 Evergreen Blvd.",
        "address_2": "Minneapolis  MN  55433-6040",
        "country": "US"
    },
    "002263": {
        "oui_hex": "00-22-63",
        "organization": "Koos Technical Services, Inc.",
        "address_1": "1025 Greenwood Blvd.",
        "address_2": "Lake Mary  FL  32746",
        "country": "US"
    },
    "00226C": {
        "oui_hex": "00-22-6C",
        "organization": "LinkSprite Technologies, Inc.",
        "address_1": "1410 Cannon Mountain Dr",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "00225C": {
        "oui_hex": "00-22-5C",
        "organization": "Multimedia & Communication Technology",
        "address_1": "Digital Empire D-801 #980-3",
        "address_2": "Suwon-City  KyeongGi-Do  443-813",
        "country": "KR"
    },
    "002284": {
        "oui_hex": "00-22-84",
        "organization": "DESAY A&V SCIENCE AND TECHNOLOGY CO.,LTD",
        "address_1": "DESAY 3rd Zone,Chenjiang,",
        "address_2": "Huizhou  Guangdong  516229",
        "country": "CN"
    },
    "002286": {
        "oui_hex": "00-22-86",
        "organization": "ASTRON",
        "address_1": "Oudehoogeveensedijk 4",
        "address_2": "Dwingeloo  Drenthe  7991PD",
        "country": "NL"
    },
    "002282": {
        "oui_hex": "00-22-82",
        "organization": "8086 Consultancy",
        "address_1": "17 Lowfield Lane",
        "address_2": "Newark  Notts  NG24 3HJ",
        "country": "GB"
    },
    "002246": {
        "oui_hex": "00-22-46",
        "organization": "Evoc Intelligent Technology Co.,Ltd.",
        "address_1": "No.31 Gaoxin Centeral Avenue 4th Road,Nanshan District Shenzhen City",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002248": {
        "oui_hex": "00-22-48",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "002290": {
        "oui_hex": "00-22-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00228A": {
        "oui_hex": "00-22-8A",
        "organization": "Teratronik elektronische systeme gmbh",
        "address_1": "Karl-Ulrich-Strasse 1",
        "address_2": "Gross-Umstadt    D-64823",
        "country": "DE"
    },
    "00228E": {
        "oui_hex": "00-22-8E",
        "organization": "TV-NUMERIC",
        "address_1": "24-26 rue Louis Armand",
        "address_2": "Paris    75015",
        "country": "FR"
    },
    "002254": {
        "oui_hex": "00-22-54",
        "organization": "Bigelow Aerospace",
        "address_1": "1899 W. Brooks Ave",
        "address_2": "North Las Vegas  NV  89032",
        "country": "US"
    },
    "002257": {
        "oui_hex": "00-22-57",
        "organization": "3COM EUROPE LTD",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  HERTS.  HP2 4NW",
        "country": "GB"
    },
    "002276": {
        "oui_hex": "00-22-76",
        "organization": "Triple EYE B.V.",
        "address_1": "Vaassenseweg 71",
        "address_2": "Emst    8166 AT",
        "country": "NL"
    },
    "002274": {
        "oui_hex": "00-22-74",
        "organization": "FamilyPhone AB",
        "address_1": "Anckargripsgatan 3",
        "address_2": "Malmö    21119",
        "country": "SE"
    },
    "002236": {
        "oui_hex": "00-22-36",
        "organization": "VECTOR SP. Z O.O.",
        "address_1": "KRZEMOWA 6",
        "address_2": "GDYNIA    81-577",
        "country": "PL"
    },
    "002230": {
        "oui_hex": "00-22-30",
        "organization": "FutureLogic Inc.",
        "address_1": "425 E. Colorado St., Ste. 100",
        "address_2": "Glendale  CA  91205",
        "country": "US"
    },
    "00222E": {
        "oui_hex": "00-22-2E",
        "organization": "maintech GmbH",
        "address_1": "Seeweg 60",
        "address_2": "Höchberg  Bavaria  97204",
        "country": "DE"
    },
    "002214": {
        "oui_hex": "00-22-14",
        "organization": "RINNAI KOREA",
        "address_1": "560-2, Shibjong-1dong, Pupyoung-gu",
        "address_2": "Pupyoung-gu  Incheon  403-847",
        "country": "KR"
    },
    "00220B": {
        "oui_hex": "00-22-0B",
        "organization": "National Source Coding Center",
        "address_1": "Suite 701,Power Creative A,No.1",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "00220C": {
        "oui_hex": "00-22-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0021EA": {
        "oui_hex": "00-21-EA",
        "organization": "Bystronic Laser AG",
        "address_1": "Industriestrasse 21",
        "address_2": "3362  Niederönz",
        "country": "CH"
    },
    "0021FD": {
        "oui_hex": "00-21-FD",
        "organization": "LACROIX TRAFFIC S.A.U",
        "address_1": "Majada 4",
        "address_2": "Tres Cantos  Madrid  28760",
        "country": "ES"
    },
    "0021CD": {
        "oui_hex": "00-21-CD",
        "organization": "LiveTV",
        "address_1": "1333 Gateway Drive, Suite 1007",
        "address_2": "Melbourne  Florida  32901",
        "country": "US"
    },
    "0021D0": {
        "oui_hex": "00-21-D0",
        "organization": "Global Display Solutions Spa",
        "address_1": "Via Tezze, 20/A",
        "address_2": "Cornedo Vicentino  Vicenza  36073",
        "country": "IT"
    },
    "002228": {
        "oui_hex": "00-22-28",
        "organization": "Breeze Innovations Ltd.",
        "address_1": "Har Hotzvim, P.O. Box 45397",
        "address_2": "Jerusalem  Israel  91451",
        "country": "IL"
    },
    "002229": {
        "oui_hex": "00-22-29",
        "organization": "Compumedics Ltd",
        "address_1": "30 - 40 Flockhart Street",
        "address_2": "Abbotsford  Victoria  3067",
        "country": "AU"
    },
    "002216": {
        "oui_hex": "00-22-16",
        "organization": "SHIBAURA VENDING MACHINE CORPORATION",
        "address_1": "Ekimae-cho13-10",
        "address_2": "Obama-shi  Fukui-ken  917-0077",
        "country": "JP"
    },
    "0021E1": {
        "oui_hex": "00-21-E1",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002200": {
        "oui_hex": "00-22-00",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0021C6": {
        "oui_hex": "00-21-C6",
        "organization": "CSJ Global, Inc.",
        "address_1": "9th Fl. Samwhan Bldg. Annex, 17-26 Yeouido-dong,",
        "address_2": "Seoul    150-874",
        "country": "KR"
    },
    "0021C3": {
        "oui_hex": "00-21-C3",
        "organization": "CORNELL Communications, Inc.",
        "address_1": "7915 N. 81st Street",
        "address_2": "Milwaukee  Wisconsin  53223",
        "country": "US"
    },
    "0021C7": {
        "oui_hex": "00-21-C7",
        "organization": "Russound",
        "address_1": "5 Forbes Road",
        "address_2": "Newmarket  NH  03857",
        "country": "US"
    },
    "0021C1": {
        "oui_hex": "00-21-C1",
        "organization": "ABB Oy / Medium Voltage Products",
        "address_1": "PO Box 699",
        "address_2": "Vaasa    FI-65101",
        "country": "FI"
    },
    "0021C0": {
        "oui_hex": "00-21-C0",
        "organization": "Mobile Appliance, Inc.",
        "address_1": "#819 Kranz Techno,",
        "address_2": "Seong nam  Gyeonggi-Do  462-729",
        "country": "KR"
    },
    "0021BB": {
        "oui_hex": "00-21-BB",
        "organization": "Riken Keiki Co., Ltd.",
        "address_1": " 2-7-6 Azusawa",
        "address_2": "Itabashi-Ku  Tokyo  174-8744",
        "country": "JP"
    },
    "002166": {
        "oui_hex": "00-21-66",
        "organization": "NovAtel Inc.",
        "address_1": "1120 - 68 Ave NE",
        "address_2": "Calgary  Alberta  T2E 8S5",
        "country": "CA"
    },
    "002164": {
        "oui_hex": "00-21-64",
        "organization": "Special Design Bureau for Seismic Instrumentation",
        "address_1": "129, Krainyaya Str.",
        "address_2": "Saratov  Saratov region  410019",
        "country": "RU"
    },
    "002160": {
        "oui_hex": "00-21-60",
        "organization": "Hidea Solutions Co. Ltd.",
        "address_1": "4F, Do&Can house Dldg., #656-1683, Seongsu 1-ga 2-dong, Seongdong-gu",
        "address_2": "Seoul    656-1683",
        "country": "KR"
    },
    "0021B1": {
        "oui_hex": "00-21-B1",
        "organization": "DIGITAL SOLUTIONS LTD",
        "address_1": "Tsarigradsko Shose 7km BLVD",
        "address_2": "Sofia  Sofia  1784",
        "country": "BG"
    },
    "0021B0": {
        "oui_hex": "00-21-B0",
        "organization": "Tyco Telecommunications",
        "address_1": "1011 Pawtucket Blvd",
        "address_2": "Lowell  Massachusetts  01853",
        "country": "US"
    },
    "0021AD": {
        "oui_hex": "00-21-AD",
        "organization": "Nordic ID Oy",
        "address_1": "Myllyojankatu 2A",
        "address_2": "SALO    FIN-24100",
        "country": "FI"
    },
    "00217F": {
        "oui_hex": "00-21-7F",
        "organization": "Intraco Technology Pte Ltd",
        "address_1": "750e Chai Chee Road #05-01",
        "address_2": "Singapore    4690005",
        "country": "SG"
    },
    "00217D": {
        "oui_hex": "00-21-7D",
        "organization": "PYXIS S.R.L.",
        "address_1": "C/O DIP. INFORMATICA E SISTEMISTICA - UNIVERSITY OF PAVIA",
        "address_2": "PAVIA    27100",
        "country": "IT"
    },
    "00216F": {
        "oui_hex": "00-21-6F",
        "organization": "SymCom, Inc.",
        "address_1": "2880 North Plaza Drive",
        "address_2": "Rapid City  SD  57702",
        "country": "US"
    },
    "0021A3": {
        "oui_hex": "00-21-A3",
        "organization": "Micromint",
        "address_1": "111 Commerce St",
        "address_2": "Lake Mary  FL  32746",
        "country": "US"
    },
    "0021A5": {
        "oui_hex": "00-21-A5",
        "organization": "ERLPhase Power Technologies Ltd.",
        "address_1": "74 Scurfield Blvd.",
        "address_2": "Winnipeg  Manitoba  R3Y 1G4",
        "country": "CA"
    },
    "00219D": {
        "oui_hex": "00-21-9D",
        "organization": "Adesys BV",
        "address_1": "Molenweer 4",
        "address_2": "Wateringen  Zuid Holland  2291 NR",
        "country": "NL"
    },
    "002195": {
        "oui_hex": "00-21-95",
        "organization": "GWD Media Limited",
        "address_1": "10 Leeds Road",
        "address_2": "Sheffield  South Yorkshire  S9 3TY",
        "country": "GB"
    },
    "002188": {
        "oui_hex": "00-21-88",
        "organization": "EMC Corporation",
        "address_1": "2421 Mission College Blvd",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "00211A": {
        "oui_hex": "00-21-1A",
        "organization": "LInTech Corporation",
        "address_1": "Krasnokazarmennaya st., 12",
        "address_2": "Moscow    111250",
        "country": "RU"
    },
    "002116": {
        "oui_hex": "00-21-16",
        "organization": "Transcon Electronic Systems, spol. s r. o.",
        "address_1": "Kvapilova 2133",
        "address_2": "Frydek-Mistek    73802",
        "country": "CZ"
    },
    "002115": {
        "oui_hex": "00-21-15",
        "organization": "PHYWE Systeme GmbH & Co. KG",
        "address_1": "Robert-Bosch-Breite 10",
        "address_2": "Goettingen  Niedersachsen  37079",
        "country": "DE"
    },
    "002141": {
        "oui_hex": "00-21-41",
        "organization": "RADLIVE",
        "address_1": "4 Hanechoshet St.",
        "address_2": "Tel Aviv    69710",
        "country": "IL"
    },
    "002140": {
        "oui_hex": "00-21-40",
        "organization": "EN Technologies Inc.",
        "address_1": "Geumbok Bldg. 9F, Band-yi-dong 45-2, Songpa-gu",
        "address_2": "Seoul    138-828",
        "country": "KR"
    },
    "00213D": {
        "oui_hex": "00-21-3D",
        "organization": "Cermetek Microelectronics, Inc.",
        "address_1": "374 Turquoise Street",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "002111": {
        "oui_hex": "00-21-11",
        "organization": "Uniphone Inc.",
        "address_1": "795 Main Street",
        "address_2": "Half Moon Bay  CA  94019",
        "country": "US"
    },
    "002114": {
        "oui_hex": "00-21-14",
        "organization": "Hylab Technology Inc.",
        "address_1": "15F-2.,No.872,Jhongjheng Rd.",
        "address_2": "Jhonghe City,  Taipei  235",
        "country": "TW"
    },
    "002132": {
        "oui_hex": "00-21-32",
        "organization": "Masterclock, Inc.",
        "address_1": "2484 W. Clay St.",
        "address_2": "St. Charles  MO  63301",
        "country": "US"
    },
    "002131": {
        "oui_hex": "00-21-31",
        "organization": "Blynke Inc.",
        "address_1": "133 Richmond St. West",
        "address_2": "Toronto  Ontario  M5H 2L3",
        "country": "CA"
    },
    "002129": {
        "oui_hex": "00-21-29",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "00211D": {
        "oui_hex": "00-21-1D",
        "organization": "Dataline AB",
        "address_1": "Katrinedalsgatan 53",
        "address_2": "Borås    S-50451",
        "country": "SE"
    },
    "002120": {
        "oui_hex": "00-21-20",
        "organization": "Sequel Technologies",
        "address_1": "2951 Cleveland Ave N",
        "address_2": "Roseville  MN  55113",
        "country": "US"
    },
    "002152": {
        "oui_hex": "00-21-52",
        "organization": "General Satellite Research & Development Limited",
        "address_1": "Lit. E, building 2, 4 Novoladozhskaya str",
        "address_2": "Saint Petersburg    197110",
        "country": "RU"
    },
    "002158": {
        "oui_hex": "00-21-58",
        "organization": "Style Flying Technology Co.",
        "address_1": "22/F,Cyber Tower B,No.2 Zhong Guan Cun South Street,Haidian District,",
        "address_2": "Beijing    100086",
        "country": "CN"
    },
    "002148": {
        "oui_hex": "00-21-48",
        "organization": "Kaco Solar Korea",
        "address_1": "Chung-won-ku Sang-dea-won-dong 333-1",
        "address_2": "Songnam  Kyung-kido  462-806",
        "country": "KR"
    },
    "00213C": {
        "oui_hex": "00-21-3C",
        "organization": "AliphCom",
        "address_1": "150 Executive Park Blvd",
        "address_2": "San Francisco  CA  94134",
        "country": "US"
    },
    "001FB5": {
        "oui_hex": "00-1F-B5",
        "organization": "I/O Interconnect Inc.",
        "address_1": "1202 E Wakeham Ave",
        "address_2": "Santa Ana  CA  92708",
        "country": "US"
    },
    "001FE7": {
        "oui_hex": "00-1F-E7",
        "organization": "Simet",
        "address_1": "Strada del Portone 129",
        "address_2": "Grugliasco  Torino  10095",
        "country": "IT"
    },
    "001FDB": {
        "oui_hex": "00-1F-DB",
        "organization": "Network Supply Corp.,",
        "address_1": "1938 NAKADAIRA KANAE",
        "address_2": "IIDA  NAGANO  395-0801",
        "country": "JP"
    },
    "001FBF": {
        "oui_hex": "00-1F-BF",
        "organization": "Fulhua Microelectronics Corp. Taiwan Branch",
        "address_1": "1F, No.12, R&D Road,",
        "address_2": "Hsin-Chu, 300    886",
        "country": "TW"
    },
    "001FBE": {
        "oui_hex": "00-1F-BE",
        "organization": "Shenzhen Mopnet Industrial Co.,Ltd",
        "address_1": "3F.No.3 Keyuan Rd.,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001FC2": {
        "oui_hex": "00-1F-C2",
        "organization": "Jow Tong Technology Co Ltd",
        "address_1": "46 Lane 337 Chung Cheng Rd",
        "address_2": "Yung Kang City  Tainan County  71066",
        "country": "TW"
    },
    "001FD2": {
        "oui_hex": "00-1F-D2",
        "organization": "COMMTECH TECHNOLOGY MACAO COMMERCIAL OFFSHORE LTD.",
        "address_1": "31,TAI YIP STREET, 7/F KWUN TONG,",
        "address_2": "KOWLOON,  HONGKONG",
        "country": "CN"
    },
    "001FB8": {
        "oui_hex": "00-1F-B8",
        "organization": "Universal Remote Control, Inc.",
        "address_1": "500 Mamaroneck Avenue",
        "address_2": "Harrison  NY  10528",
        "country": "US"
    },
    "001FD4": {
        "oui_hex": "00-1F-D4",
        "organization": "4IPNET, INC.",
        "address_1": "38129 CAMBRIDGE COURT",
        "address_2": "FREMONT  CA  94536",
        "country": "US"
    },
    "001FCB": {
        "oui_hex": "00-1F-CB",
        "organization": "NIW Solutions",
        "address_1": "P.O. Box 62",
        "address_2": "One Tree Hill  South Australia  5114",
        "country": "AU"
    },
    "001FF7": {
        "oui_hex": "00-1F-F7",
        "organization": "Nakajima All Precision Co., Ltd.",
        "address_1": "Kami-Gomyo1480",
        "address_2": "Hanishina-Gun  Nagano-Ken  389-0606",
        "country": "JP"
    },
    "001FEB": {
        "oui_hex": "00-1F-EB",
        "organization": "Trio Datacom Pty Ltd",
        "address_1": "41 Aster Avenue",
        "address_2": "Carrum Downs  Victoria  3201",
        "country": "AU"
    },
    "001F69": {
        "oui_hex": "00-1F-69",
        "organization": "Pingood Technology Co., Ltd.",
        "address_1": "Rm1917, South Block, Cangsong Bldg., Tairan Industrial Zone, Futian District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "001F4D": {
        "oui_hex": "00-1F-4D",
        "organization": "Segnetics LLC",
        "address_1": "Shkiperski protok 14",
        "address_2": "Saint-Petersburg    199106",
        "country": "RU"
    },
    "001F81": {
        "oui_hex": "00-1F-81",
        "organization": "Accel Semiconductor Corp",
        "address_1": "1F,Mainbldg,149 Chun Xiao Road,",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "001F83": {
        "oui_hex": "00-1F-83",
        "organization": "Teleplan Technology Services Sdn Bhd",
        "address_1": "2580, Tingkat Perusahaan 4B",
        "address_2": "Perai  Penang  13600",
        "country": "MY"
    },
    "001F9B": {
        "oui_hex": "00-1F-9B",
        "organization": "POSBRO",
        "address_1": "ShinyoungGtower 6F, 271-1",
        "address_2": "Seongnam-si  Kyunggi-do  463-824",
        "country": "KR"
    },
    "001F78": {
        "oui_hex": "00-1F-78",
        "organization": "Blue Fox Porini Textile",
        "address_1": "1208 Pointe Centre Drive",
        "address_2": "Chattanooga  TN  37421",
        "country": "US"
    },
    "001F68": {
        "oui_hex": "00-1F-68",
        "organization": "Martinsson Elektronik AB",
        "address_1": "Box 9060",
        "address_2": "Hägersten  Stockholm  126 09",
        "country": "SE"
    },
    "001F63": {
        "oui_hex": "00-1F-63",
        "organization": "JSC Goodwin-Europa",
        "address_1": "20/5 Marksistskaya st.",
        "address_2": "Moscow    109147",
        "country": "RU"
    },
    "001FAD": {
        "oui_hex": "00-1F-AD",
        "organization": "Brown Innovations, Inc",
        "address_1": "369 Congress Street",
        "address_2": "Boston  MA  02210",
        "country": "US"
    },
    "001FA6": {
        "oui_hex": "00-1F-A6",
        "organization": "Stilo srl",
        "address_1": "Via Besana, 4",
        "address_2": "20122  Milano",
        "country": "IT"
    },
    "001F97": {
        "oui_hex": "00-1F-97",
        "organization": "BERTANA srl",
        "address_1": "Viale GALILEO FERRARIS 27",
        "address_2": "BRUINO  TORINO  10090",
        "country": "IT"
    },
    "001F8C": {
        "oui_hex": "00-1F-8C",
        "organization": "CCS Inc.",
        "address_1": "Shimodachiuri-agaru",
        "address_2": "Kyoto  Kyoto  602-8011",
        "country": "JP"
    },
    "001F10": {
        "oui_hex": "00-1F-10",
        "organization": "TOLEDO DO BRASIL INDUSTRIA DE BALANCAS  LTDA",
        "address_1": "RUA MANOEL CREMONESI, 1",
        "address_2": "SAO BERNARDO DO CAMPO  SP  09851-900",
        "country": "BR"
    },
    "001F0F": {
        "oui_hex": "00-1F-0F",
        "organization": "Select Engineered Systems",
        "address_1": "7991 W. 26 Ave",
        "address_2": "Hialeah  Florida  33016",
        "country": "US"
    },
    "001F02": {
        "oui_hex": "00-1F-02",
        "organization": "Pixelmetrix Corporation Pte Ltd",
        "address_1": "31 Kaki Bukit Road 3",
        "address_2": "    417818",
        "country": "SG"
    },
    "001EFE": {
        "oui_hex": "00-1E-FE",
        "organization": "LEVEL s.r.o.",
        "address_1": "Plhovska 1997",
        "address_2": "Nachod    547 01",
        "country": "CZ"
    },
    "001F1A": {
        "oui_hex": "00-1F-1A",
        "organization": "Prominvest",
        "address_1": "7, Bobruiskaya ulica",
        "address_2": "Saint-Petersburg  North-West Federal District  195009",
        "country": "RU"
    },
    "001F18": {
        "oui_hex": "00-1F-18",
        "organization": "Hakusan.Mfg.Co,.Ltd",
        "address_1": "Tomin-Kougyou-Ikebukuro BLD.5F",
        "address_2": "Tosima Ward  Tokyo-Met.  171-0022",
        "country": "JP"
    },
    "001F13": {
        "oui_hex": "00-1F-13",
        "organization": "S.& A.S. Ltd.",
        "address_1": "Boutros Bldg. 1st bsmt",
        "address_2": "Beirut    2067 7808",
        "country": "LB"
    },
    "001F25": {
        "oui_hex": "00-1F-25",
        "organization": "MBS GmbH",
        "address_1": "Römerstraße 15",
        "address_2": "Krefeld  Nordrhein-Westfalen  47809",
        "country": "DE"
    },
    "001F27": {
        "oui_hex": "00-1F-27",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F26": {
        "oui_hex": "00-1F-26",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001EEF": {
        "oui_hex": "00-1E-EF",
        "organization": "Cantronic International Limited",
        "address_1": "Unit 515-516, Building 15, East Wing, No 8 Science Park West Avenue, Hong Kong Science Park Phase II",
        "address_2": "Shatin  New Territories  852",
        "country": "HK"
    },
    "001EDE": {
        "oui_hex": "00-1E-DE",
        "organization": "BYD COMPANY LIMITED",
        "address_1": "NO.1,Baoping Road,Baolong Industrial Town,Longgang",
        "address_2": "SHEN ZHEN  Guangdong  518116",
        "country": "CN"
    },
    "001EDD": {
        "oui_hex": "00-1E-DD",
        "organization": "WASKO S.A.",
        "address_1": "Berbeckiego 6",
        "address_2": "Gliwice  Silesia  44-100",
        "country": "PL"
    },
    "001EDB": {
        "oui_hex": "00-1E-DB",
        "organization": "Giken Trastem Co., Ltd.",
        "address_1": "4-1 Takeda Dankawaracho Fushimiku",
        "address_2": "Kyoto    612-8414",
        "country": "JP"
    },
    "001F42": {
        "oui_hex": "00-1F-42",
        "organization": "Etherstack plc",
        "address_1": "80 Abercrombie Street",
        "address_2": "Chippendale  NSW  2008",
        "country": "AU"
    },
    "001F35": {
        "oui_hex": "00-1F-35",
        "organization": "AIR802 LLC",
        "address_1": "1169 Banyon Court",
        "address_2": "Naperville  IL  60540",
        "country": "US"
    },
    "001F34": {
        "oui_hex": "00-1F-34",
        "organization": "Lung Hwa Electronics Co., Ltd.",
        "address_1": "3F, 248, Pei Sheng Rd. Sec. 3,",
        "address_2": "Taipei  Hsien  222",
        "country": "TW"
    },
    "001EEB": {
        "oui_hex": "00-1E-EB",
        "organization": "Talk-A-Phone Co.",
        "address_1": "5013 N. Kedzie Ave.",
        "address_2": "Chicago  IL  60625",
        "country": "US"
    },
    "001E6A": {
        "oui_hex": "00-1E-6A",
        "organization": "Beijing Bluexon Technology Co.,Ltd",
        "address_1": "Jinqiuzhichun 7-301,Zhichun Rd.,",
        "address_2": "Beijing    100088",
        "country": "CN"
    },
    "001E66": {
        "oui_hex": "00-1E-66",
        "organization": "RESOL Elektronische Regelungen GmbH",
        "address_1": "Heiskampstraße 10",
        "address_2": "Hattingen  NRW  45527",
        "country": "DE"
    },
    "001E63": {
        "oui_hex": "00-1E-63",
        "organization": "Vibro-Meter SA",
        "address_1": "Route de Moncor 4",
        "address_2": "Fribourg    CH-1701",
        "country": "CH"
    },
    "001E7F": {
        "oui_hex": "00-1E-7F",
        "organization": "CBM of America",
        "address_1": "1455 West Newport Center Drive",
        "address_2": "Deerfield Beach  Florida  33442",
        "country": "US"
    },
    "001E82": {
        "oui_hex": "00-1E-82",
        "organization": "SanDisk Corporation",
        "address_1": "630 Alder Drive,",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001EB1": {
        "oui_hex": "00-1E-B1",
        "organization": "Cryptsoft Pty Ltd",
        "address_1": "P.O. Box 6389",
        "address_2": "Fairfield Gardens  Queensland  4103",
        "country": "AU"
    },
    "001EAF": {
        "oui_hex": "00-1E-AF",
        "organization": "Ophir Optronics Ltd",
        "address_1": "POB 45021",
        "address_2": "Jerusalem    91450",
        "country": "IL"
    },
    "001EAD": {
        "oui_hex": "00-1E-AD",
        "organization": "Wingtech Group Limited",
        "address_1": "6th floor, Unit G, No.668, East Beijing Road,",
        "address_2": "Shanghai    200001",
        "country": "CN"
    },
    "001ED1": {
        "oui_hex": "00-1E-D1",
        "organization": "Keyprocessor B.V.",
        "address_1": "Paasheuvelweg 20",
        "address_2": "Amsterdam  NH  1105 BJ",
        "country": "NL"
    },
    "001ED0": {
        "oui_hex": "00-1E-D0",
        "organization": "Ingespace",
        "address_1": "6 rue de lourmede",
        "address_2": "Eurocentre    31621",
        "country": "FR"
    },
    "001E8E": {
        "oui_hex": "00-1E-8E",
        "organization": "Hunkeler AG",
        "address_1": "Bahnhofstrasse 31",
        "address_2": "Wikon  CH  4806",
        "country": "CH"
    },
    "001E87": {
        "oui_hex": "00-1E-87",
        "organization": "Realease Limited",
        "address_1": "15/F, Morrison Commercial Building",
        "address_2": "WanChai",
        "country": "HK"
    },
    "001ECD": {
        "oui_hex": "00-1E-CD",
        "organization": "KYLAND Technology Co. LTD",
        "address_1": "Building No.2,Shixing Avenue 30#",
        "address_2": "Shijingshan District  Beijing  100044",
        "country": "CN"
    },
    "001EBF": {
        "oui_hex": "00-1E-BF",
        "organization": "Haas Automation Inc.",
        "address_1": "2800 Sturgis Rd",
        "address_2": "Oxnard  CA  93030",
        "country": "US"
    },
    "001EBC": {
        "oui_hex": "00-1E-BC",
        "organization": "WINTECH AUTOMATION CO.,LTD.",
        "address_1": "#1115, TAEKWANG BLVD.",
        "address_2": "SUWON-SI  KYUNGGI  443-816",
        "country": "KR"
    },
    "001E6F": {
        "oui_hex": "00-1E-6F",
        "organization": "Magna-Power Electronics, Inc.",
        "address_1": "39 Royal Road",
        "address_2": "Flemington  NJ  08822",
        "country": "US"
    },
    "001EA1": {
        "oui_hex": "00-1E-A1",
        "organization": "Brunata a/s",
        "address_1": "Vesterlundvej 14",
        "address_2": "Herlev    2730",
        "country": "DK"
    },
    "001E53": {
        "oui_hex": "00-1E-53",
        "organization": "Further Tech Co., LTD",
        "address_1": "8F,NO 421, Sungshan RD.,Taipei, Taiwn,R.O.C.",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001E4E": {
        "oui_hex": "00-1E-4E",
        "organization": "DAKO EDV-Ingenieur- und Systemhaus GmbH",
        "address_1": "Ernst-Haeckel-Platz 5/6",
        "address_2": "Jena  Thuringia  07745",
        "country": "DE"
    },
    "001E49": {
        "oui_hex": "00-1E-49",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E28": {
        "oui_hex": "00-1E-28",
        "organization": "Lumexis Corporation",
        "address_1": "3184 Airway Ave Bldg D",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "001E24": {
        "oui_hex": "00-1E-24",
        "organization": "Zhejiang Bell Technology Co.,ltd",
        "address_1": "6 Xidoumen Rd. West Lake district",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "001E20": {
        "oui_hex": "00-1E-20",
        "organization": "Intertain Inc.",
        "address_1": "Suite 608 LG Eclat-2, 245-4 Seohyun-dong, Bundang-gu",
        "address_2": "Sungngm-shi  Kyunggi-do  463-824",
        "country": "KR"
    },
    "001E1C": {
        "oui_hex": "00-1E-1C",
        "organization": "SWS Australia Pty Limited",
        "address_1": "23 Scanlon Drive",
        "address_2": "Epping  Victoria  3076",
        "country": "AU"
    },
    "001E12": {
        "oui_hex": "00-1E-12",
        "organization": "Ecolab",
        "address_1": "655 Lone Oak Drive",
        "address_2": "Eagan  MN  55121",
        "country": "US"
    },
    "001E16": {
        "oui_hex": "00-1E-16",
        "organization": "Keytronix",
        "address_1": "Ungargasse 64-66/1/109",
        "address_2": "Vienna    1030",
        "country": "AT"
    },
    "001E32": {
        "oui_hex": "00-1E-32",
        "organization": "Zensys",
        "address_1": "Emdrupvej 26",
        "address_2": "Copenhagen O    DK-2100",
        "country": "DK"
    },
    "001E35": {
        "oui_hex": "00-1E-35",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001E2B": {
        "oui_hex": "00-1E-2B",
        "organization": "Radio Systems Design, Inc.",
        "address_1": "601 Heron Drive",
        "address_2": "Logan Twp  New Jersey  08085",
        "country": "US"
    },
    "001E42": {
        "oui_hex": "00-1E-42",
        "organization": "Teltonika",
        "address_1": "Zirmunu 27",
        "address_2": "Vilnius    LT - 09105",
        "country": "LT"
    },
    "001E43": {
        "oui_hex": "00-1E-43",
        "organization": "AISIN AW CO.,LTD.",
        "address_1": "6-18 HARAYAMA",
        "address_2": "OKAZAKI  AICHI  444-8564",
        "country": "JP"
    },
    "001E08": {
        "oui_hex": "00-1E-08",
        "organization": "Centec Networks Inc",
        "address_1": " Suite 4F-13/16, Building B, No.5 Xing Han Street",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "001DFB": {
        "oui_hex": "00-1D-FB",
        "organization": "NETCLEUS Systems Corporation",
        "address_1": "3F, Daiichi-maeda Bldg.",
        "address_2": "Yamato-shi    242-0017",
        "country": "JP"
    },
    "001DB9": {
        "oui_hex": "00-1D-B9",
        "organization": "Wellspring Wireless",
        "address_1": "107 Magella Court",
        "address_2": "North Wales  Pa  19454",
        "country": "US"
    },
    "001DBB": {
        "oui_hex": "00-1D-BB",
        "organization": "Dynamic System Electronics Corp.",
        "address_1": "5F,NO,9,LANE 130,SEC 1,KUANGG FU RD.SAN CHUNG CITY,",
        "address_2": "Taipei  Hsien  24158",
        "country": "TW"
    },
    "001DB3": {
        "oui_hex": "00-1D-B3",
        "organization": "HPN Supply Chain",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "001DB1": {
        "oui_hex": "00-1D-B1",
        "organization": "Crescendo Networks",
        "address_1": "6 Yoni Netanyahu St.",
        "address_2": "Or-Yehuda    60376",
        "country": "IL"
    },
    "001DB4": {
        "oui_hex": "00-1D-B4",
        "organization": "KUMHO ENG CO.,LTD",
        "address_1": "498-13, HYUNDAI B/D 5F",
        "address_2": "DAEGU    703-835",
        "country": "KR"
    },
    "001DA4": {
        "oui_hex": "00-1D-A4",
        "organization": "Hangzhou System Technology CO., LTD",
        "address_1": "ROOM A1505 HuaXing times plaza,NO 478 Wensan Road",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "001D9F": {
        "oui_hex": "00-1D-9F",
        "organization": "MATT   R.P.Traczynscy Sp.J.",
        "address_1": "Polnocna 44",
        "address_2": "Koscian  wielkopolskie  PL-64000",
        "country": "PL"
    },
    "001D90": {
        "oui_hex": "00-1D-90",
        "organization": "EMCO Flow Systems",
        "address_1": "2150 Miller Drive",
        "address_2": "Longmont  CO  80501",
        "country": "US"
    },
    "001D93": {
        "oui_hex": "00-1D-93",
        "organization": "Modacom",
        "address_1": "Jinsuk Building 1536-7",
        "address_2": "Seoul    137-073",
        "country": "KR"
    },
    "001D94": {
        "oui_hex": "00-1D-94",
        "organization": "Climax Technology Co., Ltd",
        "address_1": "No. 258, Hsin Hu 2nd Road",
        "address_2": "Taipei City  Taipei  114",
        "country": "TW"
    },
    "001D8E": {
        "oui_hex": "00-1D-8E",
        "organization": "Alereon, Inc.",
        "address_1": "7600 N. Capital of Texas Hwy",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "001DDB": {
        "oui_hex": "00-1D-DB",
        "organization": "C-BEL Corporation",
        "address_1": "Futabacho 35-12",
        "address_2": "Itabashi-ku  Tokyo  173-0011",
        "country": "JP"
    },
    "001DE6": {
        "oui_hex": "00-1D-E6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001DE7": {
        "oui_hex": "00-1D-E7",
        "organization": "Marine Sonic Technology, Ltd.",
        "address_1": "5508 George Washington Memorial Highway",
        "address_2": "White Marsh  Virginia  23183",
        "country": "US"
    },
    "001D7B": {
        "oui_hex": "00-1D-7B",
        "organization": "Ice Energy, Inc.",
        "address_1": "9351 Eastman Park Drive",
        "address_2": "Windsor  Colorado  80550",
        "country": "US"
    },
    "001D6C": {
        "oui_hex": "00-1D-6C",
        "organization": "ClariPhy Communications, Inc.",
        "address_1": "16 Technology Dr., Suite 165",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "001DC5": {
        "oui_hex": "00-1D-C5",
        "organization": "Beijing Jiaxun Feihong Electricial Co., Ltd.",
        "address_1": "Electrical Building,No. 31 Jiaoda East Road,",
        "address_2": "Beijing  Haidian District,  100044",
        "country": "CN"
    },
    "001DC6": {
        "oui_hex": "00-1D-C6",
        "organization": "SNR Inc.",
        "address_1": "VBIC T223ho, ICU, 103-6 Munji-dong, Youseong-gu",
        "address_2": "Daejeon    305-732",
        "country": "KR"
    },
    "001D84": {
        "oui_hex": "00-1D-84",
        "organization": "Gateway, Inc.",
        "address_1": "610 Gateway Drive",
        "address_2": "North Sioux City  South Dakota  57049",
        "country": "US"
    },
    "001D85": {
        "oui_hex": "00-1D-85",
        "organization": "Call Direct Cellular Solutions",
        "address_1": "Suite 145, National Innovation Centre",
        "address_2": "Eveleigh  NSW  1430",
        "country": "AU"
    },
    "001DBF": {
        "oui_hex": "00-1D-BF",
        "organization": "Radiient Technologies, Inc.",
        "address_1": "2084-A Walsh Ave",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "001D34": {
        "oui_hex": "00-1D-34",
        "organization": "SYRIS Technology Corp",
        "address_1": "21 F-2,  NO. 12,  SEC. 1,  Taijunggang Rd.",
        "address_2": "Taichung    403",
        "country": "US"
    },
    "001D32": {
        "oui_hex": "00-1D-32",
        "organization": "Longkay Communication & Technology (Shanghai) Co. Ltd",
        "address_1": "No.5 Building, Unit 2, Lane 299 Bisheng Rd,",
        "address_2": "Shanghai    201204",
        "country": "CN"
    },
    "001D2A": {
        "oui_hex": "00-1D-2A",
        "organization": "SHENZHEN BUL-TECH CO.,LTD.",
        "address_1": "4/F, COFCO Bdlg , 3rd District,Baoan District, Shenzhen City,",
        "address_2": "shengzhen  guangdong  518101",
        "country": "CN"
    },
    "001D2D": {
        "oui_hex": "00-1D-2D",
        "organization": "Pylone, Inc.",
        "address_1": "4F Nakano Bldg. 4-30-8 Kita-Shinjuku",
        "address_2": "Shinjuku-ku,  Tokyo  169-0074",
        "country": "JP"
    },
    "001D5B": {
        "oui_hex": "00-1D-5B",
        "organization": "Tecvan Informática Ltda",
        "address_1": "Rua Guaicurus, 145",
        "address_2": "Diadema  São Paulo  09911-630",
        "country": "BR"
    },
    "001D5D": {
        "oui_hex": "00-1D-5D",
        "organization": "Control Dynamics Pty. Ltd.",
        "address_1": "PO Box 636",
        "address_2": "MORLEY  Western Australia  6943",
        "country": "AU"
    },
    "001D59": {
        "oui_hex": "00-1D-59",
        "organization": "Mitra Energy & Infrastructure",
        "address_1": "Boulevard de l'Europe 131",
        "address_2": "1301  Wavre",
        "country": "BE"
    },
    "001D2B": {
        "oui_hex": "00-1D-2B",
        "organization": "Wuhan Pont Technology CO. , LTD",
        "address_1": "Building E, Guandong Science and Technology Industry  Park,",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "001D22": {
        "oui_hex": "00-1D-22",
        "organization": "Foss Analytical A/S",
        "address_1": "Slangerupgade 69",
        "address_2": "Hillerød  Seeland  3400",
        "country": "DK"
    },
    "001D23": {
        "oui_hex": "00-1D-23",
        "organization": "SENSUS",
        "address_1": "44 CASTILIAN DRIVE",
        "address_2": "GOLETA  CALIFORNIA  93117",
        "country": "US"
    },
    "001D3E": {
        "oui_hex": "00-1D-3E",
        "organization": "SAKA TECHNO SCIENCE CO.,LTD",
        "address_1": "Nishi 105-1",
        "address_2": "Kanazawa  Ishikawa  920-0367",
        "country": "JP"
    },
    "001D40": {
        "oui_hex": "00-1D-40",
        "organization": " Intel – GE Care Innovations LLC",
        "address_1": "3721 Douglas Blvd",
        "address_2": "Roseville  CA  95661",
        "country": "US"
    },
    "001D57": {
        "oui_hex": "00-1D-57",
        "organization": "CAETEC Messtechnik",
        "address_1": "Schlossstraße 95a",
        "address_2": "Olching  Bayern  82140",
        "country": "DE"
    },
    "001D51": {
        "oui_hex": "00-1D-51",
        "organization": "Babcock & Wilcox Power Generation Group, Inc",
        "address_1": "11864 Canon Blvd, Suite 105",
        "address_2": "Newport News  VA  23606",
        "country": "US"
    },
    "001D4C": {
        "oui_hex": "00-1D-4C",
        "organization": "Alcatel-Lucent",
        "address_1": "601 Data Dr.",
        "address_2": "Plano  TX  75075",
        "country": "US"
    },
    "001D1A": {
        "oui_hex": "00-1D-1A",
        "organization": "OvisLink S.A.",
        "address_1": "C/Andres Obispo, 37. Pl. 4.",
        "address_2": "Madrid    28043",
        "country": "ES"
    },
    "001CB7": {
        "oui_hex": "00-1C-B7",
        "organization": "USC DigiArk Corporation",
        "address_1": "6F Tennoz Central Tower 2-2-24 Higashishinagawa",
        "address_2": "Tokyo  Shinagawa-ku  140-0002",
        "country": "JP"
    },
    "001CAF": {
        "oui_hex": "00-1C-AF",
        "organization": "Plato Networks Inc.",
        "address_1": "2855 Kifer Road",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "001CB1": {
        "oui_hex": "00-1C-B1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001CFE": {
        "oui_hex": "00-1C-FE",
        "organization": "Quartics Inc",
        "address_1": "15241 Laguna Canyon Road",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "001D0B": {
        "oui_hex": "00-1D-0B",
        "organization": "Power Standards Lab",
        "address_1": "1201 Marina Village Parkway #101",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "001D02": {
        "oui_hex": "00-1D-02",
        "organization": "Cybertech Telecom Development",
        "address_1": "Hazenkoog 25",
        "address_2": "Alkmaar  Noord Holland  1822 BS",
        "country": "NL"
    },
    "001CE9": {
        "oui_hex": "00-1C-E9",
        "organization": "Galaxy Technology Limited",
        "address_1": "9/F Win Full Commerical Building, 172-176 Wing Lok Street,",
        "address_2": "Sheung Wan,",
        "country": "HK"
    },
    "001CEA": {
        "oui_hex": "00-1C-EA",
        "organization": "Scientific-Atlanta, Inc",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001CE7": {
        "oui_hex": "00-1C-E7",
        "organization": "Rocon PLC Research Centre",
        "address_1": "21 Vek 56A str.",
        "address_2": "Sofia    1700",
        "country": "US"
    },
    "001CDB": {
        "oui_hex": "00-1C-DB",
        "organization": "CARPOINT CO.,LTD",
        "address_1": "1340-6, Namgang Bld 7F, Seocho-Dong",
        "address_2": "SEOUL    137-070",
        "country": "KR"
    },
    "001CD5": {
        "oui_hex": "00-1C-D5",
        "organization": "ZeeVee, Inc.",
        "address_1": "1 Monarch Drive",
        "address_2": "Littleton  MA  01460",
        "country": "US"
    },
    "001CBC": {
        "oui_hex": "00-1C-BC",
        "organization": "CastGrabber, LLC",
        "address_1": "6507 Wilkins Avenue Ste. 212",
        "address_2": "Pittsburgh  PA  15217",
        "country": "US"
    },
    "001CE4": {
        "oui_hex": "00-1C-E4",
        "organization": "EleSy JSC",
        "address_1": "Altayskaya street, 161a",
        "address_2": "  Tomsk oblast  634021",
        "country": "RU"
    },
    "001CE2": {
        "oui_hex": "00-1C-E2",
        "organization": "Attero Tech, LLC.",
        "address_1": "1315 Directors Row - Suite 107",
        "address_2": "Fort Wayne  Indiana  46808",
        "country": "US"
    },
    "001CAA": {
        "oui_hex": "00-1C-AA",
        "organization": "Bellon Pty Ltd",
        "address_1": "Unit 12/12-18 Victoria St East",
        "address_2": "Lidcombe  NSW  2000",
        "country": "AU"
    },
    "001CA0": {
        "oui_hex": "00-1C-A0",
        "organization": "Production Resource Group, LLC",
        "address_1": "539 Temple Hill Road",
        "address_2": "New Windsor  NY  12553",
        "country": "US"
    },
    "001CD3": {
        "oui_hex": "00-1C-D3",
        "organization": "ZP Engineering SEL",
        "address_1": "via Ardito Desio, 60",
        "address_2": "ROME    00131",
        "country": "IT"
    },
    "001CCB": {
        "oui_hex": "00-1C-CB",
        "organization": "Forth Corporation Public Company Limited",
        "address_1": "226/12,13,16 Paholyothin Road",
        "address_2": "Bangkok    10400",
        "country": "TH"
    },
    "001C75": {
        "oui_hex": "00-1C-75",
        "organization": "Segnet Ltd.",
        "address_1": "146 New London Road",
        "address_2": "Chelmsford Essex CM2 OAW",
        "country": "GB"
    },
    "001C74": {
        "oui_hex": "00-1C-74",
        "organization": "Syswan Technologies Inc.",
        "address_1": "2050 Beavercreek Road",
        "address_2": "Oregon City  Oregon  97045",
        "country": "US"
    },
    "001C68": {
        "oui_hex": "00-1C-68",
        "organization": "Anhui Sun Create Electronics Co., Ltd",
        "address_1": "NO.199 Xiangzhang Road",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "001C66": {
        "oui_hex": "00-1C-66",
        "organization": "UCAMP CO.,LTD",
        "address_1": "#1015, Kolon Science Valley ¥±",
        "address_2": "Seoul  Guro-Dong,Guro-gu,  152-848",
        "country": "KR"
    },
    "001C98": {
        "oui_hex": "00-1C-98",
        "organization": "LUCKY TECHNOLOGY (HK) COMPANY LIMITED",
        "address_1": "FLAT/RM 1503 15/F ISLAND BEVERLEY NO 1 GREAT GEORGE STREET CAUSEWAY BAY",
        "address_2": "    999077",
        "country": "HK"
    },
    "001C81": {
        "oui_hex": "00-1C-81",
        "organization": "NextGen Venturi LTD",
        "address_1": "Technium 2",
        "address_2": "Swansea  West Glamorgan  SA18PJ",
        "country": "GB"
    },
    "001C7A": {
        "oui_hex": "00-1C-7A",
        "organization": "Perfectone Netware Company Ltd",
        "address_1": "Unit 815, Sun Fung Centre,",
        "address_2": "Kwai Chung",
        "country": "HK"
    },
    "001C7B": {
        "oui_hex": "00-1C-7B",
        "organization": "Castlenet Technology Inc.",
        "address_1": "No.64, Chung-Shan Rd.",
        "address_2": "Tu-Cheng City  Taipei  236",
        "country": "TW"
    },
    "001C53": {
        "oui_hex": "00-1C-53",
        "organization": "Synergy Lighting Controls",
        "address_1": "One Lithonia Way",
        "address_2": "Conyers  GA  30012",
        "country": "US"
    },
    "001C4D": {
        "oui_hex": "00-1C-4D",
        "organization": "Aplix IP Holdings Corporation",
        "address_1": "2-20-9 Nishiwaseda",
        "address_2": "Shinjuku-ku  Tokyo  169-0051",
        "country": "JP"
    },
    "001C92": {
        "oui_hex": "00-1C-92",
        "organization": "Tervela",
        "address_1": "43 Nagog Park",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "001C8A": {
        "oui_hex": "00-1C-8A",
        "organization": "Cirrascale Corporation",
        "address_1": "9449 Carroll Park Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001C38": {
        "oui_hex": "00-1C-38",
        "organization": "Bio-Rad Laboratories, Inc.",
        "address_1": "245 Winter St.",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "001C30": {
        "oui_hex": "00-1C-30",
        "organization": "Mode Lighting (UK ) Ltd.",
        "address_1": "The Maltings",
        "address_2": "Ware  Hertfordshire  SG12 9AD",
        "country": "GB"
    },
    "001C2E": {
        "oui_hex": "00-1C-2E",
        "organization": "HPN Supply Chain",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "001C2A": {
        "oui_hex": "00-1C-2A",
        "organization": "Envisacor Technologies Inc.",
        "address_1": "237 Romina Drive",
        "address_2": "Concord  Ontario  L4K 4V3",
        "country": "CA"
    },
    "001C02": {
        "oui_hex": "00-1C-02",
        "organization": "Pano Logic",
        "address_1": "2000 Seaport Drive, Suite 200",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "001C05": {
        "oui_hex": "00-1C-05",
        "organization": "Nonin Medical Inc.",
        "address_1": "13700 1st Avenue North",
        "address_2": "Plymouth  MN  55441",
        "country": "US"
    },
    "001C06": {
        "oui_hex": "00-1C-06",
        "organization": "Siemens Numerical Control Ltd., Nanjing",
        "address_1": "No. 18 Siemens Road, Jiangning Development Zone",
        "address_2": "Nanjing  JiangSu  211100",
        "country": "CN"
    },
    "001BEA": {
        "oui_hex": "00-1B-EA",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001BE5": {
        "oui_hex": "00-1B-E5",
        "organization": "802automation Limited",
        "address_1": "18 First Avenue",
        "address_2": "Worthing  West Sussex  BN14 9NJ",
        "country": "GB"
    },
    "001BE4": {
        "oui_hex": "00-1B-E4",
        "organization": "TOWNET SRL",
        "address_1": "VIA DEI FINALE, 20",
        "address_2": "61043  CAGLI (PU)",
        "country": "IT"
    },
    "001C04": {
        "oui_hex": "00-1C-04",
        "organization": "Airgain, Inc.",
        "address_1": "1930 Palomar Point Way",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "001C01": {
        "oui_hex": "00-1C-01",
        "organization": "ABB Oy Drives",
        "address_1": "Hiomotie 13",
        "address_2": "Helsinki    FI-00380",
        "country": "FI"
    },
    "001BFF": {
        "oui_hex": "00-1B-FF",
        "organization": "Millennia Media inc.",
        "address_1": "4200 Day Spring CT",
        "address_2": "Placerville  CA  95667",
        "country": "US"
    },
    "001BF2": {
        "oui_hex": "00-1B-F2",
        "organization": "KWORLD COMPUTER CO., LTD",
        "address_1": "No. 113, Jian 2nd Rd.,",
        "address_2": "Jhonghe  Taipei county  235",
        "country": "TW"
    },
    "001BF0": {
        "oui_hex": "00-1B-F0",
        "organization": "Value Platforms Limited",
        "address_1": "Rm 712-713, Building 9, 5, Science Park West Ave.,",
        "address_2": "Shatin,",
        "country": "HK"
    },
    "001C1B": {
        "oui_hex": "00-1C-1B",
        "organization": "Hyperstone GmbH",
        "address_1": "Line-Eid-Straße 3",
        "address_2": "Konstanz  Baden-Württemberg  78467",
        "country": "DE"
    },
    "001C10": {
        "oui_hex": "00-1C-10",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "001BD2": {
        "oui_hex": "00-1B-D2",
        "organization": "ULTRA-X ASIA PACIFIC Inc.",
        "address_1": "5-1-15 Sotokanda",
        "address_2": "Tokyo  Chiyoda-ku  101-0021",
        "country": "JP"
    },
    "001B8D": {
        "oui_hex": "00-1B-8D",
        "organization": "Electronic Computer Systems, Inc.",
        "address_1": "418 Donegal Drive",
        "address_2": "Towson  MD  21286",
        "country": "US"
    },
    "001B86": {
        "oui_hex": "00-1B-86",
        "organization": "Bosch Access Systems GmbH",
        "address_1": "Charlottenburger Allee 50",
        "address_2": "AACHEN    D-52068",
        "country": "DE"
    },
    "001BC2": {
        "oui_hex": "00-1B-C2",
        "organization": "Integrated Control Technology Limitied",
        "address_1": "11 Canaveral Drive",
        "address_2": "Auckland  Auckland  0735",
        "country": "NZ"
    },
    "001BBB": {
        "oui_hex": "00-1B-BB",
        "organization": "RFTech Co.,Ltd",
        "address_1": "339-17 Jwahang-Ri,Wonsam-Myun,",
        "address_2": "Yongin-Si  Kyungki-Do  449-871",
        "country": "KR"
    },
    "001BAA": {
        "oui_hex": "00-1B-AA",
        "organization": "XenICs nv",
        "address_1": "Ambachtenlaan 44",
        "address_2": "Leuven  Vlaams-Brabant  B-3001",
        "country": "BE"
    },
    "001B7C": {
        "oui_hex": "00-1B-7C",
        "organization": "A & R Cambridge",
        "address_1": "Pembroke Avenue",
        "address_2": "Cambridge  CAMBS  CB25 9QR",
        "country": "GB"
    },
    "001B5D": {
        "oui_hex": "00-1B-5D",
        "organization": "Vololink Pty Ltd",
        "address_1": "Level 2, 541 Blackburn Road",
        "address_2": "Mount Waverley  Victoria  3149",
        "country": "AU"
    },
    "001B5A": {
        "oui_hex": "00-1B-5A",
        "organization": "Apollo Imaging Technologies, Inc.",
        "address_1": "18545 Rangeland Rd",
        "address_2": "Ramona  CA  92065",
        "country": "US"
    },
    "001B56": {
        "oui_hex": "00-1B-56",
        "organization": "Tehuti Networks Ltd.",
        "address_1": "1, Shenkar St.",
        "address_2": "Hertzliya    46105",
        "country": "IL"
    },
    "001BC6": {
        "oui_hex": "00-1B-C6",
        "organization": "Strato Rechenzentrum AG",
        "address_1": "Pascalstrasse 10",
        "address_2": "D-10587  Berlin",
        "country": "DE"
    },
    "001BC4": {
        "oui_hex": "00-1B-C4",
        "organization": "Ultratec, Inc.",
        "address_1": "450 Science Drive",
        "address_2": "Madison  WI  53711",
        "country": "US"
    },
    "001BA1": {
        "oui_hex": "00-1B-A1",
        "organization": "Åmic AB",
        "address_1": "Uppsala science park",
        "address_2": "Uppsala    75183",
        "country": "SE"
    },
    "001B96": {
        "oui_hex": "00-1B-96",
        "organization": "General Sensing",
        "address_1": "Unit 716, Cyberport 1",
        "address_2": "Pok Fu Lam",
        "country": "US"
    },
    "001AEA": {
        "oui_hex": "00-1A-EA",
        "organization": "Radio Terminal Systems Pty Ltd",
        "address_1": "1st Floor",
        "address_2": "Laverton North  Victoria  3026",
        "country": "AU"
    },
    "001ADD": {
        "oui_hex": "00-1A-DD",
        "organization": "PePWave Ltd",
        "address_1": "17/F., Park Building,",
        "address_2": "Cheung Sha Wan  Kowloon",
        "country": "HK"
    },
    "001AD6": {
        "oui_hex": "00-1A-D6",
        "organization": "JIAGNSU AETNA ELECTRIC CO.,LTD",
        "address_1": "NO.571 QIANHU ROAD,QIANQIAO INDUSTRY PARK,WUXI,JIANGSU,CHINA",
        "address_2": "WUXI  JIANGSU  214151",
        "country": "CN"
    },
    "001AD4": {
        "oui_hex": "00-1A-D4",
        "organization": "iPOX Technology Co., Ltd.",
        "address_1": "15F-1, No.186, Jian-Yi Rd., Chung-Ho City,",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "001B14": {
        "oui_hex": "00-1B-14",
        "organization": "Carex Lighting Equipment Factory",
        "address_1": "50 Chang Tang Rd., Yan Tian District,",
        "address_2": "  Guangdong province",
        "country": "CN"
    },
    "001B15": {
        "oui_hex": "00-1B-15",
        "organization": "Voxtel, Inc.",
        "address_1": "12725 SW Millikan Way",
        "address_2": "Beaverton  OR  97005",
        "country": "US"
    },
    "001B09": {
        "oui_hex": "00-1B-09",
        "organization": "Matrix Telecom Pvt. Ltd.",
        "address_1": "394, GIDC, Makarpura,",
        "address_2": "Vadodara  Gujarat  390010",
        "country": "IN"
    },
    "001B03": {
        "oui_hex": "00-1B-03",
        "organization": "Action Technology (SZ) Co., Ltd",
        "address_1": "Action Technology Building Baoyuan Road, Xixiang, Bao'an District",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "001AFB": {
        "oui_hex": "00-1A-FB",
        "organization": "Joby Inc.",
        "address_1": "1535 Mission St.",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "001AFD": {
        "oui_hex": "00-1A-FD",
        "organization": "EVOLIS",
        "address_1": "29 avenue de la fontaine",
        "address_2": "Beaucouze    49070",
        "country": "FR"
    },
    "001B1E": {
        "oui_hex": "00-1B-1E",
        "organization": "HART Communication Foundation",
        "address_1": "STE 1-350",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "001B4C": {
        "oui_hex": "00-1B-4C",
        "organization": "Signtech",
        "address_1": "609 Seonil Technopia 609",
        "address_2": "Sungnamsi  Kyunggido  462-120",
        "country": "KR"
    },
    "001AD5": {
        "oui_hex": "00-1A-D5",
        "organization": "KMC CHAIN INDUSTRIAL CO., LTD.",
        "address_1": "7F-8, No. 81, Sui-Lih Rd., Hsinchu",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001AD0": {
        "oui_hex": "00-1A-D0",
        "organization": "Albis Technologies AG",
        "address_1": "Albisriederstrasse 199",
        "address_2": "CH 8047  Zuerich",
        "country": "CH"
    },
    "001AD3": {
        "oui_hex": "00-1A-D3",
        "organization": "Vamp Ltd.",
        "address_1": "PO Box 810",
        "address_2": "Vaasa    65101",
        "country": "FI"
    },
    "001AD8": {
        "oui_hex": "00-1A-D8",
        "organization": "AlsterAero GmbH",
        "address_1": "Heidenkampsweg 45",
        "address_2": "Hamburg    20097",
        "country": "DE"
    },
    "001ADA": {
        "oui_hex": "00-1A-DA",
        "organization": "Biz-2-Me Inc.",
        "address_1": "1301 West Eau Gallie Blvd",
        "address_2": "Melbourne  FL  32935",
        "country": "US"
    },
    "001A6F": {
        "oui_hex": "00-1A-6F",
        "organization": "MI.TEL s.r.l.",
        "address_1": "VIA GUIDO ROSSA, 22",
        "address_2": "CORNATE D'ADDA  MILANO  20040",
        "country": "IT"
    },
    "001A71": {
        "oui_hex": "00-1A-71",
        "organization": "Diostech Co., Ltd.",
        "address_1": "151-21, Buk-ri, Namsa-myeon,",
        "address_2": "Yongin-city  Gyeonggi-do  449 884",
        "country": "KR"
    },
    "001A69": {
        "oui_hex": "00-1A-69",
        "organization": "Wuhan Yangtze Optical Technology CO.,Ltd.",
        "address_1": "4#,Guanshan 2 Road",
        "address_2": "Wuhan  Hubei  430073",
        "country": "CN"
    },
    "001A67": {
        "oui_hex": "00-1A-67",
        "organization": "Infinite QL Sdn Bhd",
        "address_1": "G.02, Block A, Dataran Hamodal",
        "address_2": "Petaling Jaya  Selangor Darul Ehsan  46300",
        "country": "MY"
    },
    "001AC3": {
        "oui_hex": "00-1A-C3",
        "organization": "Scientific-Atlanta, Inc",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001ABF": {
        "oui_hex": "00-1A-BF",
        "organization": "TRUMPF Laser Marking Systems AG",
        "address_1": "Ausserfeld",
        "address_2": "Gruesch  GR  7214",
        "country": "CH"
    },
    "001AB8": {
        "oui_hex": "00-1A-B8",
        "organization": "Anseri Corporation",
        "address_1": "35E Industrial Way",
        "address_2": "Rochester  NH  03867",
        "country": "US"
    },
    "001ABC": {
        "oui_hex": "00-1A-BC",
        "organization": "U4EA Technologies Ltd",
        "address_1": "City Point",
        "address_2": "Bristol    BS1 6PL",
        "country": "GB"
    },
    "001ACB": {
        "oui_hex": "00-1A-CB",
        "organization": "Autocom Products Ltd",
        "address_1": "Unit 4 Tachbrook Link, Tachbrook Park Drive",
        "address_2": "Warwick  Warwickshire  CV34 6RH",
        "country": "GB"
    },
    "001ACF": {
        "oui_hex": "00-1A-CF",
        "organization": "C.T. ELETTRONICA",
        "address_1": "Via Caduti di Nassiriya 5 B",
        "address_2": "Barberino Val D'Elsa (FI)    50021",
        "country": "IT"
    },
    "001AA3": {
        "oui_hex": "00-1A-A3",
        "organization": "DELORME",
        "address_1": "2 DELORME DRIVE",
        "address_2": "YARMOUTH  MAINE  04096",
        "country": "US"
    },
    "001A9B": {
        "oui_hex": "00-1A-9B",
        "organization": "ADEC & Parter AG",
        "address_1": "Staldenbachstrasse 30",
        "address_2": "Pfaeffikon  ZH  8808",
        "country": "CH"
    },
    "001A9D": {
        "oui_hex": "00-1A-9D",
        "organization": "Skipper Wireless, Inc.",
        "address_1": "Shinjuku-Sumitomo Bldg. 20F",
        "address_2": "Shinjuku  Tokyo  163-0220",
        "country": "JP"
    },
    "001A85": {
        "oui_hex": "00-1A-85",
        "organization": "NV Michel Van de Wiele",
        "address_1": "M. Vandewielestraat 7",
        "address_2": "Marke  West-Vlaanderen  8510",
        "country": "BE"
    },
    "001A8E": {
        "oui_hex": "00-1A-8E",
        "organization": "3Way Networks Ltd",
        "address_1": "7200 Cambridge Research Park",
        "address_2": "Cambridge  Cambridgeshire  CB5 9TL",
        "country": "GB"
    },
    "001A44": {
        "oui_hex": "00-1A-44",
        "organization": "JWTrading Co., Ltd",
        "address_1": "1590 Kwanyang-dong, Dongan-ku",
        "address_2": "Ahnyang  Kyungki - do  431-060",
        "country": "KR"
    },
    "001A49": {
        "oui_hex": "00-1A-49",
        "organization": "Micro Vision Co.,LTD",
        "address_1": "1-9-15",
        "address_2": "Niigata-city  Niigata-ken  950-0986",
        "country": "JP"
    },
    "001A3D": {
        "oui_hex": "00-1A-3D",
        "organization": "Ajin Vision Co.,Ltd",
        "address_1": "1404, Mario-Tower, 222-12",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "001A41": {
        "oui_hex": "00-1A-41",
        "organization": "INOCOVA Co.,Ltd",
        "address_1": "5F SEOUL BD.736-17",
        "address_2": "Yeoksam-Dong, Kangnam-Ku  SEOUL  135-924",
        "country": "KR"
    },
    "001A33": {
        "oui_hex": "00-1A-33",
        "organization": "ASI Communications, Inc.",
        "address_1": "1042 E Guadalupe Rd",
        "address_2": "Tempe  AZ  85283",
        "country": "US"
    },
    "001A23": {
        "oui_hex": "00-1A-23",
        "organization": "Ice Qube, Inc",
        "address_1": "141 Wilson Ave",
        "address_2": "Greensburg  Pa  15601",
        "country": "US"
    },
    "001A1D": {
        "oui_hex": "00-1A-1D",
        "organization": "PChome Online Inc.",
        "address_1": "11F, 105, Sec. 2, Tun-Hwa S. Rd.",
        "address_2": "  Taipei  106",
        "country": "TW"
    },
    "001A17": {
        "oui_hex": "00-1A-17",
        "organization": "Teak Technologies, Inc.",
        "address_1": "2901 Tasman Dr., Ste. #210",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001A1C": {
        "oui_hex": "00-1A-1C",
        "organization": "GT&T Engineering Pte Ltd",
        "address_1": "2 Ang Mo Kio St.64, Econ Building, #04-00",
        "address_2": "  Singapore  569084",
        "country": "SG"
    },
    "001A1F": {
        "oui_hex": "00-1A-1F",
        "organization": "Coastal Environmental Systems",
        "address_1": "820 First Avenue South",
        "address_2": "Seattle  wa  98134",
        "country": "US"
    },
    "001A64": {
        "oui_hex": "00-1A-64",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "001A51": {
        "oui_hex": "00-1A-51",
        "organization": "Alfred Mann Foundation",
        "address_1": "P.O. Box 905",
        "address_2": "Santa Clarita  CA  91380-9005",
        "country": "US"
    },
    "001A55": {
        "oui_hex": "00-1A-55",
        "organization": "ACA-Digital Corporation",
        "address_1": "17 F, No. 866-7, Chung Cheng Rd.,",
        "address_2": "Chung Ho City  Taipei County  23586",
        "country": "TW"
    },
    "0019E6": {
        "oui_hex": "00-19-E6",
        "organization": "TOYO MEDIC CO.,LTD.",
        "address_1": "1-17-22 Kitahorie, Nishi-ku",
        "address_2": "Osaka    550-0014",
        "country": "JP"
    },
    "0019E2": {
        "oui_hex": "00-19-E2",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0019E8": {
        "oui_hex": "00-19-E8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019DF": {
        "oui_hex": "00-19-DF",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290-1102",
        "country": "US"
    },
    "0019DD": {
        "oui_hex": "00-19-DD",
        "organization": "FEI-Zyfer, Inc.",
        "address_1": "1515 S. Manchester",
        "address_2": "Anaheim  CA  92802",
        "country": "US"
    },
    "0019B2": {
        "oui_hex": "00-19-B2",
        "organization": "XYnetsoft Co.,Ltd",
        "address_1": "NO.158Zhenyu Street High Industries Development area",
        "address_2": "ChangChun  JiLin  130000",
        "country": "CN"
    },
    "0019A4": {
        "oui_hex": "00-19-A4",
        "organization": "Austar Technology (hang zhou) Co.,Ltd",
        "address_1": "7-402,West Lake Software Part",
        "address_2": "Hang Zhou  Zhe Jiang  310012",
        "country": "CN"
    },
    "0019AA": {
        "oui_hex": "00-19-AA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019B1": {
        "oui_hex": "00-19-B1",
        "organization": "Arrow7 Corporation",
        "address_1": "Kamijima 3-27-7",
        "address_2": "Hamamatsu  Shizuoka  433-8122",
        "country": "JP"
    },
    "0019B3": {
        "oui_hex": "00-19-B3",
        "organization": "Stanford Research Systems",
        "address_1": "1290-D Reamwood Ave",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "001A0A": {
        "oui_hex": "00-1A-0A",
        "organization": "Adaptive Micro-Ware Inc.",
        "address_1": "6917 Innovation Blvd",
        "address_2": "Fort Wayne  IN  46818",
        "country": "US"
    },
    "001A05": {
        "oui_hex": "00-1A-05",
        "organization": "OPTIBASE LTD",
        "address_1": "7 Shankar St.",
        "address_2": "Herzliya  ISRAEL  46120",
        "country": "IL"
    },
    "0019D4": {
        "oui_hex": "00-19-D4",
        "organization": "ICX Technologies",
        "address_1": "3440 Francis-Hughes",
        "address_2": "Laval  Quebec  H7L 5A9",
        "country": "CA"
    },
    "0019CF": {
        "oui_hex": "00-19-CF",
        "organization": "SALICRU, S.A.",
        "address_1": "Av. Serra , 100",
        "address_2": "Sta.Ma.Palautordera  Barcelona  08460",
        "country": "ES"
    },
    "0019FC": {
        "oui_hex": "00-19-FC",
        "organization": "PT. Ufoakses Sukses Luarbiasa",
        "address_1": "Jl. Sultan Hasanudin No. 41",
        "address_2": "Jakarta Selatan  DKI Jakarta  12160",
        "country": "ID"
    },
    "0019F4": {
        "oui_hex": "00-19-F4",
        "organization": "Convergens Oy Ltd",
        "address_1": "Westendintie 99 B",
        "address_2": "Espoo  Uusimaa  FIN-02160",
        "country": "FI"
    },
    "001996": {
        "oui_hex": "00-19-96",
        "organization": "TurboChef Technologies Inc.",
        "address_1": "4240 International Parkway",
        "address_2": "Carrollton  Texas  75007",
        "country": "US"
    },
    "001997": {
        "oui_hex": "00-19-97",
        "organization": "Soft Device Sdn Bhd",
        "address_1": "67-2 Jalan 2/27F",
        "address_2": "Kuala Lumpur  WP  53300",
        "country": "MY"
    },
    "001998": {
        "oui_hex": "00-19-98",
        "organization": "SATO CORPORATION",
        "address_1": "1-207,ONARI-CHO,",
        "address_2": "SAITAMA-SHI  SAITAMA  330-0852",
        "country": "JP"
    },
    "00199C": {
        "oui_hex": "00-19-9C",
        "organization": "CTRING",
        "address_1": "#514, World Meridian Venture Center II",
        "address_2": "Keumcheon-gu  Seoul  153-803",
        "country": "KR"
    },
    "001946": {
        "oui_hex": "00-19-46",
        "organization": "Cianet Industria e Comercio S/A",
        "address_1": "rod SC401, km01 Tecnopolis/Alfama 4o. Andar",
        "address_2": "Florianopolis  Santa Catarina  88030-902",
        "country": "BR"
    },
    "001949": {
        "oui_hex": "00-19-49",
        "organization": "TENTEL  COMTECH CO., LTD.",
        "address_1": "3/F., NO. 42, LANE 80, SEC. 3, NAN-KANG RD.,",
        "address_2": "TAIPEI    115",
        "country": "TW"
    },
    "001944": {
        "oui_hex": "00-19-44",
        "organization": "Fossil Partners, L.P.",
        "address_1": "2280 N. Greenville Ave.",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "001971": {
        "oui_hex": "00-19-71",
        "organization": "Guangzhou Unicomp Technology Co.,Ltd",
        "address_1": "7/F,North Tower,Jinshan Building.No.248",
        "address_2": "Guangzhou  Guangdong  510630",
        "country": "CN"
    },
    "001964": {
        "oui_hex": "00-19-64",
        "organization": "Doorking Inc.",
        "address_1": "120 Glasgow St.",
        "address_2": "Inglewood  CA.  90301",
        "country": "US"
    },
    "001976": {
        "oui_hex": "00-19-76",
        "organization": "Xipher Technologies, LLC",
        "address_1": "156 River Road",
        "address_2": "Willington  CT  06279",
        "country": "US"
    },
    "00196C": {
        "oui_hex": "00-19-6C",
        "organization": "ETROVISION TECHNOLOGY",
        "address_1": "2F, 19-5 San Chung Rd.,",
        "address_2": "TAIPEI    115",
        "country": "TW"
    },
    "001967": {
        "oui_hex": "00-19-67",
        "organization": "TELDAT Sp.J.",
        "address_1": "Kijowska 44",
        "address_2": "Bydgoszcz  woj. kujawsko-pomorskie  85-703",
        "country": "PL"
    },
    "001952": {
        "oui_hex": "00-19-52",
        "organization": "ACOGITO Co., Ltd",
        "address_1": "#501 Shinyoung Palace Tower, 246-2, Seohyun",
        "address_2": "Sungnam  Kyunggi  463-824",
        "country": "KR"
    },
    "00198B": {
        "oui_hex": "00-19-8B",
        "organization": "Novera Optics Korea, Inc.",
        "address_1": "463-1 Jeon Min Dong Yuseong Gu",
        "address_2": "Deajeon    305-811",
        "country": "KR"
    },
    "001961": {
        "oui_hex": "00-19-61",
        "organization": "Blaupunkt  Embedded Systems GmbH",
        "address_1": "Bahnhofsstrasse 16",
        "address_2": "Schlitz    36110",
        "country": "DE"
    },
    "001942": {
        "oui_hex": "00-19-42",
        "organization": "ON SOFTWARE INTERNATIONAL LIMITED",
        "address_1": "9F, NO. 17, SEC. 1, CHENG-TE RD.",
        "address_2": "TAIPEI    103",
        "country": "TW"
    },
    "00193F": {
        "oui_hex": "00-19-3F",
        "organization": "RDI technology(Shenzhen) Co.,LTD",
        "address_1": "Building C1&C2,  Xin Tang Industrial Zone,East BaiShiXia Village, Fuyong Town, Baoan District",
        "address_2": "SHENZHEN  GUANGDONG province  518103",
        "country": "CN"
    },
    "001941": {
        "oui_hex": "00-19-41",
        "organization": "Pitney Bowes, Inc",
        "address_1": "35 Waterview Drive",
        "address_2": "Shelton  CT  06484",
        "country": "US"
    },
    "0018FD": {
        "oui_hex": "00-18-FD",
        "organization": "Optimal Technologies International Inc.",
        "address_1": "12 Spanish Main Drive",
        "address_2": "Freeport  GBI",
        "country": "BS"
    },
    "0018F0": {
        "oui_hex": "00-18-F0",
        "organization": "JOYTOTO Co., Ltd.",
        "address_1": "3F Sungwoo Bldg. 717-3, Sooseo-Dong",
        "address_2": "Seoul    135-220",
        "country": "KR"
    },
    "0018E9": {
        "oui_hex": "00-18-E9",
        "organization": "Numata Corporation",
        "address_1": "8-2-39 nanko-higashi",
        "address_2": "Osaka-shi  Osaka-fu  559-0031",
        "country": "JP"
    },
    "001908": {
        "oui_hex": "00-19-08",
        "organization": "Duaxes Corporation",
        "address_1": "2-5, Kasumigaseki 3-chome, Chiyoda-ku.",
        "address_2": "Tokyo  Foreign  100-6014",
        "country": "JP"
    },
    "00190C": {
        "oui_hex": "00-19-0C",
        "organization": "Encore Electronics, Inc.",
        "address_1": "16483 Old Valley Blvd.",
        "address_2": "La Puente  CA  91744",
        "country": "US"
    },
    "001919": {
        "oui_hex": "00-19-19",
        "organization": "ASTEL Inc.",
        "address_1": "59-7 Jang-dong Yusung-Gu",
        "address_2": "Daejeon  Chungnam  305-343",
        "country": "KR"
    },
    "00192D": {
        "oui_hex": "00-19-2D",
        "organization": "Nokia Corporation",
        "address_1": "Rensingstraße 15",
        "address_2": "Bochum  NRW  44807",
        "country": "DE"
    },
    "0018EF": {
        "oui_hex": "00-18-EF",
        "organization": "Escape Communications, Inc.",
        "address_1": "2615 Pacific Coast Hwy",
        "address_2": "Hermosa Beach  CA  90254",
        "country": "US"
    },
    "0018E6": {
        "oui_hex": "00-18-E6",
        "organization": "Computer Hardware Design SIA",
        "address_1": "Dzelzavas 120i",
        "address_2": "Riga    LV-1021",
        "country": "LV"
    },
    "001930": {
        "oui_hex": "00-19-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001927": {
        "oui_hex": "00-19-27",
        "organization": "ImCoSys Ltd",
        "address_1": "Bundesstrasse 5",
        "address_2": "Zug  ZG  6300",
        "country": "CH"
    },
    "0018F7": {
        "oui_hex": "00-18-F7",
        "organization": "Kameleon Technologies",
        "address_1": "217, rue St Honoré",
        "address_2": "Paris    75001",
        "country": "FR"
    },
    "001885": {
        "oui_hex": "00-18-85",
        "organization": "Avigilon Corporation",
        "address_1": "Box 378, 101 - 1001 West Broadway",
        "address_2": "Vancouver  BC  V6H 4E4",
        "country": "CA"
    },
    "001888": {
        "oui_hex": "00-18-88",
        "organization": "GOTIVE a.s.",
        "address_1": "Zámocká 34",
        "address_2": "Bratislava    81101",
        "country": "SK"
    },
    "00188A": {
        "oui_hex": "00-18-8A",
        "organization": "Infinova LLC",
        "address_1": "51 Stouts Lane, Unit 1 & 2",
        "address_2": "Monmouth Junction  New Jersey  08852",
        "country": "US"
    },
    "001886": {
        "oui_hex": "00-18-86",
        "organization": "EL-TECH, INC.",
        "address_1": "A-711, WOOLIM LION'S VALLEY, 371-28",
        "address_2": "SEOUL    150-834",
        "country": "KR"
    },
    "001887": {
        "oui_hex": "00-18-87",
        "organization": "Metasystem SpA",
        "address_1": "Via Oberdan 16",
        "address_2": "Reggio Emilia  RE  42100",
        "country": "IT"
    },
    "0018BE": {
        "oui_hex": "00-18-BE",
        "organization": "ANSA Corporation",
        "address_1": "17F, No. 738, Chung Cheng Road",
        "address_2": "Chung Ho City  Taipei County  235",
        "country": "TW"
    },
    "0018BA": {
        "oui_hex": "00-18-BA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0018B4": {
        "oui_hex": "00-18-B4",
        "organization": "Dawon Media Inc.",
        "address_1": "Rm503. woolim e-biz center 170-5, Guro3dong Gurogu,",
        "address_2": "Seoul    152-769",
        "country": "KR"
    },
    "0018B6": {
        "oui_hex": "00-18-B6",
        "organization": "S3C, Inc.",
        "address_1": "1010 Stewart Dr.",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "0018A3": {
        "oui_hex": "00-18-A3",
        "organization": "ZIPPY TECHNOLOGY CORP.",
        "address_1": "10F, No. 50, Mincyuan Rd., Sindian City",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "0018A0": {
        "oui_hex": "00-18-A0",
        "organization": "Cierma Ascenseurs",
        "address_1": "17 avenue guiglionda de saint agathe",
        "address_2": "Nice  PACA  06300",
        "country": "FR"
    },
    "001893": {
        "oui_hex": "00-18-93",
        "organization": "SHENZHEN PHOTON BROADBAND TECHNOLOGY CO.,LTD",
        "address_1": "2/F Hivac BLD,2th Langshan Rd,North Hi-Tech Industrial",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0018B1": {
        "oui_hex": "00-18-B1",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00187B": {
        "oui_hex": "00-18-7B",
        "organization": "4NSYS Co. Ltd.",
        "address_1": "3F, Hana Bldg",
        "address_2": "Guro-Gu  Seoul  152-100",
        "country": "KR"
    },
    "00187F": {
        "oui_hex": "00-18-7F",
        "organization": "ZODIANET",
        "address_1": "23, rue des Fraisettes",
        "address_2": "PALAISEAU  ESSONNE  91120",
        "country": "FR"
    },
    "00187E": {
        "oui_hex": "00-18-7E",
        "organization": "RGB Spectrum",
        "address_1": "950 Marina Village Pkwy",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "00189D": {
        "oui_hex": "00-18-9D",
        "organization": "Navcast Inc.",
        "address_1": "Suite 612, 6711 Mississauga Road",
        "address_2": "Mississauga  ON  m2r 1a3",
        "country": "CA"
    },
    "0018D6": {
        "oui_hex": "00-18-D6",
        "organization": "Swirlnet A/S",
        "address_1": "Diplomvej 381",
        "address_2": "Lyngby    DK-2800",
        "country": "DK"
    },
    "0018CD": {
        "oui_hex": "00-18-CD",
        "organization": "Erae Electronics Industry Co., Ltd",
        "address_1": "#371-51, Gasan-dong",
        "address_2": "Geumchen-gu  Seoul  153-803",
        "country": "KR"
    },
    "0018DB": {
        "oui_hex": "00-18-DB",
        "organization": "EPL Technology Ltd",
        "address_1": "LongDong,Longgang District",
        "address_2": "ShenZhen  GuangDong  518116",
        "country": "CN"
    },
    "0018C8": {
        "oui_hex": "00-18-C8",
        "organization": "ISONAS Inc.",
        "address_1": "6325 Gunpark Drive",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "001849": {
        "oui_hex": "00-18-49",
        "organization": "nVent, Schroff GmbH",
        "address_1": "Langenalber Strasse 96-100",
        "address_2": "Straubenhardt    75334",
        "country": "DE"
    },
    "001846": {
        "oui_hex": "00-18-46",
        "organization": "Crypto S.A.",
        "address_1": "V. Ipirou 45",
        "address_2": "Marousi  Athens  15125",
        "country": "GR"
    },
    "001845": {
        "oui_hex": "00-18-45",
        "organization": "Pulsar-Telecom LLC.",
        "address_1": "Zaharova, 18a",
        "address_2": "Penza    440044",
        "country": "RU"
    },
    "00181E": {
        "oui_hex": "00-18-1E",
        "organization": "GDX Technologies Ltd.",
        "address_1": "61-63 Back Sneddon Street",
        "address_2": "Paisley  Renfrewshire  PA3 2DD",
        "country": "GB"
    },
    "00181C": {
        "oui_hex": "00-18-1C",
        "organization": "Exterity Limited",
        "address_1": "Ridge Way, Hillend Industrial Estate",
        "address_2": "Dunfermline  Fife  KY11 9JD",
        "country": "GB"
    },
    "001863": {
        "oui_hex": "00-18-63",
        "organization": "Veritech Electronics Limited",
        "address_1": "8F, 67, Sec. 1, Zhongshan Road, Xinzhuang,",
        "address_2": "Taipei    242",
        "country": "TW"
    },
    "00185A": {
        "oui_hex": "00-18-5A",
        "organization": "uControl, Inc.",
        "address_1": "5914 W. Courtyard Drive",
        "address_2": "Austin  TX  78730",
        "country": "US"
    },
    "001852": {
        "oui_hex": "00-18-52",
        "organization": "StorLink Semiconductors, Inc.",
        "address_1": "1804 N. Shoreline Boulevard",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001850": {
        "oui_hex": "00-18-50",
        "organization": "Secfone Kft",
        "address_1": "51 Bercsenyi str",
        "address_2": "Jaszbereny    5100",
        "country": "HU"
    },
    "001858": {
        "oui_hex": "00-18-58",
        "organization": "TagMaster AB",
        "address_1": "Kronborgsgréind 1",
        "address_2": "Kista  Stockholm  S-16487",
        "country": "SE"
    },
    "001824": {
        "oui_hex": "00-18-24",
        "organization": "Kimaldi Electronics, S.L.",
        "address_1": "Ctra. de Rubí, 292 B",
        "address_2": "Terrassa  Barcelona  08228",
        "country": "ES"
    },
    "00183D": {
        "oui_hex": "00-18-3D",
        "organization": "Vertex Link Corporation",
        "address_1": "Meitetsu Fudosan Takebashi Bldg 6F",
        "address_2": "Chiyoda-ku  Tokyo  101-0054",
        "country": "JP"
    },
    "001825": {
        "oui_hex": "00-18-25",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "001879": {
        "oui_hex": "00-18-79",
        "organization": "dSys",
        "address_1": "Soeflinger Str. 100",
        "address_2": "Ulm  BW  89077",
        "country": "DE"
    },
    "001803": {
        "oui_hex": "00-18-03",
        "organization": "ArcSoft Shanghai Co. LTD",
        "address_1": "20th Floor, Suite (EAST) 2008, China Merchants Plaza, 333",
        "address_2": "Shanghai    200041",
        "country": "CN"
    },
    "0017EF": {
        "oui_hex": "00-17-EF",
        "organization": "IBM Corp",
        "address_1": "2051 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0017F5": {
        "oui_hex": "00-17-F5",
        "organization": "LIG NEOPTEK",
        "address_1": "926 Gosaek-dong",
        "address_2": "Suwon-si  Gyeonggi-do  441-813",
        "country": "KR"
    },
    "0017CD": {
        "oui_hex": "00-17-CD",
        "organization": "CEC Wireless R&D Ltd.",
        "address_1": "West M5 Building,No.1 East Road",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "0017D0": {
        "oui_hex": "00-17-D0",
        "organization": "Opticom Communications, LLC",
        "address_1": "1050 Connecticut Avenue, NW",
        "address_2": "Washington  DC  20036",
        "country": "US"
    },
    "0017C6": {
        "oui_hex": "00-17-C6",
        "organization": "Cross Match Technologies Inc",
        "address_1": "400, boul. Jean-Lesage",
        "address_2": "Québec    G1K 8W1",
        "country": "CA"
    },
    "0017FE": {
        "oui_hex": "00-17-FE",
        "organization": "TALOS SYSTEM INC.",
        "address_1": "6191 CORNERSTONE CT. STE #109",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "0017F8": {
        "oui_hex": "00-17-F8",
        "organization": "Motech Industries Inc.",
        "address_1": "6F, No. 248, Sec. 3, Pei-Shen Rd.,",
        "address_2": "Taipei Hsien    222",
        "country": "TW"
    },
    "0017C3": {
        "oui_hex": "00-17-C3",
        "organization": "KTF Technologies Inc.",
        "address_1": "4th Fl., Central Tower, 265-3, Seohyun-Dong",
        "address_2": "Sungnam-City  Kyunggi-Do  463-769",
        "country": "KR"
    },
    "0017B7": {
        "oui_hex": "00-17-B7",
        "organization": "Tonze Technology Co.",
        "address_1": "5F-10, No.6, Lane 180,",
        "address_2": "Taipei    11490",
        "country": "TW"
    },
    "0017AB": {
        "oui_hex": "00-17-AB",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001807": {
        "oui_hex": "00-18-07",
        "organization": "Fanstel Corp.",
        "address_1": "7466 E. Monte Cristo Ave.",
        "address_2": "Scottsdale  Arizona  85260",
        "country": "US"
    },
    "001808": {
        "oui_hex": "00-18-08",
        "organization": "SightLogix, Inc.",
        "address_1": "745 Alexander Road",
        "address_2": "Princeton  NJ  08540",
        "country": "US"
    },
    "0017CE": {
        "oui_hex": "00-17-CE",
        "organization": "Screen Service Spa",
        "address_1": "Via G.Di Vittorio 17",
        "address_2": "  Brescia  25125",
        "country": "IT"
    },
    "0017DB": {
        "oui_hex": "00-17-DB",
        "organization": "CANKO TECHNOLOGIES INC.",
        "address_1": "5 FL. DONG SUNG BLDG. 17-8",
        "address_2": "SEOUL    150-874",
        "country": "KR"
    },
    "0017D6": {
        "oui_hex": "00-17-D6",
        "organization": "Bluechips Microhouse Co.,Ltd.",
        "address_1": "212/2 M.10 Tambol Umong",
        "address_2": "Lamphun    51150",
        "country": "TH"
    },
    "001787": {
        "oui_hex": "00-17-87",
        "organization": "Brother, Brother & Sons ApS",
        "address_1": "Ved Amagerbanen 9",
        "address_2": "Copenhagen S    DK-2300",
        "country": "DK"
    },
    "001789": {
        "oui_hex": "00-17-89",
        "organization": "Zenitron Corporation",
        "address_1": "No. 8, Lane 250, Sinhu 2nd Rd., Neihu District,",
        "address_2": "Taipei    11494",
        "country": "TW"
    },
    "001760": {
        "oui_hex": "00-17-60",
        "organization": "Naito Densei Machida MFG.CO.,LTD",
        "address_1": "2-17-28 Fuchinobe",
        "address_2": "Sagamihara  Kanagawa  229-0006",
        "country": "JP"
    },
    "001761": {
        "oui_hex": "00-17-61",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "001768": {
        "oui_hex": "00-17-68",
        "organization": "Zinwave Ltd",
        "address_1": "Zinwave Ltd, Harston Mill",
        "address_2": "Cambridge  Cambridgeshire  CB2 5GG",
        "country": "GB"
    },
    "001769": {
        "oui_hex": "00-17-69",
        "organization": "Cymphonix Corp",
        "address_1": "8871 S. Sandy Parkway, Suite 150",
        "address_2": "Sandy  UT  84070",
        "country": "US"
    },
    "001762": {
        "oui_hex": "00-17-62",
        "organization": "Solar Technology, Inc.",
        "address_1": "7620 Cetronia Road",
        "address_2": "Allentown  PA  18106",
        "country": "US"
    },
    "00178F": {
        "oui_hex": "00-17-8F",
        "organization": "NINGBO YIDONG ELECTRONIC CO.,LTD.",
        "address_1": "No.65 Siming East Rd",
        "address_2": "Yuyao City, Zhejiang Province  Zhejiang Province China  P.C 315400",
        "country": "CN"
    },
    "001794": {
        "oui_hex": "00-17-94",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00178A": {
        "oui_hex": "00-17-8A",
        "organization": "DARTS TECHNOLOGIES CORP.",
        "address_1": "2F,No.119,Chien Kang Rd.,",
        "address_2": "Chung-Ho  Taipei Hsien  235",
        "country": "TW"
    },
    "001734": {
        "oui_hex": "00-17-34",
        "organization": "ADC Telecommunications",
        "address_1": "541 E Trimble Road",
        "address_2": "San Jose  California  95134-1224",
        "country": "US"
    },
    "00172E": {
        "oui_hex": "00-17-2E",
        "organization": "FXC Inc.",
        "address_1": "10-16 6F, Nihonbashi Tomizawa-Chou, Chuo-ku",
        "address_2": "Tokyo    103-0006",
        "country": "JP"
    },
    "00172B": {
        "oui_hex": "00-17-2B",
        "organization": "Global Technologies Inc.",
        "address_1": "4/F Kicox Bldg.,188-5,Guro-Dong,Guro-gu,",
        "address_2": "  Seoul  152-848",
        "country": "KR"
    },
    "001772": {
        "oui_hex": "00-17-72",
        "organization": "ASTRO Strobel Kommunikationssysteme GmbH",
        "address_1": "Olefant 1-3",
        "address_2": "Bergisch Gladbach  NRW  51427",
        "country": "DE"
    },
    "00173E": {
        "oui_hex": "00-17-3E",
        "organization": "LeucotronEquipamentos Ltda.",
        "address_1": "Rua Jorge Dionisio Barbosa, 312",
        "address_2": "Santa Rita do Sapucai  Minas Gerais  37.540-000",
        "country": "BR"
    },
    "001798": {
        "oui_hex": "00-17-98",
        "organization": "Azonic Technology Co., LTD",
        "address_1": "15F-3, No. 163, Sec., 1 Keelung Rd.",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001747": {
        "oui_hex": "00-17-47",
        "organization": "Trimble",
        "address_1": "345 SW Avery Ave",
        "address_2": "Corvallis  OR  97333",
        "country": "US"
    },
    "00177A": {
        "oui_hex": "00-17-7A",
        "organization": "ASSA ABLOY AB",
        "address_1": "Theres Svenssons gata 15",
        "address_2": "Goteborg    41755",
        "country": "SE"
    },
    "0016F4": {
        "oui_hex": "00-16-F4",
        "organization": "Eidicom Co., Ltd.",
        "address_1": "Polychem B/D 4th Floor, 900-1",
        "address_2": "Anyang-si  Kyeonggi-do  431-060",
        "country": "KR"
    },
    "0016E7": {
        "oui_hex": "00-16-E7",
        "organization": "Dynamix Promotions Limited",
        "address_1": "788-790, Finchley Road",
        "address_2": "London    NW11 7TJ",
        "country": "GB"
    },
    "0016E5": {
        "oui_hex": "00-16-E5",
        "organization": "FORDLEY DEVELOPMENT LIMITED",
        "address_1": "ROOM 706, 7TH FLOOR, YU SUNG BOON BUILDING, 107-111 DES VOEUX ROAD, CENTRAL,",
        "address_2": "",
        "country": "HK"
    },
    "0016E6": {
        "oui_hex": "00-16-E6",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan",
        "address_2": "    324",
        "country": "TW"
    },
    "001720": {
        "oui_hex": "00-17-20",
        "organization": "Image Sensing Systems, Inc.",
        "address_1": "1600 University Ave. W.",
        "address_2": "St. Paul  MN  55104",
        "country": "US"
    },
    "00171A": {
        "oui_hex": "00-17-1A",
        "organization": "Winegard Company",
        "address_1": "3000 Kirkwood Street",
        "address_2": "Burlington  IA  52601",
        "country": "US"
    },
    "0016C8": {
        "oui_hex": "00-16-C8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0016C4": {
        "oui_hex": "00-16-C4",
        "organization": "SiRF Technology, Inc.",
        "address_1": "217 Devcon Dr.",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "0016F3": {
        "oui_hex": "00-16-F3",
        "organization": "CAST Information Co., Ltd",
        "address_1": "5F MSA Bldg. 891-43 Dacchi-Dong,",
        "address_2": "SEOUL    135-280",
        "country": "KR"
    },
    "0016F5": {
        "oui_hex": "00-16-F5",
        "organization": "Dalian Golden Hualu Digital Technology Co.,Ltd",
        "address_1": "No.1 Hua Road,Qixianling",
        "address_2": "Dalian  LiaoNing  116023",
        "country": "CN"
    },
    "0016F1": {
        "oui_hex": "00-16-F1",
        "organization": "OmniSense, LLC",
        "address_1": "72 sams point road",
        "address_2": "Ladys Island  SC  29907",
        "country": "US"
    },
    "0016DD": {
        "oui_hex": "00-16-DD",
        "organization": "Gigabeam Corporation",
        "address_1": "407 Springpark Place",
        "address_2": "Herndon  VA  20170",
        "country": "US"
    },
    "00171C": {
        "oui_hex": "00-17-1C",
        "organization": "NT MicroSystems, Inc.",
        "address_1": "1-5-3-2F Tamagawadai",
        "address_2": "Setagaya  Tokyo  158-0096",
        "country": "JP"
    },
    "001716": {
        "oui_hex": "00-17-16",
        "organization": "Qno Technology Inc.",
        "address_1": "6F-2, No.25, Puding Road",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "001726": {
        "oui_hex": "00-17-26",
        "organization": "m2c Electronic Technology Ltd.",
        "address_1": "2403, 24/F, Nanyang Plaza",
        "address_2": "Kwuntong  Hong Kong  999 999",
        "country": "CN"
    },
    "001721": {
        "oui_hex": "00-17-21",
        "organization": "FITRE S.p.A.",
        "address_1": "Via Valsolda, 15",
        "address_2": "MILANO  MI  20142",
        "country": "IT"
    },
    "0016F9": {
        "oui_hex": "00-16-F9",
        "organization": "CETRTA POT, d.o.o., Kranj",
        "address_1": "Planina 3",
        "address_2": "Kranj  SI  4000",
        "country": "SI"
    },
    "00170A": {
        "oui_hex": "00-17-0A",
        "organization": "INEW DIGITAL COMPANY",
        "address_1": "Supply Bureau 3th floor KT&G 203-1,",
        "address_2": "Daejeon    306-712",
        "country": "KR"
    },
    "0016BD": {
        "oui_hex": "00-16-BD",
        "organization": "ATI Industrial Automation",
        "address_1": "1031 Goodworth Drive",
        "address_2": "Apex  North Carolina  27539-3869",
        "country": "US"
    },
    "0016C0": {
        "oui_hex": "00-16-C0",
        "organization": "Semtech Corporation",
        "address_1": "200 Flynn Rd",
        "address_2": "Camarillo  California  93012",
        "country": "US"
    },
    "0016C2": {
        "oui_hex": "00-16-C2",
        "organization": "Avtec Systems Inc",
        "address_1": "14432 Albemarle Point Place",
        "address_2": "Chantilly  Virginia  20151",
        "country": "US"
    },
    "0016BA": {
        "oui_hex": "00-16-BA",
        "organization": "WEATHERNEWS INC.",
        "address_1": "NAKASE 1-3 MTG",
        "address_2": "CHIBA    262-0032",
        "country": "US"
    },
    "0016B2": {
        "oui_hex": "00-16-B2",
        "organization": "DriveCam Inc",
        "address_1": "3954 Murphy Canyon Road",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "0016B3": {
        "oui_hex": "00-16-B3",
        "organization": "Photonicbridges (China) Co., Ltd.",
        "address_1": "No. 900, Yishan road,",
        "address_2": "Shanghai    200233",
        "country": "US"
    },
    "0016AD": {
        "oui_hex": "00-16-AD",
        "organization": "BT-Links Company Limited",
        "address_1": "Rm 802, Nan Fung Centre, 264-298 Castle Peak Rd",
        "address_2": "",
        "country": "HK"
    },
    "00166E": {
        "oui_hex": "00-16-6E",
        "organization": "Arbitron Inc.",
        "address_1": "9705 Patuxent Woods Drive",
        "address_2": "Columbia  MD  21046",
        "country": "US"
    },
    "0016AF": {
        "oui_hex": "00-16-AF",
        "organization": "Shenzhen Union Networks Equipment Co.,Ltd.",
        "address_1": "Yihai Square east building 2307, Chuangye road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "00169E": {
        "oui_hex": "00-16-9E",
        "organization": "TV One Ltd",
        "address_1": "Unit V Continental Approach",
        "address_2": "Margate  Kent  CT9 4JG",
        "country": "GB"
    },
    "00166A": {
        "oui_hex": "00-16-6A",
        "organization": "TPS",
        "address_1": "145 quai de Stalingrad",
        "address_2": "Issy Les Moulineaux  Ile de France  92137",
        "country": "FR"
    },
    "001663": {
        "oui_hex": "00-16-63",
        "organization": "KBT Mobile",
        "address_1": "4F, Polaris I, 15-3, Jeongja-dong, Bundang-gu",
        "address_2": "Seongnam-si,  Gyeonggi-do  463-811",
        "country": "KR"
    },
    "00169F": {
        "oui_hex": "00-16-9F",
        "organization": "Vimtron Electronics Co., Ltd.",
        "address_1": "7F., No.9, Alley 2, Lane 35",
        "address_2": "Neihu District  Taipei City  11492",
        "country": "TW"
    },
    "00169A": {
        "oui_hex": "00-16-9A",
        "organization": "Quadrics Ltd",
        "address_1": "1 Bridewell Street",
        "address_2": "Bristol    BS1 2AA",
        "country": "GB"
    },
    "001692": {
        "oui_hex": "00-16-92",
        "organization": "Scientific-Atlanta, Inc.",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001691": {
        "oui_hex": "00-16-91",
        "organization": "Moser-Baer AG",
        "address_1": "Spitalstrasse 7",
        "address_2": "Sumiswald  BE  3454",
        "country": "CH"
    },
    "001688": {
        "oui_hex": "00-16-88",
        "organization": "ServerEngines LLC",
        "address_1": "209 N. Fair Oaks Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00168B": {
        "oui_hex": "00-16-8B",
        "organization": "Paralan Corporation",
        "address_1": "455 Ruffner St.",
        "address_2": "San Diego  CA  92111",
        "country": "US"
    },
    "001682": {
        "oui_hex": "00-16-82",
        "organization": "Pro Dex, Inc",
        "address_1": "1800 NW 169th Place",
        "address_2": "Beaverton  Oregon  97006",
        "country": "US"
    },
    "00160A": {
        "oui_hex": "00-16-0A",
        "organization": "SWEEX Europe BV",
        "address_1": "Ampereweg 3",
        "address_2": "Delft  Zuid-Holland  2627 BG",
        "country": "NL"
    },
    "001602": {
        "oui_hex": "00-16-02",
        "organization": "CEYON TECHNOLOGY CO.,LTD.",
        "address_1": "13F Samsung Insurance B/D. #942-9",
        "address_2": "Suwon-City  Gyeonggi-Do  442-832",
        "country": "KR"
    },
    "001600": {
        "oui_hex": "00-16-00",
        "organization": "CelleBrite Mobile Synchronization",
        "address_1": "25 Basel St",
        "address_2": "Petach Tikva    49170",
        "country": "IL"
    },
    "0015F4": {
        "oui_hex": "00-15-F4",
        "organization": "Eventide",
        "address_1": "1 Alsan Way",
        "address_2": "Little Ferry  NJ  07643",
        "country": "US"
    },
    "001629": {
        "oui_hex": "00-16-29",
        "organization": "Nivus GmbH",
        "address_1": "Im Täle 2",
        "address_2": "Eppingen  Baden-Württemberg  75031",
        "country": "DE"
    },
    "001621": {
        "oui_hex": "00-16-21",
        "organization": "Colorado Vnet",
        "address_1": "255 E. 6th St.",
        "address_2": "Loveland  CO  80537",
        "country": "US"
    },
    "00161A": {
        "oui_hex": "00-16-1A",
        "organization": "Dametric AB",
        "address_1": "Box 120",
        "address_2": "Skarholmen  Stockholm  SE-12723",
        "country": "SE"
    },
    "001615": {
        "oui_hex": "00-16-15",
        "organization": "Nittan Company, Limited",
        "address_1": "11-6, 1-chome, Hatagaya",
        "address_2": "Shibuya-ku  Tokyo  151-8535",
        "country": "JP"
    },
    "001616": {
        "oui_hex": "00-16-16",
        "organization": "BROWAN COMMUNICATION INC.",
        "address_1": "No.1 Jen-Ai Road, HsinChu Industrial Park,",
        "address_2": "HuKou Hsiang  HsinChu Hsien  303",
        "country": "TW"
    },
    "001617": {
        "oui_hex": "00-16-17",
        "organization": "MSI",
        "address_1": "No.69, Li-De St, Jung-Ho City",
        "address_2": "Taipei Hsien    235",
        "country": "TW"
    },
    "00162E": {
        "oui_hex": "00-16-2E",
        "organization": "Space Shuttle Hi-Tech Co., Ltd.",
        "address_1": "No. 226, Wu-Ho St., Wu-Lung Village,",
        "address_2": "Hsinchu Hsien    307",
        "country": "TW"
    },
    "00162A": {
        "oui_hex": "00-16-2A",
        "organization": "Antik computers & communications s.r.o.",
        "address_1": "Razusova 2",
        "address_2": "Kosice  SK  SK-04001",
        "country": "SK"
    },
    "001656": {
        "oui_hex": "00-16-56",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001651": {
        "oui_hex": "00-16-51",
        "organization": "Exeo Systems",
        "address_1": "1650, rue Michelin, suite 201",
        "address_2": "Laval  Québec  H7L 4R3",
        "country": "CA"
    },
    "001610": {
        "oui_hex": "00-16-10",
        "organization": "Carina Technology",
        "address_1": "690A Discovery Drive",
        "address_2": "Huntsville  AL  35806",
        "country": "US"
    },
    "001606": {
        "oui_hex": "00-16-06",
        "organization": "Ideal Industries",
        "address_1": "15070 Ave. of Science #200",
        "address_2": "San Diego  CA  92128",
        "country": "US"
    },
    "001607": {
        "oui_hex": "00-16-07",
        "organization": "Curves International Inc.",
        "address_1": "100 Ritchie Road",
        "address_2": "Waco  Texas  76712",
        "country": "US"
    },
    "001654": {
        "oui_hex": "00-16-54",
        "organization": "Flex-P Industries Sdn. Bhd.",
        "address_1": "No.128-12-2, Menara UMNO,",
        "address_2": "Georgetown  Penang  10400",
        "country": "US"
    },
    "001631": {
        "oui_hex": "00-16-31",
        "organization": "Xteam",
        "address_1": "room 801, No.102 international Science & Techology Park",
        "address_2": "  Beijing  8610",
        "country": "CN"
    },
    "00164B": {
        "oui_hex": "00-16-4B",
        "organization": "Quorion Data Systems GmbH",
        "address_1": "An der Klinge 6",
        "address_2": "Erfurt  Thuringia  99095",
        "country": "DE"
    },
    "001594": {
        "oui_hex": "00-15-94",
        "organization": "BIXOLON CO.,LTD",
        "address_1": "502-508,Digital Empire Bldg.",
        "address_2": "Yeongtong-Gu,Suwon  Gyeonggi-Do  443-813",
        "country": "KR"
    },
    "001590": {
        "oui_hex": "00-15-90",
        "organization": "Hectronic GmbH",
        "address_1": "Allmendstraße 15",
        "address_2": "Bonndorf  Baden-Württemberg  79848",
        "country": "DE"
    },
    "00158C": {
        "oui_hex": "00-15-8C",
        "organization": "Liab ApS",
        "address_1": "Oestre Alle 6",
        "address_2": "Stoevring    DK-9530",
        "country": "DK"
    },
    "00158F": {
        "oui_hex": "00-15-8F",
        "organization": "NTT Advanced Technology Corporation",
        "address_1": "Shinjuku Mitsui Bldg. 2-1-1, Nishi-shinjuku,",
        "address_2": "Shinjuku-ku  Tokyo  163-0431",
        "country": "JP"
    },
    "0015ED": {
        "oui_hex": "00-15-ED",
        "organization": "Fulcrum Microsystems, Inc.",
        "address_1": "26630 Agoura Road",
        "address_2": "Calabasas  CA  91302",
        "country": "US"
    },
    "0015F0": {
        "oui_hex": "00-15-F0",
        "organization": "EGO BV",
        "address_1": "Parade 15",
        "address_2": "'s-Hertogenbosch  Noord-Brabant  5211KL",
        "country": "NL"
    },
    "0015EE": {
        "oui_hex": "00-15-EE",
        "organization": "Omnex Control Systems",
        "address_1": "#74 - 1833 Coast Meridian Rd.",
        "address_2": "Port Coquitlam  BC  V3C 6G5",
        "country": "CA"
    },
    "0015C8": {
        "oui_hex": "00-15-C8",
        "organization": "FlexiPanel Ltd",
        "address_1": "7 bis rue Lalo",
        "address_2": "  Paris  75016",
        "country": "FR"
    },
    "0015C0": {
        "oui_hex": "00-15-C0",
        "organization": "DIGITAL TELEMEDIA CO.,LTD.",
        "address_1": "17TH FLOOR, CHINA YUSE BUILDING,",
        "address_2": "SHENZHEN  GUANGDONG  518040",
        "country": "CN"
    },
    "0015C2": {
        "oui_hex": "00-15-C2",
        "organization": "3M Germany",
        "address_1": "Carl Schurz Str. 1",
        "address_2": "Neuss  NRW  41453",
        "country": "US"
    },
    "001588": {
        "oui_hex": "00-15-88",
        "organization": "Salutica Allied Solutions Sdn Bhd",
        "address_1": "3 Jalan Zarib 6",
        "address_2": "Lahat, Ipoh  Perak  31500",
        "country": "MY"
    },
    "001583": {
        "oui_hex": "00-15-83",
        "organization": "IVT corporation",
        "address_1": "Shangdi Xinxi road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "US"
    },
    "001585": {
        "oui_hex": "00-15-85",
        "organization": "Aonvision Technolopy Corp.",
        "address_1": "2F, No. 58, Park 2nd Ave. Science-Based Industrial Park,",
        "address_2": "  Hsinchu  300",
        "country": "TW"
    },
    "0015A5": {
        "oui_hex": "00-15-A5",
        "organization": "DCI Co., Ltd.",
        "address_1": "4th Fl. Susung B/D, 893-4",
        "address_2": "Daejeon    305-330",
        "country": "KR"
    },
    "0015B2": {
        "oui_hex": "00-15-B2",
        "organization": "Advanced Industrial Computer, Inc.",
        "address_1": "17970 E. Ajax Circle",
        "address_2": "City of Industry  CA  91748",
        "country": "US"
    },
    "0015DA": {
        "oui_hex": "00-15-DA",
        "organization": "IRITEL A.D.",
        "address_1": "Batajnicki put 23",
        "address_2": "Beograd  Serbia  11080",
        "country": "YU"
    },
    "00154A": {
        "oui_hex": "00-15-4A",
        "organization": "WANSHIH ELECTRONIC CO., LTD",
        "address_1": "3F 72, WU KONG 6th RD.,",
        "address_2": "TAIPEI HSIEN  TAIWAN  248",
        "country": "TW"
    },
    "00154C": {
        "oui_hex": "00-15-4C",
        "organization": "Saunders Electronics",
        "address_1": "192 Gannett Drive",
        "address_2": "South Portland  ME  04106",
        "country": "US"
    },
    "00154D": {
        "oui_hex": "00-15-4D",
        "organization": "Netronome Systems, Inc.",
        "address_1": "3159 Unionville Road",
        "address_2": "Cranberry Twp.  PA  16066",
        "country": "US"
    },
    "001549": {
        "oui_hex": "00-15-49",
        "organization": "Dixtal Biomedica Ind. Com. Ltda",
        "address_1": "R. Eng. Francisco Pitta Brito, 703",
        "address_2": "São Paulo  SP  04753-080",
        "country": "BR"
    },
    "00153D": {
        "oui_hex": "00-15-3D",
        "organization": "ELIM PRODUCT CO.",
        "address_1": "602-2 GAYANG TECHNO TOWN, GAYANG, 3-DONG",
        "address_2": "  SEOUL  157-793",
        "country": "KR"
    },
    "001544": {
        "oui_hex": "00-15-44",
        "organization": "coM.s.a.t. AG",
        "address_1": "Besselstraße 3",
        "address_2": "Mannheim    D-68219",
        "country": "US"
    },
    "001539": {
        "oui_hex": "00-15-39",
        "organization": "Technodrive srl",
        "address_1": "Via Leonardo da Vinci  162",
        "address_2": "Trezzano S/N  Milan  20090",
        "country": "IT"
    },
    "001531": {
        "oui_hex": "00-15-31",
        "organization": "KOCOM",
        "address_1": "5F, KOCOM Bldg., 260-7",
        "address_2": "SEOUL    157-040",
        "country": "KR"
    },
    "001535": {
        "oui_hex": "00-15-35",
        "organization": "OTE Spa",
        "address_1": "via Barsanti 8",
        "address_2": "Florence  FI  50127",
        "country": "IT"
    },
    "001536": {
        "oui_hex": "00-15-36",
        "organization": "Powertech co.,Ltd",
        "address_1": "#705, dongyoung Venturestel, 199-32",
        "address_2": "Anyang City  Kyoungki-do  430-010",
        "country": "US"
    },
    "00152B": {
        "oui_hex": "00-15-2B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00152C": {
        "oui_hex": "00-15-2C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001528": {
        "oui_hex": "00-15-28",
        "organization": "Beacon Medical Products LLC d.b.a. BeaconMedaes",
        "address_1": "14408 W 105TH ST",
        "address_2": "LENEXA  KS  66215",
        "country": "US"
    },
    "001527": {
        "oui_hex": "00-15-27",
        "organization": "Balboa Instruments",
        "address_1": "1382 Bell Ave",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "001521": {
        "oui_hex": "00-15-21",
        "organization": "Horoquartz",
        "address_1": "BP 251",
        "address_2": "FONTENAY LE COMTE  VENDEE  85205",
        "country": "FR"
    },
    "001520": {
        "oui_hex": "00-15-20",
        "organization": "Radiocrafts AS",
        "address_1": "Sandakerveien 64",
        "address_2": "  Oslo  0484",
        "country": "NO"
    },
    "001566": {
        "oui_hex": "00-15-66",
        "organization": "A-First Technology Co., Ltd.",
        "address_1": "5F, No. 111-2, Shin-Teh Rd.,",
        "address_2": "San-Chung City  Taipei Shien  241",
        "country": "TW"
    },
    "00156B": {
        "oui_hex": "00-15-6B",
        "organization": "Perfisans Networks Corp.",
        "address_1": "4118 14th Avenue",
        "address_2": "Markham  Ontario  L3R 0J3",
        "country": "CA"
    },
    "001547": {
        "oui_hex": "00-15-47",
        "organization": "AiZen Solutions Inc.",
        "address_1": "10F-1, No.29, Puding Rd.",
        "address_2": "Hsinchu  Hsinchu County  300",
        "country": "TW"
    },
    "001579": {
        "oui_hex": "00-15-79",
        "organization": "Lunatone Industrielle Elektronik GmbH",
        "address_1": "Rennbahnweg 55",
        "address_2": "Wien    1220",
        "country": "AT"
    },
    "0014D7": {
        "oui_hex": "00-14-D7",
        "organization": "Datastore Technology Corp",
        "address_1": "9F, NO.10, SEC.1, Chung Hsing RD., Wu-Ku",
        "address_2": "Taipei Hsien,    248",
        "country": "TW"
    },
    "0014DD": {
        "oui_hex": "00-14-DD",
        "organization": "Covergence Inc.",
        "address_1": "One Clock Tower Place, Suite 200",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "0014D4": {
        "oui_hex": "00-14-D4",
        "organization": "K Technology Corporation",
        "address_1": "325 Ganbara",
        "address_2": "Kami-gun  Miyagi-ken  981-4263",
        "country": "JP"
    },
    "0014CF": {
        "oui_hex": "00-14-CF",
        "organization": "INVISIO Communications",
        "address_1": "Stamholmen 157",
        "address_2": "Hvidovre    2650",
        "country": "DK"
    },
    "0014BE": {
        "oui_hex": "00-14-BE",
        "organization": "Wink communication technology CO.LTD",
        "address_1": "Huijiang Ind Blding Dashi Town",
        "address_2": "Guang zhou  Guang dong  511430",
        "country": "CN"
    },
    "001511": {
        "oui_hex": "00-15-11",
        "organization": "Data Center Systems",
        "address_1": "14802 Venture Drive",
        "address_2": "Dallas  TX  75234",
        "country": "US"
    },
    "00150E": {
        "oui_hex": "00-15-0E",
        "organization": "OPENBRAIN TECHNOLOGIES CO., LTD.",
        "address_1": "#804,ANYANG K-CENTER,1591-9 , BURIM-DONG,DONGAN-GU,",
        "address_2": "ANYANG  KYUNGGI-DO  431-815",
        "country": "KR"
    },
    "00150D": {
        "oui_hex": "00-15-0D",
        "organization": "Hoana Medical, Inc.",
        "address_1": "828 Fort Street Mall",
        "address_2": "Honolulu  HI  96813",
        "country": "US"
    },
    "00151C": {
        "oui_hex": "00-15-1C",
        "organization": "LENECO",
        "address_1": "6th.,Dong Moon Good Morning Tower 1",
        "address_2": "Kyeong Ki-Do  GoYang-Si  411-817",
        "country": "KR"
    },
    "001519": {
        "oui_hex": "00-15-19",
        "organization": "StoreAge Networking Technologies",
        "address_1": "63 Bar-Yehuda st.",
        "address_2": "Nesher    36651",
        "country": "IL"
    },
    "001506": {
        "oui_hex": "00-15-06",
        "organization": "Neo Photonics",
        "address_1": "910 E. California St.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "001504": {
        "oui_hex": "00-15-04",
        "organization": "GAME PLUS CO., LTD.",
        "address_1": "164-57, Yeonghwa-dong, Jangan-gu",
        "address_2": "Suwon  Gyeonggi-do  440-818",
        "country": "KR"
    },
    "001505": {
        "oui_hex": "00-15-05",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0014FE": {
        "oui_hex": "00-14-FE",
        "organization": "Artech Electronics",
        "address_1": "#301, Yangjae Bldg., 276-2",
        "address_2": "Seoul    137-895",
        "country": "KR"
    },
    "0014DE": {
        "oui_hex": "00-14-DE",
        "organization": "Sage Instruments Inc.",
        "address_1": "240 Airport Blvd.",
        "address_2": "Freedom  CA  95019",
        "country": "US"
    },
    "0014DF": {
        "oui_hex": "00-14-DF",
        "organization": "HI-P Tech Corporation",
        "address_1": "1-27-23 Higashitokorozawa",
        "address_2": "Tokorozawa  Saitama  359-0021",
        "country": "JP"
    },
    "0014E6": {
        "oui_hex": "00-14-E6",
        "organization": "AIM Infrarotmodule GmbH",
        "address_1": "Soeflingerstraße 100",
        "address_2": "Ulm  BW  89077",
        "country": "DE"
    },
    "0014F3": {
        "oui_hex": "00-14-F3",
        "organization": "ViXS Systems Inc",
        "address_1": "2235 Sheppard Ave East",
        "address_2": "TORONTO  ONTARIO  M2J 5B5",
        "country": "CA"
    },
    "00147E": {
        "oui_hex": "00-14-7E",
        "organization": "InnerWireless",
        "address_1": "1155 Kas Drive, Suite 200",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "00147D": {
        "oui_hex": "00-14-7D",
        "organization": "Aeon Digital International",
        "address_1": "31-6, The Bund Center",
        "address_2": "Shanghai  SH  200002",
        "country": "CN"
    },
    "001476": {
        "oui_hex": "00-14-76",
        "organization": "MultiCom Industries Limited",
        "address_1": "Room 1206-7, Manhattan Center,",
        "address_2": "Kwai Chung, N.T.",
        "country": "HK"
    },
    "001473": {
        "oui_hex": "00-14-73",
        "organization": "Bookham Inc",
        "address_1": "10 Brewer Hunt Way",
        "address_2": "Kanata  ON  K2K 2B5",
        "country": "CA"
    },
    "001489": {
        "oui_hex": "00-14-89",
        "organization": "B15402100 - JANDEI, S.L.",
        "address_1": "POL. IND. POCOMACO, E-28",
        "address_2": "LA Coruña    15190",
        "country": "ES"
    },
    "001480": {
        "oui_hex": "00-14-80",
        "organization": "Hitachi-LG Data Storage Korea, Inc",
        "address_1": "19-1,Cheongho-ri",
        "address_2": "Pyungtaik  Kyunggi-Do  451-713",
        "country": "KR"
    },
    "0014B6": {
        "oui_hex": "00-14-B6",
        "organization": "Enswer Technology Inc.",
        "address_1": "1F No.70 Sec.2 Chung Shun St.",
        "address_2": "Taipei    116",
        "country": "TW"
    },
    "0014B2": {
        "oui_hex": "00-14-B2",
        "organization": "mCubelogics Corporation",
        "address_1": "4F, Unibooks B/D, 514-1, Dogok-Dong, KangNam",
        "address_2": "Seoul    135-270",
        "country": "KR"
    },
    "0014AE": {
        "oui_hex": "00-14-AE",
        "organization": "Wizlogics Co., Ltd.",
        "address_1": "Rm#1321, Samchang Plaza, 173,",
        "address_2": "Seoul    121-745",
        "country": "KR"
    },
    "0014A6": {
        "oui_hex": "00-14-A6",
        "organization": "Teranetics, Inc.",
        "address_1": "3965 Freedom Circle",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001469": {
        "oui_hex": "00-14-69",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0014BA": {
        "oui_hex": "00-14-BA",
        "organization": "Carvers SA de CV",
        "address_1": "Alvarez del Castillo 1550",
        "address_2": "Guadalajara  Jalisco  44620",
        "country": "MX"
    },
    "00148A": {
        "oui_hex": "00-14-8A",
        "organization": "Elin Ebg Traction Gmbh",
        "address_1": "Cumberlandstrasse 32",
        "address_2": "Vienna    1140",
        "country": "AT"
    },
    "001491": {
        "oui_hex": "00-14-91",
        "organization": "Daniels Electronics Ltd. dbo Codan Rado Communications",
        "address_1": "43 Erie St",
        "address_2": "Victoria  BC  V8V 1P8",
        "country": "CA"
    },
    "00146E": {
        "oui_hex": "00-14-6E",
        "organization": "H. Stoll GmbH & Co. KG",
        "address_1": "Stollweg",
        "address_2": "Reutlingen  Deutschland  72760",
        "country": "DE"
    },
    "0014AA": {
        "oui_hex": "00-14-AA",
        "organization": "Ashly Audio, Inc.",
        "address_1": "847 Holt Road",
        "address_2": "Webster  NY  14580",
        "country": "US"
    },
    "001409": {
        "oui_hex": "00-14-09",
        "organization": "MAGNETI MARELLI   S.E. S.p.A.",
        "address_1": "ZI Nord, Allee d'Argenson",
        "address_2": "CHATELLERAULT    86100",
        "country": "FR"
    },
    "00140B": {
        "oui_hex": "00-14-0B",
        "organization": "FIRST INTERNATIONAL COMPUTER, INC.",
        "address_1": "FIC BUILDING, NO.300, YANG GUANG ST.,",
        "address_2": "  TAIPEI COUNTY  114",
        "country": "TW"
    },
    "0013FD": {
        "oui_hex": "00-13-FD",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001400": {
        "oui_hex": "00-14-00",
        "organization": "MINERVA KOREA CO., LTD",
        "address_1": "#203, SH Sienne, Seohyeon-Dong",
        "address_2": "Seongnam-Si  Gyeonggi-Do  463-821",
        "country": "KR"
    },
    "0013FC": {
        "oui_hex": "00-13-FC",
        "organization": "SiCortex, Inc",
        "address_1": "One Clocktower Place",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "0013F6": {
        "oui_hex": "00-13-F6",
        "organization": "Cintech",
        "address_1": "21a route de la wantzenau",
        "address_2": "Hoenheim    67800",
        "country": "FR"
    },
    "00144F": {
        "oui_hex": "00-14-4F",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "001456": {
        "oui_hex": "00-14-56",
        "organization": "Edge Products",
        "address_1": "1080 South Depot Drive",
        "address_2": "Ogden  Utah  84404",
        "country": "US"
    },
    "001450": {
        "oui_hex": "00-14-50",
        "organization": "Heim Systems GmbH",
        "address_1": "Friedrich Ebert Strasse",
        "address_2": "Bergisch Gladbach  NRW  51429",
        "country": "DE"
    },
    "001452": {
        "oui_hex": "00-14-52",
        "organization": "CALCULEX,INC.",
        "address_1": "132 W. LAS CRUCES AVE.",
        "address_2": "LAS CRUCES  NEW MEXICO  88001",
        "country": "US"
    },
    "001442": {
        "oui_hex": "00-14-42",
        "organization": "ATTO CORPORATION",
        "address_1": "1-25-23 Hongo,",
        "address_2": "  Tokyo  113-8425",
        "country": "JP"
    },
    "001447": {
        "oui_hex": "00-14-47",
        "organization": "BOAZ Inc.",
        "address_1": "282 Pukok-ri SongSan-myon Dangzin-gun Chungcheongnam-do, 343-834",
        "address_2": "Seoul  SeoCho-gu  137-070",
        "country": "KR"
    },
    "00143E": {
        "oui_hex": "00-14-3E",
        "organization": "AirLink Communications, Inc.",
        "address_1": "3159 Corporate Place",
        "address_2": "Hayward  CA  94545",
        "country": "US"
    },
    "00145D": {
        "oui_hex": "00-14-5D",
        "organization": "WJ Communications, Inc.",
        "address_1": "401 River Oaks Parkway",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00143B": {
        "oui_hex": "00-14-3B",
        "organization": "Sensovation AG",
        "address_1": "Markhallen -Str",
        "address_2": "Radolfzell  Baden-Württemberg  78315",
        "country": "DE"
    },
    "00142D": {
        "oui_hex": "00-14-2D",
        "organization": "Toradex AG",
        "address_1": "Altsagenstrasse 5",
        "address_2": "Horw  LU  6048",
        "country": "CH"
    },
    "001429": {
        "oui_hex": "00-14-29",
        "organization": "V Center Technologies Co., Ltd.",
        "address_1": "7F-7, NO.35, Hsintai Rd.",
        "address_2": "Jubei City  Hsinchu  302",
        "country": "TW"
    },
    "001414": {
        "oui_hex": "00-14-14",
        "organization": "Jumpnode Systems LLC.",
        "address_1": "800 Washington Ave N.",
        "address_2": "Minneapolis  MN  55041",
        "country": "US"
    },
    "00141E": {
        "oui_hex": "00-14-1E",
        "organization": "P.A. Semi, Inc.",
        "address_1": "3965 Freedom Circle, Fl 8",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0013CB": {
        "oui_hex": "00-13-CB",
        "organization": "Zenitel Norway AS",
        "address_1": "Sandaker v 24 c",
        "address_2": "  Oslo  0403",
        "country": "NO"
    },
    "0013CF": {
        "oui_hex": "00-13-CF",
        "organization": "4Access Communications",
        "address_1": "1 N. LaSalle St.",
        "address_2": "Chicago  IL  60602",
        "country": "US"
    },
    "0013BE": {
        "oui_hex": "00-13-BE",
        "organization": "Virtual Conexions",
        "address_1": "410 rue St-Nicolas, suite 600",
        "address_2": "Montréal  QUÉBEC  H2Y 2P5",
        "country": "CA"
    },
    "0013B9": {
        "oui_hex": "00-13-B9",
        "organization": "BM SPA",
        "address_1": "VIA MILANO 54/56",
        "address_2": "Rozzano    20089",
        "country": "IT"
    },
    "0013AB": {
        "oui_hex": "00-13-AB",
        "organization": "Telemotive AG",
        "address_1": "Breitwiesen",
        "address_2": "Muehlhausen  Baden Wuerttemberg  73347",
        "country": "DE"
    },
    "0013C9": {
        "oui_hex": "00-13-C9",
        "organization": "Beyond Achieve Enterprises Ltd.",
        "address_1": "XIN LIAN HI-TECH INDUSTRIAL AREA, HU-MEN",
        "address_2": "DONGGUAN  GUANG DONG",
        "country": "CN"
    },
    "0013C6": {
        "oui_hex": "00-13-C6",
        "organization": "OpenGear, Inc",
        "address_1": "7984 South Welby Park #101",
        "address_2": "Salt Lake City  UTAH  84088",
        "country": "US"
    },
    "0013F3": {
        "oui_hex": "00-13-F3",
        "organization": "Giga-byte Communications Inc.",
        "address_1": "8F, No.43, Fu-Hsin Road. Hsin-Tien",
        "address_2": "Taipei Hsien    231",
        "country": "TW"
    },
    "0013F4": {
        "oui_hex": "00-13-F4",
        "organization": "Psitek (Pty) Ltd",
        "address_1": "The Vineyards Office Estate",
        "address_2": "Tyger Valley  Cape Town  7530",
        "country": "ZA"
    },
    "0013AC": {
        "oui_hex": "00-13-AC",
        "organization": "Sunmyung Electronics Co., LTD",
        "address_1": "LARGO-PLAZA 8F, Janghang-Dong",
        "address_2": "Koyang  Kyungki  411-837",
        "country": "KR"
    },
    "0013A8": {
        "oui_hex": "00-13-A8",
        "organization": "Tanisys Technology",
        "address_1": "11001 Lakeline blvd",
        "address_2": "Austin  TX  78717",
        "country": "US"
    },
    "0013DA": {
        "oui_hex": "00-13-DA",
        "organization": "Diskware Co., Ltd",
        "address_1": "1-4-12 Kiba",
        "address_2": "Koto-ku  Tokyo  135-0042",
        "country": "JP"
    },
    "0013D8": {
        "oui_hex": "00-13-D8",
        "organization": "Princeton Instruments",
        "address_1": "3660 Quakerbridge Road",
        "address_2": "Trenton  NJ  08619",
        "country": "US"
    },
    "001399": {
        "oui_hex": "00-13-99",
        "organization": "STAC Corporation.",
        "address_1": "2-16-37 fujimi",
        "address_2": "sayama-shi  saitama  350-1306",
        "country": "JP"
    },
    "0013E9": {
        "oui_hex": "00-13-E9",
        "organization": "VeriWave, Inc.",
        "address_1": "9600 SW Oak St.",
        "address_2": "Portland  OR  97223",
        "country": "US"
    },
    "001395": {
        "oui_hex": "00-13-95",
        "organization": "congatec AG",
        "address_1": "Auwiesenstrasse 5",
        "address_2": "Deggendorf    94469",
        "country": "DE"
    },
    "001356": {
        "oui_hex": "00-13-56",
        "organization": "FLIR Radiation Inc",
        "address_1": "100 Midland Rd",
        "address_2": "Oak Ridge  TN  37830",
        "country": "US"
    },
    "00135A": {
        "oui_hex": "00-13-5A",
        "organization": "Project T&E Limited",
        "address_1": "Room 3C, 2/F. Wah Shing Center,",
        "address_2": "Kwun Tong,  Kowloon,  852",
        "country": "HK"
    },
    "001361": {
        "oui_hex": "00-13-61",
        "organization": "Biospace Co., Ltd.",
        "address_1": "10th Floor, Poonglim Bldg, 823 Yeoksam 1-dong",
        "address_2": "Gangnam-gu  Seoul  135-784",
        "country": "KR"
    },
    "001362": {
        "oui_hex": "00-13-62",
        "organization": "ShinHeung Precision Co., Ltd.",
        "address_1": "DaeHa Bldg. 401",
        "address_2": "YoungDungPoGu  Seoul  150-050",
        "country": "KR"
    },
    "00134F": {
        "oui_hex": "00-13-4F",
        "organization": "Rapidus Wireless Networks Inc.",
        "address_1": "47 - 14550 Morris Valley Road",
        "address_2": "Agassiz  British Columbia  V0M 1A1",
        "country": "CA"
    },
    "001378": {
        "oui_hex": "00-13-78",
        "organization": "Qsan Technology, Inc.",
        "address_1": "4F., No.103, Ruihu St., Neihu Dist.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00137A": {
        "oui_hex": "00-13-7A",
        "organization": "Netvox Technology Co., Ltd.",
        "address_1": "No.21-1 Sec. 1 Chung Hua West Road",
        "address_2": "Tainan    702",
        "country": "TW"
    },
    "001381": {
        "oui_hex": "00-13-81",
        "organization": "CHIPS & Systems, Inc.",
        "address_1": "4750 Patrick Henry Drive",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "001379": {
        "oui_hex": "00-13-79",
        "organization": "PONDER INFORMATION INDUSTRIES LTD.",
        "address_1": "14F,No.77,lane700, Chung-Cheng Road",
        "address_2": "Hsin-Tien City  Taipei Hsien  231",
        "country": "TW"
    },
    "00132C": {
        "oui_hex": "00-13-2C",
        "organization": "MAZ Brandenburg GmbH",
        "address_1": "Pascalstraße 10a",
        "address_2": "Berlin  Berlin  10587",
        "country": "DE"
    },
    "001324": {
        "oui_hex": "00-13-24",
        "organization": "Schneider Electric Ultra Terminal",
        "address_1": "Industriparken 32",
        "address_2": "Copenhagen    2750",
        "country": "DK"
    },
    "001326": {
        "oui_hex": "00-13-26",
        "organization": "ECM Systems Ltd",
        "address_1": "Ellifoot Park",
        "address_2": "HULL  East Yorkshire  HU12 9DZ",
        "country": "GB"
    },
    "001327": {
        "oui_hex": "00-13-27",
        "organization": "Data Acquisitions limited",
        "address_1": "84 Gasson street",
        "address_2": "Christchurch",
        "country": "NZ"
    },
    "001367": {
        "oui_hex": "00-13-67",
        "organization": "Narayon. Co., Ltd.",
        "address_1": "#502 Hyochang T/W 181-3",
        "address_2": "Seoul    138-220",
        "country": "KR"
    },
    "00135C": {
        "oui_hex": "00-13-5C",
        "organization": "OnSite Systems, Inc.",
        "address_1": "3900 Freedom Circle",
        "address_2": "Santa Clara  CA  95054-1222",
        "country": "US"
    },
    "00135F": {
        "oui_hex": "00-13-5F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00133B": {
        "oui_hex": "00-13-3B",
        "organization": "Speed Dragon Multimedia Limited",
        "address_1": "Room 1312, Vanta Industrial Centre,",
        "address_2": "Kwai Chung  N.T.",
        "country": "HK"
    },
    "001338": {
        "oui_hex": "00-13-38",
        "organization": "FRESENIUS-VIAL",
        "address_1": "Le Grand Chemin",
        "address_2": "BREZINS    38590",
        "country": "FR"
    },
    "00132D": {
        "oui_hex": "00-13-2D",
        "organization": "iWise Communications",
        "address_1": "Unit 3C, Arden Grove",
        "address_2": "Cape Town    7441",
        "country": "ZA"
    },
    "001374": {
        "oui_hex": "00-13-74",
        "organization": "Atheros Communications, Inc.",
        "address_1": "529 Almanor Avenue",
        "address_2": "Sunnyvale  CA  94085-3512",
        "country": "US"
    },
    "001369": {
        "oui_hex": "00-13-69",
        "organization": "Honda Electron Co., LED.",
        "address_1": "Kanematsu Building 3 Floor",
        "address_2": "Chuo-ku  Tokyo  104-0031",
        "country": "JP"
    },
    "001342": {
        "oui_hex": "00-13-42",
        "organization": "Vision Research, Inc.",
        "address_1": "190 Parish Drive",
        "address_2": "Wayne  NJ  07470",
        "country": "US"
    },
    "001340": {
        "oui_hex": "00-13-40",
        "organization": "AD.EL s.r.l.",
        "address_1": "via S. Pertini,5",
        "address_2": "Martellago  VENEZIA  30030",
        "country": "IT"
    },
    "00130C": {
        "oui_hex": "00-13-0C",
        "organization": "HF System Corporation",
        "address_1": "1520-1 Ayukai",
        "address_2": "Nishiokitama-Gun  Yamagata-Ken  992-0771",
        "country": "JP"
    },
    "00130F": {
        "oui_hex": "00-13-0F",
        "organization": "EGEMEN Bilgisayar Muh San ve Tic LTD STI",
        "address_1": "Fevzi Cakmak 2 Sok 31/A",
        "address_2": "ANKARA  CANKAYA  06440",
        "country": "TR"
    },
    "001313": {
        "oui_hex": "00-13-13",
        "organization": "GuangZhou Post & Telecom Equipment ltd",
        "address_1": "139# Zhongshan Ave",
        "address_2": "Guangzhou  Guangdong  510630",
        "country": "CN"
    },
    "0012CB": {
        "oui_hex": "00-12-CB",
        "organization": "CSS Inc.",
        "address_1": "151 Superior Blvd.",
        "address_2": "Mississauga  Ontario  L5T2L1",
        "country": "CA"
    },
    "0012CE": {
        "oui_hex": "00-12-CE",
        "organization": "Advanced Cybernetics Group",
        "address_1": "2953 Bunker Hill Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0012CA": {
        "oui_hex": "00-12-CA",
        "organization": "Mechatronic Brick Aps",
        "address_1": "Alsion 2",
        "address_2": "6400  Sonderborg",
        "country": "DK"
    },
    "0012C7": {
        "oui_hex": "00-12-C7",
        "organization": "SECURAY Technologies Ltd.Co.",
        "address_1": "Tianjin Haitai Industrial Base ErWei Road",
        "address_2": "Tianjin    300384",
        "country": "CN"
    },
    "0012CD": {
        "oui_hex": "00-12-CD",
        "organization": "ASEM SpA",
        "address_1": "Via Buia, 4",
        "address_2": "ARTEGNA  Udine  I-33011",
        "country": "IT"
    },
    "0012E8": {
        "oui_hex": "00-12-E8",
        "organization": "Fraunhofer IMS",
        "address_1": "Finkenstrasse 61",
        "address_2": "Duisburg  NRW  47057",
        "country": "DE"
    },
    "0012DD": {
        "oui_hex": "00-12-DD",
        "organization": "Shengqu Information Technology (Shanghai) Co., Ltd.",
        "address_1": "No.1 Building,No. 690 Bibo Road,Pudong New Area",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "00131D": {
        "oui_hex": "00-13-1D",
        "organization": "Scanvaegt International A/S",
        "address_1": "P.O.Pedersens vej 18",
        "address_2": "Aarhus  Jylland  8200 N",
        "country": "DK"
    },
    "001318": {
        "oui_hex": "00-13-18",
        "organization": "DGSTATION Co., Ltd.",
        "address_1": "Rm.401, Bldg.A, Bundang Techno Park 150, Yatap-Dong, Bundang-Gu, Sungnam-Si, Gyunggi-Do, 463-760, Korea",
        "address_2": "Sungnam  Gyunggi  463-760",
        "country": "KR"
    },
    "00131A": {
        "oui_hex": "00-13-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0012F4": {
        "oui_hex": "00-12-F4",
        "organization": "Belco International Co.,Ltd.",
        "address_1": "212, Yeokok-Dong, Wonmi-gu",
        "address_2": "Puchun-Si  Kyongki-Do  420-100",
        "country": "KR"
    },
    "0012F5": {
        "oui_hex": "00-12-F5",
        "organization": "Imarda New Zealand Limited",
        "address_1": "Suite G16, National Innovation Centre,",
        "address_2": "Eveleigh NSW     2015",
        "country": "NZ"
    },
    "0012E0": {
        "oui_hex": "00-12-E0",
        "organization": "Codan Limited",
        "address_1": "81 Graves Street",
        "address_2": "Newton  South  5074",
        "country": "AU"
    },
    "0012DE": {
        "oui_hex": "00-12-DE",
        "organization": "Radio Components Sweden AB",
        "address_1": "Viderogatan 3B",
        "address_2": "Kista    16422",
        "country": "SE"
    },
    "001301": {
        "oui_hex": "00-13-01",
        "organization": "IronGate S.L.",
        "address_1": "C\\Alcala 268, primera planta",
        "address_2": "Madrid    28027",
        "country": "ES"
    },
    "0012F6": {
        "oui_hex": "00-12-F6",
        "organization": "MDK CO.,LTD.",
        "address_1": "2-6-27 Ibarame",
        "address_2": "Kashiwazaki City  Niigata  9451341",
        "country": "JP"
    },
    "0012F1": {
        "oui_hex": "00-12-F1",
        "organization": "IFOTEC",
        "address_1": "ZAC Champfeuillet",
        "address_2": "VOIRON    38507",
        "country": "FR"
    },
    "0012F8": {
        "oui_hex": "00-12-F8",
        "organization": "WNI Resources, LLC",
        "address_1": "2146 Bering Drive",
        "address_2": "San Jose  California  95131-2013",
        "country": "US"
    },
    "00127C": {
        "oui_hex": "00-12-7C",
        "organization": "SWEGON AB",
        "address_1": " Box 300",
        "address_2": "KVÄNUM  VÄSTRA GÖTALAND  SE 535 23",
        "country": "SE"
    },
    "001278": {
        "oui_hex": "00-12-78",
        "organization": "International Bar Code",
        "address_1": "160 Oak Street",
        "address_2": "Glastonbury  CT  06033",
        "country": "US"
    },
    "00127A": {
        "oui_hex": "00-12-7A",
        "organization": "Sanyu Industry Co.,Ltd.",
        "address_1": "Midori-ku Hakusan1-11-11",
        "address_2": "Yokohama-shi  Kanagawa-ken  226-0006",
        "country": "JP"
    },
    "001268": {
        "oui_hex": "00-12-68",
        "organization": "IPS d.o.o.",
        "address_1": "C. Ljubljanske brigade 17",
        "address_2": "Ljubljana    SI-1000",
        "country": "SI"
    },
    "0012AC": {
        "oui_hex": "00-12-AC",
        "organization": "ONTIMETEK INC.",
        "address_1": "9Fl.,Owner's Tower",
        "address_2": "Sungnam-Si  Kyunggi-Do  463-825",
        "country": "KR"
    },
    "0012BC": {
        "oui_hex": "00-12-BC",
        "organization": "Echolab LLC",
        "address_1": "267 Boston Road",
        "address_2": "Billerica  MA  01862",
        "country": "US"
    },
    "0012BD": {
        "oui_hex": "00-12-BD",
        "organization": "Avantec Manufacturing Limited",
        "address_1": "Unit L, 7/F, Camelpaint Bldg, Block 3",
        "address_2": "    852",
        "country": "HK"
    },
    "0012AB": {
        "oui_hex": "00-12-AB",
        "organization": "WiLife, Inc.",
        "address_1": "132 E. 13065 S., Suite 150",
        "address_2": "Draper  UT  84020",
        "country": "US"
    },
    "00129B": {
        "oui_hex": "00-12-9B",
        "organization": "E2S Electronic Engineering Solutions, S.L.",
        "address_1": "Sant Ferran 10",
        "address_2": "Barcelona    08031",
        "country": "ES"
    },
    "001298": {
        "oui_hex": "00-12-98",
        "organization": "MICO ELECTRIC(SHENZHEN) LIMITED",
        "address_1": "",
        "address_2": "SHENZHEN  GUANGDONG  518040",
        "country": "CN"
    },
    "001272": {
        "oui_hex": "00-12-72",
        "organization": "Redux Communications Ltd.",
        "address_1": "POB 101",
        "address_2": "Modiin    71700",
        "country": "IL"
    },
    "00126A": {
        "oui_hex": "00-12-6A",
        "organization": "OPTOELECTRONICS Co., Ltd.",
        "address_1": "3-1Kamiaokinishi 1-chome",
        "address_2": "Kawaguchi  Saitama Pref.  333-0845",
        "country": "JP"
    },
    "0012C0": {
        "oui_hex": "00-12-C0",
        "organization": "HotLava Systems, Inc.",
        "address_1": "6329 Chelton Drive",
        "address_2": "Oakland  CA  94611",
        "country": "US"
    },
    "0012B7": {
        "oui_hex": "00-12-B7",
        "organization": "PTW Freiburg",
        "address_1": "Loerracher Strasse 7",
        "address_2": "Freiburg    79115",
        "country": "DE"
    },
    "0012A1": {
        "oui_hex": "00-12-A1",
        "organization": "BluePacket Communications Co., Ltd.",
        "address_1": "10F-1, No. 420, Sec. 1, Keelung Rd., 110,",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001206": {
        "oui_hex": "00-12-06",
        "organization": "iQuest (NZ) Ltd",
        "address_1": "P.O.Box 15169",
        "address_2": "Hamilton  Waikato  3243",
        "country": "NZ"
    },
    "001207": {
        "oui_hex": "00-12-07",
        "organization": "Head Strong International Limited",
        "address_1": "Unit 9, 20/F, Metropole Square,",
        "address_2": "  Guangdong",
        "country": "HK"
    },
    "001209": {
        "oui_hex": "00-12-09",
        "organization": "Fastrax Ltd",
        "address_1": "Valimotie 7",
        "address_2": "Vantaa  FI  01510",
        "country": "FI"
    },
    "00120B": {
        "oui_hex": "00-12-0B",
        "organization": "Chinasys Technologies Limited",
        "address_1": "10/F,CAGW Building,No.30 Haidian South Road",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "001205": {
        "oui_hex": "00-12-05",
        "organization": "Terrasat Communications, Inc.",
        "address_1": "235 Vineyard Court, suite 100",
        "address_2": "Morgan Hill  California  95037",
        "country": "US"
    },
    "001238": {
        "oui_hex": "00-12-38",
        "organization": "SetaBox Technology Co., Ltd.",
        "address_1": "9F-1, No. 293-3, Sec2, Fu-Hsing S. Rd.",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "00123C": {
        "oui_hex": "00-12-3C",
        "organization": "Second Rule LLC",
        "address_1": "4119 Walnut Street",
        "address_2": "Philadelphia  PA  19104",
        "country": "US"
    },
    "00123E": {
        "oui_hex": "00-12-3E",
        "organization": "ERUNE technology Co., Ltd.",
        "address_1": "No. 429, Chin-San 2nd street,",
        "address_2": "Tao Yuan    326",
        "country": "TW"
    },
    "001254": {
        "oui_hex": "00-12-54",
        "organization": "Spectra Technologies Holdings Company Ltd",
        "address_1": "Unit 1301-09, Tower II",
        "address_2": "    852",
        "country": "HK"
    },
    "00124F": {
        "oui_hex": "00-12-4F",
        "organization": "nVent",
        "address_1": "1665 Utica Avenue, Suite 700",
        "address_2": "St Louis Park  MN  55416",
        "country": "US"
    },
    "001221": {
        "oui_hex": "00-12-21",
        "organization": "B.Braun Melsungen AG",
        "address_1": "Schwarzenberger Weg 73-79",
        "address_2": "Melsungen  Hessen  34212",
        "country": "DE"
    },
    "001212": {
        "oui_hex": "00-12-12",
        "organization": "PLUS  Corporation",
        "address_1": "1033-1, Oshitate",
        "address_2": "Inagi-shi  Tokyo  206-0811",
        "country": "JP"
    },
    "001213": {
        "oui_hex": "00-12-13",
        "organization": "Metrohm AG",
        "address_1": "Oberdorfstrasse 68",
        "address_2": "Herisau  AR  9101",
        "country": "CH"
    },
    "001218": {
        "oui_hex": "00-12-18",
        "organization": "ARUZE Corporation",
        "address_1": "Ariake Frontier Building A",
        "address_2": "Kohtoh-ku  Tokyo  135-0063",
        "country": "JP"
    },
    "001249": {
        "oui_hex": "00-12-49",
        "organization": "Delta Elettronica S.p.A.",
        "address_1": "Via Astico 41",
        "address_2": "Varese    21100",
        "country": "IT"
    },
    "00124D": {
        "oui_hex": "00-12-4D",
        "organization": "Inducon BV",
        "address_1": "Kerklaan 26",
        "address_2": "Leimuiden  ZH  2541 CG",
        "country": "NL"
    },
    "001266": {
        "oui_hex": "00-12-66",
        "organization": "Swisscom Hospitality Services SA",
        "address_1": "Chemin de l'Etang 65",
        "address_2": "1211  Geneva",
        "country": "CH"
    },
    "00125E": {
        "oui_hex": "00-12-5E",
        "organization": "CAEN",
        "address_1": "via Vetraia, 11",
        "address_2": "Viareggio  LUCCA  55049",
        "country": "IT"
    },
    "00125D": {
        "oui_hex": "00-12-5D",
        "organization": "CyberNet Inc.",
        "address_1": "#205, Lotte Suntech City, 513-15",
        "address_2": "Sungnam  Kyunggi  462-806",
        "country": "KR"
    },
    "001223": {
        "oui_hex": "00-12-23",
        "organization": "Pixim",
        "address_1": "915 Linda Vista Ave.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "00123A": {
        "oui_hex": "00-12-3A",
        "organization": "Posystech Inc., Co.",
        "address_1": "Room 407, Daeryung Techno Town 6,",
        "address_2": "Seoul    153-771",
        "country": "KR"
    },
    "001234": {
        "oui_hex": "00-12-34",
        "organization": "Camille Bauer",
        "address_1": "Aargauerstr. 7",
        "address_2": "Wohlen  AG  5610",
        "country": "CH"
    },
    "0011E3": {
        "oui_hex": "00-11-E3",
        "organization": "Thomson, Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290",
        "country": "US"
    },
    "0011DC": {
        "oui_hex": "00-11-DC",
        "organization": "Glunz & Jensen",
        "address_1": "Selandia Park 1",
        "address_2": "Ringsted    4100",
        "country": "DK"
    },
    "001196": {
        "oui_hex": "00-11-96",
        "organization": "Actuality Systems, Inc.",
        "address_1": "25 Corporate Drive",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "001187": {
        "oui_hex": "00-11-87",
        "organization": "Category Solutions, Inc",
        "address_1": "1021 W. Adams St",
        "address_2": "Chicago  IL  60607",
        "country": "US"
    },
    "001190": {
        "oui_hex": "00-11-90",
        "organization": "Digital Design Corporation",
        "address_1": "3820 Ventura Drive",
        "address_2": "Arlington Heights  IL  60004",
        "country": "US"
    },
    "0011C4": {
        "oui_hex": "00-11-C4",
        "organization": "Terminales de Telecomunicacion Terrestre, S.L.",
        "address_1": "Poligono Europolis, Calle C 26",
        "address_2": "Las Rozas  Madrid  28230",
        "country": "ES"
    },
    "0011CB": {
        "oui_hex": "00-11-CB",
        "organization": "Jacobsons AB",
        "address_1": "Nedralid s 32",
        "address_2": "Motala    591 97",
        "country": "SE"
    },
    "0011F7": {
        "oui_hex": "00-11-F7",
        "organization": "Shenzhen Forward Industry Co., Ltd",
        "address_1": "4b1 F5.8, Tian An Cyber Park, Chengongmiao,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "0011D3": {
        "oui_hex": "00-11-D3",
        "organization": "NextGenTel Holding ASA",
        "address_1": "Sandslimarka 31",
        "address_2": "Bergen  Hordaland  5861",
        "country": "NO"
    },
    "0011AB": {
        "oui_hex": "00-11-AB",
        "organization": "TRUSTABLE TECHNOLOGY CO.,LTD.",
        "address_1": "12FL.-1,NO.167,Fu-Shing N.Rd.,Sung-Shan area",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "0011A5": {
        "oui_hex": "00-11-A5",
        "organization": "Fortuna Electronic Corp.",
        "address_1": "3F, No.9, Sec.1, ChangAn East Rd.,",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "00113C": {
        "oui_hex": "00-11-3C",
        "organization": "Micronas GmbH",
        "address_1": "Hans-Bunte-Strasse 19",
        "address_2": "Freiburg    D-79108",
        "country": "DE"
    },
    "001131": {
        "oui_hex": "00-11-31",
        "organization": "UNATECH. CO.,LTD",
        "address_1": "A-727 ,GEOPYUNG TOWN,203-1",
        "address_2": "KANGNAM-GU  SEOUL  135-010",
        "country": "US"
    },
    "001127": {
        "oui_hex": "00-11-27",
        "organization": "TASI, Inc",
        "address_1": "5551 Dry Fork Road",
        "address_2": "Cleves  OH  45002",
        "country": "US"
    },
    "00112A": {
        "oui_hex": "00-11-2A",
        "organization": "Niko NV",
        "address_1": "Industriepark West 40",
        "address_2": "Sint-Niklaas  O/V  9100",
        "country": "BE"
    },
    "00112B": {
        "oui_hex": "00-11-2B",
        "organization": "NetModule AG",
        "address_1": "Meriedweg 11",
        "address_2": "Niederwangen  CH  3172",
        "country": "CH"
    },
    "00116F": {
        "oui_hex": "00-11-6F",
        "organization": "Netforyou Co., LTD.",
        "address_1": "1121-4 3F,  Kwanyang-dong, Dongan-gu",
        "address_2": "Anyang-si  Kyunggi-do  431-804",
        "country": "KR"
    },
    "001171": {
        "oui_hex": "00-11-71",
        "organization": "DEXTER Communications, Inc.",
        "address_1": "2F Shinsung B/D 404-1",
        "address_2": "Sungnam  Gyunggi  463-420",
        "country": "KR"
    },
    "001167": {
        "oui_hex": "00-11-67",
        "organization": "Integrated System Solution Corp.",
        "address_1": "3F, No. 2-1, industry East Rd., I",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00116D": {
        "oui_hex": "00-11-6D",
        "organization": "American Time and Signal",
        "address_1": "140 Third St. South",
        "address_2": "Dassel  MN  55325",
        "country": "US"
    },
    "001160": {
        "oui_hex": "00-11-60",
        "organization": "ARTDIO Company Co., LTD",
        "address_1": "7th FL.., No.476, Min-Hu RD., Hsin-Chu,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001154": {
        "oui_hex": "00-11-54",
        "organization": "Webpro Technologies Inc.",
        "address_1": "2F-1, No.81, Sec. 4, Chungching N. Rd.,",
        "address_2": "Taipei    111",
        "country": "TW"
    },
    "001145": {
        "oui_hex": "00-11-45",
        "organization": "ValuePoint Networks",
        "address_1": "350 Townsend St Ste 320",
        "address_2": "San Francisco,  CA  94107",
        "country": "US"
    },
    "001151": {
        "oui_hex": "00-11-51",
        "organization": "Mykotronx",
        "address_1": "359 Van Ness Way",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "00114E": {
        "oui_hex": "00-11-4E",
        "organization": "690885 Ontario Inc.",
        "address_1": "205 Annagem Blvd.",
        "address_2": "Mississauga  Ontario  L5T 2V1",
        "country": "CA"
    },
    "00112D": {
        "oui_hex": "00-11-2D",
        "organization": "iPulse Systems",
        "address_1": "Unit 3, Riverside Industrial Park",
        "address_2": "Gauteng  Johannesburg  1618",
        "country": "ZA"
    },
    "00117B": {
        "oui_hex": "00-11-7B",
        "organization": "Büchi  Labortechnik AG",
        "address_1": "Meierseggstrasse 40",
        "address_2": "Flawil  9230  SG",
        "country": "CH"
    },
    "000FEE": {
        "oui_hex": "00-0F-EE",
        "organization": "XTec, Incorporated",
        "address_1": "5775 Blue Lagoon Drive",
        "address_2": "Miami  Florida  33126",
        "country": "US"
    },
    "000FE4": {
        "oui_hex": "00-0F-E4",
        "organization": "Pantech Co.,Ltd",
        "address_1": "Shinsong B/D 3F, 25-12,",
        "address_2": "Youngdeungpo-GU  Seoul  150-711",
        "country": "KR"
    },
    "000FE7": {
        "oui_hex": "00-0F-E7",
        "organization": "Lutron Electronics Co., Inc.",
        "address_1": "7200 Suter Rd.",
        "address_2": "Coopersburg  PA  18036-1299",
        "country": "US"
    },
    "000FE6": {
        "oui_hex": "00-0F-E6",
        "organization": "MBTech Systems, Inc.",
        "address_1": "412 1st Ave SE",
        "address_2": "Cullman  Alabama  35055",
        "country": "US"
    },
    "000FDA": {
        "oui_hex": "00-0F-DA",
        "organization": "YAZAKI CORPORATION",
        "address_1": "1500 MISHUKU",
        "address_2": "SUSONO-CITY  SHIZUOKA-PREF  410-1194",
        "country": "JP"
    },
    "000FEF": {
        "oui_hex": "00-0F-EF",
        "organization": "Thales e-Transactions GmbH",
        "address_1": "Konrad-Zuse-Straße 19-21",
        "address_2": "Bad Hersfeld  Hessen  36251",
        "country": "DE"
    },
    "000FE9": {
        "oui_hex": "00-0F-E9",
        "organization": "GW TECHNOLOGIES CO.,LTD.",
        "address_1": "No.38 Shangdi Xilu,Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "000FE1": {
        "oui_hex": "00-0F-E1",
        "organization": "ID DIGITAL CORPORATION",
        "address_1": "6th Fl., Mirae Bldg., 271-1, Seohyun-dong, Bundang-ku, Sungnam-si, Keongki-do, South Korea",
        "address_2": "Sungnam-Si  Keongki-do  463-050",
        "country": "KR"
    },
    "000FDF": {
        "oui_hex": "00-0F-DF",
        "organization": "SOLOMON Technology Corp.",
        "address_1": "No.42,Sing Zhong Rd.,Nei Hu Dist.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000FFE": {
        "oui_hex": "00-0F-FE",
        "organization": "G-PRO COMPUTER",
        "address_1": "first arrange C YingHu industrial estate QingXi country DongGuan city",
        "address_2": "DongGuan  GuangDong  523648",
        "country": "CN"
    },
    "00110B": {
        "oui_hex": "00-11-0B",
        "organization": "Franklin Technology Systems",
        "address_1": "20406 Earl St",
        "address_2": "Torrance  CA  90503",
        "country": "US"
    },
    "001105": {
        "oui_hex": "00-11-05",
        "organization": "Sunplus Technology Co., Ltd.",
        "address_1": "19, Innovation First Road, Hsinchu Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001102": {
        "oui_hex": "00-11-02",
        "organization": "Aurora Multimedia Corp.",
        "address_1": "205 Commercial Court",
        "address_2": "Morganville  New Jersey  07751-1070",
        "country": "US"
    },
    "001123": {
        "oui_hex": "00-11-23",
        "organization": "Appointech, Inc.",
        "address_1": "6F-2 No.192 Tung-Kuan Rd.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00110F": {
        "oui_hex": "00-11-0F",
        "organization": "netplat,Inc.",
        "address_1": "2F Olympia Center, 828-10, Yeoksam-dong, Gangnam-gu",
        "address_2": "SEOUL    135-935",
        "country": "KR"
    },
    "000FD6": {
        "oui_hex": "00-0F-D6",
        "organization": "Sarotech Co., Ltd",
        "address_1": "HanGang Bldg, 1549-7, Seocho-Dong,",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "001115": {
        "oui_hex": "00-11-15",
        "organization": "EPIN Technologies, Inc.",
        "address_1": "Acorn Campus",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000FC7": {
        "oui_hex": "00-0F-C7",
        "organization": "Dionica R&D Ltd.",
        "address_1": "Bologna Centre, F11",
        "address_2": "Mosta    MST13",
        "country": "MT"
    },
    "000F64": {
        "oui_hex": "00-0F-64",
        "organization": "D&R Electronica Weesp BV",
        "address_1": "Rijnkade 15B",
        "address_2": "WEESP  NH  1382GS",
        "country": "NL"
    },
    "000F75": {
        "oui_hex": "00-0F-75",
        "organization": "First Silicon Solutions",
        "address_1": "13939 Forest Lane",
        "address_2": "Larkspur  CO  80118",
        "country": "US"
    },
    "000F7C": {
        "oui_hex": "00-0F-7C",
        "organization": "ACTi Corporation",
        "address_1": "7F., No. 1, Alley 20, Lane 407, Sec. 2, Tiding Blvd.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000F7A": {
        "oui_hex": "00-0F-7A",
        "organization": "BeiJing NuQX Technology CO.,LTD",
        "address_1": "Room 812,8F Tower B,YinWang Center, No.113,Zhi Chun Road,",
        "address_2": "Beijing    100086",
        "country": "CN"
    },
    "000FAD": {
        "oui_hex": "00-0F-AD",
        "organization": "FMN communications GmbH",
        "address_1": "Grimmelallee 4",
        "address_2": "Nordhausen  Thüringen  99734",
        "country": "DE"
    },
    "000FAB": {
        "oui_hex": "00-0F-AB",
        "organization": "Kyushu Electronics Systems Inc.",
        "address_1": "3-3, Kongo 2-Chome, Yahatanishi Ward",
        "address_2": "Kitakyushu City  Fukuoka Pref.  807-1263",
        "country": "JP"
    },
    "000FAC": {
        "oui_hex": "00-0F-AC",
        "organization": "IEEE 802.11",
        "address_1": "4125 Highlander Parkway",
        "address_2": "Richfield  Ohio  44286",
        "country": "US"
    },
    "000F72": {
        "oui_hex": "00-0F-72",
        "organization": "Sandburst",
        "address_1": "600 Federal St",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "000FB3": {
        "oui_hex": "00-0F-B3",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000F9C": {
        "oui_hex": "00-0F-9C",
        "organization": "Panduit Corp",
        "address_1": "17301 Ridgeland Ave",
        "address_2": "Tinley Park  Illinois  60477",
        "country": "US"
    },
    "000FC8": {
        "oui_hex": "00-0F-C8",
        "organization": "Chantry Networks",
        "address_1": "1900 Minnesota Court",
        "address_2": "Mississauga  Ontario  L5N 3C9",
        "country": "CA"
    },
    "000FBB": {
        "oui_hex": "00-0F-BB",
        "organization": "Nokia Siemens Networks GmbH & Co. KG.",
        "address_1": "Werner-von-Siemens Straße 2-6",
        "address_2": "Bruchsal  Baden-Württemberg  76646",
        "country": "DE"
    },
    "000FBC": {
        "oui_hex": "00-0F-BC",
        "organization": "Onkey Technologies, Inc.",
        "address_1": "780 Montague Expressway, Inc.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000FB6": {
        "oui_hex": "00-0F-B6",
        "organization": "Europlex Technologies",
        "address_1": "Clonshaugh Business & Tech. Park",
        "address_2": "Clonshaugh    Dublin 17",
        "country": "IE"
    },
    "000FB9": {
        "oui_hex": "00-0F-B9",
        "organization": "Adaptive Instruments",
        "address_1": "577 Main Street",
        "address_2": "Hudson  MA  01749",
        "country": "US"
    },
    "000F98": {
        "oui_hex": "00-0F-98",
        "organization": "Avamax Co. Ltd.",
        "address_1": "B1, No. 51, Section 2, ChongQing S. Rd.",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000F97": {
        "oui_hex": "00-0F-97",
        "organization": "Avanex Corporation",
        "address_1": "40919 Encyclopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000F96": {
        "oui_hex": "00-0F-96",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield  MA  02048",
        "country": "US"
    },
    "000F8B": {
        "oui_hex": "00-0F-8B",
        "organization": "Orion MultiSystems Inc",
        "address_1": "3375 Scott Blvd Suite 338",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000F8C": {
        "oui_hex": "00-0F-8C",
        "organization": "Gigawavetech Pte Ltd",
        "address_1": "1 Jalan Kilang Timor",
        "address_2": "    159303",
        "country": "SG"
    },
    "000F38": {
        "oui_hex": "00-0F-38",
        "organization": "Netstar",
        "address_1": "3F,No.347, Yang-kuang St.,Nei-Hu Dis.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000F3A": {
        "oui_hex": "00-0F-3A",
        "organization": "HISHARP",
        "address_1": "NO.673,CHANG HSING ROAD PATE CITY,TAOYUAN,",
        "address_2": "TAIPEI    334",
        "country": "TW"
    },
    "000F30": {
        "oui_hex": "00-0F-30",
        "organization": "Raza Microelectronics Inc",
        "address_1": "3080 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000F53": {
        "oui_hex": "00-0F-53",
        "organization": "Solarflare Communications Inc.",
        "address_1": "Suite 100, 7505 Irvine Center Drive",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000F51": {
        "oui_hex": "00-0F-51",
        "organization": "Azul Systems, Inc.",
        "address_1": "1600 Plymouth Street",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "000F07": {
        "oui_hex": "00-0F-07",
        "organization": "Mangrove Systems, Inc.",
        "address_1": "10 Fairfield Blvd.",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "000F00": {
        "oui_hex": "00-0F-00",
        "organization": "Legra Systems, Inc.",
        "address_1": "3 Burlington Woods Drive",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "000F01": {
        "oui_hex": "00-0F-01",
        "organization": "DIGITALKS INC",
        "address_1": "14 MARSHALL LANE",
        "address_2": "WESTON  CT  06883",
        "country": "US"
    },
    "000F03": {
        "oui_hex": "00-0F-03",
        "organization": "COM&C CO., LTD",
        "address_1": "2F Woojin BLD 1445-2 Secho-Dong",
        "address_2": "SEOUL    137-070",
        "country": "KR"
    },
    "000F34": {
        "oui_hex": "00-0F-34",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000F2E": {
        "oui_hex": "00-0F-2E",
        "organization": "Megapower International Corp.",
        "address_1": "Rm. 403, No 24 , Wu-Chuan 2nd Rd.,",
        "address_2": "Taipei Hsien    242",
        "country": "TW"
    },
    "000F26": {
        "oui_hex": "00-0F-26",
        "organization": "WorldAccxx  LLC",
        "address_1": "4035 Tampa Rd.",
        "address_2": "Oldsmar  FL  34667",
        "country": "US"
    },
    "000F45": {
        "oui_hex": "00-0F-45",
        "organization": "Stretch, Inc.",
        "address_1": "1322 Orleans Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000F3B": {
        "oui_hex": "00-0F-3B",
        "organization": "Fuji System Machines Co., Ltd.",
        "address_1": "5-8-10",
        "address_2": "Zama-Shi  Kanagawa-Ken  228-0003",
        "country": "JP"
    },
    "000F37": {
        "oui_hex": "00-0F-37",
        "organization": "Xambala Incorporated",
        "address_1": "2674 N. 1st Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000F54": {
        "oui_hex": "00-0F-54",
        "organization": "Entrelogic Corporation",
        "address_1": "33 Boston Post Rd. West.",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "000F25": {
        "oui_hex": "00-0F-25",
        "organization": "AimValley B.V.",
        "address_1": "Utrechtseweg 38,",
        "address_2": "Hilversum  NH  1223 TV",
        "country": "NL"
    },
    "000F19": {
        "oui_hex": "00-0F-19",
        "organization": "Boston Scientific",
        "address_1": "4100 Hamline Ave N.",
        "address_2": "St. Paul  MN  55112",
        "country": "US"
    },
    "000F10": {
        "oui_hex": "00-0F-10",
        "organization": "RDM Corporation",
        "address_1": "608 Weber St. N",
        "address_2": "Waterloo  ON  N2V 1K4",
        "country": "CA"
    },
    "000EA8": {
        "oui_hex": "00-0E-A8",
        "organization": "United Technologists Europe Limited",
        "address_1": "UTEL Laboratories, Wolves Farm Lane",
        "address_2": "Hadleigh  Suffolk  IP7 6BH",
        "country": "GB"
    },
    "000EAA": {
        "oui_hex": "00-0E-AA",
        "organization": "Scalent Systems, Inc.",
        "address_1": "490 S. California Ave",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "000EAC": {
        "oui_hex": "00-0E-AC",
        "organization": "MINTRON ENTERPRISE CO., LTD.",
        "address_1": "NO.3,Wu-Kung 5Rd., Wu-Ku Ind Park",
        "address_2": "Taipei County    248",
        "country": "TW"
    },
    "000EAE": {
        "oui_hex": "00-0E-AE",
        "organization": "GAWELL TECHNOLOGIES CORP.",
        "address_1": "2F,NO.102,SEC.3,JUNG SHAN RD,",
        "address_2": "JUNG HO CITY,  TAIPEI HSIEN  235",
        "country": "TW"
    },
    "000EBA": {
        "oui_hex": "00-0E-BA",
        "organization": "HANMI SEMICONDUCTOR CO., LTD.",
        "address_1": "#532-2, Gajwa-Dong, Seo-Ku,",
        "address_2": "Incheon,    404 250",
        "country": "KR"
    },
    "000EBC": {
        "oui_hex": "00-0E-BC",
        "organization": "Paragon Fidelity GmbH",
        "address_1": "Schwadermühlstraße",
        "address_2": "Cadolzburg    90556",
        "country": "DE"
    },
    "000EC5": {
        "oui_hex": "00-0E-C5",
        "organization": "Digital Multitools Inc",
        "address_1": "9005 Leslie Street  Unit 205",
        "address_2": "Richmond Hill  Ontario  L4B 1G7",
        "country": "CA"
    },
    "000EC7": {
        "oui_hex": "00-0E-C7",
        "organization": "Motorola Korea",
        "address_1": "Hibrand B/D 17F SW Team Motorola Korea",
        "address_2": "Yangjaedong  Seocho",
        "country": "KR"
    },
    "000E8B": {
        "oui_hex": "00-0E-8B",
        "organization": "Astarte Technology Co, Ltd.",
        "address_1": "11F, No. 166 Dah-Yeh Rd.",
        "address_2": "Peitou, Taipei",
        "country": "TW"
    },
    "000EDF": {
        "oui_hex": "00-0E-DF",
        "organization": "PLX Technology",
        "address_1": "870 Maude Ave.,",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "000EE1": {
        "oui_hex": "00-0E-E1",
        "organization": "ExtremeSpeed Inc.",
        "address_1": "PO Box 600",
        "address_2": "Mannville  Alberta  T0B 2W0",
        "country": "CA"
    },
    "000ED7": {
        "oui_hex": "00-0E-D7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000ED3": {
        "oui_hex": "00-0E-D3",
        "organization": "Epicenter, Inc.",
        "address_1": "211 B Calle Pintoresco",
        "address_2": "San Clemente  CA  92672",
        "country": "US"
    },
    "000E9D": {
        "oui_hex": "00-0E-9D",
        "organization": "Tiscali UK Ltd",
        "address_1": "20 Broadwick Street",
        "address_2": "London    W1F 8HT",
        "country": "GB"
    },
    "000E47": {
        "oui_hex": "00-0E-47",
        "organization": "NCI System Co.,Ltd.",
        "address_1": "#206, Kayang Techno-Town, 1487, Kayang 3 dong, Kangseo-Ku, Seoul, Korea",
        "address_2": "Seoul    157-810",
        "country": "KR"
    },
    "000E46": {
        "oui_hex": "00-0E-46",
        "organization": "Niigata Seimitsu Co.,Ltd.",
        "address_1": "3335-2, Shimonaka, Sanwa-mura",
        "address_2": "Nakakubiki-gun  Niigata  943-0222",
        "country": "JP"
    },
    "000E1F": {
        "oui_hex": "00-0E-1F",
        "organization": "TCL Networks Equipment Co., Ltd.",
        "address_1": "No.5 Industrial Road,Shekou",
        "address_2": "ShenZhen  GuangDong  518067",
        "country": "CN"
    },
    "000E26": {
        "oui_hex": "00-0E-26",
        "organization": "Gincom Technology Corp.",
        "address_1": "15F., No. 284, Sec.3, Sanmin Rd., Taoyuan City,",
        "address_2": "Taoyuan,    330",
        "country": "TW"
    },
    "000E6C": {
        "oui_hex": "00-0E-6C",
        "organization": "Device Drivers Limited",
        "address_1": "1-5-1-103",
        "address_2": "Fuchu-shi  Tokyo  1830005",
        "country": "JP"
    },
    "000E6B": {
        "oui_hex": "00-0E-6B",
        "organization": "Janitza electronics GmbH",
        "address_1": "Vor dem Polstück  1",
        "address_2": "Lahnau  Hessen  35633",
        "country": "DE"
    },
    "000E5F": {
        "oui_hex": "00-0E-5F",
        "organization": "activ-net GmbH & Co. KG",
        "address_1": "Konrad-Zuse-Str. 4",
        "address_2": "Bochum    44801",
        "country": "DE"
    },
    "000E57": {
        "oui_hex": "00-0E-57",
        "organization": "Iworld Networking, Inc.",
        "address_1": "125 Hanju Bldg, Nonhyun-Dong",
        "address_2": "Seoul    135010",
        "country": "KR"
    },
    "000E51": {
        "oui_hex": "00-0E-51",
        "organization": "tecna elettronica srl",
        "address_1": "via miglioli 30",
        "address_2": "castel san pietro terme  bologna  40024",
        "country": "IT"
    },
    "000E67": {
        "oui_hex": "00-0E-67",
        "organization": "Eltis Microelectronics Ltd.",
        "address_1": "Unit 902B, 9/F., Sunbeam Centre",
        "address_2": "Kwun Tong  Kowloon",
        "country": "HK"
    },
    "000E65": {
        "oui_hex": "00-0E-65",
        "organization": "TransCore",
        "address_1": "8600 Jefferson St NE",
        "address_2": "Albuquerque  NM  87113",
        "country": "US"
    },
    "000E43": {
        "oui_hex": "00-0E-43",
        "organization": "G-Tek Electronics Sdn. Bhd.",
        "address_1": "2493 Mukim 1, Lorong Perusahaan Lapan",
        "address_2": "Perai  Penang  13600",
        "country": "MY"
    },
    "000E44": {
        "oui_hex": "00-0E-44",
        "organization": "Digital 5, Inc.",
        "address_1": "101 Grovers Mill Rd.",
        "address_2": "Lawrenceville  NJ  08648",
        "country": "US"
    },
    "000E74": {
        "oui_hex": "00-0E-74",
        "organization": "Solar Telecom. Tech",
        "address_1": "B B/D, 4F, Samho Venture Tower",
        "address_2": "Seoul    137-941",
        "country": "KR"
    },
    "000E7A": {
        "oui_hex": "00-0E-7A",
        "organization": "GemWon Communications Co., Ltd.",
        "address_1": "3FL.,NO.32,Lane 135,Shianjeng 9th Rd.,Jubei City",
        "address_2": "Hsinchu    302",
        "country": "TW"
    },
    "000E80": {
        "oui_hex": "00-0E-80",
        "organization": "Thomson Technology Inc",
        "address_1": "9087A 198th ST",
        "address_2": "Surrey  BC  V1M-3B1",
        "country": "CA"
    },
    "000E85": {
        "oui_hex": "00-0E-85",
        "organization": "Catalyst Enterprises, Inc.",
        "address_1": "3385 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000E32": {
        "oui_hex": "00-0E-32",
        "organization": "Kontron Medical",
        "address_1": "Reinacherstrasse 131",
        "address_2": "Basel    4002",
        "country": "CH"
    },
    "000E0B": {
        "oui_hex": "00-0E-0B",
        "organization": "Netac Technology Co., Ltd.",
        "address_1": "6F, Incubator Building, China Academy of Science &Tech Development,",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "000E11": {
        "oui_hex": "00-0E-11",
        "organization": "BDT Büro und Datentechnik GmbH & Co.KG",
        "address_1": "Saline 29",
        "address_2": "Rottweil  Baden-Württemberg  D-78628",
        "country": "DE"
    },
    "000DF5": {
        "oui_hex": "00-0D-F5",
        "organization": "Teletronics International Inc.",
        "address_1": "2 Choke Cherry Road",
        "address_2": "Rockville  MD  20850",
        "country": "US"
    },
    "000DF7": {
        "oui_hex": "00-0D-F7",
        "organization": "Space Dynamics Lab",
        "address_1": "1695 N. Research Park Way",
        "address_2": "North Logan  UT  84341",
        "country": "US"
    },
    "000DEB": {
        "oui_hex": "00-0D-EB",
        "organization": "CompXs Limited",
        "address_1": "Robert Denholm House",
        "address_2": "Redhill  Surrey  RH1 4HW",
        "country": "GB"
    },
    "000DEE": {
        "oui_hex": "00-0D-EE",
        "organization": "Andrew RF Power Amplifier Group",
        "address_1": "40 Technology Drive",
        "address_2": "Warren  NJ  07059",
        "country": "US"
    },
    "000DEF": {
        "oui_hex": "00-0D-EF",
        "organization": "Soc. Coop. Bilanciai",
        "address_1": "via S.Ferrari 16",
        "address_2": "Campogalliano  Modena  41011",
        "country": "IT"
    },
    "000DE7": {
        "oui_hex": "00-0D-E7",
        "organization": "Snap-on OEM Group",
        "address_1": "2333 East Walton Blvd.",
        "address_2": "Auburn Hills  MI  48326",
        "country": "US"
    },
    "000DC6": {
        "oui_hex": "00-0D-C6",
        "organization": "DigiRose Technology Co., Ltd.",
        "address_1": "No. 1, Alley 20, Lane 26 Rueiguang Road,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000DC1": {
        "oui_hex": "00-0D-C1",
        "organization": "SafeWeb Inc",
        "address_1": "2200 Powell St. Ste 590",
        "address_2": "Emeryville  CA  94608",
        "country": "US"
    },
    "000DF0": {
        "oui_hex": "00-0D-F0",
        "organization": "QCOM TECHNOLOGY INC.",
        "address_1": "4F., No.301, Sec. 2, Tiding Blvd.",
        "address_2": "Taipei City  Neihu District  114",
        "country": "TW"
    },
    "000DE5": {
        "oui_hex": "00-0D-E5",
        "organization": "Samsung Thales",
        "address_1": "259 Gongdan-Dong",
        "address_2": "Gumi-City  Gyeongsangbuk-do  730-904",
        "country": "KR"
    },
    "000DC0": {
        "oui_hex": "00-0D-C0",
        "organization": "Spagat AS",
        "address_1": "Tonne Hutifeldtpl. 2",
        "address_2": "Halden  Ostfold  1767",
        "country": "NO"
    },
    "000DDD": {
        "oui_hex": "00-0D-DD",
        "organization": "Profilo Telra Elektronik Sanayi ve Ticaret. A.Ş",
        "address_1": "Cemal Sahir Sokak NO:26-28",
        "address_2": "İstanbul  TURKEY  34255",
        "country": "TR"
    },
    "000DF8": {
        "oui_hex": "00-0D-F8",
        "organization": "ORGA Kartensysteme GmbH",
        "address_1": "Konrad-Zuse-Ring 1",
        "address_2": "Flintbek  Schleswig-Holstein  24220",
        "country": "DE"
    },
    "000E16": {
        "oui_hex": "00-0E-16",
        "organization": "SouthWing S.L.",
        "address_1": "C/Avila, 48-50",
        "address_2": "Barcelona    08005",
        "country": "ES"
    },
    "000DA7": {
        "oui_hex": "00-0D-A7",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000DAD": {
        "oui_hex": "00-0D-AD",
        "organization": "Dataprobe, Inc.",
        "address_1": "1B Pearl Court",
        "address_2": "Allendale  NJ  07401",
        "country": "US"
    },
    "000DA9": {
        "oui_hex": "00-0D-A9",
        "organization": "T.E.A.M. S.L.",
        "address_1": "Parque Tecnologico Edificio 108",
        "address_2": "ZAMUDIO  Bizkaia  48170",
        "country": "ES"
    },
    "000DAB": {
        "oui_hex": "00-0D-AB",
        "organization": "Parker Hannifin GmbH Electromechanical Division Europe",
        "address_1": "Robert-Bosch-Straße 22",
        "address_2": "Offenburg  Baden-Württemberg  77656",
        "country": "DE"
    },
    "000DA8": {
        "oui_hex": "00-0D-A8",
        "organization": "Teletronics Technology Corporation",
        "address_1": "2525 Pearl Buck Road",
        "address_2": "Bristol  Pennsylvania  19007",
        "country": "US"
    },
    "000D79": {
        "oui_hex": "00-0D-79",
        "organization": "Dynamic Solutions Co,.Ltd.",
        "address_1": "17-8 Nihonbashi Hakozaki-cho",
        "address_2": "Chuo-ku  Tokyo  103-0015",
        "country": "JP"
    },
    "000D6D": {
        "oui_hex": "00-0D-6D",
        "organization": "K-Tech Devices Corp.",
        "address_1": "14016-30",
        "address_2": "nakaminowa minowamachi kamiina  nagano  399-4601",
        "country": "JP"
    },
    "000DAF": {
        "oui_hex": "00-0D-AF",
        "organization": "Plexus Corp (UK) Ltd",
        "address_1": "Pinnacle Hill",
        "address_2": "Kelso  Roxburghshire  TD5 8XX",
        "country": "GB"
    },
    "000DB1": {
        "oui_hex": "00-0D-B1",
        "organization": "Japan Network Service Co., Ltd.",
        "address_1": "Matoba Bldg. 6F,",
        "address_2": " Chuo-ku  Tokyo  104-0042",
        "country": "JP"
    },
    "000D83": {
        "oui_hex": "00-0D-83",
        "organization": "Sanmina-SCI Hungary  Ltd.",
        "address_1": "Kota Jozsef u. 2.",
        "address_2": "Tatabanya  Komarom-Esztergom  2800",
        "country": "HU"
    },
    "000D7F": {
        "oui_hex": "00-0D-7F",
        "organization": "MIDAS  COMMUNICATION TECHNOLOGIES PTE LTD ( Foreign Branch)",
        "address_1": "04-12, Phase Z.Ro Technoprenuer Park",
        "address_2": "Singapore    139 347",
        "country": "SG"
    },
    "000D75": {
        "oui_hex": "00-0D-75",
        "organization": "Kobian Pte Ltd - Taiwan Branch",
        "address_1": "2F, No.580, Rueikuang Rd.,Nei Hu,Taipei,",
        "address_2": "Taipei  Nei Hu  114",
        "country": "TW"
    },
    "000D78": {
        "oui_hex": "00-0D-78",
        "organization": "Engineering & Security",
        "address_1": "Martiri della Libertà   32/4",
        "address_2": "Genova    16155",
        "country": "IT"
    },
    "000D9E": {
        "oui_hex": "00-0D-9E",
        "organization": "TOKUDEN OHIZUMI SEISAKUSYO Co.,Ltd.",
        "address_1": "Yoshida 1221",
        "address_2": "Ouragun Ohizumi  Gunma  370-0523",
        "country": "JP"
    },
    "000DA3": {
        "oui_hex": "00-0D-A3",
        "organization": "Emerging Technologies Limited",
        "address_1": "Wong's Industrial Centre, 180 Wai Yip St",
        "address_2": "  Nil",
        "country": "HK"
    },
    "000DA4": {
        "oui_hex": "00-0D-A4",
        "organization": "DOSCH & AMAND SYSTEMS AG",
        "address_1": "Scheinerstrasse 9",
        "address_2": "Munich  Bavaria  81679",
        "country": "DE"
    },
    "000D9A": {
        "oui_hex": "00-0D-9A",
        "organization": "INFOTEC LTD",
        "address_1": "The Maltings",
        "address_2": "Ashby-de-la-Zouch  Leicestershire  LE65 2PS",
        "country": "GB"
    },
    "000D6E": {
        "oui_hex": "00-0D-6E",
        "organization": "K-Patents Oy",
        "address_1": "P.O. Box 77",
        "address_2": "VANTAA  FI  01511",
        "country": "FI"
    },
    "000D6A": {
        "oui_hex": "00-0D-6A",
        "organization": "Redwood Technologies LTD",
        "address_1": "Amber House",
        "address_2": "Bracknell  Berkshire  RG12 1JB",
        "country": "GB"
    },
    "000DBA": {
        "oui_hex": "00-0D-BA",
        "organization": "Océ Document Technologies GmbH",
        "address_1": "Max-Stromeyer-Straße  116",
        "address_2": "Konstanz    78467",
        "country": "DE"
    },
    "000DBD": {
        "oui_hex": "00-0D-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000DB5": {
        "oui_hex": "00-0D-B5",
        "organization": "GLOBALSAT TECHNOLOGY CORPORATION",
        "address_1": "Far East Century Park",
        "address_2": "Taipei Hsien    235",
        "country": "TW"
    },
    "000D97": {
        "oui_hex": "00-0D-97",
        "organization": "ABB Inc./Tropos",
        "address_1": "1710 S. Amphlett Blvd,  Suite 304",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "000D96": {
        "oui_hex": "00-0D-96",
        "organization": "Vtera Technology Inc.",
        "address_1": "No 34, Industrial East. 4th Rd.",
        "address_2": "HsinChu    300",
        "country": "TW"
    },
    "000D8B": {
        "oui_hex": "00-0D-8B",
        "organization": "T&D Corporation",
        "address_1": "5652-169 Sasaga",
        "address_2": "Matsumoto  Nagano  399-0033",
        "country": "JP"
    },
    "000D90": {
        "oui_hex": "00-0D-90",
        "organization": "Factum Electronics AB",
        "address_1": "Teknikringen 1H",
        "address_2": "Linköping  Östergötland  583 30",
        "country": "SE"
    },
    "000D85": {
        "oui_hex": "00-0D-85",
        "organization": "Tapwave, Inc.",
        "address_1": "1901 Landings Drive",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "000D82": {
        "oui_hex": "00-0D-82",
        "organization": "PHSNET",
        "address_1": "Piazza Mariano Rumor, 18",
        "address_2": "Arcugnano  Vicenza  36057",
        "country": "IT"
    },
    "000D23": {
        "oui_hex": "00-0D-23",
        "organization": "Smart Solution, Inc",
        "address_1": "465 West Lawndale #B",
        "address_2": "Salt Lake City  UT  84115",
        "country": "US"
    },
    "000D27": {
        "oui_hex": "00-0D-27",
        "organization": "MICROPLEX Printware AG",
        "address_1": "Panzerstraße 5",
        "address_2": "Varel  Niedersachsen  26316",
        "country": "DE"
    },
    "000D1B": {
        "oui_hex": "00-0D-1B",
        "organization": "Kyoto Electronics Manufacturing Co., Ltd.",
        "address_1": "56-2, Ninodan-cho, Shinden,",
        "address_2": "Kyoto-City  Kyoto Prefecture  601-8317",
        "country": "JP"
    },
    "000D1D": {
        "oui_hex": "00-0D-1D",
        "organization": "HIGH-TEK HARNESS ENT. CO., LTD.",
        "address_1": "4F-6, No18, Pu-Ting Rd. Hsinchu, Taiwan",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000D02": {
        "oui_hex": "00-0D-02",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "000D07": {
        "oui_hex": "00-0D-07",
        "organization": "Calrec Audio Ltd",
        "address_1": "Nutclough Mill",
        "address_2": "Hebden Bridge  West Yorkshire  HX7 8EZ",
        "country": "GB"
    },
    "000D40": {
        "oui_hex": "00-0D-40",
        "organization": "Verint Loronix Video Solutions",
        "address_1": "12526 High Bluff Dr. #170",
        "address_2": "San DIego  CA  92130",
        "country": "US"
    },
    "000D21": {
        "oui_hex": "00-0D-21",
        "organization": "WISCORE Inc.",
        "address_1": "6F, No. 180, Sec. 2, Duenhua S. Rd,",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "000D09": {
        "oui_hex": "00-0D-09",
        "organization": "Yuehua(Zhuhai) Electronic CO. LTD",
        "address_1": "4Rd Pingdong,Nanping Science & Technolog",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "000D37": {
        "oui_hex": "00-0D-37",
        "organization": "WIPLUG",
        "address_1": "RUA  DR. AGOSTINHO GOULAO",
        "address_2": "PETROPOLIS  RIO JANEIRO  25730050",
        "country": "BR"
    },
    "000D33": {
        "oui_hex": "00-0D-33",
        "organization": "Prediwave Corp.",
        "address_1": "48431 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000D2F": {
        "oui_hex": "00-0D-2F",
        "organization": "AIN Comm.Tech.Co., LTD",
        "address_1": "4F, No.76, Sec2 Mintzu Rd",
        "address_2": "Jung-Li City    320",
        "country": "TW"
    },
    "000D5D": {
        "oui_hex": "00-0D-5D",
        "organization": "Raritan Computer, Inc",
        "address_1": "400 Cottontail Lane",
        "address_2": "Somerset  NJ  08873",
        "country": "US"
    },
    "000D63": {
        "oui_hex": "00-0D-63",
        "organization": "DENT Instruments, Inc.",
        "address_1": "64 NW Franklin Ave",
        "address_2": "Bend  OR  97701",
        "country": "US"
    },
    "000D66": {
        "oui_hex": "00-0D-66",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000CCD": {
        "oui_hex": "00-0C-CD",
        "organization": "IEC - TC57",
        "address_1": "3, rue de Varembé",
        "address_2": "Geneva  GE  1211",
        "country": "CH"
    },
    "000CCB": {
        "oui_hex": "00-0C-CB",
        "organization": "Design Combus Ltd",
        "address_1": "Hatanapaan valtatie 34A",
        "address_2": "Tampere    FIN-33100",
        "country": "FI"
    },
    "000CC9": {
        "oui_hex": "00-0C-C9",
        "organization": "ILWOO DATA & TECHNOLOGY CO.,LTD",
        "address_1": "1475-10,HWA HYUN BLD. 2nd Floor,",
        "address_2": "SEOUL    137-071",
        "country": "KR"
    },
    "000CE9": {
        "oui_hex": "00-0C-E9",
        "organization": "BLOOMBERG L.P.",
        "address_1": "731 Lexington Ave",
        "address_2": "NEW YORK  NEW YORK  10022",
        "country": "US"
    },
    "000CEA": {
        "oui_hex": "00-0C-EA",
        "organization": "aphona Kommunikationssysteme",
        "address_1": "Entwicklungs- und VertriebsgmbH",
        "address_2": "Wien    1230",
        "country": "AT"
    },
    "000CDA": {
        "oui_hex": "00-0C-DA",
        "organization": "FreeHand Systems, Inc.",
        "address_1": "95 First St.",
        "address_2": "Los Altos  CA  94022",
        "country": "US"
    },
    "000CF5": {
        "oui_hex": "00-0C-F5",
        "organization": "InfoExpress",
        "address_1": "170 S. Whisman Road, Suite B",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "000CEE": {
        "oui_hex": "00-0C-EE",
        "organization": "jp-embedded",
        "address_1": "Buen 21, Nr. Dalby",
        "address_2": "Borup    4140",
        "country": "DK"
    },
    "000CAF": {
        "oui_hex": "00-0C-AF",
        "organization": "TRI TERM CO.,LTD.",
        "address_1": "21-5 HIRAIDE KOUGIYO DANCHI",
        "address_2": "TOCHIGI    321-0905",
        "country": "JP"
    },
    "000CB3": {
        "oui_hex": "00-0C-B3",
        "organization": "ROUND Co.,Ltd.",
        "address_1": "3-9 Gokashou-Shibahigashi",
        "address_2": "uji  kyoto  611-0011",
        "country": "JP"
    },
    "000CDD": {
        "oui_hex": "00-0C-DD",
        "organization": "AOS technologies AG",
        "address_1": "Taefernstrasse 20",
        "address_2": "Baden - Daettwil  AG  CH-5405",
        "country": "CH"
    },
    "000CA5": {
        "oui_hex": "00-0C-A5",
        "organization": "Naman NZ LTd",
        "address_1": "13/17 Kawana St",
        "address_2": "Auckland",
        "country": "NZ"
    },
    "000CA9": {
        "oui_hex": "00-0C-A9",
        "organization": "Ebtron Inc.",
        "address_1": "1663 Hwy 701 South",
        "address_2": "Loris  SC  29569",
        "country": "US"
    },
    "000CFB": {
        "oui_hex": "00-0C-FB",
        "organization": "Korea Network Systems",
        "address_1": "206  JangYoungSil Bldg, 1688-5",
        "address_2": "Taejeon    306-230",
        "country": "KR"
    },
    "000C7A": {
        "oui_hex": "00-0C-7A",
        "organization": "DaTARIUS Technologies GmbH",
        "address_1": "Anton Maria Schyrle Str. 7",
        "address_2": "Reutte  Tirol  6600",
        "country": "AT"
    },
    "000C79": {
        "oui_hex": "00-0C-79",
        "organization": "Extel Communications P/L",
        "address_1": "399 Ferntree Gully Road",
        "address_2": "Mt Waverley  Victoria  3149",
        "country": "AU"
    },
    "000C75": {
        "oui_hex": "00-0C-75",
        "organization": "Oriental integrated electronics. LTD",
        "address_1": "281-34 Dondang-dong Wonmi-Gu",
        "address_2": "Bucheon    420-808",
        "country": "KR"
    },
    "000C5D": {
        "oui_hex": "00-0C-5D",
        "organization": "CHIC TECHNOLOGY (CHINA) CORP.",
        "address_1": "7th Building,Shi'ao Ind.Zone,Longhua Tow",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "000C4F": {
        "oui_hex": "00-0C-4F",
        "organization": "UDTech Japan Corporation",
        "address_1": "Hamacho Hanacho Bldg, 2F",
        "address_2": "Chuo-ku  Tokyo  103-0007",
        "country": "JP"
    },
    "000C62": {
        "oui_hex": "00-0C-62",
        "organization": "ABB AB, Cewe-Control",
        "address_1": "Dept. LPCC/RE",
        "address_2": "Vasteras    721 61",
        "country": "SE"
    },
    "000C4C": {
        "oui_hex": "00-0C-4C",
        "organization": "Arcor AG&Co.",
        "address_1": "Alfred-Herrhausen-Allee 1",
        "address_2": "Eschborn  Hessen  65760",
        "country": "DE"
    },
    "000C47": {
        "oui_hex": "00-0C-47",
        "organization": "SK Teletech(R&D Planning Team)",
        "address_1": "21th FL Startower 737, Yeoksam-dong",
        "address_2": "Seoul    135-984",
        "country": "KR"
    },
    "000C6D": {
        "oui_hex": "00-0C-6D",
        "organization": "Edwards Ltd.",
        "address_1": "Marshall Road",
        "address_2": "Eastbourne  East Sussex  BN22 9BA",
        "country": "GB"
    },
    "000C70": {
        "oui_hex": "00-0C-70",
        "organization": "ACC GmbH",
        "address_1": "Am Sandfeld 15",
        "address_2": "Karlsruhe  Baden  76149",
        "country": "DE"
    },
    "000C6A": {
        "oui_hex": "00-0C-6A",
        "organization": "MBARI",
        "address_1": "7700 Sandholdt Road",
        "address_2": "Moss Landing  CA  95039",
        "country": "US"
    },
    "000C6B": {
        "oui_hex": "00-0C-6B",
        "organization": "Kurz Industrie-Elektronik GmbH",
        "address_1": "Foehrenbachstraße 3",
        "address_2": "Remshalden  Baden-Württemberg  73630",
        "country": "DE"
    },
    "000C9D": {
        "oui_hex": "00-0C-9D",
        "organization": "UbeeAirWalk, Inc.",
        "address_1": "1850 N. GreenVille Ave., Suite 164",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "000C9F": {
        "oui_hex": "00-0C-9F",
        "organization": "NKE Corporation",
        "address_1": "366-1 Hishikawa-cho Hazukashi Fushimi-ku",
        "address_2": "Kyoto-shi  Kyoto  612-8487",
        "country": "JP"
    },
    "000C84": {
        "oui_hex": "00-0C-84",
        "organization": "Eazix, Inc.",
        "address_1": "Unit 301 Plaza Building B",
        "address_2": "Muntinlupa City  Rizal  1770",
        "country": "PH"
    },
    "000C85": {
        "oui_hex": "00-0C-85",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000C3F": {
        "oui_hex": "00-0C-3F",
        "organization": "Cogent Defence & Security Networks,",
        "address_1": "Meadows Road,",
        "address_2": "Newport,  South Wales,  NP19 4SS",
        "country": "GB"
    },
    "000C30": {
        "oui_hex": "00-0C-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000C9A": {
        "oui_hex": "00-0C-9A",
        "organization": "Hitech Electronics Corp.",
        "address_1": "4f, No. 501-15 Chung-Cheng Rd.",
        "address_2": "Shin-tien  Taipei Shien  231",
        "country": "TW"
    },
    "000C91": {
        "oui_hex": "00-0C-91",
        "organization": "Riverhead Networks Inc.",
        "address_1": "",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000BDA": {
        "oui_hex": "00-0B-DA",
        "organization": "EyeCross Co.,Inc.",
        "address_1": "3F  Iioka-Building",
        "address_2": "Tokyo  Ueno Taitoh-ku 3-4-1  110-0005",
        "country": "JP"
    },
    "000BD6": {
        "oui_hex": "00-0B-D6",
        "organization": "Paxton Access Ltd",
        "address_1": "Paxton House",
        "address_2": "Brighton  East Sussex  BN1 9HU",
        "country": "GB"
    },
    "000BD4": {
        "oui_hex": "00-0B-D4",
        "organization": "Beijing Wise Technology & Science Development Co.Ltd",
        "address_1": "3rd Floor Caihong Building, No.2,1st Wes",
        "address_2": "Beijing    100088",
        "country": "CN"
    },
    "000C1F": {
        "oui_hex": "00-0C-1F",
        "organization": "Glimmerglass Networks",
        "address_1": "26142 Eden Landing Road",
        "address_2": "Hayward  California  94545",
        "country": "US"
    },
    "000C20": {
        "oui_hex": "00-0C-20",
        "organization": "Fi WIn, Inc.",
        "address_1": "8F, No. 10, Prosperity Rd. 1,",
        "address_2": "Hsin Chu    300",
        "country": "TW"
    },
    "000C15": {
        "oui_hex": "00-0C-15",
        "organization": "CyberPower Systems, Inc.",
        "address_1": "6F, No. 32, Sec. 1, Chenggong Rd.",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "000BF8": {
        "oui_hex": "00-0B-F8",
        "organization": "Infinera",
        "address_1": "1322 Bordeaux Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000BFF": {
        "oui_hex": "00-0B-FF",
        "organization": "Berkeley Camera Engineering",
        "address_1": "127 National Street",
        "address_2": "Santa Cruz  CA  95060",
        "country": "US"
    },
    "000C16": {
        "oui_hex": "00-0C-16",
        "organization": "Concorde Microsystems Inc.",
        "address_1": "10427 Cogdill Road, Suite 500",
        "address_2": "Knoxville  TN  37932",
        "country": "US"
    },
    "000C09": {
        "oui_hex": "00-0C-09",
        "organization": "Hitachi IE Systems Co., Ltd",
        "address_1": "Saiwai-cho 120-1,Inazawa-shi",
        "address_2": "Inazawa-shi  Aichi  492-8622",
        "country": "JP"
    },
    "000BE7": {
        "oui_hex": "00-0B-E7",
        "organization": "COMFLUX TECHNOLOGY INC.",
        "address_1": " Room 131,Bldg. 53,195-58,Sec.4,",
        "address_2": "Hsinchu    310",
        "country": "TW"
    },
    "000BEC": {
        "oui_hex": "00-0B-EC",
        "organization": "NIPPON ELECTRIC INSTRUMENT, INC.",
        "address_1": "3-56-21 Hirado",
        "address_2": "Totsuka-ku  Yokohama-shi  244-0802",
        "country": "JP"
    },
    "000C02": {
        "oui_hex": "00-0C-02",
        "organization": "ABB Oy",
        "address_1": "P.O.Box 89",
        "address_2": "Turku    FIN-20521",
        "country": "FI"
    },
    "000B71": {
        "oui_hex": "00-0B-71",
        "organization": "Litchfield Communications Inc.",
        "address_1": "27 Princeton Road",
        "address_2": "Watertown  CT  06795",
        "country": "US"
    },
    "000B74": {
        "oui_hex": "00-0B-74",
        "organization": "Kingwave Technology Co., Ltd.",
        "address_1": "18F-3, No. 186, Jian-Yi Rd.",
        "address_2": "Chung-Ho  Taipei  235",
        "country": "TW"
    },
    "000B73": {
        "oui_hex": "00-0B-73",
        "organization": "Kodeos Communications",
        "address_1": "111 Corporate Blvd",
        "address_2": "South Plainfield  NJ  07080",
        "country": "US"
    },
    "000B76": {
        "oui_hex": "00-0B-76",
        "organization": "ET&T Technology Co. Ltd.",
        "address_1": "6F No.101, SongJiang Rd.",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "000B5E": {
        "oui_hex": "00-0B-5E",
        "organization": "Audio Engineering Society Inc.",
        "address_1": "60 East 42nd Street, Suite #2520",
        "address_2": "New York  NY  10165-2520",
        "country": "US"
    },
    "000B60": {
        "oui_hex": "00-0B-60",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000B65": {
        "oui_hex": "00-0B-65",
        "organization": "Sy.A.C. srl",
        "address_1": "via Caboto 19/1",
        "address_2": "Trieste    34147",
        "country": "IT"
    },
    "000B5F": {
        "oui_hex": "00-0B-5F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000B61": {
        "oui_hex": "00-0B-61",
        "organization": "Friedrich Lütze GmbH & Co. KG",
        "address_1": "Bruckwiesenstraße 17 - 19",
        "address_2": "Weinstadt (Großheppach)  BW  71384",
        "country": "DE"
    },
    "000B59": {
        "oui_hex": "00-0B-59",
        "organization": "ScriptPro, LLC",
        "address_1": "5828 Reeds Rd.",
        "address_2": "Mission  Kansas  66202",
        "country": "US"
    },
    "000B5C": {
        "oui_hex": "00-0B-5C",
        "organization": "Newtech Co.,Ltd",
        "address_1": "K-Bldg 1-7-7 Shibadaimon Minato-ku",
        "address_2": "Tokyo    105-0012",
        "country": "JP"
    },
    "000B7E": {
        "oui_hex": "00-0B-7E",
        "organization": "SAGINOMIYA Seisakusho Inc.",
        "address_1": "535 Sasai",
        "address_2": "Sayamashi  Saitamaken  350-1395",
        "country": "JP"
    },
    "000B80": {
        "oui_hex": "00-0B-80",
        "organization": "Lycium Networks",
        "address_1": "9 Hamenofim St.",
        "address_2": "Herzliya  Israel  46733",
        "country": "IL"
    },
    "000BA7": {
        "oui_hex": "00-0B-A7",
        "organization": "Maranti Networks",
        "address_1": "3061-B Zanker Road",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000BAA": {
        "oui_hex": "00-0B-AA",
        "organization": "Aiphone co.,Ltd",
        "address_1": "2-18 Jinno-Cho",
        "address_2": "Nagoya  Aichi-ken  456-8666",
        "country": "JP"
    },
    "000BA4": {
        "oui_hex": "00-0B-A4",
        "organization": "Shiron Satellite Communications Ltd. (1996)",
        "address_1": "23 Hasivim St.",
        "address_2": "Petach Tikva    49170",
        "country": "IL"
    },
    "000BD0": {
        "oui_hex": "00-0B-D0",
        "organization": "XiMeta Technology Americas Inc.",
        "address_1": "54 Ray Street",
        "address_2": "New Brunswick  NJ  08901",
        "country": "US"
    },
    "000BC5": {
        "oui_hex": "00-0B-C5",
        "organization": "SMC Networks, Inc.",
        "address_1": "38 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000BC6": {
        "oui_hex": "00-0B-C6",
        "organization": "ISAC, Inc.",
        "address_1": "PO Box 7682",
        "address_2": "Auburn  CA  95604",
        "country": "US"
    },
    "000BC1": {
        "oui_hex": "00-0B-C1",
        "organization": "Bay Microsystems, Inc.",
        "address_1": "2055 Gateway Place",
        "address_2": "Santa Jose  CA  95110",
        "country": "US"
    },
    "000B8B": {
        "oui_hex": "00-0B-8B",
        "organization": "KERAJET, S.A.",
        "address_1": "Avda. del Boverot, 24",
        "address_2": "Almazora  Castellon  E-12550",
        "country": "ES"
    },
    "000B89": {
        "oui_hex": "00-0B-89",
        "organization": "Top Global Technology, Ltd.",
        "address_1": "Room 3310, China World Tower No. 1",
        "address_2": "Beijing  Beijing  100004",
        "country": "CN"
    },
    "000B99": {
        "oui_hex": "00-0B-99",
        "organization": "SensAble Technologies, Inc.",
        "address_1": "15 Constitution Way",
        "address_2": "Woburn  MA  01801",
        "country": "US"
    },
    "000B9C": {
        "oui_hex": "00-0B-9C",
        "organization": "TriBeam Technologies, Inc.",
        "address_1": "116 W. Eastman St., suite 208",
        "address_2": "Arlington Heights  IL  60004",
        "country": "US"
    },
    "000B7C": {
        "oui_hex": "00-0B-7C",
        "organization": "Telex Communications",
        "address_1": "8601 E. Cornhusker Hwy",
        "address_2": "Lincoln  NE  68505",
        "country": "US"
    },
    "000B83": {
        "oui_hex": "00-0B-83",
        "organization": "DATAWATT B.V.",
        "address_1": "HOUTSTRAAT 5",
        "address_2": "WOLVEGA    NL-8471-ZX",
        "country": "NL"
    },
    "000B20": {
        "oui_hex": "00-0B-20",
        "organization": "Hirata corporation",
        "address_1": "111 Hitotsugi, Ueki, Kamoto,",
        "address_2": "  Kumamoto  861-0198",
        "country": "JP"
    },
    "000B22": {
        "oui_hex": "00-0B-22",
        "organization": "Environmental Systems and Services",
        "address_1": "20 Council Street",
        "address_2": "Hawthorn East  Victoria  3123",
        "country": "AU"
    },
    "000B1B": {
        "oui_hex": "00-0B-1B",
        "organization": "Systronix, Inc.",
        "address_1": "939 Edison St.",
        "address_2": "Salt Lake City  Utah  84111",
        "country": "US"
    },
    "000B03": {
        "oui_hex": "00-0B-03",
        "organization": "Taekwang Industrial Co., Ltd",
        "address_1": "#191-1, Anyang-7Dong, Manan-Gu",
        "address_2": "Anyang-Si  South Korea  430-017",
        "country": "KR"
    },
    "000B01": {
        "oui_hex": "00-0B-01",
        "organization": "DAIICHI ELECTRONICS CO., LTD.",
        "address_1": "1-11-13",
        "address_2": "Hitotsuya  Adachi-ku Tokyo  121-8639",
        "country": "JP"
    },
    "000B3E": {
        "oui_hex": "00-0B-3E",
        "organization": "BittWare, Inc",
        "address_1": "31 B South Main St",
        "address_2": "Concord  NH  03301",
        "country": "US"
    },
    "000B29": {
        "oui_hex": "00-0B-29",
        "organization": "LS(LG) Industrial Systems co.,Ltd",
        "address_1": "533 Hogye-dong, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do",
        "country": "KR"
    },
    "000B39": {
        "oui_hex": "00-0B-39",
        "organization": "Keisoku Giken Co.,Ltd.",
        "address_1": "Tsuzuki-ku",
        "address_2": "Yokohama  Kanagawa  224-0037",
        "country": "JP"
    },
    "000B3A": {
        "oui_hex": "00-0B-3A",
        "organization": "QuStream Corporation",
        "address_1": "3305 Breckinridge Blvd.",
        "address_2": "Duluth  Georgia  30096",
        "country": "US"
    },
    "000B33": {
        "oui_hex": "00-0B-33",
        "organization": "Vivato Technologies",
        "address_1": "444 Cedros Ave",
        "address_2": "Solana Beach  CA  92027",
        "country": "US"
    },
    "000B05": {
        "oui_hex": "00-0B-05",
        "organization": "Pacific Broadband Networks",
        "address_1": "Suite 15,  Building 3, 195 Wellington Road",
        "address_2": "Clayton  VIC  3168",
        "country": "AU"
    },
    "000B00": {
        "oui_hex": "00-0B-00",
        "organization": "FUJIAN START COMPUTER EQUIPMENT CO.,LTD",
        "address_1": "HONG SHAN YUAN ROAD NO.68 HONGSHAN,GULOU",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "000B5B": {
        "oui_hex": "00-0B-5B",
        "organization": "Rincon Research Corporation",
        "address_1": "101 N. Wilmot Rd.",
        "address_2": "Tucson  AZ  85711",
        "country": "US"
    },
    "000AF6": {
        "oui_hex": "00-0A-F6",
        "organization": "Emerson Climate Technologies Retail Solutions, Inc.",
        "address_1": "1640 Airport Rd",
        "address_2": "Kennesaw  GA  30144-7038",
        "country": "US"
    },
    "000B11": {
        "oui_hex": "00-0B-11",
        "organization": "HIMEJI ABC TRADING CO.,LTD.",
        "address_1": "1-8-22",
        "address_2": "HJMEJI  HYOGO  670-0883",
        "country": "JP"
    },
    "000B41": {
        "oui_hex": "00-0B-41",
        "organization": "Ing. Büro Dr. Beutlhauser",
        "address_1": "Roemerweg 4",
        "address_2": "  Grassau  D-83224",
        "country": "DE"
    },
    "000AEA": {
        "oui_hex": "00-0A-EA",
        "organization": "ADAM ELEKTRONIK LTD. ŞTI",
        "address_1": "UZUNAYNA CAD. CELENK SOK. NO:1 Çakmak",
        "address_2": "İstanbul    81260",
        "country": "TR"
    },
    "000AE3": {
        "oui_hex": "00-0A-E3",
        "organization": "YANG MEI TECHNOLOGY CO., LTD",
        "address_1": "21, Alley 1, Lane 342",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000ADC": {
        "oui_hex": "00-0A-DC",
        "organization": "RuggedCom Inc.",
        "address_1": "30 Whitmore Road",
        "address_2": "Woodbridge  Ontario  L4L 7Z4",
        "country": "CA"
    },
    "000AB7": {
        "oui_hex": "00-0A-B7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000AAD": {
        "oui_hex": "00-0A-AD",
        "organization": "Stargames Corporation",
        "address_1": "13 Sheridan Close",
        "address_2": "Milperra  NSW  2031",
        "country": "AU"
    },
    "000AB1": {
        "oui_hex": "00-0A-B1",
        "organization": "GENETEC Corporation",
        "address_1": "BYGS Shinjyuku Bldg. 5F",
        "address_2": "Shinjuku-ku  Tokyo  162-0022",
        "country": "JP"
    },
    "000AB9": {
        "oui_hex": "00-0A-B9",
        "organization": "Astera Technologies Corp.",
        "address_1": " 2380 Waverley Street",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "000A90": {
        "oui_hex": "00-0A-90",
        "organization": "Bayside Interactive, Inc.",
        "address_1": "330 Biscayne Blvd.",
        "address_2": "Miami  FL  33132",
        "country": "US"
    },
    "000A9D": {
        "oui_hex": "00-0A-9D",
        "organization": "King Young Technology Co. Ltd.",
        "address_1": "1Fl., No. 9, Lane 26, Gangchi Rd., Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000AA1": {
        "oui_hex": "00-0A-A1",
        "organization": "V V S Limited",
        "address_1": "HPIC, 1. Ainslie Road ,",
        "address_2": "Glasgow  Scotland  G52 4RU",
        "country": "GB"
    },
    "000AA4": {
        "oui_hex": "00-0A-A4",
        "organization": "SHANGHAI SURVEILLANCE TECHNOLOGY CO,LTD",
        "address_1": "FL.25A,NO.8 CHANGYANG ROAD",
        "address_2": "SHANGHAI    200082",
        "country": "CN"
    },
    "000A9E": {
        "oui_hex": "00-0A-9E",
        "organization": "BroadWeb Corportation",
        "address_1": "3F, 24-1, Industry East Rd., IV,",
        "address_2": "  Hsin-Chu  300",
        "country": "TW"
    },
    "000AE0": {
        "oui_hex": "00-0A-E0",
        "organization": "Fujitsu Softek",
        "address_1": "1250 East Arques Ave",
        "address_2": "Sunnyvale  Ca  94085",
        "country": "US"
    },
    "000A8B": {
        "oui_hex": "00-0A-8B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000A88": {
        "oui_hex": "00-0A-88",
        "organization": "InCypher S.A.",
        "address_1": "18 rue de l'Eau",
        "address_2": "Luxembourg    1449",
        "country": "LU"
    },
    "000ABB": {
        "oui_hex": "00-0A-BB",
        "organization": "Taiwan Secom Co,. Ltd",
        "address_1": "13F, 108, Sec1, Shin-Tai 5th Road",
        "address_2": "Hsi-Chih  Taipei County  221",
        "country": "TW"
    },
    "000A7C": {
        "oui_hex": "00-0A-7C",
        "organization": "Tecton Ltd",
        "address_1": "Fishers Court",
        "address_2": "Eastleigh  Hampshire  SO50 7HG",
        "country": "GB"
    },
    "000A6E": {
        "oui_hex": "00-0A-6E",
        "organization": "Harmonic, Inc",
        "address_1": "4300 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000A6D": {
        "oui_hex": "00-0A-6D",
        "organization": "EKS Elektronikservice GmbH",
        "address_1": "Enzstr. 9",
        "address_2": "Kornwestheim  Baden-Württemberg  70806",
        "country": "DE"
    },
    "000A43": {
        "oui_hex": "00-0A-43",
        "organization": "Chunghwa Telecom Co., Ltd.",
        "address_1": "12, Lane 551, Min-Tsu Road",
        "address_2": "Taoyuan    326",
        "country": "TW"
    },
    "000A45": {
        "oui_hex": "00-0A-45",
        "organization": "Audio-Technica Corp.",
        "address_1": "Naruse 1,348",
        "address_2": "Machida  Tokyo  194-8566",
        "country": "JP"
    },
    "000A35": {
        "oui_hex": "00-0A-35",
        "organization": "Xilinx",
        "address_1": "2100 Logic Drive",
        "address_2": "San Jose  CA  94110",
        "country": "US"
    },
    "000A3B": {
        "oui_hex": "00-0A-3B",
        "organization": "GCT Semiconductor, Inc",
        "address_1": "2121 Ringwood Avenue",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000A74": {
        "oui_hex": "00-0A-74",
        "organization": "Manticom Networks Inc.",
        "address_1": "14016-C Sullyfield Circle",
        "address_2": "Chantilly  VA  20151",
        "country": "US"
    },
    "000A6F": {
        "oui_hex": "00-0A-6F",
        "organization": "ZyFLEX Technologies Inc",
        "address_1": "2Fl. No. 58 Park Ave. II",
        "address_2": "S.B.I.P., Hsinchu    30077",
        "country": "TW"
    },
    "000A63": {
        "oui_hex": "00-0A-63",
        "organization": "DHD GmbH",
        "address_1": "Haferkornstrasse 5",
        "address_2": "Leipzig  Sachsen  04129",
        "country": "DE"
    },
    "000A2E": {
        "oui_hex": "00-0A-2E",
        "organization": "MAPLE NETWORKS CO., LTD",
        "address_1": "602, Dongwha",
        "address_2": "SEOUL    156-010",
        "country": "KR"
    },
    "000A2D": {
        "oui_hex": "00-0A-2D",
        "organization": "Cabot Communications Limited",
        "address_1": "Verona House",
        "address_2": "Bristol  Gloucestershire  BS16 3RY",
        "country": "US"
    },
    "000A25": {
        "oui_hex": "00-0A-25",
        "organization": "CERAGON NETWORKS",
        "address_1": "24 RAUEL WALLENBERG STREET",
        "address_2": "TEL-AVIV    96719",
        "country": "IL"
    },
    "000A21": {
        "oui_hex": "00-0A-21",
        "organization": "Integra Telecom Co. Ltd",
        "address_1": "7th floor Hwayoung Bld. 112-2",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000A1E": {
        "oui_hex": "00-0A-1E",
        "organization": "Red-M Products Limited",
        "address_1": "Neptune House",
        "address_2": "Wooburn Green  Buckinghamshire  HP10 0HH",
        "country": "GB"
    },
    "000A4B": {
        "oui_hex": "00-0A-4B",
        "organization": "DataPower Technology, Inc.",
        "address_1": "One Alewife Center",
        "address_2": "Cambridge  MA  02140",
        "country": "US"
    },
    "000A33": {
        "oui_hex": "00-0A-33",
        "organization": "Emulex Corporation",
        "address_1": "2021 Opportunity Drive",
        "address_2": "Roseville  CA  95678",
        "country": "US"
    },
    "000A67": {
        "oui_hex": "00-0A-67",
        "organization": "OngCorp",
        "address_1": "481 Hackensack Ave.",
        "address_2": "Hackensack  NJ  07601",
        "country": "US"
    },
    "0009F9": {
        "oui_hex": "00-09-F9",
        "organization": "ART JAPAN CO., LTD.",
        "address_1": "322-7, Ichinotsubo,",
        "address_2": "Kawasaki  Kanagawa  211-0016",
        "country": "JP"
    },
    "0009FC": {
        "oui_hex": "00-09-FC",
        "organization": "IPFLEX Inc.",
        "address_1": "Mowa-Bldg 3F, 1-16-6",
        "address_2": "Shibuya-ku  Tokyo  150-0021",
        "country": "JP"
    },
    "0009FD": {
        "oui_hex": "00-09-FD",
        "organization": "Ubinetics Limited",
        "address_1": "Cambridge Technology Centre",
        "address_2": "Melbourn  Hertfordshire  SG8 6DP",
        "country": "GB"
    },
    "0009F7": {
        "oui_hex": "00-09-F7",
        "organization": "SED, a division of Calian",
        "address_1": "18 Innnovation Boulevard",
        "address_2": "Saskatoon  Saskatchewan (SK)  S7K 3P7",
        "country": "CA"
    },
    "0009E2": {
        "oui_hex": "00-09-E2",
        "organization": "Sinbon Electronics Co., Ltd.",
        "address_1": "4F-13, No. 79, Sec 1, Hsin Tai Wu Rd.",
        "address_2": "Hsi-Chih, Taipei    221",
        "country": "TW"
    },
    "0009DA": {
        "oui_hex": "00-09-DA",
        "organization": "Control Module Inc.",
        "address_1": "227 Brainard Road",
        "address_2": "Enfield  CT  06082",
        "country": "US"
    },
    "0009D7": {
        "oui_hex": "00-09-D7",
        "organization": "DC Security Products",
        "address_1": "One Lindsay Circle",
        "address_2": "San Francisco  California  94124",
        "country": "US"
    },
    "0009D8": {
        "oui_hex": "00-09-D8",
        "organization": "Fält Communications AB",
        "address_1": "Kylgränd 6a",
        "address_2": "SE 906 20  Umeå",
        "country": "SE"
    },
    "000A14": {
        "oui_hex": "00-0A-14",
        "organization": "TECO a.s.",
        "address_1": "Havlickova 260",
        "address_2": "KOLIN  CZ  280 58",
        "country": "CZ"
    },
    "000A0B": {
        "oui_hex": "00-0A-0B",
        "organization": "Sealevel Systems, Inc.",
        "address_1": "155 Technology Place",
        "address_2": "Liberty  SC  29657",
        "country": "US"
    },
    "000A10": {
        "oui_hex": "00-0A-10",
        "organization": "FAST media integrations AG",
        "address_1": "Schöngrund 26",
        "address_2": "Rotkreuz  Canton of Zug  6343",
        "country": "CH"
    },
    "0009DB": {
        "oui_hex": "00-09-DB",
        "organization": "eSpace",
        "address_1": "9623 Simsbury Ct.",
        "address_2": "Twinsburg  OH  44087-3220",
        "country": "US"
    },
    "0009D5": {
        "oui_hex": "00-09-D5",
        "organization": "Signal Communication, Inc.",
        "address_1": "100 Wood Ave South",
        "address_2": "Iselin  NJ  08830",
        "country": "US"
    },
    "0009D3": {
        "oui_hex": "00-09-D3",
        "organization": "Western DataCom Co., Inc.",
        "address_1": "925-D Bassett Rd.",
        "address_2": "Westlake  OH  44145",
        "country": "US"
    },
    "0009BC": {
        "oui_hex": "00-09-BC",
        "organization": "Utility, Inc",
        "address_1": "250 E Ponce de Leon Ave Suite 700",
        "address_2": "Decatur  GA  30030",
        "country": "US"
    },
    "0009BE": {
        "oui_hex": "00-09-BE",
        "organization": "Mamiya-OP Co.,Ltd.",
        "address_1": "3-23-10, Negishi Minami-ku",
        "address_2": "Saitama-shi  Saitama  336-8581",
        "country": "JP"
    },
    "0009E6": {
        "oui_hex": "00-09-E6",
        "organization": "Cyber Switching Inc.",
        "address_1": "1800 De La Cruz Blvd.",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "0009FB": {
        "oui_hex": "00-09-FB",
        "organization": "Philips Patient Monitoring",
        "address_1": "Hewlett-Packard-Str.2",
        "address_2": "Boeblingen    71034",
        "country": "DE"
    },
    "00098F": {
        "oui_hex": "00-09-8F",
        "organization": "Cetacean Networks",
        "address_1": "110 Corporate Drive",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "000987": {
        "oui_hex": "00-09-87",
        "organization": "NISHI NIPPON ELECTRIC WIRE & CABLE CO.,LTD.",
        "address_1": "Kasugaura",
        "address_2": "Oita-City  OITA  870-8632",
        "country": "JP"
    },
    "000989": {
        "oui_hex": "00-09-89",
        "organization": "VividLogic Inc.",
        "address_1": "40994 Encyclopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000986": {
        "oui_hex": "00-09-86",
        "organization": "Metalink LTD.",
        "address_1": "Yakum Business Park",
        "address_2": "Yakum  HOF HASHARON  60972",
        "country": "IL"
    },
    "00098C": {
        "oui_hex": "00-09-8C",
        "organization": "Option Wireless Sweden",
        "address_1": "Sturegatan 2",
        "address_2": "  Sundbyberg  SE-172 24",
        "country": "SE"
    },
    "000985": {
        "oui_hex": "00-09-85",
        "organization": "Auto Telecom Company",
        "address_1": "10F, No.3,Lane 16, Sec.2, Sichuan Rd.",
        "address_2": "Banqiao City  Taipei County  22061",
        "country": "TW"
    },
    "00098D": {
        "oui_hex": "00-09-8D",
        "organization": "Velocity Semiconductor",
        "address_1": "Suite 32 Wey House",
        "address_2": "Weybridge  Surrey  KT13 8NA",
        "country": "GB"
    },
    "000981": {
        "oui_hex": "00-09-81",
        "organization": "Newport Networks",
        "address_1": "Enterprise House",
        "address_2": "Chepstow  Monmouthshire  NP16 5PB",
        "country": "GB"
    },
    "000955": {
        "oui_hex": "00-09-55",
        "organization": "Young Generation International Corp.",
        "address_1": "4F.,No. 188, Minchuan Rd., Shindian City",
        "address_2": "Shindian    231",
        "country": "TW"
    },
    "00094A": {
        "oui_hex": "00-09-4A",
        "organization": "Homenet Communications",
        "address_1": "Innovation Centre",
        "address_2": "Limerick",
        "country": "IE"
    },
    "00094B": {
        "oui_hex": "00-09-4B",
        "organization": "FillFactory NV",
        "address_1": "Schalienhoevedreef 20B",
        "address_2": "B-2800 Mechelen",
        "country": "BE"
    },
    "00094D": {
        "oui_hex": "00-09-4D",
        "organization": "Braintree Communications Pty Ltd",
        "address_1": "Unit 3",
        "address_2": "Slacks Creek  QLD  4127",
        "country": "AU"
    },
    "000950": {
        "oui_hex": "00-09-50",
        "organization": "Independent Storage Corporation",
        "address_1": "6273 Monarch Park Place",
        "address_2": "Niwot  Colorado  80503",
        "country": "US"
    },
    "000954": {
        "oui_hex": "00-09-54",
        "organization": "AMiT spol. s. r. o.",
        "address_1": "Naskove 3",
        "address_2": "150 00  Praha 5",
        "country": "CZ"
    },
    "000992": {
        "oui_hex": "00-09-92",
        "organization": "InterEpoch Technology,INC.",
        "address_1": "7F,No.3,Alley 6,Lane 235,Pao-Chiao Rd",
        "address_2": "Hsin-Tien  Taipei Hsien  231",
        "country": "TW"
    },
    "000995": {
        "oui_hex": "00-09-95",
        "organization": "Castle Technology Ltd",
        "address_1": "Ore Trading Estate",
        "address_2": "Framlingham  Suffolk  IP13 9LL",
        "country": "GB"
    },
    "000998": {
        "oui_hex": "00-09-98",
        "organization": "Capinfo Company Limited",
        "address_1": "7th Floor A Corporate Square, NO. 35 Fin",
        "address_2": "Beijing    100032",
        "country": "CN"
    },
    "0009B6": {
        "oui_hex": "00-09-B6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0009B3": {
        "oui_hex": "00-09-B3",
        "organization": "MCM Systems Ltd",
        "address_1": "Kolomban 9F",
        "address_2": "Ankaran  Slovenija  6280",
        "country": "SI"
    },
    "00095C": {
        "oui_hex": "00-09-5C",
        "organization": "Philips Medical Systems - Cardiac and Monitoring Systems (CM",
        "address_1": "3000 Minuteman Road",
        "address_2": "Andover  Massachusetts  01810",
        "country": "US"
    },
    "000958": {
        "oui_hex": "00-09-58",
        "organization": "INTELNET S.A.",
        "address_1": "FRANCISCO OLIVAN BAYLE, 4",
        "address_2": "ZARAGOZA    50015",
        "country": "ES"
    },
    "0009A3": {
        "oui_hex": "00-09-A3",
        "organization": "Leadfly Techologies Corp. Ltd.",
        "address_1": "9Fl, No.260, Bade Rd.,",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "0009A5": {
        "oui_hex": "00-09-A5",
        "organization": "HANSUNG ELETRONIC INDUSTRIES DEVELOPMENT CO., LTD",
        "address_1": "HEUNGJIN BLDG 3F, #217-3 POI-DONG, KANGN",
        "address_2": "SEOUL    135-963",
        "country": "KR"
    },
    "000962": {
        "oui_hex": "00-09-62",
        "organization": "Sonitor Technologies AS",
        "address_1": "Forskningsveien 1B",
        "address_2": "Oslo  Blindern  N-0134",
        "country": "NO"
    },
    "00095D": {
        "oui_hex": "00-09-5D",
        "organization": "Dialogue Technology Corp.",
        "address_1": "10F, No. 196, Sec. 2, Jungshing Rd.",
        "address_2": "Shindian City  Taipei  231",
        "country": "TW"
    },
    "00099A": {
        "oui_hex": "00-09-9A",
        "organization": "ELMO COMPANY, LIMITED",
        "address_1": "6-14, MEIZEN-CHO, MIZUHO-KU",
        "address_2": "NAGOYA  AICHI-Pref.  467-8567",
        "country": "JP"
    },
    "00099C": {
        "oui_hex": "00-09-9C",
        "organization": "Naval Research Laboratory",
        "address_1": "Code 5592",
        "address_2": "Washington  DC  20375-5000",
        "country": "US"
    },
    "000984": {
        "oui_hex": "00-09-84",
        "organization": "MyCasa Network Inc.",
        "address_1": "200 Sheridan Ave #103",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "00092B": {
        "oui_hex": "00-09-2B",
        "organization": "iQstor Networks, Inc.",
        "address_1": "2001 Corporate Center Drive",
        "address_2": "Newbury Park  CA  91320",
        "country": "US"
    },
    "000926": {
        "oui_hex": "00-09-26",
        "organization": "YODA COMMUNICATIONS, INC.",
        "address_1": "2F, No.3-1, Industry East Road IX,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000927": {
        "oui_hex": "00-09-27",
        "organization": "TOYOKEIKI CO.,LTD.",
        "address_1": "17-10-3,Shimosinjyo",
        "address_2": "Osaka    533-0021",
        "country": "JP"
    },
    "000923": {
        "oui_hex": "00-09-23",
        "organization": "Heaman System Co., Ltd",
        "address_1": "Building M6,National Hi-tech & Indus",
        "address_2": "Changsha  Hunan Province  410013",
        "country": "US"
    },
    "00091D": {
        "oui_hex": "00-09-1D",
        "organization": "Proteam Computer Corporation",
        "address_1": "7F, No. 157. Section 2 Ta-Tung Rd",
        "address_2": "Hsi-Chih  Taipei Hsien  221",
        "country": "US"
    },
    "0008EB": {
        "oui_hex": "00-08-EB",
        "organization": "ROMWin Co.,Ltd.",
        "address_1": "406 OmiyaOhtaka Bldg. 1-103",
        "address_2": "Saitama    330-0843",
        "country": "US"
    },
    "0008E8": {
        "oui_hex": "00-08-E8",
        "organization": "Excel Master Ltd.",
        "address_1": "Room D, 3/F., Yeung Yiu Chung (No. 8) Ind. Bldg.",
        "address_2": "  Kowloon Bay",
        "country": "HK"
    },
    "0008DC": {
        "oui_hex": "00-08-DC",
        "organization": "Wiznet",
        "address_1": "5F Simmtech bldg., 228-3,",
        "address_2": "Seoul    135-830",
        "country": "KR"
    },
    "0008DD": {
        "oui_hex": "00-08-DD",
        "organization": "Telena Communications, Inc.",
        "address_1": "6725 Mesa Ridge Road",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0008E1": {
        "oui_hex": "00-08-E1",
        "organization": "Barix AG",
        "address_1": "Seefeld Strasse 303",
        "address_2": "Zürich  ZH  8008",
        "country": "US"
    },
    "000909": {
        "oui_hex": "00-09-09",
        "organization": "Telenor Connect A/S",
        "address_1": "Ellegaardvej 25L",
        "address_2": "Sønderborg  Als  6400",
        "country": "DK"
    },
    "00090A": {
        "oui_hex": "00-09-0A",
        "organization": "SnedFar Technology Co., Ltd.",
        "address_1": "15FL., No.866-2, Jung Jeng Rd.,",
        "address_2": "Junghe  Taipei  235",
        "country": "TW"
    },
    "00090F": {
        "oui_hex": "00-09-0F",
        "organization": "Fortinet Inc.",
        "address_1": "1090 Kifer Road",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "00092C": {
        "oui_hex": "00-09-2C",
        "organization": "Hitpoint Inc.",
        "address_1": "No.7, Fenliao, 2nd Industrial Park, Link",
        "address_2": "Taipei    244",
        "country": "TW"
    },
    "000903": {
        "oui_hex": "00-09-03",
        "organization": "Panasas, Inc",
        "address_1": "15333 John F Kennedy Blvd, Suite 400",
        "address_2": "Houston  TX  77032-2351",
        "country": "US"
    },
    "000907": {
        "oui_hex": "00-09-07",
        "organization": "Chrysalis Development",
        "address_1": "8125 River Dr. Suite 100",
        "address_2": "Morton Grove  IL  60053",
        "country": "US"
    },
    "000906": {
        "oui_hex": "00-09-06",
        "organization": "Esteem Networks",
        "address_1": "4F, No.900, Yishan Road",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "000952": {
        "oui_hex": "00-09-52",
        "organization": "Auerswald GmbH & Co. KG",
        "address_1": "Vor den Grashoefen 1",
        "address_2": "Cremlingen  Niedersachsen  38162",
        "country": "DE"
    },
    "000944": {
        "oui_hex": "00-09-44",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0008FB": {
        "oui_hex": "00-08-FB",
        "organization": "SonoSite, Inc.",
        "address_1": "21919 30th Drive SE",
        "address_2": "Bothell  WA  98021",
        "country": "US"
    },
    "0008EE": {
        "oui_hex": "00-08-EE",
        "organization": "Logic Product Development",
        "address_1": "411 Washington Ave N. Suite 101",
        "address_2": "Minneapolis  Minnesota  55401",
        "country": "US"
    },
    "000917": {
        "oui_hex": "00-09-17",
        "organization": "WEM Technology Inc",
        "address_1": "8F-2, No 386, Sec 5 Nanjing East Road.",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "000881": {
        "oui_hex": "00-08-81",
        "organization": "DIGITAL HANDS CO.,LTD.",
        "address_1": "KAKiYA Building 2F",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "000882": {
        "oui_hex": "00-08-82",
        "organization": "SIGMA CORPORATION",
        "address_1": "2-3-15 Iwato-minami",
        "address_2": "Komae-shi  Tokyo  201-8630",
        "country": "JP"
    },
    "000873": {
        "oui_hex": "00-08-73",
        "organization": "DapTechnology B.V.",
        "address_1": "Zutphenstraat 67",
        "address_2": "EJ Oldenzaal    7575",
        "country": "NL"
    },
    "00087A": {
        "oui_hex": "00-08-7A",
        "organization": "Wipotec GmbH",
        "address_1": "Adam-Hoffman Str. 26",
        "address_2": "",
        "country": "DE"
    },
    "000871": {
        "oui_hex": "00-08-71",
        "organization": "NORTHDATA Co., Ltd.",
        "address_1": "#302 KayangTechno-Town 1487",
        "address_2": "Kangseo-Gu  Seoul  157-810",
        "country": "KR"
    },
    "0008B2": {
        "oui_hex": "00-08-B2",
        "organization": "SHENZHEN COMPASS TECHNOLOGY DEVELOPMENT CO.,LTD",
        "address_1": "4th Floor,Building 205,TaiRan Industry",
        "address_2": "Shenzhen  GUANGDONG  518040",
        "country": "CN"
    },
    "0008B1": {
        "oui_hex": "00-08-B1",
        "organization": "ProQuent Systems",
        "address_1": "67 Forest Street",
        "address_2": "Marlboro  MA  01752",
        "country": "US"
    },
    "0008AF": {
        "oui_hex": "00-08-AF",
        "organization": "Novatec Corporation",
        "address_1": "2-19-2 Nishi-Gotanda",
        "address_2": "Shinagawa-ku  Tokyo  141-0031",
        "country": "JP"
    },
    "0008A6": {
        "oui_hex": "00-08-A6",
        "organization": "Multiware & Image Co., Ltd.",
        "address_1": "Saedong Bldg. 65-25,",
        "address_2": "Pusan    606-032",
        "country": "KR"
    },
    "00087E": {
        "oui_hex": "00-08-7E",
        "organization": "Bon Electro-Telecom Inc.",
        "address_1": "Gayang 1st Factory 701, 14-81",
        "address_2": "Seoul    157-808",
        "country": "KR"
    },
    "000880": {
        "oui_hex": "00-08-80",
        "organization": "BroadTel Canada Communications inc.",
        "address_1": "3700 Griffith, Suite 389",
        "address_2": "Saint-Laurent  Quebec  H4T 2B3",
        "country": "CA"
    },
    "00086D": {
        "oui_hex": "00-08-6D",
        "organization": "Missouri FreeNet",
        "address_1": "PO Box 771026",
        "address_2": "St. Louis  Missouri  63177-1026",
        "country": "US"
    },
    "0008D4": {
        "oui_hex": "00-08-D4",
        "organization": "IneoQuest Technologies, Inc",
        "address_1": "1931 Washington St",
        "address_2": "Canton  Massachusetts  02021",
        "country": "US"
    },
    "0008D6": {
        "oui_hex": "00-08-D6",
        "organization": "HASSNET Inc.",
        "address_1": "2F Missy2000 B/D 725, SooSeo-Dong,",
        "address_2": "Seoul    135-757",
        "country": "KR"
    },
    "0008CE": {
        "oui_hex": "00-08-CE",
        "organization": "IPMobileNet Inc.",
        "address_1": "11909 E Telegraph Rd.",
        "address_2": "Santa Fe Springs  CA  90670",
        "country": "US"
    },
    "0008C2": {
        "oui_hex": "00-08-C2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0008C0": {
        "oui_hex": "00-08-C0",
        "organization": "ASA SYSTEMS",
        "address_1": "S245 Korea Maritime University, 1 Dongsa",
        "address_2": "Busan  Busan Metropolitan City  606-791",
        "country": "KR"
    },
    "0008A3": {
        "oui_hex": "00-08-A3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00089E": {
        "oui_hex": "00-08-9E",
        "organization": "Beijing Enter-Net co.LTD",
        "address_1": "NO 1 courtyard,",
        "address_2": "Beijing    100085",
        "country": "US"
    },
    "0008B4": {
        "oui_hex": "00-08-B4",
        "organization": "SYSPOL",
        "address_1": "4th Fl,SYSPOL B/D, Bangbae 4 Dong, Seoch",
        "address_2": "Seoul    137-064",
        "country": "US"
    },
    "0008B3": {
        "oui_hex": "00-08-B3",
        "organization": "Fastwel",
        "address_1": "Profsoyuznaya 108,",
        "address_2": "Moscow    117313",
        "country": "RU"
    },
    "00088E": {
        "oui_hex": "00-08-8E",
        "organization": "Nihon Computer Co., Ltd.",
        "address_1": "36-8 Higashitamachi",
        "address_2": "Hamamatsu  Shizuoka  430-0915",
        "country": "JP"
    },
    "0008DA": {
        "oui_hex": "00-08-DA",
        "organization": "SofaWare Technologies Ltd.",
        "address_1": "3 Hilazon St.",
        "address_2": "Ramat-Gan    52522",
        "country": "IL"
    },
    "0007D5": {
        "oui_hex": "00-07-D5",
        "organization": "3e Technologies Int;., Inc.",
        "address_1": "15800 Crabbs Branch Way",
        "address_2": "Rockville  MD  20855",
        "country": "US"
    },
    "0007DB": {
        "oui_hex": "00-07-DB",
        "organization": "Kirana Networks, Inc.",
        "address_1": "331 Newman Springs Road",
        "address_2": "Red Bank  NJ  07701",
        "country": "US"
    },
    "00086A": {
        "oui_hex": "00-08-6A",
        "organization": "Securiton Gmbh",
        "address_1": "Von-Drais-Strasse 33",
        "address_2": "Achern    D-77855",
        "country": "DE"
    },
    "000863": {
        "oui_hex": "00-08-63",
        "organization": "Entrisphere Inc.",
        "address_1": "1601 S. De Anza Blvd.",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000866": {
        "oui_hex": "00-08-66",
        "organization": "DSX Access Systems, Inc.",
        "address_1": "10731 Rockwall Rd.",
        "address_2": "Dallas  TX  75238",
        "country": "US"
    },
    "0007EF": {
        "oui_hex": "00-07-EF",
        "organization": "Lockheed Martin Tactical Systems",
        "address_1": "3333 Pilot Knob Road",
        "address_2": "Eagan  MN  55121",
        "country": "US"
    },
    "0007F4": {
        "oui_hex": "00-07-F4",
        "organization": "Eletex Co., Ltd.",
        "address_1": "8-2-56 Nankou-Higashi Suminoe-ku",
        "address_2": "",
        "country": "JP"
    },
    "0007DD": {
        "oui_hex": "00-07-DD",
        "organization": "Cradle Technologies",
        "address_1": "3130 West Warren Ave.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00081B": {
        "oui_hex": "00-08-1B",
        "organization": "Windigo Systems",
        "address_1": "2210 O'Toole Ave. #200",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0007FF": {
        "oui_hex": "00-07-FF",
        "organization": "Gluon Networks",
        "address_1": "5401 Old Redwood Hwy.",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "0007F7": {
        "oui_hex": "00-07-F7",
        "organization": "Galtronics",
        "address_1": "4645 East Cotton Center Blvd.",
        "address_2": "Phoenix  AZ  85040",
        "country": "US"
    },
    "00085F": {
        "oui_hex": "00-08-5F",
        "organization": "Picanol N.V.",
        "address_1": "Polenlaan 3-7",
        "address_2": "",
        "country": "BE"
    },
    "000852": {
        "oui_hex": "00-08-52",
        "organization": "Davolink Co. Inc.",
        "address_1": "Room-604, Kumhwa Plaza,",
        "address_2": "Kyunggi-Do    435-040",
        "country": "KR"
    },
    "00080C": {
        "oui_hex": "00-08-0C",
        "organization": "VDA Elettronica spa",
        "address_1": "Viale Lino Zanussi, 3",
        "address_2": "33170  Pordenone",
        "country": "IT"
    },
    "000804": {
        "oui_hex": "00-08-04",
        "organization": "ICA Inc.",
        "address_1": "542-1 Noguki",
        "address_2": "",
        "country": "JP"
    },
    "000857": {
        "oui_hex": "00-08-57",
        "organization": "Polaris Networks, Inc.",
        "address_1": "6810 Santa Teresa Blvd.",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "00078B": {
        "oui_hex": "00-07-8B",
        "organization": "Wegener Communications, Inc.",
        "address_1": "11350 Technology Circle",
        "address_2": "Duluth  GA  30097",
        "country": "US"
    },
    "000783": {
        "oui_hex": "00-07-83",
        "organization": "SynCom Network, Inc.",
        "address_1": "4F, No. 31, Hsintai Road, Chupei City,",
        "address_2": "",
        "country": "TW"
    },
    "000787": {
        "oui_hex": "00-07-87",
        "organization": "Idea System Co., Ltd.",
        "address_1": "4-1-21 Shinmei-cho Okaya-shi",
        "address_2": "",
        "country": "JP"
    },
    "000789": {
        "oui_hex": "00-07-89",
        "organization": "Allradio Co., Ltd",
        "address_1": "861-5, Gwanyang-Dong, Dongan-Gu,",
        "address_2": "Anyang-si, Gyeonggi-do,    430-803",
        "country": "KR"
    },
    "0007B9": {
        "oui_hex": "00-07-B9",
        "organization": "Ginganet Corporation",
        "address_1": "Kintetsu Shin Namba Building",
        "address_2": "Osaka Shi    1556-0017",
        "country": "JP"
    },
    "00047F": {
        "oui_hex": "00-04-7F",
        "organization": "Chr. Mayr GmbH & Co. KG",
        "address_1": "Eichenstraße 1",
        "address_2": "",
        "country": "DE"
    },
    "00047B": {
        "oui_hex": "00-04-7B",
        "organization": "Schlumberger",
        "address_1": "Sugar Land Product Center",
        "address_2": "Sugar Land  TX  77478",
        "country": "US"
    },
    "0007B4": {
        "oui_hex": "00-07-B4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0007B3": {
        "oui_hex": "00-07-B3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0007B5": {
        "oui_hex": "00-07-B5",
        "organization": "Any One Wireless Ltd.",
        "address_1": "Namseoul Bd., 8F, 1304-3",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000785": {
        "oui_hex": "00-07-85",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000775": {
        "oui_hex": "00-07-75",
        "organization": "Valence Semiconductor, Inc.",
        "address_1": "41 Discovery",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000793": {
        "oui_hex": "00-07-93",
        "organization": "Shin Satellite Public Company Limited",
        "address_1": "41/103  Rattanathibet Road,",
        "address_2": "",
        "country": "TH"
    },
    "000796": {
        "oui_hex": "00-07-96",
        "organization": "LSI Systems, Inc.",
        "address_1": "10-1 Minami-kurokawa,",
        "address_2": "Kanagawa    215-0034",
        "country": "JP"
    },
    "00077F": {
        "oui_hex": "00-07-7F",
        "organization": "J Communications Co., Ltd.",
        "address_1": "124-4 Ojeon-Dong, Ulwang-City",
        "address_2": "",
        "country": "KR"
    },
    "000771": {
        "oui_hex": "00-07-71",
        "organization": "Embedded System Corporation",
        "address_1": "13-5, Takadanobaba 3-chome,",
        "address_2": "",
        "country": "JP"
    },
    "000770": {
        "oui_hex": "00-07-70",
        "organization": "Ubiquoss Inc",
        "address_1": "Ubiquoss B/D, 68, Pangyo-ro 255beon-gil,",
        "address_2": "",
        "country": "KR"
    },
    "0007D1": {
        "oui_hex": "00-07-D1",
        "organization": "Spectrum Signal Processing Inc.",
        "address_1": "#200-2700 Production Way",
        "address_2": "",
        "country": "CA"
    },
    "0007A2": {
        "oui_hex": "00-07-A2",
        "organization": "Opteon Corporation",
        "address_1": "70 Hastings Street",
        "address_2": "Wellesley  MA  02481",
        "country": "US"
    },
    "0006F8": {
        "oui_hex": "00-06-F8",
        "organization": "The Boeing Company",
        "address_1": "5731 W. Las Positas Blvd.",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "0006FB": {
        "oui_hex": "00-06-FB",
        "organization": "Hitachi Printing Solutions, Ltd.",
        "address_1": "1060, Takeda Hitachinaka-City",
        "address_2": "    312-8502",
        "country": "JP"
    },
    "0006FC": {
        "oui_hex": "00-06-FC",
        "organization": "Fnet Co., Ltd.",
        "address_1": "KFSB Bldg. 10th F. 16-2",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0006F4": {
        "oui_hex": "00-06-F4",
        "organization": "Prime Electronics & Satellitics Inc.",
        "address_1": "69,Tung-Yuan Rd",
        "address_2": "Chung-Li City  Tao-Yuan County  32000",
        "country": "TW"
    },
    "000738": {
        "oui_hex": "00-07-38",
        "organization": "Young Technology Co., Ltd.",
        "address_1": "D-604, Sigma-II Officetel,",
        "address_2": "Sungnam-si,  Kyeonggi-do  763-741",
        "country": "KR"
    },
    "000729": {
        "oui_hex": "00-07-29",
        "organization": "Kistler Instrumente AG",
        "address_1": "Eulachstrasse 22",
        "address_2": "",
        "country": "CH"
    },
    "00072A": {
        "oui_hex": "00-07-2A",
        "organization": "Innovance Networks",
        "address_1": "19 Fairmont Avenue",
        "address_2": "",
        "country": "CA"
    },
    "00074A": {
        "oui_hex": "00-07-4A",
        "organization": "Carl Valentin GmbH",
        "address_1": "Neckarstrabe 78-80",
        "address_2": "",
        "country": "DE"
    },
    "00073C": {
        "oui_hex": "00-07-3C",
        "organization": "Telecom Design",
        "address_1": "Voie Romaine, Zone de Remora",
        "address_2": "",
        "country": "FR"
    },
    "000736": {
        "oui_hex": "00-07-36",
        "organization": "Data Video Technologies Co., Ltd.",
        "address_1": "7F, No. 352, Sec. 2",
        "address_2": "Taipei Hsien",
        "country": "TW"
    },
    "000750": {
        "oui_hex": "00-07-50",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000742": {
        "oui_hex": "00-07-42",
        "organization": "Ormazabal",
        "address_1": "Parque Tecnologico 104",
        "address_2": "48170 Zamudio, Bizkaia",
        "country": "ES"
    },
    "00074B": {
        "oui_hex": "00-07-4B",
        "organization": "Daihen Corporation",
        "address_1": "2-1-11 Tagawa Yodogawa-ku",
        "address_2": "",
        "country": "JP"
    },
    "000764": {
        "oui_hex": "00-07-64",
        "organization": "YoungWoo Telecom Co. Ltd.",
        "address_1": "3F, Sehwa B/D, 355-1",
        "address_2": "Sungnam-Si  Kyungki-Do",
        "country": "KR"
    },
    "000766": {
        "oui_hex": "00-07-66",
        "organization": "Chou Chin Industrial Co., Ltd.",
        "address_1": "9F, #35, Chiau An St. Chung Ho City,",
        "address_2": "",
        "country": "TW"
    },
    "000761": {
        "oui_hex": "00-07-61",
        "organization": "29530",
        "address_1": "EPFL - Quartier de l'Innovation",
        "address_2": "Lausanne  CH  1015",
        "country": "CH"
    },
    "000755": {
        "oui_hex": "00-07-55",
        "organization": "Lafon",
        "address_1": "44 Avenue Victor Meunier",
        "address_2": " Bassens    33530",
        "country": "FR"
    },
    "000759": {
        "oui_hex": "00-07-59",
        "organization": "Boris Manufacturing Corp.",
        "address_1": "PO Box 601",
        "address_2": "Castle Point  NY  12511",
        "country": "US"
    },
    "000751": {
        "oui_hex": "00-07-51",
        "organization": "m-u-t AG",
        "address_1": "Messgeräte für Medizin- und Umwelttechnik",
        "address_2": "Wedel    22880",
        "country": "DE"
    },
    "000719": {
        "oui_hex": "00-07-19",
        "organization": "Mobiis Co., Ltd.",
        "address_1": "277-1, Shinhwa Bldg. 4F",
        "address_2": "Seoul,",
        "country": "KR"
    },
    "00070D": {
        "oui_hex": "00-07-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00070E": {
        "oui_hex": "00-07-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00070B": {
        "oui_hex": "00-07-0B",
        "organization": "Novabase SGPS, SA",
        "address_1": "Av. D Joao II, Lote 1.03.2.3",
        "address_2": "Lisboa    1998-031",
        "country": "PT"
    },
    "000710": {
        "oui_hex": "00-07-10",
        "organization": "Adax, Inc.",
        "address_1": "614 Bancroft Way",
        "address_2": "Berkeley  CA  94556",
        "country": "US"
    },
    "0006E8": {
        "oui_hex": "00-06-E8",
        "organization": "Optical Network Testing, Inc.",
        "address_1": "55 Merchant St.",
        "address_2": "Honolulu  HI  96813",
        "country": "US"
    },
    "0006EE": {
        "oui_hex": "00-06-EE",
        "organization": "Shenyang Neu-era Information & Technology Stock Co., Ltd",
        "address_1": "8/F, the 21st Century Building,",
        "address_2": "Dvlpmnt Zone  Shenyang,",
        "country": "CN"
    },
    "0006E2": {
        "oui_hex": "00-06-E2",
        "organization": "Ceemax Technology Co., Ltd.",
        "address_1": "5f-7, 736, Chung Cheng Rd.,",
        "address_2": "",
        "country": "TW"
    },
    "0006A5": {
        "oui_hex": "00-06-A5",
        "organization": "PINON Corp.",
        "address_1": "Axis Gotanda Bldg.7F-701",
        "address_2": "Tokyo    141-0031",
        "country": "JP"
    },
    "00069D": {
        "oui_hex": "00-06-9D",
        "organization": "Petards Ltd",
        "address_1": "390 Princesway, Team Valley",
        "address_2": "Gateshead  Tyne and Wear  NE11 OTU",
        "country": "GB"
    },
    "0006A8": {
        "oui_hex": "00-06-A8",
        "organization": "KC Technology, Inc.",
        "address_1": "1900 McCarthy Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0006A0": {
        "oui_hex": "00-06-A0",
        "organization": "Mx Imaging",
        "address_1": "2894 Columbia Street",
        "address_2": "Torrance  CA  90503",
        "country": "US"
    },
    "0006BE": {
        "oui_hex": "00-06-BE",
        "organization": "Baumer Optronic GmbH",
        "address_1": "Badstraße 30",
        "address_2": "",
        "country": "DE"
    },
    "0006BA": {
        "oui_hex": "00-06-BA",
        "organization": "Westwave Communications",
        "address_1": "463 Aviation Blvd.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "0006C4": {
        "oui_hex": "00-06-C4",
        "organization": "Piolink Inc.",
        "address_1": "IT Castle 1-401, 550-1 Gasan-dong,",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "0006B5": {
        "oui_hex": "00-06-B5",
        "organization": "Source Photonics, Inc.",
        "address_1": "20550 Nordhoff St.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "00068F": {
        "oui_hex": "00-06-8F",
        "organization": "Telemonitor, Inc.",
        "address_1": "9055F Guilford Road",
        "address_2": "Columbia  MD  21046",
        "country": "US"
    },
    "0006DA": {
        "oui_hex": "00-06-DA",
        "organization": "ITRAN Communications Ltd.",
        "address_1": "1 Azrieli Center,",
        "address_2": "Tel Aviv 67021     67021",
        "country": "IL"
    },
    "0006D0": {
        "oui_hex": "00-06-D0",
        "organization": "Elgar Electronics Corp.",
        "address_1": "9250 Brown Deer Rd.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0006CC": {
        "oui_hex": "00-06-CC",
        "organization": "JMI Electronics Co., Ltd.",
        "address_1": "Nanyang B/D 3F, 25-4",
        "address_2": "Seoul    140-080",
        "country": "KR"
    },
    "0006BF": {
        "oui_hex": "00-06-BF",
        "organization": "Accella Technologies Co., Ltd.",
        "address_1": "Rm 512 No. 680 Gui Ping Rd.",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "000690": {
        "oui_hex": "00-06-90",
        "organization": "Euracom Communication GmbH",
        "address_1": "Franklinstraße 14",
        "address_2": "",
        "country": "DE"
    },
    "0006E1": {
        "oui_hex": "00-06-E1",
        "organization": "Techno Trade s.a",
        "address_1": "732a Chaussee de Bruxelles",
        "address_2": "",
        "country": "BE"
    },
    "00062E": {
        "oui_hex": "00-06-2E",
        "organization": "Aristos Logic Corp.",
        "address_1": "27051 Towne Centre Dr.",
        "address_2": "Foothill Ranch  CA  92610",
        "country": "US"
    },
    "000624": {
        "oui_hex": "00-06-24",
        "organization": "Gentner Communications Corp.",
        "address_1": "1825 Research Way",
        "address_2": "Salt Lake City  UT  84119",
        "country": "US"
    },
    "000625": {
        "oui_hex": "00-06-25",
        "organization": "The Linksys Group, Inc.",
        "address_1": "17401 Armstrong Ave.",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "000627": {
        "oui_hex": "00-06-27",
        "organization": "Uniwide Technologies, Inc.",
        "address_1": "Korea Development Bank B/D 5th Flr",
        "address_2": "Taejon  302-122,",
        "country": "KR"
    },
    "00062A": {
        "oui_hex": "00-06-2A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00062C": {
        "oui_hex": "00-06-2C",
        "organization": "Bivio Networks",
        "address_1": "4457 Willow Road,",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "000621": {
        "oui_hex": "00-06-21",
        "organization": "Hinox, Co., Ltd.",
        "address_1": "15-7 3-chome, Sennin-cho,",
        "address_2": "    193-0835",
        "country": "JP"
    },
    "00064E": {
        "oui_hex": "00-06-4E",
        "organization": "Broad Net Technology Inc.",
        "address_1": "5F, No.58, Lane 188, Rui Kuang Road",
        "address_2": "",
        "country": "TW"
    },
    "00062D": {
        "oui_hex": "00-06-2D",
        "organization": "TouchStar Technologies, L.L.C.",
        "address_1": "5147 South Garnett Road",
        "address_2": "Tulsa  OK  74146",
        "country": "US"
    },
    "000646": {
        "oui_hex": "00-06-46",
        "organization": "ShenZhen XunBao Network Technology Co Ltd",
        "address_1": "F3, R2-A Building, South District",
        "address_2": "Shen Zhen",
        "country": "CN"
    },
    "00064B": {
        "oui_hex": "00-06-4B",
        "organization": "Alexon Co., Ltd.",
        "address_1": "3-207-1 Teramoto,",
        "address_2": "",
        "country": "JP"
    },
    "00063C": {
        "oui_hex": "00-06-3C",
        "organization": "Intrinsyc Software International Inc.",
        "address_1": "885 Dunsmuir Street, Suite 380",
        "address_2": "Vancouver  B.C.  V6C 1N5",
        "country": "CA"
    },
    "000630": {
        "oui_hex": "00-06-30",
        "organization": "Adtranz Sweden",
        "address_1": "Dept. TCC/TH",
        "address_2": "",
        "country": "SE"
    },
    "000637": {
        "oui_hex": "00-06-37",
        "organization": "Toptrend-Meta Information (ShenZhen) Inc.",
        "address_1": "2/F, Bldg. 3, Section A, Nor-East Zone",
        "address_2": "",
        "country": "CN"
    },
    "00061C": {
        "oui_hex": "00-06-1C",
        "organization": "Hoshino Metal Industries, Ltd.",
        "address_1": "645 Yamanokami, Yabutsuka,",
        "address_2": "    379-2302",
        "country": "JP"
    },
    "000623": {
        "oui_hex": "00-06-23",
        "organization": "MGE UPS Systems France",
        "address_1": "140 Avenue Jean Kuntzmann",
        "address_2": "",
        "country": "FR"
    },
    "00060B": {
        "oui_hex": "00-06-0B",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way Suite 190",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "00067E": {
        "oui_hex": "00-06-7E",
        "organization": "WinCom Systems, Inc.",
        "address_1": "10900 World Trade Blvd.",
        "address_2": "Morrisville  NC  27560",
        "country": "US"
    },
    "000677": {
        "oui_hex": "00-06-77",
        "organization": "SICK AG",
        "address_1": "Erwin-Sick Str.1",
        "address_2": "Waldkirch    D-79183",
        "country": "DE"
    },
    "000666": {
        "oui_hex": "00-06-66",
        "organization": "Roving Networks",
        "address_1": "809 University Avenue",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "000667": {
        "oui_hex": "00-06-67",
        "organization": "Tripp Lite",
        "address_1": "1111 W. 35th Street",
        "address_2": "Chicago  IL  60609",
        "country": "US"
    },
    "00064D": {
        "oui_hex": "00-06-4D",
        "organization": "Sencore",
        "address_1": "3200 Sencore Dr.",
        "address_2": "Sioux Falls  SD  57107",
        "country": "US"
    },
    "000660": {
        "oui_hex": "00-06-60",
        "organization": "NADEX Co., Ltd.",
        "address_1": "1 Omiyamae, Tokushige,",
        "address_2": "Aichi    481-0038",
        "country": "JP"
    },
    "000679": {
        "oui_hex": "00-06-79",
        "organization": "Konami Corporation",
        "address_1": "11-14-5 Akasaka, Minato-ku,",
        "address_2": "",
        "country": "JP"
    },
    "00066C": {
        "oui_hex": "00-06-6C",
        "organization": "Robinson Corporation",
        "address_1": "12F, No. 278 Ho Ping E. Rd.,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000615": {
        "oui_hex": "00-06-15",
        "organization": "Kimoto Electric Co., Ltd.",
        "address_1": "3-1 Funahashi-Cho,",
        "address_2": "    543-0024",
        "country": "JP"
    },
    "00060A": {
        "oui_hex": "00-06-0A",
        "organization": "Blue2space",
        "address_1": "Arstaangsv. 9",
        "address_2": "",
        "country": "SE"
    },
    "0005CE": {
        "oui_hex": "00-05-CE",
        "organization": "Prolink Microsystems Corporation",
        "address_1": "6F, No. 349, Yang-Kuang St.",
        "address_2": "Nei-Hu  Taipei,",
        "country": "TW"
    },
    "0005C2": {
        "oui_hex": "00-05-C2",
        "organization": "Soronti, Inc.",
        "address_1": "12159 Business Park Dr, suite 140",
        "address_2": "Draper  Utah  84020",
        "country": "US"
    },
    "0005DF": {
        "oui_hex": "00-05-DF",
        "organization": "Electronic Innovation, Inc.",
        "address_1": "12731 Cannington Way SW",
        "address_2": "  Calgary, AB  T2W 1Z7",
        "country": "CA"
    },
    "0005DE": {
        "oui_hex": "00-05-DE",
        "organization": "Gi Fone Korea, Inc.",
        "address_1": "Twin Bldg. 4th Fl,",
        "address_2": "Seoul,",
        "country": "KR"
    },
    "0005E0": {
        "oui_hex": "00-05-E0",
        "organization": "Empirix Corp.",
        "address_1": "205 Lowell St.",
        "address_2": "Wilmington  MA  01887",
        "country": "US"
    },
    "0005D8": {
        "oui_hex": "00-05-D8",
        "organization": "Arescom, Inc.",
        "address_1": "3541 Gateway Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0005E4": {
        "oui_hex": "00-05-E4",
        "organization": "Red Lion Controls Inc.",
        "address_1": "20 Willow Springs Circle",
        "address_2": "York  PA  17402",
        "country": "US"
    },
    "0005F2": {
        "oui_hex": "00-05-F2",
        "organization": "Power R, Inc.",
        "address_1": "756 Aloha St.",
        "address_2": "Seattle  WA  98109",
        "country": "US"
    },
    "0005F3": {
        "oui_hex": "00-05-F3",
        "organization": "Webyn",
        "address_1": "26 Rue Oes Gaudines",
        "address_2": "",
        "country": "FR"
    },
    "000601": {
        "oui_hex": "00-06-01",
        "organization": "Otanikeiki Co., Ltd.",
        "address_1": "2-10-23 Hikari-Machi",
        "address_2": "    732-0052",
        "country": "JP"
    },
    "000605": {
        "oui_hex": "00-06-05",
        "organization": "Inncom International, Inc.",
        "address_1": "P.O. Box 1060",
        "address_2": "Old Lyme  CT  06371",
        "country": "US"
    },
    "0005FA": {
        "oui_hex": "00-05-FA",
        "organization": "IPOptical, Inc.",
        "address_1": "45940 Horseshoe Drive",
        "address_2": "Dulles  VA  20166",
        "country": "US"
    },
    "0005E5": {
        "oui_hex": "00-05-E5",
        "organization": "Renishaw PLC",
        "address_1": "New Mills, Wotton-under-Edge",
        "address_2": "",
        "country": "GB"
    },
    "0005F5": {
        "oui_hex": "00-05-F5",
        "organization": "Geospace Technologies",
        "address_1": "7007 Pinemont",
        "address_2": "Houston  TX  77040",
        "country": "US"
    },
    "0005FD": {
        "oui_hex": "00-05-FD",
        "organization": "PacketLight Networks Ltd.",
        "address_1": "27 Habarzel St.",
        "address_2": "Tel-Aviv    69710",
        "country": "IL"
    },
    "0005D4": {
        "oui_hex": "00-05-D4",
        "organization": "FutureSmart Networks, Inc.",
        "address_1": "6155 Almaden Expressway",
        "address_2": "San Jose  CA  95120",
        "country": "US"
    },
    "0005C4": {
        "oui_hex": "00-05-C4",
        "organization": "Telect, Inc.",
        "address_1": "2111 N. Molter Road",
        "address_2": "Liberty Lake  WA  99019",
        "country": "US"
    },
    "0005A3": {
        "oui_hex": "00-05-A3",
        "organization": "QEI, Inc.",
        "address_1": "60 Fadem Road",
        "address_2": "Springfield  NJ  07081",
        "country": "US"
    },
    "00059E": {
        "oui_hex": "00-05-9E",
        "organization": "Zinwell Corporation",
        "address_1": "7F, No.512, Yuan-Shan Road",
        "address_2": "",
        "country": "TW"
    },
    "0005A5": {
        "oui_hex": "00-05-A5",
        "organization": "KOTT",
        "address_1": "Suite 305 Daeha B/D",
        "address_2": "    135-080",
        "country": "KR"
    },
    "0005B3": {
        "oui_hex": "00-05-B3",
        "organization": "Asahi-Engineering Co., Ltd.",
        "address_1": "3-6-12-2 Gakuenhigashi-cho",
        "address_2": "Tokyo    187-0043",
        "country": "JP"
    },
    "00059D": {
        "oui_hex": "00-05-9D",
        "organization": "Daniel Computing Systems, Inc.",
        "address_1": "3208 8th Avenue NE #118",
        "address_2": "    T2A 7V8",
        "country": "CA"
    },
    "0005A4": {
        "oui_hex": "00-05-A4",
        "organization": "Lucid Voice Ltd.",
        "address_1": "5 Jabotinski Street",
        "address_2": "",
        "country": "IL"
    },
    "000563": {
        "oui_hex": "00-05-63",
        "organization": "J-Works, Inc.",
        "address_1": "12328 Gladstone St. #1",
        "address_2": "Sylmor  CA  91342",
        "country": "US"
    },
    "000557": {
        "oui_hex": "00-05-57",
        "organization": "Agile TV Corporation",
        "address_1": "333 Ravenswood Ave.,",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "00055B": {
        "oui_hex": "00-05-5B",
        "organization": "Charles Industries, Ltd.",
        "address_1": "5600 Apollo Dr.",
        "address_2": "Rolling Meadows  IL  60008",
        "country": "US"
    },
    "000554": {
        "oui_hex": "00-05-54",
        "organization": "Rangestar Wireless",
        "address_1": "9565 Soquel Drive, Suite 100",
        "address_2": "Aptos  CA  95003",
        "country": "US"
    },
    "000553": {
        "oui_hex": "00-05-53",
        "organization": "DVC Company, Inc.",
        "address_1": "10200 Hwy 290 W.",
        "address_2": "Austin  TX  78236",
        "country": "US"
    },
    "000566": {
        "oui_hex": "00-05-66",
        "organization": "Secui.com Corporation",
        "address_1": "17th Fl. Samsung Yeoksam Bldg.",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "00056C": {
        "oui_hex": "00-05-6C",
        "organization": "Hung Chang Co., Ltd.",
        "address_1": "1385-14, Juan-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "00055F": {
        "oui_hex": "00-05-5F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00055D": {
        "oui_hex": "00-05-5D",
        "organization": "D-LINK SYSTEMS, INC.",
        "address_1": "53 Discover Dr.",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000561": {
        "oui_hex": "00-05-61",
        "organization": "nac Image Technology, Inc.",
        "address_1": "8-7 Sanban-cho, Chiyoda-ku,",
        "address_2": "",
        "country": "JP"
    },
    "000594": {
        "oui_hex": "00-05-94",
        "organization": "HMS Industrial Networks",
        "address_1": "PO Box 4126",
        "address_2": "SE30004    SE",
        "country": "SE"
    },
    "00056F": {
        "oui_hex": "00-05-6F",
        "organization": "Innomedia Technologies Pvt. Ltd.",
        "address_1": "#3278, 12th Main Road",
        "address_2": "",
        "country": "IN"
    },
    "000574": {
        "oui_hex": "00-05-74",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000567": {
        "oui_hex": "00-05-67",
        "organization": "Etymonic Design, Inc.",
        "address_1": "41 Byron Avenue",
        "address_2": "    NOL 1GO",
        "country": "CA"
    },
    "000565": {
        "oui_hex": "00-05-65",
        "organization": "Tailyn Communication Company Ltd.",
        "address_1": "No. 62, Lane 205, Nan-San Road,",
        "address_2": "Taoyuan Hsien",
        "country": "TW"
    },
    "00058E": {
        "oui_hex": "00-05-8E",
        "organization": "Flextronics International GmbH & Co. Nfg. KG",
        "address_1": "Schrackgasse 9-15",
        "address_2": "Kindberg    8650",
        "country": "AT"
    },
    "000532": {
        "oui_hex": "00-05-32",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000536": {
        "oui_hex": "00-05-36",
        "organization": "Danam Communications, Inc.",
        "address_1": "900-3, Hokye-dong, Dongan-gu,",
        "address_2": "",
        "country": "KR"
    },
    "000542": {
        "oui_hex": "00-05-42",
        "organization": "Otari, Inc.",
        "address_1": "4-33-3 Kokuryo-cho,",
        "address_2": "",
        "country": "JP"
    },
    "000537": {
        "oui_hex": "00-05-37",
        "organization": "Nets Technology Co., Ltd.",
        "address_1": "#B1 YungJun Bldg.",
        "address_2": "Seoul 135-090    135-090",
        "country": "KR"
    },
    "00057C": {
        "oui_hex": "00-05-7C",
        "organization": "RCO Security AB",
        "address_1": "Box 705",
        "address_2": "",
        "country": "SE"
    },
    "000583": {
        "oui_hex": "00-05-83",
        "organization": "ImageCom Limited",
        "address_1": "Cedars Park, Cedars Road,",
        "address_2": "    SL6 1RZ",
        "country": "GB"
    },
    "00054B": {
        "oui_hex": "00-05-4B",
        "organization": "Eaton Automation AG",
        "address_1": "Spinnereistrasse 8",
        "address_2": "St.Gallen    9008",
        "country": "CH"
    },
    "0004C8": {
        "oui_hex": "00-04-C8",
        "organization": "LIBA Maschinenfabrik GmbH",
        "address_1": "PO Box 1120",
        "address_2": "",
        "country": "DE"
    },
    "0004CC": {
        "oui_hex": "00-04-CC",
        "organization": "Peek Traffic B.V.",
        "address_1": "Postbus 2542",
        "address_2": "  The",
        "country": "NL"
    },
    "0004BF": {
        "oui_hex": "00-04-BF",
        "organization": "VersaLogic Corp.",
        "address_1": "12100 SW Tualatin Rd",
        "address_2": "Tualatin  OR  97062",
        "country": "US"
    },
    "0004C3": {
        "oui_hex": "00-04-C3",
        "organization": "CASTOR Informatique",
        "address_1": "2, Rue Du Kefir",
        "address_2": "94537 Orly  Cedex",
        "country": "FR"
    },
    "0004F6": {
        "oui_hex": "00-04-F6",
        "organization": "Amphus",
        "address_1": "2372 Qume Drive, #F",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0004F4": {
        "oui_hex": "00-04-F4",
        "organization": "Infinite Electronics Inc.",
        "address_1": "No.478-1, Sec 2",
        "address_2": "",
        "country": "TW"
    },
    "0004F1": {
        "oui_hex": "00-04-F1",
        "organization": "WhereNet",
        "address_1": "107 W. McKinney Avenue",
        "address_2": "Rogersville  TN  37857",
        "country": "US"
    },
    "000521": {
        "oui_hex": "00-05-21",
        "organization": "Control Microsystems",
        "address_1": "48 Steacie Drive",
        "address_2": "Ottawa  Ontario  K2K 2A9",
        "country": "CA"
    },
    "000523": {
        "oui_hex": "00-05-23",
        "organization": "AVL List GmbH",
        "address_1": "Hans List Platz 1",
        "address_2": "Graz    8020",
        "country": "AT"
    },
    "00051F": {
        "oui_hex": "00-05-1F",
        "organization": "Taijin Media Co., Ltd.",
        "address_1": "640-8 Tungchon-Dong",
        "address_2": "Seoul    157-030",
        "country": "KR"
    },
    "00050C": {
        "oui_hex": "00-05-0C",
        "organization": "Network Photonics, Inc.",
        "address_1": "451 Aviation Boulevard",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "0004EC": {
        "oui_hex": "00-04-EC",
        "organization": "Memobox SA",
        "address_1": "1, Place Dame Suzanne",
        "address_2": "",
        "country": "FR"
    },
    "0004E4": {
        "oui_hex": "00-04-E4",
        "organization": "Daeryung Ind., Inc.",
        "address_1": "#219-6, Kasan Dong,",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "00050A": {
        "oui_hex": "00-05-0A",
        "organization": "ICS Spa",
        "address_1": "Via Romano AL",
        "address_2": "",
        "country": "IT"
    },
    "000511": {
        "oui_hex": "00-05-11",
        "organization": "Complementary Technologies Ltd",
        "address_1": "Comtech House, 28 Manchester Road",
        "address_2": "    BL5 3QJ",
        "country": "GB"
    },
    "000506": {
        "oui_hex": "00-05-06",
        "organization": "Reddo Networks AB",
        "address_1": "Livdjursgatan 4",
        "address_2": "",
        "country": "SE"
    },
    "0004E2": {
        "oui_hex": "00-04-E2",
        "organization": "SMC Networks, Inc.",
        "address_1": "6 Hughes",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0004CB": {
        "oui_hex": "00-04-CB",
        "organization": "Tdsoft Communication, Ltd.",
        "address_1": "60 Medinat Hayehudim St.",
        "address_2": "",
        "country": "IL"
    },
    "000526": {
        "oui_hex": "00-05-26",
        "organization": "IPAS GmbH",
        "address_1": "Hölscherstr. 27",
        "address_2": "",
        "country": "DE"
    },
    "000467": {
        "oui_hex": "00-04-67",
        "organization": "Wuhan Research Institute of MII",
        "address_1": "88 Youkeyuan Road,",
        "address_2": "430074  430074  P.R.CHINA",
        "country": "CN"
    },
    "00045A": {
        "oui_hex": "00-04-5A",
        "organization": "The Linksys Group, Inc.",
        "address_1": "17401 Armstrong Ave.",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "000463": {
        "oui_hex": "00-04-63",
        "organization": "Bosch Security Systems",
        "address_1": "850 Greenfield Road",
        "address_2": "Lancaster  PA  17601-5874",
        "country": "US"
    },
    "00045C": {
        "oui_hex": "00-04-5C",
        "organization": "Mobiwave Pte Ltd",
        "address_1": "Blk 16, Kallang Place",
        "address_2": "    339156",
        "country": "SG"
    },
    "000453": {
        "oui_hex": "00-04-53",
        "organization": "YottaYotta, Inc.",
        "address_1": "6020- 104 Street",
        "address_2": "Edmonton, AB    T6H 5S4",
        "country": "CA"
    },
    "000450": {
        "oui_hex": "00-04-50",
        "organization": "DMD Computers SRL",
        "address_1": "Via Monviso, 14",
        "address_2": "",
        "country": "IT"
    },
    "000443": {
        "oui_hex": "00-04-43",
        "organization": "Agilent Technologies, Inc.",
        "address_1": "5301 Stevens Creek Boulevard",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "000449": {
        "oui_hex": "00-04-49",
        "organization": "Mapletree Networks",
        "address_1": "315 Norwood Park South",
        "address_2": "Norwood  MA  02062",
        "country": "US"
    },
    "00042F": {
        "oui_hex": "00-04-2F",
        "organization": "International Communications Products, Inc.",
        "address_1": "4325 Woodland Park Drive",
        "address_2": "West Melbourne  FL  32904",
        "country": "US"
    },
    "000429": {
        "oui_hex": "00-04-29",
        "organization": "Pixord Corporation",
        "address_1": "6F, No. 12, Innovation 1st Rd.,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000426": {
        "oui_hex": "00-04-26",
        "organization": "Autosys",
        "address_1": "202 Ilsinpastel,",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "0004B8": {
        "oui_hex": "00-04-B8",
        "organization": "Kumahira Co., Ltd.",
        "address_1": "4-34 Ujinahigashi 2-Chome",
        "address_2": "  JAPAN  734-8567",
        "country": "JP"
    },
    "0004B5": {
        "oui_hex": "00-04-B5",
        "organization": "Equitrac Corporation",
        "address_1": "1905 N.W. 82nd Avenue",
        "address_2": "Miami  FL  33126",
        "country": "US"
    },
    "0004B1": {
        "oui_hex": "00-04-B1",
        "organization": "Signal Technology, Inc.",
        "address_1": "3rd. Fl. Dabo Bldg.",
        "address_2": "Seoul  KOREA  138-110",
        "country": "KR"
    },
    "000451": {
        "oui_hex": "00-04-51",
        "organization": "Medrad, Inc.",
        "address_1": "One Medrad Drive",
        "address_2": "Indianola  PA  15051",
        "country": "US"
    },
    "000483": {
        "oui_hex": "00-04-83",
        "organization": "Deltron Technology, Inc.",
        "address_1": "8F-3, No. 125, Lane 235",
        "address_2": "Taipei  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "000441": {
        "oui_hex": "00-04-41",
        "organization": "Half Dome Systems, Inc.",
        "address_1": "155 B-1 Moffet Park Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0004A5": {
        "oui_hex": "00-04-A5",
        "organization": "Barco Projection Systems NV",
        "address_1": "Noordlaan 5",
        "address_2": "",
        "country": "BE"
    },
    "000482": {
        "oui_hex": "00-04-82",
        "organization": "Medialogic Corp.",
        "address_1": "0-3, Toyamaken-Sangyou",
        "address_2": "",
        "country": "JP"
    },
    "0003CA": {
        "oui_hex": "00-03-CA",
        "organization": "MTS Systems Corp.",
        "address_1": "3001 Sheldon Drive",
        "address_2": "Cary,  NC  27513",
        "country": "US"
    },
    "0003C7": {
        "oui_hex": "00-03-C7",
        "organization": "hopf Elektronik GmbH",
        "address_1": "Nottebohmstraße 41",
        "address_2": "58511  Lüdenscheid",
        "country": "DE"
    },
    "0003C2": {
        "oui_hex": "00-03-C2",
        "organization": "Solphone K.K.",
        "address_1": "2-11-1 Kandatsukasa-cho",
        "address_2": "  101-0048",
        "country": "JP"
    },
    "0003F3": {
        "oui_hex": "00-03-F3",
        "organization": "Dazzle Multimedia, Inc.",
        "address_1": "47211 Bayside Parkway",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0003EC": {
        "oui_hex": "00-03-EC",
        "organization": "ICG Research, Inc.",
        "address_1": "775 B The Queens Way",
        "address_2": "M8Z  1N1",
        "country": "CA"
    },
    "0003E9": {
        "oui_hex": "00-03-E9",
        "organization": "Akara Canada, Inc.",
        "address_1": "150 Katimavik Road",
        "address_2": "CANADA  K2L  2N2",
        "country": "CA"
    },
    "0003E5": {
        "oui_hex": "00-03-E5",
        "organization": "Hermstedt SG",
        "address_1": "Carl-Reuther - Str. 3",
        "address_2": "",
        "country": "DE"
    },
    "000421": {
        "oui_hex": "00-04-21",
        "organization": "Ocular Networks",
        "address_1": "12700, Fair Lakes Circle",
        "address_2": "Fairfax  VA  22033",
        "country": "US"
    },
    "000424": {
        "oui_hex": "00-04-24",
        "organization": "TMC s.r.l.",
        "address_1": "202 Via A. Costa",
        "address_2": "",
        "country": "IT"
    },
    "00041D": {
        "oui_hex": "00-04-1D",
        "organization": "Corega of America",
        "address_1": "P.O. Box 159",
        "address_2": "Bothell  WA  98041-0159",
        "country": "US"
    },
    "00041A": {
        "oui_hex": "00-04-1A",
        "organization": "Ines Test and Measurement GmbH & CoKG",
        "address_1": "An der Mühlenaue 5",
        "address_2": "  Bad Nenndorf  31542",
        "country": "DE"
    },
    "00041E": {
        "oui_hex": "00-04-1E",
        "organization": "Shikoku Instrumentation Co., Ltd.",
        "address_1": "777, Oosachou, Zentsuujishi,",
        "address_2": "",
        "country": "JP"
    },
    "000413": {
        "oui_hex": "00-04-13",
        "organization": "snom technology GmbH",
        "address_1": "Wittestr 30 G",
        "address_2": "Berlin    13509",
        "country": "DE"
    },
    "0003B4": {
        "oui_hex": "00-03-B4",
        "organization": "Macrotek International Corp.",
        "address_1": "2F, No. 28, Lane 46",
        "address_2": "Taipei  Taipei  TAIWAN",
        "country": "TW"
    },
    "0003A6": {
        "oui_hex": "00-03-A6",
        "organization": "Traxit Technology, Inc.",
        "address_1": "256 Great Road,",
        "address_2": "Littleton  MA  01461",
        "country": "US"
    },
    "0003A4": {
        "oui_hex": "00-03-A4",
        "organization": "Imation Corp.",
        "address_1": "1 Imation Place",
        "address_2": "Oakdale  MN  55128-3414",
        "country": "US"
    },
    "0003AB": {
        "oui_hex": "00-03-AB",
        "organization": "Bridge Information Systems",
        "address_1": "717 Office Parkway",
        "address_2": "St. Louis  MO  63141",
        "country": "US"
    },
    "000403": {
        "oui_hex": "00-04-03",
        "organization": "Nexsi Corporation",
        "address_1": "1959 Concourse Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000406": {
        "oui_hex": "00-04-06",
        "organization": "Fa. Metabox AG",
        "address_1": "Daimlerring 37,",
        "address_2": "",
        "country": "DE"
    },
    "0003F8": {
        "oui_hex": "00-03-F8",
        "organization": "SanCastle Technologies, Inc.",
        "address_1": "2107 North First Street",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0003FA": {
        "oui_hex": "00-03-FA",
        "organization": "TiMetra Networks",
        "address_1": "500 Ellis St.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0003C6": {
        "oui_hex": "00-03-C6",
        "organization": "ICUE Systems, Inc.",
        "address_1": "17489 Gale Avenue",
        "address_2": "City of Industry  CA  91748",
        "country": "US"
    },
    "0003BB": {
        "oui_hex": "00-03-BB",
        "organization": "Signal Communications Limited",
        "address_1": "Unit 217, 2/F, HKITC,",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "0003BE": {
        "oui_hex": "00-03-BE",
        "organization": "Netility",
        "address_1": "298 South Sunnyvale Ave.",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "0003DF": {
        "oui_hex": "00-03-DF",
        "organization": "Desana Systems",
        "address_1": "1805 McCandless Ave.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0003DA": {
        "oui_hex": "00-03-DA",
        "organization": "Takamisawa Cybernetics Co., Ltd.",
        "address_1": "Nakano Heiwa Bldg.",
        "address_2": "",
        "country": "JP"
    },
    "0003D9": {
        "oui_hex": "00-03-D9",
        "organization": "Secheron SA",
        "address_1": "Untermattweg 8",
        "address_2": "",
        "country": "CH"
    },
    "0003FB": {
        "oui_hex": "00-03-FB",
        "organization": "ENEGATE Co.,Ltd.",
        "address_1": "3-14-40 Senrioka,",
        "address_2": "Settsu-city  Osaka  566-8686",
        "country": "JP"
    },
    "0003F6": {
        "oui_hex": "00-03-F6",
        "organization": "Allegro Networks, Inc.",
        "address_1": "6399 San Ignacio Avenue",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "000415": {
        "oui_hex": "00-04-15",
        "organization": "Rasteme Systems Co., Ltd.",
        "address_1": "886-2 Nihongi Nakagou-mura",
        "address_2": "",
        "country": "JP"
    },
    "000398": {
        "oui_hex": "00-03-98",
        "organization": "WISI",
        "address_1": "Wilhelm-Sihn-Str. 5-7",
        "address_2": "D-75223  Niefern-Oeschelbronn",
        "country": "DE"
    },
    "000395": {
        "oui_hex": "00-03-95",
        "organization": "California Amplifier",
        "address_1": "460 Calle San Pablo",
        "address_2": "Camarillo  CA  93012",
        "country": "US"
    },
    "000392": {
        "oui_hex": "00-03-92",
        "organization": "Hyundai Teletek Co., Ltd.",
        "address_1": "B-501, Techno Park, 148 Yatap-dong,",
        "address_2": "  KOREA  Republic",
        "country": "KR"
    },
    "00038E": {
        "oui_hex": "00-03-8E",
        "organization": "Atoga Systems, Inc.",
        "address_1": "49026 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00031A": {
        "oui_hex": "00-03-1A",
        "organization": "Beijing Broad Telecom Ltd., China",
        "address_1": "P.O. Box #147",
        "address_2": "Beijing    100876",
        "country": "CN"
    },
    "00035B": {
        "oui_hex": "00-03-5B",
        "organization": "BridgeWave Communications",
        "address_1": "3350 Thomad Road",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000357": {
        "oui_hex": "00-03-57",
        "organization": "Intervoice-Brite, Inc.",
        "address_1": "17811 Waterview Pkwy.",
        "address_2": "Dallas  TX  75252",
        "country": "US"
    },
    "00037F": {
        "oui_hex": "00-03-7F",
        "organization": "Atheros Communications, Inc.",
        "address_1": "5480 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0002F0": {
        "oui_hex": "00-02-F0",
        "organization": "AME Optimedia Technology Co., Ltd.",
        "address_1": "17F-2, 79 Hsin Tai Wu Road, Sec. 1,",
        "address_2": "",
        "country": "TW"
    },
    "00039E": {
        "oui_hex": "00-03-9E",
        "organization": "Tera System Co., Ltd.",
        "address_1": "Doosung B/F Rm 302",
        "address_2": "Republic  of  Korea",
        "country": "KR"
    },
    "000397": {
        "oui_hex": "00-03-97",
        "organization": "FireBrick Limited",
        "address_1": "C/O Andrews & Arnold Ltd,",
        "address_2": "Enterprise Court, Downmill Road  Bracknell, Berks  RG12 1QS",
        "country": "GB"
    },
    "00033F": {
        "oui_hex": "00-03-3F",
        "organization": "BigBand Networks, Ltd.",
        "address_1": "3 Azrieli Towers",
        "address_2": "",
        "country": "IL"
    },
    "000327": {
        "oui_hex": "00-03-27",
        "organization": "ACT'L",
        "address_1": "Avenue de Artisanat 10A",
        "address_2": "",
        "country": "BE"
    },
    "00032E": {
        "oui_hex": "00-03-2E",
        "organization": "Scope Information Management, Ltd.",
        "address_1": "2F Chanwoo b/o 736 Youksang-dong,",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "00037C": {
        "oui_hex": "00-03-7C",
        "organization": "Coax Media",
        "address_1": "1220 Oak Industrial Lane",
        "address_2": "Cumming  GA  30041",
        "country": "US"
    },
    "000368": {
        "oui_hex": "00-03-68",
        "organization": "Embedone Co., Ltd.",
        "address_1": "Fl. 9 Annex Samhwan B/D. 17-26",
        "address_2": "Seoul    150-01",
        "country": "KR"
    },
    "000345": {
        "oui_hex": "00-03-45",
        "organization": "Routrek Networks Corporation",
        "address_1": "Nilssei Shin Mizonokuchi Bldg. 1F",
        "address_2": "  23-0011",
        "country": "JP"
    },
    "0002C8": {
        "oui_hex": "00-02-C8",
        "organization": "Technocom Communications Technology (pte) Ltd",
        "address_1": "189 Kaki Buckit Avenue 1",
        "address_2": "  Singapore  416029",
        "country": "SG"
    },
    "0002B8": {
        "oui_hex": "00-02-B8",
        "organization": "WHI KONSULT AB",
        "address_1": "Scheelegatan 11",
        "address_2": "  Stockholm  SE-112 28",
        "country": "SE"
    },
    "0002A9": {
        "oui_hex": "00-02-A9",
        "organization": "RACOM, s.r.o.",
        "address_1": "Mirova 1283, Nove Mesto na Morave",
        "address_2": "592 31  Czech  republic",
        "country": "CZ"
    },
    "0002BB": {
        "oui_hex": "00-02-BB",
        "organization": "Continuous Computing Corp",
        "address_1": "9380 Carroll Park Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0002BC": {
        "oui_hex": "00-02-BC",
        "organization": "LVL 7 Systems, Inc.",
        "address_1": "13000 Weston Pkwy",
        "address_2": "Cary  NC  27513",
        "country": "US"
    },
    "00030F": {
        "oui_hex": "00-03-0F",
        "organization": "Digital China (Shanghai) Networks Ltd.",
        "address_1": "602-23, Haitai Building, 351 Guo Shoujin",
        "address_2": "Shanghai",
        "country": "CN"
    },
    "000311": {
        "oui_hex": "00-03-11",
        "organization": "Micro Technology Co., Ltd.",
        "address_1": "Suehiro Bldg.",
        "address_2": "  101-0021",
        "country": "JP"
    },
    "00030D": {
        "oui_hex": "00-03-0D",
        "organization": "Uniwill Computer Corp.",
        "address_1": "No. 24, Pei Yuan Rd., Chung",
        "address_2": "Li City",
        "country": "TW"
    },
    "000309": {
        "oui_hex": "00-03-09",
        "organization": "Texcel Technology PLC",
        "address_1": "Thames Road",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "000303": {
        "oui_hex": "00-03-03",
        "organization": "JAMA Electronics Co., Ltd.",
        "address_1": "10F, No. 222-1, Sec. 3",
        "address_2": "Taipei Hsien",
        "country": "TW"
    },
    "000305": {
        "oui_hex": "00-03-05",
        "organization": "MSC Vertriebs GmbH",
        "address_1": "Design Center Aachen",
        "address_2": "AACHEN    D-52076",
        "country": "DE"
    },
    "0002FE": {
        "oui_hex": "00-02-FE",
        "organization": "Viditec, Inc.",
        "address_1": "520 Central Parkway E.",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "00019F": {
        "oui_hex": "00-01-9F",
        "organization": "ReadyNet",
        "address_1": "6952 High Tech Drive",
        "address_2": "Midvale  UT  84047",
        "country": "US"
    },
    "0002FF": {
        "oui_hex": "00-02-FF",
        "organization": "Handan BroadInfoCom",
        "address_1": "5th Fl. Shinsung Plaza #697-11",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0002F4": {
        "oui_hex": "00-02-F4",
        "organization": "PCTEL, Inc.",
        "address_1": "1331 California Circle",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0002E9": {
        "oui_hex": "00-02-E9",
        "organization": "CS Systemes De Securite - C3S",
        "address_1": "23, rue de Schwobsheim",
        "address_2": "",
        "country": "FR"
    },
    "0002E5": {
        "oui_hex": "00-02-E5",
        "organization": "Timeware Ltd.",
        "address_1": "Brookfield Grange",
        "address_2": "Lancs    042 GLB",
        "country": "GB"
    },
    "0002E0": {
        "oui_hex": "00-02-E0",
        "organization": "ETAS GmbH",
        "address_1": "Borsigstraße 10",
        "address_2": "",
        "country": "DE"
    },
    "0002CE": {
        "oui_hex": "00-02-CE",
        "organization": "FoxJet, Inc.",
        "address_1": "2016 E. Randal Mill Rd. #409",
        "address_2": "Arlington  TX  76011-8223",
        "country": "US"
    },
    "0002C3": {
        "oui_hex": "00-02-C3",
        "organization": "Arelnet Ltd.",
        "address_1": "3 Hayarden St.",
        "address_2": "",
        "country": "IL"
    },
    "000316": {
        "oui_hex": "00-03-16",
        "organization": "Nobell Communications, Inc.",
        "address_1": "3410 Far West Blvd., Suite 240",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "000329": {
        "oui_hex": "00-03-29",
        "organization": "F3, Inc.",
        "address_1": "2F, No. 7, Industry E. Rd. 9,",
        "address_2": "Hsinchu",
        "country": "TW"
    },
    "000321": {
        "oui_hex": "00-03-21",
        "organization": "Reco Research Co., Ltd.",
        "address_1": "No. 47-1, Sec. 2,",
        "address_2": "",
        "country": "TW"
    },
    "0002F5": {
        "oui_hex": "00-02-F5",
        "organization": "VIVE Synergies, Inc.",
        "address_1": "30 West Beaver Creek Road, Unit 101",
        "address_2": "    L4B 3K1",
        "country": "CA"
    },
    "0002D5": {
        "oui_hex": "00-02-D5",
        "organization": "ACR",
        "address_1": "Cardoulines B2",
        "address_2": "",
        "country": "FR"
    },
    "0002AB": {
        "oui_hex": "00-02-AB",
        "organization": "CTC Union Technologies Co., Ltd.",
        "address_1": "8F No. 60 Zhouzi St.",
        "address_2": "Neihu  Taipei  114",
        "country": "TW"
    },
    "0002A4": {
        "oui_hex": "00-02-A4",
        "organization": "AddPac Technology Co., Ltd.",
        "address_1": "3F Jeoung Am Bldg., 769-12",
        "address_2": "Seoul  Seoul  Korea",
        "country": "KR"
    },
    "0002A3": {
        "oui_hex": "00-02-A3",
        "organization": "ABB Switzerland Ltd, Power Systems",
        "address_1": "Bruggerstrasse 72",
        "address_2": "Baden",
        "country": "CH"
    },
    "0002A0": {
        "oui_hex": "00-02-A0",
        "organization": "Flatstack Ltd.",
        "address_1": "1112 Budapest",
        "address_2": "",
        "country": "HU"
    },
    "0002B2": {
        "oui_hex": "00-02-B2",
        "organization": "Cablevision",
        "address_1": "420 Crossways Park Drive West",
        "address_2": "Woodbury  NY  11787",
        "country": "US"
    },
    "0002B7": {
        "oui_hex": "00-02-B7",
        "organization": "Watanabe Electric Industry Co., Ltd.",
        "address_1": "6-16-19, Jingumae, Shibuya-ku",
        "address_2": "",
        "country": "JP"
    },
    "0002AF": {
        "oui_hex": "00-02-AF",
        "organization": "TeleCruz Technology, Inc.",
        "address_1": "2391 Qume Dr.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0002A8": {
        "oui_hex": "00-02-A8",
        "organization": "Air Link Technology",
        "address_1": "Bethel Bldg. 303",
        "address_2": "Seoul  KOREA  137-130",
        "country": "KR"
    },
    "00026A": {
        "oui_hex": "00-02-6A",
        "organization": "Cocess Telecom Co., Ltd.",
        "address_1": "Research & Development Dept.",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "00026C": {
        "oui_hex": "00-02-6C",
        "organization": "Philips CFT",
        "address_1": "Building SAN 6",
        "address_2": "  The",
        "country": "NL"
    },
    "000262": {
        "oui_hex": "00-02-62",
        "organization": "Soyo Group Soyo Com Tech Co., Ltd",
        "address_1": "5H. No. 21 Wu-gong 5 Rd,",
        "address_2": "Taipei Hsien  Taiwan  R.O.C.",
        "country": "TW"
    },
    "000265": {
        "oui_hex": "00-02-65",
        "organization": "Virditech Co. Ltd.",
        "address_1": "Hyundai Topics Blgd., 11th Fl",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "00025B": {
        "oui_hex": "00-02-5B",
        "organization": "Cambridge Silicon Radio",
        "address_1": "Unit 400, Science Park,",
        "address_2": "  United  Kingdom",
        "country": "GB"
    },
    "000256": {
        "oui_hex": "00-02-56",
        "organization": "Alpha Processor, Inc.",
        "address_1": "130 C Baker Ave. Ext.",
        "address_2": "Concord  MA  01742",
        "country": "US"
    },
    "000259": {
        "oui_hex": "00-02-59",
        "organization": "Tsann Kuen China (Shanghai)Enterprise Co., Ltd. IT Group",
        "address_1": "8F, #99, Huaihai Rd, East,",
        "address_2": "  CHINA  200021",
        "country": "CN"
    },
    "000294": {
        "oui_hex": "00-02-94",
        "organization": "Tokyo Sokushin Co., Ltd.",
        "address_1": "5-16-12 Nishi-Nippori",
        "address_2": "",
        "country": "JP"
    },
    "000296": {
        "oui_hex": "00-02-96",
        "organization": "Lectron Co,. Ltd.",
        "address_1": "9F, No.171, Sec. 2, Tatung Rd.,",
        "address_2": "Taiwan  Taiwan  R.O.C.",
        "country": "TW"
    },
    "00028E": {
        "oui_hex": "00-02-8E",
        "organization": "Rapid 5 Networks, Inc.",
        "address_1": "180 Baytech Drive",
        "address_2": "San Jose  CA  95134-2302",
        "country": "US"
    },
    "00024F": {
        "oui_hex": "00-02-4F",
        "organization": "IPM Datacom S.R.L.",
        "address_1": "Via Roma, 231",
        "address_2": "  Naples",
        "country": "IT"
    },
    "000271": {
        "oui_hex": "00-02-71",
        "organization": "Zhone Technologies",
        "address_1": "7001 Oakport Street",
        "address_2": "Oakland  CA  94621",
        "country": "US"
    },
    "00028A": {
        "oui_hex": "00-02-8A",
        "organization": "Ambit Microsystems Corporation",
        "address_1": "5F-1, 5 Hsin-An Road Hsinchu,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "0001FA": {
        "oui_hex": "00-01-FA",
        "organization": "HOROSCAS",
        "address_1": "26, LOUIS BLANC",
        "address_2": "",
        "country": "FR"
    },
    "000282": {
        "oui_hex": "00-02-82",
        "organization": "ViaClix, Inc.",
        "address_1": "1400 Dell Ave., Suite B",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "000285": {
        "oui_hex": "00-02-85",
        "organization": "Riverstone Networks",
        "address_1": "5200 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000279": {
        "oui_hex": "00-02-79",
        "organization": "Control Applications, Ltd.",
        "address_1": "3 Tevuot Haarets St.",
        "address_2": "",
        "country": "IL"
    },
    "000251": {
        "oui_hex": "00-02-51",
        "organization": "Soma Networks, Inc.",
        "address_1": "650 Townsend St.",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "0001F5": {
        "oui_hex": "00-01-F5",
        "organization": "ERIM S.A.",
        "address_1": "11 Av Republique",
        "address_2": "",
        "country": "FR"
    },
    "0001FF": {
        "oui_hex": "00-01-FF",
        "organization": "Data Direct Networks, Inc.",
        "address_1": "9320 Lurline Avenue",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "0001FC": {
        "oui_hex": "00-01-FC",
        "organization": "Keyence Corporation",
        "address_1": "1-3-14, Higashi-Nakajima,",
        "address_2": "",
        "country": "JP"
    },
    "0001FD": {
        "oui_hex": "00-01-FD",
        "organization": "Digital Voice Systems, Inc.",
        "address_1": "234 Littleton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "000210": {
        "oui_hex": "00-02-10",
        "organization": "Fenecom",
        "address_1": "7/F Kon-kuk University Alumni",
        "address_2": "Seoul  Seoul  Korea",
        "country": "KR"
    },
    "00020B": {
        "oui_hex": "00-02-0B",
        "organization": "Native Networks, Inc.",
        "address_1": "P.O. Box 7165",
        "address_2": "",
        "country": "IL"
    },
    "000218": {
        "oui_hex": "00-02-18",
        "organization": "Advanced Scientific Corp",
        "address_1": "1 Fl., No. 26, Industry East 9th Road",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "0001EE": {
        "oui_hex": "00-01-EE",
        "organization": "Comtrol Europe, Ltd.",
        "address_1": "The Courtyard Studio",
        "address_2": "    U.K.",
        "country": "GB"
    },
    "0001F0": {
        "oui_hex": "00-01-F0",
        "organization": "Tridium, Inc.",
        "address_1": "3951 Westerre Parkway",
        "address_2": "Richmond  VA  23233",
        "country": "US"
    },
    "0001F1": {
        "oui_hex": "00-01-F1",
        "organization": "Innovative Concepts, Inc.",
        "address_1": "8200 Greensboro Drive",
        "address_2": "McLean  VA  22102",
        "country": "US"
    },
    "0001E2": {
        "oui_hex": "00-01-E2",
        "organization": "Ando Electric Corporation",
        "address_1": "19-7, Kamata 4-Chrome, Ota-ku",
        "address_2": "",
        "country": "JP"
    },
    "00022F": {
        "oui_hex": "00-02-2F",
        "organization": "P-Cube, Ltd.",
        "address_1": "P.O. Box 12331",
        "address_2": "",
        "country": "IL"
    },
    "000227": {
        "oui_hex": "00-02-27",
        "organization": "ESD Electronic System Design GmbH",
        "address_1": "Vahrenwalder Str. 207",
        "address_2": "30 165  Hannover",
        "country": "DE"
    },
    "00021D": {
        "oui_hex": "00-02-1D",
        "organization": "Data General Communication Ltd.",
        "address_1": "Rm. 18C, Bldg. C, CEIEC Tower",
        "address_2": "",
        "country": "CN"
    },
    "000219": {
        "oui_hex": "00-02-19",
        "organization": "Paralon Technologies",
        "address_1": "700 Fifth Ave, Suite 6101",
        "address_2": "Seattle  WA  98104",
        "country": "US"
    },
    "000203": {
        "oui_hex": "00-02-03",
        "organization": "Woonsang Telecom, Inc.",
        "address_1": "104-9, Munji-Dong, Yusong-Gu",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001D3": {
        "oui_hex": "00-01-D3",
        "organization": "PAXCOMM, Inc.",
        "address_1": "7th F The Corp. Center",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001E1": {
        "oui_hex": "00-01-E1",
        "organization": "Kinpo Electronics, Inc.",
        "address_1": "No.147, Sec. 3, Beishen Rd",
        "address_2": "Shenkeng Dist.  New Taipei City  222",
        "country": "TW"
    },
    "00022C": {
        "oui_hex": "00-02-2C",
        "organization": "ABB Bomem, Inc.",
        "address_1": "585, boul. Charest Est",
        "address_2": "Canada  G1K  9H4",
        "country": "CA"
    },
    "00023C": {
        "oui_hex": "00-02-3C",
        "organization": "Creative Technology, Ltd.",
        "address_1": "31 International Business Park",
        "address_2": "Republic  of",
        "country": "SG"
    },
    "00306C": {
        "oui_hex": "00-30-6C",
        "organization": "Hitex Holding GmbH",
        "address_1": "Greschbachstraße 12",
        "address_2": "76229 Karlsruhe",
        "country": "DE"
    },
    "00308B": {
        "oui_hex": "00-30-8B",
        "organization": "Brix Networks",
        "address_1": "300 Concord Road",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "000177": {
        "oui_hex": "00-01-77",
        "organization": "EDSL",
        "address_1": "Habarzel 1 st",
        "address_2": "  ISRAEL  69710",
        "country": "IL"
    },
    "00014D": {
        "oui_hex": "00-01-4D",
        "organization": "Shin Kin Enterprises Co., Ltd",
        "address_1": "7, FU Hsing St. Tue Cheng Ind.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0001DA": {
        "oui_hex": "00-01-DA",
        "organization": "WINCOMM Corporation",
        "address_1": "2F, No. 3, Prosperity Road 1,",
        "address_2": "  Hsinchu  Taiwan",
        "country": "TW"
    },
    "0001D2": {
        "oui_hex": "00-01-D2",
        "organization": "inXtron, Inc.",
        "address_1": "8F, No.52, MinQuan Road, Xindian Dist.",
        "address_2": "New Taipei City    23141",
        "country": "TW"
    },
    "0001C6": {
        "oui_hex": "00-01-C6",
        "organization": "Quarry Technologies",
        "address_1": "8 New England Executive Park",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "00016E": {
        "oui_hex": "00-01-6E",
        "organization": "Conklin Corporation",
        "address_1": "6141 Crooked Creek Road",
        "address_2": "Norcross  GA  30092-3193",
        "country": "US"
    },
    "000174": {
        "oui_hex": "00-01-74",
        "organization": "CyberOptics Corporation",
        "address_1": "5900 Golden Hills Drive",
        "address_2": "Golden Valley  MN  55416",
        "country": "US"
    },
    "00015E": {
        "oui_hex": "00-01-5E",
        "organization": "BEST TECHNOLOGY CO., LTD.",
        "address_1": "7F, Haesung B/D",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "000161": {
        "oui_hex": "00-01-61",
        "organization": "Meta Machine Technology",
        "address_1": "400 Silver Cedar Court - ste. #220",
        "address_2": "Chapel Hill  NC  27514",
        "country": "US"
    },
    "0001A1": {
        "oui_hex": "00-01-A1",
        "organization": "Mag-Tek, Inc.",
        "address_1": "1710 Apollo Court",
        "address_2": "Seal Beach  CA  90740",
        "country": "US"
    },
    "000186": {
        "oui_hex": "00-01-86",
        "organization": "Uwe Disch",
        "address_1": "Eichenhainstraße 14",
        "address_2": "",
        "country": "DE"
    },
    "0001A6": {
        "oui_hex": "00-01-A6",
        "organization": "Scientific-Atlanta Arcodan A/S",
        "address_1": "Avgustenborg Landevej 7",
        "address_2": "",
        "country": "DK"
    },
    "000172": {
        "oui_hex": "00-01-72",
        "organization": "TechnoLand Co., LTD.",
        "address_1": "3-17-11 Akebono-cho",
        "address_2": "",
        "country": "JP"
    },
    "0001A0": {
        "oui_hex": "00-01-A0",
        "organization": "Infinilink Corporation",
        "address_1": "1740 E. Garry Ave. - Ste. #206",
        "address_2": "Santa Ana  CA  92705",
        "country": "US"
    },
    "000196": {
        "oui_hex": "00-01-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000199": {
        "oui_hex": "00-01-99",
        "organization": "HeiSei Electronics",
        "address_1": "5/7 Alley 8, Lane 45",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00018B": {
        "oui_hex": "00-01-8B",
        "organization": "NetLinks Co., Ltd.",
        "address_1": "3F Dscom Bldg., 238-3",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00018D": {
        "oui_hex": "00-01-8D",
        "organization": "AudeSi Technologies",
        "address_1": "Suite 180, 6815",
        "address_2": "  AB",
        "country": "CA"
    },
    "00019D": {
        "oui_hex": "00-01-9D",
        "organization": "E-Control Systems, Inc.",
        "address_1": "9420 Lurline Ave., Unite",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "0001CE": {
        "oui_hex": "00-01-CE",
        "organization": "Custom Micro Products, Ltd.",
        "address_1": "450 Blandford Road",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0001BB": {
        "oui_hex": "00-01-BB",
        "organization": "Frequentis",
        "address_1": "SPITTELBREITENGASSE 34",
        "address_2": "",
        "country": "AT"
    },
    "0001BC": {
        "oui_hex": "00-01-BC",
        "organization": "Brains Corporation",
        "address_1": "2-27-8-4Fl TAMAGAWA",
        "address_2": "",
        "country": "JP"
    },
    "0001C0": {
        "oui_hex": "00-01-C0",
        "organization": "CompuLab, Ltd.",
        "address_1": "P.O. Box 66",
        "address_2": "",
        "country": "IL"
    },
    "00017C": {
        "oui_hex": "00-01-7C",
        "organization": "AG-E GmbH",
        "address_1": "Dennewartstraße 27",
        "address_2": "",
        "country": "DE"
    },
    "000108": {
        "oui_hex": "00-01-08",
        "organization": "AVLAB Technology, Inc.",
        "address_1": "3F-1, No. 134, Sec. 3",
        "address_2": "Hsin Tien, Taipei",
        "country": "TW"
    },
    "00062B": {
        "oui_hex": "00-06-2B",
        "organization": "INTRASERVER TECHNOLOGY",
        "address_1": "SEVEN OCTOBER HILL RD.",
        "address_2": "HOLLISTON  MA  01746",
        "country": "US"
    },
    "000100": {
        "oui_hex": "00-01-00",
        "organization": "EQUIP'TRANS",
        "address_1": "31 rue Paul Cezanne",
        "address_2": "LA ROCHETTE    77000",
        "country": "FR"
    },
    "00B09D": {
        "oui_hex": "00-B0-9D",
        "organization": "Point Grey Research Inc.",
        "address_1": "305-1847 West Broadway",
        "address_2": "Vancouver  British Columbia V6J 1Y6",
        "country": "CA"
    },
    "000110": {
        "oui_hex": "00-01-10",
        "organization": "Gotham Networks",
        "address_1": "15 Discovery Way",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "000112": {
        "oui_hex": "00-01-12",
        "organization": "Shark Multimedia Inc.",
        "address_1": "48890 Milmont Drive  #101-D",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000116": {
        "oui_hex": "00-01-16",
        "organization": "Netspect Technologies, Inc.",
        "address_1": "3945 Freedom Circle - Ste. #360",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00B06D": {
        "oui_hex": "00-B0-6D",
        "organization": "Jones Futurex Inc.",
        "address_1": "3715 Atherton Road",
        "address_2": "Rocklin  CA  95765",
        "country": "US"
    },
    "00B094": {
        "oui_hex": "00-B0-94",
        "organization": "Alaris, Inc.",
        "address_1": "47338 Fremont Boulevard",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0030F0": {
        "oui_hex": "00-30-F0",
        "organization": "Uniform Industrial Corp.",
        "address_1": "18F, 171, Shung Teh Road",
        "address_2": "Taipei",
        "country": "TW"
    },
    "00013B": {
        "oui_hex": "00-01-3B",
        "organization": "BNA SYSTEMS",
        "address_1": "1637 S. Main Street",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000134": {
        "oui_hex": "00-01-34",
        "organization": "Selectron Systems AG",
        "address_1": "Bernstreasse 70",
        "address_2": "",
        "country": "CH"
    },
    "000139": {
        "oui_hex": "00-01-39",
        "organization": "Point Multimedia Systems",
        "address_1": "4Ra 507, Shihwa Industrial Complex",
        "address_2": "  Korea  425-110",
        "country": "KR"
    },
    "00013E": {
        "oui_hex": "00-01-3E",
        "organization": "Ascom Tateco AB",
        "address_1": "Box 8783",
        "address_2": "",
        "country": "SE"
    },
    "00012E": {
        "oui_hex": "00-01-2E",
        "organization": "PC Partner Ltd.",
        "address_1": "Rm 1901-1908, 19/F, Shatin Galleria",
        "address_2": "",
        "country": "CN"
    },
    "000132": {
        "oui_hex": "00-01-32",
        "organization": "Dranetz - BMI",
        "address_1": "1000 New Durham Road",
        "address_2": "Edison  NJ  08818",
        "country": "US"
    },
    "000113": {
        "oui_hex": "00-01-13",
        "organization": "OLYMPUS CORPORATION",
        "address_1": "2-3 Kuboyama-cho, Hachioji-shi",
        "address_2": "Tokyo 192-8512    j",
        "country": "JP"
    },
    "00011E": {
        "oui_hex": "00-01-1E",
        "organization": "Precidia Technologies, Inc.",
        "address_1": "10A Hearst Way",
        "address_2": "Kanata  Ontario K2M-2C4",
        "country": "CA"
    },
    "000155": {
        "oui_hex": "00-01-55",
        "organization": "Promise Technology, Inc.",
        "address_1": "4F, 1, Prosperity 1st Road",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "003094": {
        "oui_hex": "00-30-94",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00308A": {
        "oui_hex": "00-30-8A",
        "organization": "NICOTRA SISTEMI S.P.A",
        "address_1": "41 Via Primo Maggio",
        "address_2": "  Baranzate (MI)  20021",
        "country": "IT"
    },
    "003072": {
        "oui_hex": "00-30-72",
        "organization": "Intellibyte Inc.",
        "address_1": "Canada Trust Tower - BCE Place",
        "address_2": "Toronto  Ontario  M5J 2S1",
        "country": "CA"
    },
    "003040": {
        "oui_hex": "00-30-40",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003032": {
        "oui_hex": "00-30-32",
        "organization": "MagicRam, Inc.",
        "address_1": "1850 Beverly Blvd.",
        "address_2": "Los Angeles  CA  90057",
        "country": "US"
    },
    "0030EA": {
        "oui_hex": "00-30-EA",
        "organization": "TeraForce Technology Corporation",
        "address_1": "1100 EXECUTIVE DRIVE",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "00309B": {
        "oui_hex": "00-30-9B",
        "organization": "Smartware",
        "address_1": "49 AV Aristide",
        "address_2": "92160 Antony",
        "country": "FR"
    },
    "003045": {
        "oui_hex": "00-30-45",
        "organization": "Village Networks, Inc. (VNI)",
        "address_1": "100 Village Court - Ste. #301",
        "address_2": "Hazlet  NJ  07730",
        "country": "US"
    },
    "0030E5": {
        "oui_hex": "00-30-E5",
        "organization": "Amper Datos S.A.",
        "address_1": "C/Marconi n*3  (PTM)",
        "address_2": "28760 Madrid",
        "country": "ES"
    },
    "003006": {
        "oui_hex": "00-30-06",
        "organization": "SUPERPOWER COMPUTER",
        "address_1": "ELECTRONICS CO., LTD.",
        "address_2": "Taipei 248",
        "country": "TW"
    },
    "003038": {
        "oui_hex": "00-30-38",
        "organization": "XCP, INC.",
        "address_1": "40 ELM STREET",
        "address_2": "DRYDEN  NY  13053",
        "country": "US"
    },
    "003079": {
        "oui_hex": "00-30-79",
        "organization": "CQOS, INC.",
        "address_1": "25 MAUCHLY  - STE. #329",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "00300C": {
        "oui_hex": "00-30-0C",
        "organization": "CONGRUENCY, LTD.",
        "address_1": "23 HASIVIM STREET",
        "address_2": "PETAH-TIKVA 49170",
        "country": "IL"
    },
    "00304C": {
        "oui_hex": "00-30-4C",
        "organization": "APPIAN COMMUNICATIONS, INC.",
        "address_1": "80 CENTRAL STREET",
        "address_2": "BOXBOROUGH  MA  01719",
        "country": "US"
    },
    "0030E8": {
        "oui_hex": "00-30-E8",
        "organization": "ENSIM CORP.",
        "address_1": "1215 Terra Bella Ave.",
        "address_2": "Mountainview  CA  94043",
        "country": "US"
    },
    "0030C9": {
        "oui_hex": "00-30-C9",
        "organization": "LuxN, N",
        "address_1": "570 Maude Court",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "003028": {
        "oui_hex": "00-30-28",
        "organization": "FASE Saldatura srl",
        "address_1": "V.R. Bernardi 5",
        "address_2": "TORINO",
        "country": "IT"
    },
    "003069": {
        "oui_hex": "00-30-69",
        "organization": "IMPACCT TECHNOLOGY CORP.",
        "address_1": "2F, NO. 12, R&D RD. II",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0030C3": {
        "oui_hex": "00-30-C3",
        "organization": "FLUECKIGER ELEKTRONIK AG",
        "address_1": "KIRCHBARGSTRASSE 201",
        "address_2": "",
        "country": "CH"
    },
    "00305A": {
        "oui_hex": "00-30-5A",
        "organization": "TELGEN CORPORATION",
        "address_1": "3101 SOVEREIGN DR. - STE.",
        "address_2": "LANSING  MI  48911",
        "country": "US"
    },
    "003010": {
        "oui_hex": "00-30-10",
        "organization": "VISIONETICS INTERNATIONAL",
        "address_1": "3F, NO. 3, PROSPERITY ROAD 1",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0030D9": {
        "oui_hex": "00-30-D9",
        "organization": "DATACORE SOFTWARE CORP.",
        "address_1": "CORPORATE PARK",
        "address_2": "FORT LAUDERDALE  FL  33309",
        "country": "US"
    },
    "003026": {
        "oui_hex": "00-30-26",
        "organization": "HeiTel Digital Video GmbH",
        "address_1": "Stuthagen 25",
        "address_2": "",
        "country": "DE"
    },
    "003077": {
        "oui_hex": "00-30-77",
        "organization": "ONPREM NETWORKS",
        "address_1": "42501 ALBRAE STREET",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "003047": {
        "oui_hex": "00-30-47",
        "organization": "NISSEI ELECTRIC CO., LTD.",
        "address_1": "32 MIYAWAKE, SHIMONOISHIKI-CHO",
        "address_2": "",
        "country": "JP"
    },
    "0030D4": {
        "oui_hex": "00-30-D4",
        "organization": "AAE Systems, Inc.",
        "address_1": "642 North Pastoria Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00D0D7": {
        "oui_hex": "00-D0-D7",
        "organization": "B2C2, INC.",
        "address_1": "2020 CHALLENGER DRIVE-",
        "address_2": "ALAMEDA  CA  94501",
        "country": "US"
    },
    "00D073": {
        "oui_hex": "00-D0-73",
        "organization": "ACN ADVANCED COMMUNICATIONS",
        "address_1": "NETWORKS SA",
        "address_2": "",
        "country": "CH"
    },
    "00D057": {
        "oui_hex": "00-D0-57",
        "organization": "ULTRAK, INC.",
        "address_1": "1301 WATERS RIDGE DRIVE",
        "address_2": "LEWISVILLE  TX  75057",
        "country": "US"
    },
    "0030AB": {
        "oui_hex": "00-30-AB",
        "organization": "DELTA NETWORKS, INC.",
        "address_1": "8, KON JAN WEST ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "003049": {
        "oui_hex": "00-30-49",
        "organization": "BRYANT TECHNOLOGY, LTD.",
        "address_1": "P.O. BOX 69557",
        "address_2": "  SOUTH  AFRICA",
        "country": "ZA"
    },
    "00306D": {
        "oui_hex": "00-30-6D",
        "organization": "LUCENT TECHNOLOGIES",
        "address_1": "300 BAKER AVENUE - STE. #100",
        "address_2": "CONCORD  MA  01742-2168",
        "country": "US"
    },
    "003017": {
        "oui_hex": "00-30-17",
        "organization": "BlueArc UK Ltd",
        "address_1": "Queensgate House",
        "address_2": "Bracknell    RG12 1RB",
        "country": "GB"
    },
    "00301C": {
        "oui_hex": "00-30-1C",
        "organization": "ALTVATER AIRDATA SYSTEMS",
        "address_1": "GMBH & CO. KG",
        "address_2": "",
        "country": "DE"
    },
    "003080": {
        "oui_hex": "00-30-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0030F7": {
        "oui_hex": "00-30-F7",
        "organization": "RAMIX INC.",
        "address_1": "1672 DONLON STREET",
        "address_2": "VENTURA  CA  93003",
        "country": "US"
    },
    "0030D0": {
        "oui_hex": "00-30-D0",
        "organization": "Tellabs",
        "address_1": "1750 Founder's Parkway",
        "address_2": "Alpharetta  GA  30004",
        "country": "US"
    },
    "003014": {
        "oui_hex": "00-30-14",
        "organization": "DIVIO, INC.",
        "address_1": "997 E. ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "003081": {
        "oui_hex": "00-30-81",
        "organization": "ALTOS C&C",
        "address_1": "150-010 RM. 1012, 44-1",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00D0F0": {
        "oui_hex": "00-D0-F0",
        "organization": "CONVISION TECHNOLOGY GMBH",
        "address_1": "REBENRING 33",
        "address_2": "",
        "country": "DE"
    },
    "00D010": {
        "oui_hex": "00-D0-10",
        "organization": "CONVERGENT NETWORKS, INC.",
        "address_1": "2 HIGHWOOD DRIVE",
        "address_2": "TEWKSBURY  MA  01876",
        "country": "US"
    },
    "00D04B": {
        "oui_hex": "00-D0-4B",
        "organization": "LA CIE GROUP S.A.",
        "address_1": "17 RUE AMPERE",
        "address_2": "",
        "country": "FR"
    },
    "00D00E": {
        "oui_hex": "00-D0-0E",
        "organization": "PLURIS, INC.",
        "address_1": "10455 BANDLEY DRIVE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00D012": {
        "oui_hex": "00-D0-12",
        "organization": "GATEWORKS CORP.",
        "address_1": "7631 MORRO ROAD",
        "address_2": "ATASCADERO  CA  93422",
        "country": "US"
    },
    "00D04D": {
        "oui_hex": "00-D0-4D",
        "organization": "DIV OF RESEARCH & STATISTICS",
        "address_1": "BOG OF THE FEDERAL RESERVE SYS",
        "address_2": "WASHINGTON  DC  20551",
        "country": "US"
    },
    "00D02E": {
        "oui_hex": "00-D0-2E",
        "organization": "COMMUNICATION AUTOMATION CORP.",
        "address_1": "1180 MCDERMOTT DRIVE",
        "address_2": "WEST CHESTER  PA  19380",
        "country": "US"
    },
    "00D0C5": {
        "oui_hex": "00-D0-C5",
        "organization": "COMPUTATIONAL SYSTEMS, INC.",
        "address_1": "835 INNOVATION DRIVE",
        "address_2": "KNOXVILLE  TN  37932",
        "country": "US"
    },
    "00D046": {
        "oui_hex": "00-D0-46",
        "organization": "DOLBY LABORATORIES, INC.",
        "address_1": "100 Potrero Avenue",
        "address_2": "San Francisco  CA  94103-4938",
        "country": "US"
    },
    "00D0DE": {
        "oui_hex": "00-D0-DE",
        "organization": "PHILIPS MULTIMEDIA NETWORK",
        "address_1": "SYSTEMS GMBH",
        "address_2": "",
        "country": "DE"
    },
    "00D00C": {
        "oui_hex": "00-D0-0C",
        "organization": "SNIJDER MICRO SYSTEMS",
        "address_1": "P.O. BOX 300",
        "address_2": "  THE",
        "country": "NL"
    },
    "00D017": {
        "oui_hex": "00-D0-17",
        "organization": "SYNTECH INFORMATION CO., LTD.",
        "address_1": "8F, 210, TA-TUNG RD., SEC. 3",
        "address_2": "TAIWAN  TAIWAN  ROC",
        "country": "TW"
    },
    "00D036": {
        "oui_hex": "00-D0-36",
        "organization": "TECHNOLOGY ATLANTA CORP.",
        "address_1": "141 W. WIEUCA RD. N.E.",
        "address_2": "ATLANTA  GA  30342",
        "country": "US"
    },
    "00D0E3": {
        "oui_hex": "00-D0-E3",
        "organization": "ELE-CHEM ENGINEERING CO., LTD.",
        "address_1": "WINDSTONE OFFICE",
        "address_2": "SEOUL 137-130  SEOUL 137-130  KOREA",
        "country": "KR"
    },
    "00D0B6": {
        "oui_hex": "00-D0-B6",
        "organization": "CRESCENT NETWORKS, INC.",
        "address_1": "201 RIVERNECK ROAD",
        "address_2": "CHELMSFORD  MA  01842",
        "country": "US"
    },
    "00D0C4": {
        "oui_hex": "00-D0-C4",
        "organization": "TERATECH CORPORATION",
        "address_1": "223 MIDDLESEX TRPK.",
        "address_2": "BURLINGTON  MA  01803-3308",
        "country": "US"
    },
    "00D061": {
        "oui_hex": "00-D0-61",
        "organization": "TREMON ENTERPRISES CO., LTD.",
        "address_1": "15F, NO. 116, SEC. 1",
        "address_2": "TAIWAN  TAIWAN  ROC",
        "country": "TW"
    },
    "00D0E5": {
        "oui_hex": "00-D0-E5",
        "organization": "SOLIDUM SYSTEMS CORP.",
        "address_1": "940 BELFAST ROAD 1S.217",
        "address_2": "",
        "country": "CA"
    },
    "00D045": {
        "oui_hex": "00-D0-45",
        "organization": "KVASER AB",
        "address_1": "BOX 4076",
        "address_2": "",
        "country": "SE"
    },
    "00D004": {
        "oui_hex": "00-D0-04",
        "organization": "PENTACOM LTD.",
        "address_1": "8 HASADNAOT STREET",
        "address_2": "",
        "country": "IL"
    },
    "00D005": {
        "oui_hex": "00-D0-05",
        "organization": "ZHS ZEITMANAGEMENTSYSTEME",
        "address_1": "HARD-UND SOFTWARE GMBH",
        "address_2": "",
        "country": "DE"
    },
    "00D0D3": {
        "oui_hex": "00-D0-D3",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D026": {
        "oui_hex": "00-D0-26",
        "organization": "HIRSCHMANN AUSTRIA GMBH",
        "address_1": "OBERER PASPELSWEG 6 - 8",
        "address_2": "",
        "country": "AT"
    },
    "00D0DA": {
        "oui_hex": "00-D0-DA",
        "organization": "TAICOM DATA SYSTEMS CO., LTD.",
        "address_1": "45, WU-KUNG 5 ROAD",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00D03C": {
        "oui_hex": "00-D0-3C",
        "organization": "Vieo, Inc.",
        "address_1": "12416 Hymeadow Drive,",
        "address_2": "Austin  TX  78750",
        "country": "US"
    },
    "00D0B4": {
        "oui_hex": "00-D0-B4",
        "organization": "KATSUJIMA CO., LTD.",
        "address_1": "1-6-1, SHIRATORI",
        "address_2": "",
        "country": "JP"
    },
    "00D086": {
        "oui_hex": "00-D0-86",
        "organization": "FOVEON, INC.",
        "address_1": "2820 San Tomas Expressway",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "00D0A8": {
        "oui_hex": "00-D0-A8",
        "organization": "NETWORK ENGINES, INC.",
        "address_1": "61 PLEASANT STREET",
        "address_2": "RANDOLPH  MA  02368",
        "country": "US"
    },
    "00D0AB": {
        "oui_hex": "00-D0-AB",
        "organization": "DELTAKABEL TELECOM CV",
        "address_1": "HANZEWEG 14",
        "address_2": "  THE",
        "country": "NL"
    },
    "00D0E8": {
        "oui_hex": "00-D0-E8",
        "organization": "MAC SYSTEM CO., LTD.",
        "address_1": "R&D INSTITUTE",
        "address_2": "KYUNGKI-DO  KOREA,  430-017",
        "country": "KR"
    },
    "00D06B": {
        "oui_hex": "00-D0-6B",
        "organization": "SR TELECOM INC.",
        "address_1": "8150 Trans Canada Highway",
        "address_2": "Quebec    H4S 1M5",
        "country": "CA"
    },
    "00D0DC": {
        "oui_hex": "00-D0-DC",
        "organization": "MODULAR MINING SYSTEMS, INC.",
        "address_1": "3289 E. HEMISPHERE LOOP",
        "address_2": "TUCSON  AZ  85706",
        "country": "US"
    },
    "00D01E": {
        "oui_hex": "00-D0-1E",
        "organization": "PINGTEL CORP.",
        "address_1": "773 WINTER STREET",
        "address_2": "N. ANDOVER  MA  01845",
        "country": "US"
    },
    "00D0CA": {
        "oui_hex": "00-D0-CA",
        "organization": "Intrinsyc Software International Inc.",
        "address_1": "885 Dunsmuir Street, Suite 380",
        "address_2": "Vancouver  B.C.  V6C 1N5",
        "country": "CA"
    },
    "00D065": {
        "oui_hex": "00-D0-65",
        "organization": "TOKO ELECTRIC",
        "address_1": "4008 KUROHAMA, HASUDA-SHI",
        "address_2": "",
        "country": "JP"
    },
    "00D09A": {
        "oui_hex": "00-D0-9A",
        "organization": "FILANET CORPORATION",
        "address_1": "931 Benecia Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00D0AE": {
        "oui_hex": "00-D0-AE",
        "organization": "ORESIS COMMUNICATIONS, INC.",
        "address_1": "14670 NW GREENBRIER PKWY",
        "address_2": "BEAVERTON  OR  97006",
        "country": "US"
    },
    "00D0F2": {
        "oui_hex": "00-D0-F2",
        "organization": "MONTEREY NETWORKS",
        "address_1": "1909 N. GLENVILLE DRIVE",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "00D014": {
        "oui_hex": "00-D0-14",
        "organization": "ROOT, INC.",
        "address_1": "8F TOC2 Bldg, 7-21-11 Nishi-Gotanda",
        "address_2": "  Tokyo  141-0031",
        "country": "JP"
    },
    "00D023": {
        "oui_hex": "00-D0-23",
        "organization": "INFORTREND TECHNOLOGY, INC.",
        "address_1": "10F, NO. 33 SAN-MIN RD.",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00D0A2": {
        "oui_hex": "00-D0-A2",
        "organization": "INTEGRATED DEVICE",
        "address_1": "TECHNOLOGY, INC.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00D034": {
        "oui_hex": "00-D0-34",
        "organization": "ORMEC SYSTEMS CORP.",
        "address_1": "19 LINDEN PARK",
        "address_2": "ROCHESTER  NY  14625",
        "country": "US"
    },
    "00D08A": {
        "oui_hex": "00-D0-8A",
        "organization": "PHOTRON USA",
        "address_1": "1101 S. WINCHESTER BLVD.",
        "address_2": "SAN JOSE  CA  95128",
        "country": "US"
    },
    "00D0A7": {
        "oui_hex": "00-D0-A7",
        "organization": "TOKYO SOKKI KENKYUJO CO., LTD.",
        "address_1": "8-2, MINAMI-OHI 6-CHOME",
        "address_2": "  JAPAN  140-8560",
        "country": "JP"
    },
    "00D01D": {
        "oui_hex": "00-D0-1D",
        "organization": "FURUNO ELECTRIC CO., LTD.",
        "address_1": "NO. 9-52, ASHIHARA-CHO",
        "address_2": "  662-8580",
        "country": "JP"
    },
    "00504C": {
        "oui_hex": "00-50-4C",
        "organization": "Galil Motion Control",
        "address_1": "270 Technology Way",
        "address_2": "Rocklin  CA  95765",
        "country": "US"
    },
    "005076": {
        "oui_hex": "00-50-76",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "0050D4": {
        "oui_hex": "00-50-D4",
        "organization": "JOOHONG INFORMATION &",
        "address_1": "COMMUNICATIONS, LTD.",
        "address_2": "SEOUL  SEOUL  KOREA",
        "country": "KR"
    },
    "0050A6": {
        "oui_hex": "00-50-A6",
        "organization": "OPTRONICS",
        "address_1": "175 CREMONA DRIVE",
        "address_2": "GOLETA  CA  93117",
        "country": "US"
    },
    "0050A9": {
        "oui_hex": "00-50-A9",
        "organization": "MOLDAT WIRELESS TECHNOLGIES",
        "address_1": "3 SHIMON ISRAELI STREET",
        "address_2": "",
        "country": "IL"
    },
    "00509B": {
        "oui_hex": "00-50-9B",
        "organization": "SWITCHCORE AB",
        "address_1": "POSITIONEN 153",
        "address_2": "",
        "country": "SE"
    },
    "00507E": {
        "oui_hex": "00-50-7E",
        "organization": "NEWER TECHNOLOGY",
        "address_1": "4848 WEST IRVING ST.",
        "address_2": "WICHITA  KS  67209-2621",
        "country": "US"
    },
    "0050CE": {
        "oui_hex": "00-50-CE",
        "organization": "LG INTERNATIONAL CORP.",
        "address_1": "LG TWIN TOWERS",
        "address_2": "SEOUL,  150-606",
        "country": "KR"
    },
    "0050F7": {
        "oui_hex": "00-50-F7",
        "organization": "VENTURE MANUFACTURING (SINGAPORE) LTD.",
        "address_1": "",
        "address_2": "#05-01 Techplace II    569873",
        "country": "SG"
    },
    "005019": {
        "oui_hex": "00-50-19",
        "organization": "SPRING TIDE NETWORKS, INC.",
        "address_1": "85 SWANSON ROAD",
        "address_2": "BOXBOROUGH  MA  01719",
        "country": "US"
    },
    "0050FD": {
        "oui_hex": "00-50-FD",
        "organization": "VISIONCOMM CO., LTD.",
        "address_1": "4, 5F, DAEWON B/D",
        "address_2": "YONGSAN-GU, SEOUL",
        "country": "KR"
    },
    "0050BF": {
        "oui_hex": "00-50-BF",
        "organization": "Metalligence Technology Corp.",
        "address_1": "NO.9, PARK AVENUE II",
        "address_2": "HSIN-CHU",
        "country": "TW"
    },
    "005036": {
        "oui_hex": "00-50-36",
        "organization": "NETCAM, LTD.",
        "address_1": "6071 N. PASEO ZALDIVAR",
        "address_2": "TUCSON  AZ  85750",
        "country": "US"
    },
    "0050DB": {
        "oui_hex": "00-50-DB",
        "organization": "CONTEMPORARY CONTROL",
        "address_1": "SYSTEMS, INC.",
        "address_2": "DOWNERS GROVE  IL  60515",
        "country": "US"
    },
    "00507C": {
        "oui_hex": "00-50-7C",
        "organization": "VIDEOCON AG",
        "address_1": "ALBERT-SCHWEITZER-STR. 64",
        "address_2": "",
        "country": "DE"
    },
    "005047": {
        "oui_hex": "00-50-47",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "00D06C": {
        "oui_hex": "00-D0-6C",
        "organization": "SHAREWAVE, INC.",
        "address_1": "5175 HILLSDALE CIRCLE",
        "address_2": "EL DORADO HILLS  CA  95762",
        "country": "US"
    },
    "0050A7": {
        "oui_hex": "00-50-A7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "005055": {
        "oui_hex": "00-50-55",
        "organization": "DOMS A/S",
        "address_1": "FORMERVANGEN 28",
        "address_2": "",
        "country": "DK"
    },
    "005072": {
        "oui_hex": "00-50-72",
        "organization": "CORVIS CORPORATION",
        "address_1": "8320 GUILFORD ROAD",
        "address_2": "COLUMBIA  MD  21046",
        "country": "US"
    },
    "00D0EE": {
        "oui_hex": "00-D0-EE",
        "organization": "DICTAPHONE CORPORATION",
        "address_1": "3191 BROADBRIDGE AVE.",
        "address_2": "STRATFORD  CT  06614-2559",
        "country": "US"
    },
    "00501B": {
        "oui_hex": "00-50-1B",
        "organization": "ABL CANADA, INC.",
        "address_1": "8550 COTE DE LIESSE",
        "address_2": "ST-LAURENT (QUEBEC) H4T 1H2",
        "country": "CA"
    },
    "009057": {
        "oui_hex": "00-90-57",
        "organization": "AANetcom, Inc.",
        "address_1": "4949 LIBERTY LANE - STE. #200",
        "address_2": "ALLENTOWN  PA  18106-9015",
        "country": "US"
    },
    "009083": {
        "oui_hex": "00-90-83",
        "organization": "TURBO COMMUNICATION, INC.",
        "address_1": "4F-2, NO. 171, SUNG-TEH ROAD",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "00903D": {
        "oui_hex": "00-90-3D",
        "organization": "BIOPAC SYSTEMS, INC.",
        "address_1": "42 AERO CAMINO",
        "address_2": "SANTA BARBARA  CA  93117",
        "country": "US"
    },
    "0090D7": {
        "oui_hex": "00-90-D7",
        "organization": "NetBoost Corp.",
        "address_1": "390 CAMBRIDGE AVENUE",
        "address_2": "PALO ALTO  CA  94306-1506",
        "country": "US"
    },
    "005083": {
        "oui_hex": "00-50-83",
        "organization": "GILBARCO, INC.",
        "address_1": "POB 22087",
        "address_2": "GREENSBORO  NC  27420",
        "country": "US"
    },
    "0050DC": {
        "oui_hex": "00-50-DC",
        "organization": "TAS TELEFONBAU A. SCHWABE GMBH & CO. KG",
        "address_1": "",
        "address_2": "D-41238 MONCHENGLADBACH",
        "country": "DE"
    },
    "005008": {
        "oui_hex": "00-50-08",
        "organization": "TIVA MICROCOMPUTER CORP. (TMC)",
        "address_1": "48550 FREMONT BLVD.",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "005052": {
        "oui_hex": "00-50-52",
        "organization": "TIARA NETWORKS, INC.",
        "address_1": "113 FOORIER AVENUE",
        "address_2": "FREMONT  CA  94539",
        "country": "US"
    },
    "005027": {
        "oui_hex": "00-50-27",
        "organization": "GENICOM CORPORATION",
        "address_1": "900 CLOPPER ROAD - STE. #110",
        "address_2": "GAITHERSBURG  MD  20878",
        "country": "US"
    },
    "00505A": {
        "oui_hex": "00-50-5A",
        "organization": "NETWORK ALCHEMY, INC.",
        "address_1": "1521.5 PACIFIC AVENUE",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "005039": {
        "oui_hex": "00-50-39",
        "organization": "MARINER NETWORKS",
        "address_1": "1585 S. MANCHESTER AVE.",
        "address_2": "ANAHEIM  CA  92802-2907",
        "country": "US"
    },
    "005064": {
        "oui_hex": "00-50-64",
        "organization": "CAE ELECTRONICS",
        "address_1": "P.O. BOX 1800",
        "address_2": "ST. LAURENT, QUEBEC H4L 4X4",
        "country": "CA"
    },
    "0050B8": {
        "oui_hex": "00-50-B8",
        "organization": "INOVA COMPUTERS GMBH & CO. KG",
        "address_1": "SUDETENSTRASSE 5",
        "address_2": "87600 KAUFBEUREN",
        "country": "DE"
    },
    "00505B": {
        "oui_hex": "00-50-5B",
        "organization": "KAWASAKI LSI U.S.A., INC.",
        "address_1": "2570 NORTHFIRST STREET",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0050CC": {
        "oui_hex": "00-50-CC",
        "organization": "Seagate Cloud Systems Inc",
        "address_1": "1351 S Sunset Street",
        "address_2": "Longmont  CO  80501",
        "country": "US"
    },
    "005016": {
        "oui_hex": "00-50-16",
        "organization": "Molex Canada Ltd",
        "address_1": "216 Bathurst Drive",
        "address_2": "Waterloo  Ontario  N2V 2L7",
        "country": "CA"
    },
    "00501F": {
        "oui_hex": "00-50-1F",
        "organization": "MRG SYSTEMS, LTD.",
        "address_1": "WILLOW HOUSE, SLAD ROAD",
        "address_2": "GLOS.  GL5 1QG England",
        "country": "GB"
    },
    "005043": {
        "oui_hex": "00-50-43",
        "organization": "MARVELL SEMICONDUCTOR, INC.",
        "address_1": "645 ALMANOR AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "005095": {
        "oui_hex": "00-50-95",
        "organization": "PERACOM NETWORKS",
        "address_1": "13000 WESTON PARKWAY",
        "address_2": "CARY  NC  27513",
        "country": "US"
    },
    "0050FA": {
        "oui_hex": "00-50-FA",
        "organization": "OXTEL, LTD.",
        "address_1": "THE MARKET PLACE",
        "address_2": "0X11 7LE England",
        "country": "GB"
    },
    "009038": {
        "oui_hex": "00-90-38",
        "organization": "FOUNTAIN TECHNOLOGIES, INC.",
        "address_1": "50 RANDOLPH ROAD",
        "address_2": "SOMERSET  NJ  08873",
        "country": "US"
    },
    "0090B0": {
        "oui_hex": "00-90-B0",
        "organization": "VADEM",
        "address_1": "1960 ZANKER RD",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "0090EF": {
        "oui_hex": "00-90-EF",
        "organization": "INTEGRIX, INC.",
        "address_1": "2001 CORPORATE CENTER DRIVE",
        "address_2": "NEWBURY PARK  CA  91320",
        "country": "US"
    },
    "0090C5": {
        "oui_hex": "00-90-C5",
        "organization": "INTERNET MAGIC, INC.",
        "address_1": "6450 LUSK BLVD.-STE. #E-201",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00908C": {
        "oui_hex": "00-90-8C",
        "organization": "ETREND ELECTRONICS, INC.",
        "address_1": "2F, 22 INDUSTRY E. 9TH ROAD",
        "address_2": "",
        "country": "TW"
    },
    "009048": {
        "oui_hex": "00-90-48",
        "organization": "ZEAL CORPORATION",
        "address_1": "301, HIRAIKE",
        "address_2": "NAGAKUTE-CHO, AICHI-PREF. 480-1155",
        "country": "JP"
    },
    "0090B9": {
        "oui_hex": "00-90-B9",
        "organization": "BERAN INSTRUMENTS LTD.",
        "address_1": "HATCHMOOR INDUSTRIAL ESTATE",
        "address_2": "N DEVON EX38 7HP",
        "country": "GB"
    },
    "0090C4": {
        "oui_hex": "00-90-C4",
        "organization": "JAVELIN SYSTEMS, INC.",
        "address_1": "1881 LANGLEY AVE.",
        "address_2": "IRVINE  CA  92614",
        "country": "US"
    },
    "0090A5": {
        "oui_hex": "00-90-A5",
        "organization": "SPECTRA LOGIC",
        "address_1": "1700 N. 55TH STREET",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "0090A3": {
        "oui_hex": "00-90-A3",
        "organization": "Corecess Inc.",
        "address_1": "135-726, Keopyung B-Town 1F, 203, Nonhyu",
        "address_2": "Seoul",
        "country": "KR"
    },
    "009082": {
        "oui_hex": "00-90-82",
        "organization": "FORCE INSTITUTE",
        "address_1": "PARK ALLE 345",
        "address_2": "DK-2605 BROENDBY",
        "country": "DK"
    },
    "009000": {
        "oui_hex": "00-90-00",
        "organization": "DIAMOND MULTIMEDIA",
        "address_1": "312 SE STONEMILL DRIVE",
        "address_2": "VANCOUVER  WA  98684",
        "country": "US"
    },
    "00906E": {
        "oui_hex": "00-90-6E",
        "organization": "PRAXON, INC.",
        "address_1": "1700 DELL AVENUE",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "009054": {
        "oui_hex": "00-90-54",
        "organization": "INNOVATIVE SEMICONDUCTORS, INC",
        "address_1": "2570 W. EL CAMINO REAL",
        "address_2": "MOUNTAIN VIEW  CA  94040",
        "country": "US"
    },
    "009061": {
        "oui_hex": "00-90-61",
        "organization": "PACIFIC RESEARCH & ENGINEERING CORPORATION",
        "address_1": "2070 LAS PALMAS DRIVE",
        "address_2": "CARLSBAD  CA  92009",
        "country": "US"
    },
    "00900B": {
        "oui_hex": "00-90-0B",
        "organization": "LANNER ELECTRONICS, INC.",
        "address_1": "8F-4, NO. 77, SEC. 1",
        "address_2": "  TAIPEI HSIEN",
        "country": "TW"
    },
    "0090CE": {
        "oui_hex": "00-90-CE",
        "organization": " avateramedical Mechatronics GmbH",
        "address_1": "Gewerbepark „Am Wald“ 4",
        "address_2": " ILMENAU    D-98693",
        "country": "DE"
    },
    "009007": {
        "oui_hex": "00-90-07",
        "organization": "DOMEX TECHNOLOGY CORP.",
        "address_1": "NO. 2, TECHNOLOGY RD. 1",
        "address_2": " HSINCHU",
        "country": "TW"
    },
    "00902D": {
        "oui_hex": "00-90-2D",
        "organization": "DATA ELECTRONICS (AUST.) PTY, LTD.",
        "address_1": "7 SEISMIC COURT",
        "address_2": "VICTORIA 3178",
        "country": "AU"
    },
    "0090D4": {
        "oui_hex": "00-90-D4",
        "organization": "BindView Development Corp.",
        "address_1": "3355 WEST ALABAMA #1200",
        "address_2": "HOUSTON  TX  77098",
        "country": "US"
    },
    "009029": {
        "oui_hex": "00-90-29",
        "organization": "CRYPTO AG",
        "address_1": "P.O. BOX",
        "address_2": "CH-6301 Zug",
        "country": "CH"
    },
    "0090DF": {
        "oui_hex": "00-90-DF",
        "organization": "MITSUBISHI CHEMICAL AMERICA, INC.",
        "address_1": "445 INDIO WAY",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0090C0": {
        "oui_hex": "00-90-C0",
        "organization": "K.J. LAW ENGINEERS, INC.",
        "address_1": "42300 W. NINE MILE ROAD",
        "address_2": "NOVI  MI  48375",
        "country": "US"
    },
    "00901F": {
        "oui_hex": "00-90-1F",
        "organization": "ADTEC PRODUCTIONS, INC.",
        "address_1": "408 RUSSELL STREET",
        "address_2": "NASHVILLE  TN  37206",
        "country": "US"
    },
    "009024": {
        "oui_hex": "00-90-24",
        "organization": "PIPELINKS, INC.",
        "address_1": "2710 WALSH AVE., STE #300",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "00903A": {
        "oui_hex": "00-90-3A",
        "organization": "NIHON MEDIA TOOL INC.",
        "address_1": "1875 OYAMA-CHO",
        "address_2": "MIE 512-1102",
        "country": "JP"
    },
    "0090B2": {
        "oui_hex": "00-90-B2",
        "organization": "AVICI SYSTEMS INC.",
        "address_1": "12 ELIZABETH DRIVE",
        "address_2": "CHELMSFORD  MA  01824",
        "country": "US"
    },
    "0090B6": {
        "oui_hex": "00-90-B6",
        "organization": "FIBEX SYSTEMS",
        "address_1": "5350 OLD REDWOOD HIGHWAY",
        "address_2": "PETALUMA  CA  94954",
        "country": "US"
    },
    "009063": {
        "oui_hex": "00-90-63",
        "organization": "COHERENT COMMUNICATIONS SYSTEMS CORPORATION",
        "address_1": "45085 UNIVERSITY DRIVE",
        "address_2": "ASHBURN  VA  20147",
        "country": "US"
    },
    "009062": {
        "oui_hex": "00-90-62",
        "organization": "ICP VORTEX COMPUTERSYSTEME GmbH",
        "address_1": "FALTERSTRASSE 51-53",
        "address_2": "D 74223 FLEIN",
        "country": "DE"
    },
    "0010D3": {
        "oui_hex": "00-10-D3",
        "organization": "GRIPS ELECTRONIC GMBH",
        "address_1": "NIESENBERGERGASSE 37",
        "address_2": "A-8020 GRAZ",
        "country": "AT"
    },
    "0010FB": {
        "oui_hex": "00-10-FB",
        "organization": "ZIDA TECHNOLOGIES LIMITED",
        "address_1": "8/F BLOCK A  GOODVIEW INDUSTRIAL BUILDIN",
        "address_2": "TUEN MUN NT",
        "country": "HK"
    },
    "001053": {
        "oui_hex": "00-10-53",
        "organization": "COMPUTER TECHNOLOGY CORP.",
        "address_1": "50 W. TECHNECENTER DRIVE",
        "address_2": "MILFORD  OH  45150",
        "country": "US"
    },
    "0010ED": {
        "oui_hex": "00-10-ED",
        "organization": "SUNDANCE TECHNOLOGY, INC.",
        "address_1": "20111 STEVENS CREEK BLVD.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00106C": {
        "oui_hex": "00-10-6C",
        "organization": "EDNT GmbH",
        "address_1": "Werner-von-Siemens-Str. 7",
        "address_2": "64625  Bensheim",
        "country": "DE"
    },
    "0010E9": {
        "oui_hex": "00-10-E9",
        "organization": "RAIDTEC LTD.",
        "address_1": "CASTLE ROAD",
        "address_2": "Little Island  County Cork",
        "country": "IE"
    },
    "001003": {
        "oui_hex": "00-10-03",
        "organization": "IMATRON, INC.",
        "address_1": "389 OYSTER POINT BLVD.",
        "address_2": "SO. SAN FRANCISCO  CA  94080",
        "country": "US"
    },
    "001071": {
        "oui_hex": "00-10-71",
        "organization": "ADVANET INC.",
        "address_1": "3-20-8 NODA",
        "address_2": "  OKAYAMI 700",
        "country": "JP"
    },
    "009015": {
        "oui_hex": "00-90-15",
        "organization": "CENTIGRAM COMMUNICATIONS CORP.",
        "address_1": "91 EAST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "009095": {
        "oui_hex": "00-90-95",
        "organization": "UNIVERSAL AVIONICS",
        "address_1": "11351 WILLOWS ROAD NE",
        "address_2": "REDMOND  WA  98052-2552",
        "country": "US"
    },
    "009041": {
        "oui_hex": "00-90-41",
        "organization": "APPLIED DIGITAL ACCESS",
        "address_1": "9855 SCRANTON ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00905A": {
        "oui_hex": "00-90-5A",
        "organization": "DEARBORN GROUP, INC.",
        "address_1": "33604 West 8 Mile Rd",
        "address_2": "Farmington Hills  MI  48335",
        "country": "US"
    },
    "009011": {
        "oui_hex": "00-90-11",
        "organization": "WAVTrace, Inc.",
        "address_1": "1555 132ND AVE. NE",
        "address_2": "BELLEVUE  WA  98005",
        "country": "US"
    },
    "009065": {
        "oui_hex": "00-90-65",
        "organization": "FINISAR CORPORATION",
        "address_1": "1389 Moffett Park Dr",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "009023": {
        "oui_hex": "00-90-23",
        "organization": "ZILOG INC.",
        "address_1": "910 East Hamilton Ave.",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "0090F6": {
        "oui_hex": "00-90-F6",
        "organization": "ESCALATE NETWORKS, INC.",
        "address_1": "6 HUGHES",
        "address_2": "IRVINE  CA  92617",
        "country": "US"
    },
    "0090A8": {
        "oui_hex": "00-90-A8",
        "organization": "NineTiles Networks, Ltd.",
        "address_1": "9 Station Road",
        "address_2": "Waterbeach  Cambridge  CB5 9HT",
        "country": "GB"
    },
    "00102A": {
        "oui_hex": "00-10-2A",
        "organization": "ZF MICROSYSTEMS, INC.",
        "address_1": "1052 ELWELL COURT",
        "address_2": "PALO ALTO  CA  94303-4307",
        "country": "US"
    },
    "0010E5": {
        "oui_hex": "00-10-E5",
        "organization": "SOLECTRON TEXAS",
        "address_1": "12455 RESEARCH BLVD. M/S 2205",
        "address_2": "AUSTIN  TX  78759",
        "country": "US"
    },
    "00109D": {
        "oui_hex": "00-10-9D",
        "organization": "CLARINET SYSTEMS, INC.",
        "address_1": "1415 KOLL CIRCLE #101",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "00100E": {
        "oui_hex": "00-10-0E",
        "organization": "MICRO LINEAR COPORATION",
        "address_1": "2092 CONCOURSE DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0090EC": {
        "oui_hex": "00-90-EC",
        "organization": "PYRESCOM",
        "address_1": "3 ALLEE DU MOULIN",
        "address_2": "66680 CANOHES",
        "country": "FR"
    },
    "0090C3": {
        "oui_hex": "00-90-C3",
        "organization": "TOPIC SEMICONDUCTOR CORP.",
        "address_1": "11F-1, NO. 2, WU-LIN RD.",
        "address_2": "HSIN-CHU",
        "country": "TW"
    },
    "0010C8": {
        "oui_hex": "00-10-C8",
        "organization": "COMMUNICATIONS ELECTRONICS SECURITY GROUP",
        "address_1": "10/4W22 FIDDLERS GREEN LANE",
        "address_2": "Benhall, Cheltenham  Glouster GL52 5AJ",
        "country": "GB"
    },
    "0010F3": {
        "oui_hex": "00-10-F3",
        "organization": "Nexcom International Co., Ltd.",
        "address_1": "18F, No. 716, Chung-Cheng Road,",
        "address_2": "Taipei Hsien 235,",
        "country": "TW"
    },
    "001086": {
        "oui_hex": "00-10-86",
        "organization": "ATTO Technology, Inc.",
        "address_1": "155 Crosspoint Pkwy.",
        "address_2": "Amherst  NY  14068",
        "country": "US"
    },
    "0010DF": {
        "oui_hex": "00-10-DF",
        "organization": "RISE COMPUTER INC.",
        "address_1": "9F, NO. 306-3, TATUNG RD.",
        "address_2": "TAIPEI HSIEN",
        "country": "TW"
    },
    "001072": {
        "oui_hex": "00-10-72",
        "organization": "GVN TECHNOLOGIES, INC.",
        "address_1": "8200 BRYAN DAIRY ROAD",
        "address_2": "LARGO  FL  33777",
        "country": "US"
    },
    "0010DA": {
        "oui_hex": "00-10-DA",
        "organization": "Kollmorgen Corp",
        "address_1": "33 S.LA PATERA LN",
        "address_2": "SANTA BARBARA  CA  93117",
        "country": "US"
    },
    "0010E4": {
        "oui_hex": "00-10-E4",
        "organization": "NSI CORPORATION",
        "address_1": "P.O. BOX 635",
        "address_2": "WILSONVILLE  OR  97070",
        "country": "US"
    },
    "00107E": {
        "oui_hex": "00-10-7E",
        "organization": "BACHMANN ELECTRONIC GmbH",
        "address_1": "KREUZAECKERWEG 33",
        "address_2": "A 6806 FELDKIRCH",
        "country": "AT"
    },
    "0010A0": {
        "oui_hex": "00-10-A0",
        "organization": "INNOVEX TECHNOLOGIES, INC.",
        "address_1": "KEYSTONE COMMONS",
        "address_2": "TURTLE CREEK  PA  15145",
        "country": "US"
    },
    "001016": {
        "oui_hex": "00-10-16",
        "organization": "T.SQWARE",
        "address_1": "6, PARC ARIANE",
        "address_2": "78284 GUYANCOURT CEDEX",
        "country": "FR"
    },
    "001090": {
        "oui_hex": "00-10-90",
        "organization": "CIMETRICS, INC.",
        "address_1": "55 TEMPLE PLACE",
        "address_2": "BOSTON  MA  02111",
        "country": "US"
    },
    "0010F5": {
        "oui_hex": "00-10-F5",
        "organization": "AMHERST SYSTEMS, INC.",
        "address_1": "30 WILSON ROAD",
        "address_2": "BUFFALO  NY  14221",
        "country": "US"
    },
    "00103D": {
        "oui_hex": "00-10-3D",
        "organization": "PHASECOM, LTD.",
        "address_1": "P.O. BOX 45017",
        "address_2": "JERUSALEM 91450",
        "country": "IL"
    },
    "001096": {
        "oui_hex": "00-10-96",
        "organization": "TRACEWELL SYSTEMS, INC.",
        "address_1": "567 ENTERPRISE DRIVE",
        "address_2": "WESTERVILLE  OH  43081",
        "country": "US"
    },
    "001082": {
        "oui_hex": "00-10-82",
        "organization": "JNA TELECOMMUNICATIONS LIMITED",
        "address_1": "16 SMITH ST, CHATSWOOD",
        "address_2": "  NSW 2067",
        "country": "AU"
    },
    "001098": {
        "oui_hex": "00-10-98",
        "organization": "STARNET TECHNOLOGIES, INC.",
        "address_1": "2210 O'TOOLE AVE.",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "001042": {
        "oui_hex": "00-10-42",
        "organization": "Alacritech, Inc.",
        "address_1": "1995 N. First Street",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "001068": {
        "oui_hex": "00-10-68",
        "organization": "COMOS TELECOM",
        "address_1": "SAEHAN B/D/, 27-1 SUPYO-DONG",
        "address_2": "CHUNG-GU,  SEOUL (100-230)",
        "country": "KR"
    },
    "0010EA": {
        "oui_hex": "00-10-EA",
        "organization": "ADEPT TECHNOLOGY",
        "address_1": "150 ROSE ORCHARD WAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0010AE": {
        "oui_hex": "00-10-AE",
        "organization": "SHINKO ELECTRIC INDUSTRIES CO.",
        "address_1": "80 OSHIMADA-MACHI",
        "address_2": "NAGANO-SHI 381-22",
        "country": "JP"
    },
    "0010C4": {
        "oui_hex": "00-10-C4",
        "organization": "MEDIA GLOBAL LINKS CO., LTD.",
        "address_1": "580-16, horikawa-cho,saiwai-ku",
        "address_2": "Kawasaki, Kanagawa 212-0013",
        "country": "JP"
    },
    "0010FE": {
        "oui_hex": "00-10-FE",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "301 ROCKRIMMON BLVD, SOUTH",
        "address_2": "COLORADO SPRINGS  CO  80919",
        "country": "US"
    },
    "001056": {
        "oui_hex": "00-10-56",
        "organization": "SODICK CO., LTD.",
        "address_1": "3-12-1 NAKAMACHIDAI",
        "address_2": "TSUZUKI-KU, YOKOHAMA  KANAGAWA 224",
        "country": "JP"
    },
    "0010CD": {
        "oui_hex": "00-10-CD",
        "organization": "INTERFACE CONCEPT",
        "address_1": "3 VENELLE de KERGOS",
        "address_2": "29000 QUIMPER",
        "country": "FR"
    },
    "001061": {
        "oui_hex": "00-10-61",
        "organization": "HOSTLINK CORP.",
        "address_1": "10F-1, NO. 181",
        "address_2": "HSI-CHIH, TAIPEI",
        "country": "TW"
    },
    "001099": {
        "oui_hex": "00-10-99",
        "organization": "InnoMedia, Inc.",
        "address_1": "4800 GREAT AMERICA PARKWAY",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0010E1": {
        "oui_hex": "00-10-E1",
        "organization": "S.I. TECH, INC.",
        "address_1": "P.O. BOX 609",
        "address_2": "GENEVA  IL  60134",
        "country": "US"
    },
    "0010BB": {
        "oui_hex": "00-10-BB",
        "organization": "DATA & INFORMATION TECHNOLOGY",
        "address_1": "TECHNOLOGY HOUSE",
        "address_2": "BOTTESFORD, NOTTINGHAM NG13 OEL",
        "country": "GB"
    },
    "001020": {
        "oui_hex": "00-10-20",
        "organization": "Hand Held Products Inc",
        "address_1": "700 Visions Drive",
        "address_2": "Skaneateles Falls  NY  13153-0208",
        "country": "US"
    },
    "00103A": {
        "oui_hex": "00-10-3A",
        "organization": "DIAMOND NETWORK TECH",
        "address_1": "P.O. BOX 84525",
        "address_2": "GREENSIDE 2034",
        "country": "ZA"
    },
    "001004": {
        "oui_hex": "00-10-04",
        "organization": "THE BRANTLEY COILE COMPANY,INC",
        "address_1": "545 RESEARCH DRIVE",
        "address_2": "ATHENS  GA  30605",
        "country": "US"
    },
    "0010EF": {
        "oui_hex": "00-10-EF",
        "organization": "DBTEL INCORPORATED",
        "address_1": "NO.29 TZU-CHIANG ST.,",
        "address_2": "TU-CHENG TAIPEI",
        "country": "TW"
    },
    "001088": {
        "oui_hex": "00-10-88",
        "organization": "AMERICAN NETWORKS INC.",
        "address_1": "6800 ORANGETHORPE AVE. #A",
        "address_2": "BUENA PARK  CA  90620",
        "country": "US"
    },
    "001022": {
        "oui_hex": "00-10-22",
        "organization": "SatCom Media Corporation",
        "address_1": "3255-7 SCOTT BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "001076": {
        "oui_hex": "00-10-76",
        "organization": "EUREM GmbH",
        "address_1": "JULICHER STR. 338B",
        "address_2": "D-52070 AACHEN",
        "country": "DE"
    },
    "00103F": {
        "oui_hex": "00-10-3F",
        "organization": "TOLLGRADE COMMUNICATIONS, INC.",
        "address_1": "493 NIXON ROAD",
        "address_2": "CHESWICK  PA  15024",
        "country": "US"
    },
    "001049": {
        "oui_hex": "00-10-49",
        "organization": "ShoreTel, Inc",
        "address_1": "960 Stewart Drive",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "00105E": {
        "oui_hex": "00-10-5E",
        "organization": "Spirent plc, Service Assurance Broadband",
        "address_1": "5280 Corporate Dr",
        "address_2": "Ballenger Creek  MD  21703",
        "country": "US"
    },
    "0010AF": {
        "oui_hex": "00-10-AF",
        "organization": "TAC SYSTEMS, INC.",
        "address_1": "1035 PUTMAN DRIVE--STE.",
        "address_2": "HUNTSVILLE  AL  35816-2271",
        "country": "US"
    },
    "00108C": {
        "oui_hex": "00-10-8C",
        "organization": "Fujitsu Services Ltd",
        "address_1": "SOLIHULL PARKWAY",
        "address_2": "BIRMINGHAM B37 7YU  England  0000",
        "country": "GB"
    },
    "0010F7": {
        "oui_hex": "00-10-F7",
        "organization": "IRIICHI TECHNOLOGIES Inc.",
        "address_1": "1-26-7 CHUO, NAKANA-KU",
        "address_2": " TOKYO 164",
        "country": "JP"
    },
    "0010AB": {
        "oui_hex": "00-10-AB",
        "organization": "KOITO ELECTRIC INDUSTRIES, LTD.",
        "address_1": "100 MAEDA-CHO, TOTSUKA-KU",
        "address_2": "YOKOHAMA 244  KANAGAWA  244-8569",
        "country": "JP"
    },
    "001010": {
        "oui_hex": "00-10-10",
        "organization": "INITIO CORPORATION",
        "address_1": "2188 B DEL FRANCO STREET",
        "address_2": "SAN JOSE  CA  95118",
        "country": "US"
    },
    "0010F2": {
        "oui_hex": "00-10-F2",
        "organization": "ANTEC",
        "address_1": "4920 AVALON RIDGE PKWY",
        "address_2": "NORCROSS  GA  30071",
        "country": "US"
    },
    "00E007": {
        "oui_hex": "00-E0-07",
        "organization": "Avaya ECS Ltd",
        "address_1": "Unit 1 Sterling Court, Mundells",
        "address_2": "Welwyn Garden City  Hert  AL7 1LZ",
        "country": "GB"
    },
    "0010BE": {
        "oui_hex": "00-10-BE",
        "organization": "MARCH NETWORKS CORPORATION",
        "address_1": "303 Terry Fox Drive",
        "address_2": "OTTAWA, ONTARIO    K2K 3J1",
        "country": "CA"
    },
    "001058": {
        "oui_hex": "00-10-58",
        "organization": "ArrowPoint Communications",
        "address_1": "235 LITTLETON ROAD",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "00100F": {
        "oui_hex": "00-10-0F",
        "organization": "INDUSTRIAL CPU SYSTEMS",
        "address_1": "111-D W. DYER ROAD",
        "address_2": "SANTA ANA  CA  92707",
        "country": "US"
    },
    "0010BC": {
        "oui_hex": "00-10-BC",
        "organization": "Aastra Telecom",
        "address_1": "8 Federal Street",
        "address_2": "Billerica  MA  01821-3570",
        "country": "US"
    },
    "00E0BF": {
        "oui_hex": "00-E0-BF",
        "organization": "TORRENT NETWORKING TECHNOLOGIES CORP.",
        "address_1": "8181 PROFESSIONAL PLACE",
        "address_2": "LANDOVER  MD  20785",
        "country": "US"
    },
    "00E0E3": {
        "oui_hex": "00-E0-E3",
        "organization": "SK-ELEKTRONIK GMBH",
        "address_1": "HEMMELRATHERWEG 201",
        "address_2": "51377 LEVERKUSEN",
        "country": "DE"
    },
    "00E0C6": {
        "oui_hex": "00-E0-C6",
        "organization": "LINK2IT, L.L.C.",
        "address_1": "4256 BECK AVENUE",
        "address_2": "STUDIO CITY  CA  91604",
        "country": "US"
    },
    "00E0E5": {
        "oui_hex": "00-E0-E5",
        "organization": "CINCO NETWORKS, INC.",
        "address_1": "6601 KOLL CENTER PARK WAY",
        "address_2": "PLEASANTON  CA  94566",
        "country": "US"
    },
    "00E061": {
        "oui_hex": "00-E0-61",
        "organization": "EdgePoint Networks, Inc.",
        "address_1": "2238 MARTIN AVENUE",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "00E053": {
        "oui_hex": "00-E0-53",
        "organization": "CELLPORT LABS, INC.",
        "address_1": "885 ARAPAHOE AVE.,",
        "address_2": "BOULDER  CO  80302",
        "country": "US"
    },
    "00E0D3": {
        "oui_hex": "00-E0-D3",
        "organization": "DATENTECHNIK GmbH",
        "address_1": "THERESIANUMGASSE 11",
        "address_2": "A-1040 WIEN",
        "country": "AT"
    },
    "00E043": {
        "oui_hex": "00-E0-43",
        "organization": "VitalCom",
        "address_1": "15222 DEL AMO AVE.",
        "address_2": "TUSTIN  CA  92780",
        "country": "US"
    },
    "00E0B3": {
        "oui_hex": "00-E0-B3",
        "organization": "EtherWAN Systems, Inc.",
        "address_1": "14 HUGHES,  STE.B-105",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "00E0ED": {
        "oui_hex": "00-E0-ED",
        "organization": "SILICOM, LTD.",
        "address_1": "8 HANAGER ST.",
        "address_2": "KFAR-SAVA 44000",
        "country": "IL"
    },
    "00E0B8": {
        "oui_hex": "00-E0-B8",
        "organization": "GATEWAY 2000",
        "address_1": "610 GATEWAY DRIVE",
        "address_2": "N. SIOUX CITY  SD  57049",
        "country": "US"
    },
    "00E07C": {
        "oui_hex": "00-E0-7C",
        "organization": "METTLER-TOLEDO, INC.",
        "address_1": "1150 DEARBORN DRIVE",
        "address_2": "WORTHINGTON  OH  43085",
        "country": "US"
    },
    "00E026": {
        "oui_hex": "00-E0-26",
        "organization": "Redlake MASD LLC",
        "address_1": "3440 E. Pritannia Dr.",
        "address_2": "Tuscon  AZ  85706",
        "country": "US"
    },
    "00E020": {
        "oui_hex": "00-E0-20",
        "organization": "TECNOMEN OY",
        "address_1": "P.O. BOX 93",
        "address_2": "FIN-02271 ESPOO",
        "country": "FI"
    },
    "00E00D": {
        "oui_hex": "00-E0-0D",
        "organization": "RADIANT SYSTEMS",
        "address_1": "1000 ALDERMAN DR.",
        "address_2": "ALPHARETTA  GA  30202",
        "country": "US"
    },
    "00E0DC": {
        "oui_hex": "00-E0-DC",
        "organization": "NEXWARE CORP.",
        "address_1": "825 STEWART DR.,  STE #4",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00E037": {
        "oui_hex": "00-E0-37",
        "organization": "CENTURY CORPORATION",
        "address_1": "2-28-5, Taito",
        "address_2": "TAITO-KU,  TOKYO  101",
        "country": "JP"
    },
    "00E0C2": {
        "oui_hex": "00-E0-C2",
        "organization": "NECSY S.p.A.",
        "address_1": "VIA LISBONA 28",
        "address_2": "35020 PADOVA",
        "country": "IT"
    },
    "00E0FB": {
        "oui_hex": "00-E0-FB",
        "organization": "LEIGHTRONIX, INC.",
        "address_1": "2330 JARCO DR.",
        "address_2": "HOLT  MI  48842",
        "country": "US"
    },
    "00E09B": {
        "oui_hex": "00-E0-9B",
        "organization": "ENGAGE NETWORKS, INC.",
        "address_1": "316 N. MILWAUKEE ST., STE.#214",
        "address_2": "MILWAUKEE  WI  53202",
        "country": "US"
    },
    "00E045": {
        "oui_hex": "00-E0-45",
        "organization": "TOUCHWAVE, INC.",
        "address_1": "Maglebjergvej 5B",
        "address_2": "DK-2800 Lyngby",
        "country": "DK"
    },
    "00E040": {
        "oui_hex": "00-E0-40",
        "organization": "DeskStation Technology, Inc.",
        "address_1": "15729 COLLEGE BLVD.",
        "address_2": "LENEXA  KS  66219",
        "country": "US"
    },
    "00E01A": {
        "oui_hex": "00-E0-1A",
        "organization": "COMTEC SYSTEMS. CO., LTD.",
        "address_1": "404-9 CHOUNGCHEN-DONG",
        "address_2": "BUPYOUNG-KU, INCHON",
        "country": "KR"
    },
    "00E078": {
        "oui_hex": "00-E0-78",
        "organization": "BERKELEY NETWORKS",
        "address_1": "683 RIVER OAKS PARKWAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00E087": {
        "oui_hex": "00-E0-87",
        "organization": "LeCroy - Networking Productions Division",
        "address_1": "25 BURLINGTON MALL ROAD",
        "address_2": "BURLINGTON  MA  01803",
        "country": "US"
    },
    "00E041": {
        "oui_hex": "00-E0-41",
        "organization": "CSPI",
        "address_1": "43 Manning Rd.",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "00E0E2": {
        "oui_hex": "00-E0-E2",
        "organization": "INNOVA CORP.",
        "address_1": "3325 SOUTH 116TH STREET",
        "address_2": "SEATTLE  WA  98168",
        "country": "US"
    },
    "00E081": {
        "oui_hex": "00-E0-81",
        "organization": "TYAN COMPUTER CORP.",
        "address_1": "3288 LAUREVIEW CT",
        "address_2": "Fremont  CA  95035",
        "country": "US"
    },
    "00E057": {
        "oui_hex": "00-E0-57",
        "organization": "HAN MICROTELECOM. CO., LTD.",
        "address_1": "FASHION BD., 3RD FR,",
        "address_2": "DONG SEO-GU, TAEJON  KOREA 302-173",
        "country": "KR"
    },
    "00E0BC": {
        "oui_hex": "00-E0-BC",
        "organization": "SYMON COMMUNICATIONS, INC.",
        "address_1": "10701 CORPORATE DR.-STE. #290",
        "address_2": "STAFFORD  TX  77477",
        "country": "US"
    },
    "00E082": {
        "oui_hex": "00-E0-82",
        "organization": "ANERMA",
        "address_1": "SCHAAPSDRIES 25",
        "address_2": "2260 WESTERLO",
        "country": "BE"
    },
    "00E077": {
        "oui_hex": "00-E0-77",
        "organization": "WEBGEAR, INC.",
        "address_1": "1263 OAKMEAD PKWY",
        "address_2": "SUNNYVALE  CA  94080",
        "country": "US"
    },
    "00E056": {
        "oui_hex": "00-E0-56",
        "organization": "HOLONTECH CORPORATION",
        "address_1": "2039 SAMARITAN DRIVE",
        "address_2": "SAN JOSE  CA  95124",
        "country": "US"
    },
    "00E031": {
        "oui_hex": "00-E0-31",
        "organization": "HAGIWARA ELECTRIC CO., LTD.",
        "address_1": "7, SHIMOKOFUKADA, ASADA-CHO",
        "address_2": "NISSHIN-SHI, AICHI  470-01",
        "country": "JP"
    },
    "00E00B": {
        "oui_hex": "00-E0-0B",
        "organization": "ROOFTOP COMMUNICATIONS CORP.",
        "address_1": "468 PACO DRIVE",
        "address_2": "LOS ALTOS  CA  94024",
        "country": "US"
    },
    "00E0B2": {
        "oui_hex": "00-E0-B2",
        "organization": "TELMAX COMMUNICATIONS CORP.",
        "address_1": "46515 LANDING PARKWAY",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00E02F": {
        "oui_hex": "00-E0-2F",
        "organization": "MCNS HOLDINGS, L.P.",
        "address_1": "TCI, INC.-TECHNOLOGY VENTURES",
        "address_2": "DENVER  CO  80217-5630",
        "country": "US"
    },
    "00E07E": {
        "oui_hex": "00-E0-7E",
        "organization": "WALT DISNEY IMAGINEERING",
        "address_1": "1401 FLOWER ST.",
        "address_2": "GLENDALE  CA  91221",
        "country": "US"
    },
    "00E099": {
        "oui_hex": "00-E0-99",
        "organization": "SAMSON AG",
        "address_1": "WEISMULLERSTR. 3",
        "address_2": "D-60314 FRANKFURT",
        "country": "DE"
    },
    "0060AE": {
        "oui_hex": "00-60-AE",
        "organization": "TRIO INFORMATION SYSTEMS AB",
        "address_1": "FOGDEVAGEN 4B",
        "address_2": "  S-183 64 TABY",
        "country": "SE"
    },
    "006053": {
        "oui_hex": "00-60-53",
        "organization": "TOYODA MACHINE WORKS, LTD.",
        "address_1": "1-7 KITAJIZOYAMA NODACHOU",
        "address_2": "KARIYA CITY, AICHI",
        "country": "JO"
    },
    "006056": {
        "oui_hex": "00-60-56",
        "organization": "NETWORK TOOLS, INC.",
        "address_1": "2975 BOWERS AVENUE, #202",
        "address_2": "SANTA CLARA  CA  95051-0955",
        "country": "US"
    },
    "00600C": {
        "oui_hex": "00-60-0C",
        "organization": "Eurotech Inc.",
        "address_1": "10260 Old Columbia Road",
        "address_2": "COLUMBIA  MD  21046",
        "country": "US"
    },
    "00601C": {
        "oui_hex": "00-60-1C",
        "organization": "TELXON CORPORATION",
        "address_1": "3330 W. MARKET STREET",
        "address_2": "AKRON  OH  44334-0582",
        "country": "US"
    },
    "00605F": {
        "oui_hex": "00-60-5F",
        "organization": "NIPPON UNISOFT CORPORATION",
        "address_1": "BR NINGYOCHO 1,2-13-9",
        "address_2": "TOKYO 103",
        "country": "JP"
    },
    "006091": {
        "oui_hex": "00-60-91",
        "organization": "FIRST PACIFIC NETWORKS, INC.",
        "address_1": "871 FOX LANE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00601D": {
        "oui_hex": "00-60-1D",
        "organization": "LUCENT TECHNOLOGIES",
        "address_1": "101 CRAWFORDS CORNER RD.",
        "address_2": "HOLMDEL  NJ  07733",
        "country": "US"
    },
    "00607B": {
        "oui_hex": "00-60-7B",
        "organization": "FORE SYSTEMS, INC.",
        "address_1": "1000 FORE DRIVE",
        "address_2": "WARRENDALE  PA  15086",
        "country": "US"
    },
    "00E06C": {
        "oui_hex": "00-E0-6C",
        "organization": "Ultra Electronics Command & Control Systems",
        "address_1": "Knaves Beech Business Centre",
        "address_2": "Hemel Hemstead  Herts England  HP2 7BW",
        "country": "GB"
    },
    "00E04A": {
        "oui_hex": "00-E0-4A",
        "organization": "ZX Technologies, Inc",
        "address_1": "760 Spanish Oak Trail",
        "address_2": "Dripping Springs  TX  78620",
        "country": "US"
    },
    "0060C9": {
        "oui_hex": "00-60-C9",
        "organization": "ControlNet, Inc.",
        "address_1": "747 CAMDEN, STE. A",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "00E07A": {
        "oui_hex": "00-E0-7A",
        "organization": "MIKRODIDAKT AB",
        "address_1": "Skiffervägen 48",
        "address_2": "LUND    SE22478",
        "country": "SE"
    },
    "006032": {
        "oui_hex": "00-60-32",
        "organization": "I-CUBE, INC.",
        "address_1": "2328-C WALSH AVENUE",
        "address_2": "SANTA CLARA  CA  95014",
        "country": "US"
    },
    "006033": {
        "oui_hex": "00-60-33",
        "organization": "ACUITY IMAGING, INC.",
        "address_1": "9 TOWNSEND WEST",
        "address_2": "NASHUA  NH  03063",
        "country": "US"
    },
    "006013": {
        "oui_hex": "00-60-13",
        "organization": "NETSTAL MASCHINEN AG",
        "address_1": "INDUSTRIESTRASSE",
        "address_2": "CH-8752 NAEFELS",
        "country": "CH"
    },
    "006022": {
        "oui_hex": "00-60-22",
        "organization": "VICOM SYSTEMS, INC.",
        "address_1": "1961 LANDINGS DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "0060EE": {
        "oui_hex": "00-60-EE",
        "organization": "APOLLO",
        "address_1": "3610 BIRCH STREET--STE #100",
        "address_2": "NEWPORT BEACH  CA  92660",
        "country": "US"
    },
    "0060D8": {
        "oui_hex": "00-60-D8",
        "organization": "ELMIC SYSTEMS, INC.",
        "address_1": "DAI-ICHI SEIMEI BLDG.",
        "address_2": "YOKOHAMA 231",
        "country": "JP"
    },
    "0060EF": {
        "oui_hex": "00-60-EF",
        "organization": "FLYTECH TECHNOLOGY CO., LTD.",
        "address_1": "No.168 Sing-ai Rd., Neihu District",
        "address_2": "TAIPEI CITY    114",
        "country": "TW"
    },
    "006085": {
        "oui_hex": "00-60-85",
        "organization": "Storage Concepts",
        "address_1": "14352 Chamber Road",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "006011": {
        "oui_hex": "00-60-11",
        "organization": "CRYSTAL SEMICONDUCTOR CORP.",
        "address_1": "P.O. BOX 17847",
        "address_2": "AUSTIN  TX  78760",
        "country": "US"
    },
    "0060F5": {
        "oui_hex": "00-60-F5",
        "organization": "ICON WEST, INC.",
        "address_1": "3342 SOUTH 300 EAST",
        "address_2": "SALT LAKE CITY  UT  84115",
        "country": "US"
    },
    "006062": {
        "oui_hex": "00-60-62",
        "organization": "TELESYNC, INC.",
        "address_1": "5555 OAKBROOK PKWY-STE #110",
        "address_2": "NORCROSS  GA  30093",
        "country": "US"
    },
    "0060E9": {
        "oui_hex": "00-60-E9",
        "organization": "ATOP TECHNOLOGIES, INC.",
        "address_1": "SUITE 305, NO. 47, PARK AVENUE II,",
        "address_2": "HSINCHU 30047",
        "country": "TW"
    },
    "006043": {
        "oui_hex": "00-60-43",
        "organization": "iDirect, INC.",
        "address_1": "13865 Sunrise Vally Drive",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "006028": {
        "oui_hex": "00-60-28",
        "organization": "MACROVISION CORPORATION",
        "address_1": "2830 De La Cruz Boulevard",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "0060F0": {
        "oui_hex": "00-60-F0",
        "organization": "JOHNSON & JOHNSON MEDICAL, INC",
        "address_1": "4110 GEORGE RD.",
        "address_2": "TAMPA  FL  33634",
        "country": "US"
    },
    "0060E0": {
        "oui_hex": "00-60-E0",
        "organization": "AXIOM TECHNOLOGY CO., LTD.",
        "address_1": "3F, 14, LANE 235",
        "address_2": "TAIPEI HSIEN",
        "country": "TW"
    },
    "006096": {
        "oui_hex": "00-60-96",
        "organization": "T.S. MICROTECH INC.",
        "address_1": "20818 HIGGINS COURT",
        "address_2": "TORRANCE  CA  90501",
        "country": "US"
    },
    "00603A": {
        "oui_hex": "00-60-3A",
        "organization": "QUICK CONTROLS LTD.",
        "address_1": "DURHAM HOUSE, WARWICK COURT",
        "address_2": "MANCHESTER  M24 1AE",
        "country": "GB"
    },
    "000288": {
        "oui_hex": "00-02-88",
        "organization": "GLOBAL VILLAGE COMMUNICATION",
        "address_1": "1144 EAST ARQUES AVE.",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "006034": {
        "oui_hex": "00-60-34",
        "organization": "ROBERT BOSCH GmbH",
        "address_1": "POSTBOX 11 62",
        "address_2": "D-64701 ERBACH",
        "country": "DE"
    },
    "006050": {
        "oui_hex": "00-60-50",
        "organization": "INTERNIX INC.",
        "address_1": "59-10 TAKAKURA-CHO",
        "address_2": "  TOKYO 192",
        "country": "JP"
    },
    "0060FA": {
        "oui_hex": "00-60-FA",
        "organization": "EDUCATIONAL TECHNOLOGY RESOURCES, INC.",
        "address_1": "1742 CHURCH STREET",
        "address_2": "HOLBROOK  NY  11741",
        "country": "US"
    },
    "0060DA": {
        "oui_hex": "00-60-DA",
        "organization": "Red Lion Controls, LP",
        "address_1": "20 Willow Springs Circle",
        "address_2": "York  NY  17402",
        "country": "US"
    },
    "0060E4": {
        "oui_hex": "00-60-E4",
        "organization": "COMPUSERVE, INC.",
        "address_1": "5000 ARLINGTON CENTRE BLVD.",
        "address_2": "COLUMBUS  OH  43220",
        "country": "US"
    },
    "00608F": {
        "oui_hex": "00-60-8F",
        "organization": "TEKRAM TECHNOLOGY CO., LTD.",
        "address_1": "B1, NO. 17, LANE 159, SEC. 6",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "0060C4": {
        "oui_hex": "00-60-C4",
        "organization": "SOLITON SYSTEMS K.K.",
        "address_1": "2-4-3 SHINJUKU, SHINJUKU-KU",
        "address_2": "TOKYO 160",
        "country": "JP"
    },
    "00A03C": {
        "oui_hex": "00-A0-3C",
        "organization": "EG&G NUCLEAR INSTRUMENTS",
        "address_1": "100 MIDLAND ROAD",
        "address_2": "OAK RIDGE  TN  37830",
        "country": "US"
    },
    "00A0C4": {
        "oui_hex": "00-A0-C4",
        "organization": "CRISTIE ELECTRONICS LTD.",
        "address_1": "BOND'S MILL",
        "address_2": "GLOUCESTERSHIRE GL10 3RG",
        "country": "GB"
    },
    "00A063": {
        "oui_hex": "00-A0-63",
        "organization": "JRL SYSTEMS, INC.",
        "address_1": "8305 HWY 71 WEST",
        "address_2": "AUSTIN  TX  78735",
        "country": "US"
    },
    "00A02C": {
        "oui_hex": "00-A0-2C",
        "organization": "interWAVE Communications",
        "address_1": "656 BAIR ISLAND BLVD.-STE.#108",
        "address_2": "REDWOOD CITY  CA  94063-2704",
        "country": "US"
    },
    "00A0F7": {
        "oui_hex": "00-A0-F7",
        "organization": "V.I COMPUTER CORP.",
        "address_1": "531 ENCINITAS BLVD--#114",
        "address_2": "ENCINITAS  CA  92024",
        "country": "US"
    },
    "00A090": {
        "oui_hex": "00-A0-90",
        "organization": "TimeStep Corporation",
        "address_1": "359 TERRY FOX DRIVE",
        "address_2": "KANATA, ONTARIO K2K 2E7",
        "country": "CA"
    },
    "00A0EA": {
        "oui_hex": "00-A0-EA",
        "organization": "ETHERCOM CORP.",
        "address_1": "45990 HOTCHKISS ST.",
        "address_2": "FREEMONT  CA  94539",
        "country": "US"
    },
    "00A0DC": {
        "oui_hex": "00-A0-DC",
        "organization": "O.N. ELECTRONIC CO., LTD.",
        "address_1": "3-20-27, TARUMI",
        "address_2": "SUITA, OSAKA 564",
        "country": "JP"
    },
    "00A00B": {
        "oui_hex": "00-A0-0B",
        "organization": "COMPUTEX CO., LTD.",
        "address_1": "432-13 GOJYOBASHI-HIGASHI 4-CHYOME",
        "address_2": " HIGASHIYAMAKU, KYOTO-CITY 605",
        "country": "JP"
    },
    "00A0E2": {
        "oui_hex": "00-A0-E2",
        "organization": "Keisokugiken Corporation",
        "address_1": "2021-5 Houshakuji",
        "address_2": "Shioya-gun  Tochigi  329-1233",
        "country": "JP"
    },
    "00A033": {
        "oui_hex": "00-A0-33",
        "organization": "imc MeBsysteme GmbH",
        "address_1": "VOLTASTRASSE 5",
        "address_2": "D-13355 BERLIN",
        "country": "DE"
    },
    "00A0A9": {
        "oui_hex": "00-A0-A9",
        "organization": "NAVTEL COMMUNICATIONS INC.",
        "address_1": "55 RENFREW DRIVE",
        "address_2": "MARKHAM, ONTARIO L3R 8H3",
        "country": "CA"
    },
    "00A071": {
        "oui_hex": "00-A0-71",
        "organization": "VIDEO LOTTERY TECHNOLOGIES,INC",
        "address_1": "2311 SOUTH 7TH AVENUE",
        "address_2": "BOZEMAN  MT  59715",
        "country": "US"
    },
    "006000": {
        "oui_hex": "00-60-00",
        "organization": "XYCOM INC.",
        "address_1": "750 N. MAPLE",
        "address_2": "SALINE  MI  48176",
        "country": "US"
    },
    "006045": {
        "oui_hex": "00-60-45",
        "organization": "PATHLIGHT TECHNOLOGIES",
        "address_1": "767 WARREN ROAD",
        "address_2": "ITHACA  NY  14850",
        "country": "US"
    },
    "00A05D": {
        "oui_hex": "00-A0-5D",
        "organization": "CS COMPUTER SYSTEME GmbH",
        "address_1": "ISARSTRASSE 3,",
        "address_2": "82065 BAIERBRUNN",
        "country": "DE"
    },
    "00A061": {
        "oui_hex": "00-A0-61",
        "organization": "PURITAN BENNETT",
        "address_1": "2200 FARADAY AVENUE",
        "address_2": "CARLSBAD  CA  92008",
        "country": "US"
    },
    "0060A6": {
        "oui_hex": "00-60-A6",
        "organization": "PARTICLE MEASURING SYSTEMS",
        "address_1": "5475 AIRPORT BLVD.",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00602A": {
        "oui_hex": "00-60-2A",
        "organization": "SYMICRON COMPUTER COMMUNICATIONS, LTD.",
        "address_1": "UNIT 4 GREEN LANE BUSINESS PARK",
        "address_2": "London SE9 3TL",
        "country": "US"
    },
    "00A06D": {
        "oui_hex": "00-A0-6D",
        "organization": "MANNESMANN TALLY CORPORATION",
        "address_1": "P.O. BOX 97018",
        "address_2": "KENT  WA  98064-9718",
        "country": "US"
    },
    "00A0F6": {
        "oui_hex": "00-A0-F6",
        "organization": "AutoGas Systems Inc.",
        "address_1": "P.O. BOX 6957",
        "address_2": "ABIOLENE  TX  79608",
        "country": "US"
    },
    "0060BE": {
        "oui_hex": "00-60-BE",
        "organization": "WEBTRONICS",
        "address_1": "3B-1  8-2-12",
        "address_2": "SHINAGAWA-KU TOKYO 141",
        "country": "JP"
    },
    "0060BF": {
        "oui_hex": "00-60-BF",
        "organization": "MACRAIGOR SYSTEMS, INC.",
        "address_1": "PO BOX 1008",
        "address_2": "BROOKLINE VILLAGE  MA  02147",
        "country": "US"
    },
    "006080": {
        "oui_hex": "00-60-80",
        "organization": "MICROTRONIX DATACOM LTD.",
        "address_1": "4056 Meadowbrook Drive, Unit 126",
        "address_2": "LONDON  ONTARIO  N6L 1E3",
        "country": "CA"
    },
    "00A037": {
        "oui_hex": "00-A0-37",
        "organization": "Mindray DS USA, Inc.",
        "address_1": "800 Macarthur Blvd.",
        "address_2": "Mahwah  NJ  07430",
        "country": "US"
    },
    "00A04C": {
        "oui_hex": "00-A0-4C",
        "organization": "INNOVATIVE SYSTEMS & TECHNOLOGIES, INC.",
        "address_1": "48511 WARM SPRINGS BLVD.",
        "address_2": "FREMONT  CA  94539",
        "country": "US"
    },
    "00A031": {
        "oui_hex": "00-A0-31",
        "organization": "HAZELTINE CORPORATION, MS 1-17",
        "address_1": "450 E. PULASKI ROAD",
        "address_2": "GREENLAWN  NY  11740",
        "country": "US"
    },
    "00A041": {
        "oui_hex": "00-A0-41",
        "organization": "INFICON",
        "address_1": "2 Technology Place",
        "address_2": "E. Syracuse  NY  13057",
        "country": "US"
    },
    "00A0A7": {
        "oui_hex": "00-A0-A7",
        "organization": "VORAX CORPORATION",
        "address_1": "1031 EAST DUANE AVENUE, STE H",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00A07E": {
        "oui_hex": "00-A0-7E",
        "organization": "AVID TECHNOLOGY, INC.",
        "address_1": "METROPOLITAN TECHNOLOGY PARK",
        "address_2": "TEWKSBURY  MA  01876",
        "country": "US"
    },
    "00A06F": {
        "oui_hex": "00-A0-6F",
        "organization": "Color Sentinel Systems, LLC",
        "address_1": "97 Ridgeland Rd, Suite #2",
        "address_2": "ROCHESTER  NY  14623",
        "country": "US"
    },
    "00A0C7": {
        "oui_hex": "00-A0-C7",
        "organization": "TADIRAN TELECOMMUNICATIONS",
        "address_1": "P.O. BOX 500",
        "address_2": "PETAH-TIKVA 49104",
        "country": "IL"
    },
    "00A01A": {
        "oui_hex": "00-A0-1A",
        "organization": "BINAR ELEKTRONIK AB",
        "address_1": "MAGNETUAGEN 18",
        "address_2": "",
        "country": "SE"
    },
    "00A088": {
        "oui_hex": "00-A0-88",
        "organization": "ESSENTIAL COMMUNICATIONS",
        "address_1": "4374 ALEXANDER BLVD. NE-STE",
        "address_2": "ALBUQUERQUE  NM  87107",
        "country": "US"
    },
    "00A0C2": {
        "oui_hex": "00-A0-C2",
        "organization": "R.A. SYSTEMS CO., LTD.",
        "address_1": "1850-3 HIROOKANOMURA",
        "address_2": "",
        "country": "JP"
    },
    "00A098": {
        "oui_hex": "00-A0-98",
        "organization": "NetApp",
        "address_1": "1395 Crossman Ave",
        "address_2": "Sunnyvale,  CA  94089",
        "country": "US"
    },
    "00A04B": {
        "oui_hex": "00-A0-4B",
        "organization": "TFL LAN INC.",
        "address_1": "9F, NO. 499 CHUNG CHENG ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00A064": {
        "oui_hex": "00-A0-64",
        "organization": "KVB/ANALECT",
        "address_1": "9420 JERONIMO ROAD",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "00A03E": {
        "oui_hex": "00-A0-3E",
        "organization": "ATM FORUM",
        "address_1": "WORLDWIDE HEADQUARTERS",
        "address_2": "FOSTER CITY  CA  94404-1138",
        "country": "US"
    },
    "00A01F": {
        "oui_hex": "00-A0-1F",
        "organization": "TRICORD SYSTEMS, INC.",
        "address_1": "2800 NORTHWEST BOULEVARD",
        "address_2": "PLYMOUTH  MN  55441-2625",
        "country": "US"
    },
    "00A0FB": {
        "oui_hex": "00-A0-FB",
        "organization": "TORAY ENGINEERING CO., LTD.",
        "address_1": "1-45, OE 1-CHOME, OTSU CITY",
        "address_2": "  520-21",
        "country": "JP"
    },
    "00A06C": {
        "oui_hex": "00-A0-6C",
        "organization": "SHINDENGEN ELECTRIC MFG. CO., LTD.",
        "address_1": "10-13, MINAMI-CHO, HANNOU-CITY",
        "address_2": "SAITAMA 357",
        "country": "JO"
    },
    "00A0DB": {
        "oui_hex": "00-A0-DB",
        "organization": "FISHER & PAYKEL PRODUCTION",
        "address_1": "MACHINERY LIMITED",
        "address_2": "",
        "country": "NZ"
    },
    "00A081": {
        "oui_hex": "00-A0-81",
        "organization": "ALCATEL DATA NETWORKS",
        "address_1": "12502 SUNRISE VALLEY DRIVE",
        "address_2": "RESTON  VA  22096",
        "country": "US"
    },
    "00A0B1": {
        "oui_hex": "00-A0-B1",
        "organization": "FIRST VIRTUAL CORPORATION",
        "address_1": "3393 OCTAVIUS DR.-STE.# 102",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "002010": {
        "oui_hex": "00-20-10",
        "organization": "JEOL SYSTEM TECHNOLOGY CO. LTD",
        "address_1": "3-1-2 Musashino",
        "address_2": "Akishima-shi  Tokyo  196-8558",
        "country": "JP"
    },
    "00209F": {
        "oui_hex": "00-20-9F",
        "organization": "MERCURY COMPUTER SYSTEMS, INC.",
        "address_1": "199 RIVERNECK ROAD",
        "address_2": "CHELMSFORD  MA  01824",
        "country": "US"
    },
    "00A073": {
        "oui_hex": "00-A0-73",
        "organization": "COM21, INC.",
        "address_1": "2113 LANDINGS DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00A03A": {
        "oui_hex": "00-A0-3A",
        "organization": "KUBOTEK CORPORATION",
        "address_1": "56 NISHIAKETA-CHO, HIGASHIKUJO",
        "address_2": "",
        "country": "JP"
    },
    "00A0B2": {
        "oui_hex": "00-A0-B2",
        "organization": "SHIMA SEIKI",
        "address_1": "85, SAKATA WAKAYAMA-CITY",
        "address_2": "",
        "country": "JP"
    },
    "00A08B": {
        "oui_hex": "00-A0-8B",
        "organization": "ASTON ELECTRONIC DESIGNS LTD.",
        "address_1": "123/127 DEEPCUT BRIDGE ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00A097": {
        "oui_hex": "00-A0-97",
        "organization": "JC INFORMATION SYSTEMS",
        "address_1": "4487 TECHNOLOGY DRIVE",
        "address_2": "FREMONT  CA  94538-6343",
        "country": "US"
    },
    "00A027": {
        "oui_hex": "00-A0-27",
        "organization": "FIREPOWER SYSTEMS, INC.",
        "address_1": "190 INDEPENDENCE DRIVE",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "00A046": {
        "oui_hex": "00-A0-46",
        "organization": "SCITEX CORP. LTD.",
        "address_1": "P.O.BOX 330",
        "address_2": "",
        "country": "IL"
    },
    "00A0D4": {
        "oui_hex": "00-A0-D4",
        "organization": "RADIOLAN,  INC.",
        "address_1": "454 DEGUIGNE DRIVE - STE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00A092": {
        "oui_hex": "00-A0-92",
        "organization": "H. BOLLMANN MANUFACTURERS, LTD",
        "address_1": "26 VICTORIA WAY",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "00200D": {
        "oui_hex": "00-20-0D",
        "organization": "CARL ZEISS",
        "address_1": "POSTFACH 1380",
        "address_2": "",
        "country": "DE"
    },
    "00202D": {
        "oui_hex": "00-20-2D",
        "organization": "TAIYO CORPORATION",
        "address_1": "1-2-6 SANNOH, OHTA-KU",
        "address_2": "  143",
        "country": "JP"
    },
    "002091": {
        "oui_hex": "00-20-91",
        "organization": "J125, NATIONAL SECURITY AGENCY",
        "address_1": "9800 SAVAGE ROAD",
        "address_2": "FT. MEADE  MD  20755-6000",
        "country": "US"
    },
    "0020BD": {
        "oui_hex": "00-20-BD",
        "organization": "NIOBRARA R & D CORPORATION",
        "address_1": "PO BOX 3418",
        "address_2": "JOPLIN  MO  64803-3418",
        "country": "US"
    },
    "002054": {
        "oui_hex": "00-20-54",
        "organization": "Sycamore Networks",
        "address_1": "220 Mill Rd",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "0020A7": {
        "oui_hex": "00-20-A7",
        "organization": "PAIRGAIN TECHNOLOGIES, INC.",
        "address_1": "14402 FRANKLIN AVENUE",
        "address_2": "TUSTIN  CA  92680-7013",
        "country": "US"
    },
    "002055": {
        "oui_hex": "00-20-55",
        "organization": "ALTECH CO., LTD.",
        "address_1": "OHISHI BLDG., 2-23-11",
        "address_2": " TOKYO 116",
        "country": "JP"
    },
    "00200A": {
        "oui_hex": "00-20-0A",
        "organization": "SOURCE-COMM CORP.",
        "address_1": "25020 W. AVENUE STANFORD",
        "address_2": "VALENCIA  CA  91355",
        "country": "US"
    },
    "0020CF": {
        "oui_hex": "00-20-CF",
        "organization": "TEST & MEASUREMENT SYSTEMS INC",
        "address_1": "2045 SITKA COURT",
        "address_2": "LOVELAND  CO  80538",
        "country": "US"
    },
    "0020B4": {
        "oui_hex": "00-20-B4",
        "organization": "TERMA ELEKTRONIK AS",
        "address_1": "HOVMARKEN 4,",
        "address_2": "DK-8520 LYSTRUP",
        "country": "DK"
    },
    "0020E4": {
        "oui_hex": "00-20-E4",
        "organization": "HSING TECH ENTERPRISE CO., LTD",
        "address_1": "NO. 2, LANE 128, SEC. 2",
        "address_2": "TEIPEI,",
        "country": "TW"
    },
    "00206C": {
        "oui_hex": "00-20-6C",
        "organization": "EVERGREEN TECHNOLOGY CORP.",
        "address_1": "231 EMERSON STREET",
        "address_2": "PALO ALTO  CA  94301",
        "country": "US"
    },
    "00205E": {
        "oui_hex": "00-20-5E",
        "organization": "CASTLE ROCK, INC.",
        "address_1": "20 SOUTH SANTA CRUZ AVE.",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "002012": {
        "oui_hex": "00-20-12",
        "organization": "CAMTRONICS MEDICAL SYSTEMS",
        "address_1": "P.O. BOX 950",
        "address_2": "HARTLAND  WI  53029",
        "country": "US"
    },
    "002075": {
        "oui_hex": "00-20-75",
        "organization": "MOTOROLA COMMUNICATION ISRAEL",
        "address_1": "3 KREMENETSKI STREET",
        "address_2": "TEL-AVIV  61250",
        "country": "IL"
    },
    "0020A5": {
        "oui_hex": "00-20-A5",
        "organization": "API ENGINEERING",
        "address_1": "2689 POPLARWOOD WAY",
        "address_2": "SAN JOSE  CA  95132",
        "country": "US"
    },
    "002064": {
        "oui_hex": "00-20-64",
        "organization": "PROTEC MICROSYSTEMS, INC.",
        "address_1": "297 LABROSSE",
        "address_2": "POINTE-CLAIRE, QUEBEC H9R 1A3",
        "country": "CA"
    },
    "002033": {
        "oui_hex": "00-20-33",
        "organization": "SYNAPSE TECHNOLOGIES, INC.",
        "address_1": "4822 ALBEMARLE ROAD, #104",
        "address_2": "CHARLOTTE  NC  28205",
        "country": "US"
    },
    "0020CB": {
        "oui_hex": "00-20-CB",
        "organization": "PRETEC ELECTRONICS CORP.",
        "address_1": "39899 BALENTINE DR.",
        "address_2": "NEWARK  CA  94560",
        "country": "US"
    },
    "0020EB": {
        "oui_hex": "00-20-EB",
        "organization": "CINCINNATI MICROWAVE, INC.",
        "address_1": "ONE MICROWAVE PLAZA",
        "address_2": "CINCINNATI  OH  45249",
        "country": "US"
    },
    "0020A0": {
        "oui_hex": "00-20-A0",
        "organization": "OA LABORATORY CO., LTD.",
        "address_1": "228 KAMIMACHIYA KAMAKURA",
        "address_2": "",
        "country": "JP"
    },
    "0020E2": {
        "oui_hex": "00-20-E2",
        "organization": "INFORMATION RESOURCE ENGINEERING",
        "address_1": "8029 CORPORATE DRIVE",
        "address_2": "BALTIMORE  MD  21236",
        "country": "US"
    },
    "002007": {
        "oui_hex": "00-20-07",
        "organization": "SFA, INC.",
        "address_1": "1401 MCCORMICK DRIVE",
        "address_2": "LANDOVER  MD  20785",
        "country": "US"
    },
    "00205C": {
        "oui_hex": "00-20-5C",
        "organization": "InterNet Systems of Florida, Inc.",
        "address_1": "P.O. BOX 578",
        "address_2": "CRESTVIEW  FL  32536",
        "country": "US"
    },
    "0020A2": {
        "oui_hex": "00-20-A2",
        "organization": "GALCOM NETWORKING LTD.",
        "address_1": "P.O. BOX 1568",
        "address_2": "RAMAT HASHARON 47113",
        "country": "IL"
    },
    "002031": {
        "oui_hex": "00-20-31",
        "organization": "Tattile SRL",
        "address_1": "AM PESTALOZZIRING 24",
        "address_2": "D-91058 ERLANGEN",
        "country": "DE"
    },
    "0020D0": {
        "oui_hex": "00-20-D0",
        "organization": "VERSALYNX CORPORATION",
        "address_1": "8950 CARLEY CIRCLE",
        "address_2": "SAN DIEGO  CA  92126",
        "country": "US"
    },
    "0020B9": {
        "oui_hex": "00-20-B9",
        "organization": "METRICOM, INC.",
        "address_1": "980 UNIVERSITY AVENUE",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "002039": {
        "oui_hex": "00-20-39",
        "organization": "SCINETS",
        "address_1": "1575 TENAKA - STE# N8",
        "address_2": "SUNNYVALE  CA  94087",
        "country": "US"
    },
    "002072": {
        "oui_hex": "00-20-72",
        "organization": "WORKLINK INNOVATIONS",
        "address_1": "2452 ARMSTRONG STREET",
        "address_2": "LIVERMORE  CA  9455O",
        "country": "US"
    },
    "0020EC": {
        "oui_hex": "00-20-EC",
        "organization": "TECHWARE SYSTEMS CORP.",
        "address_1": "#100 - 12051 HORSESHOE WAY",
        "address_2": "  V7A  4V4",
        "country": "CA"
    },
    "00206E": {
        "oui_hex": "00-20-6E",
        "organization": "XACT, INC.",
        "address_1": "P.O. BOX 55",
        "address_2": "ARGYLE  TX  76226",
        "country": "US"
    },
    "0020F1": {
        "oui_hex": "00-20-F1",
        "organization": "ALTOS INDIA LIMITED",
        "address_1": "D-60, OKLHLA INDUSTRIAL",
        "address_2": "",
        "country": "IN"
    },
    "002041": {
        "oui_hex": "00-20-41",
        "organization": "DATA NET",
        "address_1": "SUWON P.O. BOX 106, SUWON",
        "address_2": "  KOREA  440-600",
        "country": "KR"
    },
    "002076": {
        "oui_hex": "00-20-76",
        "organization": "REUDO CORPORATION",
        "address_1": "4-1-10 SHINSAN",
        "address_2": "",
        "country": "JP"
    },
    "0020E8": {
        "oui_hex": "00-20-E8",
        "organization": "DATATREK CORPORATION",
        "address_1": "4505 WYLAND DRIVE",
        "address_2": "ELKHART  IN  46516",
        "country": "US"
    },
    "0020C5": {
        "oui_hex": "00-20-C5",
        "organization": "EAGLE TECHNOLOGY",
        "address_1": "2865 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "002009": {
        "oui_hex": "00-20-09",
        "organization": "PACKARD BELL ELEC., INC.",
        "address_1": "9425 CANOGA AVENUE",
        "address_2": "CHATSWORTH  CA  913211",
        "country": "US"
    },
    "002027": {
        "oui_hex": "00-20-27",
        "organization": "MING FORTUNE INDUSTRY CO., LTD",
        "address_1": "4F, NO. 800 CHUNG CHENG RD,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00208A": {
        "oui_hex": "00-20-8A",
        "organization": "SONIX COMMUNICATIONS, LTD.",
        "address_1": "WILKINSON ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0020D2": {
        "oui_hex": "00-20-D2",
        "organization": "RAD DATA COMMUNICATIONS, LTD.",
        "address_1": "8 HANECHOSHET STREET",
        "address_2": "",
        "country": "KZ"
    },
    "002002": {
        "oui_hex": "00-20-02",
        "organization": "SERITECH ENTERPRISE CO., LTD.",
        "address_1": "FL. 182, NO. 531-1",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00204B": {
        "oui_hex": "00-20-4B",
        "organization": "AUTOCOMPUTER CO., LTD.",
        "address_1": "NO. 18, PEI YUAN ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0020EA": {
        "oui_hex": "00-20-EA",
        "organization": "EFFICIENT NETWORKS, INC.",
        "address_1": "4201 SPRING VALLEY ROAD",
        "address_2": "DALLAS  TX  75244-3666",
        "country": "US"
    },
    "00206A": {
        "oui_hex": "00-20-6A",
        "organization": "OSAKA COMPUTER CORP.",
        "address_1": "2-8 KOYACHOU NEYAGAW-SHI",
        "address_2": "",
        "country": "JP"
    },
    "0020DB": {
        "oui_hex": "00-20-DB",
        "organization": "XNET TECHNOLOGY, INC.",
        "address_1": "426 S. HILLVIEW DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "0020BB": {
        "oui_hex": "00-20-BB",
        "organization": "ZAX CORPORATION",
        "address_1": "20-12 OGIKUBO 5-CHOME",
        "address_2": "  167",
        "country": "JP"
    },
    "0020A8": {
        "oui_hex": "00-20-A8",
        "organization": "SAST TECHNOLOGY CORP.",
        "address_1": "225 OLD NEW BRUNSWICK RD.",
        "address_2": "PISCATAWAY  NJ  08854",
        "country": "US"
    },
    "002045": {
        "oui_hex": "00-20-45",
        "organization": "ION Networks, Inc.",
        "address_1": "1551 South Washington Ave.",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "002049": {
        "oui_hex": "00-20-49",
        "organization": "COMTRON, INC.",
        "address_1": "SANCATHERINA BLDG.",
        "address_2": "TOKYO  160",
        "country": "JP"
    },
    "002050": {
        "oui_hex": "00-20-50",
        "organization": "KOREA COMPUTER INC.",
        "address_1": "469, DAEHEUNG-DONG",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "002084": {
        "oui_hex": "00-20-84",
        "organization": "OCE PRINTING SYSTEMS, GMBH",
        "address_1": "SIEMENSALLEE 2",
        "address_2": "",
        "country": "DE"
    },
    "00208C": {
        "oui_hex": "00-20-8C",
        "organization": "GALAXY NETWORKS, INC.",
        "address_1": "9348 DE SOTO AVENUE",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "00202C": {
        "oui_hex": "00-20-2C",
        "organization": "WELLTRONIX CO., LTD.",
        "address_1": "3F, NO. 36-1, HWANG HSI STREET",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "002021": {
        "oui_hex": "00-20-21",
        "organization": "ALGORITHMS SOFTWARE PVT. LTD.",
        "address_1": "83 JOLLY MAKER CHAMBERS II",
        "address_2": "",
        "country": "IN"
    },
    "00C0F9": {
        "oui_hex": "00-C0-F9",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way Suite 190",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "00C075": {
        "oui_hex": "00-C0-75",
        "organization": "XANTE CORPORATION",
        "address_1": "2559 EMOGENE STREET",
        "address_2": "MOBILE  AL  36606",
        "country": "US"
    },
    "001C7C": {
        "oui_hex": "00-1C-7C",
        "organization": "PERQ SYSTEMS CORPORATION",
        "address_1": "2600 LIBERTY AVENUE",
        "address_2": "PITTSBURGH  PA  15230",
        "country": "US"
    },
    "00C039": {
        "oui_hex": "00-C0-39",
        "organization": "Teridian Semiconductor Corporation",
        "address_1": "6440 Oak Canyon",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "00C0A9": {
        "oui_hex": "00-C0-A9",
        "organization": "BARRON MCCANN LTD.",
        "address_1": "BEMAC HOUSE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C04B": {
        "oui_hex": "00-C0-4B",
        "organization": "CREATIVE MICROSYSTEMS",
        "address_1": "9, AVENUE DU CANADA",
        "address_2": "91966  LES  ULIS---FRANC",
        "country": "FR"
    },
    "00C0B9": {
        "oui_hex": "00-C0-B9",
        "organization": "FUNK SOFTWARE, INC.",
        "address_1": "222 THIRD STREET",
        "address_2": "CAMBRIDGE  MA  02142",
        "country": "US"
    },
    "00C015": {
        "oui_hex": "00-C0-15",
        "organization": "NEW MEDIA CORPORATION",
        "address_1": "15375 BARRANCA PARKWAY",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "00C083": {
        "oui_hex": "00-C0-83",
        "organization": "TRACE MOUNTAIN PRODUCTS, INC.",
        "address_1": "1040 EAST BROKAW ROAD",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00C094": {
        "oui_hex": "00-C0-94",
        "organization": "VMX INC.",
        "address_1": "2115 O'NEL DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00C019": {
        "oui_hex": "00-C0-19",
        "organization": "LEAP TECHNOLOGY, INC.",
        "address_1": "20",
        "address_2": "BURLINGTON  MA  01803",
        "country": "US"
    },
    "00C0CF": {
        "oui_hex": "00-C0-CF",
        "organization": "IMATRAN VOIMA OY",
        "address_1": "IVO",
        "address_2": "",
        "country": "FI"
    },
    "00C07D": {
        "oui_hex": "00-C0-7D",
        "organization": "RISC DEVELOPMENTS LTD.",
        "address_1": "117 HATFIELD ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00C043": {
        "oui_hex": "00-C0-43",
        "organization": "STRATACOM",
        "address_1": "1400 PARKMOOR AVENUE",
        "address_2": "SAN JOSE  CA  95126",
        "country": "US"
    },
    "00C0B5": {
        "oui_hex": "00-C0-B5",
        "organization": "CORPORATE NETWORK SYSTEMS,INC.",
        "address_1": "5711 SIX FORKS ROAD--STE #306",
        "address_2": "RALEIGH  NC  27609",
        "country": "US"
    },
    "00C0ED": {
        "oui_hex": "00-C0-ED",
        "organization": "US ARMY ELECTRONIC",
        "address_1": "PROVING GROUND",
        "address_2": "SIERRA VISTA  AZ  85635",
        "country": "US"
    },
    "00C032": {
        "oui_hex": "00-C0-32",
        "organization": "I-CUBED LIMITED",
        "address_1": "UNIT J1, THE POADDOCKS",
        "address_2": "CB1 4DH  CB1 4DH  ENGLAND",
        "country": "GB"
    },
    "00C0A5": {
        "oui_hex": "00-C0-A5",
        "organization": "DICKENS DATA SYSTEMS",
        "address_1": "1175 NORTHMEADOW PKWY-STE #150",
        "address_2": "ROSWELL  GA  30076",
        "country": "US"
    },
    "00C0EF": {
        "oui_hex": "00-C0-EF",
        "organization": "ABIT CORPORATION",
        "address_1": "29-11 HIRAOKA-CHO",
        "address_2": "  192",
        "country": "JP"
    },
    "00C061": {
        "oui_hex": "00-C0-61",
        "organization": "SOLECTEK CORPORATION",
        "address_1": "6370 NANCY RIDGE DR.-STE.#109",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00C0AD": {
        "oui_hex": "00-C0-AD",
        "organization": "MARBEN COMMUNICATION SYSTEMS",
        "address_1": "1 RUE DU BOIS CHALAND",
        "address_2": "",
        "country": "FR"
    },
    "00C07F": {
        "oui_hex": "00-C0-7F",
        "organization": "NUPON COMPUTING CORP.",
        "address_1": "1391 WARNER AVE., -SUITE",
        "address_2": "TUSTIN  CA  92680",
        "country": "US"
    },
    "00C057": {
        "oui_hex": "00-C0-57",
        "organization": "MYCO ELECTRONICS",
        "address_1": "MUSSERONGRAND 1G",
        "address_2": "",
        "country": "SE"
    },
    "00C056": {
        "oui_hex": "00-C0-56",
        "organization": "SOMELEC",
        "address_1": "BP 7010 - 95050",
        "address_2": "",
        "country": "FR"
    },
    "00C027": {
        "oui_hex": "00-C0-27",
        "organization": "CIPHER SYSTEMS, INC.",
        "address_1": "22115 NW Imbrie Dr #285",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "00C05C": {
        "oui_hex": "00-C0-5C",
        "organization": "ELONEX PLC",
        "address_1": "2 APSLEY WAY",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C028": {
        "oui_hex": "00-C0-28",
        "organization": "JASCO CORPORATION",
        "address_1": "2967-5 ISHIKAWA-CHO,",
        "address_2": "",
        "country": "JP"
    },
    "00C08D": {
        "oui_hex": "00-C0-8D",
        "organization": "TRONIX PRODUCT DEVELOPMENT",
        "address_1": "4908 E. MCDOWELL RD. STE.#100",
        "address_2": "PHOENIX  AZ  85008",
        "country": "US"
    },
    "00C02A": {
        "oui_hex": "00-C0-2A",
        "organization": "OHKURA ELECTRIC CO., LTD.",
        "address_1": "2-90-20 SHIRAKO WAKO CITY",
        "address_2": "  351-01",
        "country": "JP"
    },
    "00C0FC": {
        "oui_hex": "00-C0-FC",
        "organization": "ELASTIC REALITY, INC.",
        "address_1": "925 STEWART STREET",
        "address_2": "MADISON  WI  53713",
        "country": "US"
    },
    "00C0BB": {
        "oui_hex": "00-C0-BB",
        "organization": "FORVAL CREATIVE, INC.",
        "address_1": "3-27-12 HONGO",
        "address_2": "",
        "country": "JP"
    },
    "00C0E0": {
        "oui_hex": "00-C0-E0",
        "organization": "DSC COMMUNICATION CORP.",
        "address_1": "1000 COIT ROAD,  MS#ADVP 3",
        "address_2": "PLANO  TX  75075",
        "country": "US"
    },
    "00C05B": {
        "oui_hex": "00-C0-5B",
        "organization": "NETWORKS NORTHWEST, INC.",
        "address_1": "P.O. BOX 1188",
        "address_2": "ISSAQUAH  WA  98027",
        "country": "US"
    },
    "00C008": {
        "oui_hex": "00-C0-08",
        "organization": "SECO SRL",
        "address_1": "VIA CALAMANDREI 91",
        "address_2": "",
        "country": "IT"
    },
    "00C0B7": {
        "oui_hex": "00-C0-B7",
        "organization": "AMERICAN POWER CONVERSION CORP",
        "address_1": "267 BOSTON ROAD #2",
        "address_2": "NORTH BILLERICA  MA  01862",
        "country": "US"
    },
    "00C0D3": {
        "oui_hex": "00-C0-D3",
        "organization": "OLYMPUS IMAGE SYSTEMS, INC.",
        "address_1": "15271 BARRANCA PARKWAY",
        "address_2": "IRVINE  CA  92718-2201",
        "country": "US"
    },
    "00C0E8": {
        "oui_hex": "00-C0-E8",
        "organization": "PLEXCOM, INC.",
        "address_1": "65 MORELAND ROADENUYE",
        "address_2": "SIMI VALLEY  CA  93065",
        "country": "US"
    },
    "00C0DA": {
        "oui_hex": "00-C0-DA",
        "organization": "NICE SYSTEMS LTD.",
        "address_1": "3 TEVUOT HA'ARETZ ST",
        "address_2": "",
        "country": "IL"
    },
    "00C0D1": {
        "oui_hex": "00-C0-D1",
        "organization": "COMTREE TECHNOLOGY CORPORATION",
        "address_1": "5F-7, NO. 1, FU-HSING NORTH RD",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "CN"
    },
    "00C038": {
        "oui_hex": "00-C0-38",
        "organization": "RASTER IMAGE PROCESSING SYSTEM",
        "address_1": "4665 NAUTILUS COURT SOUTH",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00409B": {
        "oui_hex": "00-40-9B",
        "organization": "HAL COMPUTER SYSTEMS INC.",
        "address_1": "1315 DELL AVENUE",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "0040EB": {
        "oui_hex": "00-40-EB",
        "organization": "MARTIN MARIETTA CORPORATION",
        "address_1": "12506 LAKE UNDERHILL",
        "address_2": "ORLANDO  FL  32825",
        "country": "US"
    },
    "0040BD": {
        "oui_hex": "00-40-BD",
        "organization": "STARLIGHT NETWORKS, INC.",
        "address_1": "444 CASTRO STREET STE",
        "address_2": "MOUNTAIN VIEW  CA  94041",
        "country": "US"
    },
    "0040ED": {
        "oui_hex": "00-40-ED",
        "organization": "NETWORK CONTROLS INT'NATL INC.",
        "address_1": "9 WOODLAWN GREEN",
        "address_2": "CHARLOTTE  NC  28217",
        "country": "US"
    },
    "004021": {
        "oui_hex": "00-40-21",
        "organization": "RASTER GRAPHICS",
        "address_1": "285 N. WOLFE ROAD",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0040C1": {
        "oui_hex": "00-40-C1",
        "organization": "BIZERBA-WERKE WILHEIM KRAUT",
        "address_1": "GMBH & CO. KG,",
        "address_2": "D-7460 BALINGEN  D-7460 BALINGEN",
        "country": "DE"
    },
    "0040E1": {
        "oui_hex": "00-40-E1",
        "organization": "MARNER INTERNATIONAL, INC.",
        "address_1": "1617 93RD LANE NE",
        "address_2": "BLAINE  MN  55449",
        "country": "US"
    },
    "0040FE": {
        "oui_hex": "00-40-FE",
        "organization": "SYMPLEX COMMUNICATIONS",
        "address_1": "5 RESEARCH DRIVE",
        "address_2": "ANN ARBOR  MI  48103",
        "country": "US"
    },
    "0040E5": {
        "oui_hex": "00-40-E5",
        "organization": "SYBUS CORPORATION",
        "address_1": "2300 TALL PINE DRIVE-STE. #100",
        "address_2": "LARGO  FL  34641",
        "country": "US"
    },
    "0040A5": {
        "oui_hex": "00-40-A5",
        "organization": "CLINICOMP INTL.",
        "address_1": "4510 EXECCUTIVE DRIVE-STE.#200",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "004005": {
        "oui_hex": "00-40-05",
        "organization": "ANI COMMUNICATIONS INC.",
        "address_1": "8 ANZIO",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "0040D9": {
        "oui_hex": "00-40-D9",
        "organization": "AMERICAN MEGATRENDS INC.",
        "address_1": "6145F N BELT PARKWAY",
        "address_2": "NORCROSS  GA  30071",
        "country": "US"
    },
    "00404C": {
        "oui_hex": "00-40-4C",
        "organization": "HYPERTEC PTY LTD.",
        "address_1": "P.O. BOX 1782",
        "address_2": "",
        "country": "AU"
    },
    "00C030": {
        "oui_hex": "00-C0-30",
        "organization": "INTEGRATED ENGINEERING B. V.",
        "address_1": "ELLERMANSTRAAT 15",
        "address_2": "  THE",
        "country": "NL"
    },
    "00C0A6": {
        "oui_hex": "00-C0-A6",
        "organization": "EXICOM AUSTRALIA PTY. LTD",
        "address_1": "44-46 MANDARIN STREET",
        "address_2": "",
        "country": "AU"
    },
    "00C0CB": {
        "oui_hex": "00-C0-CB",
        "organization": "CONTROL TECHNOLOGY CORPORATION",
        "address_1": "25 SOUTH STREET",
        "address_2": "HOPKINTON  MA  01748",
        "country": "US"
    },
    "00C0EB": {
        "oui_hex": "00-C0-EB",
        "organization": "SEH COMPUTERTECHNIK GMBH",
        "address_1": "Suedring 11",
        "address_2": "",
        "country": "DE"
    },
    "0040DB": {
        "oui_hex": "00-40-DB",
        "organization": "ADVANCED TECHNICAL SOLUTIONS",
        "address_1": "8050 SEMINOLE OFFICE CENTER",
        "address_2": "SEMINOLE  FL  34642",
        "country": "US"
    },
    "00C092": {
        "oui_hex": "00-C0-92",
        "organization": "MENNEN MEDICAL INC.",
        "address_1": "10123 MAIN STREET",
        "address_2": "CLARENCE  NY  14031-2095",
        "country": "US"
    },
    "00C052": {
        "oui_hex": "00-C0-52",
        "organization": "BURR-BROWN",
        "address_1": "P.O. BOX 11400",
        "address_2": "TUCSON  AZ  85734-1400",
        "country": "US"
    },
    "00400E": {
        "oui_hex": "00-40-0E",
        "organization": "MEMOTEC, INC.",
        "address_1": "7755 Henri-Bourassa",
        "address_2": "MONTREAL, QUEBEC     H4S 1P7",
        "country": "CA"
    },
    "00C03D": {
        "oui_hex": "00-C0-3D",
        "organization": "WIESEMANN & THEIS GMBH",
        "address_1": "WITTENER STR. 312",
        "address_2": "",
        "country": "DE"
    },
    "0040C8": {
        "oui_hex": "00-40-C8",
        "organization": "MILAN TECHNOLOGY CORPORATION",
        "address_1": "894 ROSS DRIVE--STE #105",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "0040BA": {
        "oui_hex": "00-40-BA",
        "organization": "ALLIANT COMPUTER SYSTEMS CORP.",
        "address_1": "ONE MONARCH DRIVE",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "004038": {
        "oui_hex": "00-40-38",
        "organization": "TALENT ELECTRIC INCORPORATED",
        "address_1": "3RD FL., NO. 260, PA TEH ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0040D8": {
        "oui_hex": "00-40-D8",
        "organization": "OCEAN OFFICE AUTOMATION LTD.",
        "address_1": "4TH & 5TH FLOOR, KADER BLDG.",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "004088": {
        "oui_hex": "00-40-88",
        "organization": "MOBIUS TECHNOLOGIES, INC.",
        "address_1": "5835 DOYLE STREET",
        "address_2": "EMERYVILLE  CA  94608",
        "country": "US"
    },
    "004032": {
        "oui_hex": "00-40-32",
        "organization": "DIGITAL COMMUNICATIONS",
        "address_1": "ASSOCIATES, INC.",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0040C2": {
        "oui_hex": "00-40-C2",
        "organization": "APPLIED COMPUTING DEVICES",
        "address_1": "ALEPH PARK",
        "address_2": "TERRE HAUTE  IN  47802",
        "country": "US"
    },
    "0040D4": {
        "oui_hex": "00-40-D4",
        "organization": "GAGE TALKER CORP.",
        "address_1": "13680 NE 16TH STREET",
        "address_2": "BELLEVUE  WA  98005",
        "country": "US"
    },
    "0040CE": {
        "oui_hex": "00-40-CE",
        "organization": "NET-SOURCE, INC.",
        "address_1": "1265 EL CAMINO REAL",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "004062": {
        "oui_hex": "00-40-62",
        "organization": "E-SYSTEMS, INC./GARLAND DIV.",
        "address_1": "P.O. BOX 660023",
        "address_2": "DALLAS  TX  75266-0023",
        "country": "US"
    },
    "004034": {
        "oui_hex": "00-40-34",
        "organization": "BUSTEK CORPORATION",
        "address_1": "4151 BURTON DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00401C": {
        "oui_hex": "00-40-1C",
        "organization": "AST RESEARCH, INC.",
        "address_1": "MS 2-78",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "00400F": {
        "oui_hex": "00-40-0F",
        "organization": "DATACOM TECHNOLOGIES",
        "address_1": "11001 31ST PLACE WEST",
        "address_2": "EVERETT  WA  98204",
        "country": "US"
    },
    "004006": {
        "oui_hex": "00-40-06",
        "organization": "SAMPO TECHNOLOGY CORPORATION",
        "address_1": "26-2 TING-HU,",
        "address_2": "33334 TAIWAN  33334 TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0080AA": {
        "oui_hex": "00-80-AA",
        "organization": "MAXPEED",
        "address_1": "1120 CHESS DRIVE",
        "address_2": "FOSTER CITY  CA  94404",
        "country": "US"
    },
    "00C050": {
        "oui_hex": "00-C0-50",
        "organization": "TOYO DENKI SEIZO K.K.",
        "address_1": "4-6-32 HIGASHIKASHIWAGAYA",
        "address_2": "KANAGAWA  JAPAN  243-04",
        "country": "JP"
    },
    "0040C6": {
        "oui_hex": "00-40-C6",
        "organization": "FIBERNET RESEARCH, INC.",
        "address_1": "1 TARA BOULEVARD-#405",
        "address_2": "NASHUA  NH  03062",
        "country": "US"
    },
    "004047": {
        "oui_hex": "00-40-47",
        "organization": "WIND RIVER SYSTEMS",
        "address_1": "1010 ATLANTIC AVENUE",
        "address_2": "ALAMEDA  CA  94501",
        "country": "US"
    },
    "004050": {
        "oui_hex": "00-40-50",
        "organization": "IRONICS, INCORPORATED",
        "address_1": "767 WARREN RD",
        "address_2": "ITHACA  N.Y.  14850",
        "country": "US"
    },
    "008092": {
        "oui_hex": "00-80-92",
        "organization": "Silex Technology, Inc.",
        "address_1": "2-3-1 Hikaridai,",
        "address_2": "Kyoto    619-0237",
        "country": "JP"
    },
    "008093": {
        "oui_hex": "00-80-93",
        "organization": "XYRON CORPORATION",
        "address_1": "7864 LILY COURT",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00805A": {
        "oui_hex": "00-80-5A",
        "organization": "TULIP COMPUTERS INTERNAT'L B.V",
        "address_1": "P.O. BOX 3333",
        "address_2": "  THE",
        "country": "NL"
    },
    "004041": {
        "oui_hex": "00-40-41",
        "organization": "FUJIKURA LTD.",
        "address_1": "1-5-1, KIBA, KOTO-KU",
        "address_2": "",
        "country": "JP"
    },
    "00804E": {
        "oui_hex": "00-80-4E",
        "organization": "APEX COMPUTER COMPANY",
        "address_1": "4500 150TH AVENUE, NE",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "008055": {
        "oui_hex": "00-80-55",
        "organization": "FERMILAB",
        "address_1": "P.O. BOX 500, MS-234",
        "address_2": "BATAVIA  IL  60510",
        "country": "US"
    },
    "00802A": {
        "oui_hex": "00-80-2A",
        "organization": "TEST SYSTEMS & SIMULATIONS INC",
        "address_1": "32429 INDUSTRIAL DRIVE",
        "address_2": "MADISON HEIGHTS  MI  48071-1528",
        "country": "US"
    },
    "008035": {
        "oui_hex": "00-80-35",
        "organization": "TECHNOLOGY WORKS, INC.",
        "address_1": "4030 BRAKER LANE #350",
        "address_2": "AUSTIN  TX  78759",
        "country": "US"
    },
    "00807E": {
        "oui_hex": "00-80-7E",
        "organization": "SOUTHERN PACIFIC LTD.",
        "address_1": "SANWA BLDG., 2-16-20",
        "address_2": "JAPAN  JAPAN  220",
        "country": "JP"
    },
    "0080EF": {
        "oui_hex": "00-80-EF",
        "organization": "RATIONAL",
        "address_1": "3320 SCOTT BOULEVARD",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0080F0": {
        "oui_hex": "00-80-F0",
        "organization": "Panasonic Communications Co., Ltd.",
        "address_1": "4-1-62 Minoshima Hakata Fukuoka",
        "address_2": "    812-8531",
        "country": "JP"
    },
    "00801D": {
        "oui_hex": "00-80-1D",
        "organization": "INTEGRATED INFERENCE MACHINES",
        "address_1": "1468 EAST KATELLA",
        "address_2": "ANAHEIM  CA  92805",
        "country": "US"
    },
    "008075": {
        "oui_hex": "00-80-75",
        "organization": "PARSYTEC GMBH",
        "address_1": "JUELICHER STR. 338",
        "address_2": "  F.R.",
        "country": "DE"
    },
    "008051": {
        "oui_hex": "00-80-51",
        "organization": "FIBERMUX",
        "address_1": "9310 TOPANGA CANYON BLVD.",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "0080C6": {
        "oui_hex": "00-80-C6",
        "organization": "NATIONAL DATACOMM CORPORATION",
        "address_1": "2F, 28, INDUSTRY EAST 9TH RD.",
        "address_2": "TAIWAN  30077  TAIWAN  30077  R.O.C.",
        "country": "TW"
    },
    "0080C0": {
        "oui_hex": "00-80-C0",
        "organization": "PENRIL DATACOMM",
        "address_1": "1300 QUINCE ORCHARD BLVD.",
        "address_2": "GAITHERSBURG  MD  20878",
        "country": "US"
    },
    "00802E": {
        "oui_hex": "00-80-2E",
        "organization": "CASTLE ROCK COMPUTING",
        "address_1": "20837 BOYCE LANE",
        "address_2": "SARATOGA  CA  95070-4806",
        "country": "US"
    },
    "0080F2": {
        "oui_hex": "00-80-F2",
        "organization": "RAYCOM SYSTEMS INC",
        "address_1": "16525 SHERMAN WAY #C-8",
        "address_2": "VAN NUYS  CA  91406",
        "country": "US"
    },
    "0080BD": {
        "oui_hex": "00-80-BD",
        "organization": "THE FURUKAWA ELECTRIC CO., LTD",
        "address_1": "6-1, MARUNOUCHI 2-CHOME",
        "address_2": "  100",
        "country": "JP"
    },
    "008025": {
        "oui_hex": "00-80-25",
        "organization": "Telit Wireless Solutions GmbH",
        "address_1": "Mendelssohnstrasse15D",
        "address_2": "Hamburg    22761",
        "country": "DE"
    },
    "0080EA": {
        "oui_hex": "00-80-EA",
        "organization": "ADVA Optical Networking Ltd.",
        "address_1": "ADVAntage House",
        "address_2": "York    YO30 4RY",
        "country": "GB"
    },
    "00001E": {
        "oui_hex": "00-00-1E",
        "organization": "TELSIST INDUSTRIA ELECTRONICA",
        "address_1": "RUA VILHENA DE MORAES, 380",
        "address_2": "",
        "country": "BR"
    },
    "000050": {
        "oui_hex": "00-00-50",
        "organization": "RADISYS CORPORATION",
        "address_1": "15025 S.W. KOLL PARKWAY",
        "address_2": "BEAVERTON  OR  97006-6056",
        "country": "US"
    },
    "008004": {
        "oui_hex": "00-80-04",
        "organization": "ANTLOW COMMUNICATIONS, LTD.",
        "address_1": "4 COLTHROP WAY",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0080D0": {
        "oui_hex": "00-80-D0",
        "organization": "COMPUTER PERIPHERALS, INC.",
        "address_1": "667 RANCHO CONEJO BLVD.",
        "address_2": "NEWBURY PARK  CA  91320",
        "country": "US"
    },
    "008024": {
        "oui_hex": "00-80-24",
        "organization": "KALPANA, INC.",
        "address_1": "1154 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "008040": {
        "oui_hex": "00-80-40",
        "organization": "JOHN FLUKE MANUFACTURING CO.",
        "address_1": "P.O. BOX C9090-M/S 244F",
        "address_2": "EVERETT  WA  98206",
        "country": "US"
    },
    "008021": {
        "oui_hex": "00-80-21",
        "organization": "Alcatel Canada Inc.",
        "address_1": "349 Terry Fox Drive",
        "address_2": "Kanata  Ontario  K2K 2V6",
        "country": "CA"
    },
    "0080E8": {
        "oui_hex": "00-80-E8",
        "organization": "CUMULUS CORPORATIION",
        "address_1": "23500 MERCANTILE ROAD",
        "address_2": "CLEVELAND  OH  44122",
        "country": "US"
    },
    "008069": {
        "oui_hex": "00-80-69",
        "organization": "COMPUTONE SYSTEMS",
        "address_1": "1100 NORTHMEADOW PARKWAY",
        "address_2": "ROSWELL  GA  30076",
        "country": "US"
    },
    "00800D": {
        "oui_hex": "00-80-0D",
        "organization": "VOSSWINKEL F.U.",
        "address_1": "AM JOSTENHOF 15",
        "address_2": "",
        "country": "DE"
    },
    "0080D1": {
        "oui_hex": "00-80-D1",
        "organization": "KIMTRON CORPORATION",
        "address_1": "1709 JUNCTION COURT",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "008042": {
        "oui_hex": "00-80-42",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "00809A": {
        "oui_hex": "00-80-9A",
        "organization": "NOVUS NETWORKS LTD",
        "address_1": "JOHN SCOTT HOUSE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "008000": {
        "oui_hex": "00-80-00",
        "organization": "MULTITECH SYSTEMS, INC.",
        "address_1": "2205 WOODALE DRIVE",
        "address_2": "MOUNDS VIEW  MN  55112",
        "country": "US"
    },
    "0080ED": {
        "oui_hex": "00-80-ED",
        "organization": "IQ TECHNOLOGIES, INC.",
        "address_1": "11811 NE FIRST STREET",
        "address_2": "BELLEVUE  WA  98005",
        "country": "US"
    },
    "00804A": {
        "oui_hex": "00-80-4A",
        "organization": "PRO-LOG",
        "address_1": "12 UPPER RAGSDALE DRIVE",
        "address_2": "MONTEREY  CA  93940",
        "country": "US"
    },
    "000066": {
        "oui_hex": "00-00-66",
        "organization": "TALARIS SYSTEMS, INC.",
        "address_1": "11339 SORRENTO VALLEY ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "000049": {
        "oui_hex": "00-00-49",
        "organization": "APRICOT COMPUTERS, LTD",
        "address_1": "90 VINCENT DRIVE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000FA": {
        "oui_hex": "00-00-FA",
        "organization": "MICROSAGE COMPUTER SYSTEMS INC",
        "address_1": "680 SOUTH ROCK BLVD",
        "address_2": "RENO  NE  89502",
        "country": "US"
    },
    "0000D4": {
        "oui_hex": "00-00-D4",
        "organization": "PURE DATA LTD.",
        "address_1": "200 WEST BEAVER CREEK ROAD",
        "address_2": "L4B  1B4",
        "country": "CA"
    },
    "000019": {
        "oui_hex": "00-00-19",
        "organization": "APPLIED DYNAMICS INTERNATIONAL",
        "address_1": "3800 STONE SCHOOL ROAD",
        "address_2": "ANN ARBOR  MI  48104-2499",
        "country": "US"
    },
    "000015": {
        "oui_hex": "00-00-15",
        "organization": "DATAPOINT CORPORATION",
        "address_1": "9725 DATAPOINT DRIVE",
        "address_2": "SAN ANTONIO  TX  78284",
        "country": "US"
    },
    "00001C": {
        "oui_hex": "00-00-1C",
        "organization": "BELL TECHNOLOGIES",
        "address_1": "330 WARREN AVENUE",
        "address_2": "FREMONT  CA  94539",
        "country": "US"
    },
    "000034": {
        "oui_hex": "00-00-34",
        "organization": "NETWORK RESOURCES CORPORATION",
        "address_1": "61 EAST DAGGETT DRIVE",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "000022": {
        "oui_hex": "00-00-22",
        "organization": "VISUAL TECHNOLOGY INC.",
        "address_1": "1703 MIDDLESEX STREET",
        "address_2": "LOWELL  MA  01851",
        "country": "US"
    },
    "0000B5": {
        "oui_hex": "00-00-B5",
        "organization": "DATABILITY SOFTWARE SYS. INC.",
        "address_1": "ONE PALMER TERRACE",
        "address_2": "CARLSTADT  NJ  07072",
        "country": "US"
    },
    "00002F": {
        "oui_hex": "00-00-2F",
        "organization": "TIMEPLEX INC.",
        "address_1": "530 CHESTNUT RIDGE ROAD",
        "address_2": "WOODCLIFF LAKE  NJ  07675",
        "country": "US"
    },
    "0000B8": {
        "oui_hex": "00-00-B8",
        "organization": "SEIKOSHA CO., LTD.",
        "address_1": "SYSTEM EQUIPMENT DIVISION",
        "address_2": "",
        "country": "JP"
    },
    "0000E6": {
        "oui_hex": "00-00-E6",
        "organization": "APTOR PRODUITS DE COMM INDUST",
        "address_1": "61, CHEMIN DU VIEUX-CHENE",
        "address_2": "",
        "country": "FR"
    },
    "000084": {
        "oui_hex": "00-00-84",
        "organization": "SUPERNET",
        "address_1": "846 DEL REY AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00009A": {
        "oui_hex": "00-00-9A",
        "organization": "RC COMPUTER A/S",
        "address_1": "LAUTRUPBJERG 1",
        "address_2": "",
        "country": "DK"
    },
    "000027": {
        "oui_hex": "00-00-27",
        "organization": "JAPAN RADIO COMPANY",
        "address_1": "LABORATORY",
        "address_2": "",
        "country": "JP"
    },
    "0000E8": {
        "oui_hex": "00-00-E8",
        "organization": "ACCTON TECHNOLOGY CORP.",
        "address_1": "46750 FREMONT BLVD. #104",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00004B": {
        "oui_hex": "00-00-4B",
        "organization": "ICL DATA OY",
        "address_1": "KUTOMOTIE 16-18",
        "address_2": "",
        "country": "FI"
    },
    "0000E0": {
        "oui_hex": "00-00-E0",
        "organization": "QUADRAM CORP.",
        "address_1": "ONE QUAD WAY",
        "address_2": "NORCROSS  GA  30093",
        "country": "US"
    },
    "0000AB": {
        "oui_hex": "00-00-AB",
        "organization": "LOGIC MODELING CORPORATION",
        "address_1": "1520 MCCANDLESS DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "0080AC": {
        "oui_hex": "00-80-AC",
        "organization": "IMLOGIX, DIVISION OF GENESYS",
        "address_1": "1900 SUMMIT TOWER BLVD.STE#770",
        "address_2": "ORLANDO  FL  32810",
        "country": "US"
    },
    "00004F": {
        "oui_hex": "00-00-4F",
        "organization": "LOGICRAFT, INC.",
        "address_1": "22 COTTON ROAD",
        "address_2": "NASHUA  NH  03063",
        "country": "US"
    },
    "00006F": {
        "oui_hex": "00-00-6F",
        "organization": "Madge Ltd.",
        "address_1": "Madge House",
        "address_2": "Maindenhead  Berkshire  SL6 2HP",
        "country": "GB"
    },
    "000078": {
        "oui_hex": "00-00-78",
        "organization": "LABTAM LIMITED",
        "address_1": "43 MALCOLM ROAD   P.O. BOX297",
        "address_2": "",
        "country": "AU"
    },
    "00005A": {
        "oui_hex": "00-00-5A",
        "organization": "SysKonnect GmbH",
        "address_1": "SIEMENSSTRAßE 23",
        "address_2": "",
        "country": "DE"
    },
    "00005B": {
        "oui_hex": "00-00-5B",
        "organization": "ELTEC ELEKTRONIK AG",
        "address_1": "Galileo-Galilei-Strasse 11",
        "address_2": "",
        "country": "DE"
    },
    "000071": {
        "oui_hex": "00-00-71",
        "organization": "ADRA SYSTEMS INC.",
        "address_1": "59 TECHNOLOGY DRIVE",
        "address_2": "LOWELL  MA  01851",
        "country": "US"
    },
    "000073": {
        "oui_hex": "00-00-73",
        "organization": "SIECOR CORPORATION",
        "address_1": "P.O. BOX 13625",
        "address_2": "RESEARCH TRIANGLE PK  NC  27709",
        "country": "US"
    },
    "0000B9": {
        "oui_hex": "00-00-B9",
        "organization": "MCDONNELL DOUGLAS COMPUTER SYS",
        "address_1": "DIV MCDONNELL DOUGLAS INF SYS",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000BF": {
        "oui_hex": "00-00-BF",
        "organization": "SYMMETRIC COMPUTER SYSTEMS",
        "address_1": "1620 OAKLAND ROAD  SUITE D-200",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00002D": {
        "oui_hex": "00-00-2D",
        "organization": "CHROMATICS INC",
        "address_1": "2558 MOUNTAIN INDUSTRIAL BLVD",
        "address_2": "TUCKER  GA  30084",
        "country": "US"
    },
    "000018": {
        "oui_hex": "00-00-18",
        "organization": "WEBSTER COMPUTER CORPORATION",
        "address_1": "16040 REDWOOD LODGE ROAD",
        "address_2": "LOS GATOS  CA  95033-9260",
        "country": "US"
    },
    "0000C8": {
        "oui_hex": "00-00-C8",
        "organization": "ALTOS COMPUTER SYSTEMS",
        "address_1": "2641 ORCHARD PARKWAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0000D5": {
        "oui_hex": "00-00-D5",
        "organization": "MICROGNOSIS INTERNATIONAL",
        "address_1": "63 QUEEN VICTORIA STREET",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00003A": {
        "oui_hex": "00-00-3A",
        "organization": "CHYRON CORPORATION",
        "address_1": "265 SPAGNOLI ROAD",
        "address_2": "MELVILLE  NY  11747",
        "country": "US"
    },
    "000059": {
        "oui_hex": "00-00-59",
        "organization": "Hellige GMBH",
        "address_1": "Heinrich-von-Stephan-Str. 4",
        "address_2": "  West Gernany",
        "country": "DE"
    },
    "000069": {
        "oui_hex": "00-00-69",
        "organization": "CONCORD COMMUNICATIONS INC",
        "address_1": "753 FOREST STREET",
        "address_2": "MARLBOROUGH  MA  01752",
        "country": "US"
    },
    "0000E7": {
        "oui_hex": "00-00-E7",
        "organization": "Star Gate Technologies",
        "address_1": "29300 Aurora Road",
        "address_2": "Solon  OH  44139",
        "country": "US"
    },
    "00004D": {
        "oui_hex": "00-00-4D",
        "organization": "DCI CORPORATION",
        "address_1": "64J PRINCETON-HIGHTSTOWN RD",
        "address_2": "PRINCETON JUNCTION  NJ  08550",
        "country": "US"
    },
    "000023": {
        "oui_hex": "00-00-23",
        "organization": "ABB INDUSTRIAL SYSTEMS AB",
        "address_1": "DEPT. SEISY/LKSB",
        "address_2": "",
        "country": "SE"
    },
    "0000BE": {
        "oui_hex": "00-00-BE",
        "organization": "THE NTI GROUP",
        "address_1": "4701 PATRICK HENRY DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0000D9": {
        "oui_hex": "00-00-D9",
        "organization": "NIPPON TELEGRAPH & TELEPHONE",
        "address_1": "CORPORATION (NTT)",
        "address_2": "TOKYO  100-8116",
        "country": "JP"
    },
    "000080": {
        "oui_hex": "00-00-80",
        "organization": "CRAY COMMUNICATIONS A/S",
        "address_1": "SMEDEHOLM 12-14",
        "address_2": "",
        "country": "DK"
    },
    "08002A": {
        "oui_hex": "08-00-2A",
        "organization": "MOSAIC TECHNOLOGIES INC.",
        "address_1": "47 MANNING ROAD",
        "address_2": "BILLERICA  MA  01821-3970",
        "country": "US"
    },
    "080089": {
        "oui_hex": "08-00-89",
        "organization": "Kinetics",
        "address_1": "",
        "address_2": "Walnut Creek  CA",
        "country": "US"
    },
    "080086": {
        "oui_hex": "08-00-86",
        "organization": "KONICA MINOLTA HOLDINGS, INC.",
        "address_1": "1-6-1, Marunouchi,",
        "address_2": "Tokyo    100-0005",
        "country": "JP"
    },
    "080083": {
        "oui_hex": "08-00-83",
        "organization": "Seiko Instruments Inc.",
        "address_1": "8, Nakase 1-chome Mihama-ku",
        "address_2": "Chiba-shi  Chiba  261-8507",
        "country": "JP"
    },
    "080061": {
        "oui_hex": "08-00-61",
        "organization": "JAROGATE LTD.",
        "address_1": "197-213 LYHAM ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "08005F": {
        "oui_hex": "08-00-5F",
        "organization": "SABER TECHNOLOGY CORP.",
        "address_1": "2381 BERING DRIVE",
        "address_2": "SAN JOSE  CA  95131-1125",
        "country": "US"
    },
    "080058": {
        "oui_hex": "08-00-58",
        "organization": "SYSTEMS CONCEPTS",
        "address_1": "520 THIRD STREET",
        "address_2": "SAN FRANCISCO  CA  94107",
        "country": "US"
    },
    "080049": {
        "oui_hex": "08-00-49",
        "organization": "UNIVATION",
        "address_1": "1037 NORTH FAIR OAKS AVE.",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "080024": {
        "oui_hex": "08-00-24",
        "organization": "10NET COMMUNICATIONS/DCA",
        "address_1": "7777 WASHINGTON VILLAGE DR.",
        "address_2": "DAYTON  OH  45459-3957",
        "country": "US"
    },
    "080022": {
        "oui_hex": "08-00-22",
        "organization": "NBI INC.",
        "address_1": "3450 MITCHELL LANE",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "080020": {
        "oui_hex": "08-00-20",
        "organization": "Oracle Corporation",
        "address_1": "17 Network Circle",
        "address_2": "Menlo Park  CA  95025",
        "country": "US"
    },
    "08001F": {
        "oui_hex": "08-00-1F",
        "organization": "SHARP CORPORATION",
        "address_1": "ENGINEERING DEPARTMENT 6",
        "address_2": "NARA  639-11",
        "country": "JP"
    },
    "080014": {
        "oui_hex": "08-00-14",
        "organization": "EXCELAN",
        "address_1": "1599 FLICKINGER AVENUE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "AA0000": {
        "oui_hex": "AA-00-00",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "AA0001": {
        "oui_hex": "AA-00-01",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "AA0002": {
        "oui_hex": "AA-00-02",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "000007": {
        "oui_hex": "00-00-07",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "00801F": {
        "oui_hex": "00-80-1F",
        "organization": "KRUPP ATLAS ELECTRONIK GMBH",
        "address_1": "P.O. BOX 448545",
        "address_2": "",
        "country": "DE"
    },
    "080006": {
        "oui_hex": "08-00-06",
        "organization": "SIEMENS AG",
        "address_1": "Siemens IT Solutions and Services, SIS GO QM O",
        "address_2": "POB 2353  Fuerth  90713",
        "country": "DE"
    },
    "04E0C4": {
        "oui_hex": "04-E0-C4",
        "organization": "TRIUMPH-ADLER AG",
        "address_1": "HUNDINGSTRAßE 11B",
        "address_2": "",
        "country": "DE"
    },
    "020701": {
        "oui_hex": "02-07-01",
        "organization": "RACAL-DATACOM",
        "address_1": "LAN INTERNETWORKING DIVISION",
        "address_2": "BOXBOROUGH  MA  01719",
        "country": "US"
    },
    "080013": {
        "oui_hex": "08-00-13",
        "organization": "Exxon",
        "address_1": "",
        "address_2": "",
        "country": "US"
    },
    "00DD08": {
        "oui_hex": "00-DD-08",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "000005": {
        "oui_hex": "00-00-05",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "021C7C": {
        "oui_hex": "02-1C-7C",
        "organization": "PERQ SYSTEMS CORPORATION",
        "address_1": "2600 LIBERTY AVENUE",
        "address_2": "PITTSBURGH  PA  15230",
        "country": "US"
    },
    "080065": {
        "oui_hex": "08-00-65",
        "organization": "GENRAD INC.",
        "address_1": "300 BAKER AVENUE",
        "address_2": "CONCORD  MA  01742",
        "country": "US"
    },
    "84A9EA": {
        "oui_hex": "84-A9-EA",
        "organization": "Career Technologies USA",
        "address_1": "9134 Independence Ave",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "E405F8": {
        "oui_hex": "E4-05-F8",
        "organization": "Delta Innovation Technology Co., Ltd.",
        "address_1": "China Digital Kingdom Building, Chaoyang District",
        "address_2": "Beijing  Beijing  100102",
        "country": "CN"
    },
    "000009": {
        "oui_hex": "00-00-09",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "0080E9": {
        "oui_hex": "00-80-E9",
        "organization": "Madge Ltd.",
        "address_1": "Madge House",
        "address_2": "Maindenhead  Berkshire  SL6 2HP",
        "country": "GB"
    },
    "0040D6": {
        "oui_hex": "00-40-D6",
        "organization": "LOCAMATION B.V.",
        "address_1": "POSTBOX 360",
        "address_2": "    HOLLAND",
        "country": "NL"
    },
    "08004B": {
        "oui_hex": "08-00-4B",
        "organization": "Planning Research Corp.",
        "address_1": "1508 Kennedy Drive",
        "address_2": "Bellvue  NE  68005",
        "country": "US"
    },
    "02AA3C": {
        "oui_hex": "02-AA-3C",
        "organization": "OLIVETTI TELECOMM SPA (OLTECO)",
        "address_1": "20300 STEVENS  CREEK BLVD.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "080059": {
        "oui_hex": "08-00-59",
        "organization": "A/S MYCRON",
        "address_1": "PO BOX 6199",
        "address_2": "",
        "country": "NO"
    },
    "080008": {
        "oui_hex": "08-00-08",
        "organization": "BOLT BERANEK AND NEWMAN INC.",
        "address_1": "70 FAWCETT STREET",
        "address_2": "CAMBRIDGE  MA  02138",
        "country": "US"
    },
    "F47488": {
        "oui_hex": "F4-74-88",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "FCC233": {
        "oui_hex": "FC-C2-33",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "401175": {
        "oui_hex": "40-11-75",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8031F0": {
        "oui_hex": "80-31-F0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "583526": {
        "oui_hex": "58-35-26",
        "organization": "DEEPLET TECHNOLOGY CORP",
        "address_1": "5F,No.9,Lane235,Pao-Chiao Rd., Hsin-Tien,",
        "address_2": "New Taipei City      23145",
        "country": "TW"
    },
    "34B5A3": {
        "oui_hex": "34-B5-A3",
        "organization": "CIG SHANGHAI CO LTD",
        "address_1": "5th Floor, Building 8 No 2388 Chenhang Road",
        "address_2": "SHANGHAI    201114",
        "country": "CN"
    },
    "6C1DEB": {
        "oui_hex": "6C-1D-EB",
        "organization": "u-blox AG",
        "address_1": "Zuercherstrasse 68",
        "address_2": "Thalwil    8800",
        "country": "CH"
    },
    "2852F9": {
        "oui_hex": "28-52-F9",
        "organization": "Zhongxin Intelligent Times (Shenzhen) Co., Ltd.",
        "address_1": "3rd Floor,Building 46,Cuigang Industrial Zone 5,Fuyong Street,Baoan District",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "B8F853": {
        "oui_hex": "B8-F8-53",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "E0D083": {
        "oui_hex": "E0-D0-83",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "743C18": {
        "oui_hex": "74-3C-18",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "4C80BA": {
        "oui_hex": "4C-80-BA",
        "organization": "Wuhan Tianyu Information Industry Co., Ltd.",
        "address_1": "HUST Industry Park, East-Lake Development Zone",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "8C02FA": {
        "oui_hex": "8C-02-FA",
        "organization": "COMMANDO Networks Limited",
        "address_1": "Rm407, 4th floor, 3-2 HuaYuan Rd., DaLang Subdistrict, LongHua District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "F0264C": {
        "oui_hex": "F0-26-4C",
        "organization": "Sigrist-Photometer AG",
        "address_1": "Hofurlistrasse 1",
        "address_2": "Ennetbürgen    6373",
        "country": "CH"
    },
    "D03D52": {
        "oui_hex": "D0-3D-52",
        "organization": "Vaion Limited",
        "address_1": "The Charter Building, Charter Place",
        "address_2": "Uxbridge    UB8 1JG",
        "country": "GB"
    },
    "D80B9A": {
        "oui_hex": "D8-0B-9A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "AC8D34": {
        "oui_hex": "AC-8D-34",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "645299": {
        "oui_hex": "64-52-99",
        "organization": "The Chamberlain Group, Inc",
        "address_1": "300 Windsor Drive",
        "address_2": "Oak Brook  IL  60523",
        "country": "US"
    },
    "F875A4": {
        "oui_hex": "F8-75-A4",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "00D2B1": {
        "oui_hex": "00-D2-B1",
        "organization": "TPV Display Technology (Xiamen) Co.,Ltd.",
        "address_1": "No.1, Xianghai Road, Xiamen Torch Hi-Tech Industrial Development Zone",
        "address_2": "XM  Fujian  361101",
        "country": "CN"
    },
    "C0E434": {
        "oui_hex": "C0-E4-34",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "6C710D": {
        "oui_hex": "6C-71-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "246F8C": {
        "oui_hex": "24-6F-8C",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "1C1386": {
        "oui_hex": "1C-13-86",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "BC2EF6": {
        "oui_hex": "BC-2E-F6",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "4455C4": {
        "oui_hex": "44-55-C4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "000829": {
        "oui_hex": "00-08-29",
        "organization": "TOKYO ELECTRON DEVICE NAGASAKI LIMITED",
        "address_1": "6-42 Tsukuba-machi, Isahaya-shi",
        "address_2": "Nagasaki  Kyushu  854-0065",
        "country": "JP"
    },
    "1C4455": {
        "oui_hex": "1C-44-55",
        "organization": "Sieb & Meyer AG",
        "address_1": "Auf dem Schmaarkamp 21",
        "address_2": "Lueneburg    21339",
        "country": "DE"
    },
    "F88A5E": {
        "oui_hex": "F8-8A-5E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "5CE7A0": {
        "oui_hex": "5C-E7-A0",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "E01F88": {
        "oui_hex": "E0-1F-88",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "8CDC02": {
        "oui_hex": "8C-DC-02",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B4BC7C": {
        "oui_hex": "B4-BC-7C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E0AAB0": {
        "oui_hex": "E0-AA-B0",
        "organization": "SUNTAILI ENTERPRISE CO. LTD,",
        "address_1": "No. 6 ALY 3,LN 64 XINGFU RD, XINZHUNAG DISTRICT",
        "address_2": "NEW TAIPEI CITY    242",
        "country": "TW"
    },
    "683943": {
        "oui_hex": "68-39-43",
        "organization": "ittim",
        "address_1": "1202, No.6, Zhongguancun South Street, Haidian District,",
        "address_2": "beijing    100080",
        "country": "CN"
    },
    "10C65E": {
        "oui_hex": "10-C6-5E",
        "organization": "Adapt-IP",
        "address_1": "1671 Dell Avenue, Suite 130",
        "address_2": "Campbell  CA  95008-6900",
        "country": "US"
    },
    "7CA7B0": {
        "oui_hex": "7C-A7-B0",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268? Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "20311C": {
        "oui_hex": "20-31-1C",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "104F58": {
        "oui_hex": "10-4F-58",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B4E842": {
        "oui_hex": "B4-E8-42",
        "organization": "Hong Kong Bouffalo Lab Limited",
        "address_1": "RM 1903, 19/F Lee Garden One 33 Hysan Avenue, Causeway Bay",
        "address_2": "HongKong    999077",
        "country": "HK"
    },
    "0003CB": {
        "oui_hex": "00-03-CB",
        "organization": "SystemGear Co., Ltd.",
        "address_1": "1-9-14 Edobori",
        "address_2": "Osaka  Nishi-ku  550-0002",
        "country": "JP"
    },
    "F0A7B2": {
        "oui_hex": "F0-A7-B2",
        "organization": "FUTABA CORPORATION",
        "address_1": "629 Oshiba",
        "address_2": "Mobara  Chiba Prefecture  297-8588",
        "country": "JP"
    },
    "609B2D": {
        "oui_hex": "60-9B-2D",
        "organization": "JMACS Japan Co., Ltd.",
        "address_1": "11F, KM Nishi-Umeda bldg., 7-20-1 Fukushima, Fukushima-ku",
        "address_2": "Osaka-city  Osaka  553-0003",
        "country": "JP"
    },
    "14A32F": {
        "oui_hex": "14-A3-2F",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "04D3B5": {
        "oui_hex": "04-D3-B5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "00BB1C": {
        "oui_hex": "00-BB-1C",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "80AC7C": {
        "oui_hex": "80-AC-7C",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "DC4BFE": {
        "oui_hex": "DC-4B-FE",
        "organization": "Shenzhen Belon Technology CO.,LTD",
        "address_1": "Tsinghua Information",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "506255": {
        "oui_hex": "50-62-55",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "58D50A": {
        "oui_hex": "58-D5-0A",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "88A303": {
        "oui_hex": "88-A3-03",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCDE90": {
        "oui_hex": "FC-DE-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1854CF": {
        "oui_hex": "18-54-CF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "80795D": {
        "oui_hex": "80-79-5D",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "E884C6": {
        "oui_hex": "E8-84-C6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "642CAC": {
        "oui_hex": "64-2C-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "08CC27": {
        "oui_hex": "08-CC-27",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "04D395": {
        "oui_hex": "04-D3-95",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "E09806": {
        "oui_hex": "E0-98-06",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F4CFA2": {
        "oui_hex": "F4-CF-A2",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F81E6F": {
        "oui_hex": "F8-1E-6F",
        "organization": "EBG compleo GmbH",
        "address_1": "Oberste-Wilms-Straße 15a",
        "address_2": "Dortmund  Nordrhein-Westfalen  44309",
        "country": "DE"
    },
    "F0A35A": {
        "oui_hex": "F0-A3-5A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "608373": {
        "oui_hex": "60-83-73",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84AD8D": {
        "oui_hex": "84-AD-8D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "74428B": {
        "oui_hex": "74-42-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "149138": {
        "oui_hex": "14-91-38",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "6C410E": {
        "oui_hex": "6C-41-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6C310E": {
        "oui_hex": "6C-31-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2877F1": {
        "oui_hex": "28-77-F1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A8E77D": {
        "oui_hex": "A8-E7-7D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "DC543D": {
        "oui_hex": "DC-54-3D",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "0C8447": {
        "oui_hex": "0C-84-47",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "9C6B72": {
        "oui_hex": "9C-6B-72",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "50C6AD": {
        "oui_hex": "50-C6-AD",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "748A28": {
        "oui_hex": "74-8A-28",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "D42493": {
        "oui_hex": "D4-24-93",
        "organization": "GW Technologies Co.,Ltd",
        "address_1": "Building 16,No.8,Heying Road,Changping District",
        "address_2": "Beijing  Beijing  102200",
        "country": "CN"
    },
    "0023E6": {
        "oui_hex": "00-23-E6",
        "organization": "Innovation Farm, Inc.",
        "address_1": "47-8, Hasunuma-cho",
        "address_2": "Itabashi-ku  Tokyo  174-8580",
        "country": "JP"
    },
    "ECA940": {
        "oui_hex": "EC-A9-40",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FC8596": {
        "oui_hex": "FC-85-96",
        "organization": "Axonne Inc.",
        "address_1": "1290 Kifer Rd. #301",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "5CB4E2": {
        "oui_hex": "5C-B4-E2",
        "organization": "Inspur Software Group Ltd.",
        "address_1": "No. 1036, Langchao Road",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "3C510E": {
        "oui_hex": "3C-51-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D8AED0": {
        "oui_hex": "D8-AE-D0",
        "organization": "Shanghai Engineering Science & Technology Co.,LTD CGNPC",
        "address_1": "No.1588, Rd Zixing",
        "address_2": "Shanghai  Shanghai  200241",
        "country": "CN"
    },
    "E0859A": {
        "oui_hex": "E0-85-9A",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0C42A1": {
        "oui_hex": "0C-42-A1",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "B47AF1": {
        "oui_hex": "B4-7A-F1",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "349F7B": {
        "oui_hex": "34-9F-7B",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "F4D9C6": {
        "oui_hex": "F4-D9-C6",
        "organization": "UNIONMAN TECHNOLOGY CO.,LTD",
        "address_1": "No.5,Huitai Road,Huinan High-Tech Park,Huiao Highway",
        "address_2": "Huizhou  Guangdong  516025",
        "country": "CN"
    },
    "34F150": {
        "oui_hex": "34-F1-50",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "CC5289": {
        "oui_hex": "CC-52-89",
        "organization": "SHENZHEN OPTFOCUS TECHNOLOGY.,LTD",
        "address_1": "Floor 3, Building No.7,Tangtou 3rd Industrial Park,Shiyan Street of BaoAn District",
        "address_2": "ShenZhen    518000",
        "country": "CN"
    },
    "CC5D78": {
        "oui_hex": "CC-5D-78",
        "organization": "JTD Consulting",
        "address_1": "92 King Street South, Suite 200",
        "address_2": "Waterloo  Ontario  N2J 1P5",
        "country": "CA"
    },
    "BCF9F2": {
        "oui_hex": "BC-F9-F2",
        "organization": "TEKO",
        "address_1": "Prospect Pobedy, 19",
        "address_2": "Kazan  Republic of Tatarstan  420138",
        "country": "RU"
    },
    "000EA4": {
        "oui_hex": "00-0E-A4",
        "organization": "Quantum Corp.",
        "address_1": "8560 Upland Dr.",
        "address_2": "Englewood  CA  80112",
        "country": "US"
    },
    "005084": {
        "oui_hex": "00-50-84",
        "organization": "Quantum Corp.",
        "address_1": "8560 Upland Dr.",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "809F9B": {
        "oui_hex": "80-9F-9B",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "A82BCD": {
        "oui_hex": "A8-2B-CD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "48DC2D": {
        "oui_hex": "48-DC-2D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ACEB51": {
        "oui_hex": "AC-EB-51",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "6010A2": {
        "oui_hex": "60-10-A2",
        "organization": "Crompton Instruments",
        "address_1": "12 Freebournes Road",
        "address_2": "Witham  Essex  CM8 3AH",
        "country": "GB"
    },
    "C4B239": {
        "oui_hex": "C4-B2-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B0A454": {
        "oui_hex": "B0-A4-54",
        "organization": "Tripwire Inc.",
        "address_1": "308 SW 2nd Avenue Suite 400",
        "address_2": "Portland  OR  97204",
        "country": "US"
    },
    "6490C1": {
        "oui_hex": "64-90-C1",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "CC5CDE": {
        "oui_hex": "CC-5C-DE",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "60CE86": {
        "oui_hex": "60-CE-86",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "4C4FEE": {
        "oui_hex": "4C-4F-EE",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "4CE175": {
        "oui_hex": "4C-E1-75",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A824B8": {
        "oui_hex": "A8-24-B8",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "000CE6": {
        "oui_hex": "00-0C-E6",
        "organization": "Fortinet Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "9055DE": {
        "oui_hex": "90-55-DE",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E8910F": {
        "oui_hex": "E8-91-0F",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D005E4": {
        "oui_hex": "D0-05-E4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "30AAE4": {
        "oui_hex": "30-AA-E4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "14AB56": {
        "oui_hex": "14-AB-56",
        "organization": "WUXI FUNIDE DIGITAL CO.,LTD",
        "address_1": "No. 38 East Chunhui Road, Xishan Economic & Technology Development Zone",
        "address_2": "WUXI  JIANGSU  214101",
        "country": "CN"
    },
    "E8D8D1": {
        "oui_hex": "E8-D8-D1",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "28CDC4": {
        "oui_hex": "28-CD-C4",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "000CDF": {
        "oui_hex": "00-0C-DF",
        "organization": "JAI Manufacturing",
        "address_1": "2960-14 Uenojo Nishikata",
        "address_2": "Kushima  Miyazaki  888-0004",
        "country": "JP"
    },
    "2C91AB": {
        "oui_hex": "2C-91-AB",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "807B3E": {
        "oui_hex": "80-7B-3E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F8F1E6": {
        "oui_hex": "F8-F1-E6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88A9B7": {
        "oui_hex": "88-A9-B7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "ECCED7": {
        "oui_hex": "EC-CE-D7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48EB62": {
        "oui_hex": "48-EB-62",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "5CE176": {
        "oui_hex": "5C-E1-76",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "AC9085": {
        "oui_hex": "AC-90-85",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3448ED": {
        "oui_hex": "34-48-ED",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "3C5731": {
        "oui_hex": "3C-57-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "6C55E8": {
        "oui_hex": "6C-55-E8",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "342FBD": {
        "oui_hex": "34-2F-BD",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "A02D13": {
        "oui_hex": "A0-2D-13",
        "organization": "AirTies Wireless Networks",
        "address_1": "Esentepe Mah., Kore ?ehitleri Cad.",
        "address_2": "Istanbul  ?i?li  34360",
        "country": "TR"
    },
    "8468C8": {
        "oui_hex": "84-68-C8",
        "organization": "TOTOLINK TECHNOLOGY INT‘L LIMITED",
        "address_1": "ROOM 702,7/F SPA CENTER NO 53055 LOCKHART ROAD",
        "address_2": "WAN CHAI    999077",
        "country": "HK"
    },
    "9C28F7": {
        "oui_hex": "9C-28-F7",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "10521C": {
        "oui_hex": "10-52-1C",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "6C42AB": {
        "oui_hex": "6C-42-AB",
        "organization": "Subscriber Networks, Inc.",
        "address_1": "148 W. State Street",
        "address_2": "Kennett Square  PA  19348",
        "country": "US"
    },
    "64F6F7": {
        "oui_hex": "64-F6-F7",
        "organization": "Anhui Dynamic Power Co., Ltd.",
        "address_1": "NO.20 Jinniu Mid Road,",
        "address_2": "Xuancheng  Anhui  242100",
        "country": "CN"
    },
    "941C56": {
        "oui_hex": "94-1C-56",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "D80BCB": {
        "oui_hex": "D8-0B-CB",
        "organization": "Telink Semiconductor (Shanghai) Co., Ltd.",
        "address_1": "No. 1500 Zuchongzhi Rd, Building #3",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "F0F0A4": {
        "oui_hex": "F0-F0-A4",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "C0D682": {
        "oui_hex": "C0-D6-82",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "CC2D1B": {
        "oui_hex": "CC-2D-1B",
        "organization": "SFR",
        "address_1": "12 rue jean-philippe Rameau CS 80001",
        "address_2": "La plaine saint denis   FRANCE  93634",
        "country": "FR"
    },
    "80E540": {
        "oui_hex": "80-E5-40",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000DB4": {
        "oui_hex": "00-0D-B4",
        "organization": "Stormshield",
        "address_1": "2-10 rue Marceau",
        "address_2": "ISSY LES MOULINEAUX    92130",
        "country": "FR"
    },
    "2CF05D": {
        "oui_hex": "2C-F0-5D",
        "organization": "Micro-Star INTL CO., LTD.",
        "address_1": "No.69, Lide St.,",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "943BB0": {
        "oui_hex": "94-3B-B0",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "9043E2": {
        "oui_hex": "90-43-E2",
        "organization": "Cornami, Inc",
        "address_1": "300 Orchard City Dr, Suite 131",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "803049": {
        "oui_hex": "80-30-49",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "E84943": {
        "oui_hex": "E8-49-43",
        "organization": "YUGE Information technology Co. Ltd",
        "address_1": "Room 303, Building No. 6, ShengRong Rd. 88, Pudong, Shanghai",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "501408": {
        "oui_hex": "50-14-08",
        "organization": "AiNET",
        "address_1": "11700 MONTGOMERY RD",
        "address_2": "BELTSVILLE  MD  20705-1159",
        "country": "US"
    },
    "289AF7": {
        "oui_hex": "28-9A-F7",
        "organization": "ADVA Optical Networking Ltd.",
        "address_1": "ADVAntage House",
        "address_2": "York    YO30 4RY",
        "country": "GB"
    },
    "2811EC": {
        "oui_hex": "28-11-EC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B0B194": {
        "oui_hex": "B0-B1-94",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E42686": {
        "oui_hex": "E4-26-86",
        "organization": "DWnet Technologies(Suzhou) Corporation",
        "address_1": "No.8,Tangzhuang Road, Suzhou Industrial Park, Jiangsu, China",
        "address_2": "Suzhou    21500",
        "country": "CN"
    },
    "38EB47": {
        "oui_hex": "38-EB-47",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "10C3AB": {
        "oui_hex": "10-C3-AB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00692D": {
        "oui_hex": "00-69-2D",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "0C3796": {
        "oui_hex": "0C-37-96",
        "organization": "BIZLINK TECHNOLOGY, INC.",
        "address_1": "47211 BAYSIDE PARKWAY",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "F4032A": {
        "oui_hex": "F4-03-2A",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "147740": {
        "oui_hex": "14-77-40",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B4157E": {
        "oui_hex": "B4-15-7E",
        "organization": "Celona Inc.",
        "address_1": "10061, Bubb Road Suite 300",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18D98F": {
        "oui_hex": "18-D9-8F",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "645E2C": {
        "oui_hex": "64-5E-2C",
        "organization": "IRay Technology Co., Ltd.",
        "address_1": "11th Guiyang St.,",
        "address_2": "Yantai  Shandong  264000",
        "country": "CN"
    },
    "703811": {
        "oui_hex": "70-38-11",
        "organization": "Siemens Mobility Limited",
        "address_1": "17 Langley Park Way",
        "address_2": "Chippenham  Wiltshire  SN15 1GG",
        "country": "GB"
    },
    "00E0EC": {
        "oui_hex": "00-E0-EC",
        "organization": "CELESTICA INC.",
        "address_1": "1900-5140 Yonge Street PO Box 42",
        "address_2": "Toronto  Ontario  M2N 6L7",
        "country": "CA"
    },
    "B89047": {
        "oui_hex": "B8-90-47",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "646266": {
        "oui_hex": "64-62-66",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "487AF6": {
        "oui_hex": "48-7A-F6",
        "organization": "NCS ELECTRICAL SDN BHD",
        "address_1": "NO. 20, 22, 24, 26, JALAN 1/3, RAWANG INTEGRATED INDUSTRIAL PARK, 48000 Rawang Selangor, MALAYSIA",
        "address_2": "RAWANG  SELANGOR  48000",
        "country": "MY"
    },
    "486E70": {
        "oui_hex": "48-6E-70",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "601D9D": {
        "oui_hex": "60-1D-9D",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou, Industrial Park",
        "address_2": "Mianyang  Sichuan  622650",
        "country": "CN"
    },
    "20826A": {
        "oui_hex": "20-82-6A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D85F77": {
        "oui_hex": "D8-5F-77",
        "organization": "Telink Semiconductor (Shanghai) Co., Ltd.",
        "address_1": "No. 1500 Zuchongzhi Rd, Building #3",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "2C97ED": {
        "oui_hex": "2C-97-ED",
        "organization": "Sony Imaging Products & Solutions Inc.",
        "address_1": "konan 1-7-1",
        "address_2": "minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "909C4A": {
        "oui_hex": "90-9C-4A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "908C43": {
        "oui_hex": "90-8C-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "188A6A": {
        "oui_hex": "18-8A-6A",
        "organization": "AVPro Global Hldgs",
        "address_1": "2222 E 52nd Steeet N",
        "address_2": "Sioux Falls  SD  57104",
        "country": "US"
    },
    "3C7D0A": {
        "oui_hex": "3C-7D-0A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F01090": {
        "oui_hex": "F0-10-90",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "2050E7": {
        "oui_hex": "20-50-E7",
        "organization": "AMPAK Technology,Inc.",
        "address_1": "3F, No.15-1 Zhonghua Road, Hsinchu Industrail Park, Hukou,",
        "address_2": "Hsinchu  Hsinchu,Taiwan R.O.C.  30352",
        "country": "TW"
    },
    "3822E2": {
        "oui_hex": "38-22-E2",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "701F3C": {
        "oui_hex": "70-1F-3C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D48A39": {
        "oui_hex": "D4-8A-39",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E4F3C4": {
        "oui_hex": "E4-F3-C4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C2F4E": {
        "oui_hex": "9C-2F-4E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D8A8C8": {
        "oui_hex": "D8-A8-C8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "08BFA0": {
        "oui_hex": "08-BF-A0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5C5578": {
        "oui_hex": "5C-55-78",
        "organization": "iryx corp",
        "address_1": "14 Hughes",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "B8C6AA": {
        "oui_hex": "B8-C6-AA",
        "organization": "Earda Technologies co Ltd",
        "address_1": "Block A,Lianfeng Creative Park, #2 Jisheng Rd., Nansha District",
        "address_2": "Guangzhou  Guangdong  511455",
        "country": "CN"
    },
    "54AED0": {
        "oui_hex": "54-AE-D0",
        "organization": "DASAN Networks, Inc.",
        "address_1": "DASAN Tower, 49, Daewangpangyo-ro, 644 Beon-gil, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13493",
        "country": "KR"
    },
    "08C0EB": {
        "oui_hex": "08-C0-EB",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "E4E112": {
        "oui_hex": "E4-E1-12",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3414B5": {
        "oui_hex": "34-14-B5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D003EB": {
        "oui_hex": "D0-03-EB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "94DB56": {
        "oui_hex": "94-DB-56",
        "organization": "Sony Home Entertainment&Sound Products Inc",
        "address_1": "Sony City Osaki 2-10-1 Osaki Shinagawa-ku",
        "address_2": "Tokyo  Japan  141-8610",
        "country": "JP"
    },
    "889E68": {
        "oui_hex": "88-9E-68",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "6409AC": {
        "oui_hex": "64-09-AC",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "743AEF": {
        "oui_hex": "74-3A-EF",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "884-3, Seongnam-daero, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13517",
        "country": "KR"
    },
    "189E2C": {
        "oui_hex": "18-9E-2C",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "40DEAD": {
        "oui_hex": "40-DE-AD",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "6CF712": {
        "oui_hex": "6C-F7-12",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "68B9D3": {
        "oui_hex": "68-B9-D3",
        "organization": "Shenzhen Trolink Technology CO, LTD",
        "address_1": "201 B building 4 shijie, Chashu industry 505 block, Baoan airport Sanwei community, Hangcheng street Baoan area.",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "4CC53E": {
        "oui_hex": "4C-C5-3E",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "9056FC": {
        "oui_hex": "90-56-FC",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "1070FD": {
        "oui_hex": "10-70-FD",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "98ED5C": {
        "oui_hex": "98-ED-5C",
        "organization": "Tesla,Inc.",
        "address_1": "3500 Deer Creek Road",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "C44268": {
        "oui_hex": "C4-42-68",
        "organization": "CRESTRON ELECTRONICS, INC.",
        "address_1": "15 Volvo Drive",
        "address_2": "Rockleigh  NJ  07647",
        "country": "US"
    },
    "B86392": {
        "oui_hex": "B8-63-92",
        "organization": "GUANGDONG GENIUS TECHNOLOGY CO., LTD.",
        "address_1": "No.168, Middle Road Of East Gate",
        "address_2": "Xiaobian Community  Chang'an Town  523851",
        "country": "CN"
    },
    "78AA82": {
        "oui_hex": "78-AA-82",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "5471DD": {
        "oui_hex": "54-71-DD",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "40F520": {
        "oui_hex": "40-F5-20",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "38F601": {
        "oui_hex": "38-F6-01",
        "organization": "Solid State Storage Technology Corporation",
        "address_1": "21F, 392, Ruey Kuang Road, Neihu",
        "address_2": " Taipei    11492",
        "country": "TW"
    },
    "605464": {
        "oui_hex": "60-54-64",
        "organization": "Eyedro Green Solutions Inc.",
        "address_1": "130 Weber St W, Suite 201",
        "address_2": "Kitchener  Ontario  N2H4A2",
        "country": "CA"
    },
    "206C8A": {
        "oui_hex": "20-6C-8A",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "348584": {
        "oui_hex": "34-85-84",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "4018B1": {
        "oui_hex": "40-18-B1",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "E4A749": {
        "oui_hex": "E4-A7-49",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "84D6C5": {
        "oui_hex": "84-D6-C5",
        "organization": "SolarEdge Technologies",
        "address_1": "1 Abba Eban St.",
        "address_2": "Herzelia    46725",
        "country": "IL"
    },
    "885BDD": {
        "oui_hex": "88-5B-DD",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "D89136": {
        "oui_hex": "D8-91-36",
        "organization": "Dover Fueling Solutions",
        "address_1": "Industrieweg 5",
        "address_2": "Bladel  NBR  5531AD",
        "country": "NL"
    },
    "C88314": {
        "oui_hex": "C8-83-14",
        "organization": "Tempo Communications",
        "address_1": "1390 Aspen Way",
        "address_2": "Vista  CA  92081",
        "country": "US"
    },
    "FC956A": {
        "oui_hex": "FC-95-6A",
        "organization": "OCTAGON SYSTEMS CORP.",
        "address_1": "7403 Church Ranch Blvd",
        "address_2": "Westminster  CO  80021",
        "country": "US"
    },
    "B8E3EE": {
        "oui_hex": "B8-E3-EE",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "24C8D3": {
        "oui_hex": "24-C8-D3",
        "organization": "McWane India Pvt Ltd",
        "address_1": "483, Kamaraj Road, Upplipalayam",
        "address_2": "Coimbatore  Tamil Nadu  641015",
        "country": "IN"
    },
    "884033": {
        "oui_hex": "88-40-33",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "AC7A56": {
        "oui_hex": "AC-7A-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C0A66D": {
        "oui_hex": "C0-A6-6D",
        "organization": "Inspur Group Co., Ltd.",
        "address_1": "No.1036 Langchao Rd.",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "70F096": {
        "oui_hex": "70-F0-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "40B31E": {
        "oui_hex": "40-B3-1E",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "E0F6B5": {
        "oui_hex": "E0-F6-B5",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "448DBF": {
        "oui_hex": "44-8D-BF",
        "organization": "Rhino Mobility LLC",
        "address_1": "8 The Green, Suite A",
        "address_2": "Dover  DE  19901",
        "country": "US"
    },
    "00051E": {
        "oui_hex": "00-05-1E",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "948AC6": {
        "oui_hex": "94-8A-C6",
        "organization": "Realme Chongqing Mobile Telecommunications Corp.,Ltd.",
        "address_1": "No.178 Yulong Avenue, Yufengshan, Yubei District, Chongqing.",
        "address_2": "Chongqing   China  401120",
        "country": "CN"
    },
    "E0D462": {
        "oui_hex": "E0-D4-62",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "909838": {
        "oui_hex": "90-98-38",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0012F2": {
        "oui_hex": "00-12-F2",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "C4F57C": {
        "oui_hex": "C4-F5-7C",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0020A6": {
        "oui_hex": "00-20-A6",
        "organization": "Proxim Wireless",
        "address_1": "2114 Ringwood Ave",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "5850ED": {
        "oui_hex": "58-50-ED",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "988B0A": {
        "oui_hex": "98-8B-0A",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "BCBAC2": {
        "oui_hex": "BC-BA-C2",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "ACCB51": {
        "oui_hex": "AC-CB-51",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "2C9FFB": {
        "oui_hex": "2C-9F-FB",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "84CCA8": {
        "oui_hex": "84-CC-A8",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "0C14D2": {
        "oui_hex": "0C-14-D2",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "708CBB": {
        "oui_hex": "70-8C-BB",
        "organization": "MIMODISPLAYKOREA",
        "address_1": "#812, 19, Ojeongongeop-gil",
        "address_2": "Uiwang-si  Gyeonggi-do  16072",
        "country": "KR"
    },
    "987ECA": {
        "oui_hex": "98-7E-CA",
        "organization": "Inventus Power Eletronica do Brasil LTDA",
        "address_1": "Av Buriti, 4285 Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075000",
        "country": "BR"
    },
    "F0B022": {
        "oui_hex": "F0-B0-22",
        "organization": "TOHO Electronics INC.",
        "address_1": "1-13-21 Tanashioda, Chuo-Ku",
        "address_2": "Sagamihara-City  Kanagawa  252-0245",
        "country": "JP"
    },
    "50382F": {
        "oui_hex": "50-38-2F",
        "organization": "ASE Group Chung-Li",
        "address_1": "No 550,Chung-Hwa Road Section1",
        "address_2": "Chung-Li , Taoyuan  Taoyuan  32016",
        "country": "TW"
    },
    "6C2F8A": {
        "oui_hex": "6C-2F-8A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B848AA": {
        "oui_hex": "B8-48-AA",
        "organization": "EM Microelectronic",
        "address_1": "Rue des Sors 3",
        "address_2": "Marin-Epagnier  Neuchatel  2074",
        "country": "CH"
    },
    "D834EE": {
        "oui_hex": "D8-34-EE",
        "organization": "Stem Audio",
        "address_1": "2552 White Road, Suite A",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "D4F829": {
        "oui_hex": "D4-F8-29",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "244BFE": {
        "oui_hex": "24-4B-FE",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "28B371": {
        "oui_hex": "28-B3-71",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E06234": {
        "oui_hex": "E0-62-34",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F8572E": {
        "oui_hex": "F8-57-2E",
        "organization": "Core Brands, LLC",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "001C91": {
        "oui_hex": "00-1C-91",
        "organization": "Gefen LLC",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "08ACC4": {
        "oui_hex": "08-AC-C4",
        "organization": "FMTech",
        "address_1": "yuehai",
        "address_2": "ShenZhen    518000",
        "country": "CN"
    },
    "DC503A": {
        "oui_hex": "DC-50-3A",
        "organization": "Nanjing Ticom Tech Co., Ltd.",
        "address_1": "No.35 Fenghui Road, Yuhuatai District",
        "address_2": "Nanjing  Jiangsu  210039",
        "country": "CN"
    },
    "18473D": {
        "oui_hex": "18-47-3D",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "F82F65": {
        "oui_hex": "F8-2F-65",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0831A4": {
        "oui_hex": "08-31-A4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C014FE": {
        "oui_hex": "C0-14-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7CAD4F": {
        "oui_hex": "7C-AD-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A8E978": {
        "oui_hex": "A8-E9-78",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "7CDDE9": {
        "oui_hex": "7C-DD-E9",
        "organization": "ATOM tech Inc.",
        "address_1": "Sky Menor Yokohama 422, 2-11-2 Takashima, Nishi-ku",
        "address_2": "Yokohama-shi  Kanagawa  220-0011",
        "country": "JP"
    },
    "F86BD9": {
        "oui_hex": "F8-6B-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "44F4E7": {
        "oui_hex": "44-F4-E7",
        "organization": "Cohesity Inc",
        "address_1": "300 park ave",
        "address_2": "san jose  CA  95110",
        "country": "US"
    },
    "D477B2": {
        "oui_hex": "D4-77-B2",
        "organization": "Netix Global B.V.",
        "address_1": "1119RB Schipol - Rijk, Beechavenue, 113, Schipol,",
        "address_2": "Amsterdam NL    1119",
        "country": "NL"
    },
    "70B5E8": {
        "oui_hex": "70-B5-E8",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "942533": {
        "oui_hex": "94-25-33",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "605661": {
        "oui_hex": "60-56-61",
        "organization": "IXECLOUD Tech",
        "address_1": "118, 3rd Floor, Building 195, Area 1 Beiwa Road,Haidian District, Beijing",
        "address_2": "Beijing    100000",
        "country": "CN"
    },
    "0C599C": {
        "oui_hex": "0C-59-9C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "706979": {
        "oui_hex": "70-69-79",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "FC609B": {
        "oui_hex": "FC-60-9B",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "E8A1F8": {
        "oui_hex": "E8-A1-F8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "98A942": {
        "oui_hex": "98-A9-42",
        "organization": "Guangzhou Tozed Kangwei Intelligent Technology Co., LTD",
        "address_1": "Room 1301, NO. 37 Jinlong , Nansha Street, Xiangjiang Financial Business Center, Nansha District",
        "address_2": "Guangzhou  Guangdong  511458",
        "country": "CN"
    },
    "108B6A": {
        "oui_hex": "10-8B-6A",
        "organization": "Antailiye Technology Co.,Ltd",
        "address_1": "7/F,Zhengjiyuan Buiding,2 Road,Qianjing, Xixiang, Baoan District,Shenzhen",
        "address_2": "SHEN ZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "304240": {
        "oui_hex": "30-42-40",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4C2113": {
        "oui_hex": "4C-21-13",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai",
        "address_2": "Shanghai     201206",
        "country": "CN"
    },
    "802DBF": {
        "oui_hex": "80-2D-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "60F677": {
        "oui_hex": "60-F6-77",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A08869": {
        "oui_hex": "A0-88-69",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "74E5F9": {
        "oui_hex": "74-E5-F9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "80000B": {
        "oui_hex": "80-00-0B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "24F150": {
        "oui_hex": "24-F1-50",
        "organization": "Guangzhou Qi'an Technology Co., Ltd.",
        "address_1": "No. 3, Dasonggang, Jiangnan Avenue Middle Road, Haizhu District, Guangzhou (office only)",
        "address_2": "Guangzhou  Guangdong  510220",
        "country": "CN"
    },
    "14C88B": {
        "oui_hex": "14-C8-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "EC2651": {
        "oui_hex": "EC-26-51",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "183EEF": {
        "oui_hex": "18-3E-EF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "40882F": {
        "oui_hex": "40-88-2F",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "E43D1A": {
        "oui_hex": "E4-3D-1A",
        "organization": "Broadcom Limited",
        "address_1": "15191 Alton Parkway",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "607EC9": {
        "oui_hex": "60-7E-C9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "08FA79": {
        "oui_hex": "08-FA-79",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "8C5EBD": {
        "oui_hex": "8C-5E-BD",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3CF011": {
        "oui_hex": "3C-F0-11",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "644C36": {
        "oui_hex": "64-4C-36",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4889E7": {
        "oui_hex": "48-89-E7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "24EE9A": {
        "oui_hex": "24-EE-9A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5C879C": {
        "oui_hex": "5C-87-9C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "50EB71": {
        "oui_hex": "50-EB-71",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0CDD24": {
        "oui_hex": "0C-DD-24",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "34415D": {
        "oui_hex": "34-41-5D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "94B86D": {
        "oui_hex": "94-B8-6D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2016B9": {
        "oui_hex": "20-16-B9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "38BAF8": {
        "oui_hex": "38-BA-F8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3C6AA7": {
        "oui_hex": "3C-6A-A7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "34E12D": {
        "oui_hex": "34-E1-2D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00BB60": {
        "oui_hex": "00-BB-60",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1012FB": {
        "oui_hex": "10-12-FB",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "FC7774": {
        "oui_hex": "FC-77-74",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "982CBC": {
        "oui_hex": "98-2C-BC",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "287FCF": {
        "oui_hex": "28-7F-CF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "803253": {
        "oui_hex": "80-32-53",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D8C0A6": {
        "oui_hex": "D8-C0-A6",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "9CFCE8": {
        "oui_hex": "9C-FC-E8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F8AC65": {
        "oui_hex": "F8-AC-65",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "CCD083": {
        "oui_hex": "CC-D0-83",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "C01C30": {
        "oui_hex": "C0-1C-30",
        "organization": "Shenzhen WIFI-3L Technology Co.,Ltd",
        "address_1": "East 5 Floor,B Building, WeiHao Technology Park,Sunny Indusrtrial zone, Xili Town, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "D8C678": {
        "oui_hex": "D8-C6-78",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "B8CB29": {
        "oui_hex": "B8-CB-29",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "44BB3B": {
        "oui_hex": "44-BB-3B",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "14C14E": {
        "oui_hex": "14-C1-4E",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "2CA042": {
        "oui_hex": "2C-A0-42",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C083C9": {
        "oui_hex": "C0-83-C9",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "9844CE": {
        "oui_hex": "98-44-CE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F09BB8": {
        "oui_hex": "F0-9B-B8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ECC01B": {
        "oui_hex": "EC-C0-1B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC17B8": {
        "oui_hex": "BC-17-B8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "441C7F": {
        "oui_hex": "44-1C-7F",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "00B8B6": {
        "oui_hex": "00-B8-B6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "8012DF": {
        "oui_hex": "80-12-DF",
        "organization": "Shenzhen SuperElectron Technology Co.,Ltd.",
        "address_1": "1213-1214, haosheng business center, dongbin road, nanshan street, nanshan district, shenzhen city",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C4A151": {
        "oui_hex": "C4-A1-51",
        "organization": "Sichuan Tianyi Comheart Telecom Co., Ltd.",
        "address_1": "No.198,First Section,Snow Mountain Avenue, Jinyuan Town, Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "CN"
    },
    "1CE61D": {
        "oui_hex": "1C-E6-1D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "10E77A": {
        "oui_hex": "10-E7-7A",
        "organization": "STMicrolectronics International NV",
        "address_1": "39, Chemin du Champ-des-Filles",
        "address_2": " Geneva, Plan-les-Quates    1228",
        "country": "CH"
    },
    "90769F": {
        "oui_hex": "90-76-9F",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "80EA07": {
        "oui_hex": "80-EA-07",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "04A2F3": {
        "oui_hex": "04-A2-F3",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "BC03A7": {
        "oui_hex": "BC-03-A7",
        "organization": "MFP MICHELIN",
        "address_1": "23 place des Carmes Dechaux",
        "address_2": "Clermont-Ferrand    63000",
        "country": "FR"
    },
    "2C6F51": {
        "oui_hex": "2C-6F-51",
        "organization": "Herospeed Digital Technology Limited",
        "address_1": "728 Kaichuang Avenue,Huangpu Distric",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "982FF8": {
        "oui_hex": "98-2F-F8",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "40DCA5": {
        "oui_hex": "40-DC-A5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "CCDB93": {
        "oui_hex": "CC-DB-93",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18D61C": {
        "oui_hex": "18-D6-1C",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "5448E6": {
        "oui_hex": "54-48-E6",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "Xiaomi Campus, No. 33 Xi erqi Middle Road, Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "60D4E9": {
        "oui_hex": "60-D4-E9",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "30C50F": {
        "oui_hex": "30-C5-0F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2868D2": {
        "oui_hex": "28-68-D2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "90A935": {
        "oui_hex": "90-A9-35",
        "organization": "JWEntertainment",
        "address_1": "3f 10 Dwitgol-ro",
        "address_2": "Gwacheon-si  Gyeonggi-do  13814",
        "country": "KR"
    },
    "A486AE": {
        "oui_hex": "A4-86-AE",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "No.1801 Hongmei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "1CD6BE": {
        "oui_hex": "1C-D6-BE",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "28D127": {
        "oui_hex": "28-D1-27",
        "organization": "Beijing Xiaomi Mobile Software Co., Ltd",
        "address_1": "The Rainbow City Office Building, 68 Qinghe Middle Street Haidian District",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "C868DE": {
        "oui_hex": "C8-68-DE",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "D00DF7": {
        "oui_hex": "D0-0D-F7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "4805E2": {
        "oui_hex": "48-05-E2",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "10341B": {
        "oui_hex": "10-34-1B",
        "organization": "Spacelink",
        "address_1": "8830 Complex dr",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "F81B04": {
        "oui_hex": "F8-1B-04",
        "organization": "Zhong Shan City Richsound Electronic Industrial Ltd",
        "address_1": "Qunle Industrial Area,East ShaGang Road,GangKou ZhongShan,GuangDong,China",
        "address_2": "ZhongShan  GuangDong  528400",
        "country": "CN"
    },
    "D88C79": {
        "oui_hex": "D8-8C-79",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "30A452": {
        "oui_hex": "30-A4-52",
        "organization": "Arrival Elements BV",
        "address_1": "M. Keynesplein 12-46",
        "address_2": "Amsterdam    1066 EP",
        "country": "NL"
    },
    "000BA2": {
        "oui_hex": "00-0B-A2",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "0008F6": {
        "oui_hex": "00-08-F6",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "001E68": {
        "oui_hex": "00-1E-68",
        "organization": "Quanta Computer Inc.",
        "address_1": "NO. 211, WEN HWA 2RD., KUEI SHAN HSIANG",
        "address_2": "TAIPEI  TAO YUAN SHIEN  333",
        "country": "TW"
    },
    "00238B": {
        "oui_hex": "00-23-8B",
        "organization": "Quanta Computer Inc.",
        "address_1": "NO. 211, WEN HWA 2RD.,KUEI SHAN HSIANG, TAO YUAN SHIEN,",
        "address_2": "TAIPEI  TAIWAN  333",
        "country": "TW"
    },
    "8CC5B4": {
        "oui_hex": "8C-C5-B4",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "18ECE7": {
        "oui_hex": "18-EC-E7",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "F469D5": {
        "oui_hex": "F4-69-D5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2C600C": {
        "oui_hex": "2C-60-0C",
        "organization": "Quanta Computer Inc.",
        "address_1": "No.211, Wen Hwa 2nd Rd",
        "address_2": "Taoyuan  Taiwan  33377",
        "country": "TW"
    },
    "00005F": {
        "oui_hex": "00-00-5F",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "0003E8": {
        "oui_hex": "00-03-E8",
        "organization": "Wavesight Limited",
        "address_1": "13 Dencora Way",
        "address_2": "Luton  Sundon Business Park  LU3 3HP",
        "country": "GB"
    },
    "3C1A9E": {
        "oui_hex": "3C-1A-9E",
        "organization": "VitalThings AS",
        "address_1": "Jarlsoveien 48",
        "address_2": "Tonsberg    3124",
        "country": "NO"
    },
    "C884A1": {
        "oui_hex": "C8-84-A1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "083AF2": {
        "oui_hex": "08-3A-F2",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "743A20": {
        "oui_hex": "74-3A-20",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "30C9AB": {
        "oui_hex": "30-C9-AB",
        "organization": "CLOUD NETWORK TECHNOLOGY SINGAPORE PTE. LTD.",
        "address_1": "B22 Building,NO.51 Tongle Road, Shajing Town, Jiangnan District, Nanning, Guangxi Province, China",
        "address_2": "Nanning  Guangxi  530007",
        "country": "CN"
    },
    "D8778B": {
        "oui_hex": "D8-77-8B",
        "organization": "Intelbras",
        "address_1": "BR 101, KM 210",
        "address_2": "São Jose  Santa Catarina  88104-800",
        "country": "BR"
    },
    "F8D027": {
        "oui_hex": "F8-D0-27",
        "organization": "Seiko Epson Corporation",
        "address_1": "2070 Kotobuki Koaka",
        "address_2": "Matsumoto-shi  Nagano-ken  399-8702",
        "country": "JP"
    },
    "5C666C": {
        "oui_hex": "5C-66-6C",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "4C4BF9": {
        "oui_hex": "4C-4B-F9",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "1CEA0B": {
        "oui_hex": "1C-EA-0B",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "44EFBF": {
        "oui_hex": "44-EF-BF",
        "organization": "China Dragon Technology Limited",
        "address_1": "B4 Bldg.Haoshan 1st Industry Park,",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "B81F5E": {
        "oui_hex": "B8-1F-5E",
        "organization": "Apption Labs Limited",
        "address_1": "7-8 Westbridge Close",
        "address_2": "Leicester    LE3 5LW",
        "country": "GB"
    },
    "D81265": {
        "oui_hex": "D8-12-65",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "4CB44A": {
        "oui_hex": "4C-B4-4A",
        "organization": "NANOWAVE Technologies Inc.",
        "address_1": "425 Horner Avenue",
        "address_2": "Etobicoke  Ontario  M8W 4W3",
        "country": "CA"
    },
    "048C9A": {
        "oui_hex": "04-8C-9A",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "EC3CBB": {
        "oui_hex": "EC-3C-BB",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "8C3A7E": {
        "oui_hex": "8C-3A-7E",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "70441C": {
        "oui_hex": "70-44-1C",
        "organization": "SHENZHEN KAIFA TECHNOLOGY CO.,LTD.",
        "address_1": "7006 Caitian Rd., Futian Dist.",
        "address_2": "Shen Zhen  Guang Dong  518035",
        "country": "CN"
    },
    "B47C59": {
        "oui_hex": "B4-7C-59",
        "organization": "Jiangsu Hengxin Technology Co.,Ltd.",
        "address_1": "No.138 Taodu Road,Yixing city,Jiangsu Province,China",
        "address_2": "Yixing  Jiangsu  214200",
        "country": "CN"
    },
    "300D9E": {
        "oui_hex": "30-0D-9E",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "20# Building,Star-net Science Plaza,Juyuanzhou, 618 Jinshan Road",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "ECFA5C": {
        "oui_hex": "EC-FA-5C",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "F8B46A": {
        "oui_hex": "F8-B4-6A",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "BCB0E7": {
        "oui_hex": "BC-B0-E7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5434EF": {
        "oui_hex": "54-34-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "88D5A8": {
        "oui_hex": "88-D5-A8",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "208593": {
        "oui_hex": "20-85-93",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "ACE342": {
        "oui_hex": "AC-E3-42",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9017C8": {
        "oui_hex": "90-17-C8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E4922A": {
        "oui_hex": "E4-92-2A",
        "organization": "DBG HOLDINGS LIMITED",
        "address_1": "UNIT D, 6/F., UNISON INDUSTRIAL CENTRE, 27-31 AUPUI WAN STREET, FOTAN, N.T.",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "2C641F": {
        "oui_hex": "2C-64-1F",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "207759": {
        "oui_hex": "20-77-59",
        "organization": "OPTICAL NETWORK VIDEO TECHNOLOGIES (SHENZHEN) CO., LTD.",
        "address_1": "The 4-6th Floor, No. 59, HuaNing Road, Xinwei Community, Dalang Street, Longhua District",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "54E7D5": {
        "oui_hex": "54-E7-D5",
        "organization": "Sun Cupid Technology (HK) LTD",
        "address_1": "Room 1201-3, 12/F., Tower 6",
        "address_2": "Tsim Sha Tsui",
        "country": "HK"
    },
    "189088": {
        "oui_hex": "18-90-88",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "4C56DF": {
        "oui_hex": "4C-56-DF",
        "organization": "Targus US LLC",
        "address_1": "1211 North Miller Street",
        "address_2": "Anaheim  CA  92806",
        "country": "US"
    },
    "241510": {
        "oui_hex": "24-15-10",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "6C4D51": {
        "oui_hex": "6C-4D-51",
        "organization": "Shenzhen Ceres Technology Co., Ltd.",
        "address_1": "#601, Fl6, Bldg F, No.1008  Yangguang Community, Xili, Nanshan",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "889D98": {
        "oui_hex": "88-9D-98",
        "organization": "Allied-telesisK.K.",
        "address_1": "7-21-11 Nishi-Gotannda",
        "address_2": "Shinagawa-ku  Tokyo  141-0031",
        "country": "JP"
    },
    "DCF8B9": {
        "oui_hex": "DC-F8-B9",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "18BF1C": {
        "oui_hex": "18-BF-1C",
        "organization": "Jiangsu Huitong Group Co.,Ltd.",
        "address_1": "No. 24, Block 2, Taohuawu New District",
        "address_2": "Zhenjiang  Jiangsu  212003",
        "country": "CN"
    },
    "ACDE48": {
        "oui_hex": "AC-DE-48",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0050C7": {
        "oui_hex": "00-50-C7",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002067": {
        "oui_hex": "00-20-67",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "4801C5": {
        "oui_hex": "48-01-C5",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B4EE25": {
        "oui_hex": "B4-EE-25",
        "organization": "Shenzhen Belon Technology CO.,LTD",
        "address_1": "Tsinghua Information",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "C82B96": {
        "oui_hex": "C8-2B-96",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "98523D": {
        "oui_hex": "98-52-3D",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "D015A6": {
        "oui_hex": "D0-15-A6",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000163": {
        "oui_hex": "00-01-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "60634C": {
        "oui_hex": "60-63-4C",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "205F3D": {
        "oui_hex": "20-5F-3D",
        "organization": "Cambridge Communication Systems Ltd",
        "address_1": "Victory House, Vision Park, Chivers Way, Histon",
        "address_2": "Cambridge    CB24 9ZR",
        "country": "GB"
    },
    "04819B": {
        "oui_hex": "04-81-9B",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "E00084": {
        "oui_hex": "E0-00-84",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2CA89C": {
        "oui_hex": "2C-A8-9C",
        "organization": "Creatz inc.",
        "address_1": "16, Deogyeong-daero 1556beon-gil, Yeongtong-gu",
        "address_2": "Suwon-si,  Gyeonggi-do,   16690",
        "country": "KR"
    },
    "4CDC0D": {
        "oui_hex": "4C-DC-0D",
        "organization": "Coral Telecom Limited",
        "address_1": "E-2, Sector 63",
        "address_2": "Noida  Uttar Pradesh  201301",
        "country": "IN"
    },
    "004E01": {
        "oui_hex": "00-4E-01",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "C4E1A1": {
        "oui_hex": "C4-E1-A1",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "ACC358": {
        "oui_hex": "AC-C3-58",
        "organization": "Continental Automotive Czech Republic s.r.o.",
        "address_1": "Průmyslová 1851",
        "address_2": "Brandýs nad Labem    250 01",
        "country": "CZ"
    },
    "3CECEF": {
        "oui_hex": "3C-EC-EF",
        "organization": "Super Micro Computer, Inc.",
        "address_1": "980 Rock Ave",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "1855E3": {
        "oui_hex": "18-55-E3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E450EB": {
        "oui_hex": "E4-50-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "886440": {
        "oui_hex": "88-64-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6070C0": {
        "oui_hex": "60-70-C0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0C371": {
        "oui_hex": "F0-C3-71",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64FF0A": {
        "oui_hex": "64-FF-0A",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "F09919": {
        "oui_hex": "F0-99-19",
        "organization": "Garmin International",
        "address_1": "1200 E. 151st St",
        "address_2": "Olathe  KS  66062",
        "country": "US"
    },
    "0000DE": {
        "oui_hex": "00-00-DE",
        "organization": "CETIA",
        "address_1": "150 RUE BERTHELOT",
        "address_2": "",
        "country": "FR"
    },
    "F43E66": {
        "oui_hex": "F4-3E-66",
        "organization": "Bee Computing (HK) Limited",
        "address_1": "Room 1902, 19/F, Lee Garden One 33 Hysan Avenue, Causeway Bay",
        "address_2": "Hong Kong    100043",
        "country": "HK"
    },
    "DC396F": {
        "oui_hex": "DC-39-6F",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "B4C476": {
        "oui_hex": "B4-C4-76",
        "organization": "Wuhan Maritime Communication Research Institute",
        "address_1": "No.312 Luoyu road, Hongshan District",
        "address_2": "Wuhan  Hubei  430079",
        "country": "CN"
    },
    "683489": {
        "oui_hex": "68-34-89",
        "organization": "LEA Professional",
        "address_1": "635 S. Lafayette Blvd",
        "address_2": "South Bend  IN  46601",
        "country": "US"
    },
    "B46C47": {
        "oui_hex": "B4-6C-47",
        "organization": "Panasonic Appliances Company",
        "address_1": "2-3-1-2 Noji-higashi",
        "address_2": "Kusatsu City  Shiga  525-8555",
        "country": "JP"
    },
    "44422F": {
        "oui_hex": "44-42-2F",
        "organization": "TESTOP CO.,LTD.",
        "address_1": "808RM Hanshin IT Tower ,272, Digital-ro",
        "address_2": "Guro-gu  Seoul  08389",
        "country": "KR"
    },
    "549C27": {
        "oui_hex": "54-9C-27",
        "organization": "Plasma Cloud Limited",
        "address_1": "5/F, Yat Chau Building, 262 Des Voeux Road Central",
        "address_2": "Hong Kong    NA",
        "country": "HK"
    },
    "D04E50": {
        "oui_hex": "D0-4E-50",
        "organization": "Mobiwire Mobiles (NingBo) Co., LTD",
        "address_1": "No.999 Dacheng East Road, Fenghua District, Ningbo City , Zhejiang Province, PRC",
        "address_2": "Ningbo  Zhejiang  315500",
        "country": "CN"
    },
    "94BF80": {
        "oui_hex": "94-BF-80",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "987A14": {
        "oui_hex": "98-7A-14",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "C83DDC": {
        "oui_hex": "C8-3D-DC",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "9C3A9A": {
        "oui_hex": "9C-3A-9A",
        "organization": "Shenzhen Sundray Technologies Company Limited",
        "address_1": "5th Floor, Block A4, Nanshan ipark,NO.1001 Xue Yuan Road, Nanshan District, Shenzhen 518055, P.R. China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B0B5E8": {
        "oui_hex": "B0-B5-E8",
        "organization": "Ruroc LTD",
        "address_1": "Unit 2, Barnett Way, Barnwood Estate",
        "address_2": "Gloucester    GL4 3RT",
        "country": "GB"
    },
    "04D590": {
        "oui_hex": "04-D5-90",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  null  94086",
        "country": "US"
    },
    "541589": {
        "oui_hex": "54-15-89",
        "organization": "MCS Logic Inc.",
        "address_1": "A-1701, Munjeong-dong, SK V1 GL Metro City, 128, Beobwon-ro, Songpa-gu,",
        "address_2": "seoul  seoul  05854",
        "country": "KR"
    },
    "845733": {
        "oui_hex": "84-57-33",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND    98052",
        "country": "US"
    },
    "002423": {
        "oui_hex": "00-24-23",
        "organization": "AzureWave Technologies (Shanghai) Inc.",
        "address_1": "NO. 8, LANE 66, CHENGBAO RD.",
        "address_2": "SHANGHAI    201801",
        "country": "CN"
    },
    "8C593C": {
        "oui_hex": "8C-59-3C",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "6029D5": {
        "oui_hex": "60-29-D5",
        "organization": "DAVOLINK Inc.",
        "address_1": "112, Beolmal-ro",
        "address_2": "Dongan-gu, Anyang-si  Gyeonggi-do  14057",
        "country": "KR"
    },
    "509744": {
        "oui_hex": "50-97-44",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "58F39C": {
        "oui_hex": "58-F3-9C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C4411E": {
        "oui_hex": "C4-41-1E",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  null  90094",
        "country": "US"
    },
    "0077E4": {
        "oui_hex": "00-77-E4",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "00AD63": {
        "oui_hex": "00-AD-63",
        "organization": "Dedicated Micros Malta LTD",
        "address_1": "Blb017, Qasam Industrijali Bulebel",
        "address_2": "ZEJTUN    ZTN 3000",
        "country": "MT"
    },
    "E415F6": {
        "oui_hex": "E4-15-F6",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "AC4228": {
        "oui_hex": "AC-42-28",
        "organization": "Parta Networks",
        "address_1": "Teknopark Izmir No:38",
        "address_2": "URLA  IZMIR  35433",
        "country": "TR"
    },
    "F41D6B": {
        "oui_hex": "F4-1D-6B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "7CEC9B": {
        "oui_hex": "7C-EC-9B",
        "organization": "Fuzhou Teraway Information Technology Co.,Ltd",
        "address_1": "2F, Building 5#, No. 59, Yangqi Road, Cangshan District",
        "address_2": "Fuzhou  Fujian  350000",
        "country": "CN"
    },
    "CC9070": {
        "oui_hex": "CC-90-70",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2841C6": {
        "oui_hex": "28-41-C6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "380118": {
        "oui_hex": "38-01-18",
        "organization": "ULVAC,Inc.",
        "address_1": "2500 Hagizono",
        "address_2": "Chigasaki  Kanagawa  253-8543",
        "country": "JP"
    },
    "14ADCA": {
        "oui_hex": "14-AD-CA",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "809133": {
        "oui_hex": "80-91-33",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "B4F58E": {
        "oui_hex": "B4-F5-8E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C48FC1": {
        "oui_hex": "C4-8F-C1",
        "organization": "DEEPTRACK S.L.U.",
        "address_1": "Avenida de Barajas 32, Parque E. Omega, Edificio A",
        "address_2": "Alcobendas    28100",
        "country": "ES"
    },
    "F82387": {
        "oui_hex": "F8-23-87",
        "organization": "Shenzhen Horn Audio Co.,Ltd.",
        "address_1": "NO.6 4th GuiHua road,PingShan,",
        "address_2": "Shenzhen  Guangdong  518118",
        "country": "CN"
    },
    "E828C1": {
        "oui_hex": "E8-28-C1",
        "organization": "Eltex Enterprise Ltd.",
        "address_1": "Okruzhnaya st. 29v",
        "address_2": "Novosibirsk    630020",
        "country": "RU"
    },
    "78D347": {
        "oui_hex": "78-D3-47",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "A4A179": {
        "oui_hex": "A4-A1-79",
        "organization": "Nanjing dianyan electric power automation co. LTD",
        "address_1": "No. 29, liuzhou north road, pukou district",
        "address_2": "Nanjing  Jiangsu  210031",
        "country": "CN"
    },
    "68DB67": {
        "oui_hex": "68-DB-67",
        "organization": "Nantong Coship Electronics Co., Ltd.",
        "address_1": "No.188 Xinsheng Road",
        "address_2": "Nantong    226000",
        "country": "US"
    },
    "1819D6": {
        "oui_hex": "18-19-D6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC98DF": {
        "oui_hex": "BC-98-DF",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "70FC8F": {
        "oui_hex": "70-FC-8F",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "501B32": {
        "oui_hex": "50-1B-32",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "980D67": {
        "oui_hex": "98-0D-67",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "0002D8": {
        "oui_hex": "00-02-D8",
        "organization": "BRECIS Communications Corporation",
        "address_1": "2025 Gateway Place, Suite 132",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "B0A6F5": {
        "oui_hex": "B0-A6-F5",
        "organization": "Xaptum, Inc.",
        "address_1": "350 W Ontario ST FL 4",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "ACF5E6": {
        "oui_hex": "AC-F5-E6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "DCB082": {
        "oui_hex": "DC-B0-82",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "F8C397": {
        "oui_hex": "F8-C3-97",
        "organization": "NZXT Corp. Ltd.",
        "address_1": "13164 E. Temple Ave.",
        "address_2": "City of Industry  California  91746",
        "country": "US"
    },
    "70DDA8": {
        "oui_hex": "70-DD-A8",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "4C6F9C": {
        "oui_hex": "4C-6F-9C",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "782C29": {
        "oui_hex": "78-2C-29",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "BC9FE4": {
        "oui_hex": "BC-9F-E4",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "702E80": {
        "oui_hex": "70-2E-80",
        "organization": "DIEHL Connectivity Solutions",
        "address_1": "Stephanstraße 49",
        "address_2": "Nürnberg  Bayern  90478",
        "country": "DE"
    },
    "ACA46E": {
        "oui_hex": "AC-A4-6E",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "C8B422": {
        "oui_hex": "C8-B4-22",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "94EE9F": {
        "oui_hex": "94-EE-9F",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "DC2AA1": {
        "oui_hex": "DC-2A-A1",
        "organization": "MedHab LLC",
        "address_1": "3501 North US Highway 67",
        "address_2": "San Angelo  TX  76905",
        "country": "US"
    },
    "E4F3E8": {
        "oui_hex": "E4-F3-E8",
        "organization": "Shenzhen SuperElectron Technology Co.,Ltd.",
        "address_1": "1213-1214, haosheng business center, dongbin road, nanshan street, nanshan district, shenzhen city",
        "address_2": "Shenzhen   Guangdong  518000",
        "country": "CN"
    },
    "F4323D": {
        "oui_hex": "F4-32-3D",
        "organization": "Sichuan tianyi kanghe communications co., LTD",
        "address_1": "No.198, section 1, xueshan avenue, jinyuan town, dayi county, sichuan province",
        "address_2": "chengdu  sichuan  611330",
        "country": "CN"
    },
    "F8B797": {
        "oui_hex": "F8-B7-97",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "2-3 Kandatsukasamachi",
        "address_2": "Chiyodaku  Tokyo  101-8532",
        "country": "JP"
    },
    "B0AAD2": {
        "oui_hex": "B0-AA-D2",
        "organization": "Sichuan tianyi kanghe communications co., LTD",
        "address_1": "No.198, section 1, xueshan avenue, jinyuan town, dayi county, sichuan province",
        "address_2": "chengdu  sichuan  611330",
        "country": "CN"
    },
    "109397": {
        "oui_hex": "10-93-97",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5075F1": {
        "oui_hex": "50-75-F1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C46516": {
        "oui_hex": "C4-65-16",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "E41E0A": {
        "oui_hex": "E4-1E-0A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "CCA12B": {
        "oui_hex": "CC-A1-2B",
        "organization": "TCL King Electrical Appliances (Huizhou) Co., Ltd",
        "address_1": "10F, TCL Multimedia Building, TCL International E City, No.1001 Zhongshanyuan Rd., Nanshan District",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "AC00D0": {
        "oui_hex": "AC-00-D0",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E8C417": {
        "oui_hex": "E8-C4-17",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "001EA3": {
        "oui_hex": "00-1E-A3",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "38F32E": {
        "oui_hex": "38-F3-2E",
        "organization": "Skullcandy",
        "address_1": "6301 N. LANDMARK DRIVE",
        "address_2": "Park City    84098",
        "country": "US"
    },
    "981E19": {
        "oui_hex": "98-1E-19",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "84B866": {
        "oui_hex": "84-B8-66",
        "organization": "Beijing XiaoLu technology co. LTD",
        "address_1": "Room 002, floor 2, building 1, yard 4, BeiTuCheng East Road, ChaoYang district, Beijing",
        "address_2": "Beijing    100102",
        "country": "CN"
    },
    "18BC5A": {
        "oui_hex": "18-BC-5A",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C4C138": {
        "oui_hex": "C4-C1-38",
        "organization": "OWLink Technology Inc",
        "address_1": "760 Roosevelt",
        "address_2": "Irvine  CA  92620",
        "country": "US"
    },
    "AC37C9": {
        "oui_hex": "AC-37-C9",
        "organization": "RAID Incorporated",
        "address_1": "200 Brickstone Square",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "205869": {
        "oui_hex": "20-58-69",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "CC37AB": {
        "oui_hex": "CC-37-AB",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation Road 3.",
        "address_2": "Hsinchu  Hsinchu  30077",
        "country": "TW"
    },
    "1422DB": {
        "oui_hex": "14-22-DB",
        "organization": "eero inc.",
        "address_1": "230 9th St.",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "C86314": {
        "oui_hex": "C8-63-14",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "243154": {
        "oui_hex": "24-31-54",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2C58E8": {
        "oui_hex": "2C-58-E8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "70CD91": {
        "oui_hex": "70-CD-91",
        "organization": "TERACOM TELEMATICA S.A",
        "address_1": "RUA AMERICA,1000",
        "address_2": "Eldorado do Sul  Rio Grande do Sul  92990-000",
        "country": "BR"
    },
    "2C1875": {
        "oui_hex": "2C-18-75",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D06EDE": {
        "oui_hex": "D0-6E-DE",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "18399C": {
        "oui_hex": "18-39-9C",
        "organization": "Skorpios Technologies",
        "address_1": "7401 Snaproll St NE",
        "address_2": "Albuquerque  NM  87109",
        "country": "US"
    },
    "94C2BD": {
        "oui_hex": "94-C2-BD",
        "organization": "TECNOBIT",
        "address_1": "C/ FUDRE, 18",
        "address_2": "VALDEPEÑAS  CIUDAD REAL  13300",
        "country": "ES"
    },
    "4883B4": {
        "oui_hex": "48-83-B4",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "84B8B8": {
        "oui_hex": "84-B8-B8",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "D041C9": {
        "oui_hex": "D0-41-C9",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E8018D": {
        "oui_hex": "E8-01-8D",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "10A3B8": {
        "oui_hex": "10-A3-B8",
        "organization": "Iskratel d.o.o.",
        "address_1": "Ljubljanska cesta 24a",
        "address_2": "Kranj    4000",
        "country": "SI"
    },
    "E8ECA3": {
        "oui_hex": "E8-EC-A3",
        "organization": "Dongguan Liesheng Electronic Co.Ltd",
        "address_1": "13th Floor South Building, Gosun Science Park, Hongtu Rd",
        "address_2": "Dongguan  Dongguan  523073",
        "country": "CN"
    },
    "08A6BC": {
        "oui_hex": "08-A6-BC",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "701E68": {
        "oui_hex": "70-1E-68",
        "organization": "Hanna Instruments, Inc.",
        "address_1": "584 Park East Dr.",
        "address_2": "Woonsocket  RI  02895",
        "country": "US"
    },
    "1CB3E9": {
        "oui_hex": "1C-B3-E9",
        "organization": " Shenzhen Zhongke United Communication Technology",
        "address_1": "6C jiajiahao commercial building, Shennan avenue",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "8C965F": {
        "oui_hex": "8C-96-5F",
        "organization": "Shandong Zhongan Technology Co., Ltd.",
        "address_1": "North of Kejia Road, East District, Jinan High-tech Zone",
        "address_2": "Jinan  Shandong  250100",
        "country": "CN"
    },
    "C0074A": {
        "oui_hex": "C0-07-4A",
        "organization": "Brita GmbH",
        "address_1": "Heinrich-Hertz-Str. 4",
        "address_2": "Taunusstein    65232",
        "country": "DE"
    },
    "E8B2FE": {
        "oui_hex": "E8-B2-FE",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "80FD7A": {
        "oui_hex": "80-FD-7A",
        "organization": "BLU Products Inc",
        "address_1": "10814 NW 33rd Street",
        "address_2": "Miami  FL  33172",
        "country": "US"
    },
    "0017FA": {
        "oui_hex": "00-17-FA",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "941625": {
        "oui_hex": "94-16-25",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "543B30": {
        "oui_hex": "54-3B-30",
        "organization": "duagon AG",
        "address_1": "Riedstrasse 12",
        "address_2": "Zürich  Dietikon  8953",
        "country": "CH"
    },
    "40F21C": {
        "oui_hex": "40-F2-1C",
        "organization": "DASAN Zhone Solutions",
        "address_1": "7195 Oakport Street",
        "address_2": "Oakland  CA  94621",
        "country": "US"
    },
    "B0BB8B": {
        "oui_hex": "B0-BB-8B",
        "organization": "WAVETEL TECHNOLOGY LIMITED",
        "address_1": "ROOM 1611B, 16/F, HO KING COMMERCIAL CENTRE, 2-16 FAYUEN STREET, MONGKOK, KOWLOON",
        "address_2": "HONGKONG    999077",
        "country": "CN"
    },
    "34A8EB": {
        "oui_hex": "34-A8-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "94BFC4": {
        "oui_hex": "94-BF-C4",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "A483E7": {
        "oui_hex": "A4-83-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F4AFE7": {
        "oui_hex": "F4-AF-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC88FD": {
        "oui_hex": "AC-88-FD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "503E7C": {
        "oui_hex": "50-3E-7C",
        "organization": "LeiShen Intelligent  System Co.Ltd",
        "address_1": "4th Floor,No.1 Commercial Building,Cultural Center,Tanggang Road,Tanggang Community,Shajing Street,Baoan District",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "24586E": {
        "oui_hex": "24-58-6E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B4A305": {
        "oui_hex": "B4-A3-05",
        "organization": "XIAMEN YAXON NETWORK CO., LTD.",
        "address_1": "46#,Guanri Road, Software Park II",
        "address_2": "Xiamen  Fujian  361008",
        "country": "CN"
    },
    "803E48": {
        "oui_hex": "80-3E-48",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "243F30": {
        "oui_hex": "24-3F-30",
        "organization": "Oxygen Broadband s.a.",
        "address_1": "2 Messogeion ave., Athens Tower",
        "address_2": "Athens  Attiki  11527",
        "country": "GR"
    },
    "3C9180": {
        "oui_hex": "3C-91-80",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "20326C": {
        "oui_hex": "20-32-6C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "6489F1": {
        "oui_hex": "64-89-F1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2034FB": {
        "oui_hex": "20-34-FB",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "A89CED": {
        "oui_hex": "A8-9C-ED",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "6CA604": {
        "oui_hex": "6C-A6-04",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5CF9DD": {
        "oui_hex": "5C-F9-DD",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "D0EC35": {
        "oui_hex": "D0-EC-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "10AE60": {
        "oui_hex": "10-AE-60",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0025DF": {
        "oui_hex": "00-25-DF",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "BCCF4F": {
        "oui_hex": "BC-CF-4F",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "C010B1": {
        "oui_hex": "C0-10-B1",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "90895F": {
        "oui_hex": "90-89-5F",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road, Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "48D845": {
        "oui_hex": "48-D8-45",
        "organization": "Shenzhen Mainuoke Electronics Co., Ltd",
        "address_1": "9th Floor, Hengtemei Building, Buji",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "0CE041": {
        "oui_hex": "0C-E0-41",
        "organization": "iDruide",
        "address_1": "19 Rue de la Turbie",
        "address_2": "MONACO    98000",
        "country": "MC"
    },
    "B88FB4": {
        "oui_hex": "B8-8F-B4",
        "organization": "JABIL CIRCUIT ITALIA S.R.L",
        "address_1": "via andrea appiani 12",
        "address_2": "milano    20121",
        "country": "IT"
    },
    "0052C2": {
        "oui_hex": "00-52-C2",
        "organization": "peiker acustic GmbH",
        "address_1": "Max-Planck-Strasse 28-32",
        "address_2": "Friedrichsdorf    61381",
        "country": "DE"
    },
    "8C53D2": {
        "oui_hex": "8C-53-D2",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "D45383": {
        "oui_hex": "D4-53-83",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "A04246": {
        "oui_hex": "A0-42-46",
        "organization": "IT Telecom Co., Ltd.",
        "address_1": "517 TheOvalley 555-9 Hogye-dong, Dong An-gu",
        "address_2": "Anyang-si   Gyeonggi-do  14117",
        "country": "KR"
    },
    "0CF475": {
        "oui_hex": "0C-F4-75",
        "organization": "Zliide Technologies ApS",
        "address_1": "Sverigesgade 6",
        "address_2": "Aarhus    8000",
        "country": "DK"
    },
    "68FF7B": {
        "oui_hex": "68-FF-7B",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "808F1D": {
        "oui_hex": "80-8F-1D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00124E": {
        "oui_hex": "00-12-4E",
        "organization": "XAC AUTOMATION CORP.",
        "address_1": "4F, 30 Industry E. Road IX",
        "address_2": "Hsin-Chu    300",
        "country": "US"
    },
    "88E034": {
        "oui_hex": "88-E0-34",
        "organization": "Shinwa industries(China) ltd.",
        "address_1": "No.26,Huifeng West 2 Road,Zhongkai High-tech Zone",
        "address_2": "Huizhou  Guangdong  516006",
        "country": "CN"
    },
    "48BD0E": {
        "oui_hex": "48-BD-0E",
        "organization": "Quanta Storage Inc.",
        "address_1": "3F. No.188, Wenhua 2nd Rd",
        "address_2": "Taoyuan City  Guishan District  33383",
        "country": "TW"
    },
    "000F69": {
        "oui_hex": "00-0F-69",
        "organization": "SEW Eurodrive GmbH & Co. KG",
        "address_1": "Ernst Blickle Str. 42",
        "address_2": "Bruchsal    76646",
        "country": "DE"
    },
    "E458E7": {
        "oui_hex": "E4-58-E7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00104A": {
        "oui_hex": "00-10-4A",
        "organization": "The Parvus Corporation",
        "address_1": "3222 S Washington St.",
        "address_2": "Salt Lake City  UT  84115",
        "country": "US"
    },
    "D058C0": {
        "oui_hex": "D0-58-C0",
        "organization": "Qingdao Haier Multimedia Limited.",
        "address_1": "Pingban Building, Haier Industry Park, Laoshan District,",
        "address_2": "Qingdao  Shandong  266103",
        "country": "CN"
    },
    "F8D478": {
        "oui_hex": "F8-D4-78",
        "organization": "Flextronics Tech.(Ind) Pvt Ltd",
        "address_1": "SURVEYNO.381, PADUR ROAD, KUTHAMBAKKAM VILLAGE, 602107 POONAMALLEE TALUK, THIRUVALLUR DISTRIC",
        "address_2": "Chennai    602107",
        "country": "IN"
    },
    "48C3B0": {
        "oui_hex": "48-C3-B0",
        "organization": "Pharos Co.Ltd",
        "address_1": "503 Ogong-ro 144  Deokjin-gu",
        "address_2": "Jeonju-si     54873",
        "country": "KR"
    },
    "DC58BC": {
        "oui_hex": "DC-58-BC",
        "organization": "Thomas-Krenn.AG",
        "address_1": "Speltenbach-Steinaecker 1",
        "address_2": "Freyung    94078",
        "country": "DE"
    },
    "001025": {
        "oui_hex": "00-10-25",
        "organization": "Grayhill, Inc",
        "address_1": "561 Hillgrove Ave",
        "address_2": "LaGrange  IL  60525",
        "country": "US"
    },
    "3821C7": {
        "oui_hex": "38-21-C7",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "A45F9B": {
        "oui_hex": "A4-5F-9B",
        "organization": "Nexell",
        "address_1": "12F, 31 Hwangsaeul-ro 258 beon-gil, Bundang-gu",
        "address_2": "Seongnam-si, Gyeonggi-do    13595",
        "country": "KR"
    },
    "70EA1A": {
        "oui_hex": "70-EA-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "808A8B": {
        "oui_hex": "80-8A-8B",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "9844B6": {
        "oui_hex": "98-44-B6",
        "organization": "INFRANOR SAS",
        "address_1": "Avenue Jean Moulin",
        "address_2": "LOURDES    65100",
        "country": "FR"
    },
    "38839A": {
        "oui_hex": "38-83-9A",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "DC6723": {
        "oui_hex": "DC-67-23",
        "organization": "barox Kommunikation GmbH",
        "address_1": "Marie-Curie-Strasse 8",
        "address_2": "Lörrach    DE-79539",
        "country": "DE"
    },
    "44B462": {
        "oui_hex": "44-B4-62",
        "organization": "Flextronics Tech.(Ind) Pvt Ltd",
        "address_1": "SURVEYNO.381, PADUR ROAD, KUTHAMBAKKAM VILLAGE, 602107 POONAMALLEE TALUK, THIRUVALLUR DISTRIC",
        "address_2": "Chennai    602107",
        "country": "IN"
    },
    "94B40F": {
        "oui_hex": "94-B4-0F",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001A1E": {
        "oui_hex": "00-1A-1E",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00246C": {
        "oui_hex": "00-24-6C",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "201BC9": {
        "oui_hex": "20-1B-C9",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C8F6C8": {
        "oui_hex": "C8-F6-C8",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "1C3B8F": {
        "oui_hex": "1C-3B-8F",
        "organization": "Selve GmbH & Co. KG",
        "address_1": "Werdohler Landstraße 286",
        "address_2": "Lüdenscheid    58513",
        "country": "DE"
    },
    "E4E749": {
        "oui_hex": "E4-E7-49",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "ECC57F": {
        "oui_hex": "EC-C5-7F",
        "organization": "Suzhou Pairlink Network Technology",
        "address_1": "Room304, Building 4, No.209, Zhu Yuan Road, Suzhou new district",
        "address_2": "Suzhou  Jiangsu  215011",
        "country": "CN"
    },
    "38C2BA": {
        "oui_hex": "38-C2-BA",
        "organization": "CCTV NEOTECH",
        "address_1": "68, Digital-ro 9-gil, Geumcheon-gu",
        "address_2": "Seoul    ks013",
        "country": "KR"
    },
    "A0F9B7": {
        "oui_hex": "A0-F9-B7",
        "organization": "Ademco Smart Homes Technology(Tianjin)Co.,Ltd.",
        "address_1": "No.156 Nanhai Road,TEDA, Jinbin Development Park , 21st Factory Building",
        "address_2": "Tianjin  Tianjin  300457",
        "country": "CN"
    },
    "A83CCB": {
        "oui_hex": "A8-3C-CB",
        "organization": "ROSSMA",
        "address_1": " Malkova,12-108",
        "address_2": "PERM    614087",
        "country": "RU"
    },
    "886FD4": {
        "oui_hex": "88-6F-D4",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "CC3FEA": {
        "oui_hex": "CC-3F-EA",
        "organization": "BAE Systems, Inc",
        "address_1": "1098 Clark St",
        "address_2": "Endicott  NY  13760",
        "country": "US"
    },
    "4CF2BF": {
        "oui_hex": "4C-F2-BF",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22 Floor,Qilai Tower;889 Yishan Road",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "CC9EA2": {
        "oui_hex": "CC-9E-A2",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno    89507",
        "country": "US"
    },
    "AC4330": {
        "oui_hex": "AC-43-30",
        "organization": "Versa Networks",
        "address_1": "6001 America center Drive, Suite 400",
        "address_2": "San Jose  CA  95070",
        "country": "US"
    },
    "E85BB7": {
        "oui_hex": "E8-5B-B7",
        "organization": "Ample Systems Inc.",
        "address_1": "11F-2, No. 95 Minquan Rd.",
        "address_2": "New Taipei City     231",
        "country": "TW"
    },
    "94677E": {
        "oui_hex": "94-67-7E",
        "organization": "Belden India Private Limited",
        "address_1": "Plot No. D-228, Chakan MIDC Phase 2,",
        "address_2": "Village Bhamboli, Taluka:Khed  Pune, Maharashtra  410 507",
        "country": "IN"
    },
    "AC5775": {
        "oui_hex": "AC-57-75",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "D43A2E": {
        "oui_hex": "D4-3A-2E",
        "organization": "SHENZHEN MTC CO LTD",
        "address_1": "5th Floor, 3rd Building, SHENZHEN MTC Industrial Park, XiaLilang Rd, Nanwan Street, Long’gang District",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "50AD92": {
        "oui_hex": "50-AD-92",
        "organization": "NX Technologies",
        "address_1": "5F(OS Building), 57, Daeril-2gil, Beomseo-eup",
        "address_2": "Ulsan    44922",
        "country": "KR"
    },
    "30C3D9": {
        "oui_hex": "30-C3-D9",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "003217": {
        "oui_hex": "00-32-17",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001BFB": {
        "oui_hex": "00-1B-FB",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "94E0D6": {
        "oui_hex": "94-E0-D6",
        "organization": "China Dragon Technology Limited",
        "address_1": "B4 Bldg.Haoshan 1st Industry Park,",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "B4A9FC": {
        "oui_hex": "B4-A9-FC",
        "organization": "Quanta Computer Inc.",
        "address_1": "No. 211, Wen-Hwa 2nd Rd.,Kuei-Shan Dist.",
        "address_2": "Taoyuan City  Taiwan  33377",
        "country": "TW"
    },
    "6CA936": {
        "oui_hex": "6C-A9-36",
        "organization": "DisplayLink (UK) Ltd",
        "address_1": "140 Science Park, Milton road",
        "address_2": "Cambridge  Cambridgeshire  CB4 0GF",
        "country": "GB"
    },
    "708540": {
        "oui_hex": "70-85-40",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "08F1EA": {
        "oui_hex": "08-F1-EA",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F00DF5": {
        "oui_hex": "F0-0D-F5",
        "organization": "ACOMA Medical Industry Co,. Ltd.",
        "address_1": "2-14-14 hongo",
        "address_2": "bunkyo-ku  Tokyo  113-0033",
        "country": "JP"
    },
    "6845F1": {
        "oui_hex": "68-45-F1",
        "organization": "TOSHIBA CLIENT SOLUTIONS CO., LTD.",
        "address_1": "Tachihi Building No.2, 6-1-3, Sakae-Cho",
        "address_2": "Tachikawa-shi  Tokyo  190-0003",
        "country": "JP"
    },
    "8CAEDB": {
        "oui_hex": "8C-AE-DB",
        "organization": "NAG LLC",
        "address_1": "Predelnaya st 57/2",
        "address_2": "Ekaterinburg  Sverdlovskaya oblast   620161",
        "country": "RU"
    },
    "78B213": {
        "oui_hex": "78-B2-13",
        "organization": "DWnet Technologies(Suzhou) Corporation",
        "address_1": "No.8,Tangzhuang Road, Suzhou Industrial Park, Jiangsu, China",
        "address_2": "Suzhou    21500",
        "country": "CN"
    },
    "58C232": {
        "oui_hex": "58-C2-32",
        "organization": "NEC Corporation",
        "address_1": "1753, Shimonumabe, Nakahara-Ku, Kawasaki",
        "address_2": "Kanagawa    211-8666",
        "country": "JP"
    },
    "381D14": {
        "oui_hex": "38-1D-14",
        "organization": "Skydio Inc.",
        "address_1": "114 Hazel Ave",
        "address_2": "Redwood City  CA  94061",
        "country": "US"
    },
    "7CDB98": {
        "oui_hex": "7C-DB-98",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "380B3C": {
        "oui_hex": "38-0B-3C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "9C8CD8": {
        "oui_hex": "9C-8C-D8",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "A48CC0": {
        "oui_hex": "A4-8C-C0",
        "organization": "JLG Industries, Inc.",
        "address_1": "13224 Fountainhead Plaza",
        "address_2": "Hagerstown  MD  21742",
        "country": "US"
    },
    "3C286D": {
        "oui_hex": "3C-28-6D",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "00093A": {
        "oui_hex": "00-09-3A",
        "organization": "Molex CMS",
        "address_1": "5224 Katrine Avenue",
        "address_2": "Downers Grove  IL  60515",
        "country": "US"
    },
    "04F9D9": {
        "oui_hex": "04-F9-D9",
        "organization": "Speaker Electronic(Jiashan) Co.,Ltd",
        "address_1": "No. 8 Development Zone Road, Huimin Sub-district",
        "address_2": " Jiashan  Zhejiang  314112",
        "country": "CN"
    },
    "DC080F": {
        "oui_hex": "DC-08-0F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F8E94E": {
        "oui_hex": "F8-E9-4E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "EC2CE2": {
        "oui_hex": "EC-2C-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "40BC60": {
        "oui_hex": "40-BC-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E83617": {
        "oui_hex": "E8-36-17",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C648B": {
        "oui_hex": "9C-64-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "344262": {
        "oui_hex": "34-42-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "14D00D": {
        "oui_hex": "14-D0-0D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88D211": {
        "oui_hex": "88-D2-11",
        "organization": "Eko Devices, Inc.",
        "address_1": "2600 10th St Ste 260",
        "address_2": "Berkeley  CA  94710-2597",
        "country": "US"
    },
    "B8C227": {
        "oui_hex": "B8-C2-27",
        "organization": "PSTec",
        "address_1": "#80, Hwanggeum 3-ro 7beon-gil, Yangchon-eup",
        "address_2": "Gimpo-si  Gyeonggi-do  10048",
        "country": "KR"
    },
    "74F737": {
        "oui_hex": "74-F7-37",
        "organization": "KCE",
        "address_1": "5F KCE B/D,34,Annam-ro 369beon-gil,Bupyoung-gu",
        "address_2": "Incheon    21312",
        "country": "KR"
    },
    "48A493": {
        "oui_hex": "48-A4-93",
        "organization": "TAIYO YUDEN CO.,LTD",
        "address_1": "8-1, Sakae-cho",
        "address_2": "Takasaki-shi  Gunma  370-8522",
        "country": "JP"
    },
    "E82C6D": {
        "oui_hex": "E8-2C-6D",
        "organization": "SmartRG, Inc.",
        "address_1": "501 SE Columbia Shores Blvd",
        "address_2": "Vancouver  WA  98661",
        "country": "US"
    },
    "48E695": {
        "oui_hex": "48-E6-95",
        "organization": "Insigma Inc",
        "address_1": "43490, Yukon Drive, Suite 102",
        "address_2": "Ashburn  VA  20147",
        "country": "US"
    },
    "B479C8": {
        "oui_hex": "B4-79-C8",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B40B78": {
        "oui_hex": "B4-0B-78",
        "organization": "Brusa Elektronik AG",
        "address_1": "Neudorf 14",
        "address_2": "Sennwald  St. Gallen  9466",
        "country": "CH"
    },
    "C03DD9": {
        "oui_hex": "C0-3D-D9",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "2CAA8E": {
        "oui_hex": "2C-AA-8E",
        "organization": "Wyze Labs Inc",
        "address_1": "4030 Lake Washington Boulevard NE",
        "address_2": "Kirkland  WA  98033",
        "country": "US"
    },
    "703A51": {
        "oui_hex": "70-3A-51",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "DC48B2": {
        "oui_hex": "DC-48-B2",
        "organization": "Baraja Pty. Ltd.",
        "address_1": "36 Bradfield Road",
        "address_2": "West Lindfield  NSW  2070",
        "country": "AU"
    },
    "ACAE19": {
        "oui_hex": "AC-AE-19",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "181E95": {
        "oui_hex": "18-1E-95",
        "organization": "AuVerte",
        "address_1": "14 Riverview Road",
        "address_2": "Niantic  CT  06357",
        "country": "US"
    },
    "0C9541": {
        "oui_hex": "0C-95-41",
        "organization": "CHIPSEA TECHNOLOGIES (SHENZHEN) CORP.",
        "address_1": "9F,BLOCK A,GARDEN CITY DIGITAL BUILDING,NO.1079 NANHAI ROAD,NANSHAN DISTRICT",
        "address_2": "SHEN ZHEN  GUANG DONG  518000",
        "country": "CN"
    },
    "ACF85C": {
        "oui_hex": "AC-F8-5C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "9C6937": {
        "oui_hex": "9C-69-37",
        "organization": "Qorvo Utrecht B.V.",
        "address_1": "Leidseveer 10",
        "address_2": "Utrecht  Utrecht  3511SB",
        "country": "NL"
    },
    "3C3786": {
        "oui_hex": "3C-37-86",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "48352E": {
        "oui_hex": "48-35-2E",
        "organization": "Shenzhen Wolck Network Product Co.,LTD",
        "address_1": "9# BuJi BanTian LongBi Industry Area",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "04E598": {
        "oui_hex": "04-E5-98",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "1012B4": {
        "oui_hex": "10-12-B4",
        "organization": "SICHUAN TIANYI COMHEART TELECOM CO.,LTD",
        "address_1": "NO.198 FIRST SECTION,SNOW MOUNTAIN AVENUE, JINYUAN TOWN, DAYI COUNTY,",
        "address_2": "CHENGDU  SICHUAN  611330",
        "country": "CN"
    },
    "B82CA0": {
        "oui_hex": "B8-2C-A0",
        "organization": "Resideo",
        "address_1": "2 Corporate Center Dr.",
        "address_2": "Melville  NY  11747",
        "country": "US"
    },
    "6CC7EC": {
        "oui_hex": "6C-C7-EC",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "B033A6": {
        "oui_hex": "B0-33-A6",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D89685": {
        "oui_hex": "D8-96-85",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "3C01EF": {
        "oui_hex": "3C-01-EF",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "C0BDC8": {
        "oui_hex": "C0-BD-C8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "647BCE": {
        "oui_hex": "64-7B-CE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A887B3": {
        "oui_hex": "A8-87-B3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "6C006B": {
        "oui_hex": "6C-00-6B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001060": {
        "oui_hex": "00-10-60",
        "organization": "BILLIONTON SYSTEMS, INC.",
        "address_1": "3F-1, NO. 8, LANE 99",
        "address_2": "HSIN-CHU",
        "country": "TW"
    },
    "C4D489": {
        "oui_hex": "C4-D4-89",
        "organization": "JiangSu Joyque Information Industry Co.,Ltd",
        "address_1": "10  Floor YaHua Building, Xi'anBei Road,",
        "address_2": "Xuzhou  JiangSu  221006",
        "country": "CN"
    },
    "B4F949": {
        "oui_hex": "B4-F9-49",
        "organization": "optilink networks pvt ltd",
        "address_1": "501/502, sanjona complex, hemu kalani marg, chembur",
        "address_2": "mumbai  maharashtra  400071",
        "country": "IN"
    },
    "E43C80": {
        "oui_hex": "E4-3C-80",
        "organization": "University of Oklahoma",
        "address_1": "Advanced Radar Research Center",
        "address_2": "Norman  OK  73019",
        "country": "US"
    },
    "3C2C30": {
        "oui_hex": "3C-2C-30",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "706D15": {
        "oui_hex": "70-6D-15",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4A1E4": {
        "oui_hex": "A4-A1-E4",
        "organization": "Innotube, Inc.",
        "address_1": "#1212 MegaCenter SknTechnoPark 124 Sagimakgol-ro Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  462-120",
        "country": "KR"
    },
    "94EAEA": {
        "oui_hex": "94-EA-EA",
        "organization": "TELLESCOM INDUSTRIA E COMERCIO EM TELECOMUNICACAO",
        "address_1": "Av. Buriti, 1900 – Setor B – Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075-000",
        "country": "BR"
    },
    "1CFD08": {
        "oui_hex": "1C-FD-08",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B8599F": {
        "oui_hex": "B8-59-9F",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "301389": {
        "oui_hex": "30-13-89",
        "organization": "Siemens AG, Automations & Drives,",
        "address_1": "Systems Engineering",
        "address_2": "FÃ¼rth  Deutschlang  90766",
        "country": "DE"
    },
    "046B25": {
        "oui_hex": "04-6B-25",
        "organization": "SICHUAN TIANYI COMHEART TELECOM CO.,LTD",
        "address_1": "NO.198 FIRST SECTION,SNOW MOUNTAIN AVENUE, JINYUAN TOWN, DAYI COUNTY,",
        "address_2": "CHENGDU  SICHUAN  611330",
        "country": "CN"
    },
    "98D3E7": {
        "oui_hex": "98-D3-E7",
        "organization": "Netafim L",
        "address_1": "Kibutz Magal",
        "address_2": "Kibutz Magal    38845",
        "country": "IL"
    },
    "F063F9": {
        "oui_hex": "F0-63-F9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CC385": {
        "oui_hex": "7C-C3-85",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "900EB3": {
        "oui_hex": "90-0E-B3",
        "organization": "Shenzhen Amediatech Technology Co., Ltd.",
        "address_1": "2th floor, block A, building B, Minsheng Industrial Zone, Longhua District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "549FAE": {
        "oui_hex": "54-9F-AE",
        "organization": "iBASE Gaming Inc",
        "address_1": "2F., No.542-17, Zhongzheng Rd",
        "address_2": "Xinzhuang Dist., New Taipei City    24255",
        "country": "TW"
    },
    "1469A2": {
        "oui_hex": "14-69-A2",
        "organization": "SICHUAN TIANYI COMHEART TELECOM CO.,LTD",
        "address_1": "NO.198 FIRST SECTION,SNOW MOUNTAIN AVENUE, JINYUAN TOWN, DAYI COUNTY,",
        "address_2": "CHENGDU  SICHUAN  611330",
        "country": "CN"
    },
    "548028": {
        "oui_hex": "54-80-28",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "00AD24": {
        "oui_hex": "00-AD-24",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "54068B": {
        "oui_hex": "54-06-8B",
        "organization": "Ningbo Deli Kebei Technology Co.LTD",
        "address_1": "zone 2nd , 301#, Road Xuxiake, Ninghai yuelong district",
        "address_2": "ningbo  Zhejiang  315600",
        "country": "CN"
    },
    "60CE92": {
        "oui_hex": "60-CE-92",
        "organization": "The Refined Industry Company Limited",
        "address_1": "7/F Sun King Factory Bldg,1 - 7 Shing Chuen Road, Shatin, NT",
        "address_2": "Hong Kong  NT  000000",
        "country": "HK"
    },
    "105BAD": {
        "oui_hex": "10-5B-AD",
        "organization": "Mega Well Limited",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "74BFC0": {
        "oui_hex": "74-BF-C0",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "C8D9D2": {
        "oui_hex": "C8-D9-D2",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "24FCE5": {
        "oui_hex": "24-FC-E5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "809621": {
        "oui_hex": "80-96-21",
        "organization": "Lenovo",
        "address_1": "1009 Think Place",
        "address_2": "Morrisvilee  NC  27560",
        "country": "US"
    },
    "78055F": {
        "oui_hex": "78-05-5F",
        "organization": "Shenzhen WYC Technology Co., Ltd.",
        "address_1": "No.618 Wenzhengxin Building，Hi-tech Park，Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "00EABD": {
        "oui_hex": "00-EA-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "48872D": {
        "oui_hex": "48-87-2D",
        "organization": "SHEN ZHEN DA XIA LONG QUE TECHNOLOGY CO.,LTD",
        "address_1": "Room 511, Building C,  Yuxing Technology Park, Gushu Second Road, Bao’an District",
        "address_2": "SHEN ZHEN  GUANG DONG  518000",
        "country": "CN"
    },
    "E81A58": {
        "oui_hex": "E8-1A-58",
        "organization": "TECHNOLOGIC SYSTEMS",
        "address_1": "16525 E Laser Dr",
        "address_2": "Fountain Hills  AZ  85268-6534",
        "country": "US"
    },
    "20B001": {
        "oui_hex": "20-B0-01",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "C0BFA7": {
        "oui_hex": "C0-BF-A7",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F05494": {
        "oui_hex": "F0-54-94",
        "organization": "Honeywell Connected Building",
        "address_1": "1985 DOUGLAS DRIVE",
        "address_2": "Golden Valley  MN  55422",
        "country": "US"
    },
    "5CC999": {
        "oui_hex": "5C-C9-99",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "B02A43": {
        "oui_hex": "B0-2A-43",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "C474F8": {
        "oui_hex": "C4-74-F8",
        "organization": "Hot Pepper, Inc.",
        "address_1": "5151 California Ave., Suite 100,",
        "address_2": "Irvine     92617",
        "country": "US"
    },
    "142233": {
        "oui_hex": "14-22-33",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "743400": {
        "oui_hex": "74-34-00",
        "organization": "MTG Co., Ltd.",
        "address_1": "MTG No. 2 HIKARI Bldg., 4-13 Honjindori",
        "address_2": "Nakamura-ku, Nagoya  Aichi  453-0041",
        "country": "JP"
    },
    "DC3757": {
        "oui_hex": "DC-37-57",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "005099": {
        "oui_hex": "00-50-99",
        "organization": "3COM EUROPE LTD",
        "address_1": "BOUNDARY WAY",
        "address_2": "HERTS. HP2 7YU      vvvvvv",
        "country": "GB"
    },
    "04BC87": {
        "oui_hex": "04-BC-87",
        "organization": "Shenzhen JustLink Technology Co., LTD",
        "address_1": "Room 5002,The 2nd Unit  of  the   Building  East,   Laobing   Building, No.3012  Xingye Road,Baoan District",
        "address_2": "Shenzhen  Guangdong Province  518101",
        "country": "CN"
    },
    "54C33E": {
        "oui_hex": "54-C3-3E",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "EC79F2": {
        "oui_hex": "EC-79-F2",
        "organization": "Startel",
        "address_1": "Xi Chuang Industrial Park，Second industrial district of Guan Long Village，Xili town ，Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "BCB22B": {
        "oui_hex": "BC-B2-2B",
        "organization": "EM-Tech",
        "address_1": "40, Changwon-daero 1144beon-gil",
        "address_2": "Seongsan-gu Changwon  Gyeongsangnam-do  KR 642-120",
        "country": "KR"
    },
    "D4AB82": {
        "oui_hex": "D4-AB-82",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "704FB8": {
        "oui_hex": "70-4F-B8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0060EB": {
        "oui_hex": "00-60-EB",
        "organization": "FOURTHTRACK SYSTEMS",
        "address_1": "UNIT 3 THE SYCAMORES",
        "address_2": "MARLOW - SL7 1QB",
        "country": "GB"
    },
    "1862E4": {
        "oui_hex": "18-62-E4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "6035C0": {
        "oui_hex": "60-35-C0",
        "organization": "SFR",
        "address_1": "12 rue jean-philippe Rameau CS 80001",
        "address_2": "La plaine saint denis   FRANCE  93634",
        "country": "FR"
    },
    "C4985C": {
        "oui_hex": "C4-98-5C",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "30A1FA": {
        "oui_hex": "30-A1-FA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "242E90": {
        "oui_hex": "24-2E-90",
        "organization": "PALIT MICROSYSTEMS, LTD",
        "address_1": "21F.,No.88,Sec.2,Zhongxiao E.Rd.,Golden Tower,",
        "address_2": "TAIPEI    100",
        "country": "TW"
    },
    "9CAA1B": {
        "oui_hex": "9C-AA-1B",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "A89A93": {
        "oui_hex": "A8-9A-93",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "001AC5": {
        "oui_hex": "00-1A-C5",
        "organization": "Keysight Technologies, Inc.",
        "address_1": "1400 Fountaingrove Pkwy.",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "00201E": {
        "oui_hex": "00-20-1E",
        "organization": "NETQUEST CORPORATION",
        "address_1": "523 FELLOWSHIP ROAD-STE.#205",
        "address_2": "MT. LAUREL  NJ  08054",
        "country": "US"
    },
    "64628A": {
        "oui_hex": "64-62-8A",
        "organization": "evon GmbH",
        "address_1": "Frank-Stronach-Straße 8",
        "address_2": "Gleisdorf  Styria  8200",
        "country": "AT"
    },
    "0415D9": {
        "oui_hex": "04-15-D9",
        "organization": "Viwone",
        "address_1": "54 - 56 , Avenue Hoche",
        "address_2": "Paris    75008",
        "country": "FR"
    },
    "ECB313": {
        "oui_hex": "EC-B3-13",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "B08BCF": {
        "oui_hex": "B0-8B-CF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00608C": {
        "oui_hex": "00-60-8C",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "00A024": {
        "oui_hex": "00-A0-24",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "0020AF": {
        "oui_hex": "00-20-AF",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "00104B": {
        "oui_hex": "00-10-4B",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "A85AF3": {
        "oui_hex": "A8-5A-F3",
        "organization": "Shanghai Siflower Communication Technology Co., Ltd",
        "address_1": " Rm. 408, No. 84, Lane 887. Zhangjiang Hi-Tech Park. Zuchongzhi Rd. Shanghai, China",
        "address_2": "Shanghai  Shanghai  201210",
        "country": "CN"
    },
    "70FD46": {
        "oui_hex": "70-FD-46",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8C83E1": {
        "oui_hex": "8C-83-E1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "889F6F": {
        "oui_hex": "88-9F-6F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5C63C9": {
        "oui_hex": "5C-63-C9",
        "organization": "Intellithings Ltd.",
        "address_1": "Hanehoshet 10",
        "address_2": "Tel Aviv  Israel  6971072",
        "country": "IL"
    },
    "0C96E6": {
        "oui_hex": "0C-96-E6",
        "organization": "Cloud Network Technology (Samoa) Limited",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "3C8994": {
        "oui_hex": "3C-89-94",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "E00EE1": {
        "oui_hex": "E0-0E-E1",
        "organization": "We Corporation Inc.",
        "address_1": "201, 33, Deokcheon-ro, Manan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  14088",
        "country": "KR"
    },
    "000C43": {
        "oui_hex": "00-0C-43",
        "organization": "Ralink Technology, Corp.",
        "address_1": "4F, No.2, Technology 5th Road,",
        "address_2": "Hsin-Chu    200",
        "country": "TW"
    },
    "8C9246": {
        "oui_hex": "8C-92-46",
        "organization": "Oerlikon Textile Gmbh&Co.KG",
        "address_1": "NO.9 Changyang Street",
        "address_2": "Suzhou  Jiangsu  215000",
        "country": "CN"
    },
    "000E94": {
        "oui_hex": "00-0E-94",
        "organization": "Maas International BV",
        "address_1": "Science Park Eindhoven 5051",
        "address_2": "Son  Noord Brabant  NL-5692 EB",
        "country": "NL"
    },
    "4898CA": {
        "oui_hex": "48-98-CA",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "247E51": {
        "oui_hex": "24-7E-51",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E8B541": {
        "oui_hex": "E8-B5-41",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0C9D92": {
        "oui_hex": "0C-9D-92",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "988ED4": {
        "oui_hex": "98-8E-D4",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "E8A788": {
        "oui_hex": "E8-A7-88",
        "organization": "XIAMEN LEELEN TECHNOLOGY CO., LTD",
        "address_1": "65 Sunban South Rd., Jimei North Industrial Zone,",
        "address_2": "Xiamen   Fujian  361021",
        "country": "CN"
    },
    "582D34": {
        "oui_hex": "58-2D-34",
        "organization": "Qingping Electronics (Suzhou) Co., Ltd",
        "address_1": "Room 304, A3 Building, NO.88 Dongchang Road, Suzhou Industrial Park",
        "address_2": "Suzhou  Jiangsu Province  215028",
        "country": "CN"
    },
    "20DE88": {
        "oui_hex": "20-DE-88",
        "organization": "IC Realtime LLC",
        "address_1": "3050 N Andrews Ave Ext.",
        "address_2": "Pompano Beach  FL  33064",
        "country": "US"
    },
    "F4068D": {
        "oui_hex": "F4-06-8D",
        "organization": "devolo AG",
        "address_1": "Charlottenburger Allee 67",
        "address_2": "Aachen  NRW  52068",
        "country": "DE"
    },
    "001A31": {
        "oui_hex": "00-1A-31",
        "organization": "SCAN COIN AB",
        "address_1": "Jagershillgatan 26",
        "address_2": "Malmö  Skåne  21375",
        "country": "SE"
    },
    "001B84": {
        "oui_hex": "00-1B-84",
        "organization": "Scan Engineering Telecom",
        "address_1": "Svobody str. 75",
        "address_2": "Voronezh    394030",
        "country": "RU"
    },
    "482CA0": {
        "oui_hex": "48-2C-A0",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "3412F9": {
        "oui_hex": "34-12-F9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BCE265": {
        "oui_hex": "BC-E2-65",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4CD1A1": {
        "oui_hex": "4C-D1-A1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "88BFE4": {
        "oui_hex": "88-BF-E4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4017E2": {
        "oui_hex": "40-17-E2",
        "organization": "INTAI TECHNOLOGY CORP.",
        "address_1": "No.9, JINGKE RD.,NANTUN DIST.",
        "address_2": "TAICHUNG CITY    40852",
        "country": "TW"
    },
    "0CCB85": {
        "oui_hex": "0C-CB-85",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "A4E615": {
        "oui_hex": "A4-E6-15",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "741F79": {
        "oui_hex": "74-1F-79",
        "organization": "YOUNGKOOK ELECTRONICS CO.,LTD",
        "address_1": "#810, Daewoo Frontier Valley 1,16-25, Dongbaekjungang-ro 16beon-gil, Giheung-gu",
        "address_2": "YONGIN  Gyeonggi-do  17015",
        "country": "KR"
    },
    "A09351": {
        "oui_hex": "A0-93-51",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "98039B": {
        "oui_hex": "98-03-9B",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "208984": {
        "oui_hex": "20-89-84",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "No.25, Third Avenue, A Zone, Kunshan Comprehensive Free Trade Zone",
        "address_2": "KUNSHAN   SUZHOU   215300",
        "country": "CN"
    },
    "B4CEFE": {
        "oui_hex": "B4-CE-FE",
        "organization": "James Czekaj",
        "address_1": "41716 Waterfall Rd",
        "address_2": "Northville  MI  48168",
        "country": "US"
    },
    "F8CC6E": {
        "oui_hex": "F8-CC-6E",
        "organization": "DEPO Electronics Ltd",
        "address_1": "12, kommunalnaya zona Krasnogorsk-Mitino",
        "address_2": "Krasnogorsk  Moscow region  143404",
        "country": "RU"
    },
    "F8369B": {
        "oui_hex": "F8-36-9B",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "88AE1D": {
        "oui_hex": "88-AE-1D",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD STREET KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "B888E3": {
        "oui_hex": "B8-88-E3",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "No.25, Third Avenue, A Zone, Kunshan Comprehensive Free Trade Zone,, Jiangsu,",
        "address_2": "KUNSHAN   SUZHOU  215300",
        "country": "CN"
    },
    "289EFC": {
        "oui_hex": "28-9E-FC",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "00C055": {
        "oui_hex": "00-C0-55",
        "organization": "MODULAR COMPUTING TECHNOLOGIES",
        "address_1": "2352 MAIN STREET",
        "address_2": "CONCORD  MA  01742",
        "country": "US"
    },
    "E41FE9": {
        "oui_hex": "E4-1F-E9",
        "organization": "Dunkermotoren GmbH",
        "address_1": "Allmendstr. 11",
        "address_2": "Bonndorf  Baden-Württemberg  79848",
        "country": "DE"
    },
    "C4518D": {
        "oui_hex": "C4-51-8D",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "486834": {
        "oui_hex": "48-68-34",
        "organization": "Silicon Motion, Inc.",
        "address_1": "8F, No. 36, Taiyuan St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "001133": {
        "oui_hex": "00-11-33",
        "organization": "Siemens AG Austria",
        "address_1": "Siemensstrasse 90-92",
        "address_2": "Vienna    1210",
        "country": "AT"
    },
    "000B23": {
        "oui_hex": "00-0B-23",
        "organization": "Siemens Home & Office Comm. Devices",
        "address_1": "4849 Alpha Road",
        "address_2": "Dallas    74244",
        "country": "US"
    },
    "641331": {
        "oui_hex": "64-13-31",
        "organization": "Bosch Car Multimedia (Wuhu) Co. Ltd.",
        "address_1": "NO.48 North Yinhu Road",
        "address_2": "Wuhu city  Anhui Province  241000",
        "country": "CN"
    },
    "183A48": {
        "oui_hex": "18-3A-48",
        "organization": "VostroNet",
        "address_1": "GPO Box 3154",
        "address_2": "Brisbane  Queensland  4000",
        "country": "AU"
    },
    "782F17": {
        "oui_hex": "78-2F-17",
        "organization": "Xlab Co.,Ltd",
        "address_1": "#401 4F, Achasan-ro, Seongdong-gu",
        "address_2": "SEOUL    04793",
        "country": "KR"
    },
    "B0027E": {
        "oui_hex": "B0-02-7E",
        "organization": "MULLER SERVICES",
        "address_1": "107 Boulevard Ney",
        "address_2": "PARIS  ILE DE FRANCE  75018",
        "country": "FR"
    },
    "24FAF3": {
        "oui_hex": "24-FA-F3",
        "organization": "Shanghai Flexem Technology Co.,Ltd.",
        "address_1": "Room 804, C6 Building,No.52 Bay Valley Technology Park, Lane 1688 North Guoquan Road, Yangpu District.",
        "address_2": "Shanghai    200438",
        "country": "CN"
    },
    "88D2BF": {
        "oui_hex": "88-D2-BF",
        "organization": "German Autolabs",
        "address_1": "Köpenicker Str. 154",
        "address_2": "Berlin  Berlin  10997",
        "country": "DE"
    },
    "20163D": {
        "oui_hex": "20-16-3D",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "E0735F": {
        "oui_hex": "E0-73-5F",
        "organization": "NUCOM",
        "address_1": "Arte, 21,5B",
        "address_2": "Madrid  Madrid  28033",
        "country": "ES"
    },
    "0051ED": {
        "oui_hex": "00-51-ED",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "40DC9D": {
        "oui_hex": "40-DC-9D",
        "organization": "HAJEN",
        "address_1": "102-1302, Sinwon-ro 88, Yeongtong-gu",
        "address_2": "Suwon-Si  Gyeonggi-do  16681",
        "country": "KR"
    },
    "340A98": {
        "oui_hex": "34-0A-98",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "646D6C": {
        "oui_hex": "64-6D-6C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C4B8B4": {
        "oui_hex": "C4-B8-B4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F0BCC9": {
        "oui_hex": "F0-BC-C9",
        "organization": "PFU LIMITED",
        "address_1": "Nu 98-2 Unoke",
        "address_2": "Kahoku-shi, Ishikawa    929-1192",
        "country": "JP"
    },
    "487583": {
        "oui_hex": "48-75-83",
        "organization": "Intellion AG",
        "address_1": "Schuppisstrasse 10",
        "address_2": "St. Gallen  St. Gallen  9016",
        "country": "CH"
    },
    "904C81": {
        "oui_hex": "90-4C-81",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "8C3579": {
        "oui_hex": "8C-35-79",
        "organization": "QDIQO Sp. z o.o.",
        "address_1": "Stanisława Wyspiańskiego 11",
        "address_2": "Zielona Góra  lubuskie  65-036",
        "country": "PL"
    },
    "38C70A": {
        "oui_hex": "38-C7-0A",
        "organization": "WiFiSong",
        "address_1": "Rm. 605, Building 3, No. 75 Wenyi West Road",
        "address_2": "Hangzhou  Zhengjiang  310012",
        "country": "CN"
    },
    "D8760A": {
        "oui_hex": "D8-76-0A",
        "organization": "Escort, Inc.",
        "address_1": "5440 West Chester Rd.",
        "address_2": "West Chester  Ohio  45069",
        "country": "US"
    },
    "5C2ED2": {
        "oui_hex": "5C-2E-D2",
        "organization": "ABC(XiSheng) Electronics Co.,Ltd",
        "address_1": "No.2 Industrial building, FuRong 7 Road",
        "address_2": "ShenZhen  GongDong  518100",
        "country": "CN"
    },
    "FCFBFB": {
        "oui_hex": "FC-FB-FB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "007E95": {
        "oui_hex": "00-7E-95",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9C5A44": {
        "oui_hex": "9C-5A-44",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "14CAA0": {
        "oui_hex": "14-CA-A0",
        "organization": "Hu&Co",
        "address_1": "105 Rue du Jardin",
        "address_2": "Bordeaux    33000",
        "country": "FR"
    },
    "08D46A": {
        "oui_hex": "08-D4-6A",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "683A1E": {
        "oui_hex": "68-3A-1E",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "001017": {
        "oui_hex": "00-10-17",
        "organization": "Bosch Access Systems GmbH",
        "address_1": "Charlottenburger Allee 50",
        "address_2": "AACHEN      D-52068",
        "country": "DE"
    },
    "F4EE14": {
        "oui_hex": "F4-EE-14",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "6C5940": {
        "oui_hex": "6C-59-40",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D02516": {
        "oui_hex": "D0-25-16",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "1C60DE": {
        "oui_hex": "1C-60-DE",
        "organization": "MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "Mid-Fourth Flr.,Building 28,Cui Xi Fourth Road,Ke Yuan West,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D82477": {
        "oui_hex": "D8-24-77",
        "organization": "Universal Electric Corporation",
        "address_1": "168 Georgetown Road",
        "address_2": "Canonsburg  PA  15317",
        "country": "US"
    },
    "00907F": {
        "oui_hex": "00-90-7F",
        "organization": "WatchGuard Technologies, Inc.",
        "address_1": "605 Fifth Ave. S",
        "address_2": "Seattle  WA  98104-3892",
        "country": "US"
    },
    "4C5E0C": {
        "oui_hex": "4C-5E-0C",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga    LV1009",
        "country": "LV"
    },
    "D4CA6D": {
        "oui_hex": "D4-CA-6D",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga    LV-1009",
        "country": "LV"
    },
    "001472": {
        "oui_hex": "00-14-72",
        "organization": "China Broadband Wireless IP Standard group(ChinaBWIPS)",
        "address_1": "P.O.BOX 88,West High-tech",
        "address_2": "Xi'an  Shaan Xi  710075",
        "country": "CN"
    },
    "80B575": {
        "oui_hex": "80-B5-75",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4BE2B": {
        "oui_hex": "A4-BE-2B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "68E7C2": {
        "oui_hex": "68-E7-C2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "58B10F": {
        "oui_hex": "58-B1-0F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4006A0": {
        "oui_hex": "40-06-A0",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F82DC0": {
        "oui_hex": "F8-2D-C0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "189C27": {
        "oui_hex": "18-9C-27",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3CF5CC": {
        "oui_hex": "3C-F5-CC",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "D08A91": {
        "oui_hex": "D0-8A-91",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "2811A5": {
        "oui_hex": "28-11-A5",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "D8F3DB": {
        "oui_hex": "D8-F3-DB",
        "organization": "Post CH AG",
        "address_1": "Wankdorfallee 4",
        "address_2": "Bern    3030",
        "country": "CH"
    },
    "DCB4AC": {
        "oui_hex": "DC-B4-AC",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "A492CB": {
        "oui_hex": "A4-92-CB",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "C0D2F3": {
        "oui_hex": "C0-D2-F3",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "B88303": {
        "oui_hex": "B8-83-03",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "203DBD": {
        "oui_hex": "20-3D-BD",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "A45385": {
        "oui_hex": "A4-53-85",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road,Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "00402F": {
        "oui_hex": "00-40-2F",
        "organization": "XLNT DESIGNS INC.",
        "address_1": "15050 AVENUE OF SCIENCE",
        "address_2": "SAN DIEGO  CA  92128",
        "country": "US"
    },
    "04ECBB": {
        "oui_hex": "04-EC-BB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "64A2F9": {
        "oui_hex": "64-A2-F9",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A87D12": {
        "oui_hex": "A8-7D-12",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D42122": {
        "oui_hex": "D4-21-22",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "00C002": {
        "oui_hex": "00-C0-02",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "BC9911": {
        "oui_hex": "BC-99-11",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "280245": {
        "oui_hex": "28-02-45",
        "organization": "Konze System Technology Co.,Ltd.",
        "address_1": "4F., No.134, Ln. 235, Baoqiao Rd., Xindian Dist.",
        "address_2": "New Taipei City  ---  231",
        "country": "TW"
    },
    "E48F65": {
        "oui_hex": "E4-8F-65",
        "organization": "Yelatma Instrument Making Enterprise, JSC",
        "address_1": "Yanina 25",
        "address_2": "Yelatma  Ryazan Region  391351",
        "country": "RU"
    },
    "0000A8": {
        "oui_hex": "00-00-A8",
        "organization": "Stratus Technologies",
        "address_1": "5 Mill and Main Place, Suite 500",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "0004FC": {
        "oui_hex": "00-04-FC",
        "organization": "Stratus Technologies",
        "address_1": "5 Mill and Main Place, Suite 500",
        "address_2": "Maynard  MA  01754",
        "country": "US"
    },
    "3C24F0": {
        "oui_hex": "3C-24-F0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "00BB3A": {
        "oui_hex": "00-BB-3A",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "0CB34F": {
        "oui_hex": "0C-B3-4F",
        "organization": "Shenzhen Xiaoqi Intelligent Technology Co., Ltd.",
        "address_1": "Room 1501, Block B4, Building 9, Section 2, Shenzhen Bay Science & Technology Ecological Park, West Shahe Road, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "3CF4F9": {
        "oui_hex": "3C-F4-F9",
        "organization": "Moda-InnoChips",
        "address_1": "42-7(Wonsi-Dong),Dongsan-ro 27beon-gil,Danwon-gu",
        "address_2": "Ansan-si   Gyeonggi-Do  15433",
        "country": "KR"
    },
    "94193A": {
        "oui_hex": "94-19-3A",
        "organization": "Elvaco AB",
        "address_1": "Kabelgatan 2T",
        "address_2": "Kungsbacka    43437",
        "country": "SE"
    },
    "C08135": {
        "oui_hex": "C0-81-35",
        "organization": "Ningbo Forfan technology Co., LTD",
        "address_1": "Room B308,Tianjing Building,Tianan Cyber Park,Futian",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "840D8E": {
        "oui_hex": "84-0D-8E",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "002082": {
        "oui_hex": "00-20-82",
        "organization": "ONEAC CORPORATION",
        "address_1": "27944 N. BRADLEY RD.",
        "address_2": "LIBERTYVILLE  IL  60048",
        "country": "US"
    },
    "B4C0F5": {
        "oui_hex": "B4-C0-F5",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "406231": {
        "oui_hex": "40-62-31",
        "organization": "GIFA",
        "address_1": "11th Fl., Suojia Business Building , No.7 Hangkong Road , Baoan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "FCB7F0": {
        "oui_hex": "FC-B7-F0",
        "organization": "Idaho National Laboratory",
        "address_1": "2525 N. Fremont Ave",
        "address_2": "Idaho Falls  ID  83415",
        "country": "US"
    },
    "2C28B7": {
        "oui_hex": "2C-28-B7",
        "organization": "Hangzhou Ruiying technology co., LTD",
        "address_1": "No. 1, building 305, Yunqi Town Cloud Computing Industrial Park, Hangzhou City, Xihu District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "106530": {
        "oui_hex": "10-65-30",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "046B1B": {
        "oui_hex": "04-6B-1B",
        "organization": "SYSDINE Co., Ltd.",
        "address_1": "506 Convergence technology research commercialization center 218 Gajung-Ro, Yuseong-gu",
        "address_2": "Daejeon-City  Daejeon-City  34129",
        "country": "KR"
    },
    "B0A37E": {
        "oui_hex": "B0-A3-7E",
        "organization": "QING DAO HAIER TELECOM CO.,LTD.",
        "address_1": "No.1,Haier Road,Qingdao 266101 P.R.China",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "3CEAF9": {
        "oui_hex": "3C-EA-F9",
        "organization": "JUBIXCOLTD",
        "address_1": "Rm 808, 809, B dong, Gunpo IT vally, 17, Gosan-ro 148beon-gil, Gunpo-si, Gyeonggi-do, Republic of Korea",
        "address_2": "GUNPOSI    15850",
        "country": "KR"
    },
    "58DB15": {
        "oui_hex": "58-DB-15",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "5050CE": {
        "oui_hex": "50-50-CE",
        "organization": "Hangzhou Dianyixia Communication Technology Co. Ltd.",
        "address_1": "Room 207, Building 7, 1197 bin 'an road, Binjiang district,",
        "address_2": "Hangzhou  Zhejiang  310011",
        "country": "CN"
    },
    "FC6947": {
        "oui_hex": "FC-69-47",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E07DEA": {
        "oui_hex": "E0-7D-EA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "DCDE4F": {
        "oui_hex": "DC-DE-4F",
        "organization": "Gionee Communication Equipment Co Ltd",
        "address_1": "21/F Times Technology Building, 7028 Shennan Road",
        "address_2": "Shenzhen  Futian District  518040",
        "country": "CN"
    },
    "4CD0CB": {
        "oui_hex": "4C-D0-CB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "505DAC": {
        "oui_hex": "50-5D-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8FAF7": {
        "oui_hex": "E8-FA-F7",
        "organization": "Guangdong Uniteddata Holding Group Co., Ltd.",
        "address_1": "39L, Pearl River Tower, No.15 Zhujiang West Road,Tianhe District",
        "address_2": "GUANGZHOU  GUANGDONG  510623",
        "country": "CN"
    },
    "949D57": {
        "oui_hex": "94-9D-57",
        "organization": "Panasonic do Brasil Limitada",
        "address_1": "Rua Matrinxa",
        "address_2": "Manaus  Amazonas  69075150",
        "country": "BR"
    },
    "88D37B": {
        "oui_hex": "88-D3-7B",
        "organization": "FirmTek, LLC",
        "address_1": "29300 Kohoutek Way",
        "address_2": "Union City  CA  94587",
        "country": "US"
    },
    "1C666D": {
        "oui_hex": "1C-66-6D",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "84F3EB": {
        "oui_hex": "84-F3-EB",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "001B48": {
        "oui_hex": "00-1B-48",
        "organization": "Shenzhen Lantech Electronics Co., Ltd.",
        "address_1": "306 Room, Nanshan Water Building,",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "00250C": {
        "oui_hex": "00-25-0C",
        "organization": "Senet Inc",
        "address_1": "100 Market Street, Suite 302",
        "address_2": " Portsmouth  NH  03801",
        "country": "US"
    },
    "0C8063": {
        "oui_hex": "0C-80-63",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "007278": {
        "oui_hex": "00-72-78",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "645AED": {
        "oui_hex": "64-5A-ED",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0B658": {
        "oui_hex": "C0-B6-58",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48A91C": {
        "oui_hex": "48-A9-1C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "50BC96": {
        "oui_hex": "50-BC-96",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FC2A9C": {
        "oui_hex": "FC-2A-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "682C7B": {
        "oui_hex": "68-2C-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "441E98": {
        "oui_hex": "44-1E-98",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "A056F3": {
        "oui_hex": "A0-56-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "549963": {
        "oui_hex": "54-99-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90DD5D": {
        "oui_hex": "90-DD-5D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC2919": {
        "oui_hex": "DC-29-19",
        "organization": "AltoBeam (Xiamen) Technology Ltd, Co.",
        "address_1": "South Building 203-38,Huoju Square ,No.56-58,Huoju Road, Huoju Park, Huoju High-tech District",
        "address_2": "Xiamen    361000",
        "country": "CN"
    },
    "885FE8": {
        "oui_hex": "88-5F-E8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "002FD9": {
        "oui_hex": "00-2F-D9",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "B4CD27": {
        "oui_hex": "B4-CD-27",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C819F7": {
        "oui_hex": "C8-19-F7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "64C3D6": {
        "oui_hex": "64-C3-D6",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00A021": {
        "oui_hex": "00-A0-21",
        "organization": "General Dynamics Mission Systems",
        "address_1": "150 Rustcraft Road",
        "address_2": "Dedham  MA  02026",
        "country": "US"
    },
    "F0AF50": {
        "oui_hex": "F0-AF-50",
        "organization": "Phantom Intelligence",
        "address_1": "319 Rue Franquet Suite F",
        "address_2": "Quebec  QC  G1P 4R4",
        "country": "CA"
    },
    "C42C4F": {
        "oui_hex": "C4-2C-4F",
        "organization": "Qingdao Hisense Mobile Communication Technology Co,Ltd",
        "address_1": "No.399, Song Ling Road",
        "address_2": "Qingdao  Shandong  266100",
        "country": "CN"
    },
    "24CACB": {
        "oui_hex": "24-CA-CB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "543E64": {
        "oui_hex": "54-3E-64",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "6402CB": {
        "oui_hex": "64-02-CB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F4E11E": {
        "oui_hex": "F4-E1-1E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3880DF": {
        "oui_hex": "38-80-DF",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "BC6A2F": {
        "oui_hex": "BC-6A-2F",
        "organization": "Henge Docks LLC",
        "address_1": "455 10th St.",
        "address_2": "San Francisco  California  94103",
        "country": "US"
    },
    "0C08B4": {
        "oui_hex": "0C-08-B4",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "002705": {
        "oui_hex": "00-27-05",
        "organization": "Sectronic",
        "address_1": "Z.I. Les Saulniers",
        "address_2": "Sainte-Maure de Touraine    37800",
        "country": "FR"
    },
    "48BD3D": {
        "oui_hex": "48-BD-3D",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "184C08": {
        "oui_hex": "18-4C-08",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "DC0265": {
        "oui_hex": "DC-02-65",
        "organization": "Meditech Kft",
        "address_1": "Üllõi út 200.",
        "address_2": "Budapest    1191",
        "country": "HU"
    },
    "180F76": {
        "oui_hex": "18-0F-76",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "14A72B": {
        "oui_hex": "14-A7-2B",
        "organization": "currentoptronics Pvt.Ltd",
        "address_1": "CRT Building, Jupitor Jn , Near Time kids Koothattukulam - Piravom Rd",
        "address_2": "ERNAKULAM  Time Kids day care  686662",
        "country": "IN"
    },
    "A4DA22": {
        "oui_hex": "A4-DA-22",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "3C1710": {
        "oui_hex": "3C-17-10",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "DC729B": {
        "oui_hex": "DC-72-9B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "909497": {
        "oui_hex": "90-94-97",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "34029B": {
        "oui_hex": "34-02-9B",
        "organization": "Plexonics Technologies LImited",
        "address_1": "1st Floor, 181/23 Industrial Area Phase 1",
        "address_2": "Chandigarh  Punjab  160002",
        "country": "IN"
    },
    "900372": {
        "oui_hex": "90-03-72",
        "organization": "Longnan Junya Digital Technology Co. Ltd.",
        "address_1": "Champion Asia Road, Xinzhen industrial Park, Longnan national economic and technological development zone, Ganzhou city, JiangXi Province , China",
        "address_2": "ganzhou  jiangxi  341700",
        "country": "CN"
    },
    "84DB9E": {
        "oui_hex": "84-DB-9E",
        "organization": "Aifloo AB",
        "address_1": "Postbox 2005",
        "address_2": "Stockholm    10311",
        "country": "SE"
    },
    "0CC6CC": {
        "oui_hex": "0C-C6-CC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "785860": {
        "oui_hex": "78-58-60",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8ABF3": {
        "oui_hex": "E8-AB-F3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3CDCBC": {
        "oui_hex": "3C-DC-BC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "804E70": {
        "oui_hex": "80-4E-70",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D4E6B7": {
        "oui_hex": "D4-E6-B7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8C4CAD": {
        "oui_hex": "8C-4C-AD",
        "organization": "Evoluzn Inc.",
        "address_1": "34 Samoset Lane",
        "address_2": "Schaumburg  IL  60193",
        "country": "US"
    },
    "8CF957": {
        "oui_hex": "8C-F9-57",
        "organization": "RuiXingHengFang Network (Shenzhen) Co.,Ltd",
        "address_1": "Room 507, 2nd tower of KangTai biological building  NO.6 KeFa Rd. NanShan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4C776D": {
        "oui_hex": "4C-77-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "74E182": {
        "oui_hex": "74-E1-82",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "449EF9": {
        "oui_hex": "44-9E-F9",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "6CC4D5": {
        "oui_hex": "6C-C4-D5",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "80C548": {
        "oui_hex": "80-C5-48",
        "organization": "Shenzhen Zowee Technology Co.,Ltd",
        "address_1": "NO.5 Zowee technology building, Science & Technology industrial park of privately  Science & Technology industrial park of privately owned enterprises",
        "address_2": "Shenzhen  GuangDong  518055",
        "country": "CN"
    },
    "10C25A": {
        "oui_hex": "10-C2-5A",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "E8DEFB": {
        "oui_hex": "E8-DE-FB",
        "organization": "MESOTIC SAS",
        "address_1": "11, Avenue de la Division Leclerc",
        "address_2": "Cachan    94230",
        "country": "FR"
    },
    "C400AD": {
        "oui_hex": "C4-00-AD",
        "organization": "Advantech Technology (CHINA) Co., Ltd.",
        "address_1": "No.666, Han-Pu Rd. Yu-Shan",
        "address_2": "Kun-Shan  Jiang Su  215316",
        "country": "CN"
    },
    "94FE9D": {
        "oui_hex": "94-FE-9D",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "SONGGANG",
        "address_2": "SHENZHEN  GUANGDONG  518105",
        "country": "CN"
    },
    "6CB6CA": {
        "oui_hex": "6C-B6-CA",
        "organization": "DIVUS GmbH",
        "address_1": "Pillhof 51",
        "address_2": "Eppan    39057",
        "country": "IT"
    },
    "04D13A": {
        "oui_hex": "04-D1-3A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "4CC206": {
        "oui_hex": "4C-C2-06",
        "organization": "Somfy",
        "address_1": "50 avenue du nouveau monde",
        "address_2": "Cluses    74300",
        "country": "FR"
    },
    "040973": {
        "oui_hex": "04-09-73",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "3499D7": {
        "oui_hex": "34-99-D7",
        "organization": "Universal Flow Monitors, Inc.",
        "address_1": "1755 E. Nine Mile Rd.",
        "address_2": "Hazel Park  MI  48030",
        "country": "US"
    },
    "0C8BD3": {
        "oui_hex": "0C-8B-D3",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "C0A8F0": {
        "oui_hex": "C0-A8-F0",
        "organization": "Adamson Systems Engineering",
        "address_1": "1401 Scugog Line 6",
        "address_2": "Port Perry  Ontario  L9L 1B2",
        "country": "CA"
    },
    "9C431E": {
        "oui_hex": "9C-43-1E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0024AF": {
        "oui_hex": "00-24-AF",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "282C02": {
        "oui_hex": "28-2C-02",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "FCA183": {
        "oui_hex": "FC-A1-83",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno    89507",
        "country": "US"
    },
    "6C2ACB": {
        "oui_hex": "6C-2A-CB",
        "organization": "Paxton Access Ltd",
        "address_1": "Paxton House",
        "address_2": "Brighton  East Sussex  BN1 9HU",
        "country": "GB"
    },
    "583BD9": {
        "oui_hex": "58-3B-D9",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "DCA266": {
        "oui_hex": "DC-A2-66",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C48466": {
        "oui_hex": "C4-84-66",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "347C25": {
        "oui_hex": "34-7C-25",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC2DB7": {
        "oui_hex": "CC-2D-B7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0BDCD": {
        "oui_hex": "A0-BD-CD",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "BC91B5": {
        "oui_hex": "BC-91-B5",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "282FC2": {
        "oui_hex": "28-2F-C2",
        "organization": "Automotive Data Solutions",
        "address_1": "8400 rue Bougainville",
        "address_2": "Montreal  Quebec  H4P2G1",
        "country": "CA"
    },
    "980074": {
        "oui_hex": "98-00-74",
        "organization": "Raisecom Technology CO., LTD",
        "address_1": "No. 11, East Area, No. 10 Block, East Xibeiwang Road",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "18C19D": {
        "oui_hex": "18-C1-9D",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "0C9838": {
        "oui_hex": "0C-98-38",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "74EACB": {
        "oui_hex": "74-EA-CB",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "D41A3F": {
        "oui_hex": "D4-1A-3F",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D8B122": {
        "oui_hex": "D8-B1-22",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B4C799": {
        "oui_hex": "B4-C7-99",
        "organization": "Extreme Networks, Inc.",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "646E6C": {
        "oui_hex": "64-6E-6C",
        "organization": "Radio Datacom LLC",
        "address_1": "9601 N 35th St",
        "address_2": "Phoenix  AZ  85028",
        "country": "US"
    },
    "E88E60": {
        "oui_hex": "E8-8E-60",
        "organization": "NSD Corporation",
        "address_1": "Osu 3-31-28",
        "address_2": "Nagoya  Aichi  460-8302",
        "country": "JP"
    },
    "000F9B": {
        "oui_hex": "00-0F-9B",
        "organization": "Ross Video Limited",
        "address_1": "8 John Street",
        "address_2": "Iroquois  Ontario  K0E 1K0",
        "country": "CA"
    },
    "0024BA": {
        "oui_hex": "00-24-BA",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "60512C": {
        "oui_hex": "60-51-2C",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "64DB81": {
        "oui_hex": "64-DB-81",
        "organization": "Syszone Co., Ltd.",
        "address_1": "9F Garak, 310 Ogeum-ro",
        "address_2": "Seoul  Seoul, Korea  138-716",
        "country": "KR"
    },
    "44AD19": {
        "oui_hex": "44-AD-19",
        "organization": "XINGFEI （H.K）LIMITED",
        "address_1": "6/F North Tower Wandelai Building  No.29 Kejinan 6th Road, Nanshan District,Shenzhen,China",
        "address_2": "Shenzhen     518057",
        "country": "CN"
    },
    "38ADBE": {
        "oui_hex": "38-AD-BE",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "5CAD76": {
        "oui_hex": "5C-AD-76",
        "organization": "Shenzhen TCL New Technology Co., Ltd",
        "address_1": "B area,10 Floor, TCL Multimedia Building, TCL International E city, #1001 Zhongshan Park Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "5C865C": {
        "oui_hex": "5C-86-5C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "04F128": {
        "oui_hex": "04-F1-28",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "04B167": {
        "oui_hex": "04-B1-67",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "EC8350": {
        "oui_hex": "EC-83-50",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "D007CA": {
        "oui_hex": "D0-07-CA",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "1CDF52": {
        "oui_hex": "1C-DF-52",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "30C507": {
        "oui_hex": "30-C5-07",
        "organization": "ECI Telecom Ltd.",
        "address_1": "30 Hasivim St.",
        "address_2": "Petah Tikva    49133",
        "country": "IL"
    },
    "C8458F": {
        "oui_hex": "C8-45-8F",
        "organization": "Wyler AG",
        "address_1": "Im Hoelderli 13",
        "address_2": "Winterthur  ZH  8405",
        "country": "CH"
    },
    "001BB9": {
        "oui_hex": "00-1B-B9",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22, Alley 38, Lane 91 , Sec. 1 , Nei Hu Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "002461": {
        "oui_hex": "00-24-61",
        "organization": "Shin Wang Tech.",
        "address_1": "632-62, Guro-Dong, Guro-Gu",
        "address_2": "Seoul    152-866",
        "country": "KR"
    },
    "0C5203": {
        "oui_hex": "0C-52-03",
        "organization": "AGM GROUP LIMITED",
        "address_1": "4F,Building B,HuaFeng Ind park,Gushu,Xixiang,BaoAn,ShenZhen,China",
        "address_2": "ShenZhen  GuangDong  518100",
        "country": "CN"
    },
    "2C5491": {
        "oui_hex": "2C-54-91",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "3817C3": {
        "oui_hex": "38-17-C3",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "001E1D": {
        "oui_hex": "00-1E-1D",
        "organization": "East Coast Datacom, Inc.",
        "address_1": "245 Gus Hipp Blvd., STE 3",
        "address_2": "Rockledge  FL  32955",
        "country": "US"
    },
    "7846C4": {
        "oui_hex": "78-46-C4",
        "organization": "DAEHAP HYPER-TECH",
        "address_1": "#A-805, Woolim Lions Vally 5-cha, #144-3 Sangdaewon-dong, Jungwon-Gu",
        "address_2": "Seongnam    462-726",
        "country": "US"
    },
    "5CE28C": {
        "oui_hex": "5C-E2-8C",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "E4BD4B": {
        "oui_hex": "E4-BD-4B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "38D7CA": {
        "oui_hex": "38-D7-CA",
        "organization": "7HUGS LABS",
        "address_1": "29 bd Romain Rolland",
        "address_2": "Montrouge     92120",
        "country": "FR"
    },
    "000144": {
        "oui_hex": "00-01-44",
        "organization": "Dell EMC",
        "address_1": "228 South St.",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "08001B": {
        "oui_hex": "08-00-1B",
        "organization": "Dell EMC",
        "address_1": "176 South Street",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "7C010A": {
        "oui_hex": "7C-01-0A",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E42B34": {
        "oui_hex": "E4-2B-34",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C2EF9": {
        "oui_hex": "3C-2E-F9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A04EA7": {
        "oui_hex": "A0-4E-A7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0989D": {
        "oui_hex": "F0-98-9D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCD6BD": {
        "oui_hex": "FC-D6-BD",
        "organization": "Robert Bosch GmbH",
        "address_1": "AE-BE/EKE",
        "address_2": "Leonberg  BW  71206",
        "country": "DE"
    },
    "701F53": {
        "oui_hex": "70-1F-53",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18396E": {
        "oui_hex": "18-39-6E",
        "organization": "SUNSEA TELECOMMUNICATIONS CO.,LTD.",
        "address_1": "High tech Industrial Park,Longhua District of Shenzhen City,South central concept",
        "address_2": "Shenzhen    518110",
        "country": "CN"
    },
    "EC7D11": {
        "oui_hex": "EC-7D-11",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "480EEC": {
        "oui_hex": "48-0E-EC",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "503EAA": {
        "oui_hex": "50-3E-AA",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5800BB": {
        "oui_hex": "58-00-BB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "48BA4E": {
        "oui_hex": "48-BA-4E",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "D80831": {
        "oui_hex": "D8-08-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9441C1": {
        "oui_hex": "94-41-C1",
        "organization": "Mini-Cam Limited",
        "address_1": "Unit 4 Yew Tree Way",
        "address_2": "Warrington  Cheshire  WA33JD",
        "country": "GB"
    },
    "504EDC": {
        "oui_hex": "50-4E-DC",
        "organization": "Ping Communication",
        "address_1": "Brenden 18",
        "address_2": "Appenzell Meistersrüte  AI  9050",
        "country": "CH"
    },
    "08674E": {
        "oui_hex": "08-67-4E",
        "organization": "Hisense broadband multimedia technology Co.,Ltd",
        "address_1": "Song ling Road 399",
        "address_2": "Qingdao    266000",
        "country": "CN"
    },
    "500F80": {
        "oui_hex": "50-0F-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "10F1F2": {
        "oui_hex": "10-F1-F2",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "8C68C8": {
        "oui_hex": "8C-68-C8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "EC8263": {
        "oui_hex": "EC-82-63",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "683C7D": {
        "oui_hex": "68-3C-7D",
        "organization": "Magic Intelligence Technology Limited",
        "address_1": "B13/Flat 4,East block,Jinhui Blding.Nanhai Road",
        "address_2": "Nanshan District, Shenzhen  guangdong  518000",
        "country": "CN"
    },
    "0C1C20": {
        "oui_hex": "0C-1C-20",
        "organization": "Kakao Corp",
        "address_1": "242, Cheomdan-ro",
        "address_2": "Jeju-si  Jeju-do  63309",
        "country": "KR"
    },
    "24F5A2": {
        "oui_hex": "24-F5-A2",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  null  90094",
        "country": "US"
    },
    "74BBD3": {
        "oui_hex": "74-BB-D3",
        "organization": "Shenzhen xeme Communication Co., Ltd.",
        "address_1": "303,Block D,Huayuan  technology innovation park,Bao Yuen road,Xixiang street,Baoan District",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "94282E": {
        "oui_hex": "94-28-2E",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "98F5A9": {
        "oui_hex": "98-F5-A9",
        "organization": "OHSUNG",
        "address_1": "181",
        "address_2": "GUMI  KYUNGBUK  730-030",
        "country": "KR"
    },
    "D89EF3": {
        "oui_hex": "D8-9E-F3",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "384F49": {
        "oui_hex": "38-4F-49",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "4CBD8F": {
        "oui_hex": "4C-BD-8F",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "ECEBB8": {
        "oui_hex": "EC-EB-B8",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "6CB749": {
        "oui_hex": "6C-B7-49",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "989C57": {
        "oui_hex": "98-9C-57",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "185282": {
        "oui_hex": "18-52-82",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "8C3C4A": {
        "oui_hex": "8C-3C-4A",
        "organization": "NAKAYO Inc",
        "address_1": "Development Support Center 165 Higashiomuro-machi",
        "address_2": "Maebashi-shi  Gunma  379-2105",
        "country": "JP"
    },
    "7086C1": {
        "oui_hex": "70-86-C1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F4D7B2": {
        "oui_hex": "F4-D7-B2",
        "organization": "LGS Innovations, LLC",
        "address_1": "13665 Dulles Technology Drive",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "00152A": {
        "oui_hex": "00-15-2A",
        "organization": "Nokia Corporation",
        "address_1": "Rensingstraße 15",
        "address_2": "Bochum  NRW  44807",
        "country": "DE"
    },
    "9C4A7B": {
        "oui_hex": "9C-4A-7B",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "D86162": {
        "oui_hex": "D8-61-62",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "28840E": {
        "oui_hex": "28-84-0E",
        "organization": "silicon valley immigration service",
        "address_1": "1410 Sharp Ave,",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "80615F": {
        "oui_hex": "80-61-5F",
        "organization": "Beijing Sinead Technology Co., Ltd.",
        "address_1": "Room 504,Block A, New material Building, Yongfeng industrial, Haiding District, Beijing.China",
        "address_2": "Beijing  Beijing  100000",
        "country": "CN"
    },
    "2CD2E7": {
        "oui_hex": "2C-D2-E7",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "386EA2": {
        "oui_hex": "38-6E-A2",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "982D68": {
        "oui_hex": "98-2D-68",
        "organization": "Samsung Electronics Co., Ltd",
        "address_1": "Samsung 1-ro",
        "address_2": "Hwaseong-si  Gyeonggi-do  445330",
        "country": "KR"
    },
    "BC2E48": {
        "oui_hex": "BC-2E-48",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "608CE6": {
        "oui_hex": "60-8C-E6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "080070": {
        "oui_hex": "08-00-70",
        "organization": "Mitsubishi Precision Co.,LTd.",
        "address_1": "325 KAMIMACHIYA",
        "address_2": "000    00",
        "country": "JP"
    },
    "444AB0": {
        "oui_hex": "44-4A-B0",
        "organization": "Zhejiang Moorgen Intelligence Technology Co., Ltd",
        "address_1": "No.181 Changluo road Luotuo street Zhenhai district",
        "address_2": "Ningbo  Zhejiang  315202",
        "country": "CN"
    },
    "DC6AEA": {
        "oui_hex": "DC-6A-EA",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "C421C8": {
        "oui_hex": "C4-21-C8",
        "organization": "KYOCERA CORPORATION",
        "address_1": "2-1-1,Kagahara,",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "80739F": {
        "oui_hex": "80-73-9F",
        "organization": "KYOCERA CORPORATION",
        "address_1": "2-1-1 Kagahara",
        "address_2": "Yokohama-shi  Kanagawa  224-8502",
        "country": "JP"
    },
    "48EC5B": {
        "oui_hex": "48-EC-5B",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "705812": {
        "oui_hex": "70-58-12",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma  Osaka  571-8504",
        "country": "JP"
    },
    "04209A": {
        "oui_hex": "04-20-9A",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma City  Osaka  571-8504",
        "country": "JP"
    },
    "34008A": {
        "oui_hex": "34-00-8A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A41115": {
        "oui_hex": "A4-11-15",
        "organization": "Robert Bosch Engineering and Business Solutions pvt. Ltd.",
        "address_1": "123, Industrial Layout, Hosur Road, Koramangala,",
        "address_2": "Bangalore  Karnataka  560095",
        "country": "IN"
    },
    "40D63C": {
        "oui_hex": "40-D6-3C",
        "organization": "Equitech Industrial(DongGuan)Co.,Ltd",
        "address_1": "4F Building B No.2 ShiChang Road SongYuan Technology Park,DongCheng District",
        "address_2": "DongGuan  GuangDong  523122",
        "country": "CN"
    },
    "F4F3AA": {
        "oui_hex": "F4-F3-AA",
        "organization": "JBL GmbH & Co. KG",
        "address_1": "Dieselstrasse 3",
        "address_2": "Neuhofen    67141",
        "country": "DE"
    },
    "9050CA": {
        "oui_hex": "90-50-CA",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "409922": {
        "oui_hex": "40-99-22",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "C06D1A": {
        "oui_hex": "C0-6D-1A",
        "organization": "Tianjin Henxinhuifeng Technology Co.,Ltd.",
        "address_1": "Rm 233, Tianjin Technology Innovation Service Center, 12 Keyan West Road, Nankai District, Tianjin, P.R.C.",
        "address_2": "Tianjin  Tianjin  300192",
        "country": "CN"
    },
    "107B44": {
        "oui_hex": "10-7B-44",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "84253F": {
        "oui_hex": "84-25-3F",
        "organization": "silex technology, Inc.",
        "address_1": "2-3-1 Hikaridai",
        "address_2": "Seika-cho  Kyoto  619-0237",
        "country": "JP"
    },
    "0008C9": {
        "oui_hex": "00-08-C9",
        "organization": "TechniSat Digital GmbH Daun",
        "address_1": "Gewerbepark Merbitz Nr. 5",
        "address_2": "Dresden    01156",
        "country": "US"
    },
    "D8B12A": {
        "oui_hex": "D8-B1-2A",
        "organization": "Panasonic Mobile Communications Co.,Ltd.",
        "address_1": "600 Saedo-cho Tsuzuki-ku",
        "address_2": "Yokohama City  Kanagawa  224-8539",
        "country": "JP"
    },
    "B019C6": {
        "oui_hex": "B0-19-C6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3866F0": {
        "oui_hex": "38-66-F0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "008009": {
        "oui_hex": "00-80-09",
        "organization": "JUPITER SYSTEMS, INC.",
        "address_1": "3073 TEAGARDEN STREET",
        "address_2": "SAN LEANDRO  CA  94577-5720",
        "country": "US"
    },
    "00C064": {
        "oui_hex": "00-C0-64",
        "organization": "General Datacomm LLC",
        "address_1": "353 Christian Street, Suite 4",
        "address_2": "Oxford  CT  06478",
        "country": "US"
    },
    "E86819": {
        "oui_hex": "E8-68-19",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1CAB34": {
        "oui_hex": "1C-AB-34",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "3C7843": {
        "oui_hex": "3C-78-43",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5C0979": {
        "oui_hex": "5C-09-79",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E4FB5D": {
        "oui_hex": "E4-FB-5D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0001CC": {
        "oui_hex": "00-01-CC",
        "organization": "Japan Total Design Communication Co., Ltd.",
        "address_1": "Enesta Suginamihigashi Build., 3F,",
        "address_2": "",
        "country": "JP"
    },
    "0030C8": {
        "oui_hex": "00-30-C8",
        "organization": "GAD LINE, LTD.",
        "address_1": "BEIT ROKAR HAR HOTZVIM",
        "address_2": "",
        "country": "IL"
    },
    "0016E0": {
        "oui_hex": "00-16-E0",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "D8DECE": {
        "oui_hex": "D8-DE-CE",
        "organization": "ISUNG CO.,LTD",
        "address_1": "92, Huimanggongwon-ro",
        "address_2": "Siheung-si  Kyunggido  429-859",
        "country": "KR"
    },
    "703EAC": {
        "oui_hex": "70-3E-AC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0011C0": {
        "oui_hex": "00-11-C0",
        "organization": "Aday Technology Inc",
        "address_1": "9F.-3, No. 247, Sec. 1, Taichung Port Rd.,",
        "address_2": "Taichung City    403",
        "country": "TW"
    },
    "0005F1": {
        "oui_hex": "00-05-F1",
        "organization": "Vrcom, Inc.",
        "address_1": "401, Songam Bldg, 479-1,",
        "address_2": "Seoul",
        "country": "KR"
    },
    "AC512C": {
        "oui_hex": "AC-51-2C",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "309935": {
        "oui_hex": "30-99-35",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0C72D9": {
        "oui_hex": "0C-72-D9",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1062D0": {
        "oui_hex": "10-62-D0",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "50642B": {
        "oui_hex": "50-64-2B",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "28401A": {
        "oui_hex": "28-40-1A",
        "organization": "C8 MediSensors, Inc.",
        "address_1": "727 University Ave",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "30C01B": {
        "oui_hex": "30-C0-1B",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "8886C2": {
        "oui_hex": "88-86-C2",
        "organization": "STABILO International GmbH",
        "address_1": "Schwanweg 1",
        "address_2": "Heroldsberg    90562",
        "country": "DE"
    },
    "08A8A1": {
        "oui_hex": "08-A8-A1",
        "organization": "Cyclotronics Power Concepts, Inc",
        "address_1": "PO Box 37449",
        "address_2": "Houston  TX  77237-7449",
        "country": "US"
    },
    "F4B520": {
        "oui_hex": "F4-B5-20",
        "organization": "Biostar Microtech international corp.",
        "address_1": "3F. No. 108-2 Min Chuan Road, Hsin Tien District",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "CC2F71": {
        "oui_hex": "CC-2F-71",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001CC5": {
        "oui_hex": "00-1C-C5",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "887A31": {
        "oui_hex": "88-7A-31",
        "organization": "Velankani Electronics Pvt. Ltd.",
        "address_1": "43, Electronics City, Phase 1, Hosur road",
        "address_2": "Bangalore  Karnataka  560100",
        "country": "IN"
    },
    "8C0F6F": {
        "oui_hex": "8C-0F-6F",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "8C2505": {
        "oui_hex": "8C-25-05",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8C3BAD": {
        "oui_hex": "8C-3B-AD",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "64CFD9": {
        "oui_hex": "64-CF-D9",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "747D24": {
        "oui_hex": "74-7D-24",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "D09466": {
        "oui_hex": "D0-94-66",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "38E595": {
        "oui_hex": "38-E5-95",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "B116,B118,A211-A213,B201-B213,A311-A313,B411-413,BF08-09 Nanshan Medical Instrument Industry Park,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "BC9680": {
        "oui_hex": "BC-96-80",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "B116,B118,A211-A213,B201-B213,A311-A313,B411-413,BF08-09 Nanshan Medical Instrument Industry Park,",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "A47B9D": {
        "oui_hex": "A4-7B-9D",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "B8F8BE": {
        "oui_hex": "B8-F8-BE",
        "organization": "BLUECOM",
        "address_1": "116, Venture-ro, Yeonsu-gu,",
        "address_2": "Incheon    406-840",
        "country": "KR"
    },
    "002482": {
        "oui_hex": "00-24-82",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "689234": {
        "oui_hex": "68-92-34",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "50A733": {
        "oui_hex": "50-A7-33",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2C5D93": {
        "oui_hex": "2C-5D-93",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "38FF36": {
        "oui_hex": "38-FF-36",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "84183A": {
        "oui_hex": "84-18-3A",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "24C9A1": {
        "oui_hex": "24-C9-A1",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "7C2EDD": {
        "oui_hex": "7C-2E-DD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3CF7A4": {
        "oui_hex": "3C-F7-A4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "103034": {
        "oui_hex": "10-30-34",
        "organization": "Cara Systems",
        "address_1": "Ruzgarlibahce Mah. Kavak Sok. No: 31/1 Smart Plaza B Blok Kat: 4",
        "address_2": "Istanbul  Kavacik Beykoz  23805",
        "country": "TR"
    },
    "0000FE": {
        "oui_hex": "00-00-FE",
        "organization": "Annapolis Micro Systems, Inc.",
        "address_1": "190 ADMIRAL COCHRANE DRIVE",
        "address_2": "ANNAPOLIS  MD  21401",
        "country": "US"
    },
    "00D01F": {
        "oui_hex": "00-D0-1F",
        "organization": "Senetas Corporation Ltd",
        "address_1": "1/11 Queens Road",
        "address_2": "consolidation    consolidation",
        "country": "AU"
    },
    "E0CBBC": {
        "oui_hex": "E0-CB-BC",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "6447E0": {
        "oui_hex": "64-47-E0",
        "organization": "Feitian Technologies Co., Ltd",
        "address_1": "Floor 17, Tower B, Huizhi Mansion, No.9 Xueqing Rd, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "B44F96": {
        "oui_hex": "B4-4F-96",
        "organization": "Zhejiang Xinzailing Technology co., ltd",
        "address_1": "No.1805, Dongliu Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "4C65A8": {
        "oui_hex": "4C-65-A8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B0DFC1": {
        "oui_hex": "B0-DF-C1",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "9C6F52": {
        "oui_hex": "9C-6F-52",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E86D65": {
        "oui_hex": "E8-6D-65",
        "organization": "AUDIO MOBIL Elektronik GmbH",
        "address_1": "Audio-Mobil-Straße 5 - 7",
        "address_2": "Braunau am Inn - Ranshofen    5282",
        "country": "AT"
    },
    "706E6D": {
        "oui_hex": "70-6E-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "604762": {
        "oui_hex": "60-47-62",
        "organization": "Beijing Sensoro Technology Co.,Ltd.",
        "address_1": "Room 2807, Building 1B, Wangjing SOHO, No10 Wangjing Street, Chaoyang District, Beijing, China",
        "address_2": "Beijing  Beijing  100102 PRC",
        "country": "CN"
    },
    "BC1C81": {
        "oui_hex": "BC-1C-81",
        "organization": "Sichuan iLink Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial park,Mianyang,Sichuan",
        "address_2": "Mianyang    622651",
        "country": "CN"
    },
    "900A1A": {
        "oui_hex": "90-0A-1A",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "506E92": {
        "oui_hex": "50-6E-92",
        "organization": "Innocent Technology Co., Ltd.",
        "address_1": "PROSIT AZUMA 3 #201, 1973, NIPPA-CHO, KOHOKU-KU,",
        "address_2": "YOKOHAMA-SHI  KANAGAWA  2230057",
        "country": "JP"
    },
    "30FE31": {
        "oui_hex": "30-FE-31",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "98F2B3": {
        "oui_hex": "98-F2-B3",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "C4571F": {
        "oui_hex": "C4-57-1F",
        "organization": "June Life Inc",
        "address_1": "649 Front Street",
        "address_2": "San Francisco  CA  94111",
        "country": "US"
    },
    "886AE3": {
        "oui_hex": "88-6A-E3",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing 7th Rd., Science-based Industrial Park, Hsinchu, Taiwan, R.O.C",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "1C4D70": {
        "oui_hex": "1C-4D-70",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D822F4": {
        "oui_hex": "D8-22-F4",
        "organization": "Avnet Silica",
        "address_1": "16 av carnot",
        "address_2": "Massy    91349",
        "country": "FR"
    },
    "348F27": {
        "oui_hex": "34-8F-27",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2C9EEC": {
        "oui_hex": "2C-9E-EC",
        "organization": "Jabil Circuit Penang",
        "address_1": "Plot 56 , Hilir Sungai Keluang 1, Bayan Lepas Industrial Park, Phase 4",
        "address_2": "George Town  Penang  11900",
        "country": "MY"
    },
    "001CFA": {
        "oui_hex": "00-1C-FA",
        "organization": "Alarm.com",
        "address_1": "8150 Leesburg Pike",
        "address_2": "Vienna  VA  22182",
        "country": "US"
    },
    "60313B": {
        "oui_hex": "60-31-3B",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "6CB227": {
        "oui_hex": "6C-B2-27",
        "organization": "Sony Video & Sound Products Inc.",
        "address_1": "Sony City Osaki, 2-10-1 Osaki",
        "address_2": "Shinagawa-ku  Tokyo  141-8610",
        "country": "JP"
    },
    "986F60": {
        "oui_hex": "98-6F-60",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "000CAB": {
        "oui_hex": "00-0C-AB",
        "organization": "Commend International GmbH",
        "address_1": "Hoelzlstrasse 561",
        "address_2": "Wals  Salzburg  A-5071",
        "country": "AT"
    },
    "745427": {
        "oui_hex": "74-54-27",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "60720B": {
        "oui_hex": "60-72-0B",
        "organization": "BLU Products Inc",
        "address_1": "10814 NW 33rd Street",
        "address_2": "Miami  FL  33172",
        "country": "US"
    },
    "308976": {
        "oui_hex": "30-89-76",
        "organization": "DALIAN LAMBA TECHNOLOGY CO.,LTD",
        "address_1": "Dalian Hi-tech Zone Keypark Room 1201",
        "address_2": "Dalian  Liaoning  116000",
        "country": "CN"
    },
    "2C2617": {
        "oui_hex": "2C-26-17",
        "organization": "Oculus VR, LLC",
        "address_1": "1 Hacker Way",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "34D954": {
        "oui_hex": "34-D9-54",
        "organization": "WiBotic Inc.",
        "address_1": "4000 15th Ave NE Lab 225, Fluke Hall, Box 352141",
        "address_2": "Seattle  WA  98195",
        "country": "US"
    },
    "4857DD": {
        "oui_hex": "48-57-DD",
        "organization": "Facebook Inc",
        "address_1": "1 Hacker Way",
        "address_2": "Menlo Park    94025",
        "country": "US"
    },
    "487D2E": {
        "oui_hex": "48-7D-2E",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B0DAF9": {
        "oui_hex": "B0-DA-F9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1835D1": {
        "oui_hex": "18-35-D1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C0A5DD": {
        "oui_hex": "C0-A5-DD",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "488D36": {
        "oui_hex": "48-8D-36",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "BCD713": {
        "oui_hex": "BC-D7-13",
        "organization": "Owl Labs",
        "address_1": "33-1/2 Union Square",
        "address_2": "Somerville  MA  02143",
        "country": "US"
    },
    "E8E1E1": {
        "oui_hex": "E8-E1-E1",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No.15-1 Zhonghua Road",
        "address_2": "Hukou  Hsinchu  30352",
        "country": "TW"
    },
    "28070D": {
        "oui_hex": "28-07-0D",
        "organization": "GUANGZHOU WINSOUND INFORMATION TECHNOLOGY CO.,LTD.",
        "address_1": "Building1 NO.13 DABU ROAD HUADU DISTRICT",
        "address_2": "GUANGZHOU  GUANGDONG  510800",
        "country": "CN"
    },
    "00A3D1": {
        "oui_hex": "00-A3-D1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "FC4D8C": {
        "oui_hex": "FC-4D-8C",
        "organization": "SHENZHEN PANTE ELECTRONICS TECHNOLOGY CO., LTD",
        "address_1": "Building 5,Hui Mingsheng industrial park,Tongfu Rd,Fu Yong street",
        "address_2": "Shenzhen  Guangdong  518042",
        "country": "CN"
    },
    "FC06ED": {
        "oui_hex": "FC-06-ED",
        "organization": "M2Motive Technology Inc.",
        "address_1": "Room 148, Lane 999, new two road, Baoshan District",
        "address_2": "Shanghai  Shanghai  200439",
        "country": "CN"
    },
    "F0D4F6": {
        "oui_hex": "F0-D4-F6",
        "organization": "Lars Thrane A/S",
        "address_1": "Stubbeled 2",
        "address_2": "Vedbæk    2950",
        "country": "DK"
    },
    "F4A997": {
        "oui_hex": "F4-A9-97",
        "organization": "CANON INC.",
        "address_1": "30-2 Shimomaruko 3-chome,",
        "address_2": "Ohta-ku  Tokyo  146-8501",
        "country": "JP"
    },
    "64DFE9": {
        "oui_hex": "64-DF-E9",
        "organization": "ATEME",
        "address_1": "6 rue Dewoitine",
        "address_2": "Vélizy-Villacoublay    78140",
        "country": "FR"
    },
    "10C6FC": {
        "oui_hex": "10-C6-FC",
        "organization": "Garmin International",
        "address_1": "1200 East 151st Street",
        "address_2": "Olathe   KS  66062",
        "country": "US"
    },
    "AC2205": {
        "oui_hex": "AC-22-05",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "80A036": {
        "oui_hex": "80-A0-36",
        "organization": "Shanghai MXCHIP Information Technology Co., Ltd.",
        "address_1": "9th Floor, No. 5 Building, 2145 Jinshajiang Rd., Putuo District",
        "address_2": "Shanghai    200333",
        "country": "CN"
    },
    "F07485": {
        "oui_hex": "F0-74-85",
        "organization": "NGD Systems, Inc.",
        "address_1": "355 Goddard, Suite 200",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "405CFD": {
        "oui_hex": "40-5C-FD",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "20F452": {
        "oui_hex": "20-F4-52",
        "organization": "Shanghai IUV Software Development Co. Ltd",
        "address_1": "No.18, Lane 1387 Zhangdong Rd, Pudong, Shanghai, P.R.C",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "509A4C": {
        "oui_hex": "50-9A-4C",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "A0094C": {
        "oui_hex": "A0-09-4C",
        "organization": "CenturyLink",
        "address_1": "100 CenturyLink Drive",
        "address_2": "Monroe    71203",
        "country": "US"
    },
    "B43934": {
        "oui_hex": "B4-39-34",
        "organization": "Pen Generations, Inc.",
        "address_1": "8th FL., SOLiD Space,",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "7426AC": {
        "oui_hex": "74-26-AC",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B02628": {
        "oui_hex": "B0-26-28",
        "organization": "Broadcom Limited",
        "address_1": "5300 California Ave.",
        "address_2": "irvine  CA  92617",
        "country": "US"
    },
    "9874DA": {
        "oui_hex": "98-74-DA",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "40B4F0": {
        "oui_hex": "40-B4-F0",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "143F27": {
        "oui_hex": "14-3F-27",
        "organization": "Noccela Oy",
        "address_1": "Kaarinantie 700",
        "address_2": "Turku    20540",
        "country": "FI"
    },
    "105887": {
        "oui_hex": "10-58-87",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "704CA5": {
        "oui_hex": "70-4C-A5",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  null  94086",
        "country": "US"
    },
    "9C061B": {
        "oui_hex": "9C-06-1B",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "50338B": {
        "oui_hex": "50-33-8B",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "68262A": {
        "oui_hex": "68-26-2A",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "E8DE8E": {
        "oui_hex": "E8-DE-8E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "D8D866": {
        "oui_hex": "D8-D8-66",
        "organization": "SHENZHEN TOZED TECHNOLOGIES CO.,LTD.",
        "address_1": " 4F/A1,A2,TIANJI BUILDING,TIAN’AN CYBER PARK,FUTIAN",
        "address_2": "SHENZHEN  GUANGDONG  518040",
        "country": "CN"
    },
    "D8C06A": {
        "oui_hex": "D8-C0-6A",
        "organization": "Hunantv.com Interactive Entertainment Media Co.,Ltd.",
        "address_1": "Floor 2U, Hunan International Exhibition Center, Kaifu District, Changsha City, Hunan Province, P.R.C.",
        "address_2": "Changsha  Hunan  410000",
        "country": "CN"
    },
    "AC202E": {
        "oui_hex": "AC-20-2E",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "9C32A9": {
        "oui_hex": "9C-32-A9",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "1C5A0B": {
        "oui_hex": "1C-5A-0B",
        "organization": "Tegile Systems",
        "address_1": "7999 Gateway Blvd Suite 120",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "046E02": {
        "oui_hex": "04-6E-02",
        "organization": "OpenRTLS Group",
        "address_1": "De Nieuwe Ploeg 5",
        "address_2": "Berlicum    5258 EX",
        "country": "NL"
    },
    "900E83": {
        "oui_hex": "90-0E-83",
        "organization": "Monico Monitoring, Inc.",
        "address_1": "18530 Klein Church Rd",
        "address_2": "Spring  TX  77379",
        "country": "US"
    },
    "601466": {
        "oui_hex": "60-14-66",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "6854ED": {
        "oui_hex": "68-54-ED",
        "organization": "Alcatel-Lucent",
        "address_1": "777 E. Middlefield Rd",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "680235": {
        "oui_hex": "68-02-35",
        "organization": "Konten Networks Inc.",
        "address_1": "7F-1, No.108, Minquan Rd., Xindian Dist.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "38AC3D": {
        "oui_hex": "38-AC-3D",
        "organization": "Nephos Inc",
        "address_1": "2840 Junction Ave.  ,",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E037BF": {
        "oui_hex": "E0-37-BF",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20,Park Avenue II,Hsinchu Science Park",
        "address_2": "Hsin-Chu  R.O.C.  308",
        "country": "TW"
    },
    "E81367": {
        "oui_hex": "E8-13-67",
        "organization": "AIRSOUND Inc.",
        "address_1": "515-ho,75,Techno-1ro,Yuseoung-gu",
        "address_2": "Daejeon    34014",
        "country": "KR"
    },
    "001192": {
        "oui_hex": "00-11-92",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "38F135": {
        "oui_hex": "38-F1-35",
        "organization": "SensorTec-Canada",
        "address_1": "1Yonge Street, Suite 1801",
        "address_2": "Toronto  ON  M5E 1W7",
        "country": "CA"
    },
    "AC7409": {
        "oui_hex": "AC-74-09",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "C49DED": {
        "oui_hex": "C4-9D-ED",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "98A40E": {
        "oui_hex": "98-A4-0E",
        "organization": "Snap, Inc.",
        "address_1": "64 Market Street",
        "address_2": "Venice  CA  90291",
        "country": "US"
    },
    "F40343": {
        "oui_hex": "F4-03-43",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F093C5": {
        "oui_hex": "F0-93-C5",
        "organization": "Garland Technology",
        "address_1": "2130 Oak Bend Lane",
        "address_2": "Garland  TX  75040",
        "country": "US"
    },
    "9810E8": {
        "oui_hex": "98-10-E8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0D012": {
        "oui_hex": "C0-D0-12",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BCA920": {
        "oui_hex": "BC-A9-20",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48A195": {
        "oui_hex": "48-A1-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F80377": {
        "oui_hex": "F8-03-77",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F49634": {
        "oui_hex": "F4-96-34",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "107D1A": {
        "oui_hex": "10-7D-1A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "70AF24": {
        "oui_hex": "70-AF-24",
        "organization": "TP Vision Belgium NV",
        "address_1": "Technologiepark Zwijnaarde 19",
        "address_2": "Gent    9052",
        "country": "BE"
    },
    "A41163": {
        "oui_hex": "A4-11-63",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C4D197": {
        "oui_hex": "C4-D1-97",
        "organization": "Ventia Utility Services",
        "address_1": "Level 4, Tower 1, 495 Victoria Avenue",
        "address_2": "Chatswood  NSW  2067",
        "country": "AU"
    },
    "2C86D2": {
        "oui_hex": "2C-86-D2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7CE97C": {
        "oui_hex": "7C-E9-7C",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "8058F8": {
        "oui_hex": "80-58-F8",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "DCA4CA": {
        "oui_hex": "DC-A4-CA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C8FE9": {
        "oui_hex": "8C-8F-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70AF25": {
        "oui_hex": "70-AF-25",
        "organization": "Nishiyama Industry Co.,LTD.",
        "address_1": "177-2",
        "address_2": "Fuji  Shizuoka  419-0205",
        "country": "JP"
    },
    "E8D11B": {
        "oui_hex": "E8-D1-1B",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "B8224F": {
        "oui_hex": "B8-22-4F",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "9800C1": {
        "oui_hex": "98-00-C1",
        "organization": "GuangZhou CREATOR Technology Co.,Ltd.(CHINA)",
        "address_1": "Level 3,Blg 6,No 9 Keji Yuan,LanYusi St,",
        "address_2": "GuangZhou  GuangDong  510730",
        "country": "CN"
    },
    "54E1AD": {
        "oui_hex": "54-E1-AD",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "98D3D2": {
        "oui_hex": "98-D3-D2",
        "organization": "MEKRA Lang GmbH & Co. KG",
        "address_1": "Buchheimerstr. 4",
        "address_2": "Ergersheim    91465",
        "country": "DE"
    },
    "0C5F35": {
        "oui_hex": "0C-5F-35",
        "organization": "Niagara Video Corporation",
        "address_1": "5627 Stoneridge Drive, Suite 316",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "F8A34F": {
        "oui_hex": "F8-A3-4F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "001912": {
        "oui_hex": "00-19-12",
        "organization": "Welcat Inc",
        "address_1": "East Tower 6F, Shinagawa Seaside, 4-12-8, Higashi Shinagawa, Shinagawa Section",
        "address_2": "  Tokyo  140-0002",
        "country": "JP"
    },
    "8C78D7": {
        "oui_hex": "8C-78-D7",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B8EAAA": {
        "oui_hex": "B8-EA-AA",
        "organization": "ICG NETWORKS CO.,ltd",
        "address_1": "Room 2030，Block B，Yamei Park，Haidian District",
        "address_2": "BEIJING    100010",
        "country": "CN"
    },
    "B8F883": {
        "oui_hex": "B8-F8-83",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "DCFE18": {
        "oui_hex": "DC-FE-18",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "704F57": {
        "oui_hex": "70-4F-57",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B0C46C": {
        "oui_hex": "B0-C4-6C",
        "organization": "Senseit",
        "address_1": "Suschevsky val 16 str. 4",
        "address_2": "Moscow  Russian Federation  127018",
        "country": "RU"
    },
    "0002A1": {
        "oui_hex": "00-02-A1",
        "organization": "World Wide Packets",
        "address_1": "PO Box 14645",
        "address_2": "Spokane  WA  99214",
        "country": "US"
    },
    "00E022": {
        "oui_hex": "00-E0-22",
        "organization": "Analog Devices, Inc.",
        "address_1": "Three Technology Way",
        "address_2": "Norwood   MA  02062-2666",
        "country": "US"
    },
    "14B7F8": {
        "oui_hex": "14-B7-F8",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "903D6B": {
        "oui_hex": "90-3D-6B",
        "organization": "Zicon Technology Corp.",
        "address_1": "15F., No.688-2, Zhongzheng Rd., Zhonghe City, Taipei County 235",
        "address_2": "Taipei    23586",
        "country": "TW"
    },
    "B04089": {
        "oui_hex": "B0-40-89",
        "organization": "Senient Systems LTD",
        "address_1": "152 Morrison St",
        "address_2": "Edinburgh  Other (Non US)  EH3 8EB",
        "country": "GB"
    },
    "5425EA": {
        "oui_hex": "54-25-EA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3C7F6F": {
        "oui_hex": "3C-7F-6F",
        "organization": "Telechips, Inc.",
        "address_1": "19F~23F,Luther Bldg.42, Olympic-ro 35da-gil, Songpa-gu,",
        "address_2": "Seoul  Seoul  05510",
        "country": "KR"
    },
    "5CBA37": {
        "oui_hex": "5C-BA-37",
        "organization": "Microsoft Corporation",
        "address_1": "31807 - 25th Ave SW",
        "address_2": "Federal Way    98023",
        "country": "US"
    },
    "00C0C6": {
        "oui_hex": "00-C0-C6",
        "organization": "PERSONAL MEDIA CORP.",
        "address_1": "1-7-7 MY BLDG. HIRATSUKA",
        "address_2": "",
        "country": "JP"
    },
    "28FECD": {
        "oui_hex": "28-FE-CD",
        "organization": "Lemobile Information Technology (Beijing) Co., Ltd.",
        "address_1": "5/F LeEco Building, 105 Yaojiayuan Road, Chaoyang District",
        "address_2": "Beijing  Beijing  100025",
        "country": "CN"
    },
    "C894BB": {
        "oui_hex": "C8-94-BB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "10B1F8": {
        "oui_hex": "10-B1-F8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "089E08": {
        "oui_hex": "08-9E-08",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "00210D": {
        "oui_hex": "00-21-0D",
        "organization": "SAMSIN INNOTEC",
        "address_1": "SARIYUNDONG ILSANDONG-GU",
        "address_2": "GOYANG  KYUNGGI  411530",
        "country": "KR"
    },
    "C87324": {
        "oui_hex": "C8-73-24",
        "organization": " Sow Cheng Technology Co. Ltd.",
        "address_1": "No.26, Ln. 181, Xinsheng W. Rd., Dali Dist",
        "address_2": "Taichung    412",
        "country": "TW"
    },
    "001F16": {
        "oui_hex": "00-1F-16",
        "organization": "Wistron Corporation",
        "address_1": "21F, 88, Sec.1, Hsin Tai Wu Rd., Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "00262D": {
        "oui_hex": "00-26-2D",
        "organization": "Wistron Corporation",
        "address_1": "21F, 88, Sec.1, Hsin Tai Wu Rd., Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "0495E6": {
        "oui_hex": "04-95-E6",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "50E666": {
        "oui_hex": "50-E6-66",
        "organization": "Shenzhen Techtion Electronics Co., Ltd.",
        "address_1": "Floor 2, C2 Building, Huafeng Industrial Park, Hangcheng Avenue, Gushu, Xixiang, Baoan",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "0016D3": {
        "oui_hex": "00-16-D3",
        "organization": "Wistron Corporation",
        "address_1": "21F, 88, Sec.1, Hsin Tai Wu Rd., Hsichih,",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "4C4E03": {
        "oui_hex": "4C-4E-03",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "908674": {
        "oui_hex": "90-86-74",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "901711": {
        "oui_hex": "90-17-11",
        "organization": "Hagenuk Marinekommunikation GmbH",
        "address_1": "Hamburger Chaussee 25",
        "address_2": "Flintbek    24220",
        "country": "DE"
    },
    "0010DE": {
        "oui_hex": "00-10-DE",
        "organization": "INTERNATIONAL DATACASTING CORPORATION",
        "address_1": "2680 QUEENSVIEW DRIVE",
        "address_2": "OTTAWA,  ONTARIO  K2B 8H6",
        "country": "CA"
    },
    "C0D9F7": {
        "oui_hex": "C0-D9-F7",
        "organization": "ShanDong Domor Intelligent S&T CO.,Ltd",
        "address_1": "Jining high-tech zone base of production,education & research",
        "address_2": "Jining  Shandong  272000",
        "country": "CN"
    },
    "00608B": {
        "oui_hex": "00-60-8B",
        "organization": "ConferTech International",
        "address_1": "12110 N. PECOS STREET",
        "address_2": "WESTMINSTER  CO  80234-2074",
        "country": "US"
    },
    "702D84": {
        "oui_hex": "70-2D-84",
        "organization": "i4C Innovations",
        "address_1": "3800 Concorde Parkway, Suite 400",
        "address_2": "Chantilly  VA  20151",
        "country": "US"
    },
    "2C200B": {
        "oui_hex": "2C-20-0B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8866A5": {
        "oui_hex": "88-66-A5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000277": {
        "oui_hex": "00-02-77",
        "organization": "Cash Systemes Industrie",
        "address_1": "Technoparc Epsilon",
        "address_2": "",
        "country": "FR"
    },
    "CCA219": {
        "oui_hex": "CC-A2-19",
        "organization": "SHENZHEN ALONG INVESTMENT CO.,LTD",
        "address_1": "Room 1301,13F,Zhenye international Business Center,No.3101-90,Qianhai Road,Nanshan District",
        "address_2": "Shenzhen  Guangdong Province  518052",
        "country": "CN"
    },
    "4C1A3A": {
        "oui_hex": "4C-1A-3A",
        "organization": "PRIMA Research And Production Enterprise Ltd.",
        "address_1": "63, Svobody st.",
        "address_2": "  Nizhny Novgorod   603003",
        "country": "RU"
    },
    "14B31F": {
        "oui_hex": "14-B3-1F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "ACC1EE": {
        "oui_hex": "AC-C1-EE",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "5419C8": {
        "oui_hex": "54-19-C8",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "B0B98A": {
        "oui_hex": "B0-B9-8A",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "805A04": {
        "oui_hex": "80-5A-04",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "8CA5A1": {
        "oui_hex": "8C-A5-A1",
        "organization": "Oregano Systems - Design & Consulting GmbH",
        "address_1": "Franzosengraben 8",
        "address_2": "Vienna    1030",
        "country": "AT"
    },
    "B8ECA3": {
        "oui_hex": "B8-EC-A3",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "BC8385": {
        "oui_hex": "BC-83-85",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "001438": {
        "oui_hex": "00-14-38",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "E4B005": {
        "oui_hex": "E4-B0-05",
        "organization": "Beijing IQIYI Science & Technology Co., Ltd.",
        "address_1": "Room 1101, Floor 11, Capital Development Tower, No.2 Haidian North 1st Street,Haidian District,",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "000048": {
        "oui_hex": "00-00-48",
        "organization": "Seiko Epson Corporation",
        "address_1": "80 HIROOKA SHIOJIRI-CITY",
        "address_2": "japan  JAPAN  399-07",
        "country": "JP"
    },
    "B0E892": {
        "oui_hex": "B0-E8-92",
        "organization": "Seiko Epson Corporation",
        "address_1": "3-3-5 OWA",
        "address_2": "SUWA-SHI  NAGANO-KEN  392-8502",
        "country": "JP"
    },
    "AC1826": {
        "oui_hex": "AC-18-26",
        "organization": "Seiko Epson Corporation",
        "address_1": "3-3-5 OWA",
        "address_2": "SUWA-SHI  NAGANO-KEN  392-8502",
        "country": "JP"
    },
    "A4EE57": {
        "oui_hex": "A4-EE-57",
        "organization": "Seiko Epson Corporation",
        "address_1": "3-3-5 OWA",
        "address_2": "SUWA-SHI  NAGANO-KEN  392-8502",
        "country": "JP"
    },
    "9CAED3": {
        "oui_hex": "9C-AE-D3",
        "organization": "Seiko Epson Corporation",
        "address_1": "80 Harashinden",
        "address_2": "Shiojiri-shi  Nagano-ken  399-0785",
        "country": "JP"
    },
    "707C69": {
        "oui_hex": "70-7C-69",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "500B91": {
        "oui_hex": "50-0B-91",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F8461C": {
        "oui_hex": "F8-46-1C",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "704D7B": {
        "oui_hex": "70-4D-7B",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "64A68F": {
        "oui_hex": "64-A6-8F",
        "organization": "Zhongshan Readboy Electronics Co.,Ltd",
        "address_1": "Changmingshui Industrial Park Wuguishan Zhongshan City,Guangdong Province",
        "address_2": "Zhongshan  Guangdong  528400",
        "country": "CN"
    },
    "38BC01": {
        "oui_hex": "38-BC-01",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "341E6B": {
        "oui_hex": "34-1E-6B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "886639": {
        "oui_hex": "88-66-39",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00425A": {
        "oui_hex": "00-42-5A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18DBF2": {
        "oui_hex": "18-DB-F2",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "18F87A": {
        "oui_hex": "18-F8-7A",
        "organization": "i3 International Inc.",
        "address_1": "780 Birchmount Road",
        "address_2": "Scarborough  Ontario  M1K5H4",
        "country": "CA"
    },
    "4C26E7": {
        "oui_hex": "4C-26-E7",
        "organization": "Welgate Co., Ltd.",
        "address_1": "19F, Geopyeong Bldg. 129",
        "address_2": "Seoul  Seoul  135726",
        "country": "KR"
    },
    "006041": {
        "oui_hex": "00-60-41",
        "organization": "Yokogawa Digital Computer Corporation",
        "address_1": "Shinjuku MIDWEST Bldg.4-30-3",
        "address_2": "Yoyogi  Shibuya-ku, Tokyo  151-0053",
        "country": "JP"
    },
    "C816A5": {
        "oui_hex": "C8-16-A5",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "0C0227": {
        "oui_hex": "0C-02-27",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "4C11BF": {
        "oui_hex": "4C-11-BF",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "NO.1199 Bin An Road,Binjiang District,HangZhou,P.R.China",
        "address_2": "HangZhou  ZheJiang  310053",
        "country": "CN"
    },
    "2C598A": {
        "oui_hex": "2C-59-8A",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "B05216": {
        "oui_hex": "B0-52-16",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A0E4CB": {
        "oui_hex": "A0-E4-CB",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "284ED7": {
        "oui_hex": "28-4E-D7",
        "organization": "OutSmart Power Systems, Inc.",
        "address_1": "11 Mercer Rd",
        "address_2": "Natick  23  01760",
        "country": ""
    },
    "14A78B": {
        "oui_hex": "14-A7-8B",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199, Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "A0B8F8": {
        "oui_hex": "A0-B8-F8",
        "organization": "Amgen U.S.A. Inc.",
        "address_1": "1 Amgen Center Drive",
        "address_2": "Thousand Oaks  CA  91320",
        "country": "US"
    },
    "884477": {
        "oui_hex": "88-44-77",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "149D09": {
        "oui_hex": "14-9D-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "686975": {
        "oui_hex": "68-69-75",
        "organization": "Angler Labs Inc",
        "address_1": "940 Pearce Mill Rd.",
        "address_2": "Wexford  PA  15090",
        "country": "US"
    },
    "20D25F": {
        "oui_hex": "20-D2-5F",
        "organization": "SmartCap Technologies",
        "address_1": "L1 18 Finchley Street",
        "address_2": "Milton  Queensland  4064",
        "country": "AU"
    },
    "E47DBD": {
        "oui_hex": "E4-7D-BD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "9CFBD5": {
        "oui_hex": "9C-FB-D5",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "18F76B": {
        "oui_hex": "18-F7-6B",
        "organization": "Zhejiang Winsight Technology CO.,LTD",
        "address_1": "No.3339 Linggongtang Road，NanHu District",
        "address_2": "Jiaxing  Zhejiang   314000",
        "country": "CN"
    },
    "583112": {
        "oui_hex": "58-31-12",
        "organization": "DRUST",
        "address_1": "8 rue fabre d'églantine",
        "address_2": "Paris    75012",
        "country": "FR"
    },
    "9C83BF": {
        "oui_hex": "9C-83-BF",
        "organization": "PRO-VISION, Inc.",
        "address_1": "8625-B Byron Commerce Dr. SW",
        "address_2": "Byron Center  MI  49315",
        "country": "US"
    },
    "78EF4C": {
        "oui_hex": "78-EF-4C",
        "organization": "Unetconvergence Co., Ltd.",
        "address_1": "101-511, Digital Empire2, 486, Shin-dong, Youngtong-gu",
        "address_2": "Suwon  Kyonggi-do  443-390",
        "country": "KR"
    },
    "58696C": {
        "oui_hex": "58-69-6C",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "19# Building,Star-net Science Plaza,Juyuanzhou, 618 Jinshan Road",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "48D343": {
        "oui_hex": "48-D3-43",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00C05A": {
        "oui_hex": "00-C0-5A",
        "organization": "SEMAPHORE COMMUNICATIONS CORP.",
        "address_1": "217 HUMBOLDT COURT",
        "address_2": "SUNNYVALE  CA  94089-1300",
        "country": "US"
    },
    "0007F9": {
        "oui_hex": "00-07-F9",
        "organization": "Sensaphone",
        "address_1": "901 Tryens Road",
        "address_2": "Aston  PA  19014",
        "country": "US"
    },
    "001CB3": {
        "oui_hex": "00-1C-B3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "407183": {
        "oui_hex": "40-71-83",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C81B5C": {
        "oui_hex": "C8-1B-5C",
        "organization": "BCTech",
        "address_1": "14 Building, Tiandeng road 259#",
        "address_2": "shanghai  xuhui district, shanghai   200237",
        "country": "CN"
    },
    "5CE30E": {
        "oui_hex": "5C-E3-0E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1CC0E1": {
        "oui_hex": "1C-C0-E1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "001A39": {
        "oui_hex": "00-1A-39",
        "organization": "Merten GmbH&CoKG",
        "address_1": "Fritz-Kotz-Str. 8",
        "address_2": "Wiehl  NRW  51674",
        "country": "DE"
    },
    "FCECDA": {
        "oui_hex": "FC-EC-DA",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00B0E1": {
        "oui_hex": "00-B0-E1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "005093": {
        "oui_hex": "00-50-93",
        "organization": "BOEING",
        "address_1": "3370 Miraloma Avenue",
        "address_2": "Anaheim  CA  92803-3105",
        "country": "US"
    },
    "905C44": {
        "oui_hex": "90-5C-44",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "44BA46": {
        "oui_hex": "44-BA-46",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "E07C13": {
        "oui_hex": "E0-7C-13",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F41F88": {
        "oui_hex": "F4-1F-88",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "14EDBB": {
        "oui_hex": "14-ED-BB",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "18E29F": {
        "oui_hex": "18-E2-9F",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "28EE52": {
        "oui_hex": "28-EE-52",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "687251": {
        "oui_hex": "68-72-51",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "91 E. Tasman Dr.",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "B4FBE4": {
        "oui_hex": "B4-FB-E4",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "707990": {
        "oui_hex": "70-79-90",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A04E01": {
        "oui_hex": "A0-4E-01",
        "organization": "CENTRAL ENGINEERING co.,ltd.",
        "address_1": "2-3-19 shinyokohama kouhoku-ku",
        "address_2": "yokohama-shi  kanagawa  222-0033",
        "country": "JP"
    },
    "28CA09": {
        "oui_hex": "28-CA-09",
        "organization": "ThyssenKrupp Elevators (Shanghai) Co.,Ltd",
        "address_1": "No. 2, Xunye Rd, Sheshan Subarea Songjiang Industrial Area",
        "address_2": "Shanghai  Shanghai  201602",
        "country": "CN"
    },
    "842519": {
        "oui_hex": "84-25-19",
        "organization": "Samsung Electronics",
        "address_1": "129, Samsung-rom Yeongtong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  16677",
        "country": "KR"
    },
    "5C2443": {
        "oui_hex": "5C-24-43",
        "organization": "O-Sung Telecom Co., Ltd.",
        "address_1": "43-9 Pyeongdongro 803-gil , Gwangsan-Gu",
        "address_2": "Gwangju    54611",
        "country": "KR"
    },
    "24920E": {
        "oui_hex": "24-92-0E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FC4203": {
        "oui_hex": "FC-42-03",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A01081": {
        "oui_hex": "A0-10-81",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3C8BCD": {
        "oui_hex": "3C-8B-CD",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "4CF95D": {
        "oui_hex": "4C-F9-5D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8421F1": {
        "oui_hex": "84-21-F1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00F22C": {
        "oui_hex": "00-F2-2C",
        "organization": "Shanghai B-star Technology Co.,Ltd.",
        "address_1": "4Floor NO.1158 Xiehe Road,Changning District ,shanghai ,China 200335",
        "address_2": "Shanghai     200335",
        "country": "CN"
    },
    "0005EE": {
        "oui_hex": "00-05-EE",
        "organization": "Vanderbilt International (SWE) AB",
        "address_1": "Englundavaegen 7",
        "address_2": "Solna    SE-171 41",
        "country": "SE"
    },
    "F07960": {
        "oui_hex": "F0-79-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A0D795": {
        "oui_hex": "A0-D7-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0090E7": {
        "oui_hex": "00-90-E7",
        "organization": "HORSCH ELEKTRONIK AG",
        "address_1": "HAAGERSTRASSE",
        "address_2": "CH-9473 GAMS",
        "country": "CH"
    },
    "E43ED7": {
        "oui_hex": "E4-3E-D7",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "5454CF": {
        "oui_hex": "54-54-CF",
        "organization": "PROBEDIGITAL CO.,LTD",
        "address_1": "#107 Hyundai I-Valley, 31, Galmachi-ro 244beon-gil, Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13212",
        "country": "KR"
    },
    "F8633F": {
        "oui_hex": "F8-63-3F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "088620": {
        "oui_hex": "08-86-20",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "F0D5BF": {
        "oui_hex": "F0-D5-BF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6474F6": {
        "oui_hex": "64-74-F6",
        "organization": "Shooter Detection Systems",
        "address_1": "300 Newburyport Turnpike",
        "address_2": "Rowley  MA  01969",
        "country": "US"
    },
    "981333": {
        "oui_hex": "98-13-33",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "2047ED": {
        "oui_hex": "20-47-ED",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "748A69": {
        "oui_hex": "74-8A-69",
        "organization": "Korea Image Technology Co., Ltd",
        "address_1": "125, beolmal road, dongan gu,",
        "address_2": "anyang  gyeonggi  14056",
        "country": "KR"
    },
    "BC4760": {
        "oui_hex": "BC-47-60",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "04180F": {
        "oui_hex": "04-18-0F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2013E0": {
        "oui_hex": "20-13-E0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002566": {
        "oui_hex": "00-25-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0DB32": {
        "oui_hex": "D0-DB-32",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "E80036": {
        "oui_hex": "E8-00-36",
        "organization": "Befs co,. ltd",
        "address_1": "C-#403, 242 Pangyo-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13487",
        "country": "KR"
    },
    "C09F05": {
        "oui_hex": "C0-9F-05",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "5C4979": {
        "oui_hex": "5C-49-79",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "C0F945": {
        "oui_hex": "C0-F9-45",
        "organization": "Toshiba Toko Meter Systems Co., LTD.",
        "address_1": "3484, Sakuragaoka, Kurohama",
        "address_2": "Hasuda-shi  Saitama  349-0192",
        "country": "JP"
    },
    "70F8E7": {
        "oui_hex": "70-F8-E7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D42C44": {
        "oui_hex": "D4-2C-44",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "843DC6": {
        "oui_hex": "84-3D-C6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002485": {
        "oui_hex": "00-24-85",
        "organization": "ConteXtream Ltd",
        "address_1": "94 Em-HaMoshavot",
        "address_2": "Petach-Tikva    49527",
        "country": "IL"
    },
    "28FCF6": {
        "oui_hex": "28-FC-F6",
        "organization": "Shenzhen Xin KingBrand enterprises Co.,Ltd",
        "address_1": "Kingbrand Industrial Zone,Nanpu Road,Shang liao ling pi keng,Shajing Town",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "001F58": {
        "oui_hex": "00-1F-58",
        "organization": "EMH Energiemesstechnik GmbH",
        "address_1": "Vor dem Hassel 2",
        "address_2": "Brackel    21438",
        "country": "DE"
    },
    "689423": {
        "oui_hex": "68-94-23",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "844BF5": {
        "oui_hex": "84-4B-F5",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "08EDB9": {
        "oui_hex": "08-ED-B9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "3C77E6": {
        "oui_hex": "3C-77-E6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "70188B": {
        "oui_hex": "70-18-8B",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "5C6D20": {
        "oui_hex": "5C-6D-20",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "5CAC4C": {
        "oui_hex": "5C-AC-4C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0016DF": {
        "oui_hex": "00-16-DF",
        "organization": "Lundinova AB",
        "address_1": "Dalbyvägen 1",
        "address_2": "Lund  Skåne  SE-224 60",
        "country": "US"
    },
    "001D0C": {
        "oui_hex": "00-1D-0C",
        "organization": "MobileCompia",
        "address_1": "Dongwon Bldg, 725-30, Yeoksam-dong, Gangnam-gu,",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "B88EDF": {
        "oui_hex": "B8-8E-DF",
        "organization": "Zencheer Communication Technology Co., Ltd.",
        "address_1": "Room 2706, BLDG#7, Changjiang Building, NO.12, Changjiang Road, New District",
        "address_2": "Wuxi  Jiangsu  214028",
        "country": "CN"
    },
    "DC7144": {
        "oui_hex": "DC-71-44",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon    443-743",
        "country": "US"
    },
    "980C82": {
        "oui_hex": "98-0C-82",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "Metan Dong 314, Youngtong Gu",
        "address_2": "Suwon  Kyung-gi Do.  443-743",
        "country": "KR"
    },
    "A00BBA": {
        "oui_hex": "A0-0B-BA",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "Suwon-Si, Gyeonggi_Do, Korea",
        "address_2": "Suwon  Gyeonggi_Do  443-743",
        "country": "KR"
    },
    "606BBD": {
        "oui_hex": "60-6B-BD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  443742",
        "country": "KR"
    },
    "00214C": {
        "oui_hex": "00-21-4C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, METAN-3DONG,",
        "address_2": "SUWON  KYUNGKI-DO  442-742",
        "country": "KR"
    },
    "08C6B3": {
        "oui_hex": "08-C6-B3",
        "organization": "QTECH LLC",
        "address_1": "Novozavodskaya st. 18 build. 1",
        "address_2": "Moscow  Moscow region  121309",
        "country": "RU"
    },
    "0018AF": {
        "oui_hex": "00-18-AF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "001EE1": {
        "oui_hex": "00-1E-E1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00166B": {
        "oui_hex": "00-16-6B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416,Maetan-3Dong,Yeongtong-Gu",
        "address_2": "Suwon-City  Kyeonggi-Do  443-742",
        "country": "KR"
    },
    "0000F0": {
        "oui_hex": "00-00-F0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, MAETAN-3DONG, PALDAL-GU",
        "address_2": "kwon    442-742",
        "country": "KR"
    },
    "8CC8CD": {
        "oui_hex": "8C-C8-CD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, Yeongtong-gu",
        "address_2": "Suwon  Gyeonggi-do  443742",
        "country": "KR"
    },
    "A8F274": {
        "oui_hex": "A8-F2-74",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D487D8": {
        "oui_hex": "D4-87-D8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "184617": {
        "oui_hex": "18-46-17",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "380A94": {
        "oui_hex": "38-0A-94",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0DFC7": {
        "oui_hex": "D0-DF-C7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0C1B1": {
        "oui_hex": "D0-C1-B1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8018A7": {
        "oui_hex": "80-18-A7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyeonggi-Do  443742",
        "country": "KR"
    },
    "F47B5E": {
        "oui_hex": "F4-7B-5E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyeonggi-Do  443742",
        "country": "KR"
    },
    "70F927": {
        "oui_hex": "70-F9-27",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "34E71C": {
        "oui_hex": "34-E7-1C",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "886AB1": {
        "oui_hex": "88-6A-B1",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "6C1E90": {
        "oui_hex": "6C-1E-90",
        "organization": "Hansol Technics Co., Ltd.",
        "address_1": "55, Hansam-ro, Deoksan-Myeon",
        "address_2": "Jincheon-Gun  Chungbuk  27850",
        "country": "KR"
    },
    "005A13": {
        "oui_hex": "00-5A-13",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C45006": {
        "oui_hex": "C4-50-06",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88329B": {
        "oui_hex": "88-32-9B",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "1449E0": {
        "oui_hex": "14-49-E0",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong    24180",
        "country": "US"
    },
    "D02544": {
        "oui_hex": "D0-25-44",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "BC4486": {
        "oui_hex": "BC-44-86",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "20D390": {
        "oui_hex": "20-D3-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9401C2": {
        "oui_hex": "94-01-C2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "50FC9F": {
        "oui_hex": "50-FC-9F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "380B40": {
        "oui_hex": "38-0B-40",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B8FF61": {
        "oui_hex": "B8-FF-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "946124": {
        "oui_hex": "94-61-24",
        "organization": "Pason Systems",
        "address_1": "6130 - 3rd Street S.E.",
        "address_2": "Calgary  Alberta  T2H1K4",
        "country": "CA"
    },
    "F0728C": {
        "oui_hex": "F0-72-8C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "34AA8B": {
        "oui_hex": "34-AA-8B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "24DBED": {
        "oui_hex": "24-DB-ED",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C8DE51": {
        "oui_hex": "C8-DE-51",
        "organization": " IntegraOptics",
        "address_1": "745 Albany Shaker Rd",
        "address_2": "Latham   NY  12110",
        "country": "US"
    },
    "98F058": {
        "oui_hex": "98-F0-58",
        "organization": "Lynxspring, Incl.",
        "address_1": "1210 NE Windsor Drive",
        "address_2": "Lees Summit  MO  64086",
        "country": "US"
    },
    "68C44D": {
        "oui_hex": "68-C4-4D",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "400D10": {
        "oui_hex": "40-0D-10",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "943DC9": {
        "oui_hex": "94-3D-C9",
        "organization": "Asahi Net, Inc.",
        "address_1": "Ginza 4-12-15 Chuo-ku",
        "address_2": "Tokyo    104-0061",
        "country": "JP"
    },
    "440444": {
        "oui_hex": "44-04-44",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "00177E": {
        "oui_hex": "00-17-7E",
        "organization": "Meshcom Technologies Inc.",
        "address_1": "Meritullinkatu 1 C",
        "address_2": "Helsinki    00170",
        "country": "FI"
    },
    "A00460": {
        "oui_hex": "A0-04-60",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "9884E3": {
        "oui_hex": "98-84-E3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "38D269": {
        "oui_hex": "38-D2-69",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C8FD19": {
        "oui_hex": "C8-FD-19",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "508CB1": {
        "oui_hex": "50-8C-B1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "C4F5A5": {
        "oui_hex": "C4-F5-A5",
        "organization": "Kumalift Co., Ltd.",
        "address_1": "7-2-6 Saito-Asagi",
        "address_2": "Ibaraki  Osaka  567-0085",
        "country": "JP"
    },
    "70B14E": {
        "oui_hex": "70-B1-4E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "304487": {
        "oui_hex": "30-44-87",
        "organization": "Hefei Radio Communication Technology Co., Ltd",
        "address_1": "No.108, YinXing Road, High-tech Development Zone",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "2C9D1E": {
        "oui_hex": "2C-9D-1E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0081C4": {
        "oui_hex": "00-81-C4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "58E876": {
        "oui_hex": "58-E8-76",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D03742": {
        "oui_hex": "D0-37-42",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "Coolpad Information Harbor, 2nd Mengxi road, Hi-Tech Industrial Park(North), Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001765": {
        "oui_hex": "00-17-65",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "0015E8": {
        "oui_hex": "00-15-E8",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "00159B": {
        "oui_hex": "00-15-9B",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000F06": {
        "oui_hex": "00-0F-06",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "84B541": {
        "oui_hex": "84-B5-41",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "006F64": {
        "oui_hex": "00-6F-64",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DC6672": {
        "oui_hex": "DC-66-72",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "EC8EB5": {
        "oui_hex": "EC-8E-B5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "70AF6A": {
        "oui_hex": "70-AF-6A",
        "organization": "SHENZHEN FENGLIAN TECHNOLOGY CO., LTD.",
        "address_1": "ORIENTAL CYBERPORT, HIGHTECH 6 ROAD",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "20F543": {
        "oui_hex": "20-F5-43",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "E0DDC0": {
        "oui_hex": "E0-DD-C0",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "00164D": {
        "oui_hex": "00-16-4D",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield RD.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001AF0": {
        "oui_hex": "00-1A-F0",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94943",
        "country": "US"
    },
    "38521A": {
        "oui_hex": "38-52-1A",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "001E40": {
        "oui_hex": "00-1E-40",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F, lnfo Tech Building, NO.1555 Kongjiang Road,",
        "address_2": "Shanghai    200092",
        "country": "CN"
    },
    "94D723": {
        "oui_hex": "94-D7-23",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F Info-Tech Building",
        "address_2": "Shanghai    200092",
        "country": "CN"
    },
    "C4047B": {
        "oui_hex": "C4-04-7B",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Shenzhen University-town Business Park,Lishan Road,Taoyuan Street",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "20F41B": {
        "oui_hex": "20-F4-1B",
        "organization": "Shenzhen Bilian electronic CO.,LTD",
        "address_1": "NO 268, Fuqian Rd,Jutang Community,Guanlan town,",
        "address_2": "ShenZhen  Guangdong  518110",
        "country": "CN"
    },
    "FCFAF7": {
        "oui_hex": "FC-FA-F7",
        "organization": "Shanghai Baud Data Communication Co.,Ltd.",
        "address_1": "NO.123 JULI RD",
        "address_2": "SHANGHAI    201203",
        "country": "CN"
    },
    "D826B9": {
        "oui_hex": "D8-26-B9",
        "organization": "Guangdong Coagent Electronics S&amp;T Co.,Ltd.",
        "address_1": "Section C,Xi Nan Industrial Zone Sanshui",
        "address_2": "Foshan  Guangdong  528133",
        "country": "CN"
    },
    "AC9CE4": {
        "oui_hex": "AC-9C-E4",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "00233E": {
        "oui_hex": "00-23-3E",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "6CBEE9": {
        "oui_hex": "6C-BE-E9",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001540": {
        "oui_hex": "00-15-40",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001ECA": {
        "oui_hex": "00-1E-CA",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "00130A": {
        "oui_hex": "00-13-0A",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001F0A": {
        "oui_hex": "00-1F-0A",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "F8E61A": {
        "oui_hex": "F8-E6-1A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A091C8": {
        "oui_hex": "A0-91-C8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "6CA858": {
        "oui_hex": "6C-A8-58",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "CC2D8C": {
        "oui_hex": "CC-2D-8C",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1,Cheongho-Ri,Jinwi-Myeon",
        "address_2": "Pyeongtaek  Gyeonggi-Do  451-713",
        "country": "KR"
    },
    "98D6F7": {
        "oui_hex": "98-D6-F7",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "700514": {
        "oui_hex": "70-05-14",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "E892A4": {
        "oui_hex": "E8-92-A4",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "10683F": {
        "oui_hex": "10-68-3F",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "40B0FA": {
        "oui_hex": "40-B0-FA",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0025E5": {
        "oui_hex": "00-25-E5",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0021FB": {
        "oui_hex": "00-21-FB",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "34FCEF": {
        "oui_hex": "34-FC-EF",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "BCF5AC": {
        "oui_hex": "BC-F5-AC",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "A84E3F": {
        "oui_hex": "A8-4E-3F",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "0C4885": {
        "oui_hex": "0C-48-85",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0022A9": {
        "oui_hex": "00-22-A9",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "2C6A6F": {
        "oui_hex": "2C-6A-6F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "08D833": {
        "oui_hex": "08-D8-33",
        "organization": "Shenzhen RF Technology Co., Ltd",
        "address_1": "5/F,Building 4 ,Baokun science and Technology Industrial Park,Dalang Street,Baoan District,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "A46032": {
        "oui_hex": "A4-60-32",
        "organization": "MRV Communications (Networks) LTD",
        "address_1": "Hayetzira 6",
        "address_2": "Yokneam  Yokneam  20692",
        "country": "IL"
    },
    "40667A": {
        "oui_hex": "40-66-7A",
        "organization": "mediola - connected living AG",
        "address_1": "Nobelring 26",
        "address_2": "Frankfurt am Main  Hessen  60598",
        "country": "DE"
    },
    "68A0F6": {
        "oui_hex": "68-A0-F6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "000E5C": {
        "oui_hex": "00-0E-5C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "845DD7": {
        "oui_hex": "84-5D-D7",
        "organization": "Shenzhen Netcom Electronics Co.,Ltd",
        "address_1": "8/F,1 Building,Finance Base,No.8,Kefa Road,High-Tech Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00B064": {
        "oui_hex": "00-B0-64",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9C2A83": {
        "oui_hex": "9C-2A-83",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C80210": {
        "oui_hex": "C8-02-10",
        "organization": "LG Innotek",
        "address_1": "Jangduk-dong 978-1",
        "address_2": "Gwang-ju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "A039F7": {
        "oui_hex": "A0-39-F7",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "1CCAE3": {
        "oui_hex": "1C-CA-E3",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E4956E": {
        "oui_hex": "E4-95-6E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B437D1": {
        "oui_hex": "B4-37-D1",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0055DA": {
        "oui_hex": "00-55-DA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "78C2C0": {
        "oui_hex": "78-C2-C0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "000EE8": {
        "oui_hex": "00-0E-E8",
        "organization": "Zioncom Electronics (Shenzhen) Ltd.",
        "address_1": "West wing 5/F ., Block 1, GaoXin South Ring Rd/Keji South Rd,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00C095": {
        "oui_hex": "00-C0-95",
        "organization": "ZNYX Networks, Inc.",
        "address_1": "48421 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "002025": {
        "oui_hex": "00-20-25",
        "organization": "CONTROL TECHNOLOGY, INC.",
        "address_1": "5734 MIDDLEBROOK PIKE",
        "address_2": "KNOXVILLE  TN  37921",
        "country": "US"
    },
    "001A6B": {
        "oui_hex": "00-1A-6B",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "001641": {
        "oui_hex": "00-16-41",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "0010C6": {
        "oui_hex": "00-10-C6",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "00247E": {
        "oui_hex": "00-24-7E",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1,  TAIPING RD.",
        "address_2": "nantou  NANTOU  54261",
        "country": "TW"
    },
    "00DD0A": {
        "oui_hex": "00-DD-0A",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "683563": {
        "oui_hex": "68-35-63",
        "organization": "SHENZHEN LIOWN ELECTRONICS CO.,LTD.",
        "address_1": "ROOM 301, NO.7, GONGYE 3RD ROAD",
        "address_2": "SHEKOU, NANSHAN DISTRICT  SHENZHEN  518054",
        "country": "CN"
    },
    "004072": {
        "oui_hex": "00-40-72",
        "organization": "Applied Innovation Inc.",
        "address_1": "5800 Innovation Drive",
        "address_2": "Dublin  OH  43016-3271",
        "country": "US"
    },
    "001938": {
        "oui_hex": "00-19-38",
        "organization": "UMB Communications Co., Ltd.",
        "address_1": "1010, 5, ACE Techno Tower, 197-22, Guro-dong, Guro-gu",
        "address_2": "Seoul    151-766",
        "country": "KR"
    },
    "4439C4": {
        "oui_hex": "44-39-C4",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141,Lane351,Taiping Rd.Sec.1",
        "address_2": "nan tou    542",
        "country": "TW"
    },
    "402CF4": {
        "oui_hex": "40-2C-F4",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, Taiping Rd. Sec. 1, Tsao Tuen,",
        "address_2": "Nan-Tou Hsien,    542",
        "country": "TW"
    },
    "001E37": {
        "oui_hex": "00-1E-37",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, LANE 351,SEC.1, TAIPING RD.",
        "address_2": "TSAOTUEN,  NANTOU  54261",
        "country": "TW"
    },
    "1C57D8": {
        "oui_hex": "1C-57-D8",
        "organization": "Kraftway Corporation PLC",
        "address_1": "16, 3rd Mytischinskaya st.",
        "address_2": "Moscow    129626",
        "country": "RU"
    },
    "002318": {
        "oui_hex": "00-23-18",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "B86B23": {
        "oui_hex": "B8-6B-23",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "0008F1": {
        "oui_hex": "00-08-F1",
        "organization": "Voltaire",
        "address_1": "9 Hamenofim st.",
        "address_2": "Herzelia    46725",
        "country": "IL"
    },
    "00199D": {
        "oui_hex": "00-19-9D",
        "organization": "Vizio, Inc",
        "address_1": "39 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "00E08B": {
        "oui_hex": "00-E0-8B",
        "organization": "QLogic Corporation",
        "address_1": "26600 Laguna Hills Dr.",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "D8EB97": {
        "oui_hex": "D8-EB-97",
        "organization": "TRENDnet, Inc.",
        "address_1": "20675 Manhattan Place",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "001C7E": {
        "oui_hex": "00-1C-7E",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome    1988710",
        "country": "JP"
    },
    "002517": {
        "oui_hex": "00-25-17",
        "organization": "Venntis, LLC",
        "address_1": "11301 James Street",
        "address_2": "Holland  MI  49424",
        "country": "US"
    },
    "00600F": {
        "oui_hex": "00-60-0F",
        "organization": "Westell Technologies Inc.",
        "address_1": "750 N Commons Dr",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "00183A": {
        "oui_hex": "00-18-3A",
        "organization": "Westell Technologies Inc.",
        "address_1": "750 N Commons Dr",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "6002B4": {
        "oui_hex": "60-02-B4",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No.20 Park Avenue II",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "94DF4E": {
        "oui_hex": "94-DF-4E",
        "organization": "Wistron InfoComm(Kunshan)Co.,Ltd.",
        "address_1": "168# First Avence,Kunshan Export Processing Zone ,China",
        "address_2": "Kunsha  JiangSu  215300",
        "country": "CN"
    },
    "98EECB": {
        "oui_hex": "98-EE-CB",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "No.38,East Keji Road,Zhongshan Torch Development Zone,Zhongshan City,Guangdong,China",
        "address_2": "Zhongshan  Guangdong  528437",
        "country": "CN"
    },
    "643AB1": {
        "oui_hex": "64-3A-B1",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road, Chengdu, Sichuan",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "001BFE": {
        "oui_hex": "00-1B-FE",
        "organization": "Zavio Inc.",
        "address_1": "No.1,Lising 1st Rd. Science Based Industrial Park,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "5410EC": {
        "oui_hex": "54-10-EC",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "0004A3": {
        "oui_hex": "00-04-A3",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "789CE7": {
        "oui_hex": "78-9C-E7",
        "organization": "Shenzhen Aikede Technology Co., Ltd",
        "address_1": "Room 9B,Block B,Neptunus Mansion,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "509F3B": {
        "oui_hex": "50-9F-3B",
        "organization": "OI ELECTRIC CO.,LTD",
        "address_1": "7-3-16 KIKUNA",
        "address_2": "YOKOHAMA  KANAGAWA-KEN  222-0011",
        "country": "JP"
    },
    "446EE5": {
        "oui_hex": "44-6E-E5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "88F7C7": {
        "oui_hex": "88-F7-C7",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "8048A5": {
        "oui_hex": "80-48-A5",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,TianYi International Hotel",
        "address_2": "Chengdu  Sichuan  61000",
        "country": "CN"
    },
    "683E34": {
        "oui_hex": "68-3E-34",
        "organization": "MEIZU Technology Co., Ltd.",
        "address_1": "MEIZU Tech Bldg., Technology & Innovation Coast",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "C8778B": {
        "oui_hex": "C8-77-8B",
        "organization": "Mercury Systems – Trusted Mission Solutions, Inc.",
        "address_1": "47200 Bayside Pkwy",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00044B": {
        "oui_hex": "00-04-4B",
        "organization": "NVIDIA",
        "address_1": "3535 Monroe St.",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "AC9B0A": {
        "oui_hex": "AC-9B-0A",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "104FA8": {
        "oui_hex": "10-4F-A8",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "000B6B": {
        "oui_hex": "00-0B-6B",
        "organization": "Wistron Neweb Corporation",
        "address_1": "No. 10-1, Li-Hsin Road I, Science-based",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "AC040B": {
        "oui_hex": "AC-04-0B",
        "organization": "Peloton Interactive, Inc",
        "address_1": "158 W 27th St, 4th Fl",
        "address_2": "New York  NY  10001",
        "country": "US"
    },
    "48FCB6": {
        "oui_hex": "48-FC-B6",
        "organization": "LAVA INTERNATIONAL(H.K) LIMITED",
        "address_1": "UNIT L 1/F MAU LAM COMM BLDG 16-18 MAU LAM ST, JORDAN KL, HK",
        "address_2": "Hong kong    999077",
        "country": "CN"
    },
    "B0E235": {
        "oui_hex": "B0-E2-35",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "40C729": {
        "oui_hex": "40-C7-29",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "14C913": {
        "oui_hex": "14-C9-13",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "F8A097": {
        "oui_hex": "F8-A0-97",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FC2325": {
        "oui_hex": "FC-23-25",
        "organization": "EosTek (Shenzhen) Co., Ltd.",
        "address_1": "Room 306, Complex Building Tsinghua High-Tech Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "FC3D93": {
        "oui_hex": "FC-3D-93",
        "organization": "LONGCHEER TELECOMMUNICATION LIMITED",
        "address_1": "Building 1,No.401,Caobao Rd",
        "address_2": "Shanghai  Xuhui District  200233",
        "country": "CN"
    },
    "D8E0B8": {
        "oui_hex": "D8-E0-B8",
        "organization": "BULAT LLC",
        "address_1": "Zagorievsiy proezd 1, room 7",
        "address_2": "Moscow    115547",
        "country": "RU"
    },
    "603197": {
        "oui_hex": "60-31-97",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "C0C976": {
        "oui_hex": "C0-C9-76",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "588BF3": {
        "oui_hex": "58-8B-F3",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "5067F0": {
        "oui_hex": "50-67-F0",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "001349": {
        "oui_hex": "00-13-49",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "E09861": {
        "oui_hex": "E0-98-61",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "9C8ECD": {
        "oui_hex": "9C-8E-CD",
        "organization": "Amcrest Technologies",
        "address_1": "16727 Park Row",
        "address_2": "Houston  TX  77084",
        "country": "US"
    },
    "A009ED": {
        "oui_hex": "A0-09-ED",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "0014B4": {
        "oui_hex": "00-14-B4",
        "organization": "General Dynamics United Kingdom Ltd",
        "address_1": "Castleham Road",
        "address_2": "St Leonards on Sea  East Sussex  TN38 9NJ",
        "country": "GB"
    },
    "A0B437": {
        "oui_hex": "A0-B4-37",
        "organization": " GD Mission Systems",
        "address_1": "8220 EAST ROOSEVELT ST R2121",
        "address_2": "SCOTTSDALE  AZ  85257",
        "country": "US"
    },
    "8C6D50": {
        "oui_hex": "8C-6D-50",
        "organization": "SHENZHEN MTC CO LTD",
        "address_1": "5th Floor, 3rd Building, SHENZHEN MTC Industrial Park, XiaLilang Rd, Nanwan Street, Long’gang District",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "00F663": {
        "oui_hex": "00-F6-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A06090": {
        "oui_hex": "A0-60-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC765E": {
        "oui_hex": "BC-76-5E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E0A8B8": {
        "oui_hex": "E0-A8-B8",
        "organization": "Le Shi Zhi Xin Electronic Technology (Tianjin) Limited",
        "address_1": ",Le Shi Building, No.105 Yaojiayuan Road,Chaoyang District,Beijing,China",
        "address_2": "beijing  beijing  100025",
        "country": "CN"
    },
    "F45B73": {
        "oui_hex": "F4-5B-73",
        "organization": "Wanjiaan Interconnected Technology Co., Ltd",
        "address_1": "2nd Floor,Incubation Building, Science Development Institute of China, High-tech South 1st Street, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "B88198": {
        "oui_hex": "B8-81-98",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B0D7CC": {
        "oui_hex": "B0-D7-CC",
        "organization": "Tridonic GmbH & Co KG",
        "address_1": "Färbergasse 15",
        "address_2": "Dornbirn  Vorarlberg  6851",
        "country": "AT"
    },
    "2CDDA3": {
        "oui_hex": "2C-DD-A3",
        "organization": "Point Grey Research Inc.",
        "address_1": "305-1847 West Broadway",
        "address_2": "Vancouver  British Columbia V6J 1Y6",
        "country": "CA"
    },
    "00809F": {
        "oui_hex": "00-80-9F",
        "organization": "ALE International",
        "address_1": "32 avenue Kléber",
        "address_2": "Colombes    92700",
        "country": "FR"
    },
    "48C663": {
        "oui_hex": "48-C6-63",
        "organization": "GTO Access Systems LLC",
        "address_1": "3121 Hartsfield Road",
        "address_2": "Tallahassee  FL  32303",
        "country": "US"
    },
    "005F86": {
        "oui_hex": "00-5F-86",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "381DD9": {
        "oui_hex": "38-1D-D9",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "1CB9C4": {
        "oui_hex": "1C-B9-C4",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "8C59C3": {
        "oui_hex": "8C-59-C3",
        "organization": "ADB Italia",
        "address_1": "Viale Sarca 222",
        "address_2": "Milan  Italy  20126",
        "country": "IT"
    },
    "B824F0": {
        "oui_hex": "B8-24-F0",
        "organization": "SOYO Technology Development Co., Ltd.",
        "address_1": "4F, 9Bldg, Longbi Industry Zone, Longgang Dist, Shenzhen City, Guangdong Pro, China",
        "address_2": "Shenzhen City   Guangdong Pro  518129",
        "country": "CN"
    },
    "D85B2A": {
        "oui_hex": "D8-5B-2A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCA89A": {
        "oui_hex": "FC-A8-9A",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "1C7B23": {
        "oui_hex": "1C-7B-23",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "000BDE": {
        "oui_hex": "00-0B-DE",
        "organization": "TELDIX GmbH",
        "address_1": "Grenzhoefer Weg 36",
        "address_2": "Heidelberg    69123",
        "country": "DE"
    },
    "CCD31E": {
        "oui_hex": "CC-D3-1E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "34B354": {
        "oui_hex": "34-B3-54",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C6E76": {
        "oui_hex": "1C-6E-76",
        "organization": "Quarion Technology Inc",
        "address_1": "3248 Commerce Drive",
        "address_2": "Newburgh  IN  47630",
        "country": "US"
    },
    "90C1C6": {
        "oui_hex": "90-C1-C6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C0EE6": {
        "oui_hex": "6C-0E-E6",
        "organization": "Chengdu Xiyida Electronic Technology Co,.Ltd",
        "address_1": "Room 408,Building A,No.33 Wuqing South Road,Wuhou District",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "CC500A": {
        "oui_hex": "CC-50-0A",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D046DC": {
        "oui_hex": "D0-46-DC",
        "organization": "Southwest Research Institute",
        "address_1": "6220 Culebra Road",
        "address_2": "San Antonio  Texas  78238",
        "country": "US"
    },
    "70A2B3": {
        "oui_hex": "70-A2-B3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F40F24": {
        "oui_hex": "F4-0F-24",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C57CA": {
        "oui_hex": "4C-57-CA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000763": {
        "oui_hex": "00-07-63",
        "organization": "Sunniwell Cyber Tech. Co., Ltd.",
        "address_1": "17th Floor Haitai Building #229",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "0062EC": {
        "oui_hex": "00-62-EC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "CC167E": {
        "oui_hex": "CC-16-7E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C46AB7": {
        "oui_hex": "C4-6A-B7",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "000AED": {
        "oui_hex": "00-0A-ED",
        "organization": "HARTING Electronics GmbH",
        "address_1": "Wilhelm Harting Str.1",
        "address_2": "Espelkamp  NRW/OWL  32339",
        "country": "DE"
    },
    "240A11": {
        "oui_hex": "24-0A-11",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "D8E56D": {
        "oui_hex": "D8-E5-6D",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "540593": {
        "oui_hex": "54-05-93",
        "organization": "WOORI ELEC Co.,Ltd",
        "address_1": "#1401~03, #1411~12, Bucheon Deawoo Techno Park, D-Dong, 261,Doyak-Ro, Wonmi-Gu,Bucheon-Si",
        "address_2": "Gyeonggi-Do    14523",
        "country": "KR"
    },
    "C02FF1": {
        "oui_hex": "C0-2F-F1",
        "organization": "Volta Networks",
        "address_1": "109 Kingston St, 3rd Floor",
        "address_2": "Boston  MA  02111",
        "country": "US"
    },
    "E8A7F2": {
        "oui_hex": "E8-A7-F2",
        "organization": "sTraffic",
        "address_1": "4th Fl., KTNET Building, 338 Pangyoro, Bundang-gu",
        "address_2": "Seongnam  Gyeonggi-do  13493",
        "country": "KR"
    },
    "001F20": {
        "oui_hex": "00-1F-20",
        "organization": "Logitech Europe SA",
        "address_1": "EPFL - Quartier de l'Innovation",
        "address_2": "Lausanne  CH  1015",
        "country": "CH"
    },
    "741F4A": {
        "oui_hex": "74-1F-4A",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District,",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "E41D2D": {
        "oui_hex": "E4-1D-2D",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "0CDA41": {
        "oui_hex": "0C-DA-41",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "74258A": {
        "oui_hex": "74-25-8A",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "A0B662": {
        "oui_hex": "A0-B6-62",
        "organization": "Acutvista Innovation Co., Ltd.",
        "address_1": "2F-1, No. 20 Alley 1, Lane 768, Sec. 4",
        "address_2": "Taipei City    11577",
        "country": "TW"
    },
    "E42F56": {
        "oui_hex": "E4-2F-56",
        "organization": "OptoMET GmbH",
        "address_1": "Pfungstaedter Str. 92",
        "address_2": "Darmstadt    64297",
        "country": "DE"
    },
    "F8DA0C": {
        "oui_hex": "F8-DA-0C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "1C1B0D": {
        "oui_hex": "1C-1B-0D",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "48E9F1": {
        "oui_hex": "48-E9-F1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "903809": {
        "oui_hex": "90-38-09",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "00A006": {
        "oui_hex": "00-A0-06",
        "organization": "IMAGE DATA PROCESSING SYSTEM GROUP",
        "address_1": "SHINTOYOFUTA 2-1",
        "address_2": "KASHIWA-CITY, CHIBA 277",
        "country": "JP"
    },
    "C83F26": {
        "oui_hex": "C8-3F-26",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "3497F6": {
        "oui_hex": "34-97-F6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "50680A": {
        "oui_hex": "50-68-0A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "002238": {
        "oui_hex": "00-22-38",
        "organization": "LOGIPLUS",
        "address_1": "1, RUE CLEMENT ADER",
        "address_2": "GOSSELIES  HAINAUT  B-6041",
        "country": "BE"
    },
    "000C49": {
        "oui_hex": "00-0C-49",
        "organization": "Dangaard Telecom Denmark A/S",
        "address_1": "Industrivej 1",
        "address_2": "Padborg    DK-6330",
        "country": "DK"
    },
    "0008B9": {
        "oui_hex": "00-08-B9",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "#113 Imae 1-Dong, Bundang-Gu",
        "address_2": "Sungnam-City  Kyungki-Do  463-829",
        "country": "KR"
    },
    "60B387": {
        "oui_hex": "60-B3-87",
        "organization": "Synergics Technologies GmbH",
        "address_1": "Hummelgasse 74-76/19",
        "address_2": "Vienna  Austria  1130",
        "country": "AT"
    },
    "A4D8CA": {
        "oui_hex": "A4-D8-CA",
        "organization": "HONG KONG WATER WORLD TECHNOLOGY CO. LIMITED",
        "address_1": "RM B-C, 24/F, GOLDEN BEAR INDUSTRIAL CENTRE, 66-82  CHAI WAN KOK STREET,TSUEN WAN. N.T.",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "8019FE": {
        "oui_hex": "80-19-FE",
        "organization": "JianLing Technology CO., LTD",
        "address_1": "No. 383-1, Sec. 2, Jinling Rd., Pingzhen Dist.,",
        "address_2": "Tao Yuan    324",
        "country": "TW"
    },
    "60B4F7": {
        "oui_hex": "60-B4-F7",
        "organization": "Plume Design Inc",
        "address_1": "200 California Ave",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "487ADA": {
        "oui_hex": "48-7A-DA",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "001F45": {
        "oui_hex": "00-1F-45",
        "organization": "Enterasys",
        "address_1": "50 Minuteman Road",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "001E90": {
        "oui_hex": "00-1E-90",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.239, Sec. 2, Ti Ding Blvd",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "0022B1": {
        "oui_hex": "00-22-B1",
        "organization": "Elbit Systems Ltd.",
        "address_1": "p.o.b. 539",
        "address_2": "Haifa    36925",
        "country": "IL"
    },
    "0000B4": {
        "oui_hex": "00-00-B4",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "00168F": {
        "oui_hex": "00-16-8F",
        "organization": "GN Netcom A/S",
        "address_1": "Metalbuen 66",
        "address_2": "Ballerup  Skovlunde  DK-2750",
        "country": "DK"
    },
    "000D87": {
        "oui_hex": "00-0D-87",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22, Alley 38, Lane 91, Sec. 1, Nei Hu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "1078D2": {
        "oui_hex": "10-78-D2",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO. 239, Sec. 2, Ti Ding Blvd.",
        "address_2": "Taipei  Taiwan  11493",
        "country": "TW"
    },
    "002197": {
        "oui_hex": "00-21-97",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "NO.239, Sec. 2, Ti Ding Blvd.,",
        "address_2": "Taipei    11493",
        "country": "TW"
    },
    "E4F3F5": {
        "oui_hex": "E4-F3-F5",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A08CFD": {
        "oui_hex": "A0-8C-FD",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000E03": {
        "oui_hex": "00-0E-03",
        "organization": "Emulex Corporation",
        "address_1": "3333 Susan Street",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "00CAE5": {
        "oui_hex": "00-CA-E5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "004268": {
        "oui_hex": "00-42-68",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4883C7": {
        "oui_hex": "48-83-C7",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "40163B": {
        "oui_hex": "40-16-3B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "44650D": {
        "oui_hex": "44-65-0D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "D4F207": {
        "oui_hex": "D4-F2-07",
        "organization": "DIAODIAO(Beijing)Technology CO.,Ltd",
        "address_1": "48D Image Base, No 3 Guangqu Road, Chaoyang District, Beijing, China",
        "address_2": "Beijing    100124",
        "country": "CN"
    },
    "D4AD2D": {
        "oui_hex": "D4-AD-2D",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "F08CFB": {
        "oui_hex": "F0-8C-FB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "48555F": {
        "oui_hex": "48-55-5F",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "FC3F7C": {
        "oui_hex": "FC-3F-7C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "384C4F": {
        "oui_hex": "38-4C-4F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0CBF3F": {
        "oui_hex": "0C-BF-3F",
        "organization": "Shenzhen Lencotion Technology Co.,Ltd",
        "address_1": "LongGang,Buji Xia Shuijing,Hubei Baofeng Lndustrial Area,2/F,TowerB",
        "address_2": "shenzhen  Guangdong  518112",
        "country": "CN"
    },
    "50FF99": {
        "oui_hex": "50-FF-99",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "84E323": {
        "oui_hex": "84-E3-23",
        "organization": "Green Wave Telecommunication SDN BHD",
        "address_1": "8, 12, 9 - Menara Mutiara, Bangsar, Jalan Liku, Off Jalan Bangsar",
        "address_2": "Kuala Lumpur    59100",
        "country": "MY"
    },
    "705A9E": {
        "oui_hex": "70-5A-9E",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "04A316": {
        "oui_hex": "04-A3-16",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "140C5B": {
        "oui_hex": "14-0C-5B",
        "organization": "PLNetworks",
        "address_1": "B-613, Tancheonsang-ro 164(Sigma 2)",
        "address_2": "Seongnam-si  Bundang-gu, Gyeonggi-do  13631",
        "country": "KR"
    },
    "001706": {
        "oui_hex": "00-17-06",
        "organization": "Techfaithwireless Communication Technology Limited.",
        "address_1": "2/F M8 West No.1 Jiu Xian Qiao Dong Road,",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "FC084A": {
        "oui_hex": "FC-08-4A",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "BC9889": {
        "oui_hex": "BC-98-89",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "24615A": {
        "oui_hex": "24-61-5A",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "405EE1": {
        "oui_hex": "40-5E-E1",
        "organization": "Shenzhen H&T Intelligent Control Co.,Ltd.",
        "address_1": "D-Zone,10/F,Shenzhen Academy of Aerospace Technology,Hi-Tech Park at Nanshan District,Shenzhen,China",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "002578": {
        "oui_hex": "00-25-78",
        "organization": "JSC Concern Sozvezdie",
        "address_1": "Plekhanovskaya st., 14",
        "address_2": "Voronezh    394018",
        "country": "RU"
    },
    "30B49E": {
        "oui_hex": "30-B4-9E",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C83870": {
        "oui_hex": "C8-38-70",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1C553A": {
        "oui_hex": "1C-55-3A",
        "organization": "QianGua Corp.",
        "address_1": "Room 1106, block B,No.391,Gui Ping Road",
        "address_2": "Xu Hui District  ShangHai  200223",
        "country": "CN"
    },
    "34E70B": {
        "oui_hex": "34-E7-0B",
        "organization": "HAN Networks Co., Ltd",
        "address_1": "5F,#37 Building,#8 Dongbeiwang Eest Road",
        "address_2": "Haidian District  Beijing  100193",
        "country": "CN"
    },
    "007888": {
        "oui_hex": "00-78-88",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "900325": {
        "oui_hex": "90-03-25",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "98E7F5": {
        "oui_hex": "98-E7-F5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "085BDA": {
        "oui_hex": "08-5B-DA",
        "organization": "CliniCare LTD",
        "address_1": "HaSadna 11 Suite 207",
        "address_2": "Ra'anana    4365006",
        "country": "IL"
    },
    "1CC035": {
        "oui_hex": "1C-C0-35",
        "organization": "PLANEX COMMUNICATIONS INC.",
        "address_1": "Planex Volta Bldg., 2-11-9 Ebisu-Nishi,Shibuya-ku,Tokyo 150-0021,Japan",
        "address_2": "Tokyo  Tokyo  150-0021",
        "country": "JP"
    },
    "34543C": {
        "oui_hex": "34-54-3C",
        "organization": "TAKAOKA TOKO CO.,LTD.",
        "address_1": "8F,SIA TOYOSU PRIME SQUARE,5-6-36,Toyosu",
        "address_2": "Koto-ku  Tokyo  1350061",
        "country": "JP"
    },
    "1866DA": {
        "oui_hex": "18-66-DA",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "583277": {
        "oui_hex": "58-32-77",
        "organization": "Reliance Communications LLC",
        "address_1": "555 Wireless Blvd",
        "address_2": "Hauppauge  NY  11788",
        "country": "US"
    },
    "248A07": {
        "oui_hex": "24-8A-07",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "9C9D5D": {
        "oui_hex": "9C-9D-5D",
        "organization": "Raden Inc",
        "address_1": "15 Maiden Lane",
        "address_2": "New York  NY  10038",
        "country": "US"
    },
    "DC4D23": {
        "oui_hex": "DC-4D-23",
        "organization": "MRV Comunications",
        "address_1": "Hayetzira",
        "address_2": "Yokneam    614",
        "country": "IL"
    },
    "0023B3": {
        "oui_hex": "00-23-B3",
        "organization": "Lyyn AB",
        "address_1": "IDEON Science Park",
        "address_2": "Lund    223 70",
        "country": "SE"
    },
    "402E28": {
        "oui_hex": "40-2E-28",
        "organization": "MiXTelematics",
        "address_1": "Blaauwklip Office Park 2",
        "address_2": "Stellenbosch  Cape Province  7600",
        "country": "ZA"
    },
    "6C8FB5": {
        "oui_hex": "6C-8F-B5",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "008E73": {
        "oui_hex": "00-8E-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0015C1": {
        "oui_hex": "00-15-C1",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "A09D91": {
        "oui_hex": "A0-9D-91",
        "organization": "SoundBridge",
        "address_1": "#810, IT Convergence Industrial Bldg. 47, Gyeongdae-ro 17-Gil, Buk-gu,",
        "address_2": "Daegu    41566",
        "country": "KR"
    },
    "40B688": {
        "oui_hex": "40-B6-88",
        "organization": "LEGIC Identsystems AG",
        "address_1": "Binzackerstrasse 41",
        "address_2": "Wetzikon    8620",
        "country": "CH"
    },
    "9CD48B": {
        "oui_hex": "9C-D4-8B",
        "organization": "Innolux Technology Europe BV",
        "address_1": "Stationstraat 39G",
        "address_2": "Heerlen    6411NK",
        "country": "NL"
    },
    "90A62F": {
        "oui_hex": "90-A6-2F",
        "organization": "NAVER",
        "address_1": "NAVER Green Factory, 6, Buljeong-ro, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-867",
        "country": "KR"
    },
    "C0C522": {
        "oui_hex": "C0-C5-22",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1C9E46": {
        "oui_hex": "1C-9E-46",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C4E510": {
        "oui_hex": "C4-E5-10",
        "organization": "Mechatro, Inc.",
        "address_1": "169-28, Gasan Digital 2-ro, Geumcheon-Gu",
        "address_2": "Seoul    08500",
        "country": "KR"
    },
    "18A6F7": {
        "oui_hex": "18-A6-F7",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00351A": {
        "oui_hex": "00-35-1A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00AF1F": {
        "oui_hex": "00-AF-1F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "803896": {
        "oui_hex": "80-38-96",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "0060EC": {
        "oui_hex": "00-60-EC",
        "organization": "HERMARY OPTO ELECTRONICS INC.",
        "address_1": "201-4050 GRAVELEY ST",
        "address_2": "BURNABY, BC V5C-3T6",
        "country": "CA"
    },
    "C0CCF8": {
        "oui_hex": "C0-CC-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C4FDA": {
        "oui_hex": "9C-4F-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8489AD": {
        "oui_hex": "84-89-AD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC3A7A": {
        "oui_hex": "AC-3A-7A",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave",
        "address_2": "Saratoga    95070",
        "country": "US"
    },
    "B83E59": {
        "oui_hex": "B8-3E-59",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave.",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "DC3A5E": {
        "oui_hex": "DC-3A-5E",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave.",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "001A73": {
        "oui_hex": "00-1A-73",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road, Hsinchu Industrial Park, Hukou,",
        "address_2": "Hsinchu    303",
        "country": "TW"
    },
    "00904B": {
        "oui_hex": "00-90-4B",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road,",
        "address_2": "Hukou, Hsinchu,  Taiwan  30352",
        "country": "TW"
    },
    "001A7F": {
        "oui_hex": "00-1A-7F",
        "organization": "GCI Science & Technology Co.,LTD",
        "address_1": "No.381, Xingangzhong Road,",
        "address_2": "guangzhou  guangdong  510310",
        "country": "CN"
    },
    "00180F": {
        "oui_hex": "00-18-0F",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V  Denmark  1790V",
        "country": "DK"
    },
    "C8979F": {
        "oui_hex": "C8-97-9F",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "ECF35B": {
        "oui_hex": "EC-F3-5B",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "544408": {
        "oui_hex": "54-44-08",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  Varsinais-Suomi  24101",
        "country": "FI"
    },
    "3CC243": {
        "oui_hex": "3C-C2-43",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  NA  24101",
        "country": "FI"
    },
    "0021FC": {
        "oui_hex": "00-21-FC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001F5D": {
        "oui_hex": "00-1F-5D",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001F01": {
        "oui_hex": "00-1F-01",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001BEE": {
        "oui_hex": "00-1B-EE",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001979": {
        "oui_hex": "00-19-79",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0025D0": {
        "oui_hex": "00-25-D0",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0024D4": {
        "oui_hex": "00-24-D4",
        "organization": "FREEBOX SAS",
        "address_1": "8 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "347E39": {
        "oui_hex": "34-7E-39",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "00507F": {
        "oui_hex": "00-50-7F",
        "organization": "DrayTek Corp.",
        "address_1": "26, Fushing Rd.",
        "address_2": "Hsinchu  Hukou  303",
        "country": "TW"
    },
    "647791": {
        "oui_hex": "64-77-91",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9CE6E7": {
        "oui_hex": "9C-E6-E7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C0298": {
        "oui_hex": "9C-02-98",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "28987B": {
        "oui_hex": "28-98-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54FA3E": {
        "oui_hex": "54-FA-3E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "0C8910": {
        "oui_hex": "0C-89-10",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "78ABBB": {
        "oui_hex": "78-AB-BB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "D8C4E9": {
        "oui_hex": "D8-C4-E9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BCD11F": {
        "oui_hex": "BC-D1-1F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F4428F": {
        "oui_hex": "F4-42-8F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0090A2": {
        "oui_hex": "00-90-A2",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99, Park Avenue III",
        "address_2": "Hsinchu    12345",
        "country": "TW"
    },
    "0090D6": {
        "oui_hex": "00-90-D6",
        "organization": "Crystal Group, Inc.",
        "address_1": "850 KACENA RD.",
        "address_2": "HIAWATHA  IA  52233",
        "country": "US"
    },
    "446D6C": {
        "oui_hex": "44-6D-6C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00F46F": {
        "oui_hex": "00-F4-6F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0C715D": {
        "oui_hex": "0C-71-5D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C80DF": {
        "oui_hex": "9C-80-DF",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "002308": {
        "oui_hex": "00-23-08",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "880355": {
        "oui_hex": "88-03-55",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F., No.9 , Park Avenue II",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "34BB1F": {
        "oui_hex": "34-BB-1F",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "406F2A": {
        "oui_hex": "40-6F-2A",
        "organization": "BlackBerry RTS",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2V 2S7",
        "country": "CA"
    },
    "7C1CF1": {
        "oui_hex": "7C-1C-F1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "78F557": {
        "oui_hex": "78-F5-57",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E02861": {
        "oui_hex": "E0-28-61",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D0D04B": {
        "oui_hex": "D0-D0-4B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "480031": {
        "oui_hex": "48-00-31",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D476EA": {
        "oui_hex": "D4-76-EA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00175A": {
        "oui_hex": "00-17-5A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0896D7": {
        "oui_hex": "08-96-D7",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "506A03": {
        "oui_hex": "50-6A-03",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "100D7F": {
        "oui_hex": "10-0D-7F",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "504A6E": {
        "oui_hex": "50-4A-6E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "4C09D4": {
        "oui_hex": "4C-09-D4",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "18C086": {
        "oui_hex": "18-C0-86",
        "organization": "Broadcom",
        "address_1": "5300 California Avenue",
        "address_2": "Irvine  CA  92617",
        "country": "US"
    },
    "001018": {
        "oui_hex": "00-10-18",
        "organization": "Broadcom",
        "address_1": "16215 ALTON PARKWAY",
        "address_2": "IRVINE  CA  92619-7013",
        "country": "US"
    },
    "C8FF28": {
        "oui_hex": "C8-FF-28",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "B81619": {
        "oui_hex": "B8-16-19",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "B077AC": {
        "oui_hex": "B0-77-AC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "FCB4E6": {
        "oui_hex": "FC-B4-E6",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "TAIWAN  NEW TAIPEI  23585",
        "country": "TW"
    },
    "00192C": {
        "oui_hex": "00-19-2C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00195E": {
        "oui_hex": "00-19-5E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001A1B": {
        "oui_hex": "00-1A-1B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001A66": {
        "oui_hex": "00-1A-66",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001A77": {
        "oui_hex": "00-1A-77",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "64ED57": {
        "oui_hex": "64-ED-57",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A4ED4E": {
        "oui_hex": "A4-ED-4E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00211E": {
        "oui_hex": "00-21-1E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002180": {
        "oui_hex": "00-21-80",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001BDD": {
        "oui_hex": "00-1B-DD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001D6B": {
        "oui_hex": "00-1D-6B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DBE": {
        "oui_hex": "00-1D-BE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0012C9": {
        "oui_hex": "00-12-C9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0023A2": {
        "oui_hex": "00-23-A2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0023ED": {
        "oui_hex": "00-23-ED",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001B52": {
        "oui_hex": "00-1B-52",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001E8D": {
        "oui_hex": "00-1E-8D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E0469A": {
        "oui_hex": "E0-46-9A",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "30469A": {
        "oui_hex": "30-46-9A",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "002493": {
        "oui_hex": "00-24-93",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002641": {
        "oui_hex": "00-26-41",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015D0": {
        "oui_hex": "00-15-D0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001596": {
        "oui_hex": "00-15-96",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "04E676": {
        "oui_hex": "04-E6-76",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road",
        "address_2": "Hsinchu    30352",
        "country": "TW"
    },
    "0022F4": {
        "oui_hex": "00-22-F4",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No. 8-1, Nanyuan 2nd Rd.",
        "address_2": "Jhongli  Taoyuan  320",
        "country": "TW"
    },
    "001DBA": {
        "oui_hex": "00-1D-BA",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec,5-1-12,",
        "address_2": "Shinagawa-ku  Tokyo  141-0001",
        "country": "JP"
    },
    "0024BE": {
        "oui_hex": "00-24-BE",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec. 5-1-12",
        "address_2": "Shinagawa-ku  Tokyo  141-0001",
        "country": "JP"
    },
    "000FDE": {
        "oui_hex": "00-0F-DE",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0CFE45": {
        "oui_hex": "0C-FE-45",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "2016D8": {
        "oui_hex": "20-16-D8",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "E063E5": {
        "oui_hex": "E0-63-E5",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "F8D0AC": {
        "oui_hex": "F8-D0-AC",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "2421AB": {
        "oui_hex": "24-21-AB",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "B8F934": {
        "oui_hex": "B8-F9-34",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "8C6422": {
        "oui_hex": "8C-64-22",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "20E564": {
        "oui_hex": "20-E5-64",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "90B134": {
        "oui_hex": "90-B1-34",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "40B7F3": {
        "oui_hex": "40-B7-F3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001B59": {
        "oui_hex": "00-1B-59",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "002298": {
        "oui_hex": "00-22-98",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "0017E2": {
        "oui_hex": "00-17-E2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001675": {
        "oui_hex": "00-16-75",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000CE5": {
        "oui_hex": "00-0C-E5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0003E0": {
        "oui_hex": "00-03-E0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00D0C9": {
        "oui_hex": "00-D0-C9",
        "organization": "ADVANTECH CO., LTD.",
        "address_1": "FL. 4, NO.  108-3",
        "address_2": "TAIPEI  TAIPEI  TAIWAN",
        "country": "TW"
    },
    "6487D7": {
        "oui_hex": "64-87-D7",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "E0B2F1": {
        "oui_hex": "E0-B2-F1",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "5th Floor, A Building, Haoye Logistics Park, Shugang Channel, Bao'an District,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "0C4C39": {
        "oui_hex": "0C-4C-39",
        "organization": "MitraStar Technology Corp.",
        "address_1": "4F No.6 Innovation Road II",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "74888B": {
        "oui_hex": "74-88-8B",
        "organization": "ADB Broadband Italia",
        "address_1": "via Sarca 222",
        "address_2": "Milano    20126",
        "country": "IT"
    },
    "008C54": {
        "oui_hex": "00-8C-54",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "US"
    },
    "00247B": {
        "oui_hex": "00-24-7B",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0004E3": {
        "oui_hex": "00-04-E3",
        "organization": "Accton Technology Corp",
        "address_1": "No. 1 Creation Rd. III,",
        "address_2": "Hsinchu  Hsinchu  TAIWAN",
        "country": "TW"
    },
    "0010B5": {
        "oui_hex": "00-10-B5",
        "organization": "Accton Technology Corp",
        "address_1": "NO.1, CREATION RD. III",
        "address_2": "HSINCHU 300    12345",
        "country": "TW"
    },
    "001974": {
        "oui_hex": "00-19-74",
        "organization": "16063",
        "address_1": "1F , No. 21, Yanfa 2nd Rd., SBIP",
        "address_2": "Hsinchu City  Hsinchu  300",
        "country": "TW"
    },
    "E8617E": {
        "oui_hex": "E8-61-7E",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "18CF5E": {
        "oui_hex": "18-CF-5E",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "F0272D": {
        "oui_hex": "F0-27-2D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "84D6D0": {
        "oui_hex": "84-D6-D0",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "18FE34": {
        "oui_hex": "18-FE-34",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "38229D": {
        "oui_hex": "38-22-9D",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "A4526F": {
        "oui_hex": "A4-52-6F",
        "organization": "ADB Broadband Italia",
        "address_1": "via Sarca 222",
        "address_2": "Milano    20126",
        "country": "IT"
    },
    "605BB4": {
        "oui_hex": "60-5B-B4",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.,",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "64D954": {
        "oui_hex": "64-D9-54",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD, Lu Du,",
        "address_2": "Taicang  Jiangsu  215412",
        "country": "CN"
    },
    "5C36B8": {
        "oui_hex": "5C-36-B8",
        "organization": "TCL King Electrical Appliances (Huizhou) Co., Ltd",
        "address_1": "7/F，TCL Multimedia Building, TCL International E City, No.1001 Zhongshanyuan Road, Nanshan",
        "address_2": "Shenzhen  Guangdong   518052",
        "country": "CN"
    },
    "00AA01": {
        "oui_hex": "00-AA-01",
        "organization": "Intel Corporation",
        "address_1": "445",
        "address_2": "piscataway  NJ  08554",
        "country": "US"
    },
    "985FD3": {
        "oui_hex": "98-5F-D3",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "00DA55": {
        "oui_hex": "00-DA-55",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "18E3BC": {
        "oui_hex": "18-E3-BC",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "CC1FC4": {
        "oui_hex": "CC-1F-C4",
        "organization": "InVue",
        "address_1": "15015 Lancaster Hwy",
        "address_2": "Charlotte  NC  28277",
        "country": "US"
    },
    "00AA00": {
        "oui_hex": "00-AA-00",
        "organization": "Intel Corporation",
        "address_1": "5200 NE ELAM YOUNG PARKWAY",
        "address_2": "HILLSBORO  OR  97124",
        "country": "US"
    },
    "00C2C6": {
        "oui_hex": "00-C2-C6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5CD2E4": {
        "oui_hex": "5C-D2-E4",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "28B2BD": {
        "oui_hex": "28-B2-BD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "002243": {
        "oui_hex": "00-22-43",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd., Xindian",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "00006E": {
        "oui_hex": "00-00-6E",
        "organization": "Artisoft Inc.",
        "address_1": "691 EAST RIVER ROAD",
        "address_2": "TUCSON  AZ  85704",
        "country": "US"
    },
    "448723": {
        "oui_hex": "44-87-23",
        "organization": "HOYA SERVICE CORPORATION",
        "address_1": "4-10-2 Nakano",
        "address_2": "Nakano-ku  Tokyo  164-8545",
        "country": "JP"
    },
    "D86C02": {
        "oui_hex": "D8-6C-02",
        "organization": "Huaqin Telecom Technology Co.,Ltd",
        "address_1": "No.1 Building,399 Keyuan Road, Zhangjian Hi-Tech Park, Pudong New Area",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "60BEB5": {
        "oui_hex": "60-BE-B5",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "F8F1B6": {
        "oui_hex": "F8-F1-B6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "3CFDFE": {
        "oui_hex": "3C-FD-FE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A4C494": {
        "oui_hex": "A4-C4-94",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "902E1C": {
        "oui_hex": "90-2E-1C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A434D9": {
        "oui_hex": "A4-34-D9",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "685D43": {
        "oui_hex": "68-5D-43",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A0369F": {
        "oui_hex": "A0-36-9F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "64D4DA": {
        "oui_hex": "64-D4-DA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4025C2": {
        "oui_hex": "40-25-C2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "502DA2": {
        "oui_hex": "50-2D-A2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "78929C": {
        "oui_hex": "78-92-9C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "843A4B": {
        "oui_hex": "84-3A-4B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5C514F": {
        "oui_hex": "5C-51-4F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A44E31": {
        "oui_hex": "A4-4E-31",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4CEB42": {
        "oui_hex": "4C-EB-42",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F81654": {
        "oui_hex": "F8-16-54",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "606C66": {
        "oui_hex": "60-6C-66",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4C8093": {
        "oui_hex": "4C-80-93",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "AC7289": {
        "oui_hex": "AC-72-89",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "448500": {
        "oui_hex": "44-85-00",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0CD292": {
        "oui_hex": "0C-D2-92",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DCA971": {
        "oui_hex": "DC-A9-71",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "58946B": {
        "oui_hex": "58-94-6B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0024D7": {
        "oui_hex": "00-24-D7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0024D6": {
        "oui_hex": "00-24-D6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001DE0": {
        "oui_hex": "00-1D-E0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4C79BA": {
        "oui_hex": "4C-79-BA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "84A6C8": {
        "oui_hex": "84-A6-C8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5891CF": {
        "oui_hex": "58-91-CF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0C8BFD": {
        "oui_hex": "0C-8B-FD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00215C": {
        "oui_hex": "00-21-5C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00216B": {
        "oui_hex": "00-21-6B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0022FB": {
        "oui_hex": "00-22-FB",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001517": {
        "oui_hex": "00-15-17",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A0A8CD": {
        "oui_hex": "A0-A8-CD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5CC5D4": {
        "oui_hex": "5C-C5-D4",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001E64": {
        "oui_hex": "00-1E-64",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F4F1E1": {
        "oui_hex": "F4-F1-E1",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "9CD917": {
        "oui_hex": "9C-D9-17",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "9068C3": {
        "oui_hex": "90-68-C3",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "3C197D": {
        "oui_hex": "3C-19-7D",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "B4E10F": {
        "oui_hex": "B4-E1-0F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "002219": {
        "oui_hex": "00-22-19",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "0024E8": {
        "oui_hex": "00-24-E8",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "B083FE": {
        "oui_hex": "B0-83-FE",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "3417EB": {
        "oui_hex": "34-17-EB",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "F8BC12": {
        "oui_hex": "F8-BC-12",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "18A99B": {
        "oui_hex": "18-A9-9B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001372": {
        "oui_hex": "00-13-72",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001143": {
        "oui_hex": "00-11-43",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "4C7625": {
        "oui_hex": "4C-76-25",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "44A842": {
        "oui_hex": "44-A8-42",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00253C": {
        "oui_hex": "00-25-3C",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "34EF44": {
        "oui_hex": "34-EF-44",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "B0E754": {
        "oui_hex": "B0-E7-54",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "F01FAF": {
        "oui_hex": "F0-1F-AF",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "00188B": {
        "oui_hex": "00-18-8B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "000874": {
        "oui_hex": "00-08-74",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "B8E625": {
        "oui_hex": "B8-E6-25",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "001D5A": {
        "oui_hex": "00-1D-5A",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San  Jose    95131",
        "country": "US"
    },
    "1C4419": {
        "oui_hex": "1C-44-19",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5C353B": {
        "oui_hex": "5C-35-3B",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "28FAA0": {
        "oui_hex": "28-FA-A0",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "ECDF3A": {
        "oui_hex": "EC-DF-3A",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "F42981": {
        "oui_hex": "F4-29-81",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "84F6FA": {
        "oui_hex": "84-F6-FA",
        "organization": "Miovision Technologies Incorporated",
        "address_1": "148 Manitou Drive",
        "address_2": "KITCHENER  Ontario  N2C1L4",
        "country": "CA"
    },
    "70106F": {
        "oui_hex": "70-10-6F",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "F8E71E": {
        "oui_hex": "F8-E7-1E",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "08863B": {
        "oui_hex": "08-86-3B",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "247C4C": {
        "oui_hex": "24-7C-4C",
        "organization": "Herman Miller",
        "address_1": "Unit 2, 2/F The Factory, 1 Yip Fat Street",
        "address_2": "Wong Chuk Hang    -",
        "country": "HK"
    },
    "E46F13": {
        "oui_hex": "E4-6F-13",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "2C56DC": {
        "oui_hex": "2C-56-DC",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "003146": {
        "oui_hex": "00-31-46",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00604C": {
        "oui_hex": "00-60-4C",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "27 RUE LEBLANC",
        "address_2": "CEDEX 15  PARIS  75512",
        "country": "FR"
    },
    "001F95": {
        "oui_hex": "00-1F-95",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "002348": {
        "oui_hex": "00-23-48",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "002691": {
        "oui_hex": "00-26-91",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "988B5D": {
        "oui_hex": "98-8B-5D",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison    92848",
        "country": "FR"
    },
    "90013B": {
        "oui_hex": "90-01-3B",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "7C034C": {
        "oui_hex": "7C-03-4C",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "6C2E85": {
        "oui_hex": "6C-2E-85",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "94FEF4": {
        "oui_hex": "94-FE-F4",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "34B1F7": {
        "oui_hex": "34-B1-F7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "2CFD37": {
        "oui_hex": "2C-FD-37",
        "organization": "Blue Calypso, Inc.",
        "address_1": "101 West Renner RD Suite 280",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "0C6127": {
        "oui_hex": "0C-61-27",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "3CD92B": {
        "oui_hex": "3C-D9-2B",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "78DEE4": {
        "oui_hex": "78-DE-E4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001833": {
        "oui_hex": "00-18-33",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001834": {
        "oui_hex": "00-18-34",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017E3": {
        "oui_hex": "00-17-E3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001830": {
        "oui_hex": "00-18-30",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0023D4": {
        "oui_hex": "00-23-D4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "BCF685": {
        "oui_hex": "BC-F6-85",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "78542E": {
        "oui_hex": "78-54-2E",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12.",
        "address_2": "SINGAPORE  Singapore  609917",
        "country": "TW"
    },
    "C4A81D": {
        "oui_hex": "C4-A8-1D",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,",
        "address_2": "SINGAPORE  Singapore  609917",
        "country": "SG"
    },
    "002191": {
        "oui_hex": "00-21-91",
        "organization": "D-Link Corporation",
        "address_1": "NO.289, Sinhu 3rd Rd.,",
        "address_2": "Neihu District,  Taipei City  114",
        "country": "TW"
    },
    "ACF1DF": {
        "oui_hex": "AC-F1-DF",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "C0E422": {
        "oui_hex": "C0-E4-22",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D00790": {
        "oui_hex": "D0-07-90",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "3C7DB1": {
        "oui_hex": "3C-7D-B1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F4FC32": {
        "oui_hex": "F4-FC-32",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "90D7EB": {
        "oui_hex": "90-D7-EB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0017E8": {
        "oui_hex": "00-17-E8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "001783": {
        "oui_hex": "00-17-83",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "00F871": {
        "oui_hex": "00-F8-71",
        "organization": "DGS Denmark A/S",
        "address_1": "Kongebakken 9",
        "address_2": "Smørum    2765",
        "country": "DK"
    },
    "2435CC": {
        "oui_hex": "24-35-CC",
        "organization": "Zhongshan Scinan Internet of Things Co.,Ltd.",
        "address_1": "15/F Bldg 1·Dezhong Plaza Torch Development Zone Zhongshan·Guangdong",
        "address_2": "ZhongShan  GuangDong  528437",
        "country": "CN"
    },
    "2C3033": {
        "oui_hex": "2C-30-33",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CC46D6": {
        "oui_hex": "CC-46-D6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0041D2": {
        "oui_hex": "00-41-D2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2CAB00": {
        "oui_hex": "2C-AB-00",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8CA7B": {
        "oui_hex": "A8-CA-7B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC4434": {
        "oui_hex": "BC-44-34",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "04BF6D": {
        "oui_hex": "04-BF-6D",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "F88FCA": {
        "oui_hex": "F8-8F-CA",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View    94043",
        "country": "US"
    },
    "3898D8": {
        "oui_hex": "38-98-D8",
        "organization": "MERITECH CO.,LTD",
        "address_1": "52-17 Sinjeon-Ro 41beon-gil",
        "address_2": "Giheung-gu, Yongin-City Kyungki-do    446-599",
        "country": "KR"
    },
    "9486CD": {
        "oui_hex": "94-86-CD",
        "organization": "SEOUL ELECTRONICS&TELECOM",
        "address_1": "709, Namkwangcentrex 440-4, Cheongcheon-dong,",
        "address_2": "Bupyeong-gu  Incheon  403-030",
        "country": "KR"
    },
    "3897D6": {
        "oui_hex": "38-97-D6",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "1CA770": {
        "oui_hex": "1C-A7-70",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit A 13-16/F,Skyworth Bldg., Gaoxin Ave.1.S.,Nanshan District",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "4419B6": {
        "oui_hex": "44-19-B6",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "68DBCA": {
        "oui_hex": "68-DB-CA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "086698": {
        "oui_hex": "08-66-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC5436": {
        "oui_hex": "BC-54-36",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "044BED": {
        "oui_hex": "04-4B-ED",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C8DC1": {
        "oui_hex": "6C-8D-C1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84ACFB": {
        "oui_hex": "84-AC-FB",
        "organization": "Crouzet Automatismes",
        "address_1": "2 rue du docteur Abel",
        "address_2": "Valence  France  26902",
        "country": "FR"
    },
    "7CBB8A": {
        "oui_hex": "7C-BB-8A",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "FCFFAA": {
        "oui_hex": "FC-FF-AA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0CD746": {
        "oui_hex": "0C-D7-46",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60A37D": {
        "oui_hex": "60-A3-7D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88A25E": {
        "oui_hex": "88-A2-5E",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "541E56": {
        "oui_hex": "54-1E-56",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "8896B6": {
        "oui_hex": "88-96-B6",
        "organization": "Global Fire Equipment S.A.",
        "address_1": "Sitio dos Barrabés, Armazém Nave Y,",
        "address_2": "São Brás de Alportel  Faro  8150-016",
        "country": "PT"
    },
    "88B8D0": {
        "oui_hex": "88-B8-D0",
        "organization": "Dongguan Koppo Electronic Co.,Ltd",
        "address_1": "No.2, Third Road, Buxinji Industrial Area, Guanjingtou Village, Fenggang Town, Dongguan City, Guangdong Province, China",
        "address_2": "Dongguan    523705",
        "country": "CN"
    },
    "601971": {
        "oui_hex": "60-19-71",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F8CAB8": {
        "oui_hex": "F8-CA-B8",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001111": {
        "oui_hex": "00-11-11",
        "organization": "Intel Corporation",
        "address_1": "2111 NE 25th Avenue",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "001302": {
        "oui_hex": "00-13-02",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6CCA08": {
        "oui_hex": "6C-CA-08",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "78719C": {
        "oui_hex": "78-71-9C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D40598": {
        "oui_hex": "D4-05-98",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E83381": {
        "oui_hex": "E8-33-81",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8C7F3B": {
        "oui_hex": "8C-7F-3B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5C571A": {
        "oui_hex": "5C-57-1A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E8892C": {
        "oui_hex": "E8-89-2C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "94877C": {
        "oui_hex": "94-87-7C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "407009": {
        "oui_hex": "40-70-09",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "083E0C": {
        "oui_hex": "08-3E-0C",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3C36E4": {
        "oui_hex": "3C-36-E4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1C1B68": {
        "oui_hex": "1C-1B-68",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000423": {
        "oui_hex": "00-04-23",
        "organization": "Intel Corporation",
        "address_1": "M/S:  JF3-420",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "207355": {
        "oui_hex": "20-73-55",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F8EDA5": {
        "oui_hex": "F8-ED-A5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5465DE": {
        "oui_hex": "54-65-DE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "58AC78": {
        "oui_hex": "58-AC-78",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "780AC7": {
        "oui_hex": "78-0A-C7",
        "organization": "Baofeng TV Co., Ltd.",
        "address_1": "Room 2D, Building 5D, Nanshan District Software Industry Base",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "000D0B": {
        "oui_hex": "00-0D-0B",
        "organization": "BUFFALO.INC",
        "address_1": "MELCO HI-TECH CENTER,",
        "address_2": "NAGOYA    457-8520",
        "country": "JP"
    },
    "001D73": {
        "oui_hex": "00-1D-73",
        "organization": "BUFFALO.INC",
        "address_1": "15,Shibata Hondori 4-chome,",
        "address_2": "Nagoya  Aichi Pref.  457-8520",
        "country": "JP"
    },
    "001601": {
        "oui_hex": "00-16-01",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "7403BD": {
        "oui_hex": "74-03-BD",
        "organization": "BUFFALO.INC",
        "address_1": " AKAMONDORI Bldg, 30-20, Ohsu 3-chome,",
        "address_2": "Minami-ku, Nagoya  Aichi Pref.  457-8520",
        "country": "JP"
    },
    "B8FC9A": {
        "oui_hex": "B8-FC-9A",
        "organization": "Le Shi Zhi Xin Electronic Technology (Tianjin) Limited",
        "address_1": ",Le Shi Building, No.105 Yaojiayuan Road,Chaoyang District,Beijing,China",
        "address_2": "beijing  beijing  100025",
        "country": "CN"
    },
    "A45D36": {
        "oui_hex": "A4-5D-36",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "F0921C": {
        "oui_hex": "F0-92-1C",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "A0481C": {
        "oui_hex": "A0-48-1C",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "A01D48": {
        "oui_hex": "A0-1D-48",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "40A8F0": {
        "oui_hex": "40-A8-F0",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "8851FB": {
        "oui_hex": "88-51-FB",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "082E5F": {
        "oui_hex": "08-2E-5F",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "E4115B": {
        "oui_hex": "E4-11-5B",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "28924A": {
        "oui_hex": "28-92-4A",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "288023": {
        "oui_hex": "28-80-23",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "CC3E5F": {
        "oui_hex": "CC-3E-5F",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D89D67": {
        "oui_hex": "D8-9D-67",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "0014C2": {
        "oui_hex": "00-14-C2",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00805F": {
        "oui_hex": "00-80-5F",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0018FE": {
        "oui_hex": "00-18-FE",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "001A4B": {
        "oui_hex": "00-1A-4B",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "002481": {
        "oui_hex": "00-24-81",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000F61": {
        "oui_hex": "00-0F-61",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "480FCF": {
        "oui_hex": "48-0F-CF",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D40B1A": {
        "oui_hex": "D4-0B-1A",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd.",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "945330": {
        "oui_hex": "94-53-30",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A08D16": {
        "oui_hex": "A0-8D-16",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "4CD08A": {
        "oui_hex": "4C-D0-8A",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village,216,Hwangsaeul-ro,",
        "address_2": "Seongnam-si  Gyeonggi-do  463875",
        "country": "KR"
    },
    "CC4EEC": {
        "oui_hex": "CC-4E-EC",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bundang-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "403DEC": {
        "oui_hex": "40-3D-EC",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bundang-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "EC4D47": {
        "oui_hex": "EC-4D-47",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C44044": {
        "oui_hex": "C4-40-44",
        "organization": "RackTop Systems Inc.",
        "address_1": "11840 W Market Pl Suite K",
        "address_2": "Fulton  MD  20759",
        "country": "US"
    },
    "4CA161": {
        "oui_hex": "4C-A1-61",
        "organization": "Rain Bird Corporation",
        "address_1": "970 West Sierra Madre Ave.",
        "address_2": "AZUSA  CA  91702",
        "country": "US"
    },
    "8CAB8E": {
        "oui_hex": "8C-AB-8E",
        "organization": "Shanghai Feixun Communication Co.,Ltd.",
        "address_1": "No.3666,Sixian Rd.,Songjiang District,Shanghai,P.R.China",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "FC64BA": {
        "oui_hex": "FC-64-BA",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "9060F1": {
        "oui_hex": "90-60-F1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F8D111": {
        "oui_hex": "F8-D1-11",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B0487A": {
        "oui_hex": "B0-48-7A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "940C6D": {
        "oui_hex": "94-0C-6D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A4516F": {
        "oui_hex": "A4-51-6F",
        "organization": "Microsoft Mobile Oy",
        "address_1": "Keilalahdentie 4",
        "address_2": "Espoo    02150",
        "country": "FI"
    },
    "542758": {
        "oui_hex": "54-27-58",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "00242B": {
        "oui_hex": "00-24-2B",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "08181A": {
        "oui_hex": "08-18-1A",
        "organization": "zte corporation",
        "address_1": "12/F ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  GUANGDONG  518057",
        "country": "CN"
    },
    "001E73": {
        "oui_hex": "00-1E-73",
        "organization": "zte corporation",
        "address_1": "12/F ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District,",
        "address_2": "Shenzhen  GUANGDONG  518057",
        "country": "CN"
    },
    "0015EB": {
        "oui_hex": "00-15-EB",
        "organization": "zte corporation",
        "address_1": "5/F,A Wing,ZTE Plaza,Keji Road South,Hi-Tech Industrial Park,Nanshan District",
        "address_2": "Shenzhen    518057",
        "country": "US"
    },
    "001C25": {
        "oui_hex": "00-1C-25",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00197E": {
        "oui_hex": "00-19-7E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "90FBA6": {
        "oui_hex": "90-FB-A6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "4437E6": {
        "oui_hex": "44-37-E6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "CCAF78": {
        "oui_hex": "CC-AF-78",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "F4B7E2": {
        "oui_hex": "F4-B7-E2",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "647002": {
        "oui_hex": "64-70-02",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan,",
        "address_2": "Shenzhen  Guangdong Province,  518057",
        "country": "CN"
    },
    "10FEED": {
        "oui_hex": "10-FE-ED",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "645601": {
        "oui_hex": "64-56-01",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "F02765": {
        "oui_hex": "F0-27-65",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "5CF8A1": {
        "oui_hex": "5C-F8-A1",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "44A7CF": {
        "oui_hex": "44-A7-CF",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "0013E0": {
        "oui_hex": "00-13-E0",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "EC26CA": {
        "oui_hex": "EC-26-CA",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "9471AC": {
        "oui_hex": "94-71-AC",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "2C088C": {
        "oui_hex": "2C-08-8C",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "1C994C": {
        "oui_hex": "1C-99-4C",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "F4559C": {
        "oui_hex": "F4-55-9C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "80B686": {
        "oui_hex": "80-B6-86",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "10C61F": {
        "oui_hex": "10-C6-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "CC96A0": {
        "oui_hex": "CC-96-A0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "F80113": {
        "oui_hex": "F8-01-13",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A49947": {
        "oui_hex": "A4-99-47",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C8D15E": {
        "oui_hex": "C8-D1-5E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "785968": {
        "oui_hex": "78-59-68",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C07009": {
        "oui_hex": "C0-70-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8038BC": {
        "oui_hex": "80-38-BC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C4072F": {
        "oui_hex": "C4-07-2F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F48E92": {
        "oui_hex": "F4-8E-92",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00664B": {
        "oui_hex": "00-66-4B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9CC172": {
        "oui_hex": "9C-C1-72",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "247F3C": {
        "oui_hex": "24-7F-3C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "581F28": {
        "oui_hex": "58-1F-28",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ECCB30": {
        "oui_hex": "EC-CB-30",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4DCF9": {
        "oui_hex": "F4-DC-F9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "308730": {
        "oui_hex": "30-87-30",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "C057BC": {
        "oui_hex": "C0-57-BC",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "64A7DD": {
        "oui_hex": "64-A7-DD",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "241FA0": {
        "oui_hex": "24-1F-A0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "18C58A": {
        "oui_hex": "18-C5-8A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "080028": {
        "oui_hex": "08-00-28",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "405FC2": {
        "oui_hex": "40-5F-C2",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E0E5CF": {
        "oui_hex": "E0-E5-CF",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "68DFDD": {
        "oui_hex": "68-DF-DD",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "7054F5": {
        "oui_hex": "70-54-F5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "DCD2FC": {
        "oui_hex": "DC-D2-FC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "9017AC": {
        "oui_hex": "90-17-AC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "34CDBE": {
        "oui_hex": "34-CD-BE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "D8490B": {
        "oui_hex": "D8-49-0B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen    518129",
        "country": "CN"
    },
    "44322A": {
        "oui_hex": "44-32-2A",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "7038EE": {
        "oui_hex": "70-38-EE",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "703018": {
        "oui_hex": "70-30-18",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "9C28EF": {
        "oui_hex": "9C-28-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "EC24B8": {
        "oui_hex": "EC-24-B8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "7CEC79": {
        "oui_hex": "7C-EC-79",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "689E19": {
        "oui_hex": "68-9E-19",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "20CD39": {
        "oui_hex": "20-CD-39",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B4994C": {
        "oui_hex": "B4-99-4C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A4251B": {
        "oui_hex": "A4-25-1B",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "646A52": {
        "oui_hex": "64-6A-52",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "00100B": {
        "oui_hex": "00-10-0B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00173B": {
        "oui_hex": "00-17-3B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Dr.",
        "address_2": "San Jose  CA  95134-1706",
        "country": "US"
    },
    "04DAD2": {
        "oui_hex": "04-DA-D2",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F02929": {
        "oui_hex": "F0-29-29",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "20BBC0": {
        "oui_hex": "20-BB-C0",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "4C4E35": {
        "oui_hex": "4C-4E-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "98FAE3": {
        "oui_hex": "98-FA-E3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "F0B429": {
        "oui_hex": "F0-B4-29",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "005080": {
        "oui_hex": "00-50-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "005073": {
        "oui_hex": "00-50-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00900C": {
        "oui_hex": "00-90-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00905F": {
        "oui_hex": "00-90-5F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00E0F7": {
        "oui_hex": "00-E0-F7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001BD7": {
        "oui_hex": "00-1B-D7",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "006083": {
        "oui_hex": "00-60-83",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "006009": {
        "oui_hex": "00-60-09",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00067C": {
        "oui_hex": "00-06-7C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00107B": {
        "oui_hex": "00-10-7B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W.TASMAN DR.-SJA-2",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0050E2": {
        "oui_hex": "00-50-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E4D3F1": {
        "oui_hex": "E4-D3-F1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "8478AC": {
        "oui_hex": "84-78-AC",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0090A6": {
        "oui_hex": "00-90-A6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "009086": {
        "oui_hex": "00-90-86",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00248C": {
        "oui_hex": "00-24-8C",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "002354": {
        "oui_hex": "00-23-54",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "1C872C": {
        "oui_hex": "1C-87-2C",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.., Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "60182E": {
        "oui_hex": "60-18-2E",
        "organization": "ShenZhen Protruly Electronic Ltd co.",
        "address_1": "ShenNan Road 1004",
        "address_2": "Shen Zhen  GuangDong  518000",
        "country": "CN"
    },
    "C4143C": {
        "oui_hex": "C4-14-3C",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3C08F6": {
        "oui_hex": "3C-08-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001E8C": {
        "oui_hex": "00-1E-8C",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "0013D4": {
        "oui_hex": "00-13-D4",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "No.5 Shing Yeh Street",
        "address_2": "Tao Yuan Hsien    333",
        "country": "TW"
    },
    "20CF30": {
        "oui_hex": "20-CF-30",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "BC1665": {
        "oui_hex": "BC-16-65",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F872EA": {
        "oui_hex": "F8-72-EA",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "D0C789": {
        "oui_hex": "D0-C7-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F84F57": {
        "oui_hex": "F8-4F-57",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "501CBF": {
        "oui_hex": "50-1C-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B000B4": {
        "oui_hex": "B0-00-B4",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "544A00": {
        "oui_hex": "54-4A-00",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00E16D": {
        "oui_hex": "00-E1-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "78BAF9": {
        "oui_hex": "78-BA-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0022CE": {
        "oui_hex": "00-22-CE",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30042",
        "country": "US"
    },
    "E0D173": {
        "oui_hex": "E0-D1-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E0899D": {
        "oui_hex": "E0-89-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C47295": {
        "oui_hex": "C4-72-95",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7C69F6": {
        "oui_hex": "7C-69-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "78DA6E": {
        "oui_hex": "78-DA-6E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B8782E": {
        "oui_hex": "B8-78-2E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000502": {
        "oui_hex": "00-05-02",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000A95": {
        "oui_hex": "00-0A-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34BDC8": {
        "oui_hex": "34-BD-C8",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "DCEB94": {
        "oui_hex": "DC-EB-94",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "84B517": {
        "oui_hex": "84-B5-17",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1C6E4C": {
        "oui_hex": "1C-6E-4C",
        "organization": "Logistic Service & Engineering Co.,Ltd",
        "address_1": "Unit N,9/F,Valiant Ind. Ctr.,2-12 Au Pui Wan St.,Fotan,Shatin,N.T.,Hong Kong",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "000F66": {
        "oui_hex": "00-0F-66",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "24374C": {
        "oui_hex": "24-37-4C",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "188B9D": {
        "oui_hex": "18-8B-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E4AA5D": {
        "oui_hex": "E4-AA-5D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F45FD4": {
        "oui_hex": "F4-5F-D4",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "2CABA4": {
        "oui_hex": "2C-AB-A4",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "00264A": {
        "oui_hex": "00-26-4A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "041E64": {
        "oui_hex": "04-1E-64",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001124": {
        "oui_hex": "00-11-24",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002241": {
        "oui_hex": "00-22-41",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CC537": {
        "oui_hex": "7C-C5-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78CA39": {
        "oui_hex": "78-CA-39",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18E7F4": {
        "oui_hex": "18-E7-F4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70CD60": {
        "oui_hex": "70-CD-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C7B9D": {
        "oui_hex": "8C-7B-9D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D89E3F": {
        "oui_hex": "D8-9E-3F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8C75D": {
        "oui_hex": "B8-C7-5D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C74C2": {
        "oui_hex": "0C-74-C2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "403004": {
        "oui_hex": "40-30-04",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "842999": {
        "oui_hex": "84-29-99",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "74E2F5": {
        "oui_hex": "74-E2-F5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0C97A": {
        "oui_hex": "E0-C9-7A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68A86D": {
        "oui_hex": "68-A8-6D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CC3A1": {
        "oui_hex": "7C-C3-A1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7073CB": {
        "oui_hex": "70-73-CB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90840D": {
        "oui_hex": "90-84-0D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E80688": {
        "oui_hex": "E8-06-88",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "EC852F": {
        "oui_hex": "EC-85-2F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00F4B9": {
        "oui_hex": "00-F4-B9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C95AE": {
        "oui_hex": "5C-95-AE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9803D8": {
        "oui_hex": "98-03-D8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60C547": {
        "oui_hex": "60-C5-47",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "685B35": {
        "oui_hex": "68-5B-35",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2CB43A": {
        "oui_hex": "2C-B4-3A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "689C70": {
        "oui_hex": "68-9C-70",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "380F4A": {
        "oui_hex": "38-0F-4A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3010E4": {
        "oui_hex": "30-10-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A886DD": {
        "oui_hex": "A8-86-DD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "444C0C": {
        "oui_hex": "44-4C-0C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B4F0AB": {
        "oui_hex": "B4-F0-AB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80929F": {
        "oui_hex": "80-92-9F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C04EB": {
        "oui_hex": "9C-04-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C969D": {
        "oui_hex": "5C-96-9D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "609217": {
        "oui_hex": "60-92-17",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84B153": {
        "oui_hex": "84-B1-53",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E06678": {
        "oui_hex": "E0-66-78",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48D705": {
        "oui_hex": "48-D7-05",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "041552": {
        "oui_hex": "04-15-52",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CC785F": {
        "oui_hex": "CC-78-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88CB87": {
        "oui_hex": "88-CB-87",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0C1F1": {
        "oui_hex": "F0-C1-F1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "843835": {
        "oui_hex": "84-38-35",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C006D": {
        "oui_hex": "8C-00-6D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A8968A": {
        "oui_hex": "A8-96-8A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F41BA1": {
        "oui_hex": "F4-1B-A1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60D9C7": {
        "oui_hex": "60-D9-C7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CAB8E": {
        "oui_hex": "3C-AB-8E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F82793": {
        "oui_hex": "F8-27-93",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "907240": {
        "oui_hex": "90-72-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "908D6C": {
        "oui_hex": "90-8D-6C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8098A": {
        "oui_hex": "B8-09-8A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C7C5F": {
        "oui_hex": "4C-7C-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68644B": {
        "oui_hex": "68-64-4B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C81EE7": {
        "oui_hex": "C8-1E-E7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A43135": {
        "oui_hex": "A4-31-35",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68D93C": {
        "oui_hex": "68-D9-3C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00F76F": {
        "oui_hex": "00-F7-6F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C88550": {
        "oui_hex": "C8-85-50",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7014A6": {
        "oui_hex": "70-14-A6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "985AEB": {
        "oui_hex": "98-5A-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78D75F": {
        "oui_hex": "78-D7-5F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E0B52D": {
        "oui_hex": "E0-B5-2D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C94F8": {
        "oui_hex": "6C-94-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0CECD": {
        "oui_hex": "C0-CE-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F44B2A": {
        "oui_hex": "F4-4B-2A",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "746F19": {
        "oui_hex": "74-6F-19",
        "organization": "ICARVISIONS (SHENZHEN) TECHNOLOGY CO., LTD.",
        "address_1": "6F-1 ,Block D,Building 2#, Hongwan XinCun Ming JinHai Industry Area, Gushu Community, Xixiang Street, BaoAn District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "2CAE2B": {
        "oui_hex": "2C-AE-2B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C4ADF1": {
        "oui_hex": "C4-AD-F1",
        "organization": "GOPEACE Inc.",
        "address_1": "Woolim Bldg B-916, 14 Sagimakgol-ro 45beon-gil, Jungwon-gu",
        "address_2": "Seongnam  Gyeonggi  13209",
        "country": "KR"
    },
    "58FC73": {
        "oui_hex": "58-FC-73",
        "organization": "Arria Live Media, Inc.",
        "address_1": "2388 NE Lindsey Drive",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "0C1A10": {
        "oui_hex": "0C-1A-10",
        "organization": "Acoustic Stream",
        "address_1": "3213 W Wheeler Street",
        "address_2": "Seattle  WA  98199",
        "country": "US"
    },
    "C4EF70": {
        "oui_hex": "C4-EF-70",
        "organization": "Home Skinovations",
        "address_1": "Tavor building POB 533",
        "address_2": "Yokneam  Israel  2069206",
        "country": "IL"
    },
    "5CE3B6": {
        "oui_hex": "5C-E3-B6",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "7C5A67": {
        "oui_hex": "7C-5A-67",
        "organization": "JNC Systems, Inc.",
        "address_1": "#611, Gyeonggi Venture Yeonsung University",
        "address_2": "Anyang-si  Gyeonggi-do  430731",
        "country": "KR"
    },
    "A0F9E0": {
        "oui_hex": "A0-F9-E0",
        "organization": "VIVATEL COMPANY LIMITED",
        "address_1": "36/F,Tower Two",
        "address_2": "Causeway Bay  Causeway Bay  999077",
        "country": "HK"
    },
    "C869CD": {
        "oui_hex": "C8-69-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A4B805": {
        "oui_hex": "A4-B8-05",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90C99B": {
        "oui_hex": "90-C9-9B",
        "organization": "Tesorion Nederland B.V.",
        "address_1": "Auke Vleerstraat 6-D",
        "address_2": "Enschede    7521 PG",
        "country": "NL"
    },
    "5CADCF": {
        "oui_hex": "5C-AD-CF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "080A4E": {
        "oui_hex": "08-0A-4E",
        "organization": "Planet Bingo® — 3rd Rock Gaming®",
        "address_1": "75190 Gerald Ford Dr.",
        "address_2": "Palm Desert  CA  92211",
        "country": "US"
    },
    "B49D0B": {
        "oui_hex": "B4-9D-0B",
        "organization": "BQ",
        "address_1": "Sofia, 10",
        "address_2": "Las Rozas de Madrid  Madrid  28230",
        "country": "ES"
    },
    "3C8CF8": {
        "oui_hex": "3C-8C-F8",
        "organization": "TRENDnet, Inc.",
        "address_1": "20675 Manhattan Place",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "E81363": {
        "oui_hex": "E8-13-63",
        "organization": "Comstock RD, Inc.",
        "address_1": "4415 Mason St",
        "address_2": "Ashton  ID  83406",
        "country": "US"
    },
    "741865": {
        "oui_hex": "74-18-65",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F NO.1555 Kongjiang RD",
        "address_2": "  Shanghai  200092",
        "country": "CN"
    },
    "BC6C21": {
        "oui_hex": "BC-6C-21",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F8C372": {
        "oui_hex": "F8-C3-72",
        "organization": "TSUZUKI DENKI",
        "address_1": "shinbashi 6-19-15",
        "address_2": "mainato-ku  tokyo-to  105-8665",
        "country": "JP"
    },
    "D47208": {
        "oui_hex": "D4-72-08",
        "organization": "Bragi GmbH",
        "address_1": "Herzog-Heinrich-Strasse 20",
        "address_2": "Munich  Bavaria  80336",
        "country": "DE"
    },
    "A87285": {
        "oui_hex": "A8-72-85",
        "organization": "IDT, INC.",
        "address_1": "6024 SILVER CREEK VALLEY RD",
        "address_2": "SAN JOSE  CA  95138",
        "country": "US"
    },
    "780541": {
        "oui_hex": "78-05-41",
        "organization": "Queclink Wireless Solutions Co., Ltd",
        "address_1": "Room 501, Building 9, No.99 Tianzhou Road",
        "address_2": "shanghai  shanghai  200233",
        "country": "CN"
    },
    "044169": {
        "oui_hex": "04-41-69",
        "organization": "GoPro",
        "address_1": "3000 Clearview Way",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "C02DEE": {
        "oui_hex": "C0-2D-EE",
        "organization": "Cuff",
        "address_1": "232 Townsend St",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "6CEBB2": {
        "oui_hex": "6C-EB-B2",
        "organization": "Dongguan Sen DongLv Electronics Co.,Ltd",
        "address_1": "Nanjiang RD 111st,Daning",
        "address_2": "Dongguan  Guangdong  523930",
        "country": ""
    },
    "3C7A8A": {
        "oui_hex": "3C-7A-8A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F40E22": {
        "oui_hex": "F4-0E-22",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "881B99": {
        "oui_hex": "88-1B-99",
        "organization": "SHENZHEN XIN FEI JIA ELECTRONIC CO. LTD.",
        "address_1": "#4 BULIDING, HIGH TECH INDUSTRIAL PARK, HE PING COMMUNITY",
        "address_2": "GUANGDONG  N/A  518000",
        "country": "CN"
    },
    "544E90": {
        "oui_hex": "54-4E-90",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A4A6A9": {
        "oui_hex": "A4-A6-A9",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "8C10D4": {
        "oui_hex": "8C-10-D4",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "F898B9": {
        "oui_hex": "F8-98-B9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5CB559": {
        "oui_hex": "5C-B5-59",
        "organization": "CNEX Labs",
        "address_1": "2880 Stevens Creek Blvd",
        "address_2": "San Jose  CA  95128",
        "country": "US"
    },
    "B83A9D": {
        "oui_hex": "B8-3A-9D",
        "organization": "Alarm.com",
        "address_1": "8281 Greensboro Dr., Suite 100",
        "address_2": "Tysons  VA   22102",
        "country": "US"
    },
    "6858C5": {
        "oui_hex": "68-58-C5",
        "organization": "ZF TRW Automotive",
        "address_1": "​12001 Tech Center Drive",
        "address_2": "Livonia  MI  48150",
        "country": "US"
    },
    "C01173": {
        "oui_hex": "C0-11-73",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7853F2": {
        "oui_hex": "78-53-F2",
        "organization": "ROXTON Ltd.",
        "address_1": "15 Ostapovsky proezd",
        "address_2": "Moscow  Moscow  109316",
        "country": "RU"
    },
    "BCE63F": {
        "oui_hex": "BC-E6-3F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7C9122": {
        "oui_hex": "7C-91-22",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "ACBC32": {
        "oui_hex": "AC-BC-32",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9023EC": {
        "oui_hex": "90-23-EC",
        "organization": "Availink, Inc.",
        "address_1": "Scotia Centre P.O. Box 268GT,Grand Cayman, Cayman Islands",
        "address_2": "Grand Cayman  Grand Cayman  999159",
        "country": "KY"
    },
    "441CA8": {
        "oui_hex": "44-1C-A8",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B4293D": {
        "oui_hex": "B4-29-3D",
        "organization": "Shenzhen Urovo Technology Co.,Ltd.",
        "address_1": "A701-710, Zondy Cyber Building, Keyuan South Road,",
        "address_2": "Nanshan District, Shenzhen  Guangzhou  518057",
        "country": "CN"
    },
    "54FF82": {
        "oui_hex": "54-FF-82",
        "organization": "Davit Solution co.",
        "address_1": "103-301,Geudaegapremier,21 Deagyeong-Daero 1484beon-Gil",
        "address_2": "Suwon-Si  Gyeonggi-Do  KS002",
        "country": "KR"
    },
    "50DF95": {
        "oui_hex": "50-DF-95",
        "organization": "Lytx",
        "address_1": "9785 Towne Centre Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "9CA69D": {
        "oui_hex": "9C-A6-9D",
        "organization": "Whaley Technology Co.Ltd",
        "address_1": "Floor 3, Building E, No666 Shengxia Road",
        "address_2": "  Shanghai  201203",
        "country": "CN"
    },
    "5853C0": {
        "oui_hex": "58-53-C0",
        "organization": "Beijing Guang Runtong Technology Development Company co.,Ltd",
        "address_1": "Beijing city Haidian District North Third Ring Road 48, Beijing science and Technology Exhibition Center 1 building B block, room 18H",
        "address_2": "Beijing  Bejing  100000",
        "country": "CN"
    },
    "2CA539": {
        "oui_hex": "2C-A5-39",
        "organization": "Parallel Wireless, Inc",
        "address_1": "1 Tara Blvd",
        "address_2": "Nashua  NH  03062",
        "country": "US"
    },
    "CC794A": {
        "oui_hex": "CC-79-4A",
        "organization": "BLU Products Inc.",
        "address_1": "Tower 4, Excellence Century Center",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F4E926": {
        "oui_hex": "F4-E9-26",
        "organization": "Tianjin Zanpu Technology Inc.",
        "address_1": "3F Haiyi International Center, Huayuan Industrial Park, Tianjin",
        "address_2": "Tianjin  Tianjin  300384",
        "country": "CN"
    },
    "906F18": {
        "oui_hex": "90-6F-18",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "98CB27": {
        "oui_hex": "98-CB-27",
        "organization": "Galore Networks Pvt. Ltd.",
        "address_1": "#D1104, Salarpuria Serenity, 41A,",
        "address_2": "Bangalore  Karnataka  560068",
        "country": "IN"
    },
    "E8F2E2": {
        "oui_hex": "E8-F2-E2",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "247260": {
        "oui_hex": "24-72-60",
        "organization": "IOTTECH Corp",
        "address_1": "4F.-1, No.55, Dongguang Rd., East Dist., Hsinchu City 300, TAIWAN ,REPUBLIC OF CHINA",
        "address_2": "Hsinchu  TAIWAN  300",
        "country": "TW"
    },
    "245BF0": {
        "oui_hex": "24-5B-F0",
        "organization": "Liteon, Inc.",
        "address_1": "3001 Summit Avenue, Suite 400",
        "address_2": "Plano  Tx  75074",
        "country": "US"
    },
    "E855B4": {
        "oui_hex": "E8-55-B4",
        "organization": "SAI Technology Inc.",
        "address_1": "2376 Walsh Avenue",
        "address_2": "Santa Clara  California  95051",
        "country": "US"
    },
    "340CED": {
        "oui_hex": "34-0C-ED",
        "organization": "Moduel AB",
        "address_1": "Hudiksvallsgatan 8",
        "address_2": "Stockholm  Stockholm  11330",
        "country": "SE"
    },
    "2827BF": {
        "oui_hex": "28-27-BF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "94D859": {
        "oui_hex": "94-D8-59",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "2CFCE4": {
        "oui_hex": "2C-FC-E4",
        "organization": "CTEK Sweden AB",
        "address_1": "Rostugnsvägen 3",
        "address_2": "Vikmanshyttan  Dalarna  SE-776 70",
        "country": "SE"
    },
    "C0EE40": {
        "oui_hex": "C0-EE-40",
        "organization": "Laird Technologies",
        "address_1": "50 South Main St",
        "address_2": "Akron  Ohio  44308",
        "country": "US"
    },
    "F4B8A7": {
        "oui_hex": "F4-B8-A7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "300C23": {
        "oui_hex": "30-0C-23",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C0B713": {
        "oui_hex": "C0-B7-13",
        "organization": "Beijing Xiaoyuer Technology Co. Ltd.",
        "address_1": "No.5 Guangshunbei Rd. Rm# B129",
        "address_2": "Beijing  Beijing  100102",
        "country": "CN"
    },
    "1005B1": {
        "oui_hex": "10-05-B1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "20635F": {
        "oui_hex": "20-63-5F",
        "organization": "Abeeway",
        "address_1": "29 chemin du vieux chêne",
        "address_2": "meylan  Isere  38240",
        "country": "FR"
    },
    "083A5C": {
        "oui_hex": "08-3A-5C",
        "organization": "Junilab, Inc.",
        "address_1": "#205 107 Gyounggyo-Ro, Yeongtong-Gu, Suwon",
        "address_2": "Suwon  Gyeonggi-Do  443-766",
        "country": "KR"
    },
    "B8B3DC": {
        "oui_hex": "B8-B3-DC",
        "organization": "DEREK (SHAOGUAN) LIMITED",
        "address_1": "Gaojiling, Taiping Town,",
        "address_2": "Shao Guan  Guang Dong  512500",
        "country": "CN"
    },
    "702A7D": {
        "oui_hex": "70-2A-7D",
        "organization": "EpSpot AB",
        "address_1": "Aluddsparken 7D",
        "address_2": "  Stockholm  11265",
        "country": "SE"
    },
    "4CAE31": {
        "oui_hex": "4C-AE-31",
        "organization": "ShengHai Electronics (Shenzhen) Ltd",
        "address_1": "Block 17&18,Hui Ming Ying Industry,YanChuan,SongGang",
        "address_2": "Shenzhen  Guangdong  518105",
        "country": "CN"
    },
    "188EF9": {
        "oui_hex": "18-8E-F9",
        "organization": "G2C Co. Ltd.",
        "address_1": "1004,1591-9, K-Center Kwanyang Dong",
        "address_2": "Anyang Si  Kyeonggido  431-815",
        "country": "KR"
    },
    "44F436": {
        "oui_hex": "44-F4-36",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C47D46": {
        "oui_hex": "C4-7D-46",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "185D9A": {
        "oui_hex": "18-5D-9A",
        "organization": "BobjGear LLC",
        "address_1": "4327 S Highway 27 # 504",
        "address_2": "Clermont  Florida  34711",
        "country": "US"
    },
    "F4E9D4": {
        "oui_hex": "F4-E9-D4",
        "organization": "QLogic Corporation",
        "address_1": "26650 Aliso Viejo Parkway",
        "address_2": "Aliso Viejo  California",
        "country": "US"
    },
    "4CB76D": {
        "oui_hex": "4C-B7-6D",
        "organization": "Novi Security",
        "address_1": "1434 E 820 N",
        "address_2": "Orem  UT  84097",
        "country": "US"
    },
    "6CE01E": {
        "oui_hex": "6C-E0-1E",
        "organization": "Modcam AB",
        "address_1": "Bredgatan 4",
        "address_2": "Malmö  Skåne  21130",
        "country": "SE"
    },
    "74852A": {
        "oui_hex": "74-85-2A",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "9CB6D0": {
        "oui_hex": "9C-B6-D0",
        "organization": "Rivet Networks",
        "address_1": "11940 Jollyville Rd",
        "address_2": "Austin  tx  78759",
        "country": "US"
    },
    "40B89A": {
        "oui_hex": "40-B8-9A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "1CB72C": {
        "oui_hex": "1C-B7-2C",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "40B837": {
        "oui_hex": "40-B8-37",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "4CEEB0": {
        "oui_hex": "4C-EE-B0",
        "organization": "SHC Netzwerktechnik GmbH",
        "address_1": "Ludwigstrasse 33-37",
        "address_2": "Frankfurt am Main  Hessen  60327",
        "country": "DE"
    },
    "800184": {
        "oui_hex": "80-01-84",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "44C69B": {
        "oui_hex": "44-C6-9B",
        "organization": "Wuhan Feng Tian Information Network CO.,LTD",
        "address_1": "Room 1002,10th Floor,Oversea talent Building A,",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "FCE33C": {
        "oui_hex": "FC-E3-3C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C02567": {
        "oui_hex": "C0-25-67",
        "organization": "Nexxt Solutions",
        "address_1": "3505 NW 107TH AVENUE",
        "address_2": "MIAMI  FLORIDA  33178",
        "country": "US"
    },
    "A8827F": {
        "oui_hex": "A8-82-7F",
        "organization": "CIBN Oriental Network(Beijing) CO.,Ltd",
        "address_1": "Floor 18B,Block B(International Resources Building),No.18B(Wanda Plaza),Shijingshan Road,Shijingshan,Beijing(100043)",
        "address_2": "Beijing  Beijing  100043",
        "country": "CN"
    },
    "D048F3": {
        "oui_hex": "D0-48-F3",
        "organization": "DATTUS Inc",
        "address_1": "3000 Kent Ave",
        "address_2": "W Lafayette  IN  47906",
        "country": "US"
    },
    "B8C3BF": {
        "oui_hex": "B8-C3-BF",
        "organization": "Henan Chengshi NetWork Technology Co.，Ltd",
        "address_1": "Ruhe Road South，Kunlun Road West，Zhongyuan District，Zhengzhou，Henan，P.R.China，450007",
        "address_2": "Zhengzhou  Henan  450007",
        "country": "CN"
    },
    "44962B": {
        "oui_hex": "44-96-2B",
        "organization": "Aidon Oy",
        "address_1": "Piippukatu 11",
        "address_2": "Jyvaskyla  Jyvaskyla  40100",
        "country": "FI"
    },
    "E076D0": {
        "oui_hex": "E0-76-D0",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road",
        "address_2": "Hsinchu  Hsinchu  30352",
        "country": "TW"
    },
    "B008BF": {
        "oui_hex": "B0-08-BF",
        "organization": "Vital Connect, Inc.",
        "address_1": "900 E HAMILTON AVE STE 500",
        "address_2": "CAMPBELL  CA  95008-0667",
        "country": "US"
    },
    "D4522A": {
        "oui_hex": "D4-52-2A",
        "organization": "TangoWiFi.com",
        "address_1": "TangoWiFi Team",
        "address_2": "Beijing  Beijing  100022",
        "country": "CN"
    },
    "E807BF": {
        "oui_hex": "E8-07-BF",
        "organization": "SHENZHEN BOOMTECH INDUSTRY CO.,LTD",
        "address_1": "Floor 6 East, Bldg 6, Yusheng Industrial Area, Xixiang, Bao'an District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "84F129": {
        "oui_hex": "84-F1-29",
        "organization": "Metrascale Inc.",
        "address_1": "400 Liberty Ave.",
        "address_2": "Brooklyn  NY  11207",
        "country": "US"
    },
    "B89ACD": {
        "oui_hex": "B8-9A-CD",
        "organization": "ELITE OPTOELECTRONIC(ASIA)CO.,LTD",
        "address_1": "A9 jin Fu 1 Road,Tangchun lndustrial zone,Liaobu Town,Dongguan City,Guangdong Province",
        "address_2": "Liaobu  dongguan /guangdong  523400",
        "country": "CN"
    },
    "D468BA": {
        "oui_hex": "D4-68-BA",
        "organization": "Shenzhen Sundray Technologies Company Limited",
        "address_1": "6th Floor,Block A1, Nanshan iPark,",
        "address_2": "Nanshan District, Shenzhen 518055  Guangdong",
        "country": "CN"
    },
    "086266": {
        "oui_hex": "08-62-66",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "9C3066": {
        "oui_hex": "9C-30-66",
        "organization": "RWE Effizienz GmbH",
        "address_1": "Flamingoweg 1",
        "address_2": "Dortmund  NRW  44139",
        "country": "DE"
    },
    "18BDAD": {
        "oui_hex": "18-BD-AD",
        "organization": "L-TECH CORPORATION",
        "address_1": "201, Moonbon-dong",
        "address_2": "Ilsandong-gu  Gyeonggi-do  410-560",
        "country": "KR"
    },
    "60E6BC": {
        "oui_hex": "60-E6-BC",
        "organization": "Sino-Telecom Technology Co.,Ltd.",
        "address_1": "6F, Building 2, No.115, Lane 1276 Nanle Rd",
        "address_2": "    201613",
        "country": "CN"
    },
    "C8C50E": {
        "oui_hex": "C8-C5-0E",
        "organization": "Shenzhen Primestone Network Technologies.Co., Ltd.",
        "address_1": "Room 705,Complex Building, Tsinghua Hi-Tech Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D06A1F": {
        "oui_hex": "D0-6A-1F",
        "organization": "BSE CO.,LTD.",
        "address_1": "626-3, Gozan-dong, Namdong-ku",
        "address_2": "Incheon, 405-817",
        "country": "KR"
    },
    "700136": {
        "oui_hex": "70-01-36",
        "organization": "FATEK Automation Corporation",
        "address_1": "5F., NO.300, SEC. 1, NEIHU RD",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "FCA22A": {
        "oui_hex": "FC-A2-2A",
        "organization": "PT. Callysta Multi Engineering",
        "address_1": "Jl. Taman Cibeunying No. 2",
        "address_2": "Bandung  Jawa Barat  40114",
        "country": "ID"
    },
    "A45602": {
        "oui_hex": "A4-56-02",
        "organization": "fenglian Technology Co.,Ltd.",
        "address_1": "302 R D Building Oriental Cyberport HighTech Industrial Park Nanshan Shenzhen China",
        "address_2": "  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "94E2FD": {
        "oui_hex": "94-E2-FD",
        "organization": "Boge Kompressoren OTTO Boge GmbH & Co. KG",
        "address_1": "Otto Boge Str. 1-7",
        "address_2": "Bielefeld  Westfalia  33739",
        "country": "DE"
    },
    "F01E34": {
        "oui_hex": "F0-1E-34",
        "organization": "ORICO Technologies Co., Ltd",
        "address_1": "F-9, Block14A, Zhonghaixin Science &Technology Zone",
        "address_2": "ShenZhen  Guangdong  518116",
        "country": "CN"
    },
    "DCE026": {
        "oui_hex": "DC-E0-26",
        "organization": "Patrol Tag, Inc",
        "address_1": "2800 Western Ave",
        "address_2": "Seattle  WA  98121",
        "country": "US"
    },
    "B40566": {
        "oui_hex": "B4-05-66",
        "organization": "SP Best Corporation Co., LTD.",
        "address_1": "555/25 B-Avenue, Sukhaphibal 5 Road",
        "address_2": "Saimai  Bangkok  10220",
        "country": "TH"
    },
    "1CC72D": {
        "oui_hex": "1C-C7-2D",
        "organization": "Shenzhen Huapu Digital CO.,Ltd",
        "address_1": "R2305 Malata Technology Building,NO.9998 Shennan Boulevard, Shenzhen,P.R.China 518057",
        "address_2": "Shenzhen  Guangzhou  518057",
        "country": "CN"
    },
    "A89008": {
        "oui_hex": "A8-90-08",
        "organization": "Beijing Yuecheng Technology Co. Ltd.",
        "address_1": "Room 1601, Floor 16",
        "address_2": "Beijing  Beijing  100000",
        "country": "CN"
    },
    "183864": {
        "oui_hex": "18-38-64",
        "organization": "CAP-TECH INTERNATIONAL CO., LTD.",
        "address_1": " Rm. 6, 4F., No.120, Qiaohe Rd., Zhonghe Dist",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "6CF5E8": {
        "oui_hex": "6C-F5-E8",
        "organization": "Mooredoll Inc.",
        "address_1": "5F,No.50,Ln.316,Ruiguan Rd.,Neihu Dist.,Taipei 114, Taiwan",
        "address_2": "Taipei  Neihu  114",
        "country": "TW"
    },
    "8CBFA6": {
        "oui_hex": "8C-BF-A6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C8A823": {
        "oui_hex": "C8-A8-23",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0C559": {
        "oui_hex": "B0-C5-59",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F42C56": {
        "oui_hex": "F4-2C-56",
        "organization": "SENOR TECH CO LTD",
        "address_1": "No.165, Kangning St",
        "address_2": "New Taipei City  Taiwan  221",
        "country": "TW"
    },
    "FCDC4A": {
        "oui_hex": "FC-DC-4A",
        "organization": "G-Wearables Corp.",
        "address_1": "901, S&CTBuilding, No.9 Zhongguancun South Avenue",
        "address_2": "Beijing  Beijing  100081",
        "country": "CN"
    },
    "1C14B3": {
        "oui_hex": "1C-14-B3",
        "organization": "Airwire Technologies",
        "address_1": "9670 Gateway Drive, Suite 250",
        "address_2": "Reno  NV  89521",
        "country": "US"
    },
    "A48CDB": {
        "oui_hex": "A4-8C-DB",
        "organization": "Lenovo",
        "address_1": "1009 Think Place",
        "address_2": "Morrisvilee  NC  27560",
        "country": "US"
    },
    "D85DE2": {
        "oui_hex": "D8-5D-E2",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "3C912B": {
        "oui_hex": "3C-91-2B",
        "organization": "Vexata Inc",
        "address_1": "1735 Technology Dr Suite 520",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "346C0F": {
        "oui_hex": "34-6C-0F",
        "organization": "Pramod Telecom Pvt. Ltd",
        "address_1": "Plot No. 6-B, Malviya Nagar,",
        "address_2": "Lucknow  Uttar Pradesh  226004",
        "country": "IN"
    },
    "BC1485": {
        "oui_hex": "BC-14-85",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "9C6C15": {
        "oui_hex": "9C-6C-15",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "445ECD": {
        "oui_hex": "44-5E-CD",
        "organization": "Razer Inc",
        "address_1": "2035 Corte Del Nogal",
        "address_2": "Carlsbad  CA  92011",
        "country": "US"
    },
    "4CA928": {
        "oui_hex": "4C-A9-28",
        "organization": "Insensi",
        "address_1": "2025 Broadway, 2CD",
        "address_2": "New York City  New York  10023",
        "country": "US"
    },
    "E8447E": {
        "oui_hex": "E8-44-7E",
        "organization": "Bitdefender SRL",
        "address_1": "24 Delea Veche St.",
        "address_2": "Bucharest  Romania  024102",
        "country": "RO"
    },
    "C0335E": {
        "oui_hex": "C0-33-5E",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "B0E03C": {
        "oui_hex": "B0-E0-3C",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "B0495F": {
        "oui_hex": "B0-49-5F",
        "organization": "OMRON HEALTHCARE Co., Ltd.",
        "address_1": "53, Kunotsubo, Terado-cho",
        "address_2": "Muko  Kyoto  6170002",
        "country": "JP"
    },
    "60F189": {
        "oui_hex": "60-F1-89",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "742EFC": {
        "oui_hex": "74-2E-FC",
        "organization": "DirectPacket Research, Inc,",
        "address_1": "909 Lake Carolyn Parkway",
        "address_2": "Irving  Texas  75039",
        "country": "US"
    },
    "84CFBF": {
        "oui_hex": "84-CF-BF",
        "organization": "Fairphone",
        "address_1": "Piet Heinkade 181A",
        "address_2": "Amsterdam  North Holland  1019HC",
        "country": "NL"
    },
    "ACD1B8": {
        "oui_hex": "AC-D1-B8",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A0C2DE": {
        "oui_hex": "A0-C2-DE",
        "organization": "Costar Video Systems",
        "address_1": "101 Wrangler, Suite 201",
        "address_2": "Coppell  Texas  75019",
        "country": "US"
    },
    "88E161": {
        "oui_hex": "88-E1-61",
        "organization": "Art Beijing Science and Technology Development Co., Ltd.",
        "address_1": "Room 210,Building 1#, No. 27 Qinghe Longgang Rd., Haidian District, Beijing,100192,China",
        "address_2": "Beijing  Beijing  100192",
        "country": "CN"
    },
    "00A509": {
        "oui_hex": "00-A5-09",
        "organization": "WigWag Inc.",
        "address_1": "4009 banister lane",
        "address_2": "austin  texas  78704",
        "country": "US"
    },
    "7491BD": {
        "oui_hex": "74-91-BD",
        "organization": "Four systems Co.,Ltd.",
        "address_1": "608-608/7 Ramintra Road Kannayao",
        "address_2": "Bangkok  Bangkok  10230",
        "country": "TH"
    },
    "F0FE6B": {
        "oui_hex": "F0-FE-6B",
        "organization": "Shanghai High-Flying Electronics Technology Co., Ltd",
        "address_1": "Room 1002 ,#1Building,No.3000 Longdong Avenue,Pudong District,Shanghai,China",
        "address_2": "shanghai  shanghai  201203",
        "country": "CN"
    },
    "3CAE69": {
        "oui_hex": "3C-AE-69",
        "organization": "ESA Elektroschaltanlagen Grimma GmbH",
        "address_1": "Broner Ring 30",
        "address_2": "Grimma  Saxony  04668",
        "country": "DE"
    },
    "D43266": {
        "oui_hex": "D4-32-66",
        "organization": "Fike Corporation",
        "address_1": "704 SW 10th Street",
        "address_2": "Blue Springs  MO  64015",
        "country": "US"
    },
    "900CB4": {
        "oui_hex": "90-0C-B4",
        "organization": "Alinket Electronic Technology Co., Ltd",
        "address_1": "412 Guilin Rd. 3F, Xuhui District",
        "address_2": "Shanghai  Shanghai  201235",
        "country": "CN"
    },
    "48C093": {
        "oui_hex": "48-C0-93",
        "organization": "Xirrus, Inc.",
        "address_1": "2101 Corporate Center Dr.",
        "address_2": "Thousand Oaks  CA  91320",
        "country": "US"
    },
    "DC0914": {
        "oui_hex": "DC-09-14",
        "organization": "Talk-A-Phone Co.",
        "address_1": "7530 N. Natchez Ave.",
        "address_2": "Niles  IL  60714",
        "country": "US"
    },
    "D0929E": {
        "oui_hex": "D0-92-9E",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "BC52B4": {
        "oui_hex": "BC-52-B4",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "9405B6": {
        "oui_hex": "94-05-B6",
        "organization": "Liling FullRiver Electronics & Technology Ltd",
        "address_1": "FullRiver Industrial Area Economic Development Zone",
        "address_2": "HuNan Province    412200",
        "country": "CN"
    },
    "00F3DB": {
        "oui_hex": "00-F3-DB",
        "organization": "WOO Sports",
        "address_1": "11 Elkins St.",
        "address_2": "BOSTON  Massachusetts  02127",
        "country": "US"
    },
    "78312B": {
        "oui_hex": "78-31-2B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C81B6B": {
        "oui_hex": "C8-1B-6B",
        "organization": "Innova Security",
        "address_1": "Av. General Ataliba Leonel, 1205",
        "address_2": "Sao Paulo  Sao Paulo  02033000",
        "country": "BR"
    },
    "3438AF": {
        "oui_hex": "34-38-AF",
        "organization": "Inlab Software GmbH",
        "address_1": "Josef-Wuerth-Str. 3",
        "address_2": "Gruenwald  Bavaria  82031",
        "country": "DE"
    },
    "B4A828": {
        "oui_hex": "B4-A8-28",
        "organization": "Shenzhen Concox Information Technology Co., Ltd",
        "address_1": "Floor 4th, Building B, Gaoxinqi Industrial Park, Liuxian 1st Road, district 67, Bao’an, Shenzhen, Guangdong,China",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "00A2F5": {
        "oui_hex": "00-A2-F5",
        "organization": "Guangzhou Yuanyun Network Technology Co.,Ltd",
        "address_1": "31/F,183 TianHe Bei Rd, Metro Plz",
        "address_2": "GuangZhou  GuangDong  510630",
        "country": "CN"
    },
    "1008B1": {
        "oui_hex": "10-08-B1",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "E48C0F": {
        "oui_hex": "E4-8C-0F",
        "organization": "Discovery Insure",
        "address_1": "3 Alice lane",
        "address_2": "Sandton  Gauteng  2196",
        "country": "ZA"
    },
    "E42354": {
        "oui_hex": "E4-23-54",
        "organization": "SHENZHEN FUZHI SOFTWARE TECHNOLOGY CO.,LTD",
        "address_1": "4/F,Fuxing Bldg,Binlang Road,Futian Free Trade Zone,SHENZHEN.CHINA",
        "address_2": "SHENZHEN  Guang Dong  518038",
        "country": "CN"
    },
    "94BF95": {
        "oui_hex": "94-BF-95",
        "organization": "Shenzhen Coship Electronics Co., Ltd",
        "address_1": "Rainbow Bldg., North, Hi-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "44CE7D": {
        "oui_hex": "44-CE-7D",
        "organization": "SFR",
        "address_1": "5 RUE NOEL PONS",
        "address_2": "NANTERRE    92000",
        "country": "FR"
    },
    "344DEA": {
        "oui_hex": "34-4D-EA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4C16F1": {
        "oui_hex": "4C-16-F1",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "10FACE": {
        "oui_hex": "10-FA-CE",
        "organization": "Reacheng Communication Technology Co.,Ltd",
        "address_1": "Building No.5-401,",
        "address_2": "Pu Dong New District,  Shanghai  201203",
        "country": "CN"
    },
    "9470D2": {
        "oui_hex": "94-70-D2",
        "organization": "WINFIRM TECHNOLOGY",
        "address_1": "2-1015 Lotte IT Castle",
        "address_2": "  Seoul  153-768",
        "country": "KR"
    },
    "A44AD3": {
        "oui_hex": "A4-4A-D3",
        "organization": "ST Electronics(Shanghai) Co.,Ltd",
        "address_1": "Floors 1&3, No.6 Building, No.1151 Lianxi Road",
        "address_2": "Shanghai  Shanghai  201204",
        "country": "CN"
    },
    "7CB177": {
        "oui_hex": "7C-B1-77",
        "organization": "Satelco AG",
        "address_1": "Seestrasse 241",
        "address_2": "Au / Waedenswil  ZH  8804",
        "country": "CH"
    },
    "CC3080": {
        "oui_hex": "CC-30-80",
        "organization": "VAIO Corporation",
        "address_1": "5432 Toyoshina",
        "address_2": "Azumino  Nagano  399-8282",
        "country": "JP"
    },
    "587BE9": {
        "oui_hex": "58-7B-E9",
        "organization": "AirPro Technology India Pvt. Ltd",
        "address_1": "D30, Gautam Marg,",
        "address_2": "Jaipur  Rajasthan  302018",
        "country": "IN"
    },
    "8C18D9": {
        "oui_hex": "8C-18-D9",
        "organization": "Shenzhen RF Technology Co., Ltd",
        "address_1": "5/F,Building 4,Baokun Science and Technology Industial Park",
        "address_2": "Baoan  Guangdong  518100",
        "country": "CN"
    },
    "C4BD6A": {
        "oui_hex": "C4-BD-6A",
        "organization": "SKF GmbH",
        "address_1": "Gunnar-Wester-Strasse 12",
        "address_2": "Schweinfurt  DE  DE-97421",
        "country": "DE"
    },
    "C401CE": {
        "oui_hex": "C4-01-CE",
        "organization": "PRESITION (2000) CO., LTD.",
        "address_1": "42/6 Moo6",
        "address_2": "Muang  Samutsakorn  74000",
        "country": "TH"
    },
    "187117": {
        "oui_hex": "18-71-17",
        "organization": "eta plus electronic gmbh",
        "address_1": "Lauterstr. 29",
        "address_2": "Nuertingen  BW  72622",
        "country": "DE"
    },
    "EC0EC4": {
        "oui_hex": "EC-0E-C4",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "30FAB7": {
        "oui_hex": "30-FA-B7",
        "organization": "Tunai Creative",
        "address_1": "12F, No.221, Sec.4, Zongxiao E. Rd, Taipei 106, Taiwan",
        "address_2": "TAIPEI  TAIPEI  10690",
        "country": "TW"
    },
    "0809B6": {
        "oui_hex": "08-09-B6",
        "organization": "Masimo Corp",
        "address_1": "40 Parker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "4CF5A0": {
        "oui_hex": "4C-F5-A0",
        "organization": "Scalable Network Technologies Inc",
        "address_1": "600 Corporate Pointe",
        "address_2": "Culver City  CA  90230",
        "country": "US"
    },
    "D8FB11": {
        "oui_hex": "D8-FB-11",
        "organization": "AXACORE",
        "address_1": "2468 HISTORIC DECATUR RD",
        "address_2": "SAN DIEGO  CA  92106",
        "country": "US"
    },
    "4CE933": {
        "oui_hex": "4C-E9-33",
        "organization": "RailComm, LLC",
        "address_1": "1387 Fairport Road",
        "address_2": "Fairport  New York  14450",
        "country": "US"
    },
    "CCE17F": {
        "oui_hex": "CC-E1-7F",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E4C62B": {
        "oui_hex": "E4-C6-2B",
        "organization": "Airware",
        "address_1": "1045 Bryant St.",
        "address_2": "San Francisco  California  94103",
        "country": "US"
    },
    "EC1D7F": {
        "oui_hex": "EC-1D-7F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "AC3870": {
        "oui_hex": "AC-38-70",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information & Optoelectronics Park,",
        "address_2": "Xiamen  Fujian  361006",
        "country": ""
    },
    "4CBC42": {
        "oui_hex": "4C-BC-42",
        "organization": "Shenzhen Hangsheng Electronics Co.,Ltd.",
        "address_1": "Hangsheng Industrial Area, Fuyuan 1st Road,Heping Village, Fuyong Town,Baoan District",
        "address_2": "Shenzhen City  Guangdong  518103",
        "country": "CN"
    },
    "70F196": {
        "oui_hex": "70-F1-96",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "188219": {
        "oui_hex": "18-82-19",
        "organization": "Alibaba Cloud Computing Ltd.",
        "address_1": "Yuhang District of Hangzhou Wenyi Road, Building 1, No. 969 Xixi Park, Zhejiang Province",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "28A5EE": {
        "oui_hex": "28-A5-EE",
        "organization": "Shenzhen SDGI CATV Co., Ltd",
        "address_1": "2/F, NO, 3, QIONGYU ROAD,",
        "address_2": "shenzhen  Guangdong province  518057",
        "country": "CN"
    },
    "D0A0D6": {
        "oui_hex": "D0-A0-D6",
        "organization": "Chengdu TD Tech Ltd.",
        "address_1": "3-5F,Building 3, No.219 Tian Hua Road 2, Software Park C,High-Tech Zone",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "ECB907": {
        "oui_hex": "EC-B9-07",
        "organization": "CloudGenix Inc",
        "address_1": "2933 Bunker Hill Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "F42833": {
        "oui_hex": "F4-28-33",
        "organization": "MMPC Inc.",
        "address_1": "#F313, KAIST-ICC, 193 Munjiro Yuseong-gu",
        "address_2": "Daejeon  Daejeon  305-732",
        "country": "KR"
    },
    "0C8C8F": {
        "oui_hex": "0C-8C-8F",
        "organization": "Kamo Technology Limited",
        "address_1": "Room 1502, 15/F., Yue Xiu Building,",
        "address_2": "Wanchai  Hong Kong  160-174",
        "country": "CN"
    },
    "A4A4D3": {
        "oui_hex": "A4-A4-D3",
        "organization": "Bluebank Communication Technology Co.Ltd",
        "address_1": "No.13-2.Jiang Ying Road,",
        "address_2": "  Chongqing  401336",
        "country": "CN"
    },
    "A8329A": {
        "oui_hex": "A8-32-9A",
        "organization": "Digicom Futuristic Technologies Ltd.",
        "address_1": "406 Mirror Tower, Modi Road, TST",
        "address_2": "    000086",
        "country": "HK"
    },
    "F4D032": {
        "oui_hex": "F4-D0-32",
        "organization": "Yunnan Ideal Information&Technology.,Ltd",
        "address_1": "The 1st Floor, Building Four ,JingdianMingju,Haiyuanzhong road, High Tech Development Zone,Kunming,YunnanP.R.China",
        "address_2": "Kunming  Yunnan  650106",
        "country": "CN"
    },
    "600292": {
        "oui_hex": "60-02-92",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "B4B859": {
        "oui_hex": "B4-B8-59",
        "organization": "Texa Spa",
        "address_1": "Via I Maggio, 9",
        "address_2": "Monastier di Treviso  Treviso  31050",
        "country": "IT"
    },
    "5CF9F0": {
        "oui_hex": "5C-F9-F0",
        "organization": "Atomos Engineering P/L",
        "address_1": "36 Park St",
        "address_2": "South Melbourne  Victoria  3205",
        "country": "AU"
    },
    "702DD1": {
        "oui_hex": "70-2D-D1",
        "organization": "Newings Communication CO., LTD.",
        "address_1": "12F, Block 1, NO 7866, Humin Rd, Minhang District, Shanghai, China",
        "address_2": "Shanghai  Shanghai  200000",
        "country": "CN"
    },
    "147590": {
        "oui_hex": "14-75-90",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "50BD5F": {
        "oui_hex": "50-BD-5F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "987E46": {
        "oui_hex": "98-7E-46",
        "organization": "Emizon Networks Limited",
        "address_1": "1 Allerton Road",
        "address_2": "Rugby  Warwickshire  CV23 0PA",
        "country": "GB"
    },
    "3C46D8": {
        "oui_hex": "3C-46-D8",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4C83DE": {
        "oui_hex": "4C-83-DE",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "A81374": {
        "oui_hex": "A8-13-74",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo cho",
        "address_2": "Kadoma city  Osaka  571-8504",
        "country": "JP"
    },
    "083D88": {
        "oui_hex": "08-3D-88",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BC4E5D": {
        "oui_hex": "BC-4E-5D",
        "organization": "ZhongMiao Technology Co., Ltd.",
        "address_1": "NO.2009 Lihu Avenue,  WuxiStudioA-A3",
        "address_2": "Wuxi  Jiangsu  214000",
        "country": "CN"
    },
    "3C189F": {
        "oui_hex": "3C-18-9F",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "7C6AC3": {
        "oui_hex": "7C-6A-C3",
        "organization": "GatesAir, Inc",
        "address_1": "5300 Kings Island Drive",
        "address_2": "Mason  Ohio  45040",
        "country": "US"
    },
    "5C5BC2": {
        "oui_hex": "5C-5B-C2",
        "organization": "YIK Corporation",
        "address_1": "B-4F,Pangyo Silicon Park 613",
        "address_2": "Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "30595B": {
        "oui_hex": "30-59-5B",
        "organization": "streamnow AG",
        "address_1": "Brandstrasse 33",
        "address_2": "Schlieren  Zürich  8952",
        "country": "CH"
    },
    "84850A": {
        "oui_hex": "84-85-0A",
        "organization": "Hella Sonnen- und Wetterschutztechnik GmbH",
        "address_1": "Abfaltersbach 125",
        "address_2": "Abfaltersbach  Tirol  9913",
        "country": "AT"
    },
    "08CD9B": {
        "oui_hex": "08-CD-9B",
        "organization": "samtec automotive electronics & software GmbH",
        "address_1": "Saarstrasse 27",
        "address_2": "Filderstadt  Baden-Wuerttemberg  70794",
        "country": "DE"
    },
    "28E6E9": {
        "oui_hex": "28-E6-E9",
        "organization": "SIS Sat Internet Services GmbH",
        "address_1": "Justus-von-Liebig Str. 26",
        "address_2": "Neustadt  Niedersachsen  31535",
        "country": "DE"
    },
    "F4FD2B": {
        "oui_hex": "F4-FD-2B",
        "organization": "ZOYI Company",
        "address_1": "827-66 Yeoksam 1-dong, Second Floor",
        "address_2": "Seoul  Korea  135-935",
        "country": "KR"
    },
    "F4F646": {
        "oui_hex": "F4-F6-46",
        "organization": "Dediprog Technology Co. Ltd.",
        "address_1": "4F,No.7,Lane 143, Xinming Rd.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "300D2A": {
        "oui_hex": "30-0D-2A",
        "organization": "Zhejiang Wellcom Technology Co.,Ltd.",
        "address_1": "Liuhe Road,Binjiang District , Hangzhou",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": ""
    },
    "045C8E": {
        "oui_hex": "04-5C-8E",
        "organization": "gosund GROUP CO.,LTD",
        "address_1": "11/F., FRONT BLOCK, HANG LOK BUILDING",
        "address_2": "SHEUNG WAN, HK    999077",
        "country": "HK"
    },
    "7CC4EF": {
        "oui_hex": "7C-C4-EF",
        "organization": "Devialet",
        "address_1": "126, rue Réaumur",
        "address_2": "Paris  Paris  75002",
        "country": "FR"
    },
    "D85DFB": {
        "oui_hex": "D8-5D-FB",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "DCF110": {
        "oui_hex": "DC-F1-10",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "608F5C": {
        "oui_hex": "60-8F-5C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DC38E1": {
        "oui_hex": "DC-38-E1",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "908C63": {
        "oui_hex": "90-8C-63",
        "organization": "GZ Weedong Networks Technology Co. , Ltd",
        "address_1": "38th Floor,Ren Feng Building",
        "address_2": "Guangzhou  Guangdong  510620",
        "country": "CN"
    },
    "E8EF89": {
        "oui_hex": "E8-EF-89",
        "organization": "OPMEX Tech.",
        "address_1": "18F GDC Building, 9 Gaoxin Central Avenue 3rd, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "109266": {
        "oui_hex": "10-92-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "EC2E4E": {
        "oui_hex": "EC-2E-4E",
        "organization": "HITACHI-LG DATA STORAGE INC",
        "address_1": "4F, MSC CENTER  BLDG., 22-23 KAIGAN 3-CHOME, MINATO-KU,",
        "address_2": "TOKYO  TOKYO  108-0022",
        "country": "JP"
    },
    "3481C4": {
        "oui_hex": "34-81-C4",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "983713": {
        "oui_hex": "98-37-13",
        "organization": "PT.Navicom Indonesia",
        "address_1": "Perkantoran Citragrand Blok CW7 no 10",
        "address_2": "Bekasi  Jawa Barat  17435",
        "country": "ID"
    },
    "A47E39": {
        "oui_hex": "A4-7E-39",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "CCB691": {
        "oui_hex": "CC-B6-91",
        "organization": "NECMagnusCommunications",
        "address_1": "4-28 MITA 1Chome",
        "address_2": " Minato-ku  Tokyo  108-0073",
        "country": "JP"
    },
    "40167E": {
        "oui_hex": "40-16-7E",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "F84A73": {
        "oui_hex": "F8-4A-73",
        "organization": "EUMTECH CO., LTD",
        "address_1": "Room 1201, 115, Dongdeok-ro",
        "address_2": "Daegu  Daegu  700-719",
        "country": "KR"
    },
    "142BD6": {
        "oui_hex": "14-2B-D6",
        "organization": "Guangdong Appscomm Co.,Ltd",
        "address_1": "Rm 903, Block C3, Chuangxin Building, No.182,",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "FCC2DE": {
        "oui_hex": "FC-C2-DE",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "98349D": {
        "oui_hex": "98-34-9D",
        "organization": "Krauss Maffei Technologies GmbH",
        "address_1": "Krauss-Mafffei-Str. 2",
        "address_2": "Munich    80997",
        "country": "DE"
    },
    "880FB6": {
        "oui_hex": "88-0F-B6",
        "organization": "Jabil Circuits India Pvt Ltd,-EHTP unit",
        "address_1": "B-26, MIDC, Ranjangaon, Tal.Shirur",
        "address_2": "Pune  Maharashtra  412220",
        "country": "IN"
    },
    "B46698": {
        "oui_hex": "B4-66-98",
        "organization": "Zealabs srl",
        "address_1": "via Monte Grappa, 25",
        "address_2": "Lancenigo di Villorba  Italy  31020",
        "country": "IT"
    },
    "687CC8": {
        "oui_hex": "68-7C-C8",
        "organization": "Measurement Systems S. de R.L.",
        "address_1": "45999 Regal Plaza",
        "address_2": "Sterling  VA  20165",
        "country": "US"
    },
    "74F85D": {
        "oui_hex": "74-F8-5D",
        "organization": "Berkeley Nucleonics Corp",
        "address_1": "2955 Kerner Blvd #D",
        "address_2": "San Rafael  California  94901",
        "country": "US"
    },
    "B061C7": {
        "oui_hex": "B0-61-C7",
        "organization": "Ericsson-LG Enterprise",
        "address_1": "77, Heungan-daro 81beon-gil,",
        "address_2": "Anyang  Gyeonggi  431-749",
        "country": "KR"
    },
    "0092FA": {
        "oui_hex": "00-92-FA",
        "organization": "SHENZHEN WISKY TECHNOLOGY CO.,LTD",
        "address_1": "5/F W2-A,Hight-tech Park South 1 Road,Nanshan District,Shenzhen,Guangdong,China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4C7F62": {
        "oui_hex": "4C-7F-62",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "100F18": {
        "oui_hex": "10-0F-18",
        "organization": "Fu Gang Electronic(KunShan)CO.,LTD",
        "address_1": "No.6 Zheng Wei West Road, Jin Xi Town, Kun Shan City, Jiang Su Province, China",
        "address_2": "Jiang Su    215324",
        "country": "CN"
    },
    "D0C7C0": {
        "oui_hex": "D0-C7-C0",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4411C2": {
        "oui_hex": "44-11-C2",
        "organization": "Telegartner Karl Gartner GmbH",
        "address_1": "Lerchenstr. 35",
        "address_2": "Steinenbronn  Baden-Wurttemberg  71144",
        "country": "DE"
    },
    "8059FD": {
        "oui_hex": "80-59-FD",
        "organization": "Noviga",
        "address_1": "Lefortovskaya nab., 1",
        "address_2": "Moscow  -  105005",
        "country": "RU"
    },
    "400107": {
        "oui_hex": "40-01-07",
        "organization": "Arista Corp",
        "address_1": "40675 Encyclopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "30C750": {
        "oui_hex": "30-C7-50",
        "organization": "MIC Technology Group",
        "address_1": "No. 6 Gaoxin 3 road",
        "address_2": "Xi'an  Shaanxi  710075",
        "country": "CN"
    },
    "18CC23": {
        "oui_hex": "18-CC-23",
        "organization": "Philio Technology Corporation",
        "address_1": "8F., No.653-2, Zhongzheng Rd",
        "address_2": "New Taipei    242",
        "country": "TW"
    },
    "407875": {
        "oui_hex": "40-78-75",
        "organization": "IMBEL - Industria de Material Belico do Brasil",
        "address_1": "Rua Monsenhor Manoel Gomes,   520",
        "address_2": "Rio de Janeiro  RJ  20931-670",
        "country": "BR"
    },
    "D881CE": {
        "oui_hex": "D8-81-CE",
        "organization": "AHN INC.",
        "address_1": "1006,Halla sigma valley, 53, Gasandigital 2-Ro",
        "address_2": "Seoul    153 706",
        "country": "KR"
    },
    "28C825": {
        "oui_hex": "28-C8-25",
        "organization": "DellKing Industrial Co., Ltd",
        "address_1": "2F,Building D,Zhongxing Science Park,  No 3,Ganli 2nd Road,Gankeng Community",
        "address_2": "Shenzhen  GuangDong  518112",
        "country": "CN"
    },
    "80618F": {
        "oui_hex": "80-61-8F",
        "organization": "Shenzhen sangfei consumer communications co.,ltd",
        "address_1": "11 science and technology road,shenzhen hi-tech industrial park nanshan district,shenzhen 518057,PRC",
        "address_2": "ShenZhen  China/GuangDong  518057",
        "country": "CN"
    },
    "D82A15": {
        "oui_hex": "D8-2A-15",
        "organization": "Leitner SpA",
        "address_1": "Via Brennero 34",
        "address_2": "Vipiteno  Bolzano  39049",
        "country": "IT"
    },
    "447E76": {
        "oui_hex": "44-7E-76",
        "organization": "Trek Technology (S) Pte Ltd",
        "address_1": "30 Loyang Way #07-15",
        "address_2": "Singapore  Singapore  508769",
        "country": "SG"
    },
    "B0EC8F": {
        "oui_hex": "B0-EC-8F",
        "organization": "GMX SAS",
        "address_1": "32 Rue Brancion",
        "address_2": "PARIS    75015",
        "country": "FR"
    },
    "28DEF6": {
        "oui_hex": "28-DE-F6",
        "organization": "bioMerieux Inc.",
        "address_1": "595 Anglum Road",
        "address_2": "Hazelwood  MO  63042",
        "country": "US"
    },
    "580528": {
        "oui_hex": "58-05-28",
        "organization": "LABRIS NETWORKS",
        "address_1": "Silikon Blok 1 NK 24 Teknokent",
        "address_2": "ANKARA  AN  06540",
        "country": "TR"
    },
    "E0D31A": {
        "oui_hex": "E0-D3-1A",
        "organization": "EQUES Technology Co., Limited",
        "address_1": "Room 301, Building 1, No.168 Jixin Road,",
        "address_2": "  Shanghai  201199",
        "country": "CN"
    },
    "987770": {
        "oui_hex": "98-77-70",
        "organization": "Pep Digital Technology (Guangzhou) Co., Ltd",
        "address_1": "23F, Yinhui Building, No.117 Longyi Road,",
        "address_2": "Guangzhou  Guangdong Province  510635",
        "country": "CN"
    },
    "68D247": {
        "oui_hex": "68-D2-47",
        "organization": "Portalis LC",
        "address_1": "204 Fort Union Blvd. Ste. 202",
        "address_2": "Midvale  UT  84047",
        "country": "US"
    },
    "50B695": {
        "oui_hex": "50-B6-95",
        "organization": "Micropoint Biotechnologies,Inc.",
        "address_1": "6F, No.3, Industry 5 Road, Shekou",
        "address_2": "Shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "B4430D": {
        "oui_hex": "B4-43-0D",
        "organization": "Broadlink Pty Ltd",
        "address_1": "room 1201,  No. 588 jiangnan Rd,",
        "address_2": "Hangzhou  Zhejiang province  310052",
        "country": "CN"
    },
    "A06518": {
        "oui_hex": "A0-65-18",
        "organization": "VNPT TECHNOLOGY",
        "address_1": "HoaLac Hi-Tech Park",
        "address_2": "  HANOI  10000",
        "country": "VN"
    },
    "7C8D91": {
        "oui_hex": "7C-8D-91",
        "organization": "Shanghai Hongzhuo Information Technology co.,LTD",
        "address_1": "Room.161,Building 5,No.311 Jingao RD",
        "address_2": "Pudong  Shanghai  200136",
        "country": "CN"
    },
    "748F1B": {
        "oui_hex": "74-8F-1B",
        "organization": "MasterImage 3D",
        "address_1": "131, Gasan Digital 1-ro, Geumcheon-gu",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "083F76": {
        "oui_hex": "08-3F-76",
        "organization": "Intellian Technologies, Inc.",
        "address_1": "348-5 Chungho-Ri Jinwi-Myeon",
        "address_2": "  Gyeonggi-Do  451-862",
        "country": "KR"
    },
    "CC89FD": {
        "oui_hex": "CC-89-FD",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "34466F": {
        "oui_hex": "34-46-6F",
        "organization": "HiTEM Engineering",
        "address_1": "7420 Carroll Road",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "386C9B": {
        "oui_hex": "38-6C-9B",
        "organization": "Ivy Biomedical",
        "address_1": "11 Business Park Drive",
        "address_2": "Branford  Connecticut  06405",
        "country": "US"
    },
    "B42C92": {
        "oui_hex": "B4-2C-92",
        "organization": "Zhejiang Weirong Electronic Co., Ltd",
        "address_1": "North of South Tanghe Road, Lingxi Town,",
        "address_2": " Wenzhou City   Zhejiang Province  325800",
        "country": "CN"
    },
    "A07771": {
        "oui_hex": "A0-77-71",
        "organization": "Vialis BV",
        "address_1": "Loodsboot 15",
        "address_2": "HOUTEN  Utrecht  3991 CJ",
        "country": "US"
    },
    "10DDF4": {
        "oui_hex": "10-DD-F4",
        "organization": "Maxway Electronics CO.,LTD",
        "address_1": "2F Building 4,A Section,3rd Industrial zone,Tangtou",
        "address_2": "Shenzhen  Guangdong  518018",
        "country": "CN"
    },
    "5CE7BF": {
        "oui_hex": "5C-E7-BF",
        "organization": "New Singularity International Technical Development Co.,Ltd",
        "address_1": "8F,NorthStar-Ultrapower Tower, No.13 Beiyuan Road, Chaoyang District, Beijing, China",
        "address_2": "Beijing  Beijing  100107",
        "country": "CN"
    },
    "6C641A": {
        "oui_hex": "6C-64-1A",
        "organization": "Penguin Computing",
        "address_1": "45800 Northport Loop West",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "50A054": {
        "oui_hex": "50-A0-54",
        "organization": "Actineon",
        "address_1": "47751 Fremont Blvd",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "B48547": {
        "oui_hex": "B4-85-47",
        "organization": "Amptown System Company GmbH",
        "address_1": "Wandsbeker Strasse 26",
        "address_2": "Hamburg  Hamburg  22179",
        "country": "DE"
    },
    "5056A8": {
        "oui_hex": "50-56-A8",
        "organization": "Jolla Ltd",
        "address_1": "Itaemerenkatu 11-13",
        "address_2": "  Helsinki  00180",
        "country": "US"
    },
    "E8E770": {
        "oui_hex": "E8-E7-70",
        "organization": "Warp9 Tech Design, Inc.",
        "address_1": "3650 Pheasant Run N.E.",
        "address_2": "Blaine  MN  55449",
        "country": "US"
    },
    "609620": {
        "oui_hex": "60-96-20",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "C0F991": {
        "oui_hex": "C0-F9-91",
        "organization": "GME Standard Communications P/L",
        "address_1": "17 Gibbon Rd.",
        "address_2": "Winston Hills  New South Wales  2153",
        "country": "AU"
    },
    "D87CDD": {
        "oui_hex": "D8-7C-DD",
        "organization": "SANIX INCORPORATED",
        "address_1": "Creation Core Fukuoka 212, 3-2-16 Kamikoga,",
        "address_2": "Chikushino-shi  Fukuoka  818-0041",
        "country": "JP"
    },
    "707C18": {
        "oui_hex": "70-7C-18",
        "organization": "ADATA Technology Co., Ltd",
        "address_1": "2F, No.258, Lian Cheng Rd.",
        "address_2": "New Taipei City    23553",
        "country": "TW"
    },
    "14F28E": {
        "oui_hex": "14-F2-8E",
        "organization": "ShenYang ZhongKe-Allwin Technology Co.LTD",
        "address_1": "No.6, Gaoge Road,",
        "address_2": "ShenYang  Liaoning  110179",
        "country": "CN"
    },
    "BC14EF": {
        "oui_hex": "BC-14-EF",
        "organization": "ITON Technology Limited",
        "address_1": "Room 1302,A ablock, Building 4",
        "address_2": "ShenZhen  GuangDong Pronvice  518000",
        "country": "CN"
    },
    "080371": {
        "oui_hex": "08-03-71",
        "organization": "KRG CORPORATE",
        "address_1": "41 rue Perier",
        "address_2": "Montrouge    92120",
        "country": "FR"
    },
    "200E95": {
        "oui_hex": "20-0E-95",
        "organization": "IEC – TC9 WG43",
        "address_1": "3, rue de Varembé",
        "address_2": "Geneva  GE  1211",
        "country": "CH"
    },
    "C8F68D": {
        "oui_hex": "C8-F6-8D",
        "organization": "S.E.TECHNOLOGIES LIMITED",
        "address_1": "#303 Shiodome building Level3",
        "address_2": "Minato-ku  Tokyo  105-0022",
        "country": "JP"
    },
    "3CD4D6": {
        "oui_hex": "3C-D4-D6",
        "organization": "WirelessWERX, Inc",
        "address_1": "22687 Old Canal Rd.",
        "address_2": "Yorba Linda  California  92887",
        "country": "US"
    },
    "0C1262": {
        "oui_hex": "0C-12-62",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "78EC74": {
        "oui_hex": "78-EC-74",
        "organization": "Kyland-USA",
        "address_1": "1107 SE Willow Pl",
        "address_2": "Blue Springs  MO  64014",
        "country": "US"
    },
    "98DA92": {
        "oui_hex": "98-DA-92",
        "organization": "Vuzix Corporation",
        "address_1": "2166 Brighton Henrietta Town Line Road",
        "address_2": "Rochester  NY  14623",
        "country": "US"
    },
    "387B47": {
        "oui_hex": "38-7B-47",
        "organization": "AKELA, Inc.",
        "address_1": "5551 Ekwill Street, Suite A",
        "address_2": "Santa Barbara  California  93111",
        "country": "US"
    },
    "C064C6": {
        "oui_hex": "C0-64-C6",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "E40439": {
        "oui_hex": "E4-04-39",
        "organization": "TomTom Software Ltd",
        "address_1": "20th Floor Euston Tower",
        "address_2": "London    NW1 3AS",
        "country": "GB"
    },
    "D0C42F": {
        "oui_hex": "D0-C4-2F",
        "organization": "Tamagawa Seiki Co.,Ltd.",
        "address_1": "1-3-47 Kitainter Kogyodanchi",
        "address_2": "Hachinohe city  Aomori-Pref.  039-2245",
        "country": "US"
    },
    "549359": {
        "oui_hex": "54-93-59",
        "organization": "SHENZHEN TWOWING TECHNOLOGIES CO.,LTD.",
        "address_1": "F 4th ,5th , 6th, No.6 Building,",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "US"
    },
    "90356E": {
        "oui_hex": "90-35-6E",
        "organization": "Vodafone Omnitel N.V.",
        "address_1": "Via Guglielmo Jervis, 13",
        "address_2": "Ivrea  Italy / Tourin  10015",
        "country": "IT"
    },
    "284430": {
        "oui_hex": "28-44-30",
        "organization": "GenesisTechnical Systems (UK) Ltd",
        "address_1": "Venture Centre",
        "address_2": "Coventry    CV4 7EZ",
        "country": "GB"
    },
    "5C1193": {
        "oui_hex": "5C-11-93",
        "organization": "Seal One AG",
        "address_1": "Berliner Str. 44",
        "address_2": "Frankfurt am Main  Hessen  60311",
        "country": "DE"
    },
    "783D5B": {
        "oui_hex": "78-3D-5B",
        "organization": "TELNET Redes Inteligentes S.A.",
        "address_1": "Polígono Industrial Centrovía",
        "address_2": "La Muela  Zaragoza  50198",
        "country": "ES"
    },
    "D0B523": {
        "oui_hex": "D0-B5-23",
        "organization": "Bestcare Cloucal Corp.",
        "address_1": "4F.,No.106,Sec.1,Xintai 5th Rd.,",
        "address_2": "New Taipei City    22102",
        "country": "TW"
    },
    "24A495": {
        "oui_hex": "24-A4-95",
        "organization": "Thales Canada Inc.",
        "address_1": "105 Moatfield Road",
        "address_2": "Toronto  Ontario  M3B 0A4",
        "country": "CA"
    },
    "847616": {
        "oui_hex": "84-76-16",
        "organization": "Addat s.r.o.",
        "address_1": "U krematoria 24",
        "address_2": "Liberec  Liberec  46001",
        "country": "CZ"
    },
    "DC0575": {
        "oui_hex": "DC-05-75",
        "organization": "SIEMENS ENERGY AUTOMATION",
        "address_1": " GOA WORKS ,L-6 ,",
        "address_2": "VERNA  GOA   403722",
        "country": "IN"
    },
    "E097F2": {
        "oui_hex": "E0-97-F2",
        "organization": "Atomax Inc.",
        "address_1": "8F-1, No.300, Sec.1, Nei-hu Rd.",
        "address_2": "  Taipei  114",
        "country": "TW"
    },
    "70305E": {
        "oui_hex": "70-30-5E",
        "organization": "Nanjing Zhongke Menglian Information Technology Co.,LTD",
        "address_1": "3rd Floor,Building A,Area 3",
        "address_2": "Nanjing  Jiangsu  210042",
        "country": "CN"
    },
    "C098E5": {
        "oui_hex": "C0-98-E5",
        "organization": "University of Michigan",
        "address_1": "4808 Beyster Bldg,",
        "address_2": "Ann Arbor  Michigan  48109",
        "country": "US"
    },
    "50E14A": {
        "oui_hex": "50-E1-4A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "708D09": {
        "oui_hex": "70-8D-09",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "98FB12": {
        "oui_hex": "98-FB-12",
        "organization": "Grand Electronics (HK) Ltd",
        "address_1": "Flat/Room 1120, 11/F Beverley Commercial Centre",
        "address_2": "    999077",
        "country": "HK"
    },
    "3C1040": {
        "oui_hex": "3C-10-40",
        "organization": "daesung network",
        "address_1": "#209 e-space Bldg,Guro-dong,Guro-gu",
        "address_2": "Seoul    152-789",
        "country": "KR"
    },
    "443C9C": {
        "oui_hex": "44-3C-9C",
        "organization": "Pintsch Tiefenbach GmbH",
        "address_1": "Beisenbruchstrasse 10",
        "address_2": "Sprockhoevel    45549",
        "country": "DE"
    },
    "28FC51": {
        "oui_hex": "28-FC-51",
        "organization": "The Electric Controller and Manufacturing Co., LLC",
        "address_1": "PO Box 468",
        "address_2": "Saint Matthews  SC  29135",
        "country": "US"
    },
    "407496": {
        "oui_hex": "40-74-96",
        "organization": "aFUN TECHNOLOGY INC.",
        "address_1": "2F.,No.3,Lane29,HuLu ST.,Shihlin District,",
        "address_2": "Taipei    11165",
        "country": "TW"
    },
    "701D7F": {
        "oui_hex": "70-1D-7F",
        "organization": "Comtech Technology Co., Ltd.",
        "address_1": "2F, No. 42, Sec. 3 Chung Yang Rd.",
        "address_2": "New Taipei City    23673",
        "country": "TW"
    },
    "705986": {
        "oui_hex": "70-59-86",
        "organization": "OOO TTV",
        "address_1": "No. 75, Okulov Street, Building 8",
        "address_2": "Perm    614068",
        "country": "RU"
    },
    "844F03": {
        "oui_hex": "84-4F-03",
        "organization": "Ablelink Electronics Ltd",
        "address_1": "Flat 1602,16/F Kodak House 2 39 Healthy Street East,",
        "address_2": "",
        "country": "CN"
    },
    "906717": {
        "oui_hex": "90-67-17",
        "organization": "Alphion India Private Limited",
        "address_1": "405 Windfall, Sahar Plaza",
        "address_2": "Mumbai  Maharashtra  400059",
        "country": "IN"
    },
    "6064A1": {
        "oui_hex": "60-64-A1",
        "organization": "RADiflow Ltd.",
        "address_1": "31 Habarzel St.",
        "address_2": "Tel Aviv    6971045",
        "country": "IL"
    },
    "58B961": {
        "oui_hex": "58-B9-61",
        "organization": "SOLEM Electronique",
        "address_1": "ZAE La Plaine",
        "address_2": "CLAPIERS    34830",
        "country": "FR"
    },
    "0C473D": {
        "oui_hex": "0C-47-3D",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "8CCDA2": {
        "oui_hex": "8C-CD-A2",
        "organization": "ACTP, Inc.",
        "address_1": "2400 Sand Lake Rd",
        "address_2": "Orlando  FL  32809",
        "country": "US"
    },
    "84262B": {
        "oui_hex": "84-26-2B",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "986CF5": {
        "oui_hex": "98-6C-F5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "447BC4": {
        "oui_hex": "44-7B-C4",
        "organization": "DualShine Technology(SZ)Co.,Ltd",
        "address_1": "No.334-1,LuoTian 3rd Industrial Park,",
        "address_2": "Shen Zhen  Guang Dong  518000",
        "country": "CN"
    },
    "9C039E": {
        "oui_hex": "9C-03-9E",
        "organization": "Beijing Winchannel Software Technology Co., Ltd",
        "address_1": "8F, Block E, Dazhongsi Zhongkun Plaza No. A",
        "address_2": "Haidian District  BEIJING  100089",
        "country": "CN"
    },
    "680AD7": {
        "oui_hex": "68-0A-D7",
        "organization": "Yancheng Kecheng Optoelectronic Technology Co., Ltd",
        "address_1": "No.1 East Road, Kaifa Avenue,",
        "address_2": "Yancheng  Jiangsu  224007",
        "country": "CN"
    },
    "BC8893": {
        "oui_hex": "BC-88-93",
        "organization": "VILLBAU Ltd.",
        "address_1": "Üllöi ut 611.",
        "address_2": "Budapest  -  H-1182",
        "country": "HU"
    },
    "706173": {
        "oui_hex": "70-61-73",
        "organization": "Calantec GmbH",
        "address_1": "Doebelner Str. 4",
        "address_2": "  Berlin  12627",
        "country": "DE"
    },
    "7C49B9": {
        "oui_hex": "7C-49-B9",
        "organization": "Plexus Manufacturing Sdn Bhd",
        "address_1": "Plot 87",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "9CF8DB": {
        "oui_hex": "9C-F8-DB",
        "organization": "shenzhen eyunmei technology co,.ltd",
        "address_1": "8/F Yiben Building,No.1063 ChaGuang Road,XiLi Town,",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "20D21F": {
        "oui_hex": "20-D2-1F",
        "organization": "Wincal Technology Corp.",
        "address_1": "1028 South Greenwood Ave.",
        "address_2": "Montebello  California  90640",
        "country": "US"
    },
    "F89550": {
        "oui_hex": "F8-95-50",
        "organization": "Proton Products Chengdu Ltd",
        "address_1": "1st Ring",
        "address_2": "Chengdu  Sichuan  610051",
        "country": "CN"
    },
    "58639A": {
        "oui_hex": "58-63-9A",
        "organization": "TPL SYSTEMES",
        "address_1": "ZAE DU PERIGORD NOIR",
        "address_2": "SARLAT    24200",
        "country": "FR"
    },
    "187ED5": {
        "oui_hex": "18-7E-D5",
        "organization": "shenzhen kaism technology Co. Ltd",
        "address_1": "37# chuanglong west road pinghu shenzhen",
        "address_2": "shenzhen    518111",
        "country": "CN"
    },
    "841B38": {
        "oui_hex": "84-1B-38",
        "organization": "Shenzhen Excelsecu Data Technology Co.,Ltd",
        "address_1": "Unit 701-709,7/F，South Block,SDGI Building A, No.2,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "4CCBF5": {
        "oui_hex": "4C-CB-F5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "44700B": {
        "oui_hex": "44-70-0B",
        "organization": "IFFU",
        "address_1": "33, Annyeom-gil 112 beon-gil,jeongnam-myeon",
        "address_2": "Hwaseong-si  Gyeonggi-do  445-968",
        "country": "US"
    },
    "54A54B": {
        "oui_hex": "54-A5-4B",
        "organization": "NSC Communications Siberia Ltd",
        "address_1": "Ordjonikidze 38",
        "address_2": "  Novosibirsk  630099",
        "country": "RU"
    },
    "BC2B6B": {
        "oui_hex": "BC-2B-6B",
        "organization": "Beijing Haier IC Design Co.,Ltd",
        "address_1": "Room 205, Tongheng Building, No.4 Huayuan Road, Haidian District",
        "address_2": "Beijing  Beijing  100088",
        "country": "CN"
    },
    "98D331": {
        "oui_hex": "98-D3-31",
        "organization": "Shenzhen Bolutek Technology Co.,Ltd.",
        "address_1": "Building B, District A, Internet industry base, Baoan",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "38EC11": {
        "oui_hex": "38-EC-11",
        "organization": "Novatek Microelectronics Corp.",
        "address_1": "No.1-2 Innovation Rd I.,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "1C4158": {
        "oui_hex": "1C-41-58",
        "organization": "Gemalto M2M GmbH",
        "address_1": "Siemensdamm 50",
        "address_2": "Berlin  Berlin  13629",
        "country": "DE"
    },
    "9C2840": {
        "oui_hex": "9C-28-40",
        "organization": "Discovery Technology,LTD..",
        "address_1": "5th floor Building 2,Block A,Internet industrial park,",
        "address_2": "Shenzhen  Guangzhou  518100",
        "country": "CN"
    },
    "1C7B21": {
        "oui_hex": "1C-7B-21",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "E0AF4B": {
        "oui_hex": "E0-AF-4B",
        "organization": "Pluribus Networks, Inc.",
        "address_1": "1808 Embarcadero Rd Suite B",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "840F45": {
        "oui_hex": "84-0F-45",
        "organization": "Shanghai GMT Digital Technologies Co., Ltd",
        "address_1": "Room 501-505",
        "address_2": "Zhangjiang Hi-tech Park  Shanghai  201204",
        "country": "CN"
    },
    "2C5FF3": {
        "oui_hex": "2C-5F-F3",
        "organization": "Pertronic Industries",
        "address_1": "17 Eastern Hutt Road",
        "address_2": "Wingate    5019",
        "country": "NZ"
    },
    "78491D": {
        "oui_hex": "78-49-1D",
        "organization": "The Will-Burt Company",
        "address_1": "169 S. Main St.",
        "address_2": "Orrivlle  Ohio  44667",
        "country": "US"
    },
    "F46ABC": {
        "oui_hex": "F4-6A-BC",
        "organization": "Adonit Corp. Ltd.",
        "address_1": "10689 Rm. A, 9F, No.107 Sec.4 Ren-Ai Rd.,",
        "address_2": "Taipei  Taipei  10689",
        "country": "TW"
    },
    "28C671": {
        "oui_hex": "28-C6-71",
        "organization": "Yota Devices OY",
        "address_1": "Elektronikkatie 13",
        "address_2": "Oulu    90590",
        "country": "FI"
    },
    "D86960": {
        "oui_hex": "D8-69-60",
        "organization": "Steinsvik",
        "address_1": "Rundhaug 25",
        "address_2": "FOERRESFJORDEN  Rogaland  5563",
        "country": "NO"
    },
    "08EF3B": {
        "oui_hex": "08-EF-3B",
        "organization": "MCS Logic Inc.",
        "address_1": "6F. Samho Center B Bldg., 275-6,Yangjae-Dong, Secho-Ku,Seoul",
        "address_2": "Seoul    137-941",
        "country": "KR"
    },
    "E8EADA": {
        "oui_hex": "E8-EA-DA",
        "organization": "Denkovi Assembly Electronics LTD",
        "address_1": "St. Stambolov str. 21",
        "address_2": "Byala  Rousse  7100",
        "country": "BG"
    },
    "F85BC9": {
        "oui_hex": "F8-5B-C9",
        "organization": "M-Cube Spa",
        "address_1": "Corso Cavour 2/2d",
        "address_2": "  Trieste  34132",
        "country": "IT"
    },
    "7CB77B": {
        "oui_hex": "7C-B7-7B",
        "organization": "Paradigm Electronics Inc",
        "address_1": "5340 Canotek Rd Unit#4",
        "address_2": "Ottawa  ON  K1J 9C6",
        "country": "CA"
    },
    "B0CE18": {
        "oui_hex": "B0-CE-18",
        "organization": "Zhejiang shenghui lighting co.,Ltd",
        "address_1": "Rm801,1th Xinye Building",
        "address_2": "cao he jing Develop Zone  Shanghai  200233",
        "country": "CN"
    },
    "6CF97C": {
        "oui_hex": "6C-F9-7C",
        "organization": "Nanoptix Inc.",
        "address_1": "699 Champlain St",
        "address_2": "Dieppe  NB  E1A 1P6",
        "country": "CA"
    },
    "F8FF5F": {
        "oui_hex": "F8-FF-5F",
        "organization": "Shenzhen Communication Technology Co.,Ltd",
        "address_1": "2F,6 Block, Kupai inforport,No.2 Mengxi Street,(North)High-tech Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "102279": {
        "oui_hex": "10-22-79",
        "organization": "ZeroDesktop, Inc.",
        "address_1": "125 University Ave, Suite 150",
        "address_2": "Palo Alto  California  94301",
        "country": "US"
    },
    "7C1AFC": {
        "oui_hex": "7C-1A-FC",
        "organization": "Dalian Co-Edifice Video Technology Co., Ltd",
        "address_1": "23F , Block A , #32 Huoju Road , Hi-Tech Zone",
        "address_2": "Dalian  Liaoning  116023",
        "country": "CN"
    },
    "F47A4E": {
        "oui_hex": "F4-7A-4E",
        "organization": "Woojeon&Handan",
        "address_1": "569-12, Gasan-dong,",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "04848A": {
        "oui_hex": "04-84-8A",
        "organization": "7INOVA TECHNOLOGY LIMITED",
        "address_1": "3F, A Building, QuanYuanFa Industrial Park, No. 72, GuanLan Rd",
        "address_2": "LongHua District  Shenzhen  518000",
        "country": "CN"
    },
    "EC2257": {
        "oui_hex": "EC-22-57",
        "organization": "JiangSu NanJing University Electronic Information Technology Co.,Ltd",
        "address_1": "F7,Block 06",
        "address_2": "NanJing  JiangSu  210000",
        "country": "CN"
    },
    "F037A1": {
        "oui_hex": "F0-37-A1",
        "organization": "Huike Electronics (SHENZHEN) CO., LTD.",
        "address_1": "Huike industrial park,Minying industrial park,Shuitian country,Shiyan,Baoan District",
        "address_2": "SHENZHEN  GUANGDONG  518108",
        "country": "CN"
    },
    "704CED": {
        "oui_hex": "70-4C-ED",
        "organization": "TMRG, Inc.",
        "address_1": "11950 Democracy Drive",
        "address_2": "Reston  VA  20190",
        "country": "US"
    },
    "F08EDB": {
        "oui_hex": "F0-8E-DB",
        "organization": "VeloCloud Networks",
        "address_1": "720 University Ave.",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "C0A39E": {
        "oui_hex": "C0-A3-9E",
        "organization": "EarthCam, Inc.",
        "address_1": "84 Kennedy Street",
        "address_2": "Hackensack  New Jersey  07601",
        "country": "US"
    },
    "109AB9": {
        "oui_hex": "10-9A-B9",
        "organization": "Tosibox Oy",
        "address_1": "Elektroniikkatie 8",
        "address_2": "  Oulu  90590",
        "country": "FI"
    },
    "142D8B": {
        "oui_hex": "14-2D-8B",
        "organization": "Incipio Technologies, Inc",
        "address_1": "6001 Oak Canyon",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "68EE96": {
        "oui_hex": "68-EE-96",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "78D38D": {
        "oui_hex": "78-D3-8D",
        "organization": "HONGKONG YUNLINK TECHNOLOGY LIMITED",
        "address_1": "15B 15/F CHEUK NANG PLAZA 250 HENNESSY RD HK",
        "address_2": "ShenzhenCity  Guangdong Province  518103",
        "country": "US"
    },
    "DCAE04": {
        "oui_hex": "DC-AE-04",
        "organization": "CELOXICA Ltd",
        "address_1": "34 Porchester Road",
        "address_2": "  London  W2 6ES",
        "country": "GB"
    },
    "8005DF": {
        "oui_hex": "80-05-DF",
        "organization": "Montage Technology Group Limited",
        "address_1": "Rm#A16F, Technolgy Blgd.,Yishan Rd.",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "681D64": {
        "oui_hex": "68-1D-64",
        "organization": "Sunwave Communications Co., Ltd",
        "address_1": "581,huoju Avenue,BinJiang District",
        "address_2": " Hangzhou  Zhejiang Province  310053",
        "country": "CN"
    },
    "4C21D0": {
        "oui_hex": "4C-21-D0",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "907A0A": {
        "oui_hex": "90-7A-0A",
        "organization": "Gebr. Bode GmbH & Co KG",
        "address_1": "Ochshaeuser Str. 14",
        "address_2": "Kassel    34266",
        "country": "DE"
    },
    "A0C6EC": {
        "oui_hex": "A0-C6-EC",
        "organization": "ShenZhen ANYK Technology Co.,LTD",
        "address_1": "5F,12B,ZhongXing Industrial Zone, Venture Road",
        "address_2": "ShenZhen  GuangDong  518054",
        "country": "CN"
    },
    "78E8B6": {
        "oui_hex": "78-E8-B6",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "1078CE": {
        "oui_hex": "10-78-CE",
        "organization": "Hanvit SI, Inc.",
        "address_1": "#201 Daeheung Building, 265-18 Yangjae-dong",
        "address_2": "Seoul    137130",
        "country": "KR"
    },
    "D8DA52": {
        "oui_hex": "D8-DA-52",
        "organization": "APATOR S.A.",
        "address_1": "ul Gdanska 4A lok. C4",
        "address_2": "Torun  Kujawsko-Pomorskie  87-100",
        "country": "PL"
    },
    "587A4D": {
        "oui_hex": "58-7A-4D",
        "organization": "Stonesoft Corporation",
        "address_1": "Italahdenkatu 22A",
        "address_2": "Helsinki    00210",
        "country": "FI"
    },
    "84E629": {
        "oui_hex": "84-E6-29",
        "organization": "Bluwan SA",
        "address_1": "Espace Lumiere, Bat 2",
        "address_2": "Chatou    78400",
        "country": "FR"
    },
    "C47F51": {
        "oui_hex": "C4-7F-51",
        "organization": "Inventek Systems",
        "address_1": "2 Republic Road",
        "address_2": "Billerica  Ma  01862",
        "country": "US"
    },
    "A897DC": {
        "oui_hex": "A8-97-DC",
        "organization": "IBM",
        "address_1": "4400 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CCD29B": {
        "oui_hex": "CC-D2-9B",
        "organization": "Shenzhen Bopengfa Elec&Technology CO.,Ltd",
        "address_1": " Bldg56A,3/F,Baotian Rd3,Xixiang Town",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "A09BBD": {
        "oui_hex": "A0-9B-BD",
        "organization": "Total Aviation Solutions Pty Ltd",
        "address_1": "Suite 816A / 3 PARKLAND BVDE",
        "address_2": "Brisbane  QLD  4000",
        "country": "AU"
    },
    "D40BB9": {
        "oui_hex": "D4-0B-B9",
        "organization": "Solid Semecs bv.",
        "address_1": "Oostwijk 18",
        "address_2": "Uden  Noord Brabant  5406 XT",
        "country": "NL"
    },
    "F415FD": {
        "oui_hex": "F4-15-FD",
        "organization": "Shanghai Pateo Electronic Equipment Manufacturing Co., Ltd.",
        "address_1": "20th Floor, Metro Tower",
        "address_2": "Xuhui District  Shanghai  200030",
        "country": "CN"
    },
    "70E027": {
        "oui_hex": "70-E0-27",
        "organization": "HONGYU COMMUNICATION TECHNOLOGY LIMITED",
        "address_1": "Room4B, East Building 210,",
        "address_2": "Shen Zhen  Guang Dong Province  518040",
        "country": "CN"
    },
    "FC35E6": {
        "oui_hex": "FC-35-E6",
        "organization": "Visteon corp",
        "address_1": "One Village Center Dr",
        "address_2": "Belleville  MI  48111",
        "country": "US"
    },
    "E8481F": {
        "oui_hex": "E8-48-1F",
        "organization": "Advanced Automotive Antennas",
        "address_1": "Pol.Ind Can Mitjans s/n",
        "address_2": "Viladecavalls  Barcelona  08232",
        "country": "ES"
    },
    "3495DB": {
        "oui_hex": "34-95-DB",
        "organization": "Logitec Corporation",
        "address_1": "8268 Rokudohara, Misuzu",
        "address_2": "Ina  Nagano",
        "country": "JP"
    },
    "9CB793": {
        "oui_hex": "9C-B7-93",
        "organization": "Creatcomm Technology Inc.",
        "address_1": "Rm 619, Buld A, Modern Plaza",
        "address_2": "Kunshan  Jiangsu  201203",
        "country": "CN"
    },
    "5C335C": {
        "oui_hex": "5C-33-5C",
        "organization": "Swissphone Telecom AG",
        "address_1": "Faelmisstrasse 21",
        "address_2": "Samstagern  Zurich  CH-8833",
        "country": "CH"
    },
    "04DF69": {
        "oui_hex": "04-DF-69",
        "organization": "Car Connectivity Consortium",
        "address_1": "3855 SW 153rd Drive",
        "address_2": "Beaverton  Oregon  97006",
        "country": "US"
    },
    "78DAB3": {
        "oui_hex": "78-DA-B3",
        "organization": "GBO Technology",
        "address_1": "1150 Bayhill Dr. Ste. 111",
        "address_2": "San Bruno  CA  94066",
        "country": "US"
    },
    "700FEC": {
        "oui_hex": "70-0F-EC",
        "organization": "Poindus Systems Corp.",
        "address_1": "5F., No. 59, Lane. 77, Xing-Ai Rd., Neihu Dist.,",
        "address_2": " Taipei City    114",
        "country": "TW"
    },
    "F02405": {
        "oui_hex": "F0-24-05",
        "organization": "OPUS High Technology Corporation",
        "address_1": "1st Floor, No. 367, Gaocui Road",
        "address_2": "Hsinchu City    30064",
        "country": "TW"
    },
    "D41090": {
        "oui_hex": "D4-10-90",
        "organization": "iNFORM Systems AG",
        "address_1": "Europastrasse 15",
        "address_2": "Glattbrugg    8152",
        "country": "CH"
    },
    "78D5B5": {
        "oui_hex": "78-D5-B5",
        "organization": "NAVIELEKTRO KY",
        "address_1": "HALLIMESTARINKATU 11",
        "address_2": "KAARINA    FIN-20780",
        "country": "FI"
    },
    "E47D5A": {
        "oui_hex": "E4-7D-5A",
        "organization": "Beijing Hanbang Technology Corp.",
        "address_1": "4/F,Skirt Building",
        "address_2": "Haidian District  Beijing  100080",
        "country": "CN"
    },
    "E4F7A1": {
        "oui_hex": "E4-F7-A1",
        "organization": "Datafox GmbH",
        "address_1": "Dermbacher Str. 12 - 14",
        "address_2": "Geisa  Thüringen  36419",
        "country": "DE"
    },
    "105C3B": {
        "oui_hex": "10-5C-3B",
        "organization": "Perma-Pipe, Inc.",
        "address_1": "7720 Lehigh Ave",
        "address_2": "Niles  IL  60714",
        "country": "US"
    },
    "349D90": {
        "oui_hex": "34-9D-90",
        "organization": "Heinzmann GmbH & CO. KG",
        "address_1": "Am Haselbach 1",
        "address_2": "Schoenau  Baden Wuertemberg  79677",
        "country": "DE"
    },
    "D862DB": {
        "oui_hex": "D8-62-DB",
        "organization": "Eno Inc.",
        "address_1": "2-3-18, Komagome, Toshima-ku",
        "address_2": "Tokyo    1700013",
        "country": "JP"
    },
    "C47DFE": {
        "oui_hex": "C4-7D-FE",
        "organization": "A.N. Solutions GmbH",
        "address_1": "Am Brauhaus 12",
        "address_2": "Dresden  Saxony  01099",
        "country": "DE"
    },
    "CCBD35": {
        "oui_hex": "CC-BD-35",
        "organization": "Steinel GmbH",
        "address_1": "Dieselstrasse 80-84",
        "address_2": "Herzebrock-Clarholz    33442",
        "country": "DE"
    },
    "6CECA1": {
        "oui_hex": "6C-EC-A1",
        "organization": "SHENZHEN CLOU ELECTRONICS CO. LTD.",
        "address_1": "5/F, building. T2, Hi-tech Industrial Park",
        "address_2": "SHENZ  GUANGONG  518057",
        "country": "CN"
    },
    "B03850": {
        "oui_hex": "B0-38-50",
        "organization": "Nanjing CAS-ZDC IOT SYSTEM CO.,LTD",
        "address_1": "699-27 Xuanwu Avenue",
        "address_2": "Nanjing  Jiangsu  210000",
        "country": "CN"
    },
    "748E08": {
        "oui_hex": "74-8E-08",
        "organization": "Bestek Corp.",
        "address_1": "No. 6, Lane 229, Sec. 3, Chang-Xing Rd.",
        "address_2": "Taoyuan    33852",
        "country": "TW"
    },
    "78F5E5": {
        "oui_hex": "78-F5-E5",
        "organization": "BEGA Gantenbrink-Leuchten KG",
        "address_1": "Hennenbusch",
        "address_2": "Menden  NRW  58708",
        "country": "DE"
    },
    "8C3C07": {
        "oui_hex": "8C-3C-07",
        "organization": "Skiva Technologies, Inc.",
        "address_1": "8330 Sterling St",
        "address_2": "Irving  TX  75063",
        "country": "US"
    },
    "38A86B": {
        "oui_hex": "38-A8-6B",
        "organization": "Orga BV",
        "address_1": "Strickledeweg 13",
        "address_2": "Schiedam    3125 AT",
        "country": "NL"
    },
    "F07765": {
        "oui_hex": "F0-77-65",
        "organization": "Sourcefire, Inc",
        "address_1": "9780 Patuxent Woods Drive",
        "address_2": "Columbia  Maryland  21046",
        "country": "US"
    },
    "1441E2": {
        "oui_hex": "14-41-E2",
        "organization": "Monaco Enterprises, Inc.",
        "address_1": "14820 E. Sprague Ave.",
        "address_2": "Spokane  WA  99216",
        "country": "US"
    },
    "ECD040": {
        "oui_hex": "EC-D0-40",
        "organization": "GEA Farm Technologies GmbH",
        "address_1": "Siemensstrasse 25-27",
        "address_2": "Boenen  Northrhine-Westfalia  59199",
        "country": "DE"
    },
    "F80DEA": {
        "oui_hex": "F8-0D-EA",
        "organization": "ZyCast Technology Inc.",
        "address_1": "No.33, Lane 181, Chung Hwa Road,",
        "address_2": "Hsin Chu    30060",
        "country": "TW"
    },
    "B08807": {
        "oui_hex": "B0-88-07",
        "organization": "Strata Worldwide",
        "address_1": "8995 Roswell Road",
        "address_2": "Sandy Springs  GA  30350",
        "country": "US"
    },
    "249504": {
        "oui_hex": "24-95-04",
        "organization": "SFR",
        "address_1": "40-42 QUAI DU POINT DU JOUR",
        "address_2": "BOULOGNE BILLANCOURT  HAUT DE SEINE  92100",
        "country": "FR"
    },
    "F45842": {
        "oui_hex": "F4-58-42",
        "organization": "Boxx TV Ltd",
        "address_1": "Suite 17, Imperial Studios",
        "address_2": "  London  SW6 2AG",
        "country": "GB"
    },
    "106682": {
        "oui_hex": "10-66-82",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "246278": {
        "oui_hex": "24-62-78",
        "organization": "sysmocom - systems for mobile communications GmbH",
        "address_1": "Alt-Moabit 93",
        "address_2": "  Berlin  10559",
        "country": "DE"
    },
    "F084C9": {
        "oui_hex": "F0-84-C9",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D4016D": {
        "oui_hex": "D4-01-6D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "985C93": {
        "oui_hex": "98-5C-93",
        "organization": "SBG Systems SAS",
        "address_1": "3bis, chemin de la Jonchere",
        "address_2": "Rueil Malmaison  Ile de France  92500",
        "country": "FR"
    },
    "A08A87": {
        "oui_hex": "A0-8A-87",
        "organization": "HuiZhou KaiYue Electronic Co.,Ltd",
        "address_1": "3#,Ruttang 2nd area,Tongcheng Avenue",
        "address_2": "Huizhou  Guangdong  516005",
        "country": "CN"
    },
    "28CD9C": {
        "oui_hex": "28-CD-9C",
        "organization": "Shenzhen Dynamax Software Development Co.,Ltd.",
        "address_1": "Room 425-426,Block A,No.30,Hangkong Road",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C0C3B6": {
        "oui_hex": "C0-C3-B6",
        "organization": "Automatic Systems",
        "address_1": "avenue mercator,5",
        "address_2": "Wavre  Belgium  1300",
        "country": "BE"
    },
    "A0EB76": {
        "oui_hex": "A0-EB-76",
        "organization": "AirCUVE Inc.",
        "address_1": "Guro-gu Digital-ro",
        "address_2": "  Seoul  152-719",
        "country": "KR"
    },
    "FC4499": {
        "oui_hex": "FC-44-99",
        "organization": "Swarco LEA d.o.o.",
        "address_1": "Finzgarjeva 1A",
        "address_2": "Lesce    4248",
        "country": "SI"
    },
    "DC647C": {
        "oui_hex": "DC-64-7C",
        "organization": "C.R.S. iiMotion GmbH",
        "address_1": "Hermann-Schwer-Str. 3",
        "address_2": "Villingen-Schwenningen    78048",
        "country": "DE"
    },
    "148692": {
        "oui_hex": "14-86-92",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A8154D": {
        "oui_hex": "A8-15-4D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5CF370": {
        "oui_hex": "5C-F3-70",
        "organization": "CC&C Technologies, Inc",
        "address_1": "8F, 150, Chien I Rd.",
        "address_2": "Chung Ho  Taiwan  235",
        "country": "TW"
    },
    "A4E0E6": {
        "oui_hex": "A4-E0-E6",
        "organization": "FILIZOLA S.A. PESAGEM E AUTOMACAO",
        "address_1": "RUA JOAO VENTURA BATISTA, 450",
        "address_2": "  SAO PAULO  02054-100",
        "country": "BR"
    },
    "381766": {
        "oui_hex": "38-17-66",
        "organization": "PROMZAKAZ LTD.",
        "address_1": "Noviy Arbat street, 21",
        "address_2": "  Moscow  119019",
        "country": "RU"
    },
    "18E8DD": {
        "oui_hex": "18-E8-DD",
        "organization": "MODULETEK",
        "address_1": "Unit 4A.4F.B Building. Shenfubao Science and Technology Industrial Park",
        "address_2": "Shenzhen  Guangdong  518038",
        "country": "CN"
    },
    "D073D5": {
        "oui_hex": "D0-73-D5",
        "organization": "LIFI LABS MANAGEMENT PTY LTD",
        "address_1": "7 Cubitt St",
        "address_2": "Richmond  Victoria  3121",
        "country": "AU"
    },
    "149448": {
        "oui_hex": "14-94-48",
        "organization": "BLU CASTLE S.A.",
        "address_1": "5 RUE BONNEVOIE",
        "address_2": "  LUXEMBOURG  L-1260",
        "country": "US"
    },
    "48F925": {
        "oui_hex": "48-F9-25",
        "organization": "Maestronic",
        "address_1": "Futura plaza 2103",
        "address_2": "Kwun Tong    88",
        "country": "HK"
    },
    "386793": {
        "oui_hex": "38-67-93",
        "organization": "Asia Optical Co., Inc.",
        "address_1": "No. 22-3 South 2nd Road, T.E.P.Z.",
        "address_2": "Taichung  Taiwan  42754",
        "country": "TW"
    },
    "0C8268": {
        "oui_hex": "0C-82-68",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D81EDE": {
        "oui_hex": "D8-1E-DE",
        "organization": "B&W Group Ltd",
        "address_1": "5070 Francois Cusson",
        "address_2": "Lachine  Quebec  H8T1B3",
        "country": "CA"
    },
    "24EA40": {
        "oui_hex": "24-EA-40",
        "organization": "Helmholz GmbH & Co. KG",
        "address_1": "Hannberger Weg 2",
        "address_2": "Grossenseebach  BAY  91091",
        "country": "DE"
    },
    "D429EA": {
        "oui_hex": "D4-29-EA",
        "organization": "Zimory GmbH",
        "address_1": "Revalerstrasse 100",
        "address_2": "Berlin  Brandenburg  10245",
        "country": "DE"
    },
    "34ADE4": {
        "oui_hex": "34-AD-E4",
        "organization": "Shanghai Chint Power Systems Co., Ltd.",
        "address_1": "855 Wenhe Road, Block 4",
        "address_2": "    201614",
        "country": "CN"
    },
    "3C94D5": {
        "oui_hex": "3C-94-D5",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "68831A": {
        "oui_hex": "68-83-1A",
        "organization": "Pandora Mobility Corporation",
        "address_1": "1F., No.33, Fude St",
        "address_2": "Taoyuan  Guishan  333",
        "country": "TW"
    },
    "FCDB96": {
        "oui_hex": "FC-DB-96",
        "organization": "ENERVALLEY CO., LTD",
        "address_1": "907-101 DIGITAL EMPIRE II",
        "address_2": "SUWON SI  GYEONGGI DO  443 734",
        "country": "KR"
    },
    "1423D7": {
        "oui_hex": "14-23-D7",
        "organization": "EUTRONIX CO., LTD.",
        "address_1": "EUTRONIX BLDG. 4TH FLOOR",
        "address_2": "ANYANG  KYEONGGI  431-804",
        "country": "US"
    },
    "DC6F08": {
        "oui_hex": "DC-6F-08",
        "organization": "Bay Storage Technology",
        "address_1": "6200 Stoneridge Mall Road",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "90DA4E": {
        "oui_hex": "90-DA-4E",
        "organization": "AVANU",
        "address_1": "5205 Prospect Rd",
        "address_2": "San Jose  CA  95129-5034",
        "country": "US"
    },
    "281878": {
        "oui_hex": "28-18-78",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "7038B4": {
        "oui_hex": "70-38-B4",
        "organization": "Low Tech Solutions",
        "address_1": "350 N. Orleans",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "745F00": {
        "oui_hex": "74-5F-00",
        "organization": "Samsung Semiconductor Inc.",
        "address_1": "3566 N. 1St Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E0C3F3": {
        "oui_hex": "E0-C3-F3",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5C20D0": {
        "oui_hex": "5C-20-D0",
        "organization": "Asoni Communication Co., Ltd.",
        "address_1": " 21F-1, No.97, Sec. 4, Chongsin Rd., Sanchong District",
        "address_2": "New Taipei City  Taiwan  24161",
        "country": "TW"
    },
    "ACA430": {
        "oui_hex": "AC-A4-30",
        "organization": "Peerless AV",
        "address_1": "2300 White Oak Circle",
        "address_2": "Aurora  illinios  60502",
        "country": "US"
    },
    "847A88": {
        "oui_hex": "84-7A-88",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "A4D856": {
        "oui_hex": "A4-D8-56",
        "organization": "Gimbal, Inc",
        "address_1": "12526 High Bluff Drive",
        "address_2": "San Diego  Ca  92130",
        "country": "US"
    },
    "785517": {
        "oui_hex": "78-55-17",
        "organization": "SankyuElectronics",
        "address_1": "2-30-12",
        "address_2": "Ohta-ku  Tokyo  146-0091",
        "country": "JP"
    },
    "B47F5E": {
        "oui_hex": "B4-7F-5E",
        "organization": "Foresight Manufacture (S) Pte Ltd",
        "address_1": "1 Sims Lane #04-09",
        "address_2": "  Singapore  387355",
        "country": "SG"
    },
    "A0FE91": {
        "oui_hex": "A0-FE-91",
        "organization": "AVAT Automation GmbH",
        "address_1": "Derendinger Strasse 40",
        "address_2": "Tuebingen    72072",
        "country": "DE"
    },
    "74ECF1": {
        "oui_hex": "74-EC-F1",
        "organization": "Acumen",
        "address_1": "6F, No.207-3, Sec 3, Beisin Rd",
        "address_2": "Sindian Dist  New Taipei City  23143",
        "country": "US"
    },
    "5809E5": {
        "oui_hex": "58-09-E5",
        "organization": "Kivic Inc.",
        "address_1": "670 Sampyeong-dong, Bundang-gu",
        "address_2": "  Seongnam City  463-400",
        "country": "KR"
    },
    "504F94": {
        "oui_hex": "50-4F-94",
        "organization": "Loxone Electronics GmbH",
        "address_1": "Falkensteinstraße 6",
        "address_2": "Kollerschlag  Upper Austria  4154",
        "country": "AT"
    },
    "60B185": {
        "oui_hex": "60-B1-85",
        "organization": "ATH system",
        "address_1": "Osady Lezaku 498",
        "address_2": "Chrast    53851",
        "country": "CZ"
    },
    "BC629F": {
        "oui_hex": "BC-62-9F",
        "organization": "Telenet Systems P. Ltd.",
        "address_1": "2 Mani Bhuvan, Cama Road",
        "address_2": "Mumbai  Maharashtra  400086",
        "country": "IN"
    },
    "380FE4": {
        "oui_hex": "38-0F-E4",
        "organization": "Dedicated Network Partners Oy",
        "address_1": "Linnoitustie 6",
        "address_2": "Espoo  -  02600",
        "country": "FI"
    },
    "48F230": {
        "oui_hex": "48-F2-30",
        "organization": "Ubizcore Co.,LTD",
        "address_1": "Kranz Techno #1420, Sangdaewon 1-dong",
        "address_2": "Seongnam-Si    462-729",
        "country": "KR"
    },
    "78324F": {
        "oui_hex": "78-32-4F",
        "organization": "Millennium Group, Inc.",
        "address_1": "16 Tech Circle",
        "address_2": "Natick  MA  01760",
        "country": "US"
    },
    "384369": {
        "oui_hex": "38-43-69",
        "organization": "Patrol Products Consortium LLC",
        "address_1": "1128 Narragansett Blvd.",
        "address_2": "Cranston  RI  02905",
        "country": "US"
    },
    "44184F": {
        "oui_hex": "44-18-4F",
        "organization": "Fitview",
        "address_1": "5615 Scotts Valley Drive, Suite 110",
        "address_2": "Scotts Valley  CA  95066",
        "country": "US"
    },
    "84ACA4": {
        "oui_hex": "84-AC-A4",
        "organization": "Beijing Novel Super Digital TV Technology Co., Ltd",
        "address_1": "4F Tower B Jingmeng Hightech building",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "541FD5": {
        "oui_hex": "54-1F-D5",
        "organization": "Advantage Electronics",
        "address_1": "PO Box 407",
        "address_2": "Greenwood  IN  46143",
        "country": "US"
    },
    "ACE97F": {
        "oui_hex": "AC-E9-7F",
        "organization": "IoT Tech Limited",
        "address_1": "20b Lough Road",
        "address_2": "Lisburn  Antrim  BT28 2HA",
        "country": "GB"
    },
    "E85AA7": {
        "oui_hex": "E8-5A-A7",
        "organization": "LLC Emzior",
        "address_1": "Strelna, Svyazi street, 34, Lit A, of. 234",
        "address_2": "Saint-Petersburg    198515",
        "country": "RU"
    },
    "9C9C1D": {
        "oui_hex": "9C-9C-1D",
        "organization": "Starkey Labs Inc.",
        "address_1": "6600 Washington Ave. S.",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "D0D6CC": {
        "oui_hex": "D0-D6-CC",
        "organization": "Wintop",
        "address_1": "No. 1301,Xinfei Road",
        "address_2": "Songjiang District  Shanghai  201612",
        "country": "CN"
    },
    "58D071": {
        "oui_hex": "58-D0-71",
        "organization": "BW Broadcast",
        "address_1": "Unit 27 IO Centre",
        "address_2": "Croydon  Surrey  CR0 4WQ",
        "country": "GB"
    },
    "1C52D6": {
        "oui_hex": "1C-52-D6",
        "organization": "FLAT DISPLAY TECHNOLOGY CORPORATION",
        "address_1": "No.85, Sec. 1, Fuxing Rd., South Dist",
        "address_2": "Taichung    402",
        "country": "TW"
    },
    "D0DFB2": {
        "oui_hex": "D0-DF-B2",
        "organization": "Genie Networks Limited",
        "address_1": "5F, No.15, Lane 360, Sec., 1, Neihu Road,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "386645": {
        "oui_hex": "38-66-45",
        "organization": "OOSIC Technology CO.,Ltd",
        "address_1": "8F,No 1559, Zuchongzhi Road",
        "address_2": "  Shanghai  201203",
        "country": "CN"
    },
    "B85AF7": {
        "oui_hex": "B8-5A-F7",
        "organization": "Ouya, Inc",
        "address_1": "11693 San Vicente Blvd",
        "address_2": "Los Angeles  CA  90049",
        "country": "US"
    },
    "34F62D": {
        "oui_hex": "34-F6-2D",
        "organization": "SHARP Corporation",
        "address_1": "1 Takumi-cho, Sakai-ku",
        "address_2": "Sakai City  Osaka  590-8522",
        "country": "JP"
    },
    "4C8FA5": {
        "oui_hex": "4C-8F-A5",
        "organization": "Jastec",
        "address_1": "Jastec B/D 2F, 92-7 Kumgok-dong,",
        "address_2": "Boondang-gu,    463-804",
        "country": "KR"
    },
    "84ED33": {
        "oui_hex": "84-ED-33",
        "organization": "BBMC Co.,Ltd",
        "address_1": "#301, DaerungPostTower 3, 182-4,",
        "address_2": "Seoul  None  152-746",
        "country": "KR"
    },
    "E82E24": {
        "oui_hex": "E8-2E-24",
        "organization": "Out of the Fog Research LLC",
        "address_1": "565 Clyde Avenue, Suite 620",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "80FA5B": {
        "oui_hex": "80-FA-5B",
        "organization": "CLEVO CO.",
        "address_1": "NO. 129, XINGDE ROAD",
        "address_2": "New TAIPEI CITY    241",
        "country": "TW"
    },
    "C0B339": {
        "oui_hex": "C0-B3-39",
        "organization": "Comigo Ltd.",
        "address_1": "15 HaPardes St.",
        "address_2": "  Yarkona  45915",
        "country": "IL"
    },
    "20858C": {
        "oui_hex": "20-85-8C",
        "organization": "Assa",
        "address_1": "Gurogu Guro3dong Ace Twintower 2cha 209",
        "address_2": "  Seoul  152-779",
        "country": "KR"
    },
    "60CDC5": {
        "oui_hex": "60-CD-C5",
        "organization": "Taiwan Carol Electronics., Ltd",
        "address_1": "No.202, Tung Kuang Road",
        "address_2": "Taichung  Taiwan  40151",
        "country": "TW"
    },
    "D8182B": {
        "oui_hex": "D8-18-2B",
        "organization": "Conti Temic Microelectronic GmbH",
        "address_1": "Sieboldstraße 19",
        "address_2": "Nuremberg  Bavaria  90411",
        "country": "DE"
    },
    "80CF41": {
        "oui_hex": "80-CF-41",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,Torch Hi-tech Industry Development Zone,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "US"
    },
    "9CE1D6": {
        "oui_hex": "9C-E1-D6",
        "organization": "Junger Audio-Studiotechnik GmbH",
        "address_1": "Justus-von-Liebig-Strasse 7",
        "address_2": "12489 Berlin",
        "country": "US"
    },
    "48B9C2": {
        "oui_hex": "48-B9-C2",
        "organization": "Teletics Inc.",
        "address_1": "103 Edgevalley Close NW",
        "address_2": "Calgary  AB  T3A 5E9",
        "country": "CA"
    },
    "58D6D3": {
        "oui_hex": "58-D6-D3",
        "organization": "Dairy Cheq Inc",
        "address_1": "60 Baffin Place, Unit 5",
        "address_2": "Waterloo  Ontario  N2V 1Z7",
        "country": "CA"
    },
    "046E49": {
        "oui_hex": "04-6E-49",
        "organization": "TaiYear Electronic Technology (Suzhou) Co., Ltd",
        "address_1": "12-B101 Creative Industrial Park ,No. 328,Xinghu Street ,Suzhou Industrial Park",
        "address_2": "SuZhou  JiangSu  215000",
        "country": "CN"
    },
    "2C3BFD": {
        "oui_hex": "2C-3B-FD",
        "organization": "Netstor Technology Co., Ltd.",
        "address_1": "6F, No. 1, Alley 16, Lane 235, Baoqiao Rd., Xindian District",
        "address_2": "New Taipei City    23145",
        "country": "US"
    },
    "AC3CB4": {
        "oui_hex": "AC-3C-B4",
        "organization": "Nilan A/S",
        "address_1": "Nilanvej 2",
        "address_2": "Hedensted  Vejle amt  8722",
        "country": "DK"
    },
    "B49DB4": {
        "oui_hex": "B4-9D-B4",
        "organization": "Axion Technologies Inc.",
        "address_1": "105-1203, 70, Jingeononam-ro",
        "address_2": "Namyangju  Gyeonggi-do  472-859",
        "country": "KR"
    },
    "ACE87E": {
        "oui_hex": "AC-E8-7E",
        "organization": "Bytemark Computer Consulting Ltd",
        "address_1": "Unit 2",
        "address_2": "Opus Avenue  York YO26 6BL",
        "country": "GB"
    },
    "8007A2": {
        "oui_hex": "80-07-A2",
        "organization": "Esson Technology Inc.",
        "address_1": "Room A2, 5F Longsheng Commericial Building,",
        "address_2": "Baoan District  ShenZhen  518000",
        "country": "CN"
    },
    "C0A0E2": {
        "oui_hex": "C0-A0-E2",
        "organization": "Eden Innovations",
        "address_1": "ZAC",
        "address_2": "Eguilles  PACA  13510",
        "country": "FR"
    },
    "080FFA": {
        "oui_hex": "08-0F-FA",
        "organization": "KSP INC.",
        "address_1": "RM 501, 138 Kwangdeokdae-ro",
        "address_2": "Danwon-gu, Ansan-si  Gyeonggi-do  425906",
        "country": "KR"
    },
    "E8ABFA": {
        "oui_hex": "E8-AB-FA",
        "organization": "Shenzhen Reecam Tech.Ltd.",
        "address_1": "Room 03D-1 , North Wing Of 3 rd Floor, Block 1 , Vision Shenzhen Business Park",
        "address_2": "Nanshan District, Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "DCB058": {
        "oui_hex": "DC-B0-58",
        "organization": "Bürkert Werke GmbH",
        "address_1": "Christian-Bürkert-Straße 13-17",
        "address_2": "Ingelfingen  Baden-Württemberg  74653",
        "country": "DE"
    },
    "6C5A34": {
        "oui_hex": "6C-5A-34",
        "organization": "Shenzhen Haitianxiong Electronic Co., Ltd.",
        "address_1": "Rm.407, Block A, University-town Business Park, Taoyuan street, Lishan Road",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "9038DF": {
        "oui_hex": "90-38-DF",
        "organization": "Changzhou Tiannengbo System Co. Ltd.",
        "address_1": "#9 East Hehai Road, RM 306",
        "address_2": "Changzhou  Jiangsu Province  213000",
        "country": "CN"
    },
    "185253": {
        "oui_hex": "18-52-53",
        "organization": "Pixord Corporation",
        "address_1": "6F, No 12, Innovation 1st Road",
        "address_2": "Hsinchu    30076",
        "country": "TW"
    },
    "683B1E": {
        "oui_hex": "68-3B-1E",
        "organization": "Countwise LTD",
        "address_1": "1149 Sawgrass Corporate Parkway",
        "address_2": "Sunrise  Florida  33323",
        "country": "US"
    },
    "ACA22C": {
        "oui_hex": "AC-A2-2C",
        "organization": "Baycity Technologies Ltd",
        "address_1": "10 Nazareth Ave",
        "address_2": "Christchurch  Canterbury  8024",
        "country": "NZ"
    },
    "303294": {
        "oui_hex": "30-32-94",
        "organization": "W-IE-NE-R Plein & Baus GmbH",
        "address_1": "Muellersbaum 20",
        "address_2": "Burscheid  NRW  51399",
        "country": "US"
    },
    "7C822D": {
        "oui_hex": "7C-82-2D",
        "organization": "Nortec",
        "address_1": "2740 Fenton Rd",
        "address_2": "Ottawa  ON  K1T3T7",
        "country": "US"
    },
    "10FBF0": {
        "oui_hex": "10-FB-F0",
        "organization": "KangSheng LTD.",
        "address_1": "2F., No.11,",
        "address_2": "New Taipei City    24889",
        "country": "TW"
    },
    "6C9AC9": {
        "oui_hex": "6C-9A-C9",
        "organization": "Valentine Research, Inc.",
        "address_1": "10280 Alliance Rd",
        "address_2": "Cincinnati  OH  45242",
        "country": "US"
    },
    "AC8D14": {
        "oui_hex": "AC-8D-14",
        "organization": "Smartrove Inc",
        "address_1": "19630 Allendale Ave.",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "2091D9": {
        "oui_hex": "20-91-D9",
        "organization": "I'M SPA",
        "address_1": "VIA BIRON 102/3",
        "address_2": "MONTEVIALE  VICENZA  36050",
        "country": "IT"
    },
    "AC7236": {
        "oui_hex": "AC-72-36",
        "organization": "Lexking Technology Co., Ltd.",
        "address_1": "2F, No. 3, Baoqiang Road,",
        "address_2": "New Taipei City  Taiwan  231111",
        "country": "TW"
    },
    "3CD7DA": {
        "oui_hex": "3C-D7-DA",
        "organization": "SK Mtek microelectronics(shenzhen)limited",
        "address_1": "12F, Micro-profit Building,South 6 road",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "04F8C2": {
        "oui_hex": "04-F8-C2",
        "organization": "Flaircomm Microelectronics, Inc.",
        "address_1": "7F,Guomai Building,116 East JiangBin Ave",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "141BF0": {
        "oui_hex": "14-1B-F0",
        "organization": "Intellimedia Systems Ltd",
        "address_1": "Sandhill Barn",
        "address_2": "Washington  West Sussex  RH204TD",
        "country": "GB"
    },
    "5887E2": {
        "oui_hex": "58-87-E2",
        "organization": "Shenzhen Coship Electronics Co., Ltd.",
        "address_1": "Rainbow Bldg., North, Hi-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "6869F2": {
        "oui_hex": "68-69-F2",
        "organization": "ComAp s.r.o.",
        "address_1": "Kundratka 17",
        "address_2": "Prague    18000",
        "country": "CZ"
    },
    "B85AFE": {
        "oui_hex": "B8-5A-FE",
        "organization": "Handaer Communication Technology (Beijing) Co., Ltd",
        "address_1": "Jiancaicheng West Rd.65,Xisanqi,",
        "address_2": "  Beijing  100096",
        "country": "CN"
    },
    "F46DE2": {
        "oui_hex": "F4-6D-E2",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "F0ACA4": {
        "oui_hex": "F0-AC-A4",
        "organization": "HBC-radiomatic",
        "address_1": "Haller Str. 45-53",
        "address_2": "Crailsheim  Baden Wurttemberg  74564",
        "country": "DE"
    },
    "60748D": {
        "oui_hex": "60-74-8D",
        "organization": "Atmaca Elektronik",
        "address_1": "Namik Kemal Mahallesi 177, Sokak No:2",
        "address_2": "Istanbul  Esenyurt  34510",
        "country": "TR"
    },
    "B8B7D7": {
        "oui_hex": "B8-B7-D7",
        "organization": "2GIG Technologies",
        "address_1": "2961 West Maple Loop Drive",
        "address_2": "Lehi  Utah  84043",
        "country": "US"
    },
    "808287": {
        "oui_hex": "80-82-87",
        "organization": "ATCOM Technology Co.Ltd.",
        "address_1": "A-2F, #3 , Crown industry buildings",
        "address_2": "Shenzhen  Guang Dong  518040",
        "country": "US"
    },
    "28A186": {
        "oui_hex": "28-A1-86",
        "organization": "enblink",
        "address_1": "Room 212 Building 105-1 SNU",
        "address_2": "  SEOUL  151-742",
        "country": "KR"
    },
    "503955": {
        "oui_hex": "50-39-55",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "78D129": {
        "oui_hex": "78-D1-29",
        "organization": "Vicos",
        "address_1": "Eugenmuellerstrasse 14",
        "address_2": "Salzburg  Salzburg  5020",
        "country": "AT"
    },
    "84DF0C": {
        "oui_hex": "84-DF-0C",
        "organization": "NET2GRID BV",
        "address_1": "Krullelaan 28",
        "address_2": "Zeist  Utrecht  3701 TD",
        "country": "NL"
    },
    "388EE7": {
        "oui_hex": "38-8E-E7",
        "organization": "Fanhattan LLC",
        "address_1": "489 S El Camino Real",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "5CD41B": {
        "oui_hex": "5C-D4-1B",
        "organization": "UCZOON Technology Co., LTD",
        "address_1": "9 th Floor,Pan Gu Plaza,No.27 North  4 th Ring,",
        "address_2": "Beijing  Beijing  100029",
        "country": "CN"
    },
    "CCE798": {
        "oui_hex": "CC-E7-98",
        "organization": "My Social Stuff",
        "address_1": "Sint-Hubertussyraat 65",
        "address_2": "Berchem    2600",
        "country": "BE"
    },
    "A036F0": {
        "oui_hex": "A0-36-F0",
        "organization": "Comprehensive Power",
        "address_1": "420 Northboro Road Central",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "180CAC": {
        "oui_hex": "18-0C-AC",
        "organization": "CANON INC.",
        "address_1": "3-30-2",
        "address_2": "Ohta-Ku  Tokyo  146-8501",
        "country": "JP"
    },
    "78AB60": {
        "oui_hex": "78-AB-60",
        "organization": "ABB Australia",
        "address_1": "PMB 88",
        "address_2": "Berrimah  NT  0828",
        "country": "AU"
    },
    "8482F4": {
        "oui_hex": "84-82-F4",
        "organization": "Beijing Huasun Unicreate Technology Co., Ltd",
        "address_1": "North Region 6th Floor, Tower A, Huizhi Mansion,",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "00DB1E": {
        "oui_hex": "00-DB-1E",
        "organization": "Albedo Telecom SL",
        "address_1": "Joan d'Austria 112",
        "address_2": "Barcelona    08018",
        "country": "ES"
    },
    "18863A": {
        "oui_hex": "18-86-3A",
        "organization": "DIGITAL ART SYSTEM",
        "address_1": "838 rue de l'Aiguelongue",
        "address_2": "Montpellier  Etat  34090",
        "country": "FR"
    },
    "0CDCCC": {
        "oui_hex": "0C-DC-CC",
        "organization": "Inala Technologies",
        "address_1": "Inala House,  557 15th Road",
        "address_2": "Midrand  Gauteng  1685",
        "country": "ZA"
    },
    "98291D": {
        "oui_hex": "98-29-1D",
        "organization": "Jaguar de Mexico, SA de CV",
        "address_1": "Calle Tabla Grande No.2",
        "address_2": "Jilotzongo  Estado de Mexico  54570",
        "country": "MX"
    },
    "34AF2C": {
        "oui_hex": "34-AF-2C",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "7CD9FE": {
        "oui_hex": "7C-D9-FE",
        "organization": "New Cosmos Electric Co., Ltd.",
        "address_1": "2-5-4 Mitsuyanaka",
        "address_2": "Osaka  Osaka-fu  532-0036",
        "country": "JP"
    },
    "E49069": {
        "oui_hex": "E4-90-69",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "CCC104": {
        "oui_hex": "CC-C1-04",
        "organization": "Applied Technical Systems",
        "address_1": "P.O. Box 5705",
        "address_2": "Shreveport  LA  71135",
        "country": "US"
    },
    "A4B1E9": {
        "oui_hex": "A4-B1-E9",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "60455E": {
        "oui_hex": "60-45-5E",
        "organization": "Liptel s.r.o.",
        "address_1": "Hradna 338",
        "address_2": "Liptovsky Hradok    03301",
        "country": "SK"
    },
    "D806D1": {
        "oui_hex": "D8-06-D1",
        "organization": "Honeywell Fire System (Shanghai) Co,. Ltd.",
        "address_1": "No. 430, Li Bing Road, Pudong",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "647657": {
        "oui_hex": "64-76-57",
        "organization": "Innovative Security Designs",
        "address_1": "18 Technology Drive",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "907025": {
        "oui_hex": "90-70-25",
        "organization": "Garea Microsys Co.,Ltd.",
        "address_1": "4th Floor, Building 2, Software Park",
        "address_2": "Suzhou  Jiangsu  215163",
        "country": "CN"
    },
    "10D1DC": {
        "oui_hex": "10-D1-DC",
        "organization": "INSTAR Deutschland GmbH",
        "address_1": "Auf der Hostert 17",
        "address_2": "Huenstetten Bechtheim  Hessen  65510",
        "country": "DE"
    },
    "34996F": {
        "oui_hex": "34-99-6F",
        "organization": "VPI Engineering",
        "address_1": "11814 S. Election Rd., Suite 200",
        "address_2": "Draper  UT  84020",
        "country": "US"
    },
    "944A09": {
        "oui_hex": "94-4A-09",
        "organization": "BitWise Controls",
        "address_1": "98 Inverness Dr East",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "BC28D6": {
        "oui_hex": "BC-28-D6",
        "organization": "Rowley Associates Limited",
        "address_1": "Suite 4B/4C Drake House",
        "address_2": "Dursley  Gloucestershire  GL11 4HH",
        "country": "GB"
    },
    "10BD18": {
        "oui_hex": "10-BD-18",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5869F9": {
        "oui_hex": "58-69-F9",
        "organization": "Fusion Transactive Ltd.",
        "address_1": "PO Box 68281",
        "address_2": "Auckland    1145",
        "country": "NZ"
    },
    "D41E35": {
        "oui_hex": "D4-1E-35",
        "organization": "TOHO Electronics INC.",
        "address_1": "1-13-21 Tanashioda, Chuo-Ku",
        "address_2": "Sagamihara-City  Kanagawa  252-0245",
        "country": "JP"
    },
    "4C72B9": {
        "oui_hex": "4C-72-B9",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "2CEDEB": {
        "oui_hex": "2C-ED-EB",
        "organization": "Alpheus Digital Company Limited",
        "address_1": "Room 2, 23/F Tak King Industrial building",
        "address_2": "Hong Kong    852",
        "country": "HK"
    },
    "0CD996": {
        "oui_hex": "0C-D9-96",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "30F33A": {
        "oui_hex": "30-F3-3A",
        "organization": "+plugg srl",
        "address_1": "via giovanni ventura, 5",
        "address_2": "Milano  MI  20134",
        "country": "IT"
    },
    "0C57EB": {
        "oui_hex": "0C-57-EB",
        "organization": "Mueller Systems",
        "address_1": "48 Leona Drive, Suite C",
        "address_2": "Middleboro  MA  02346",
        "country": "US"
    },
    "745327": {
        "oui_hex": "74-53-27",
        "organization": "COMMSEN CO., LIMITED",
        "address_1": "12/F., San Toi Building,139 Connaught Road Central",
        "address_2": "    999077",
        "country": "HK"
    },
    "D08CFF": {
        "oui_hex": "D0-8C-FF",
        "organization": "UPWIS AB",
        "address_1": "Box 3000",
        "address_2": "Uppsala  Uppsala  75003",
        "country": "SE"
    },
    "68CE4E": {
        "oui_hex": "68-CE-4E",
        "organization": "L-3 Communications Infrared Products",
        "address_1": "3414 Herrmann Drive",
        "address_2": "Garland  TX  75043",
        "country": "US"
    },
    "68D1FD": {
        "oui_hex": "68-D1-FD",
        "organization": "Shenzhen Trimax Technology Co.,Ltd",
        "address_1": "Room 1016, 10F, Max Smart Commercial Center,",
        "address_2": "Shenzhen  Guangdong  518133",
        "country": "CN"
    },
    "9C066E": {
        "oui_hex": "9C-06-6E",
        "organization": "Hytera Communications Corporation Limited",
        "address_1": "Hytera Tower, Hi-Tech Industrial Park North, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "US"
    },
    "3CEAFB": {
        "oui_hex": "3C-EA-FB",
        "organization": "NSE AG",
        "address_1": "Bremgarterstrasse 54",
        "address_2": "Wohlen  AG  5610",
        "country": "CH"
    },
    "8CC7AA": {
        "oui_hex": "8C-C7-AA",
        "organization": "Radinet Communications Inc.",
        "address_1": "7F-2, No.229, Fuxing 2nd Rd, Zhubei, 30271",
        "address_2": "Hsinchu  Taiwan  30271",
        "country": "US"
    },
    "40336C": {
        "oui_hex": "40-33-6C",
        "organization": "Godrej & Boyce Mfg. co. ltd",
        "address_1": "PSS TECH CELL, 2ND FLOOR, PLANT 17, SECURITY SOLUTIONS DIVISION",
        "address_2": "MUMBAI  MAHARASHTRA  400079",
        "country": "IN"
    },
    "F8A03D": {
        "oui_hex": "F8-A0-3D",
        "organization": "Dinstar Technologies Co., Ltd.",
        "address_1": "Floor 6, Guoxing Building",
        "address_2": "shenzhen  Guangdong  518052",
        "country": "US"
    },
    "2CD444": {
        "oui_hex": "2C-D4-44",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "BC811F": {
        "oui_hex": "BC-81-1F",
        "organization": "Ingate Systems",
        "address_1": "Rissneleden 45",
        "address_2": "Sundbyberg    17444",
        "country": "SE"
    },
    "D867D9": {
        "oui_hex": "D8-67-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4E731": {
        "oui_hex": "A4-E7-31",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "98A7B0": {
        "oui_hex": "98-A7-B0",
        "organization": "MCST ZAO",
        "address_1": "35/50, Nizhnyaya Krasnoselskaya St.,",
        "address_2": "Moscow    105666",
        "country": "RU"
    },
    "4C068A": {
        "oui_hex": "4C-06-8A",
        "organization": "Basler Electric Company",
        "address_1": "12570 State Route 143",
        "address_2": "Highland  Illinois  62249",
        "country": "US"
    },
    "E856D6": {
        "oui_hex": "E8-56-D6",
        "organization": "NCTech Ltd",
        "address_1": "20-22 Braid Road",
        "address_2": "Edinburgh    EH10 6AD",
        "country": "GB"
    },
    "C08170": {
        "oui_hex": "C0-81-70",
        "organization": "Effigis GeoSolutions",
        "address_1": "4101, rue Molson",
        "address_2": "Montreal  Quebec  H1Y3L1",
        "country": "CA"
    },
    "642216": {
        "oui_hex": "64-22-16",
        "organization": "Shandong Taixin Electronic co.,Ltd",
        "address_1": "FL.6,Haichen Building",
        "address_2": "Jinan  Shandong  250010",
        "country": "CN"
    },
    "443839": {
        "oui_hex": "44-38-39",
        "organization": "Cumulus Networks, inc",
        "address_1": "650 Castro Street, suite 120-245",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "048B42": {
        "oui_hex": "04-8B-42",
        "organization": "Skspruce Technologies",
        "address_1": "A1, Tianfu Software Park, 1129 Century City Road",
        "address_2": "High-tech Zone, Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "5076A6": {
        "oui_hex": "50-76-A6",
        "organization": "Ecil Informatica Ind. Com. Ltda",
        "address_1": "Av. Araguacema, 388",
        "address_2": "Barueri  São Paulo  06460-070",
        "country": "BR"
    },
    "A44C11": {
        "oui_hex": "A4-4C-11",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "60843B": {
        "oui_hex": "60-84-3B",
        "organization": "Soladigm, Inc.",
        "address_1": "195. S Milpitas Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "AC4BC8": {
        "oui_hex": "AC-4B-C8",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "209BA5": {
        "oui_hex": "20-9B-A5",
        "organization": "JIAXING GLEAD Electronics Co.,Ltd",
        "address_1": "No.66 Zhengyuan Road in Tanghu Industrial Garden",
        "address_2": "Jiaxing  Zhejiang  314003",
        "country": "CN"
    },
    "A0F450": {
        "oui_hex": "A0-F4-50",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "6089B1": {
        "oui_hex": "60-89-B1",
        "organization": "Key Digital Systems",
        "address_1": "521 E 3rd Street",
        "address_2": "Mount Vernon  NY  10553",
        "country": "US"
    },
    "44D15E": {
        "oui_hex": "44-D1-5E",
        "organization": "Shanghai Kingto Information Technology Ltd",
        "address_1": "No.738 Guangji RD.3F shanghai.china",
        "address_2": "  shanghai  200434",
        "country": "CN"
    },
    "0036FE": {
        "oui_hex": "00-36-FE",
        "organization": "SuperVision",
        "address_1": "po box 3472",
        "address_2": "palos verdes  CA  90274",
        "country": "US"
    },
    "709E86": {
        "oui_hex": "70-9E-86",
        "organization": "X6D Limited",
        "address_1": "199, Arch. Makariou III",
        "address_2": "Limassol    3030",
        "country": "CY"
    },
    "A0F419": {
        "oui_hex": "A0-F4-19",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "1C973D": {
        "oui_hex": "1C-97-3D",
        "organization": "PRICOM Design",
        "address_1": "2755 Slocum Rd",
        "address_2": "Peyton  CO  80831",
        "country": "US"
    },
    "BC0200": {
        "oui_hex": "BC-02-00",
        "organization": "Stewart Audio",
        "address_1": "100 West El Camino Real",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "489153": {
        "oui_hex": "48-91-53",
        "organization": "Weinmann Geräte für Medizin GmbH + Co. KG",
        "address_1": "Kronsaalsweg 40",
        "address_2": "Hamburg    D-22525",
        "country": "DE"
    },
    "AC9403": {
        "oui_hex": "AC-94-03",
        "organization": "Envision Peripherals Inc",
        "address_1": "47490 Seabridge Dr",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "68D925": {
        "oui_hex": "68-D9-25",
        "organization": "ProSys Development Services",
        "address_1": "Mill House",
        "address_2": "Mitcham  Surrey  CR4 4HY",
        "country": "GB"
    },
    "848D84": {
        "oui_hex": "84-8D-84",
        "organization": "Rajant Corporation",
        "address_1": "400 East King Street",
        "address_2": "Malvern  PA  19355",
        "country": "US"
    },
    "54466B": {
        "oui_hex": "54-46-6B",
        "organization": "Shenzhen CZTIC Electronic Technology Co., Ltd",
        "address_1": "Xinghe Building, Zhongxin Road, Shajing Town, Baoan",
        "address_2": "SHENZHEN  GUANGDONG  518104",
        "country": "CN"
    },
    "44B382": {
        "oui_hex": "44-B3-82",
        "organization": "Kuang-chi Institute of Advanced Technology",
        "address_1": "Software building, Gaoxingzhong 1st Road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "60B933": {
        "oui_hex": "60-B9-33",
        "organization": "Deutron Electronics Corp.",
        "address_1": "8F, 68, Sec. 3, Nanking E. Rd.",
        "address_2": "Taipei  Taiwan  104",
        "country": "TW"
    },
    "0043FF": {
        "oui_hex": "00-43-FF",
        "organization": "KETRON S.R.L.",
        "address_1": "Via Giuseppe Taliercio n. 7",
        "address_2": "Ancona    60131",
        "country": "IT"
    },
    "7CACB2": {
        "oui_hex": "7C-AC-B2",
        "organization": "Bosch Software Innovations GmbH",
        "address_1": "Ziegelei 7",
        "address_2": "Immenstaad  BadenWuertemberg  88090",
        "country": "DE"
    },
    "18D66A": {
        "oui_hex": "18-D6-6A",
        "organization": "Inmarsat",
        "address_1": "99 City Road",
        "address_2": "London    EC1Y 1AX",
        "country": "GB"
    },
    "1C7C45": {
        "oui_hex": "1C-7C-45",
        "organization": "Vitek Industrial Video Products, Inc.",
        "address_1": "28492 Constellation Rd",
        "address_2": "Valencia  CA  91355",
        "country": "US"
    },
    "3C3888": {
        "oui_hex": "3C-38-88",
        "organization": "ConnectQuest, llc",
        "address_1": "P.O. Box 425",
        "address_2": "West Simsbury  Connecticut  06092",
        "country": "US"
    },
    "48D7FF": {
        "oui_hex": "48-D7-FF",
        "organization": "BLANKOM Antennentechnik GmbH",
        "address_1": "Hermann-Petersilge Str. 1",
        "address_2": "Bad Blankenburg  TH  07422",
        "country": "DE"
    },
    "C47130": {
        "oui_hex": "C4-71-30",
        "organization": "Fon Technology S.L.",
        "address_1": "Avda. Bruselas, n. 7, Planta 3, Alcobendas",
        "address_2": "  Madrid  28100",
        "country": "ES"
    },
    "D8337F": {
        "oui_hex": "D8-33-7F",
        "organization": "Office FA.com Co.,Ltd.",
        "address_1": "293-21",
        "address_2": "Oyama-shi  Tochigi  329-0216",
        "country": "JP"
    },
    "0036F8": {
        "oui_hex": "00-36-F8",
        "organization": "Conti Temic microelectronic GmbH",
        "address_1": "Dornierstraße 1",
        "address_2": "Markdorf    88677",
        "country": "DE"
    },
    "A4F7D0": {
        "oui_hex": "A4-F7-D0",
        "organization": "LAN Accessories Co., Ltd.",
        "address_1": "8F-1, No. 159, Sec. 1 Hsin Tai Wu Road,",
        "address_2": "New Taipei City,    221",
        "country": "US"
    },
    "C85645": {
        "oui_hex": "C8-56-45",
        "organization": "Intermas France",
        "address_1": "Rue de l'industrie",
        "address_2": "Beauvais  Oise  60000",
        "country": "FR"
    },
    "44348F": {
        "oui_hex": "44-34-8F",
        "organization": "MXT INDUSTRIAL LTDA",
        "address_1": "RODOVIA BR 381, KM 490, JARDIM DAS ALTEROSAS",
        "address_2": "BETIM  MINAS GERAIS  32670790",
        "country": "BR"
    },
    "D4EC0C": {
        "oui_hex": "D4-EC-0C",
        "organization": "Harley-Davidson Motor Company",
        "address_1": "3700 W. Juneau Avenue",
        "address_2": "Milwaukee  Wisconsin  53208",
        "country": "US"
    },
    "28E608": {
        "oui_hex": "28-E6-08",
        "organization": "Tokheim",
        "address_1": "Industrieweg 5",
        "address_2": "Bladel  NBr  5531 AD",
        "country": "NL"
    },
    "74FF7D": {
        "oui_hex": "74-FF-7D",
        "organization": "Wren Sound Systems, LLC",
        "address_1": "169 Gateshead Way",
        "address_2": "Phoenixville  PA  19460",
        "country": "US"
    },
    "ACF0B2": {
        "oui_hex": "AC-F0-B2",
        "organization": "Becker Electronics Taiwan Ltd.",
        "address_1": "No.32, Lane 30, Long Yuan Rd.",
        "address_2": "Long-Tan  Taoyuan  32544",
        "country": "TW"
    },
    "542A9C": {
        "oui_hex": "54-2A-9C",
        "organization": "LSY Defense, LLC.",
        "address_1": "4175 Westport Rd.",
        "address_2": "Louisville  Kentucky  40207",
        "country": "US"
    },
    "504A5E": {
        "oui_hex": "50-4A-5E",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine  California  92618",
        "country": "US"
    },
    "6CA96F": {
        "oui_hex": "6C-A9-6F",
        "organization": "TransPacket AS",
        "address_1": "Drammensveien 134",
        "address_2": "Oslo    0277",
        "country": "NO"
    },
    "AC0142": {
        "oui_hex": "AC-01-42",
        "organization": "Uriel Technologies SIA",
        "address_1": "Dzerbenes iela 14",
        "address_2": "Riga    LV-1006",
        "country": "LV"
    },
    "C47BA3": {
        "oui_hex": "C4-7B-A3",
        "organization": "NAVIS Inc.",
        "address_1": "Dmitrovskoe shosse 157",
        "address_2": "Moscow    127411",
        "country": "RU"
    },
    "F44848": {
        "oui_hex": "F4-48-48",
        "organization": "Amscreen Group Ltd",
        "address_1": "Paragon Business Park",
        "address_2": "Bolton  Lancs  BL6 6HG",
        "country": "GB"
    },
    "50D274": {
        "oui_hex": "50-D2-74",
        "organization": "Steffes Corporation",
        "address_1": "3050 Highway 22 North",
        "address_2": "Dickinson  ND  58601",
        "country": "US"
    },
    "C8F704": {
        "oui_hex": "C8-F7-04",
        "organization": "Building Block Video",
        "address_1": "17 APex Park",
        "address_2": "Hailsham  East Sussex  BN27 2JU",
        "country": "GB"
    },
    "508A42": {
        "oui_hex": "50-8A-42",
        "organization": "Uptmate Technology Co., LTD",
        "address_1": "6F., No.5, Jian 1st Rd.,Zhonghe Dist.,",
        "address_2": "New Taipei City    23558",
        "country": "TW"
    },
    "BCEA2B": {
        "oui_hex": "BC-EA-2B",
        "organization": "CityCom GmbH",
        "address_1": "Am Kroit 25",
        "address_2": "Amerang  Bavaria  83123",
        "country": "DE"
    },
    "0CA138": {
        "oui_hex": "0C-A1-38",
        "organization": "Blinq Wireless Inc.",
        "address_1": "400 MARCH RD UNIT 240",
        "address_2": "KANATA  ON  K2K3H4",
        "country": "CA"
    },
    "5C6F4F": {
        "oui_hex": "5C-6F-4F",
        "organization": "S.A. SISTEL",
        "address_1": "C/SOLSONES, 87",
        "address_2": "CASTELLAR DEL VALLES  BARCELONA  08211",
        "country": "ES"
    },
    "901B0E": {
        "oui_hex": "90-1B-0E",
        "organization": "Fujitsu Technology Solutions GmbH",
        "address_1": "Buergermeister-Ulrich-Strasse 100",
        "address_2": "Augsburg  Bayern  86199",
        "country": "DE"
    },
    "F85063": {
        "oui_hex": "F8-50-63",
        "organization": "Verathon",
        "address_1": "20001 N Creek Pkwy",
        "address_2": "Bothell  WA  98011",
        "country": "US"
    },
    "2C36F8": {
        "oui_hex": "2C-36-F8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "845787": {
        "oui_hex": "84-57-87",
        "organization": "DVR C&C Co., Ltd.",
        "address_1": "7F 720 Namkwang Centlex Bldg, Cheongcheon-dong, Bupyeong-gu",
        "address_2": "Incheon    403-030",
        "country": "KR"
    },
    "5808FA": {
        "oui_hex": "58-08-FA",
        "organization": "Fiber Optic & telecommunication INC.",
        "address_1": "161-4 Kumjeong-Dong,",
        "address_2": "Kunpo-city  Gyeonggi-Do  435-824",
        "country": "KR"
    },
    "AC3D05": {
        "oui_hex": "AC-3D-05",
        "organization": "Instorescreen Aisa",
        "address_1": "Room 207, North Bldg,No 28",
        "address_2": "Shanghai    200237",
        "country": "CN"
    },
    "286094": {
        "oui_hex": "28-60-94",
        "organization": "CAPELEC",
        "address_1": "1130 rue des Marels",
        "address_2": "Montpellier  Hérault  34000",
        "country": "FR"
    },
    "A45630": {
        "oui_hex": "A4-56-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C43C3C": {
        "oui_hex": "C4-3C-3C",
        "organization": "CYBELEC SA",
        "address_1": "Rue des Uttins 27",
        "address_2": "Yverdon-les-Bains    1401",
        "country": "CH"
    },
    "B826D4": {
        "oui_hex": "B8-26-D4",
        "organization": "Furukawa Industrial S.A. Produtos Elétricos",
        "address_1": "Rua Hasdrubal Bellegard, 820",
        "address_2": "  Parana  81460-120",
        "country": "BR"
    },
    "B87447": {
        "oui_hex": "B8-74-47",
        "organization": "Convergence Technologies",
        "address_1": "16W215 83rd Street Suite D",
        "address_2": "Burr Ridge  IL  60527",
        "country": "US"
    },
    "7463DF": {
        "oui_hex": "74-63-DF",
        "organization": "VTS GmbH",
        "address_1": "Am Königholz Ost 4",
        "address_2": "Eglhausen  Bavaria  85411",
        "country": "DE"
    },
    "BC125E": {
        "oui_hex": "BC-12-5E",
        "organization": "Beijing  WisVideo  INC.",
        "address_1": "RM 3A08 Technology&Fortune Center A block No.8 Xue Qing Road,Haidian District ,",
        "address_2": "  Beijing  100192",
        "country": "CN"
    },
    "14E4EC": {
        "oui_hex": "14-E4-EC",
        "organization": "mLogic LLC",
        "address_1": "8440 Warner Drive",
        "address_2": "Culver City  CA  90232",
        "country": "US"
    },
    "3828EA": {
        "oui_hex": "38-28-EA",
        "organization": "Fujian Netcom Technology Co., LTD",
        "address_1": "Netcom Technology Building, B Zone:Tongpan Software Park,",
        "address_2": "Fuzhou  Fujian  350003",
        "country": "CN"
    },
    "D01AA7": {
        "oui_hex": "D0-1A-A7",
        "organization": "UniPrint",
        "address_1": "Unit 309, 1 Eva Road",
        "address_2": "Toronto  Ontario  M9C 4Z5",
        "country": "CA"
    },
    "846AED": {
        "oui_hex": "84-6A-ED",
        "organization": "Wireless Tsukamoto.,co.LTD",
        "address_1": "16-21 1chome,Isoyama",
        "address_2": "Suzuka  Mie-pref  5100256",
        "country": "JP"
    },
    "E05DA6": {
        "oui_hex": "E0-5D-A6",
        "organization": "Detlef Fink Elektronik & Softwareentwicklung",
        "address_1": "Brühlstraße 13",
        "address_2": "Mössingen    72116",
        "country": "DE"
    },
    "045A95": {
        "oui_hex": "04-5A-95",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "04F4BC": {
        "oui_hex": "04-F4-BC",
        "organization": "Xena Networks",
        "address_1": "Graabroedretorv 6, 3. sal",
        "address_2": "København  Danmark  1154",
        "country": "DK"
    },
    "80DB31": {
        "oui_hex": "80-DB-31",
        "organization": "Power Quotient International Co., Ltd.",
        "address_1": "8F., No. 49, Sec. 4, Jhongyang Rd., Tu Cheng Dist.,",
        "address_2": "New Taipei City    23675",
        "country": "TW"
    },
    "1C51B5": {
        "oui_hex": "1C-51-B5",
        "organization": "Techaya LTD",
        "address_1": "P.O.B 1500",
        "address_2": "Pardes Hanna    3700",
        "country": "IL"
    },
    "6C3A84": {
        "oui_hex": "6C-3A-84",
        "organization": "Shenzhen Aero-Startech. Co.Ltd",
        "address_1": "F3-4, Building3,Zhongyuntai Industrial Park.Shiyan Town.,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "00D632": {
        "oui_hex": "00-D6-32",
        "organization": "GE Energy",
        "address_1": "Lissue Industrial Estate East",
        "address_2": "Lisburn  Co Antrim  BT28 2RE",
        "country": "GB"
    },
    "0C9E91": {
        "oui_hex": "0C-9E-91",
        "organization": "Sankosha Corporation",
        "address_1": "1-12, Miyashimo",
        "address_2": "Sagamihara-shi  Kanagawa-ken  252-0212",
        "country": "JP"
    },
    "383F10": {
        "oui_hex": "38-3F-10",
        "organization": "DBL Technology Ltd.",
        "address_1": "Unit 42, 18/F., Block D, Wah Lok Industrial Center",
        "address_2": "",
        "country": "HK"
    },
    "ACD364": {
        "oui_hex": "AC-D3-64",
        "organization": "ABB SPA, ABB SACE DIV.",
        "address_1": "V.LE DELL'INDUSTRIA, 18",
        "address_2": "VITTUONE  MI  20010",
        "country": "IT"
    },
    "2CEE26": {
        "oui_hex": "2C-EE-26",
        "organization": "Petroleum Geo-Services",
        "address_1": "12555 Harris Branch Pkwy",
        "address_2": "Austin  TX  78653",
        "country": "US"
    },
    "C8F9F9": {
        "oui_hex": "C8-F9-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4EF52": {
        "oui_hex": "A4-EF-52",
        "organization": "Telewave Co., Ltd.",
        "address_1": "A-203, SK Twintech Tower",
        "address_2": "Seoul    153-773",
        "country": "KR"
    },
    "A826D9": {
        "oui_hex": "A8-26-D9",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "28940F": {
        "oui_hex": "28-94-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B8DAF7": {
        "oui_hex": "B8-DA-F7",
        "organization": "Advanced Photonics, Inc.",
        "address_1": "the University of Tokyo, CCR507",
        "address_2": "Meguro-ku  Tokyo  153-8904",
        "country": "JP"
    },
    "143AEA": {
        "oui_hex": "14-3A-EA",
        "organization": "Dynapower Company LLC",
        "address_1": "85 Meadowland Drive",
        "address_2": "South Burlington  VT  05403",
        "country": "US"
    },
    "A086EC": {
        "oui_hex": "A0-86-EC",
        "organization": "SAEHAN HITEC Co., Ltd",
        "address_1": "16-3, Yongsu-ri, Chowol-eup",
        "address_2": "Gwangju-si, Gyeonggi-do    464-865",
        "country": "KR"
    },
    "942E17": {
        "oui_hex": "94-2E-17",
        "organization": "Schneider Electric Canada Inc",
        "address_1": "1400 industrielle street",
        "address_2": "La Prairie  Quebec  J5R 2E5",
        "country": "CA"
    },
    "C46044": {
        "oui_hex": "C4-60-44",
        "organization": "Everex Electronics Limited",
        "address_1": "Unit 3, Block A, 16/F",
        "address_2": "",
        "country": "HK"
    },
    "98FE03": {
        "oui_hex": "98-FE-03",
        "organization": "Ericsson - North America",
        "address_1": "6300 Legacy Drive",
        "address_2": "Plano  TX  75024",
        "country": "US"
    },
    "E03C5B": {
        "oui_hex": "E0-3C-5B",
        "organization": "SHENZHEN JIAXINJIE ELECTRON CO.,LTD",
        "address_1": "Shenzhen Jiaxinjie Security Industrial park,No 6 Xin He Xin xing Industrial Park, Fuyong Town,Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518103",
        "country": "CN"
    },
    "CC944A": {
        "oui_hex": "CC-94-4A",
        "organization": "Pfeiffer Vacuum GmbH",
        "address_1": "Berliner Str. 43",
        "address_2": "Asslar  Hessen  35614",
        "country": "DE"
    },
    "0C8525": {
        "oui_hex": "0C-85-25",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B4D8A9": {
        "oui_hex": "B4-D8-A9",
        "organization": "BetterBots",
        "address_1": "1600 Wilson Way SE, Ste. 9",
        "address_2": "Smyrna  GA  30082",
        "country": "US"
    },
    "7CC8D7": {
        "oui_hex": "7C-C8-D7",
        "organization": "Damalisk",
        "address_1": "Coriolis 2",
        "address_2": "ECUISSES    71210",
        "country": "FR"
    },
    "9CB008": {
        "oui_hex": "9C-B0-08",
        "organization": "Ubiquitous Computing Technology Corporation",
        "address_1": "2-20-1 Nishi-Gotanda",
        "address_2": "Shinagawa-ku  Tokyo  1410031",
        "country": "JP"
    },
    "A8776F": {
        "oui_hex": "A8-77-6F",
        "organization": "Zonoff",
        "address_1": "70E Swedesford Rd",
        "address_2": "Malvern  PA  19355",
        "country": "US"
    },
    "648788": {
        "oui_hex": "64-87-88",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00FA3B": {
        "oui_hex": "00-FA-3B",
        "organization": "CLOOS ELECTRONIC GMBH",
        "address_1": "Jambe ducommun 8",
        "address_2": "LE LOCLE    2400",
        "country": "CH"
    },
    "541DFB": {
        "oui_hex": "54-1D-FB",
        "organization": "Freestyle Energy Ltd",
        "address_1": "18-24 Ricketts Road",
        "address_2": "Mount Waverley  Victoria  3149",
        "country": "AU"
    },
    "60B606": {
        "oui_hex": "60-B6-06",
        "organization": "Phorus",
        "address_1": "16255 Ventura Boulevard, Suite 310",
        "address_2": "Encino  CA  91436",
        "country": "US"
    },
    "9092B4": {
        "oui_hex": "90-92-B4",
        "organization": "Diehl BGT Defence GmbH & Co. KG",
        "address_1": "Alte Nussdorfer Strasse 13",
        "address_2": "Ueberlingen    88662",
        "country": "DE"
    },
    "20AA4B": {
        "oui_hex": "20-AA-4B",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "CC6DEF": {
        "oui_hex": "CC-6D-EF",
        "organization": "TJK Tietolaite Oy",
        "address_1": "PL 443",
        "address_2": "Vaasa    65101",
        "country": "FI"
    },
    "A85BF3": {
        "oui_hex": "A8-5B-F3",
        "organization": "Audivo GmbH",
        "address_1": "Irrenloher Damm 17",
        "address_2": "Schwarzenfeld    92521",
        "country": "DE"
    },
    "B8975A": {
        "oui_hex": "B8-97-5A",
        "organization": "BIOSTAR Microtech Int'l Corp.",
        "address_1": "2Fl.  No. 108-2, Min Chuan Road, Hsin Tien Dist.,",
        "address_2": " New Taipei    231",
        "country": "TW"
    },
    "4833DD": {
        "oui_hex": "48-33-DD",
        "organization": "ZENNIO AVANCE Y TECNOLOGIA, S.L.",
        "address_1": "RIO JARAMA 132 NAVE P8.11",
        "address_2": "TOLEDO    45007",
        "country": "ES"
    },
    "087572": {
        "oui_hex": "08-75-72",
        "organization": "Obelux Oy",
        "address_1": "Kutomotie 6 B",
        "address_2": "Helsinki    00380",
        "country": "FI"
    },
    "10C2BA": {
        "oui_hex": "10-C2-BA",
        "organization": "UTT Co., Ltd.",
        "address_1": "",
        "address_2": "Seoul  Korea  135-913",
        "country": "KR"
    },
    "90D74F": {
        "oui_hex": "90-D7-4F",
        "organization": "Bookeen",
        "address_1": "27, rue de la Vistule",
        "address_2": "Paris    75013",
        "country": "FR"
    },
    "64C5AA": {
        "oui_hex": "64-C5-AA",
        "organization": "South African Broadcasting Corporation",
        "address_1": "77 Twickenham Avenue",
        "address_2": "Auckland Park  Gauteng  2006",
        "country": "ZA"
    },
    "98AAD7": {
        "oui_hex": "98-AA-D7",
        "organization": "BLUE WAVE NETWORKING CO LTD",
        "address_1": "No. 20, Lane 68, Da-feng RD,",
        "address_2": "NEW TAIPEI  TAIPEI   23121",
        "country": "TW"
    },
    "9C53CD": {
        "oui_hex": "9C-53-CD",
        "organization": "ENGICAM s.r.l.",
        "address_1": "Via Dei Pratoni n.16",
        "address_2": "Scandicci  FIRENZE  50018",
        "country": "IT"
    },
    "608645": {
        "oui_hex": "60-86-45",
        "organization": "Avery Weigh-Tronix, LLC",
        "address_1": "1000 Armstrong Drive",
        "address_2": "Fairmont  MN  56031",
        "country": "US"
    },
    "FC8FC4": {
        "oui_hex": "FC-8F-C4",
        "organization": "Intelligent Technology Inc.",
        "address_1": "Yuanhe 3 Street,Tongsha Industrial Zone,",
        "address_2": "Dongguan  Guangdong  523127",
        "country": "CN"
    },
    "10FC54": {
        "oui_hex": "10-FC-54",
        "organization": "Shany Electronic Co., Ltd.",
        "address_1": "4F, No. 92, Section 1, Nei-Hu Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "C02973": {
        "oui_hex": "C0-29-73",
        "organization": "Audyssey Laboratories Inc.",
        "address_1": "110 E. 9th Street, Suite C700",
        "address_2": "Los Angeles  CA  90079",
        "country": "US"
    },
    "78FE3D": {
        "oui_hex": "78-FE-3D",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2838CF": {
        "oui_hex": "28-38-CF",
        "organization": "Gen2wave",
        "address_1": "Gumi-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-741",
        "country": "KR"
    },
    "24BC82": {
        "oui_hex": "24-BC-82",
        "organization": "Dali Wireless, Inc.",
        "address_1": "125 University Avenue, Suite 88",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "B40C25": {
        "oui_hex": "B4-0C-25",
        "organization": "Palo Alto Networks",
        "address_1": "4401 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "F8F7D3": {
        "oui_hex": "F8-F7-D3",
        "organization": "International Communications Corporation",
        "address_1": "11801 Pierce St. 2nd FL",
        "address_2": "Riverside  CA  92505",
        "country": "US"
    },
    "28D1AF": {
        "oui_hex": "28-D1-AF",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "24C0B3": {
        "oui_hex": "24-C0-B3",
        "organization": "RSF",
        "address_1": "45 Av Marcel Dassault",
        "address_2": "Toulouse  Garonne, Haute (31)  31500",
        "country": "FR"
    },
    "FC455F": {
        "oui_hex": "FC-45-5F",
        "organization": "JIANGXI SHANSHUI OPTOELECTRONIC TECHNOLOGY CO.,LTD",
        "address_1": "No.1010,Anping Road,Eco-Industrial Park,Lushan District",
        "address_2": "Jiujiang  Jiangxi  332000",
        "country": "CN"
    },
    "F04A2B": {
        "oui_hex": "F0-4A-2B",
        "organization": "PYRAMID Computer GmbH",
        "address_1": "Boetzinger Strasse 60",
        "address_2": "Freiburg  BW  79111",
        "country": "DE"
    },
    "302DE8": {
        "oui_hex": "30-2D-E8",
        "organization": "JDA, LLC (JDA Systems)",
        "address_1": "4080 Pike Lane",
        "address_2": "Concord  CA  94520",
        "country": "US"
    },
    "48A6D2": {
        "oui_hex": "48-A6-D2",
        "organization": "GJsun Optical Science and Tech Co.,Ltd.",
        "address_1": "First floor National Information Industry Park D-08",
        "address_2": "Guilin  Guangxi  541004",
        "country": "CN"
    },
    "500B32": {
        "oui_hex": "50-0B-32",
        "organization": "Foxda Technology Industrial(ShenZhen)Co.,LTD",
        "address_1": "1F of 1st  Building&1F-3F of 2nd Building, Foxda Industrial Zone,North of Lanzhu Road,Pingshan New District,Shenzhen City,Guangdong Province,P.R.China",
        "address_2": "Shenzhen  Guangdong  518122",
        "country": "CN"
    },
    "603553": {
        "oui_hex": "60-35-53",
        "organization": "Buwon Technology",
        "address_1": "(Cunuitechnopark 102-1507) 200-1,Chunui-dong",
        "address_2": "Buchon-si  Gyeinggi-do  420-857",
        "country": "KR"
    },
    "E039D7": {
        "oui_hex": "E0-39-D7",
        "organization": "Plexxi, Inc.",
        "address_1": "100 Innovative Way Suite 3322",
        "address_2": "Nashua  NH  03062",
        "country": "US"
    },
    "7C336E": {
        "oui_hex": "7C-33-6E",
        "organization": "MEG Electronics Inc.",
        "address_1": "Bogazici Universitesi Kuzey Kampus",
        "address_2": "ISTANBUL    34342",
        "country": "TR"
    },
    "D4E33F": {
        "oui_hex": "D4-E3-3F",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "68CD0F": {
        "oui_hex": "68-CD-0F",
        "organization": "U Tek Company Limited",
        "address_1": "FL5, BLDG12, 3RD DISTRICT, TANGTOU INDUSTRIAL PARK",
        "address_2": "SHENZHEN  GUANGDONG  518018",
        "country": "CN"
    },
    "603FC5": {
        "oui_hex": "60-3F-C5",
        "organization": "COX CO., LTD",
        "address_1": "904HO, ACE TWIN TOWER 1-CHA",
        "address_2": "SEOUL    152-779",
        "country": "KR"
    },
    "A4E391": {
        "oui_hex": "A4-E3-91",
        "organization": "DENY FONTAINE",
        "address_1": "ROUTE DE SAINT VALERY",
        "address_2": "SAINT BLIMONT    80960",
        "country": "FR"
    },
    "AC6FD9": {
        "oui_hex": "AC-6F-D9",
        "organization": "Valueplus Inc.",
        "address_1": "#803, Sicox Tower, 513-14,",
        "address_2": "Seongnam-si  Gyeonggi-do  462-806",
        "country": "KR"
    },
    "DC1EA3": {
        "oui_hex": "DC-1E-A3",
        "organization": "Accensus LLC",
        "address_1": "200 South Wacker Drive",
        "address_2": "Chicago  IL  60606",
        "country": "US"
    },
    "A40130": {
        "oui_hex": "A4-01-30",
        "organization": "ABIsystems Co., LTD",
        "address_1": "308 ACE Techno Tower8 191-7 Guro-dong",
        "address_2": "  Seoul",
        "country": "KR"
    },
    "90A783": {
        "oui_hex": "90-A7-83",
        "organization": "JSW PACIFIC CORPORATION",
        "address_1": "3F-3, No.700, Chung-Zheng Rd, Zhonghe District",
        "address_2": "New Taipei City    235",
        "country": "TW"
    },
    "F8462D": {
        "oui_hex": "F8-46-2D",
        "organization": "SYNTEC Incorporation",
        "address_1": "3F, NO.105, Shing-shyue St.,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "78A5DD": {
        "oui_hex": "78-A5-DD",
        "organization": "Shenzhen Smarteye Digital Electronics Co., Ltd",
        "address_1": "#6 Northen Area",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "ECE744": {
        "oui_hex": "EC-E7-44",
        "organization": "Omntec mfg. inc",
        "address_1": "1993 Pond Road.",
        "address_2": "Ronkonkoma  NY  11779",
        "country": "US"
    },
    "28AF0A": {
        "oui_hex": "28-AF-0A",
        "organization": "Sirius XM Radio Inc",
        "address_1": "1221 Avenue of the Americas",
        "address_2": "New York  NY  10020",
        "country": "US"
    },
    "5CD4AB": {
        "oui_hex": "5C-D4-AB",
        "organization": "Zektor",
        "address_1": "12675 Danielson Ct. Ste 401",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "08FC52": {
        "oui_hex": "08-FC-52",
        "organization": "OpenXS BV",
        "address_1": "Koaibosk 3",
        "address_2": "Terwispel  Friesland  8407ED",
        "country": "NL"
    },
    "4C32D9": {
        "oui_hex": "4C-32-D9",
        "organization": "M Rutty Holdings Pty. Ltd.",
        "address_1": "Unit 1, 4 Beaumont Road",
        "address_2": "Mount Kuring-Gai  New South Wales  2080",
        "country": "AU"
    },
    "08A12B": {
        "oui_hex": "08-A1-2B",
        "organization": "ShenZhen EZL Technology Co., Ltd",
        "address_1": "RM21B, Building 2, China Phoenix Building,",
        "address_2": "ShenZhen  GuangDong  518026",
        "country": "CN"
    },
    "A00CA1": {
        "oui_hex": "A0-0C-A1",
        "organization": "SKTB SKiT",
        "address_1": "239 B. Sadovaya Str.",
        "address_2": "Saratov  Saratov region  410005",
        "country": "RU"
    },
    "64E84F": {
        "oui_hex": "64-E8-4F",
        "organization": "Serialway Communication Technology Co. Ltd",
        "address_1": "Room 315, 706 Painting Room,",
        "address_2": "Beijing    100096",
        "country": "CN"
    },
    "2C9EFC": {
        "oui_hex": "2C-9E-FC",
        "organization": "CANON INC.",
        "address_1": "3-30-2",
        "address_2": "Ohta-Ku  Tokyo  146-8501",
        "country": "JP"
    },
    "182B05": {
        "oui_hex": "18-2B-05",
        "organization": "8D Technologies",
        "address_1": "416, de Maisonneuve West",
        "address_2": "Montreal,   Quebec  H3A 1L2",
        "country": "CA"
    },
    "240BB1": {
        "oui_hex": "24-0B-B1",
        "organization": "KOSTAL Industrie Elektrik GmbH",
        "address_1": "Gewerbering 20",
        "address_2": "Schalksmuehle  North Rhine-Westphalia  58579",
        "country": "DE"
    },
    "20EEC6": {
        "oui_hex": "20-EE-C6",
        "organization": "Elefirst Science & Tech Co ., ltd",
        "address_1": "Floor 9, No 77 Zijinmingmen Building",
        "address_2": "Nanjing  Jiangsu  210007",
        "country": "CN"
    },
    "E01E07": {
        "oui_hex": "E0-1E-07",
        "organization": "Anite Telecoms  US. Inc",
        "address_1": "106 Vista Centre Dr",
        "address_2": "Forest  VA  24551",
        "country": "US"
    },
    "7C6B33": {
        "oui_hex": "7C-6B-33",
        "organization": "Tenyu Tech Co. Ltd.",
        "address_1": "1F., No.10, Ln. 36, Ganzhen 2nd St.",
        "address_2": "New Taipei City     251",
        "country": "TW"
    },
    "147DC5": {
        "oui_hex": "14-7D-C5",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "00B9F6": {
        "oui_hex": "00-B9-F6",
        "organization": "Shenzhen Super Rich Electronics Co.,Ltd",
        "address_1": "RM.102,Shibida Building,No.55,Zhenhua Road,Shenzhen Futian District,",
        "address_2": "Shenzhen  Guangdong  518031",
        "country": "CN"
    },
    "FCC23D": {
        "oui_hex": "FC-C2-3D",
        "organization": "Atmel Corporation",
        "address_1": "1150 E Cheyenne Mtn Blvd",
        "address_2": "Colorado Springs  CO  80906",
        "country": "US"
    },
    "88E7A6": {
        "oui_hex": "88-E7-A6",
        "organization": "iKnowledge Integration Corp.",
        "address_1": "10F No.2, Sec. 3, Xinsheng S. Rd.,",
        "address_2": "Taipei    10660",
        "country": "TW"
    },
    "A446FA": {
        "oui_hex": "A4-46-FA",
        "organization": "AmTRAN Video Corporation",
        "address_1": "9 Goddard",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "CCE7DF": {
        "oui_hex": "CC-E7-DF",
        "organization": "American Magnetics, Inc.",
        "address_1": "PO Box 2509",
        "address_2": "Oak Ridge  TN  37831-2509",
        "country": "US"
    },
    "2804E0": {
        "oui_hex": "28-04-E0",
        "organization": "FERMAX ELECTRONICA S.A.U.",
        "address_1": "Tres Cruces 133",
        "address_2": "Valencia    46017",
        "country": "ES"
    },
    "644346": {
        "oui_hex": "64-43-46",
        "organization": "GuangDong Quick Network Computer CO.,LTD",
        "address_1": "12F,No.80 of Middle XianLie Road,YueXiu District",
        "address_2": "GuangZhou  GuangDong  510070",
        "country": "CN"
    },
    "D4024A": {
        "oui_hex": "D4-02-4A",
        "organization": "Delphian Systems LLC",
        "address_1": "720 Dartmouth Lane",
        "address_2": "Buffalo Grove  IL  60089",
        "country": "US"
    },
    "0041B4": {
        "oui_hex": "00-41-B4",
        "organization": "Wuxi Zhongxing Optoelectronics Technology Co.,Ltd.",
        "address_1": "Block 93-C, Sci. & Tech. Industry park,",
        "address_2": "Wuxi  Jiangsu  214028",
        "country": "CN"
    },
    "F44450": {
        "oui_hex": "F4-44-50",
        "organization": "BND Co., Ltd.",
        "address_1": "573-13 Bokhyeon-dong, Buk-gu",
        "address_2": "Daegu    702-020",
        "country": "KR"
    },
    "0462D7": {
        "oui_hex": "04-62-D7",
        "organization": "ALSTOM HYDRO FRANCE",
        "address_1": "82 Avenue Leon Blum",
        "address_2": "GRENOBLE    38041",
        "country": "FR"
    },
    "D4507A": {
        "oui_hex": "D4-50-7A",
        "organization": "CEIVA Logic, Inc",
        "address_1": "214 E Magnolia Blvd",
        "address_2": "Burbank  CA  91502",
        "country": "US"
    },
    "64D989": {
        "oui_hex": "64-D9-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "645DD7": {
        "oui_hex": "64-5D-D7",
        "organization": "Shenzhen Lifesense Medical Electronics Co., Ltd.",
        "address_1": "China Academy of Science and Technology Development, Room 19A",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "EC4670": {
        "oui_hex": "EC-46-70",
        "organization": "Meinberg Funkuhren GmbH & Co. KG",
        "address_1": "Lange Wand 9",
        "address_2": "Bad Pyrmont  NDS  31812",
        "country": "DE"
    },
    "D05A0F": {
        "oui_hex": "D0-5A-0F",
        "organization": "I-BT DIGITAL CO.,LTD",
        "address_1": "17F.-8, No.866, Zhongzheng Rd., Zhonghe Dist",
        "address_2": "New Taipei     235",
        "country": "TW"
    },
    "EC9681": {
        "oui_hex": "EC-96-81",
        "organization": "2276427 Ontario Inc",
        "address_1": "31-1275 Morningside Ave",
        "address_2": "Toronto  ON  M1B3W1",
        "country": "CA"
    },
    "5C076F": {
        "oui_hex": "5C-07-6F",
        "organization": "Thought Creator",
        "address_1": "Largo da Pirâmide, Nº 3, Sala D",
        "address_2": "Oeiras  Lisboa  2795-156 Linda-a-Velha",
        "country": "PT"
    },
    "3C0FC1": {
        "oui_hex": "3C-0F-C1",
        "organization": "KBC Networks",
        "address_1": "25691 Atlantic Ocean Dr",
        "address_2": "Lake Forest  CA  92630",
        "country": "US"
    },
    "58E636": {
        "oui_hex": "58-E6-36",
        "organization": "EVRsafe Technologies",
        "address_1": "59 North Terrace",
        "address_2": "Adelaide  South Australia  5069",
        "country": "AU"
    },
    "10F9EE": {
        "oui_hex": "10-F9-EE",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "742B0F": {
        "oui_hex": "74-2B-0F",
        "organization": "Infinidat Ltd.",
        "address_1": "11 Galgalei Haplada St.",
        "address_2": "Herzliya Pituach  Center  46722",
        "country": "IL"
    },
    "C8F981": {
        "oui_hex": "C8-F9-81",
        "organization": "Seneca s.r.l.",
        "address_1": "Via Germania, 34",
        "address_2": "PADOVA    35127",
        "country": "IT"
    },
    "24497B": {
        "oui_hex": "24-49-7B",
        "organization": "Innovative Converged Devices Inc",
        "address_1": "424 8th Avenue North",
        "address_2": "Seattle  WA  98109",
        "country": "US"
    },
    "98E79A": {
        "oui_hex": "98-E7-9A",
        "organization": "Foxconn(NanJing) Communication Co.,Ltd.",
        "address_1": "A-2FMinfang Building No.189 Guangzhou Rd",
        "address_2": "Nanjing  Jiang su  210029",
        "country": "CN"
    },
    "A0E9DB": {
        "oui_hex": "A0-E9-DB",
        "organization": "Ningbo FreeWings Technologies Co.,Ltd",
        "address_1": "Room 1107-1108, No 298 XueShi Road Yinzhou District Ningbo,",
        "address_2": "Ningbo  Zhejiang  315000",
        "country": "CN"
    },
    "788973": {
        "oui_hex": "78-89-73",
        "organization": "CMC",
        "address_1": "Industriepark De Bruwaan 37B",
        "address_2": "Oudenaarde  Oost-Vlaanderen  9700",
        "country": "BE"
    },
    "14307A": {
        "oui_hex": "14-30-7A",
        "organization": "Avermetrics",
        "address_1": "2973 Glendale Blvd.",
        "address_2": "Los Angeles  CA  90039",
        "country": "US"
    },
    "A06CEC": {
        "oui_hex": "A0-6C-EC",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "203706": {
        "oui_hex": "20-37-06",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4B164": {
        "oui_hex": "F4-B1-64",
        "organization": "Lightning Telecommunications Technology Co. Ltd",
        "address_1": "Room 1302, TianÂ¡Â¯an Hi-Tech Plaza Tower A, Futian District,",
        "address_2": "ShenZhen  GuangDong  518040",
        "country": "CN"
    },
    "70B035": {
        "oui_hex": "70-B0-35",
        "organization": "Shenzhen Zowee Technology Co., Ltd",
        "address_1": "Block 5, Science and Technology Industrial",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "8821E3": {
        "oui_hex": "88-21-E3",
        "organization": "Nebusens, S.L.",
        "address_1": "C/ Adaja S/N, Edificio M2",
        "address_2": "Villamayor de la Armuña  Salamanca  37185",
        "country": "ES"
    },
    "90B97D": {
        "oui_hex": "90-B9-7D",
        "organization": "Johnson Outdoors Marine Electronics d/b/a Minnkota",
        "address_1": "1531 E Madison Ave",
        "address_2": "Mankato  MN  56001",
        "country": "US"
    },
    "7CF429": {
        "oui_hex": "7C-F4-29",
        "organization": "NUUO Inc.",
        "address_1": "C block, 18 Sihyuan St. Jhongjheng District,",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "CCB55A": {
        "oui_hex": "CC-B5-5A",
        "organization": "Fraunhofer ITWM",
        "address_1": "Fraunhoferplatz 1",
        "address_2": "Kaiserslautern  Rhineland-Palatinae  67663",
        "country": "DE"
    },
    "AC8ACD": {
        "oui_hex": "AC-8A-CD",
        "organization": "ROGER D.Wensker, G.Wensker sp.j.",
        "address_1": "Gosciszewo 59",
        "address_2": "Sztum  Pomorskie  82-400",
        "country": "PL"
    },
    "984246": {
        "oui_hex": "98-42-46",
        "organization": "SOL INDUSTRY PTE., LTD",
        "address_1": " 1 NORTH BRIDGE RD.,",
        "address_2": "    179094",
        "country": "SG"
    },
    "3429EA": {
        "oui_hex": "34-29-EA",
        "organization": "MCD ELECTRONICS SP. Z O.O.",
        "address_1": "Lelewela 26",
        "address_2": "Zywiec  slaskie  34-300",
        "country": "PL"
    },
    "8C82A8": {
        "oui_hex": "8C-82-A8",
        "organization": "Insigma Technology Co.,Ltd",
        "address_1": "No.226 Tianmushan Road,",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "60190C": {
        "oui_hex": "60-19-0C",
        "organization": "RRAMAC",
        "address_1": "15400 Medina Rd",
        "address_2": "Plymouth  MN  55447",
        "country": "US"
    },
    "D05FCE": {
        "oui_hex": "D0-5F-CE",
        "organization": "Hitachi Data Systems",
        "address_1": "750 Central Expressway",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "F80332": {
        "oui_hex": "F8-03-32",
        "organization": "Khomp",
        "address_1": "Rua Joe Collaço, 253",
        "address_2": "Florianópolis  Santa Catarina  88037-010",
        "country": "BR"
    },
    "28A574": {
        "oui_hex": "28-A5-74",
        "organization": "Miller Electric Mfg. Co.",
        "address_1": "N676 Communication Drive",
        "address_2": "Appleton  WI  54914",
        "country": "US"
    },
    "1045BE": {
        "oui_hex": "10-45-BE",
        "organization": "Norphonic AS",
        "address_1": "Fabrikkgaten 10",
        "address_2": "Bergen    5059",
        "country": "NO"
    },
    "90B8D0": {
        "oui_hex": "90-B8-D0",
        "organization": "Joyent, Inc.",
        "address_1": "345 California Street,",
        "address_2": "San Francisco  CA  94104",
        "country": "US"
    },
    "AC4723": {
        "oui_hex": "AC-47-23",
        "organization": "Genelec",
        "address_1": "Olvitie 5",
        "address_2": "Iisalmi    74100",
        "country": "FI"
    },
    "E8BA70": {
        "oui_hex": "E8-BA-70",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D4A425": {
        "oui_hex": "D4-A4-25",
        "organization": "SMAX Technology Co., Ltd.",
        "address_1": "2F., No. 3, Wuquan 3rd, Wugu Dist.",
        "address_2": "New Taipei City    248",
        "country": "TW"
    },
    "281471": {
        "oui_hex": "28-14-71",
        "organization": "Lantis co., LTD.",
        "address_1": "busan innobiz center 401",
        "address_2": "busan    616-829",
        "country": "KR"
    },
    "24470E": {
        "oui_hex": "24-47-0E",
        "organization": "PentronicAB",
        "address_1": "Bergsliden 1",
        "address_2": "GUNNEBO    59093",
        "country": "SE"
    },
    "D09B05": {
        "oui_hex": "D0-9B-05",
        "organization": "Emtronix",
        "address_1": "5# Gaopeng Dadao",
        "address_2": "Chengdu    610041",
        "country": "CN"
    },
    "8C11CB": {
        "oui_hex": "8C-11-CB",
        "organization": "ABUS Security-Center GmbH & Co. KG",
        "address_1": "Linker Kreuthweg 5",
        "address_2": "Affing / Muehlhausen  Bavaria  86444",
        "country": "DE"
    },
    "FC8329": {
        "oui_hex": "FC-83-29",
        "organization": "Trei technics",
        "address_1": "801 Northpoint Pkwy",
        "address_2": "West Palm Beach  Florida  33407",
        "country": "US"
    },
    "14EB33": {
        "oui_hex": "14-EB-33",
        "organization": "BSMediasoft Co., Ltd.",
        "address_1": "#603, Garden Bldg., 14-13, Yoido-Dong, Youngdeungpo-Gu",
        "address_2": "Seoul    150-871",
        "country": "KR"
    },
    "F4B549": {
        "oui_hex": "F4-B5-49",
        "organization": "Xiamen Yeastar Information Technology Co., Ltd.",
        "address_1": "3/F, No. 46 Guanri Road, 2nd Software Park",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "88B168": {
        "oui_hex": "88-B1-68",
        "organization": "Delta Control GmbH",
        "address_1": "Rondorfer Hauptstraße 33",
        "address_2": "Cologne  NRW  50997",
        "country": "DE"
    },
    "68876B": {
        "oui_hex": "68-87-6B",
        "organization": "INQ Mobile Limited",
        "address_1": "6 Hester Road",
        "address_2": "Battersea  London  SW11 4AN",
        "country": "GB"
    },
    "1CAA07": {
        "oui_hex": "1C-AA-07",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "685B36": {
        "oui_hex": "68-5B-36",
        "organization": "POWERTECH INDUSTRIAL CO., LTD.",
        "address_1": "10F, No. 407, Chung Shan Rd., Sec 2,",
        "address_2": "Chung Ho  Taipei County  23558",
        "country": "TW"
    },
    "28EE2C": {
        "oui_hex": "28-EE-2C",
        "organization": "Frontline Test Equipment",
        "address_1": "PO Box 7507",
        "address_2": "Charlottesville  Virginia  22906-7507",
        "country": "US"
    },
    "782EEF": {
        "oui_hex": "78-2E-EF",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "7CF0BA": {
        "oui_hex": "7C-F0-BA",
        "organization": "Linkwell Telesystems Pvt Ltd",
        "address_1": "1-11-252/1/A, Gowra Klassic",
        "address_2": "Hyderabad  Andhra Pradesh  500016",
        "country": "IN"
    },
    "AC8674": {
        "oui_hex": "AC-86-74",
        "organization": "Open Mesh, Inc.",
        "address_1": "111 SW 5th Ave Ste1150",
        "address_2": "Portland  OR  97204",
        "country": "US"
    },
    "64D241": {
        "oui_hex": "64-D2-41",
        "organization": "Keith & Koep GmbH",
        "address_1": "Uellendahler Str. 199",
        "address_2": "Wuppertal  NRW  42109",
        "country": "DE"
    },
    "18B79E": {
        "oui_hex": "18-B7-9E",
        "organization": "Invoxia",
        "address_1": "87 rue du Gouverneur Général Eboué",
        "address_2": "Issy-Les-Moulineaux    92130",
        "country": "FR"
    },
    "8C4435": {
        "oui_hex": "8C-44-35",
        "organization": "Shanghai BroadMobi Communication Technology Co., Ltd.",
        "address_1": "Rm. 901, Bld. 9, No.1515 Gumei Rd, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "F81D93": {
        "oui_hex": "F8-1D-93",
        "organization": "Longdhua(Beijing) Controls Technology Co.,Ltd",
        "address_1": "Room 1203,Lixiang Building, No.111 Zhichun Road,Haidian District,",
        "address_2": "Beijing    10086",
        "country": "CN"
    },
    "94D93C": {
        "oui_hex": "94-D9-3C",
        "organization": "ENELPS",
        "address_1": "Bul Arsenija Carnojevica 117",
        "address_2": "Belgrade    11070",
        "country": "RS"
    },
    "B8BEBF": {
        "oui_hex": "B8-BE-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "64B64A": {
        "oui_hex": "64-B6-4A",
        "organization": "ViVOtech, Inc.",
        "address_1": "451 El Camino Real",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "38D135": {
        "oui_hex": "38-D1-35",
        "organization": "EasyIO Corporation Sdn. Bhd.",
        "address_1": "No. 32-2 & 32-3, Jalan Puteri 2/4",
        "address_2": "Puchong  Selangor  47100",
        "country": "MY"
    },
    "CCF841": {
        "oui_hex": "CC-F8-41",
        "organization": "Lumewave",
        "address_1": "4803 B Street",
        "address_2": "Sacramento  CA  95819",
        "country": "US"
    },
    "30EB25": {
        "oui_hex": "30-EB-25",
        "organization": "INTEK DIGITAL",
        "address_1": "801, 8th Fl., Anyang K-center building, 1591-9",
        "address_2": "Anyang    431-060",
        "country": "KR"
    },
    "44E4D9": {
        "oui_hex": "44-E4-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "ACCA54": {
        "oui_hex": "AC-CA-54",
        "organization": "Telldus Technologies AB",
        "address_1": "Skiffervägen 102",
        "address_2": "Lund    224 78",
        "country": "SE"
    },
    "901900": {
        "oui_hex": "90-19-00",
        "organization": "SCS SA",
        "address_1": "Via Pini, 32",
        "address_2": "Biasca    6710",
        "country": "CH"
    },
    "D45D42": {
        "oui_hex": "D4-5D-42",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "B03829": {
        "oui_hex": "B0-38-29",
        "organization": "Siliconware Precision Industries Co., Ltd.",
        "address_1": "No. 123, Sec.3, Da Fong Rd, Tantzu,",
        "address_2": "Taichung    427",
        "country": "TW"
    },
    "7C6C39": {
        "oui_hex": "7C-6C-39",
        "organization": "PIXSYS SRL",
        "address_1": "VIA DELLA CROCE ROSSA 42",
        "address_2": "PADOVA  PD  35129",
        "country": "IT"
    },
    "18B3BA": {
        "oui_hex": "18-B3-BA",
        "organization": "Netlogic AB",
        "address_1": "Datavägen 14A",
        "address_2": "ASKIM  Västra Götaland  43632",
        "country": "SE"
    },
    "8C5FDF": {
        "oui_hex": "8C-5F-DF",
        "organization": "Beijing Railway Signal Factory",
        "address_1": "No.2 Sicun Xilu Langfa,Huangcun,",
        "address_2": "Beiijng    102613",
        "country": "CN"
    },
    "D47B75": {
        "oui_hex": "D4-7B-75",
        "organization": "HARTING Electronics GmbH",
        "address_1": "Marienwerderstraße. 3",
        "address_2": "Espelkamp  North Rhine Westphalia  32339",
        "country": "DE"
    },
    "D8DF0D": {
        "oui_hex": "D8-DF-0D",
        "organization": "beroNet GmbH",
        "address_1": "Friedrichstraße 231",
        "address_2": "Berlin    10969",
        "country": "DE"
    },
    "ACF97E": {
        "oui_hex": "AC-F9-7E",
        "organization": "ELESYS INC.",
        "address_1": "Suit 623, 812-1, Hyomun-dong",
        "address_2": "Ulsan  Buk-gu  683-360",
        "country": "KR"
    },
    "204005": {
        "oui_hex": "20-40-05",
        "organization": "feno GmbH",
        "address_1": "Kolpingring 22",
        "address_2": "Oberhaching  Bavaria  82041",
        "country": "DE"
    },
    "D46F42": {
        "oui_hex": "D4-6F-42",
        "organization": "WAXESS USA Inc",
        "address_1": "1401 Dove Street",
        "address_2": "Newport Beach  CA  92660",
        "country": "US"
    },
    "300B9C": {
        "oui_hex": "30-0B-9C",
        "organization": "Delta Mobile Systems, Inc.",
        "address_1": "700 Remington Road",
        "address_2": "Schaumburg  Illinois  60173",
        "country": "US"
    },
    "6CAD3F": {
        "oui_hex": "6C-AD-3F",
        "organization": "Hubbell Building Automation, Inc.",
        "address_1": "9601 Dessau Rd",
        "address_2": "Austin  Texas  78754",
        "country": "US"
    },
    "B01B7C": {
        "oui_hex": "B0-1B-7C",
        "organization": "Ontrol A.S.",
        "address_1": "Turcan Cad No:19 Y.Dudullu",
        "address_2": "Umraniye  Istanbul  34775",
        "country": "TR"
    },
    "04C5A4": {
        "oui_hex": "04-C5-A4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BC2846": {
        "oui_hex": "BC-28-46",
        "organization": "NextBIT Computing Pvt. Ltd.",
        "address_1": "30/2, 2nd Floor, R.K. Plaza,",
        "address_2": "Bangalore  Karnataka  560038",
        "country": "IN"
    },
    "BC0F2B": {
        "oui_hex": "BC-0F-2B",
        "organization": "FORTUNE TECHGROUP CO.,LTD",
        "address_1": "7-8F,No.1198 North Qinzhou Road,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "648125": {
        "oui_hex": "64-81-25",
        "organization": "Alphatron Marine BV",
        "address_1": "Schaardijk 23",
        "address_2": "Rotterdam  Zuid-Holland  3063NH",
        "country": "NL"
    },
    "8CF9C9": {
        "oui_hex": "8C-F9-C9",
        "organization": "MESADA Technology Co.,Ltd.",
        "address_1": "TongFng Information Harbor,No.11 LangShan Road,HI-tech Park,Nanshan District,",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "C0626B": {
        "oui_hex": "C0-62-6B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "94E226": {
        "oui_hex": "94-E2-26",
        "organization": "D. ORtiz Consulting, LLC",
        "address_1": "22601 N. 17th Avenue Suite 270",
        "address_2": "Phoenix  AZ  85027",
        "country": "US"
    },
    "D8C99D": {
        "oui_hex": "D8-C9-9D",
        "organization": "EA DISPLAY LIMITED",
        "address_1": "22/F DELTA HOUSE 3 ON YIU ST",
        "address_2": "SHATIN NT",
        "country": "HK"
    },
    "1083D2": {
        "oui_hex": "10-83-D2",
        "organization": "Microseven Systems, LLC",
        "address_1": "404 South Lemon Ave., #9",
        "address_2": "Walnut  California  91789",
        "country": "US"
    },
    "34684A": {
        "oui_hex": "34-68-4A",
        "organization": "Teraworks Co., Ltd.",
        "address_1": "Room No. 201 , 515-30 , Mok-Dong",
        "address_2": "Seoul    158-808",
        "country": "KR"
    },
    "CCFC6D": {
        "oui_hex": "CC-FC-6D",
        "organization": "RIZ TRANSMITTERS",
        "address_1": "BOZIDAREVICEVA 13",
        "address_2": "ZAGREB    10000",
        "country": "HR"
    },
    "E03E7D": {
        "oui_hex": "E0-3E-7D",
        "organization": "data-complex GmbH",
        "address_1": "Düsterngraben 7",
        "address_2": "Halberstadt  Sachsen-Anhalt  38820",
        "country": "DE"
    },
    "0CC6AC": {
        "oui_hex": "0C-C6-AC",
        "organization": "DAGS",
        "address_1": "Ace High end Tower 7th 1802",
        "address_2": "Seoul  Geumcheon-gu  153-802",
        "country": "KR"
    },
    "042605": {
        "oui_hex": "04-26-05",
        "organization": "GFR Gesellschaft für Regelungstechnik und Energieeinsparung mbH",
        "address_1": "Kapellenweg 42",
        "address_2": "Verl    33415",
        "country": "DE"
    },
    "24F0FF": {
        "oui_hex": "24-F0-FF",
        "organization": "GHT Co., Ltd.",
        "address_1": "#16 Nanyunyi Lu, Guangzhou Science City",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "9CC0D2": {
        "oui_hex": "9C-C0-D2",
        "organization": "Conductix-Wampfler GmbH",
        "address_1": "Rheinstrasse 27+33",
        "address_2": "  Baden-Württemberg",
        "country": "DE"
    },
    "CCF67A": {
        "oui_hex": "CC-F6-7A",
        "organization": "Ayecka Communication Systems LTD",
        "address_1": "POB 3059",
        "address_2": "Hod Hasharon    45130",
        "country": "IL"
    },
    "8065E9": {
        "oui_hex": "80-65-E9",
        "organization": "BenQ Corporation",
        "address_1": "16 Jihu Road, Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "EC986C": {
        "oui_hex": "EC-98-6C",
        "organization": "Lufft Mess- und Regeltechnik GmbH",
        "address_1": "Gutenbergstraße 20",
        "address_2": "Fellbach  Baden-Württemberg  70736",
        "country": "DE"
    },
    "D093F8": {
        "oui_hex": "D0-93-F8",
        "organization": "Stonestreet One LLC",
        "address_1": "9960 Corporate Campus Drive",
        "address_2": "Louisville  KY  40223",
        "country": "US"
    },
    "9C645E": {
        "oui_hex": "9C-64-5E",
        "organization": "Harman Consumer Group",
        "address_1": "8500 Balboa Blvd",
        "address_2": "Northridge  CA  91329",
        "country": "US"
    },
    "1C334D": {
        "oui_hex": "1C-33-4D",
        "organization": "ITS Telecom",
        "address_1": "29 Hametzuda st.",
        "address_2": "Azur  Israel  580001",
        "country": "IL"
    },
    "DCD87F": {
        "oui_hex": "DC-D8-7F",
        "organization": "Shenzhen JoinCyber Telecom Equipment Ltd",
        "address_1": "19CDE, Block A,JinFengBuilding,shangbu South Road,Futian District,",
        "address_2": "Shenzhen  Guangdong  518031",
        "country": "CN"
    },
    "B4E0CD": {
        "oui_hex": "B4-E0-CD",
        "organization": "Fusion-io, Inc",
        "address_1": "2880 Junction Avenue",
        "address_2": "San Jose  CA  95134-1922",
        "country": "US"
    },
    "286046": {
        "oui_hex": "28-60-46",
        "organization": "Lantech Communications Global, Inc.",
        "address_1": "7F, No. 45, Lane 188, Ruiguang Rd., Neihu District",
        "address_2": "Taipei City    11491",
        "country": "TW"
    },
    "10E2D5": {
        "oui_hex": "10-E2-D5",
        "organization": "Qi Hardware Inc.",
        "address_1": "555 4TH STREET #403",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "60C980": {
        "oui_hex": "60-C9-80",
        "organization": "Trymus",
        "address_1": "Bucheon Techno Park 303-902",
        "address_2": "Bucheon-si  421-741  Gyunggi-do",
        "country": "KR"
    },
    "A036FA": {
        "oui_hex": "A0-36-FA",
        "organization": "Ettus Research LLC",
        "address_1": "1043 N Shoreline Blvd",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "EC836C": {
        "oui_hex": "EC-83-6C",
        "organization": "RM Tech Co., Ltd.",
        "address_1": "C-801, Bupyeong Woolim Lions Valley",
        "address_2": "Incheon City    403-911",
        "country": "KR"
    },
    "303955": {
        "oui_hex": "30-39-55",
        "organization": "Shenzhen Jinhengjia Electronic Co., Ltd.",
        "address_1": "4-6 Floors, Factory Building, Jijia Industrial Park,",
        "address_2": "Shenzhen  Guangdong  518112",
        "country": "CN"
    },
    "FC5B24": {
        "oui_hex": "FC-5B-24",
        "organization": "Weibel Scientific A/S",
        "address_1": "Solvang 30",
        "address_2": "Alleroed    3450",
        "country": "DK"
    },
    "78593E": {
        "oui_hex": "78-59-3E",
        "organization": "RAFI GmbH & Co.KG",
        "address_1": "Ravensburger Str. 128-134",
        "address_2": "Berg  Baden Wurttemberg  88276",
        "country": "DE"
    },
    "509772": {
        "oui_hex": "50-97-72",
        "organization": "Westinghouse Digital",
        "address_1": "500 N. State College Blvd.",
        "address_2": "Orange  CA  92868",
        "country": "US"
    },
    "503DE5": {
        "oui_hex": "50-3D-E5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "540496": {
        "oui_hex": "54-04-96",
        "organization": "Gigawave LTD",
        "address_1": "GIGAWAVE TECHNICAL CENTRE",
        "address_2": "Colchester  ESSEX  CO62NS",
        "country": "GB"
    },
    "EC4644": {
        "oui_hex": "EC-46-44",
        "organization": "TTK SAS",
        "address_1": "4, Rue du Chemin Vert",
        "address_2": "Clichy    92110",
        "country": "FR"
    },
    "4CB9C8": {
        "oui_hex": "4C-B9-C8",
        "organization": "CONET CO., LTD.",
        "address_1": "2-8,HIGASHIJIMA-CHO",
        "address_2": "ICHINOMIYA  AICHI  491-0074",
        "country": "JP"
    },
    "8CB64F": {
        "oui_hex": "8C-B6-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "204AAA": {
        "oui_hex": "20-4A-AA",
        "organization": "Hanscan Spain S.A.",
        "address_1": "Avda. de la Vega, 1",
        "address_2": "Alcobendas  Madrid  28108",
        "country": "ES"
    },
    "20FECD": {
        "oui_hex": "20-FE-CD",
        "organization": "System In Frontier Inc.",
        "address_1": "4F Shinsuzuharu Bldg. 2-8-3 Akebonocyo",
        "address_2": "Tachikawa-shi  Tokyo  190-0012",
        "country": "JP"
    },
    "F0933A": {
        "oui_hex": "F0-93-3A",
        "organization": "NxtConect",
        "address_1": "Schillerstrasse 4",
        "address_2": "Bad Kissingen    97688",
        "country": "DE"
    },
    "B8415F": {
        "oui_hex": "B8-41-5F",
        "organization": "ASP AG",
        "address_1": "Max- Planck-Str. 15 a-c",
        "address_2": "Erkrath  NRW  40699",
        "country": "DE"
    },
    "2CB69D": {
        "oui_hex": "2C-B6-9D",
        "organization": "RED Digital Cinema",
        "address_1": "20291 Valencia Circle",
        "address_2": "Lake Forest  California  92630",
        "country": "US"
    },
    "582F42": {
        "oui_hex": "58-2F-42",
        "organization": "Universal Electric Corporation",
        "address_1": "168 Georgetown Road",
        "address_2": "Canonsburg  PA  15317",
        "country": "US"
    },
    "0474A1": {
        "oui_hex": "04-74-A1",
        "organization": "Aligera Equipamentos Digitais Ltda",
        "address_1": "Av. Para 330 / 302",
        "address_2": "Porto Alegre  RS  90240-590",
        "country": "BR"
    },
    "5C6984": {
        "oui_hex": "5C-69-84",
        "organization": "NUVICO",
        "address_1": "1 Enterprise Place  Unit G",
        "address_2": "Hicksville  NY  11801",
        "country": "US"
    },
    "70DDA1": {
        "oui_hex": "70-DD-A1",
        "organization": "Tellabs",
        "address_1": "One Tellabs Center",
        "address_2": "Naperville  Illinois  60563",
        "country": "US"
    },
    "94D019": {
        "oui_hex": "94-D0-19",
        "organization": "Cydle Corp.",
        "address_1": "1203, KofomoTower, 16-3 , Sunae-Dong, Bundang-Gu",
        "address_2": "Seongnam-City  Gyeonggi-Do  463825",
        "country": "KR"
    },
    "8C278A": {
        "oui_hex": "8C-27-8A",
        "organization": "Vocollect Inc",
        "address_1": "703 Rodi Road",
        "address_2": "Pittsburgh  Pa  15235",
        "country": "US"
    },
    "CC0CDA": {
        "oui_hex": "CC-0C-DA",
        "organization": "Miljovakt AS",
        "address_1": "Gannestadveien 2",
        "address_2": "Borre  Vestfold  3184",
        "country": "NO"
    },
    "E41C4B": {
        "oui_hex": "E4-1C-4B",
        "organization": "V2 TECHNOLOGY, INC.",
        "address_1": "4450 Enterprise Street",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "5CF3FC": {
        "oui_hex": "5C-F3-FC",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "A86A6F": {
        "oui_hex": "A8-6A-6F",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "68122D": {
        "oui_hex": "68-12-2D",
        "organization": "Special Instrument Development Co., Ltd.",
        "address_1": "6F-1, No. 123, Lane 235",
        "address_2": "Hsin Tien  Taipei Hsien  231",
        "country": "TW"
    },
    "94F720": {
        "oui_hex": "94-F7-20",
        "organization": "Tianjin Deviser Electronics Instrument Co., Ltd",
        "address_1": "No.40 Yibin Road,Nankai district,",
        "address_2": "Tianjin    300113",
        "country": "CN"
    },
    "DC9C52": {
        "oui_hex": "DC-9C-52",
        "organization": "Sapphire Technology Limited.",
        "address_1": "Unit 1909-1919, 19/F., Tower 2, Grand Central Plaza,",
        "address_2": "",
        "country": "HK"
    },
    "4891F6": {
        "oui_hex": "48-91-F6",
        "organization": "Shenzhen Reach software technology CO.,LTD",
        "address_1": "6/F,Block B, Kingdee Software park,#2,Keji 12th South Road,Hi-tech Industrial Park,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "649B24": {
        "oui_hex": "64-9B-24",
        "organization": "V Technology Co., Ltd.",
        "address_1": "YBP East Tower 5F,",
        "address_2": "Yokohama city  Kanagawa  240-0005",
        "country": "JP"
    },
    "846EB1": {
        "oui_hex": "84-6E-B1",
        "organization": "Park Assist LLC",
        "address_1": "111 W28th Street",
        "address_2": "New York  NY  10001",
        "country": "US"
    },
    "6C504D": {
        "oui_hex": "6C-50-4D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B8D06F": {
        "oui_hex": "B8-D0-6F",
        "organization": "GUANGZHOU HKUST FOK YING TUNG RESEARCH INSTITUTE",
        "address_1": "Rm 403, North of Software Building,Nansha IT Park,",
        "address_2": "Guangzhou  Guangdong Privince  511458",
        "country": "CN"
    },
    "EC14F6": {
        "oui_hex": "EC-14-F6",
        "organization": "BioControl AS",
        "address_1": "Grimstad Gard",
        "address_2": "Rakkestad     N-1890",
        "country": "NO"
    },
    "E8995A": {
        "oui_hex": "E8-99-5A",
        "organization": "PiiGAB, Processinformation i Goteborg AB",
        "address_1": "Anders Carlssons gata 1",
        "address_2": "Gothenburg    417 55",
        "country": "SE"
    },
    "401D59": {
        "oui_hex": "40-1D-59",
        "organization": "Biometric Associates, LP",
        "address_1": "9475 Deereco Rd.",
        "address_2": "Timonium  MD  21093",
        "country": "US"
    },
    "B8FF6F": {
        "oui_hex": "B8-FF-6F",
        "organization": "Shanghai Typrotech Technology Co.Ltd",
        "address_1": "Design Building 903, NO.63,",
        "address_2": "Shanghai    200092",
        "country": "CN"
    },
    "1CBD0E": {
        "oui_hex": "1C-BD-0E",
        "organization": "Amplified Engineering Pty Ltd",
        "address_1": "5 Turner Avenue",
        "address_2": "Bentley  WA  6102",
        "country": "AU"
    },
    "A0F217": {
        "oui_hex": "A0-F2-17",
        "organization": "GE Medical System(China) Co., Ltd.",
        "address_1": "No.19, ChangJiang Road",
        "address_2": "Wuxi  Jiangsu  214028",
        "country": "CN"
    },
    "F0A764": {
        "oui_hex": "F0-A7-64",
        "organization": "GST Co., Ltd.",
        "address_1": "#988-6, Gosaek-Dong, Gwonseon-Gu",
        "address_2": "Suwon-Si  Gyeonggi-Do  441-813",
        "country": "KR"
    },
    "1C0656": {
        "oui_hex": "1C-06-56",
        "organization": "IDY Corporation",
        "address_1": "IDEMITSU Korakuen Bld 9F",
        "address_2": "Bunkyo-ku  Tokyo  112-0002",
        "country": "JP"
    },
    "500E6D": {
        "oui_hex": "50-0E-6D",
        "organization": "TrafficCast International",
        "address_1": "2801 Coho Street",
        "address_2": "Madison  WI  53713",
        "country": "US"
    },
    "EC3BF0": {
        "oui_hex": "EC-3B-F0",
        "organization": "NovelSat",
        "address_1": "Hataasia 21",
        "address_2": "Raanana    2396",
        "country": "IL"
    },
    "4CEDDE": {
        "oui_hex": "4C-ED-DE",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "E8E08F": {
        "oui_hex": "E8-E0-8F",
        "organization": "GRAVOTECH MARKING SAS",
        "address_1": "56 AVENUE JEAN JAURES",
        "address_2": "LA CHAPELLE SAINT LUC  AUBE  10600",
        "country": "FR"
    },
    "ACAB8D": {
        "oui_hex": "AC-AB-8D",
        "organization": "Lyngso Marine A/S",
        "address_1": "Lyngso Alle 2",
        "address_2": "Horsholm    DK-2970",
        "country": "DK"
    },
    "6083B2": {
        "oui_hex": "60-83-B2",
        "organization": "GkWare e.K.",
        "address_1": "Hatzper Str. 172B",
        "address_2": "Essen  NRW  45149",
        "country": "DE"
    },
    "80D019": {
        "oui_hex": "80-D0-19",
        "organization": "Embed, Inc",
        "address_1": "410 Great Road",
        "address_2": "Littleton  MA  01460",
        "country": "US"
    },
    "68EBC5": {
        "oui_hex": "68-EB-C5",
        "organization": "Angstrem Telecom",
        "address_1": "Yuzhnaya promzona, passage 4806, 4, build 3",
        "address_2": "Zelenograd  Moscow  124460",
        "country": "RU"
    },
    "A0B5DA": {
        "oui_hex": "A0-B5-DA",
        "organization": "HongKong THTF Co., Ltd",
        "address_1": "2F,Sector C of Tsinghua University Academy,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "8886A0": {
        "oui_hex": "88-86-A0",
        "organization": "Simton Technologies, Ltd.",
        "address_1": "2 Taishan Road, Building C, 3rd Floor",
        "address_2": "Wuxi,   Province of Jiangsu,   214028",
        "country": "CN"
    },
    "A45055": {
        "oui_hex": "A4-50-55",
        "organization": "BUSWARE.DE",
        "address_1": "Lindenstrasse 18",
        "address_2": "Scharbeutz    23684",
        "country": "DE"
    },
    "A89B10": {
        "oui_hex": "A8-9B-10",
        "organization": "inMotion Ltd.",
        "address_1": "Unit 2709 Exchange Tower",
        "address_2": "    KLN",
        "country": "HK"
    },
    "B41489": {
        "oui_hex": "B4-14-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4A80F": {
        "oui_hex": "A4-A8-0F",
        "organization": "Shenzhen Coship Electronics Co., Ltd.",
        "address_1": "Rainbow Bldg., North, Hi-Tech Industrial Park, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F8B599": {
        "oui_hex": "F8-B5-99",
        "organization": "Guangzhou CHNAVS Digital Technology Co.,Ltd",
        "address_1": "Buliding C, industy base of digital home application and demonstration ,zhongyi road Guangzhou higher education mega center",
        "address_2": "Guangzhou  Guangdong  510006",
        "country": "CN"
    },
    "B8921D": {
        "oui_hex": "B8-92-1D",
        "organization": "BG T&A",
        "address_1": "4F, L&C Tower",
        "address_2": "Gunpo-si  Gyeonggi-do  435-845",
        "country": "KR"
    },
    "D08999": {
        "oui_hex": "D0-89-99",
        "organization": "APCON, Inc.",
        "address_1": "9255 SW Pioneer Court",
        "address_2": "Wilsonville  OR  97070",
        "country": "US"
    },
    "C88447": {
        "oui_hex": "C8-84-47",
        "organization": "Beautiful Enterprise Co., Ltd",
        "address_1": "26th Floor, Beautiful Group Tower",
        "address_2": "",
        "country": "HK"
    },
    "54FDBF": {
        "oui_hex": "54-FD-BF",
        "organization": "Scheidt & Bachmann GmbH",
        "address_1": "Breite Strasse 132",
        "address_2": "Moenchengladbach  NRW  41238",
        "country": "DE"
    },
    "D0BB80": {
        "oui_hex": "D0-BB-80",
        "organization": "SHL Telemedicine International Ltd.",
        "address_1": "90 Yigal Alon",
        "address_2": "Tel Aviv    67891",
        "country": "IL"
    },
    "5C17D3": {
        "oui_hex": "5C-17-D3",
        "organization": "LGE",
        "address_1": "60-39 , Kasan -dong , Gumcheon-gu.",
        "address_2": "Seoul     153-801",
        "country": "KR"
    },
    "1CDF0F": {
        "oui_hex": "1C-DF-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "68BDAB": {
        "oui_hex": "68-BD-AB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9CADEF": {
        "oui_hex": "9C-AD-EF",
        "organization": "Obihai Technology, Inc.",
        "address_1": "2105 S. Bascom Ave #285",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "C88B47": {
        "oui_hex": "C8-8B-47",
        "organization": "Nolangroup S.P.A con Socio Unico",
        "address_1": "via Terzi di S.Agata 2",
        "address_2": "Brembate di Sopra  Bergamo  24030",
        "country": "IT"
    },
    "C4CD45": {
        "oui_hex": "C4-CD-45",
        "organization": "Beijing Boomsense Technology CO.,LTD.",
        "address_1": "803 Building 4 INTERWEST Business Center,No.9 South Shouti Road ,HaidianDistrict,",
        "address_2": "Beijing    100048",
        "country": "CN"
    },
    "8CE7B3": {
        "oui_hex": "8C-E7-B3",
        "organization": "Sonardyne International Ltd",
        "address_1": "Blackbushe Business Park",
        "address_2": "Yateley  Hampshire  GU46 6GD",
        "country": "GB"
    },
    "088DC8": {
        "oui_hex": "08-8D-C8",
        "organization": "Ryowa Electronics Co.,Ltd",
        "address_1": "1483-1 Takahara-machi",
        "address_2": "Yamagata-shi  Yamagata-pref.  9900002",
        "country": "JP"
    },
    "80C6CA": {
        "oui_hex": "80-C6-CA",
        "organization": "Endian s.r.l.",
        "address_1": "Pillhof 47",
        "address_2": "Frangarto  Bolzano  39010",
        "country": "IT"
    },
    "7076F0": {
        "oui_hex": "70-76-F0",
        "organization": "LevelOne Communications (India) Private Limited",
        "address_1": "2F, Lane 1, 45 Bharat Nagar",
        "address_2": "New Delhi  DELHI  110025",
        "country": "IN"
    },
    "C02BFC": {
        "oui_hex": "C0-2B-FC",
        "organization": "iNES. applied informatics GmbH",
        "address_1": "Ohmstrasse 9",
        "address_2": "Ludwigsburg    71642",
        "country": "DE"
    },
    "94C7AF": {
        "oui_hex": "94-C7-AF",
        "organization": "Raylios Technology",
        "address_1": "12F., No.16, Jian 8th Rd",
        "address_2": "Zhonghe City  Taipei County   23511",
        "country": "TW"
    },
    "D81C14": {
        "oui_hex": "D8-1C-14",
        "organization": "Compacta International, Ltd.",
        "address_1": "31342 Via Las Palmas",
        "address_2": "San Juan Capistrano  CA  92675",
        "country": "US"
    },
    "008C10": {
        "oui_hex": "00-8C-10",
        "organization": "Black Box Corp.",
        "address_1": "1000 Park Drive",
        "address_2": "Lawrence  PA  15055",
        "country": "US"
    },
    "90903C": {
        "oui_hex": "90-90-3C",
        "organization": "TRISON TECHNOLOGY CORPORATION",
        "address_1": "No.3, Kung-Yeh 12th Rd., Ping-Jen Industrial Park,",
        "address_2": "Ping-Jen City,   TaoYuan County  32459",
        "country": "TW"
    },
    "E061B2": {
        "oui_hex": "E0-61-B2",
        "organization": "HANGZHOU ZENOINTEL TECHNOLOGY CO., LTD",
        "address_1": "Room 806, F#, Cambridge Combridge, Shenhua Road,District Xihu,",
        "address_2": "Hangzhou  Zhejiang  310030",
        "country": "CN"
    },
    "9411DA": {
        "oui_hex": "94-11-DA",
        "organization": "ITF Fröschl GmbH",
        "address_1": "Hauserbachstraße 9",
        "address_2": "Walderbach  Bavaria  93194",
        "country": "DE"
    },
    "8039E5": {
        "oui_hex": "80-39-E5",
        "organization": "PATLITE CORPORATION",
        "address_1": "19-2",
        "address_2": "SANDA  HYOUGOKEN  669-1339",
        "country": "JP"
    },
    "DC7B94": {
        "oui_hex": "DC-7B-94",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "5CCA32": {
        "oui_hex": "5C-CA-32",
        "organization": "Theben AG",
        "address_1": "Hohenbergstraße 32",
        "address_2": "Haigerloch  Baden-Württemberg  72401",
        "country": "DE"
    },
    "7415E2": {
        "oui_hex": "74-15-E2",
        "organization": "Tri-Sen Systems Corporation",
        "address_1": "17625 El Camino Real Suite 200",
        "address_2": "Houston  TX  77058",
        "country": "US"
    },
    "ECC38A": {
        "oui_hex": "EC-C3-8A",
        "organization": "Accuenergy (CANADA) Inc",
        "address_1": "2 Lansing Square, Suite 503",
        "address_2": "Toronto  Ontario  M2J 4P8",
        "country": "CA"
    },
    "D48FAA": {
        "oui_hex": "D4-8F-AA",
        "organization": "Sogecam Industrial, S.A.",
        "address_1": "Rosalind Franklin, 22-24",
        "address_2": "Malaga    29590",
        "country": "ES"
    },
    "B081D8": {
        "oui_hex": "B0-81-D8",
        "organization": "I-sys Corp",
        "address_1": "2457 Aviation Ave",
        "address_2": "N. Charleston  South Carolina  29406",
        "country": "US"
    },
    "14FEAF": {
        "oui_hex": "14-FE-AF",
        "organization": "SAGITTAR LIMITED",
        "address_1": "2-102, BLD34, BAIWANGMOLIYUAN",
        "address_2": "BEIJING    100094",
        "country": "CN"
    },
    "B0B8D5": {
        "oui_hex": "B0-B8-D5",
        "organization": "Nanjing Nengrui Auto Equipment CO.,Ltd",
        "address_1": "No.108 Ganjiabian East Yaohua Town",
        "address_2": "Nanjing  Jiangsu  210046",
        "country": "CN"
    },
    "94E711": {
        "oui_hex": "94-E7-11",
        "organization": "Xirka Dama Persada PT",
        "address_1": "Gdg CM",
        "address_2": "Jakarta    13150",
        "country": "ID"
    },
    "6C9B02": {
        "oui_hex": "6C-9B-02",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "641E81": {
        "oui_hex": "64-1E-81",
        "organization": "Dowslake Microsystems",
        "address_1": "21 High Street, Suite 306",
        "address_2": "North Andover  MA  01845",
        "country": "US"
    },
    "EC542E": {
        "oui_hex": "EC-54-2E",
        "organization": "Shanghai XiMei Electronic Technology Co. Ltd",
        "address_1": "Room 503, No.2623, GongHeXin Road",
        "address_2": "Shanghai    200072",
        "country": "CN"
    },
    "FCD4F6": {
        "oui_hex": "FC-D4-F6",
        "organization": "Messana Air.Ray Conditioning s.r.l.",
        "address_1": "Via Venezia 18",
        "address_2": "Oderzo  TV  31046",
        "country": "IT"
    },
    "D466A8": {
        "oui_hex": "D4-66-A8",
        "organization": "Riedo Networks Ltd",
        "address_1": "Route de la Fonderie 6",
        "address_2": "Fribourg    1700",
        "country": "CH"
    },
    "F0E5C3": {
        "oui_hex": "F0-E5-C3",
        "organization": "Drägerwerk AG & Co. KG aA",
        "address_1": "Moislinger Allee 53-55",
        "address_2": "Luebeck  Germany  23452",
        "country": "DE"
    },
    "D82986": {
        "oui_hex": "D8-29-86",
        "organization": "Best Wish Technology LTD",
        "address_1": "7E,Hai Yi Business Building,No.310,Tianshan RD.,",
        "address_2": "Shanghai    200336",
        "country": "CN"
    },
    "446132": {
        "oui_hex": "44-61-32",
        "organization": "ecobee inc",
        "address_1": "333 Adelaide St W 6th Floor",
        "address_2": "Toronto  Ontario  M5V1R5",
        "country": "CA"
    },
    "F41F0B": {
        "oui_hex": "F4-1F-0B",
        "organization": "YAMABISHI Corporation",
        "address_1": "3-14-12 Kamigou",
        "address_2": "Ebina-city  KANAGAWA  243-0434",
        "country": "JP"
    },
    "A082C7": {
        "oui_hex": "A0-82-C7",
        "organization": "P.T.I Co.,LTD",
        "address_1": "1-5-1,Tsurumidan",
        "address_2": "Koriyama-shi  Fukushima  963-8861",
        "country": "JP"
    },
    "043604": {
        "oui_hex": "04-36-04",
        "organization": "Gyeyoung I&T",
        "address_1": "6F, Woosung Bldg. 1000-1, Daechi-dong",
        "address_2": "  Seoul  135-502",
        "country": "KR"
    },
    "A4B2A7": {
        "oui_hex": "A4-B2-A7",
        "organization": "Adaxys Solutions AG",
        "address_1": "Eichtalstrasse 55",
        "address_2": "Hombrechtikon  CH  8634",
        "country": "CH"
    },
    "D0D0FD": {
        "oui_hex": "D0-D0-FD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E05B70": {
        "oui_hex": "E0-5B-70",
        "organization": "Innovid, Co., Ltd.",
        "address_1": "5th Floor, Boga Building, 821-3, Bangbaedong, Seochogu",
        "address_2": "Seoul    137-060",
        "country": "KR"
    },
    "141BBD": {
        "oui_hex": "14-1B-BD",
        "organization": "Volex Inc.",
        "address_1": "915 Tate Blvd. SE",
        "address_2": "Hickory  NC  28602",
        "country": "US"
    },
    "E87AF3": {
        "oui_hex": "E8-7A-F3",
        "organization": "S5 Tech S.r.l.",
        "address_1": "Via Tortona 72",
        "address_2": "Milano    20144",
        "country": "IT"
    },
    "CC5C75": {
        "oui_hex": "CC-5C-75",
        "organization": "Weightech Com. Imp. Exp. Equip. Pesagem Ltda",
        "address_1": "Rodovia Virgílio Várzea, 3110 - Sala 01",
        "address_2": "Florianópolis  SC  88032-001",
        "country": "BR"
    },
    "1C6F65": {
        "oui_hex": "1C-6F-65",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "90E0F0": {
        "oui_hex": "90-E0-F0",
        "organization": "IEEE 1722a Working Group",
        "address_1": "8760 Sandy Parkway",
        "address_2": "Sandy  Utah  84070",
        "country": "US"
    },
    "40520D": {
        "oui_hex": "40-52-0D",
        "organization": "Pico Technology",
        "address_1": "James House, Marlborough Road",
        "address_2": "St Neots  Cambridgeshire   PE19 8YP",
        "country": "GB"
    },
    "807D1B": {
        "oui_hex": "80-7D-1B",
        "organization": "Neosystem Co. Ltd.",
        "address_1": "4-19-12 Takao",
        "address_2": "Dazaifu-shi  Fukuoka  818-0122",
        "country": "JP"
    },
    "18B209": {
        "oui_hex": "18-B2-09",
        "organization": "Torrey Pines Logic, Inc",
        "address_1": "12651 High Bluff Drive, #100",
        "address_2": "San Diego  CA  92130",
        "country": "US"
    },
    "D84B2A": {
        "oui_hex": "D8-4B-2A",
        "organization": "Cognitas Technologies, Inc.",
        "address_1": "6406 Laurel Bush Ln.",
        "address_2": "Sugar Land  Texas  77479",
        "country": "US"
    },
    "684B88": {
        "oui_hex": "68-4B-88",
        "organization": "Galtronics Telemetry Inc.",
        "address_1": "31 Lupi Ct",
        "address_2": "Palm Coast  Florida  32137",
        "country": "US"
    },
    "98FC11": {
        "oui_hex": "98-FC-11",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "34E0D7": {
        "oui_hex": "34-E0-D7",
        "organization": "DONGGUAN QISHENG ELECTRONICS INDUSTRIAL CO., LTD",
        "address_1": "XINJI INDUSTRIAL ZONE, MACHONG TOWN",
        "address_2": "DONGGUAN  GUANGDONG  523123",
        "country": "CN"
    },
    "D84606": {
        "oui_hex": "D8-46-06",
        "organization": "Silicon Valley Global Marketing",
        "address_1": "830 Stewart Dr. #201",
        "address_2": "Sunnyvale  Ca  94085",
        "country": "US"
    },
    "F8AC6D": {
        "oui_hex": "F8-AC-6D",
        "organization": "Deltenna Ltd",
        "address_1": "First Floor Unit 2",
        "address_2": "Chippenham  Wiltshire  SN15 1BN",
        "country": "GB"
    },
    "F450EB": {
        "oui_hex": "F4-50-EB",
        "organization": "Telechips Inc",
        "address_1": "KORAD Bldg,1000-12, Daechi-Dong, Gangnam-Gu,",
        "address_2": "Seoul    135-280",
        "country": "KR"
    },
    "988EDD": {
        "oui_hex": "98-8E-DD",
        "organization": "TE Connectivity Limerick",
        "address_1": "International Science Centre, Block 1",
        "address_2": "Castletroy  Co. Limerick",
        "country": "IE"
    },
    "A4AE9A": {
        "oui_hex": "A4-AE-9A",
        "organization": "Maestro Wireless Solutions ltd.",
        "address_1": "3603-9, 36/F",
        "address_2": "Sai Ying Pun",
        "country": "HK"
    },
    "C848F5": {
        "oui_hex": "C8-48-F5",
        "organization": "MEDISON Xray Co., Ltd",
        "address_1": "3F Burim B/D 999 Daechi-dong",
        "address_2": "Seoul    135-280",
        "country": "KR"
    },
    "78A714": {
        "oui_hex": "78-A7-14",
        "organization": "Amphenol",
        "address_1": "20 Valley St.",
        "address_2": "Endicott  New York  13760",
        "country": "US"
    },
    "F893F3": {
        "oui_hex": "F8-93-F3",
        "organization": "VOLANS",
        "address_1": "3F IJU BD 770-13 YEOKSAM-DONG",
        "address_2": "SEOUL    135-928",
        "country": "KR"
    },
    "7866AE": {
        "oui_hex": "78-66-AE",
        "organization": "ZTEC Instruments, Inc.",
        "address_1": "7715 Tiburon St. NE",
        "address_2": "Albuquerque  NM  87109",
        "country": "US"
    },
    "4C022E": {
        "oui_hex": "4C-02-2E",
        "organization": "CMR KOREA CO., LTD",
        "address_1": "6F, J-Tower, 24-5 Bangi-dong, Songpa-Gu",
        "address_2": "Seoul    138-050",
        "country": "KR"
    },
    "34AAEE": {
        "oui_hex": "34-AA-EE",
        "organization": "Mikrovisatos Servisas UAB",
        "address_1": "Savanoriu pr. 125",
        "address_2": "Kaunas    LT44146",
        "country": "LT"
    },
    "44D63D": {
        "oui_hex": "44-D6-3D",
        "organization": "Talari Networks",
        "address_1": "3200 Glen Royal Rd.",
        "address_2": "Raleigh   NC  27617",
        "country": "US"
    },
    "78A2A0": {
        "oui_hex": "78-A2-A0",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "48FCB8": {
        "oui_hex": "48-FC-B8",
        "organization": "Woodstream Corporation",
        "address_1": "69 N. Locust Street",
        "address_2": "Lititz  PA  17543",
        "country": "US"
    },
    "D4000D": {
        "oui_hex": "D4-00-0D",
        "organization": "Phoenix Broadband Technologies, LLC.",
        "address_1": "589 Bethlehem Pike",
        "address_2": "Montgomeryville  PA  18936",
        "country": "US"
    },
    "AC5135": {
        "oui_hex": "AC-51-35",
        "organization": "MPI TECH",
        "address_1": "Vadstrupvej 35",
        "address_2": "Bagsværd    DK-2880",
        "country": "DK"
    },
    "74B9EB": {
        "oui_hex": "74-B9-EB",
        "organization": "JinQianMao Technology Co.,Ltd.",
        "address_1": "Room 506 YongHeng Building NO.58 JiangBing Raod",
        "address_2": "FuZhou  FuJian  350005",
        "country": "CN"
    },
    "D45297": {
        "oui_hex": "D4-52-97",
        "organization": "nSTREAMS Technologies, Inc.",
        "address_1": "10F-2, No. 302, Ruiguang Rd., Neihu District,",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "1880CE": {
        "oui_hex": "18-80-CE",
        "organization": "Barberry Solutions Ltd",
        "address_1": "2/13 Naviti Place",
        "address_2": "Auckland    0630",
        "country": "NZ"
    },
    "24B6B8": {
        "oui_hex": "24-B6-B8",
        "organization": "FRIEM SPA",
        "address_1": "Via Edison 1",
        "address_2": "Segrate  Milano  20090",
        "country": "IT"
    },
    "A4561B": {
        "oui_hex": "A4-56-1B",
        "organization": "MCOT Corporation",
        "address_1": "Yogohigashi 1-5-12",
        "address_2": "Matsuyama city  Ehime prefecture  790-0044",
        "country": "JP"
    },
    "80C63F": {
        "oui_hex": "80-C6-3F",
        "organization": "Remec Broadband Wireless , LLC",
        "address_1": "17034 Camino San Bernardo",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "40D40E": {
        "oui_hex": "40-D4-0E",
        "organization": "Biodata Ltd",
        "address_1": "10 Stocks Street",
        "address_2": "Manchester    M8 8QG",
        "country": "GB"
    },
    "0C826A": {
        "oui_hex": "0C-82-6A",
        "organization": "Wuhan Huagong Genuine Optics Technology Co., Ltd",
        "address_1": "Science & Technology Region of HUST, Donghu High-Tech Zone",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "E0271A": {
        "oui_hex": "E0-27-1A",
        "organization": "TTC Next-generation Home Network System WG",
        "address_1": "1-1-12 Shiba Kouen",
        "address_2": "Minato-ku  Tokyo  105-0011",
        "country": "JP"
    },
    "0097FF": {
        "oui_hex": "00-97-FF",
        "organization": "Heimann Sensor GmbH",
        "address_1": "Maria-Reiche-Str. 1",
        "address_2": "Dresden  Sachsen  01109",
        "country": "DE"
    },
    "E4AB46": {
        "oui_hex": "E4-AB-46",
        "organization": "UAB Selteka",
        "address_1": "DraugystÃ«s g. 19",
        "address_2": "Kaunas    LT-51230",
        "country": "LT"
    },
    "945B7E": {
        "oui_hex": "94-5B-7E",
        "organization": "TRILOBIT LTDA.",
        "address_1": "R. ALVARENGA 1377",
        "address_2": "São Paulo    05509002",
        "country": "BR"
    },
    "04E548": {
        "oui_hex": "04-E5-48",
        "organization": "Cohda Wireless Pty Ltd",
        "address_1": "Suite 5 / 83 Fullarton Road",
        "address_2": "Kent Town  South Australia  5067",
        "country": "AU"
    },
    "7071BC": {
        "oui_hex": "70-71-BC",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "7884EE": {
        "oui_hex": "78-84-EE",
        "organization": "INDRA ESPACIO S.A.",
        "address_1": "C/ ROC BORONAT, 133",
        "address_2": "BARCELONA    08018",
        "country": "ES"
    },
    "7C051E": {
        "oui_hex": "7C-05-1E",
        "organization": "RAFAEL LTD.",
        "address_1": "GUSH SEGEV POB 2250",
        "address_2": "HAIFA    31008",
        "country": "IL"
    },
    "10090C": {
        "oui_hex": "10-09-0C",
        "organization": "Janome Sewing Machine Co., Ltd.",
        "address_1": "1463 Hazama-Machi",
        "address_2": "Hachioji-Shi  Tokyo  193-0941",
        "country": "JP"
    },
    "E01CEE": {
        "oui_hex": "E0-1C-EE",
        "organization": "Bravo Tech, Inc.",
        "address_1": "6185 Phyllis Dr. Unit D.",
        "address_2": "Cypress  CA  90630",
        "country": "US"
    },
    "2893FE": {
        "oui_hex": "28-93-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4C795": {
        "oui_hex": "F4-C7-95",
        "organization": "WEY Elektronik AG",
        "address_1": "Dorfstrasse 57",
        "address_2": "Unterengstringen  Zurich  8103",
        "country": "CH"
    },
    "781185": {
        "oui_hex": "78-11-85",
        "organization": "NBS Payment Solutions Inc.",
        "address_1": "703 Evans Ave",
        "address_2": "Toronto  Ontario  M9C 5E9",
        "country": "CA"
    },
    "D05875": {
        "oui_hex": "D0-58-75",
        "organization": "Active Control Technology Inc.",
        "address_1": "1800 Appleby Line",
        "address_2": "Burlington  Ontario  L7L 6A1",
        "country": "CA"
    },
    "C8EF2E": {
        "oui_hex": "C8-EF-2E",
        "organization": "Beijing Gefei Tech. Co., Ltd",
        "address_1": "A-603 Power Creative Plaza, NO.1 Shangdi E. Rd.,Haidian District,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "08F6F8": {
        "oui_hex": "08-F6-F8",
        "organization": "GET Engineering",
        "address_1": "9350 Bond Ave",
        "address_2": "El Cajon  CA  92021",
        "country": "US"
    },
    "3C4C69": {
        "oui_hex": "3C-4C-69",
        "organization": "Infinity System S.L.",
        "address_1": "Crtra. N-II, Km 48,5 Pol. Ind. Cabanillas del Campo, Parc. 12B",
        "address_2": "Guadalajara    19171",
        "country": "US"
    },
    "7830E1": {
        "oui_hex": "78-30-E1",
        "organization": "UltraClenz, LLC",
        "address_1": "1440 W Indiantown Road",
        "address_2": "Jupiter  FL  33458",
        "country": "US"
    },
    "B09134": {
        "oui_hex": "B0-91-34",
        "organization": "Taleo",
        "address_1": "4140 Dublin Blvd",
        "address_2": "Dublin  California  94568",
        "country": "US"
    },
    "A4C2AB": {
        "oui_hex": "A4-C2-AB",
        "organization": "Hangzhou LEAD-IT Information & Technology Co.,Ltd",
        "address_1": "F2 Builder B,Xidomen Road NO.22",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "48AA5D": {
        "oui_hex": "48-AA-5D",
        "organization": "Store Electronic Systems",
        "address_1": "39 rue de montigny",
        "address_2": "Argenteuil    95100",
        "country": "FR"
    },
    "042F56": {
        "oui_hex": "04-2F-56",
        "organization": "ATOCS (Shenzhen) LTD",
        "address_1": "4/F., Building 10, Tongfuyu Industry Zone, Xili Town,",
        "address_2": "Shenzhen",
        "country": "CN"
    },
    "E85E53": {
        "oui_hex": "E8-5E-53",
        "organization": "Infratec Datentechnik GmbH",
        "address_1": "Gevener Weg 38",
        "address_2": "Neuenrade  NRW  58579",
        "country": "DE"
    },
    "88BA7F": {
        "oui_hex": "88-BA-7F",
        "organization": "Qfiednet Co., Ltd.",
        "address_1": "#204 KJ Bldg. DaeChi-Dong",
        "address_2": "Seoul    135-847",
        "country": "KR"
    },
    "64DB18": {
        "oui_hex": "64-DB-18",
        "organization": "OpenPattern",
        "address_1": "109/111 rue des Côtes",
        "address_2": "Maisons Laffitte  Yvelines  78600",
        "country": "FR"
    },
    "90A2DA": {
        "oui_hex": "90-A2-DA",
        "organization": "GHEO SA",
        "address_1": "Via Soldini, 22",
        "address_2": "Chiasso    CH-6830",
        "country": "CH"
    },
    "9889ED": {
        "oui_hex": "98-89-ED",
        "organization": "Anadem Information Inc.",
        "address_1": "2nd F, 79 Zhouzi Street, Neihu District,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "D81BFE": {
        "oui_hex": "D8-1B-FE",
        "organization": "TWINLINX CORPORATION",
        "address_1": "ESPACE DESCARTES BAT B",
        "address_2": "AIX EN PROVENCE  PROVENCE  13857",
        "country": "FR"
    },
    "FC4463": {
        "oui_hex": "FC-44-63",
        "organization": "Universal Audio, Inc",
        "address_1": "4585 Scotts Valley Dr.",
        "address_2": "Scotts Valley  CA  95066",
        "country": "US"
    },
    "102D96": {
        "oui_hex": "10-2D-96",
        "organization": "Looxcie Inc.",
        "address_1": "1196 Borregas Ave.",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "5C35DA": {
        "oui_hex": "5C-35-DA",
        "organization": "There Corporation Oy",
        "address_1": "Elimäenkatu 5",
        "address_2": "Helsinki    00510",
        "country": "FI"
    },
    "A06986": {
        "oui_hex": "A0-69-86",
        "organization": "Wellav Technologies Ltd",
        "address_1": "15F Desay Building",
        "address_2": "Huizhou  Guangdong  516003",
        "country": "CN"
    },
    "EC8EAD": {
        "oui_hex": "EC-8E-AD",
        "organization": "DLX",
        "address_1": "#401, Seoil B/D,1359-45 Seocho2-dong",
        "address_2": "Seoul    137-863",
        "country": "KR"
    },
    "34C69A": {
        "oui_hex": "34-C6-9A",
        "organization": "Enecsys Ltd",
        "address_1": "Harston Mill",
        "address_2": "Cambridge  Cambridgeshire  CB22 7GG",
        "country": "GB"
    },
    "D8AE90": {
        "oui_hex": "D8-AE-90",
        "organization": "Itibia Technologies",
        "address_1": "5 Clausen Ct",
        "address_2": "West Windsor  NJ  08550",
        "country": "US"
    },
    "B8653B": {
        "oui_hex": "B8-65-3B",
        "organization": "Bolymin, Inc.",
        "address_1": "13F-1, No.20, Ta-Long Rd.,",
        "address_2": "Taichung    40310",
        "country": "TW"
    },
    "38E8DF": {
        "oui_hex": "38-E8-DF",
        "organization": "b gmbh medien + datenbanken",
        "address_1": "Kurfuerstenstrasse 22",
        "address_2": "Ludwigsburg  BW  71636",
        "country": "DE"
    },
    "1C129D": {
        "oui_hex": "1C-12-9D",
        "organization": "IEEE PES PSRC/SUB",
        "address_1": " Working Group H7/Sub C7 (IEEE PC37.238)",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "E0CA4D": {
        "oui_hex": "E0-CA-4D",
        "organization": "Shenzhen Unistar Communication Co.,LTD",
        "address_1": "9/F,Qinghai Building,7043, Berhuan Road, Futian District,",
        "address_2": "Shenzhen  Guangdong  518034",
        "country": "CN"
    },
    "0CC9C6": {
        "oui_hex": "0C-C9-C6",
        "organization": "Samwin Hong Kong Limited",
        "address_1": "Rm 901-902, 9/F, Futura Plaza,",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "1062C9": {
        "oui_hex": "10-62-C9",
        "organization": "Adatis GmbH & Co. KG",
        "address_1": "Forchheimer Straße 6",
        "address_2": "Nürnberg  Bavaria  90425",
        "country": "DE"
    },
    "60B3C4": {
        "oui_hex": "60-B3-C4",
        "organization": "Elber Srl",
        "address_1": "via Pontevecchio 42 W",
        "address_2": "Carasco  Ge  16042",
        "country": "IT"
    },
    "04C880": {
        "oui_hex": "04-C8-80",
        "organization": "Samtec Inc",
        "address_1": "520 Park East Blvd",
        "address_2": "New Albany  IN  47150",
        "country": "US"
    },
    "F88DEF": {
        "oui_hex": "F8-8D-EF",
        "organization": "Tenebraex",
        "address_1": "27 Drydock Avenue",
        "address_2": "Boston  MA  02210",
        "country": "US"
    },
    "042234": {
        "oui_hex": "04-22-34",
        "organization": "Wireless Standard Extensions",
        "address_1": "1322 Crossman avenue",
        "address_2": "Sunnyvale  California  94089",
        "country": "US"
    },
    "F0B6EB": {
        "oui_hex": "F0-B6-EB",
        "organization": "Poslab Technology Co., Ltd.",
        "address_1": "5F-1, No.490 Bannan Rd.",
        "address_2": "Jhonghe City    235",
        "country": "TW"
    },
    "80C862": {
        "oui_hex": "80-C8-62",
        "organization": "Openpeak, Inc",
        "address_1": "1750 Clint Moore Rd",
        "address_2": "Boca Raton  Florida  33487",
        "country": "US"
    },
    "1C8F8A": {
        "oui_hex": "1C-8F-8A",
        "organization": "Phase Motion Control SpA",
        "address_1": "via Adamoli, 461",
        "address_2": "Genova    IT16141",
        "country": "IT"
    },
    "FCCCE4": {
        "oui_hex": "FC-CC-E4",
        "organization": "Ascon Ltd.",
        "address_1": "1-15-27 Minato-machi",
        "address_2": "Fukuyama –shi  Hiroshima-ken  721-0964",
        "country": "JP"
    },
    "5850E6": {
        "oui_hex": "58-50-E6",
        "organization": "Best Buy Corporation",
        "address_1": "7601 Penn Ave South",
        "address_2": "Richfield  MN  55423",
        "country": "US"
    },
    "3C1CBE": {
        "oui_hex": "3C-1C-BE",
        "organization": "JADAK LLC",
        "address_1": "7279 William Barry Blvd",
        "address_2": "North Syracuse  NY  13212",
        "country": "US"
    },
    "BCD5B6": {
        "oui_hex": "BC-D5-B6",
        "organization": "d2d technologies",
        "address_1": "10611 roundwood glen ct",
        "address_2": "Jacksonville  Fl  32256",
        "country": "US"
    },
    "FC683E": {
        "oui_hex": "FC-68-3E",
        "organization": "Directed Perception, Inc",
        "address_1": "890C Cowan Road",
        "address_2": "Burlingame  California  94010",
        "country": "US"
    },
    "28E794": {
        "oui_hex": "28-E7-94",
        "organization": "Microtime Computer Inc.",
        "address_1": "4F, No. 222, Sec. 4, Cheng-Teh Rd.,",
        "address_2": "Taipei    11167",
        "country": "TW"
    },
    "0CD502": {
        "oui_hex": "0C-D5-02",
        "organization": "Westell Technologies Inc.",
        "address_1": "750 N Commons Dr",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "70828E": {
        "oui_hex": "70-82-8E",
        "organization": "OleumTech Corporation",
        "address_1": "23 Hubble",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "A438FC": {
        "oui_hex": "A4-38-FC",
        "organization": "Plastic Logic",
        "address_1": "650 Castro St., Suite 500",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "18FC9F": {
        "oui_hex": "18-FC-9F",
        "organization": "Changhe Electronics Co., Ltd.",
        "address_1": "6th Floor, Building B, Dajiahao Square, YuÂ¡Â¯an 1st Road, BaoÂ¡Â¯an,",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "94592D": {
        "oui_hex": "94-59-2D",
        "organization": "EKE Building Technology Systems Ltd",
        "address_1": "Piispanportti 7",
        "address_2": "Espoo  -  02240",
        "country": "US"
    },
    "CC69B0": {
        "oui_hex": "CC-69-B0",
        "organization": "Global Traffic Technologies, LLC",
        "address_1": "7800 Third Street North",
        "address_2": "St. Paul  Minnesota  55128",
        "country": "US"
    },
    "A0593A": {
        "oui_hex": "A0-59-3A",
        "organization": "V.D.S. Video Display Systems srl",
        "address_1": "Via Del Pantano 71",
        "address_2": "SCANDICCI  FI  50018",
        "country": "IT"
    },
    "CCEA1C": {
        "oui_hex": "CC-EA-1C",
        "organization": "DCONWORKS  Co., Ltd",
        "address_1": "182-13 Daerung Post Tower 2nd 5F",
        "address_2": "Seoul    152-847",
        "country": "KR"
    },
    "7C08D9": {
        "oui_hex": "7C-08-D9",
        "organization": "Shanghai B-Star Technology Co",
        "address_1": "1158 Xiehe Road",
        "address_2": "Shanghai    200335",
        "country": "CN"
    },
    "2059A0": {
        "oui_hex": "20-59-A0",
        "organization": "Paragon Technologies Inc.",
        "address_1": "68 North 4th Ring Rd West,",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "38E98C": {
        "oui_hex": "38-E9-8C",
        "organization": "Reco S.p.A.",
        "address_1": "via dell'Industria, 8",
        "address_2": "Montano Lucino  CO  22070",
        "country": "IT"
    },
    "A0BFA5": {
        "oui_hex": "A0-BF-A5",
        "organization": "CORESYS",
        "address_1": "267-1 Nonhyundong Gangnamgu",
        "address_2": "Seoul    135-833",
        "country": "KR"
    },
    "B05B1F": {
        "oui_hex": "B0-5B-1F",
        "organization": "THERMO FISHER SCIENTIFIC S.P.A.",
        "address_1": "STRADA RIVOLTANA KM 6/7",
        "address_2": "RODANO  MILAN  20090",
        "country": "IT"
    },
    "24D2CC": {
        "oui_hex": "24-D2-CC",
        "organization": "SmartDrive Systems Inc.",
        "address_1": "9276 Scranton Road",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0CEF7C": {
        "oui_hex": "0C-EF-7C",
        "organization": "AnaCom Inc",
        "address_1": "1996 Lundy Ave",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "ECE9F8": {
        "oui_hex": "EC-E9-F8",
        "organization": "Guang Zhou TRI-SUN Electronics Technology  Co., Ltd",
        "address_1": "9th floor Guangzhou info port building B, Keyun Road, Tianhe District, Guangzhou ,PRC",
        "address_2": "Guangzhou  Guangdong  510665",
        "country": "CN"
    },
    "34CE94": {
        "oui_hex": "34-CE-94",
        "organization": "Parsec (Pty) Ltd",
        "address_1": "Building 8-10 Manhattan Office Park",
        "address_2": "Centurion  Gauteng  0157",
        "country": "ZA"
    },
    "34EF8B": {
        "oui_hex": "34-EF-8B",
        "organization": "NTT Communications Corporation",
        "address_1": "NTT Hibiya Bldg. 7F",
        "address_2": "Chiyoda-ku  Tokyo  100-8019",
        "country": "JP"
    },
    "687F74": {
        "oui_hex": "68-7F-74",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "D0D286": {
        "oui_hex": "D0-D2-86",
        "organization": "Beckman Coulter K.K.",
        "address_1": "454-32 Higashino,",
        "address_2": "Nagaizumi-cho, Sunto-gun,  Shizuoka-ken  411-0943",
        "country": "JP"
    },
    "C4198B": {
        "oui_hex": "C4-19-8B",
        "organization": "Dominion Voting Systems Corporation",
        "address_1": "215 Spadina Avenue",
        "address_2": "Toronto  Ontario  M5T 2C7",
        "country": "CA"
    },
    "C83A35": {
        "oui_hex": "C8-3A-35",
        "organization": "Tenda Technology Co., Ltd.",
        "address_1": "Room 601-602,R/D Building Complex,Tsinghua High-Tech Park,nanshan district",
        "address_2": "Shenzhen  Guandong  518057",
        "country": "CN"
    },
    "6C8CDB": {
        "oui_hex": "6C-8C-DB",
        "organization": "Otus Technologies Ltd",
        "address_1": "26 Braid Road",
        "address_2": "Edinburgh  Morningside  EH10 6AD",
        "country": "GB"
    },
    "40F52E": {
        "oui_hex": "40-F5-2E",
        "organization": "Leica Microsystems (Schweiz) AG",
        "address_1": "Max Schmidheiny-Strasse 201",
        "address_2": "Heerbrugg  SG  9435",
        "country": "CH"
    },
    "E4FFDD": {
        "oui_hex": "E4-FF-DD",
        "organization": "ELECTRON INDIA",
        "address_1": "TYPE II, NO.9, DR. V.S.I. ESTATE",
        "address_2": "CHENNAI  TAMIL NADU  600 041",
        "country": "IN"
    },
    "68A1B7": {
        "oui_hex": "68-A1-B7",
        "organization": "Honghao Mingchuan Technology (Beijing) CO.,Ltd.",
        "address_1": "Floor 8,Tower A, Wanliu Yicheng Building",
        "address_2": "Beijing    100089",
        "country": "CN"
    },
    "0CD7C2": {
        "oui_hex": "0C-D7-C2",
        "organization": "Axium Technologies, Inc.",
        "address_1": "6625 N. Calle Eva Miranda",
        "address_2": "Irwindale  CA  91702",
        "country": "US"
    },
    "E84ECE": {
        "oui_hex": "E8-4E-CE",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "1045F8": {
        "oui_hex": "10-45-F8",
        "organization": "LNT-Automation GmbH",
        "address_1": "Hans-Paul-Kaysser-Straße 1",
        "address_2": "Leutenbach-Nellmersbach  BW  D-71397",
        "country": "DE"
    },
    "DCE71C": {
        "oui_hex": "DC-E7-1C",
        "organization": "AUG Elektronik GmbH",
        "address_1": "Kleinwoellmiss 53",
        "address_2": "St. Martin a. W.  Styria  A-8580",
        "country": "AT"
    },
    "A870A5": {
        "oui_hex": "A8-70-A5",
        "organization": "UniComm Inc.",
        "address_1": "7F-7, No. 716, Chung-Cheng Road,",
        "address_2": "Chung-Ho City  Taipei Hsien  23500",
        "country": "TW"
    },
    "F8472D": {
        "oui_hex": "F8-47-2D",
        "organization": "X2gen Digital Corp. Ltd",
        "address_1": "# 89, Singlong Rd",
        "address_2": "Pin-Jhen City,     324",
        "country": "TW"
    },
    "849000": {
        "oui_hex": "84-90-00",
        "organization": "Arnold & Richter Cine Technik",
        "address_1": "Tuerkenstrasse 89",
        "address_2": "Munich  Bavaria  80799",
        "country": "DE"
    },
    "08184C": {
        "oui_hex": "08-18-4C",
        "organization": "A. S. Thomas, Inc.",
        "address_1": "355 Providence Hwy",
        "address_2": "Westwood  MA  02090",
        "country": "US"
    },
    "10880F": {
        "oui_hex": "10-88-0F",
        "organization": "Daruma Telecomunicações e Informática S.A.",
        "address_1": "AVENIDA INDEPENDENCIA, 3500, LOTEAMENTO INDUSTRIAL",
        "address_2": "Taubaté  São Paulo  12032-000",
        "country": "BR"
    },
    "FC6198": {
        "oui_hex": "FC-61-98",
        "organization": "NEC Personal Products, Ltd",
        "address_1": "6-80, Shimohanazawa 2-chome,",
        "address_2": "Yonezawa-shi  Yamagata  992-8520",
        "country": "JP"
    },
    "74D850": {
        "oui_hex": "74-D8-50",
        "organization": "Evrisko Systems",
        "address_1": "2322 Alpine Rd, Ste 10",
        "address_2": "Eau Claire  WI  54703",
        "country": "US"
    },
    "54B620": {
        "oui_hex": "54-B6-20",
        "organization": "SUHDOL E&C Co.Ltd.",
        "address_1": "920, Ilsan TechnoTown 1141-1, Baekseok-dong, Ilsandong-gu",
        "address_2": "Goyang-si  Gyunggi-do  410-722",
        "country": "KR"
    },
    "78C40E": {
        "oui_hex": "78-C4-0E",
        "organization": "H&D Wireless",
        "address_1": "Sjövägen 17",
        "address_2": "Solna    169 55",
        "country": "SE"
    },
    "2C0623": {
        "oui_hex": "2C-06-23",
        "organization": "Win Leader Inc.",
        "address_1": "Level 3 ,Alexander House,",
        "address_2": "Ebene",
        "country": "MU"
    },
    "0C2755": {
        "oui_hex": "0C-27-55",
        "organization": "Valuable Techologies Limited",
        "address_1": "602, Centre Point, J.B.Nagar,",
        "address_2": "Mumbai  Maharashtra  400059",
        "country": "IN"
    },
    "78998F": {
        "oui_hex": "78-99-8F",
        "organization": "MEDILINE ITALIA SRL",
        "address_1": "VIA 8 MARZO, 4",
        "address_2": "CORTE TEGGE  REGGIO NELL'EMILIA  42025",
        "country": "IT"
    },
    "40ECF8": {
        "oui_hex": "40-EC-F8",
        "organization": "Siemens AG",
        "address_1": "I IS MS EDM",
        "address_2": "Munich  Germany  85630",
        "country": "DE"
    },
    "BCB181": {
        "oui_hex": "BC-B1-81",
        "organization": "SHARP CORPORATION",
        "address_1": "22-22,Nagaike-cho,",
        "address_2": "Osaka,    545-8522,",
        "country": "JP"
    },
    "C8873B": {
        "oui_hex": "C8-87-3B",
        "organization": "Net Optics",
        "address_1": "5303 Betsy Ross Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "A8CE90": {
        "oui_hex": "A8-CE-90",
        "organization": "CVC",
        "address_1": "No.361,Renhua Rd.,",
        "address_2": "Dali City  Taichung  412",
        "country": "TW"
    },
    "E41F13": {
        "oui_hex": "E4-1F-13",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "701AED": {
        "oui_hex": "70-1A-ED",
        "organization": "ADVAS CO., LTD.",
        "address_1": "3-8-8 Shin-yokohama, Kohoku-ku",
        "address_2": "Yokohama-shi  Kanagawa-ken  222-0033",
        "country": "JP"
    },
    "6465C0": {
        "oui_hex": "64-65-C0",
        "organization": "Nuvon, Inc",
        "address_1": "3130 Alpine Road",
        "address_2": "Portola Valley  California  94028",
        "country": "US"
    },
    "7C1EB3": {
        "oui_hex": "7C-1E-B3",
        "organization": "2N TELEKOMUNIKACE a.s.",
        "address_1": "Modranska 621",
        "address_2": "Prague    143 01",
        "country": "CZ"
    },
    "4456B7": {
        "oui_hex": "44-56-B7",
        "organization": "Spawn Labs, Inc",
        "address_1": "2209 Granger Lane",
        "address_2": "Austin  TX  78613",
        "country": "US"
    },
    "44C9A2": {
        "oui_hex": "44-C9-A2",
        "organization": "Greenwald Industries",
        "address_1": "212 Middlesex Avenue",
        "address_2": "Chester  CT  06412",
        "country": "US"
    },
    "906DC8": {
        "oui_hex": "90-6D-C8",
        "organization": "DLG Automação Industrial Ltda",
        "address_1": "Rua José Batista Soares, 53",
        "address_2": "Sertãozinho  São Paulo  14176-119",
        "country": "BR"
    },
    "584CEE": {
        "oui_hex": "58-4C-EE",
        "organization": "Digital One Technologies, Limited",
        "address_1": "Room 2203, No.1 Shangdi Xinxi Road",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "002721": {
        "oui_hex": "00-27-21",
        "organization": "Shenzhen Baoan Fenda Industrial Co., Ltd",
        "address_1": "Fenda Hi-Tech Park",
        "address_2": "Baoan   Shenzhen  518108",
        "country": "CN"
    },
    "A07332": {
        "oui_hex": "A0-73-32",
        "organization": "Cashmaster International Limited",
        "address_1": "Fairykirk Road",
        "address_2": "Rosyth  Fife  KY11 2QQ",
        "country": "GB"
    },
    "64C6AF": {
        "oui_hex": "64-C6-AF",
        "organization": "AXERRA Networks Ltd",
        "address_1": "24  Raoul Wallenberg St. ,",
        "address_2": "Tel-Aviv    ISRAEL  69719",
        "country": "IL"
    },
    "44568D": {
        "oui_hex": "44-56-8D",
        "organization": "PNC Technologies  Co., Ltd.",
        "address_1": "Development Center",
        "address_2": "Anyang  Gyeonggi-Do  431-836",
        "country": "KR"
    },
    "406186": {
        "oui_hex": "40-61-86",
        "organization": "MICRO-STAR INT'L CO.,LTD",
        "address_1": "No.69,Li-De St",
        "address_2": "Jung-Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "0026F5": {
        "oui_hex": "00-26-F5",
        "organization": "XRPLUS Inc.",
        "address_1": "#805 Ace Techno Tower 2nd 197-17",
        "address_2": "Seoul    152-766",
        "country": "KR"
    },
    "0026F8": {
        "oui_hex": "00-26-F8",
        "organization": "Golden Highway Industry Development Co., Ltd.",
        "address_1": "Floor 7, Block 8, Vision Shenzhen Business Park, No.9 Gaoxin 9th South Road",
        "address_2": "Shenzhen City  Guangdong Province  518057",
        "country": "CN"
    },
    "0026F4": {
        "oui_hex": "00-26-F4",
        "organization": "Nesslab",
        "address_1": "489-2 Maetan 3-dong, Yeong Tong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  443-803",
        "country": "KR"
    },
    "0026EE": {
        "oui_hex": "00-26-EE",
        "organization": "TKM GmbH",
        "address_1": "Schlossstraße 123",
        "address_2": "Mönchengladbach  NRW  41238",
        "country": "DE"
    },
    "0026EF": {
        "oui_hex": "00-26-EF",
        "organization": "Technology Advancement Group, Inc.",
        "address_1": "22355 Tag Way",
        "address_2": "Dulles  VA  20166-9310",
        "country": "US"
    },
    "0026B2": {
        "oui_hex": "00-26-B2",
        "organization": "Setrix GmbH",
        "address_1": "Josephspitalstr. 15",
        "address_2": "Muenchen  Bayern  80331",
        "country": "DE"
    },
    "0026AF": {
        "oui_hex": "00-26-AF",
        "organization": "Duelco A/S",
        "address_1": "Mommarkvej 5",
        "address_2": "Soenderborg  Soenderjylland  DK6400",
        "country": "DK"
    },
    "0026B3": {
        "oui_hex": "00-26-B3",
        "organization": "Thales Communications Inc",
        "address_1": "22605 Gateway Center Drive",
        "address_2": "Clarksburg  MD  20871",
        "country": "US"
    },
    "0026A7": {
        "oui_hex": "00-26-A7",
        "organization": "CONNECT SRL",
        "address_1": "Via Cernaia, 11",
        "address_2": "Milan    20121",
        "country": "IT"
    },
    "0026A4": {
        "oui_hex": "00-26-A4",
        "organization": "Novus Produtos Eletronicos Ltda",
        "address_1": "Rua Alvaro Chaves, 155",
        "address_2": "Porto Alegre  RS  90220-040",
        "country": "BR"
    },
    "0026D8": {
        "oui_hex": "00-26-D8",
        "organization": "Magic Point Inc.",
        "address_1": "Suite 203, Building 17, No. 295 Lin Nan Road, Pudong Software Park Sanlin World Expo Block",
        "address_2": "Shanghai    2000126",
        "country": "CN"
    },
    "0026D6": {
        "oui_hex": "00-26-D6",
        "organization": "Ningbo Andy Optoelectronic Co., Ltd.",
        "address_1": "Lanjiang Street Industrial Zone",
        "address_2": "Yuyao  Zhejiang  315400",
        "country": "CN"
    },
    "00270F": {
        "oui_hex": "00-27-0F",
        "organization": "Envisionnovation Inc",
        "address_1": "4 Wareham Drive",
        "address_2": "Mississauga  Ontario  L5M 1B6",
        "country": "CA"
    },
    "00270A": {
        "oui_hex": "00-27-0A",
        "organization": "IEE S.A.",
        "address_1": "ZAE Weiergewan",
        "address_2": "Contern    L-5326",
        "country": "LU"
    },
    "002709": {
        "oui_hex": "00-27-09",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0026D3": {
        "oui_hex": "00-26-D3",
        "organization": "Zeno Information System",
        "address_1": "#1404 A-Dong Digital Empire Bldg, 980-3, Youngtong-dong, Youngtong-gu",
        "address_2": "Suwon City  Gyeonggi-Do  443-702",
        "country": "KR"
    },
    "0026D1": {
        "oui_hex": "00-26-D1",
        "organization": "S Squared Innovations Inc.",
        "address_1": "6807-104 Street",
        "address_2": "Edmonton  AB  T6H 2L5",
        "country": "CA"
    },
    "0026CB": {
        "oui_hex": "00-26-CB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002701": {
        "oui_hex": "00-27-01",
        "organization": "INCOstartec GmbH",
        "address_1": "Rheinstraße 17",
        "address_2": "Teltow  Germany  14513",
        "country": "DE"
    },
    "0026FB": {
        "oui_hex": "00-26-FB",
        "organization": "AirDio Wireless, Inc.",
        "address_1": "13-5, No. 79, Sec. 1, Hsin Tai Wu Road",
        "address_2": "Hsichih City, Taipei County  Taiwan  22101",
        "country": "TW"
    },
    "00271A": {
        "oui_hex": "00-27-1A",
        "organization": "Geenovo Technology Ltd.",
        "address_1": "Unit 402, 4/F., Tower I,SHUI QING MU HUA YUAN,",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "002714": {
        "oui_hex": "00-27-14",
        "organization": "Grainmustards, Co,ltd.",
        "address_1": "HEIWA MK Bldg,2-48-4,Nihonbashi-Hama-cho",
        "address_2": "Tokyo    103-0007",
        "country": "JP"
    },
    "002715": {
        "oui_hex": "00-27-15",
        "organization": "Rebound Telecom. Co., Ltd",
        "address_1": "12F,Building No.82,No.1198,North Qinzhou Rd,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "0026E6": {
        "oui_hex": "00-26-E6",
        "organization": "Visionhitech Co., Ltd.",
        "address_1": "Vision bldg. 150-3",
        "address_2": "Buchon  Kyunggi-Do  420-822",
        "country": "KR"
    },
    "0026DF": {
        "oui_hex": "00-26-DF",
        "organization": "TaiDoc Technology Corp.",
        "address_1": "7F, No. 127, Wugong 2nd Rd., 24888 Wugu Township",
        "address_2": "Taipei County  Taiwan  24888",
        "country": "TW"
    },
    "00266A": {
        "oui_hex": "00-26-6A",
        "organization": "ESSENSIUM NV",
        "address_1": "Gaston Geenslaan 9",
        "address_2": "LEUVEN  VL BRABANT  3001",
        "country": "BE"
    },
    "00266B": {
        "oui_hex": "00-26-6B",
        "organization": "SHINE UNION ENTERPRISE LIMITED",
        "address_1": "UNIT 1211, 12FL., CHEVALIER COMMERCIAL CENTER,",
        "address_2": "KOWLOON    NIL",
        "country": "HK"
    },
    "002667": {
        "oui_hex": "00-26-67",
        "organization": "CARECOM CO.,LTD.",
        "address_1": "3-35-4",
        "address_2": "Chofu  Tokyo  182-0025",
        "country": "JP"
    },
    "0026A2": {
        "oui_hex": "00-26-A2",
        "organization": "Instrumentation Technology Systems",
        "address_1": "19360 Business Center Drive",
        "address_2": "Northridge  CA  91324",
        "country": "US"
    },
    "00269F": {
        "oui_hex": "00-26-9F",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002699": {
        "oui_hex": "00-26-99",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002647": {
        "oui_hex": "00-26-47",
        "organization": "WFE TECHNOLOGY CORP.",
        "address_1": "17F NO.238,Chin-Hua N Rd,",
        "address_2": "Taichung    404",
        "country": "TW"
    },
    "002640": {
        "oui_hex": "00-26-40",
        "organization": "Baustem Broadband Technologies, Ltd.",
        "address_1": "910 Quantum Plaza",
        "address_2": "Beijing    100191",
        "country": "CN"
    },
    "002653": {
        "oui_hex": "00-26-53",
        "organization": "DaySequerra Corporation",
        "address_1": "154 Cooper Road",
        "address_2": "West Berlin  NJ  08091",
        "country": "US"
    },
    "00267B": {
        "oui_hex": "00-26-7B",
        "organization": "GSI Helmholtzzentrum für Schwerionenforschung GmbH",
        "address_1": "Planckstraße 1",
        "address_2": "Darmstadt  Hessen  64291",
        "country": "DE"
    },
    "002687": {
        "oui_hex": "00-26-87",
        "organization": "corega K.K",
        "address_1": "1-19-20, Shinyokohama",
        "address_2": "Yokohama-city  Kanagawa-ken  222-0033",
        "country": "JP"
    },
    "00268D": {
        "oui_hex": "00-26-8D",
        "organization": "CellTel S.p.A.",
        "address_1": "Via Romano 72",
        "address_2": "Scarmagno  Torino  10010",
        "country": "IT"
    },
    "002628": {
        "oui_hex": "00-26-28",
        "organization": "companytec automação e controle ltda.",
        "address_1": "Rua Marcilio Dias 3005",
        "address_2": "Pelotas  Rio Grande do Sul  96020-480",
        "country": "BR"
    },
    "00261F": {
        "oui_hex": "00-26-1F",
        "organization": "SAE Magnetics (H.K.) Ltd.",
        "address_1": "SAE Technology Centre",
        "address_2": "Hong Kong Science Park  Shatin, New Territories",
        "country": "HK"
    },
    "00261E": {
        "oui_hex": "00-26-1E",
        "organization": "QINGBANG ELEC(SZ) CO., LTD",
        "address_1": "No. 2, qimin Rd. North District, High-tech Industrial Park, Nanshan,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "002619": {
        "oui_hex": "00-26-19",
        "organization": "FRC",
        "address_1": "1511 South Benjamin Avenue",
        "address_2": "Mason City  IA  50401",
        "country": "US"
    },
    "0025EA": {
        "oui_hex": "00-25-EA",
        "organization": "Iphion BV",
        "address_1": "Willemstraat 106",
        "address_2": "Eindhoven    5616GE",
        "country": "NL"
    },
    "0025F0": {
        "oui_hex": "00-25-F0",
        "organization": "Suga Electronics Limited",
        "address_1": "Units 1904-1907, Chevalier Commercial Centre,",
        "address_2": "Kowloon Bay  Hong Kong",
        "country": "CN"
    },
    "0025E8": {
        "oui_hex": "00-25-E8",
        "organization": "Idaho Technology",
        "address_1": "390 Wakara way",
        "address_2": "Salt Lake city  UT  84108",
        "country": "US"
    },
    "0025E4": {
        "oui_hex": "00-25-E4",
        "organization": "OMNI-WiFi, LLC",
        "address_1": "70 Sullivan Street",
        "address_2": "Berwick  Maine  03901",
        "country": "US"
    },
    "0025FC": {
        "oui_hex": "00-25-FC",
        "organization": "ENDA ENDUSTRIYEL ELEKTRONIK LTD. STI.",
        "address_1": "Y. Dudullu Barbaros C. Kutup S. No. 20",
        "address_2": "Istanbul    34775",
        "country": "TR"
    },
    "0025FA": {
        "oui_hex": "00-25-FA",
        "organization": "J&M Analytik AG",
        "address_1": "Willy-Messerschmitt-Strasse 8",
        "address_2": "Essingen  BW  73457",
        "country": "DE"
    },
    "002633": {
        "oui_hex": "00-26-33",
        "organization": "MIR - Medical International Research",
        "address_1": "Via del Maggiolino 125",
        "address_2": "Rome  RM  00155",
        "country": "IT"
    },
    "0025D7": {
        "oui_hex": "00-25-D7",
        "organization": "CEDO",
        "address_1": "Videnska 127",
        "address_2": "BRNO    61900",
        "country": "CZ"
    },
    "0025D8": {
        "oui_hex": "00-25-D8",
        "organization": "KOREA MAINTENANCE",
        "address_1": "3F HAELIM BUIDING 103-7, GURO-5DONG",
        "address_2": "SEOUL    152-842",
        "country": "KR"
    },
    "0025D2": {
        "oui_hex": "00-25-D2",
        "organization": "InpegVision Co., Ltd",
        "address_1": "226-3, Bugok-dong, Geumjeong-gu,",
        "address_2": "Busan    609-320",
        "country": "KR"
    },
    "002630": {
        "oui_hex": "00-26-30",
        "organization": "ACOREL S.A.S",
        "address_1": "3, Rue Paul LANGEVIN",
        "address_2": "SAINT-PERAY    F-07130",
        "country": "FR"
    },
    "00262A": {
        "oui_hex": "00-26-2A",
        "organization": "Proxense, LLC",
        "address_1": "689 NW Stonepine Dr",
        "address_2": "Bend  Oregon  97701",
        "country": "US"
    },
    "0025FE": {
        "oui_hex": "00-25-FE",
        "organization": "Pilot Electronics Corporation",
        "address_1": "No. 2, Tzu-Chiang 3rd Road, Chung-Li Industrial Zone,",
        "address_2": "Taoyuan   Hsien  32063",
        "country": "TW"
    },
    "00257B": {
        "oui_hex": "00-25-7B",
        "organization": "STJ  ELECTRONICS  PVT  LTD",
        "address_1": "X-24 OKHLA  INDUSTRIAL  AREA",
        "address_2": "NEW  DELHI  DELHI  110 020",
        "country": "IN"
    },
    "00257C": {
        "oui_hex": "00-25-7C",
        "organization": "Huachentel Technology Development Co., Ltd",
        "address_1": "747 XinYu Rd. High-Tech Zone",
        "address_2": "Jinan  Shandong Province  250101",
        "country": "CN"
    },
    "002575": {
        "oui_hex": "00-25-75",
        "organization": "FiberPlex Technologies, LLC",
        "address_1": "10840-412 Guilford Rd",
        "address_2": "Annapolis Junction  MD  20701",
        "country": "US"
    },
    "002570": {
        "oui_hex": "00-25-70",
        "organization": "Eastern Communications Company Limited",
        "address_1": "No.398 Wensan Road,",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "00259B": {
        "oui_hex": "00-25-9B",
        "organization": "Beijing PKUNITY Microsystems Technology Co., Ltd",
        "address_1": "11th Floor, Resource Plaza, No.151 North Zhongguancun Street",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "002596": {
        "oui_hex": "00-25-96",
        "organization": "GIGAVISION srl",
        "address_1": "Via Figini, 16",
        "address_2": "Muggiò  Milano  20053",
        "country": "IT"
    },
    "002595": {
        "oui_hex": "00-25-95",
        "organization": "Northwest Signal Supply, Inc",
        "address_1": "12965 SW Herman Rd",
        "address_2": "Tualatin  OR  97062",
        "country": "US"
    },
    "0025C9": {
        "oui_hex": "00-25-C9",
        "organization": "SHENZHEN HUAPU DIGITAL CO., LTD",
        "address_1": "Futian District,Chegongmiao,TianAn Cyberpark",
        "address_2": "ShenZhen  Guangdong Province  518040",
        "country": "CN"
    },
    "00258F": {
        "oui_hex": "00-25-8F",
        "organization": "Trident Microsystems, Inc.",
        "address_1": "3408 Garrett Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002589": {
        "oui_hex": "00-25-89",
        "organization": "Hills Industries Limited",
        "address_1": "5 Cambria Road",
        "address_2": "Melbourne  VIC  3173",
        "country": "AU"
    },
    "002585": {
        "oui_hex": "00-25-85",
        "organization": "KOKUYO S&T Co., Ltd.",
        "address_1": "1-8-35",
        "address_2": "Minato-ku  Tokyo  108-8710",
        "country": "JP"
    },
    "002581": {
        "oui_hex": "00-25-81",
        "organization": "x-star networks Inc.",
        "address_1": "1F,NO1-2,Chungching S.Rd.Sec 3",
        "address_2": "Taipei    10076",
        "country": "TW"
    },
    "0025B5": {
        "oui_hex": "00-25-B5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0025BE": {
        "oui_hex": "00-25-BE",
        "organization": "Tektrap Systems Inc.",
        "address_1": "15 Buteau St.",
        "address_2": "Gatineau  Quebec  J8Z 1V4",
        "country": "CA"
    },
    "0025A0": {
        "oui_hex": "00-25-A0",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "00254D": {
        "oui_hex": "00-25-4D",
        "organization": "Singapore Technologies Electronics Limited",
        "address_1": "24 Ang Mo Kio",
        "address_2": "    569061",
        "country": "SG"
    },
    "00254C": {
        "oui_hex": "00-25-4C",
        "organization": "Videon Central, Inc.",
        "address_1": "2171 Sandy Drive",
        "address_2": "State College  PA  16803",
        "country": "US"
    },
    "002543": {
        "oui_hex": "00-25-43",
        "organization": "MONEYTECH",
        "address_1": "Rua Guiratinga 931 un. 103",
        "address_2": "São Paulo  SP  04141-001",
        "country": "BR"
    },
    "00255B": {
        "oui_hex": "00-25-5B",
        "organization": "CoachComm, LLC",
        "address_1": "205 Technology Parkway",
        "address_2": "Auburn  AL  36830",
        "country": "US"
    },
    "002516": {
        "oui_hex": "00-25-16",
        "organization": "Integrated Design Tools, Inc.",
        "address_1": "1202 E Park Avenue",
        "address_2": "Tallahassee  FL  32301",
        "country": "US"
    },
    "002510": {
        "oui_hex": "00-25-10",
        "organization": "Pico-Tesla Magnetic Therapies",
        "address_1": "7852 South Elati",
        "address_2": "Littleton  CO  80120",
        "country": "US"
    },
    "00256A": {
        "oui_hex": "00-25-6A",
        "organization": "inIT - Institut Industrial IT",
        "address_1": "Liebigstrasse 87",
        "address_2": "Lemgo  Northrhine-Westfalia  32657",
        "country": "DE"
    },
    "002562": {
        "oui_hex": "00-25-62",
        "organization": "interbro Co. Ltd.",
        "address_1": "6F Joyang B/D, 113 Samseong-Dong, Gangnam-Gu",
        "address_2": "Seoul    135-090",
        "country": "KR"
    },
    "002520": {
        "oui_hex": "00-25-20",
        "organization": "SMA Railway Technology GmbH",
        "address_1": "Miramstraße 87",
        "address_2": "Kassel  Hesse  34123",
        "country": "DE"
    },
    "002527": {
        "oui_hex": "00-25-27",
        "organization": "Bitrode Corp.",
        "address_1": "9787 Green Park Industrial Drive",
        "address_2": "St. Louis  MO  63123",
        "country": "US"
    },
    "002525": {
        "oui_hex": "00-25-25",
        "organization": "CTERA Networks Ltd.",
        "address_1": "24 Imber St.",
        "address_2": "Petach-Tikva    495111",
        "country": "IL"
    },
    "002551": {
        "oui_hex": "00-25-51",
        "organization": "SE-Elektronic GmbH",
        "address_1": "Eythstraße 16",
        "address_2": "Göppingen    73037",
        "country": "DE"
    },
    "00253A": {
        "oui_hex": "00-25-3A",
        "organization": "CEVA, Ltd.",
        "address_1": "2 Maskit Street.",
        "address_2": "Herzelia    46120",
        "country": "IL"
    },
    "0024A2": {
        "oui_hex": "00-24-A2",
        "organization": "Hong Kong Middleware Technology Limited",
        "address_1": "Room 1315 ,Leighton Centre,77 Leighton Road",
        "address_2": "Causeway Bay    852",
        "country": "HK"
    },
    "0024B9": {
        "oui_hex": "00-24-B9",
        "organization": "Wuhan Higheasy Electronic Technology Development Co.Ltd",
        "address_1": "Bldg A2 Optics Valley Software Park,Guanshan 1st Rd,",
        "address_2": "Wuhan  Hubei  430033",
        "country": "CN"
    },
    "0024BD": {
        "oui_hex": "00-24-BD",
        "organization": "Hainzl Industriesysteme GmbH",
        "address_1": "Industriezeile 56",
        "address_2": "Linz  Upper Austria  4021",
        "country": "AT"
    },
    "0024B6": {
        "oui_hex": "00-24-B6",
        "organization": "Seagate Technology",
        "address_1": "1280 Disc Drive",
        "address_2": "Shakopee  MN  55379",
        "country": "US"
    },
    "0024F7": {
        "oui_hex": "00-24-F7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0024E5": {
        "oui_hex": "00-24-E5",
        "organization": "Seer Technology, Inc",
        "address_1": "2681 Parleys Way",
        "address_2": "Salt Lake City  Utah  84109",
        "country": "US"
    },
    "0024E2": {
        "oui_hex": "00-24-E2",
        "organization": "HASEGAWA ELECTRIC CO.,LTD.",
        "address_1": "5-6-20 SHIOE",
        "address_2": "AMAGASAKI  HYOGO  661-0976",
        "country": "JP"
    },
    "0024E0": {
        "oui_hex": "00-24-E0",
        "organization": "DS Tech, LLC",
        "address_1": "2210 Hutton Drive",
        "address_2": "Carrollton  TX  75006",
        "country": "US"
    },
    "0024F3": {
        "oui_hex": "00-24-F3",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002501": {
        "oui_hex": "00-25-01",
        "organization": "JSC Supertel",
        "address_1": "38A Petrogradskaya emb.",
        "address_2": "St.Petersburg    197101",
        "country": "RU"
    },
    "0024C8": {
        "oui_hex": "00-24-C8",
        "organization": "Broadband Solutions Group",
        "address_1": "1101 Marina Village Parkway",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "0024C5": {
        "oui_hex": "00-24-C5",
        "organization": "Meridian Audio Limited",
        "address_1": "11 Latham Road",
        "address_2": "Huntingdon  Cambs  PE29 6YE",
        "country": "GB"
    },
    "002496": {
        "oui_hex": "00-24-96",
        "organization": "Ginzinger electronic systems",
        "address_1": "Gewerbegebiet Pirath 16",
        "address_2": "Weng  Upper Austria  4952",
        "country": "AT"
    },
    "002499": {
        "oui_hex": "00-24-99",
        "organization": "Aquila Technologies",
        "address_1": "8429A Washington Place NE",
        "address_2": "Albuquerque  NM  87113",
        "country": "US"
    },
    "00248A": {
        "oui_hex": "00-24-8A",
        "organization": "Kaga Electronics Co., Ltd.",
        "address_1": "Hongo 2-2-9",
        "address_2": "  Tokyo  113-8503",
        "country": "JP"
    },
    "002435": {
        "oui_hex": "00-24-35",
        "organization": "WIDE CORPORATION",
        "address_1": "LEADERS TOWER 7TH FL., GOMAE-DONG, GIHEUNG-GU",
        "address_2": "YONGIN  GYEONGGI  446-901",
        "country": "KR"
    },
    "002431": {
        "oui_hex": "00-24-31",
        "organization": "Uni-v co.,ltd",
        "address_1": "5/F,COFCO Property Tower,",
        "address_2": "Shenzhen  Guangdong  518126",
        "country": "CN"
    },
    "002432": {
        "oui_hex": "00-24-32",
        "organization": "Neostar Technology Co.,LTD",
        "address_1": "8F., No.102, Sec. 1, Sintai 5th Rd.",
        "address_2": "Sijhih City  Taipei  22161",
        "country": "TW"
    },
    "002443": {
        "oui_hex": "00-24-43",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002441": {
        "oui_hex": "00-24-41",
        "organization": "Wanzl Metallwarenfabrik GmbH",
        "address_1": "Bubesheimer Straße 4",
        "address_2": "Leipheim  Bavaria  89340",
        "country": "DE"
    },
    "00243B": {
        "oui_hex": "00-24-3B",
        "organization": "CSSI (S) Pte Ltd",
        "address_1": "70 Bendemeer Road Unit 04-04",
        "address_2": "    339940",
        "country": "SG"
    },
    "002451": {
        "oui_hex": "00-24-51",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00244A": {
        "oui_hex": "00-24-4A",
        "organization": "Voyant International",
        "address_1": "444 Castro St",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "002447": {
        "oui_hex": "00-24-47",
        "organization": "Kaztek Systems",
        "address_1": "17 Bromfield Road",
        "address_2": "Acton  MA  01720",
        "country": "US"
    },
    "002477": {
        "oui_hex": "00-24-77",
        "organization": "Tibbo Technology",
        "address_1": "9F-3, No 31, Lane 169, Kang-Ning St.,",
        "address_2": "Hsi-Chih  Taipei Hsien  221",
        "country": "TW"
    },
    "00246E": {
        "oui_hex": "00-24-6E",
        "organization": "Phihong USA Corp.",
        "address_1": "47800 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00245D": {
        "oui_hex": "00-24-5D",
        "organization": "Terberg besturingstechniek B.V.",
        "address_1": "Lage Dijk-Noord 3",
        "address_2": "IJsselstein  Utrecht  3401 VA",
        "country": "NL"
    },
    "002450": {
        "oui_hex": "00-24-50",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002458": {
        "oui_hex": "00-24-58",
        "organization": "PA Bastion CC",
        "address_1": "97, liter K, Buddyonnovsky ave.",
        "address_2": "Rostov-on-Don    344011",
        "country": "RU"
    },
    "002473": {
        "oui_hex": "00-24-73",
        "organization": "3COM EUROPE LTD",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  HERTS.  HP2 4NW",
        "country": "GB"
    },
    "00246B": {
        "oui_hex": "00-24-6B",
        "organization": "Covia, Inc.",
        "address_1": "Benex S-3 Bldg., 3-20-8, Shinyokohama,Kohoku-ku,",
        "address_2": "Yokohama-city  Kanagawa-pref.  222-0033",
        "country": "JP"
    },
    "0023F5": {
        "oui_hex": "00-23-F5",
        "organization": "WILO SE",
        "address_1": "Nortkirchenstraße 100",
        "address_2": "D - 44263 Dortmund  NRW  44263",
        "country": "DE"
    },
    "0023FF": {
        "oui_hex": "00-23-FF",
        "organization": "Beijing HTTC Technology Ltd.",
        "address_1": "B-13D-3 Keshi Building,Jia No.28 Xinxi Road,SHANGDI IT Industry Base",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "0023F6": {
        "oui_hex": "00-23-F6",
        "organization": "Softwell Technology Co., Ltd.",
        "address_1": "4F, No. 419, Jhonghe Rd., Yonghe City,",
        "address_2": "Taipei County    234",
        "country": "TW"
    },
    "0023F3": {
        "oui_hex": "00-23-F3",
        "organization": "Glocom, Inc.",
        "address_1": "22 Firstfield Road",
        "address_2": "Gaithersburg  Maryland  20878",
        "country": "US"
    },
    "0023F0": {
        "oui_hex": "00-23-F0",
        "organization": "Shanghai Jinghan Weighing Apparatus Co. Ltd.",
        "address_1": "Building 58, No.99 Chunguang Road, Xinzhuang Industrial Zone,Minhang,",
        "address_2": "Shanghai    201108",
        "country": "CN"
    },
    "002410": {
        "oui_hex": "00-24-10",
        "organization": "NUETEQ Technology,Inc.",
        "address_1": "11F, No. 112, Sec. 1, Zhong-Xiao E Rd.",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "002408": {
        "oui_hex": "00-24-08",
        "organization": "Pacific Biosciences",
        "address_1": "1505 Adams Drive",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "002430": {
        "oui_hex": "00-24-30",
        "organization": "Ruby Tech Corp.",
        "address_1": "3F, NO. 1, Lane 50, Nan Kang Road, Sec. 3,",
        "address_2": "Taipei    11510",
        "country": "TW"
    },
    "00242E": {
        "oui_hex": "00-24-2E",
        "organization": "Datastrip Inc.",
        "address_1": "1 Waterview Drive",
        "address_2": "Shelton  CT  06484",
        "country": "US"
    },
    "00241D": {
        "oui_hex": "00-24-1D",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "00241A": {
        "oui_hex": "00-24-1A",
        "organization": "Red Beetle Inc.",
        "address_1": "898 Silas Deane Highway",
        "address_2": "Wethersfield  CT  06109",
        "country": "US"
    },
    "002414": {
        "oui_hex": "00-24-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00240C": {
        "oui_hex": "00-24-0C",
        "organization": "DELEC GmbH",
        "address_1": "Ruheweg 17-21",
        "address_2": "Göllheim  Rheinland-Pfalz  67307",
        "country": "DE"
    },
    "0023F9": {
        "oui_hex": "00-23-F9",
        "organization": "Double-Take Software, INC.",
        "address_1": "8470 Allison Pointe Blvd",
        "address_2": "Indianapolis  IN  46250",
        "country": "US"
    },
    "0023E9": {
        "oui_hex": "00-23-E9",
        "organization": "F5 Networks, Inc.",
        "address_1": "401 Elliott Ave. W.",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "0023EA": {
        "oui_hex": "00-23-EA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0023E5": {
        "oui_hex": "00-23-E5",
        "organization": "IPaXiom Networks",
        "address_1": "Aston Court",
        "address_2": "High Wycombe  Buckinghamshire  HP11 1LA",
        "country": "GB"
    },
    "0023B6": {
        "oui_hex": "00-23-B6",
        "organization": "SECURITE COMMUNICATIONS / HONEYWELL",
        "address_1": "FONT DE L'ORME",
        "address_2": "MOUGINS  FRANCE  06250",
        "country": "US"
    },
    "0023B8": {
        "oui_hex": "00-23-B8",
        "organization": "Sichuan Jiuzhou Electronic Technology Co.,Ltd",
        "address_1": "No.259 Jiuzhou Road,",
        "address_2": "Mianyang  Sichuan  621000",
        "country": "CN"
    },
    "0023BA": {
        "oui_hex": "00-23-BA",
        "organization": "Chroma",
        "address_1": "68, Hwa-Ya 1st Rd., Hwa-Ya Technical Park,",
        "address_2": "Taoyuan Hsien  Taiwan  333",
        "country": "TW"
    },
    "0023BC": {
        "oui_hex": "00-23-BC",
        "organization": "EQ-SYS GmbH",
        "address_1": "Hinter den Gärten 15b",
        "address_2": "Treuenbrietzen OT Feldheim  Brandenburg  14929",
        "country": "DE"
    },
    "0023B1": {
        "oui_hex": "00-23-B1",
        "organization": "Longcheer Technology (Singapore) Pte Ltd",
        "address_1": "43 Kaki Bukit View,  #04-01  ,",
        "address_2": "    415970",
        "country": "SG"
    },
    "002396": {
        "oui_hex": "00-23-96",
        "organization": "ANDES TECHNOLOGY CORPORATION",
        "address_1": "2F,No. 1, Li-Hsin First Road,",
        "address_2": "Hsin-Chu  Taiwan  300",
        "country": "TW"
    },
    "002394": {
        "oui_hex": "00-23-94",
        "organization": "Samjeon",
        "address_1": "#1313-1 Joil-Ri, Samdong-Myeun,Ulju-Gun",
        "address_2": "Ulsan City  South Korea  689-934",
        "country": "KR"
    },
    "002377": {
        "oui_hex": "00-23-77",
        "organization": "Isotek Electronics Ltd",
        "address_1": "9 Clayton Wood Bank",
        "address_2": "Leeds    LS16 6QZ",
        "country": "GB"
    },
    "002371": {
        "oui_hex": "00-23-71",
        "organization": "SOAM Systel",
        "address_1": "182-13, Daerung Post Tower II, 1504",
        "address_2": "Seoul  Guro-dong, Guro-gu  152-847",
        "country": "KR"
    },
    "0023A1": {
        "oui_hex": "00-23-A1",
        "organization": "Trend Electronics Ltd",
        "address_1": "Gut No. 350",
        "address_2": "Auranagabad  Maharashtra  431210",
        "country": "IN"
    },
    "0023A6": {
        "oui_hex": "00-23-A6",
        "organization": "E-Mon",
        "address_1": "One Oxford Valley, Suite 418",
        "address_2": "Langhorne  PA  19047",
        "country": "US"
    },
    "0023A8": {
        "oui_hex": "00-23-A8",
        "organization": "Marshall Electronics",
        "address_1": "20608 Madrona Ave",
        "address_2": "Torrance  CA  90503",
        "country": "US"
    },
    "00239A": {
        "oui_hex": "00-23-9A",
        "organization": "EasyData Hardware GmbH",
        "address_1": "Breslauer Str. 24",
        "address_2": "Wehrheim  Hessen  D-61273",
        "country": "DE"
    },
    "0023CC": {
        "oui_hex": "00-23-CC",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002379": {
        "oui_hex": "00-23-79",
        "organization": "Union Business Machines Co. Ltd.",
        "address_1": "Unit 2, 2/F, Block A, Hong Kong Industrial Centre,",
        "address_2": "Lai Chi Kok  Kowloon",
        "country": "HK"
    },
    "00238C": {
        "oui_hex": "00-23-8C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0023C0": {
        "oui_hex": "00-23-C0",
        "organization": "Broadway Networks",
        "address_1": "1754 Technology Drive, Suite 208",
        "address_2": "San Jose  California  95110",
        "country": "US"
    },
    "002358": {
        "oui_hex": "00-23-58",
        "organization": "SYSTEL SA",
        "address_1": "ZI DE BELLE AIRE",
        "address_2": "AYTRE    17440",
        "country": "FR"
    },
    "002356": {
        "oui_hex": "00-23-56",
        "organization": "Packet Forensics LLC",
        "address_1": "420 S Smith Rd",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "002350": {
        "oui_hex": "00-23-50",
        "organization": "RDC, Inc. dba LynTec",
        "address_1": "8385 Melrose Drive",
        "address_2": "Lenexa  KS  66214",
        "country": "US"
    },
    "00234F": {
        "oui_hex": "00-23-4F",
        "organization": "Luminous Power Technologies Pvt. Ltd.",
        "address_1": "C8-C9, Community Center,",
        "address_2": "New Delhi    110058",
        "country": "IN"
    },
    "00234B": {
        "oui_hex": "00-23-4B",
        "organization": "Inyuan Technology Inc.",
        "address_1": "No. 3, Singye St.,",
        "address_2": "Taoyuan County    33341",
        "country": "TW"
    },
    "002349": {
        "oui_hex": "00-23-49",
        "organization": "Helmholtz Centre Berlin for Material and Energy",
        "address_1": "Department FMD",
        "address_2": "Berlin    14109",
        "country": "DE"
    },
    "002346": {
        "oui_hex": "00-23-46",
        "organization": "Vestac",
        "address_1": "P.O. Box 7358",
        "address_2": "Shrewsbury  NJ  07702",
        "country": "US"
    },
    "002307": {
        "oui_hex": "00-23-07",
        "organization": "FUTURE INNOVATION TECH CO.,LTD",
        "address_1": "312 3-DONG, GWANGMYUNG INDUSTRIAL COMPLEX 201",
        "address_2": "GWANGMYUNG  GYUNGGI  423060",
        "country": "KR"
    },
    "002305": {
        "oui_hex": "00-23-05",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0022FF": {
        "oui_hex": "00-22-FF",
        "organization": "NIVIS LLC",
        "address_1": "1000 CIRCLE 75",
        "address_2": "ATLANTA  GA  30339",
        "country": "US"
    },
    "002344": {
        "oui_hex": "00-23-44",
        "organization": "Objective Interface Systems, Inc.",
        "address_1": "220 Spring Street, Suite 530",
        "address_2": "Herndon  VA  20170-6201",
        "country": "US"
    },
    "00233C": {
        "oui_hex": "00-23-3C",
        "organization": "Alflex",
        "address_1": "Blauw-roodlaan 300",
        "address_2": "ZOETERMEER    2718 SK",
        "country": "NL"
    },
    "002333": {
        "oui_hex": "00-23-33",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00232E": {
        "oui_hex": "00-23-2E",
        "organization": "Kedah Electronics Engineering, LLC",
        "address_1": "Zelenograd, 445",
        "address_2": "Moscow    124498",
        "country": "RU"
    },
    "002320": {
        "oui_hex": "00-23-20",
        "organization": "Nicira Networks",
        "address_1": "3460 W. Bayshore Rd.",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "002364": {
        "oui_hex": "00-23-64",
        "organization": "Power Instruments Pte Ltd",
        "address_1": "BLK 40 TOH GUAN RD EAST, #01-62 ENTERPRISE HUB",
        "address_2": "    608582",
        "country": "SG"
    },
    "002317": {
        "oui_hex": "00-23-17",
        "organization": "Lasercraft Inc",
        "address_1": "1450 Oakbrook Drive",
        "address_2": "Norcross  GA  30093",
        "country": "US"
    },
    "00230E": {
        "oui_hex": "00-23-0E",
        "organization": "Gorba AG",
        "address_1": "Sandackerstrasse",
        "address_2": "Oberbüren  SG  CH - 9245",
        "country": "CH"
    },
    "002362": {
        "oui_hex": "00-23-62",
        "organization": "Goldline Controls",
        "address_1": "61 Whitecap Dr",
        "address_2": "North Kingstown  RI  02852",
        "country": "US"
    },
    "00235E": {
        "oui_hex": "00-23-5E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002322": {
        "oui_hex": "00-23-22",
        "organization": "KISS Teknical Solutions, Inc.",
        "address_1": "1583 S. Navajo Way",
        "address_2": "Chandler  Arizona  85286",
        "country": "US"
    },
    "0022B6": {
        "oui_hex": "00-22-B6",
        "organization": "Superflow Technologies Group",
        "address_1": "4060 Dixon Street",
        "address_2": "Des Moines  IA  50266",
        "country": "US"
    },
    "0022B5": {
        "oui_hex": "00-22-B5",
        "organization": "NOVITA",
        "address_1": "3F301,Namsung B/D 340-30",
        "address_2": "Geumcheon-Gu  Seoul  153-782",
        "country": "KR"
    },
    "0022B2": {
        "oui_hex": "00-22-B2",
        "organization": "4RF Communications Ltd",
        "address_1": "26 Glover Street",
        "address_2": "Ngauranga  Wellington  6031",
        "country": "NZ"
    },
    "0022AC": {
        "oui_hex": "00-22-AC",
        "organization": "Hangzhou Siyuan Tech. Co., Ltd",
        "address_1": "5 F, Tower B, No. 37, Xiang Yuan Road",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "0022AD": {
        "oui_hex": "00-22-AD",
        "organization": "TELESIS TECHNOLOGIES, INC.",
        "address_1": "28181 River Drive",
        "address_2": "Circleville  Ohio  43113",
        "country": "US"
    },
    "0022AE": {
        "oui_hex": "00-22-AE",
        "organization": "Mattel Inc.",
        "address_1": "333 Continental Blvd.",
        "address_2": "El Segundo  CA  90245",
        "country": "US"
    },
    "0022D5": {
        "oui_hex": "00-22-D5",
        "organization": "Eaton Corp. Electrical Group Data Center Solutions - Pulizzi",
        "address_1": "3200 S. Susan St.",
        "address_2": "Santa Ana  CA  92704",
        "country": "US"
    },
    "0022D1": {
        "oui_hex": "00-22-D1",
        "organization": "Albrecht Jung GmbH & Co. KG",
        "address_1": "Volmestraße 1",
        "address_2": "Schalksmühle  NRW  58579",
        "country": "DE"
    },
    "0022D2": {
        "oui_hex": "00-22-D2",
        "organization": "All Earth Comércio de Eletrônicos LTDA.",
        "address_1": "Rua Leonida Reimman Trotti, 343",
        "address_2": "Campinas  São Paulo  13065-704",
        "country": "BR"
    },
    "0022C2": {
        "oui_hex": "00-22-C2",
        "organization": "Proview Eletrônica do Brasil LTDA",
        "address_1": "R. Acará 203 - Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075-030",
        "country": "BR"
    },
    "0022BD": {
        "oui_hex": "00-22-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0022BA": {
        "oui_hex": "00-22-BA",
        "organization": "HUTH Elektronik Systeme GmbH",
        "address_1": "Echternacher Str. 10",
        "address_2": "Troisdorf-Spich  NRW  53842",
        "country": "DE"
    },
    "0022BB": {
        "oui_hex": "00-22-BB",
        "organization": "beyerdynamic GmbH & Co. KG",
        "address_1": "Theresienstraße 8",
        "address_2": "Heilbronn    74072",
        "country": "DE"
    },
    "0022A3": {
        "oui_hex": "00-22-A3",
        "organization": "California Eastern Laboratories",
        "address_1": "4590 Patrick Henry Dr.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "002302": {
        "oui_hex": "00-23-02",
        "organization": "Cobalt Digital, Inc.",
        "address_1": "2406 East University Avenue",
        "address_2": "Urbana  IL  61802",
        "country": "US"
    },
    "0022F5": {
        "oui_hex": "00-22-F5",
        "organization": "Advanced Realtime Tracking GmbH",
        "address_1": "Am Oeferl 6",
        "address_2": "Weilheim  Bayern  D-82362",
        "country": "DE"
    },
    "0022CA": {
        "oui_hex": "00-22-CA",
        "organization": "Anviz Biometric Tech. Co., Ltd.",
        "address_1": "5th Floor, 4299 Jindu Road,",
        "address_2": "Shanghai    201108",
        "country": "CN"
    },
    "0022C7": {
        "oui_hex": "00-22-C7",
        "organization": "SEGGER Microcontroller GmbH & Co. KG",
        "address_1": "In den Weiden 11",
        "address_2": "Hilden  NRW  40721",
        "country": "DE"
    },
    "0022C1": {
        "oui_hex": "00-22-C1",
        "organization": "Active Storage Inc.",
        "address_1": "2295 Jefferson Street",
        "address_2": "Torrance  CA  90501",
        "country": "US"
    },
    "00228F": {
        "oui_hex": "00-22-8F",
        "organization": "CNRS",
        "address_1": "MRCT",
        "address_2": "Meudon  Ile de France  92195",
        "country": "FR"
    },
    "002297": {
        "oui_hex": "00-22-97",
        "organization": "XMOS Semiconductor",
        "address_1": "Venturers House",
        "address_2": "Bristol    BS1 4PB",
        "country": "GB"
    },
    "002292": {
        "oui_hex": "00-22-92",
        "organization": "Cinetal",
        "address_1": "8651 Castle Park",
        "address_2": "Indianapolis  IN  46256",
        "country": "US"
    },
    "0022E5": {
        "oui_hex": "00-22-E5",
        "organization": "Fisher-Rosemount Systems Inc.",
        "address_1": "12301 Research Blvd",
        "address_2": "Austin  Texas  78759",
        "country": "US"
    },
    "0022E4": {
        "oui_hex": "00-22-E4",
        "organization": "APASS TECHNOLOGY CO., LTD.",
        "address_1": "2F, No. 267, Sec. 3, Chengde Rd.,",
        "address_2": "TEIPEI    113",
        "country": "TW"
    },
    "00224F": {
        "oui_hex": "00-22-4F",
        "organization": "Byzoro Networks Ltd.",
        "address_1": "Room 5A1,Block A, Keshi Plaza,No. 28A Info. Road,",
        "address_2": "  Beijing  100085",
        "country": "CN"
    },
    "002251": {
        "oui_hex": "00-22-51",
        "organization": "Lumasense Technologies",
        "address_1": "3033 Scott Blvd.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00225E": {
        "oui_hex": "00-22-5E",
        "organization": "Uwin Technologies Co.,LTD",
        "address_1": "2F,No.22.R&D RD II,SBIP",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "002258": {
        "oui_hex": "00-22-58",
        "organization": "Taiyo Yuden Co., Ltd.",
        "address_1": "8-1 Sakae-Cho",
        "address_2": "",
        "country": "JP"
    },
    "00225B": {
        "oui_hex": "00-22-5B",
        "organization": "Teradici Corporation",
        "address_1": "101 4621 Canada Way,",
        "address_2": "Burnaby  BC  V6G 4X8",
        "country": "CA"
    },
    "002259": {
        "oui_hex": "00-22-59",
        "organization": "Guangzhou New Postcom Equipment Co.,Ltd.",
        "address_1": "No.3Ã‚Â¡Ã‚Â¡Guangpuxi Road,Guangzhou Science City,",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "002253": {
        "oui_hex": "00-22-53",
        "organization": "Entorian Technologies",
        "address_1": "8900 Shoal Creek Blvd",
        "address_2": "Austin  TX  78757",
        "country": "US"
    },
    "00222C": {
        "oui_hex": "00-22-2C",
        "organization": "Ceton Corp",
        "address_1": "8259 122nd Ave NE, Suite 275",
        "address_2": "Kirkland  Washington  98033",
        "country": "US"
    },
    "00222D": {
        "oui_hex": "00-22-2D",
        "organization": "SMC Networks Inc.",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "00222A": {
        "oui_hex": "00-22-2A",
        "organization": "SoundEar A/S",
        "address_1": "Rentemestervej 80",
        "address_2": "Copenhagen NV  Denmark  DK-2400",
        "country": "DK"
    },
    "00227E": {
        "oui_hex": "00-22-7E",
        "organization": "Chengdu 30Kaitian Communication Industry Co.Ltd",
        "address_1": "No.6 Chuangye Road",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "00227C": {
        "oui_hex": "00-22-7C",
        "organization": "Woori SMT Co.,ltd",
        "address_1": "649-2,Suwolam-ri,Seotan-Myun",
        "address_2": "Pyongtaek  Kyonggi-Do  451-852",
        "country": "KR"
    },
    "002277": {
        "oui_hex": "00-22-77",
        "organization": "NEC Australia Pty Ltd",
        "address_1": "649-655 Springvale Rd",
        "address_2": "Mulgrave  Victoria  3170",
        "country": "AU"
    },
    "00223D": {
        "oui_hex": "00-22-3D",
        "organization": "JumpGen Systems, LLC",
        "address_1": "2111 Palomar Airport Rd",
        "address_2": "Carlsbad  CA  92011",
        "country": "US"
    },
    "002239": {
        "oui_hex": "00-22-39",
        "organization": "Indiana Life Sciences Incorporated",
        "address_1": "8875 Bash Street",
        "address_2": "Indianapolis  Indiana  46256",
        "country": "US"
    },
    "002235": {
        "oui_hex": "00-22-35",
        "organization": "Strukton Systems bv",
        "address_1": "Westkanaaldijk 2",
        "address_2": "Utrecht    3542 DA",
        "country": "NL"
    },
    "002279": {
        "oui_hex": "00-22-79",
        "organization": "Nippon Conlux Co., Ltd.",
        "address_1": "5-3-8, Chiyoda",
        "address_2": "Sakado-shi  Saitama  350-0214",
        "country": "JP"
    },
    "002271": {
        "oui_hex": "00-22-71",
        "organization": "Jäger Computergesteuerte Meßtechnik GmbH.",
        "address_1": "Rheinstraße 2-4",
        "address_2": "Lorsch  Hessen  64653",
        "country": "DE"
    },
    "002247": {
        "oui_hex": "00-22-47",
        "organization": "DAC ENGINEERING CO., LTD.",
        "address_1": "1-5 Oyanagi-cho",
        "address_2": "Kyoto    601-8128",
        "country": "JP"
    },
    "00221F": {
        "oui_hex": "00-22-1F",
        "organization": "eSang Technologies Co., Ltd.",
        "address_1": "#1-817, IT Castle 550-1, Gasan-Dong,",
        "address_2": "Seoul    153-768",
        "country": "KR"
    },
    "0021E6": {
        "oui_hex": "00-21-E6",
        "organization": "Starlight Video Limited",
        "address_1": "5/F., Shing Dao Industrial Building,",
        "address_2": "",
        "country": "HK"
    },
    "0021E0": {
        "oui_hex": "00-21-E0",
        "organization": "CommAgility Ltd",
        "address_1": "Holywell Park",
        "address_2": "Loughborough  Leics  LE11 3AQ",
        "country": "GB"
    },
    "0021DE": {
        "oui_hex": "00-21-DE",
        "organization": "Firepro Wireless",
        "address_1": "27, Zamrudpur Community Center,",
        "address_2": "New Delhi  Haryana  110020",
        "country": "IN"
    },
    "0021F9": {
        "oui_hex": "00-21-F9",
        "organization": "WIRECOM Technologies",
        "address_1": "135, rue Jacques Charles",
        "address_2": "OLIVET  Loiret  45166",
        "country": "FR"
    },
    "0021FA": {
        "oui_hex": "00-21-FA",
        "organization": "A4SP Technologies Ltd.",
        "address_1": "Keilaranta 19 D",
        "address_2": "Espoo  Uusimaa  02150",
        "country": "FI"
    },
    "0021F0": {
        "oui_hex": "00-21-F0",
        "organization": "EW3 Technologies LLC",
        "address_1": "114 E 11th St",
        "address_2": "Connersville  IN  47331",
        "country": "US"
    },
    "0021D3": {
        "oui_hex": "00-21-D3",
        "organization": "BOCOM SECURITY(ASIA PACIFIC) LIMITED",
        "address_1": "Flr.3,NO.29,#69 Guiqing RD",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "0021CC": {
        "oui_hex": "00-21-CC",
        "organization": "Flextronics International",
        "address_1": "Stretton Green Distribution Centre Langford Way",
        "address_2": "Warrington  Cheshire  WA4 4TQ",
        "country": "GB"
    },
    "0021B9": {
        "oui_hex": "00-21-B9",
        "organization": "Universal Devices Inc.",
        "address_1": "5353 Yarmouth Ave. #209",
        "address_2": "Encino  CA  91316",
        "country": "US"
    },
    "0021B3": {
        "oui_hex": "00-21-B3",
        "organization": "Ross Controls",
        "address_1": "One Ross Way",
        "address_2": "Lavonia  GA  30553",
        "country": "US"
    },
    "0021B6": {
        "oui_hex": "00-21-B6",
        "organization": "Triacta Power Technologies Inc.",
        "address_1": "Box 582, 7 Mill Street",
        "address_2": "Almonte  Ontario  K0A 1A0",
        "country": "CA"
    },
    "002217": {
        "oui_hex": "00-22-17",
        "organization": "Neat Electronics",
        "address_1": "Varuvägen 2",
        "address_2": "Löddeköpinge  Skåne  SE-24642",
        "country": "SE"
    },
    "002211": {
        "oui_hex": "00-22-11",
        "organization": "Rohati Systems",
        "address_1": "1192 Borregas Ave",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0021CF": {
        "oui_hex": "00-21-CF",
        "organization": "The Crypto Group",
        "address_1": "Zugerstrasse 42",
        "address_2": "Steinhausen  Zug  6312",
        "country": "CH"
    },
    "0021C5": {
        "oui_hex": "00-21-C5",
        "organization": "3DSP Corp",
        "address_1": "16271 Laguna Canyon Road",
        "address_2": "Irvine,  CA  92618",
        "country": "US"
    },
    "002212": {
        "oui_hex": "00-22-12",
        "organization": "CAI Networks, Inc.",
        "address_1": "4790 Irvine Blvd",
        "address_2": "Irvine  California  92620",
        "country": "US"
    },
    "00220D": {
        "oui_hex": "00-22-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002208": {
        "oui_hex": "00-22-08",
        "organization": "Certicom Corp",
        "address_1": "5520 Explorer Drive, 4th Floor",
        "address_2": "Mississauga  ON  L4W 5L1",
        "country": "CA"
    },
    "0021EE": {
        "oui_hex": "00-21-EE",
        "organization": "Full Spectrum Inc.",
        "address_1": "1149 Chestnut Street, Suite 100",
        "address_2": "Menlo Park  California  94025",
        "country": "US"
    },
    "0021EC": {
        "oui_hex": "00-21-EC",
        "organization": "Solutronic GmbH",
        "address_1": "Kueferstrasse 18",
        "address_2": "Koengen    73257",
        "country": "DE"
    },
    "002205": {
        "oui_hex": "00-22-05",
        "organization": "WeLink Solutions, Inc.",
        "address_1": "3F, No. 88, Sec. 1, Nei-Hu Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "002209": {
        "oui_hex": "00-22-09",
        "organization": "Omron Healthcare Co., Ltd",
        "address_1": "24 Yamanoshita-cho Yamanouchi",
        "address_2": "Kyoto    6150084",
        "country": "JP"
    },
    "00218C": {
        "oui_hex": "00-21-8C",
        "organization": "TopControl GMBH",
        "address_1": "Enzenbergweg 24/A",
        "address_2": "Terlan (BZ)    39018",
        "country": "IT"
    },
    "00218A": {
        "oui_hex": "00-21-8A",
        "organization": "Electronic Design and Manufacturing Company",
        "address_1": "31 Millrace Dr",
        "address_2": "Lynchburg  VA  24502",
        "country": "US"
    },
    "00218B": {
        "oui_hex": "00-21-8B",
        "organization": "Wescon Technology, Inc.",
        "address_1": "4655-170 Old Ironsides Drive",
        "address_2": "Santa Clara  California  95054",
        "country": "US"
    },
    "002184": {
        "oui_hex": "00-21-84",
        "organization": "POWERSOFT SRL",
        "address_1": "VIA ENRICO CONTI, 5",
        "address_2": "SCANDICCI  FI  50018",
        "country": "IT"
    },
    "002178": {
        "oui_hex": "00-21-78",
        "organization": "Matuschek Messtechnik GmbH",
        "address_1": "Werner Heisenberg Straße 14",
        "address_2": "Alsdorf  NRW  52477",
        "country": "DE"
    },
    "002173": {
        "oui_hex": "00-21-73",
        "organization": "Ion Torrent Systems, Inc.",
        "address_1": "37 Soundview Rd",
        "address_2": "Guilford  CT  06437",
        "country": "US"
    },
    "002177": {
        "oui_hex": "00-21-77",
        "organization": "W. L. Gore & Associates",
        "address_1": "402 Vieves Way",
        "address_2": "Elkton  MD  21921",
        "country": "US"
    },
    "002172": {
        "oui_hex": "00-21-72",
        "organization": "Seoultek Valley",
        "address_1": "Bang-i Dong 51-5, Songpa",
        "address_2": "Seoul    138-050",
        "country": "KR"
    },
    "002153": {
        "oui_hex": "00-21-53",
        "organization": "SeaMicro Inc.",
        "address_1": "3250 Jay Street",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00217A": {
        "oui_hex": "00-21-7A",
        "organization": "Sejin Electron, Inc.",
        "address_1": "SJ Technoville",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0021A4": {
        "oui_hex": "00-21-A4",
        "organization": "Dbii Networks",
        "address_1": "2217 Via Blanca",
        "address_2": "Oceanside  CA  92054",
        "country": "US"
    },
    "002199": {
        "oui_hex": "00-21-99",
        "organization": "Vacon Plc",
        "address_1": "P.O.Box 25",
        "address_2": "Vaasa    65380",
        "country": "FI"
    },
    "0021A0": {
        "oui_hex": "00-21-A0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002198": {
        "oui_hex": "00-21-98",
        "organization": "Thai Radio Co, LTD",
        "address_1": "Hi-Tech Industrial Estate",
        "address_2": "Ayutthaya    13160",
        "country": "TH"
    },
    "0021AE": {
        "oui_hex": "00-21-AE",
        "organization": "ALCATEL-LUCENT FRANCE - WTD",
        "address_1": "7-9, Avenue Morane Saulnier",
        "address_2": "VELIZY    78141",
        "country": "FR"
    },
    "0021AF": {
        "oui_hex": "00-21-AF",
        "organization": "Radio Frequency Systems",
        "address_1": "Kabelkamp 20",
        "address_2": "Hannover    30179",
        "country": "DE"
    },
    "002154": {
        "oui_hex": "00-21-54",
        "organization": "D-TACQ Solutions Ltd",
        "address_1": "James Watt Building",
        "address_2": "East Kilbride  Lanarkshire  G75 0QD",
        "country": "GB"
    },
    "002169": {
        "oui_hex": "00-21-69",
        "organization": "Prologix, LLC.",
        "address_1": "17217 NE 133rd Place",
        "address_2": "Redmond  Washington  98052-2153",
        "country": "US"
    },
    "00214B": {
        "oui_hex": "00-21-4B",
        "organization": "Shenzhen HAMP Science & Technology Co.,Ltd",
        "address_1": "No.302-303,3 Floor,District A,TCL Tower,Gaoxin Nan Yi Road,NanShan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "002145": {
        "oui_hex": "00-21-45",
        "organization": "Semptian Technologies Ltd.",
        "address_1": "No. 809,  Tower B, Shi Ji Ke Mao",
        "address_2": "Beijing    100190",
        "country": "CN"
    },
    "001FFE": {
        "oui_hex": "00-1F-FE",
        "organization": "HPN Supply Chain",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "001FFF": {
        "oui_hex": "00-1F-FF",
        "organization": "Respironics, Inc.",
        "address_1": "1740 Golden Mile Highway",
        "address_2": "Monroeville  PA  15146",
        "country": "US"
    },
    "001FFC": {
        "oui_hex": "00-1F-FC",
        "organization": "Riccius+Sohn GmbH",
        "address_1": "Haynauer Str. 49",
        "address_2": "Berlin    12249",
        "country": "DE"
    },
    "001FFD": {
        "oui_hex": "00-1F-FD",
        "organization": "Indigo Mobile Technologies Corp.",
        "address_1": "11F, No22, Lan407,TiDing Blvd Section2, Neihu Technology Park",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "002121": {
        "oui_hex": "00-21-21",
        "organization": "VRmagic GmbH",
        "address_1": "Augustaanlage 32",
        "address_2": "Mannheim  BW  68165",
        "country": "DE"
    },
    "002123": {
        "oui_hex": "00-21-23",
        "organization": "Aerosat Avionics",
        "address_1": "62 State Rd.",
        "address_2": "Amherst  NH  03031",
        "country": "US"
    },
    "00210A": {
        "oui_hex": "00-21-0A",
        "organization": "byd:sign Corporation",
        "address_1": "2-10-6 Tsukiji",
        "address_2": "Chuo-ku  Tokyo  104-0045",
        "country": "JP"
    },
    "002107": {
        "oui_hex": "00-21-07",
        "organization": "Seowonintech Co Ltd.",
        "address_1": "689-47 Geumjeongdong",
        "address_2": "Gunposi  Kyoungkido  436-862",
        "country": "KR"
    },
    "00213E": {
        "oui_hex": "00-21-3E",
        "organization": "TomTom",
        "address_1": "Oosterdoksstraat 114",
        "address_2": "Amsterdam  North Holland  1011 DK",
        "country": "NL"
    },
    "00213F": {
        "oui_hex": "00-21-3F",
        "organization": "A-Team Technology Ltd.",
        "address_1": "Rm. 1608, 16/F., Metropole Square,",
        "address_2": "New Territories,",
        "country": "HK"
    },
    "00211B": {
        "oui_hex": "00-21-1B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00212D": {
        "oui_hex": "00-21-2D",
        "organization": "SCIMOLEX CORPORATION",
        "address_1": "2430, Saijou, Showa-cho",
        "address_2": "Nakakoma-gun, Yamanashi    409-3866",
        "country": "JP"
    },
    "001FD5": {
        "oui_hex": "00-1F-D5",
        "organization": "MICRORISC s.r.o.",
        "address_1": "Delnicka 222",
        "address_2": "Jicin  kralovehradecky kraj  50601",
        "country": "CZ"
    },
    "001FB1": {
        "oui_hex": "00-1F-B1",
        "organization": "Cybertech Inc.",
        "address_1": "935 Horsham Rd",
        "address_2": "Horsham  PA  19044",
        "country": "US"
    },
    "001FB2": {
        "oui_hex": "00-1F-B2",
        "organization": "Sontheim Industrie Elektronik GmbH",
        "address_1": "Dieselstrasse 7",
        "address_2": "Kempten Allgaeu  Bavaria  D-87437",
        "country": "DE"
    },
    "001FEE": {
        "oui_hex": "00-1F-EE",
        "organization": "ubisys technologies GmbH",
        "address_1": "Am Wehrhahn 45",
        "address_2": "Düsseldorf  NRW  40211",
        "country": "DE"
    },
    "001FEF": {
        "oui_hex": "00-1F-EF",
        "organization": "SHINSEI INDUSTRIES CO.,LTD",
        "address_1": "4-12-15,HORIFUNE, KITA-KU,",
        "address_2": "TOKOYO    114-0004",
        "country": "JP"
    },
    "001FEC": {
        "oui_hex": "00-1F-EC",
        "organization": "Synapse Électronique",
        "address_1": "1010, 7e Avenue",
        "address_2": "Grand-Mère  Québec  G9T 2B8",
        "country": "CA"
    },
    "001FCA": {
        "oui_hex": "00-1F-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001FC3": {
        "oui_hex": "00-1F-C3",
        "organization": "SmartSynch, Inc",
        "address_1": "4400 Old Canton Rd",
        "address_2": "Jackson  MS  39211",
        "country": "US"
    },
    "001FE0": {
        "oui_hex": "00-1F-E0",
        "organization": "EdgeVelocity Corp",
        "address_1": "68 Stiles Road",
        "address_2": "Hudson  NH  03079",
        "country": "US"
    },
    "001FD8": {
        "oui_hex": "00-1F-D8",
        "organization": "A-TRUST COMPUTER CORPORATION",
        "address_1": "3F., NO.361, FUSING 1ST RD., GUEISHAN TOWNSHIP,",
        "address_2": "TAOYUAN    33375",
        "country": "TW"
    },
    "001FD7": {
        "oui_hex": "00-1F-D7",
        "organization": "TELERAD SA",
        "address_1": "2, avenue de la butte aux cailles",
        "address_2": "ANGLET    64600",
        "country": "FR"
    },
    "001FD3": {
        "oui_hex": "00-1F-D3",
        "organization": "RIVA Networks Inc.",
        "address_1": "555 Riva Ave",
        "address_2": "East Brunswick  NJ  08816",
        "country": "US"
    },
    "001FC1": {
        "oui_hex": "00-1F-C1",
        "organization": "Hanlong Technology Co.,LTD",
        "address_1": "2402 West Tower Building, Fuxin International Building,",
        "address_2": "Nanjing  Jiangsu  210002",
        "country": "CN"
    },
    "001FBB": {
        "oui_hex": "00-1F-BB",
        "organization": "Xenatech Co.,LTD",
        "address_1": " 514-2 Ya Tab-Dong Bun Dang Gu",
        "address_2": "Seong namsi  Gyong gi-do  463-839",
        "country": "KR"
    },
    "001FE8": {
        "oui_hex": "00-1F-E8",
        "organization": "KURUSUGAWA Electronics Industry Inc,.",
        "address_1": "2F, 52-5, Nogata 6chome",
        "address_2": "Nakano-Ku  TOKYO  165-0027",
        "country": "JP"
    },
    "001FAB": {
        "oui_hex": "00-1F-AB",
        "organization": "I.S HIGH TECH.INC",
        "address_1": "603-1,Sungbon-ri,Daeso-myun",
        "address_2": "Eumsung-gun  Chungcheongbuk-do  369-823",
        "country": "KR"
    },
    "001FAC": {
        "oui_hex": "00-1F-AC",
        "organization": "Goodmill Systems Ltd",
        "address_1": "Sinikalliontie 10",
        "address_2": "Espoo  Uusimaa  02630",
        "country": "FI"
    },
    "001F36": {
        "oui_hex": "00-1F-36",
        "organization": "Bellwin Information Co. Ltd.,",
        "address_1": "No.336, Beitun Rd., Beitun Dist.,",
        "address_2": "Taichung    406",
        "country": "TW"
    },
    "001F3D": {
        "oui_hex": "00-1F-3D",
        "organization": "Qbit GmbH",
        "address_1": "Stegwiesenstrasse 32",
        "address_2": "Bruchsal  Germany  76646",
        "country": "DE"
    },
    "001F38": {
        "oui_hex": "00-1F-38",
        "organization": "POSITRON",
        "address_1": "ESTRADA TELEBRAS-UNICAMP, KM0,97 - CJ.01",
        "address_2": "CAMPINAS  São Paulo  13084-971",
        "country": "BR"
    },
    "001F2D": {
        "oui_hex": "00-1F-2D",
        "organization": "Electro-Optical Imaging, Inc.",
        "address_1": "4300 Fortune Place, Suite C",
        "address_2": "West Melbourne  FL  32904",
        "country": "US"
    },
    "001F89": {
        "oui_hex": "00-1F-89",
        "organization": "Signalion GmbH",
        "address_1": "Sudhausweg 5",
        "address_2": "Dresden  Saxony  01099",
        "country": "DE"
    },
    "001F8A": {
        "oui_hex": "00-1F-8A",
        "organization": "Ellion Digital Inc.",
        "address_1": "Suite 809, Sicox Tower, 513-14, Sangdaewon-dong, Jungwon-gu",
        "address_2": "Sungnam-city  Kyonggi-do  426-726",
        "country": "KR"
    },
    "001F7F": {
        "oui_hex": "00-1F-7F",
        "organization": "Phabrix Limited",
        "address_1": "Blindmans Gate Cottage",
        "address_2": "Newbury  Hampshire  RG20 9XB",
        "country": "GB"
    },
    "001F76": {
        "oui_hex": "00-1F-76",
        "organization": "AirLogic Systems Inc.",
        "address_1": "3022 Peleke St.Suite 1",
        "address_2": "Lihu'e  HI  96766",
        "country": "US"
    },
    "001F73": {
        "oui_hex": "00-1F-73",
        "organization": "Teraview Technology Co., Ltd.",
        "address_1": "23F, No. 29-5, Sec. 2, Jhongjheng E. Road,",
        "address_2": "Taipei County    251",
        "country": "TW"
    },
    "001F62": {
        "oui_hex": "00-1F-62",
        "organization": "JSC Stilsoft",
        "address_1": "Mayakovskogo 15",
        "address_2": "Stavropol    355000",
        "country": "RU"
    },
    "001F67": {
        "oui_hex": "00-1F-67",
        "organization": "Hitachi,Ltd.",
        "address_1": "Minamioi 6-27-18, Shinagawa-ku",
        "address_2": "Tokyo  Tokyo  140-8572",
        "country": "JP"
    },
    "001F56": {
        "oui_hex": "00-1F-56",
        "organization": "DIGITAL FORECAST",
        "address_1": "5th Fl., 507, E&C Venture Dream Tower III, 197-33",
        "address_2": "Seoul  Gyunggi-do  152-719",
        "country": "KR"
    },
    "001F52": {
        "oui_hex": "00-1F-52",
        "organization": "UVT Unternehmensberatung fur Verkehr und Technik GmbH",
        "address_1": "Josefsstraße 54-56",
        "address_2": "Mainz  RLP  55118",
        "country": "DE"
    },
    "001F4F": {
        "oui_hex": "00-1F-4F",
        "organization": "Thinkware Co. Ltd.",
        "address_1": "15FL, Hanmi Tower, 45,",
        "address_2": "Seoul    138-724",
        "country": "KR"
    },
    "001F2F": {
        "oui_hex": "00-1F-2F",
        "organization": "Berker GmbH & Co. KG",
        "address_1": "Klagebach 38",
        "address_2": "Schalksmuehle  NRW  58579",
        "country": "DE"
    },
    "001F32": {
        "oui_hex": "00-1F-32",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001F44": {
        "oui_hex": "00-1F-44",
        "organization": "GE Transportation Systems",
        "address_1": "2901 East Lake Road",
        "address_2": "Erie  PA  16501",
        "country": "US"
    },
    "001F39": {
        "oui_hex": "00-1F-39",
        "organization": "Construcciones y Auxiliar de Ferrocarriles, S.A.",
        "address_1": "C/ J.M. Iturrioz, 26",
        "address_2": "Beasain  Guipúzcoa  E-20200",
        "country": "ES"
    },
    "001F7C": {
        "oui_hex": "00-1F-7C",
        "organization": "Witelcom AS",
        "address_1": "Verftsgt 10",
        "address_2": "Moss  Ostfold  1511",
        "country": "NO"
    },
    "001F7A": {
        "oui_hex": "00-1F-7A",
        "organization": "WiWide Inc.",
        "address_1": "10B10, Hua Jie Plaza",
        "address_2": "Beijing    100089",
        "country": "CN"
    },
    "001F77": {
        "oui_hex": "00-1F-77",
        "organization": "HEOL DESIGN",
        "address_1": "1 bd d'armor",
        "address_2": "LANNION  BRETAGNE  22300",
        "country": "FR"
    },
    "001F94": {
        "oui_hex": "00-1F-94",
        "organization": "Lascar Electronics Ltd",
        "address_1": "Module House",
        "address_2": "Nr Salisbury  Wiltshire  SP5 2SJ",
        "country": "GB"
    },
    "001F8E": {
        "oui_hex": "00-1F-8E",
        "organization": "Metris USA Inc.",
        "address_1": "44880 Falcon Place ste 100",
        "address_2": "Sterling  VA  20166",
        "country": "US"
    },
    "001F61": {
        "oui_hex": "00-1F-61",
        "organization": "Talent Communication Networks Inc.",
        "address_1": "Rm. 910 R&F Plaza, #76, Huangpu Ave. West,",
        "address_2": "Guangzhou (Canton)  Guangdong Province  510360",
        "country": "CN"
    },
    "001ECE": {
        "oui_hex": "00-1E-CE",
        "organization": "BISA Technologies (Hong Kong) Limited",
        "address_1": "1102, Trans Asia Centre,",
        "address_2": " Kwai Chung,",
        "country": "HK"
    },
    "001EC8": {
        "oui_hex": "00-1E-C8",
        "organization": "Rapid Mobile (Pty) Ltd",
        "address_1": "Building C,D,E Apex Corporate Park",
        "address_2": "Pretoria  Gauteng  0020",
        "country": "ZA"
    },
    "001ECC": {
        "oui_hex": "00-1E-CC",
        "organization": "CDVI",
        "address_1": "31 Avenue du Général Leclerc",
        "address_2": "PANTIN  Ile de France  93500",
        "country": "FR"
    },
    "001EC5": {
        "oui_hex": "00-1E-C5",
        "organization": "Middle Atlantic Products Inc",
        "address_1": "300 Fairfield Road",
        "address_2": "Fairfield  NJ  07004",
        "country": "US"
    },
    "001F03": {
        "oui_hex": "00-1F-03",
        "organization": "NUM AG",
        "address_1": "Battenhusstrasse 16",
        "address_2": "Teufen  AR  9053",
        "country": "CH"
    },
    "001EFF": {
        "oui_hex": "00-1E-FF",
        "organization": "Mueller-Elektronik GmbH & Co. KG",
        "address_1": "Franz-Kleine-Str. 18",
        "address_2": "Salzkotten  NRW  33154",
        "country": "DE"
    },
    "001F05": {
        "oui_hex": "00-1F-05",
        "organization": "iTAS Technology Corp.",
        "address_1": "No. 75, Shuiyuan St.",
        "address_2": "Hsinchu City    30069",
        "country": "TW"
    },
    "001F07": {
        "oui_hex": "00-1F-07",
        "organization": "AZTEQ Mobile",
        "address_1": "Suite 210, 525 University Ave",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "001EF6": {
        "oui_hex": "00-1E-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001EF9": {
        "oui_hex": "00-1E-F9",
        "organization": "Pascom Kommunikations systeme GmbH.",
        "address_1": "Technologiestr. 4",
        "address_2": "Arbing  Upper Austria  4332",
        "country": "AT"
    },
    "001EF3": {
        "oui_hex": "00-1E-F3",
        "organization": "From2",
        "address_1": "2F, Mester inc",
        "address_2": "Daejeon    306-230",
        "country": "KR"
    },
    "001F19": {
        "oui_hex": "00-1F-19",
        "organization": "BEN-RI ELECTRONICA S.A.",
        "address_1": "POL. IND. VENTORRO DEL CANO",
        "address_2": "ALCORCON  MADRID  28925",
        "country": "ES"
    },
    "001F11": {
        "oui_hex": "00-1F-11",
        "organization": "OPENMOKO, INC.",
        "address_1": "7F, No 300, Yang Guang Street",
        "address_2": "Taipei    11491",
        "country": "TW"
    },
    "001EE4": {
        "oui_hex": "00-1E-E4",
        "organization": "ACS Solutions France",
        "address_1": "Rue Claude Chappe",
        "address_2": "Guilherand Granges  Ardeche  07503",
        "country": "FR"
    },
    "001EED": {
        "oui_hex": "00-1E-ED",
        "organization": "Adventiq Ltd.",
        "address_1": "Technology House",
        "address_2": "Bar Hill  Cambs.  CB3 8SQ",
        "country": "GB"
    },
    "001ED2": {
        "oui_hex": "00-1E-D2",
        "organization": "Ray Shine Video Technology Inc",
        "address_1": "6F,No.98,Sec.1,Xintai 5th Rd.",
        "address_2": "Xizhi City  Taipei County  221",
        "country": "TW"
    },
    "001ED4": {
        "oui_hex": "00-1E-D4",
        "organization": "Doble Engineering",
        "address_1": "85 Walnut St",
        "address_2": "Watertown  MA  02472",
        "country": "US"
    },
    "001EFD": {
        "oui_hex": "00-1E-FD",
        "organization": "Microbit 2.0 AB",
        "address_1": "Nystaden 1",
        "address_2": "KALIX    95261",
        "country": "SE"
    },
    "001EE7": {
        "oui_hex": "00-1E-E7",
        "organization": "Epic Systems Inc",
        "address_1": "390 S. Abbott Ave",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001EE9": {
        "oui_hex": "00-1E-E9",
        "organization": "Stoneridge Electronics AB",
        "address_1": "Gårdsfogdevägen 18A",
        "address_2": "Bromma  Stockholm  168 66",
        "country": "SE"
    },
    "001F1C": {
        "oui_hex": "00-1F-1C",
        "organization": "KOBISHI ELECTRIC Co.,Ltd.",
        "address_1": "1805-1",
        "address_2": "Kounosu-shi  Saitama-ken  365-0027",
        "country": "JP"
    },
    "001E79": {
        "oui_hex": "00-1E-79",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E76": {
        "oui_hex": "00-1E-76",
        "organization": "Thermo Fisher Scientific",
        "address_1": "2215 Grand Avenue Parkway",
        "address_2": "Austin  Texas  78728",
        "country": "US"
    },
    "001E72": {
        "oui_hex": "00-1E-72",
        "organization": "PCS",
        "address_1": "2 HENRI FARMAN",
        "address_2": "LESCAR  PYRENEES ATLANTIQUES  64230",
        "country": "FR"
    },
    "001E5F": {
        "oui_hex": "00-1E-5F",
        "organization": "KwikByte, LLC",
        "address_1": "2430 W. 12th Street",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "001E5B": {
        "oui_hex": "00-1E-5B",
        "organization": "Unitron Company, Inc.",
        "address_1": "10925 Miller Road",
        "address_2": "Dallas  TX  75238",
        "country": "US"
    },
    "001E5E": {
        "oui_hex": "00-1E-5E",
        "organization": "COmputime Ltd.",
        "address_1": "17/F Great Eagle Centre",
        "address_2": "Wanchai",
        "country": "HK"
    },
    "001E9D": {
        "oui_hex": "00-1E-9D",
        "organization": "Recall Technologies, Inc.",
        "address_1": "130 Enterprise Ave.",
        "address_2": "Palm Bay  FL  32909",
        "country": "US"
    },
    "001E95": {
        "oui_hex": "00-1E-95",
        "organization": "SIGMALINK",
        "address_1": "DooSan VentureDigm 1028,",
        "address_2": "Anyang-City  Kyunggi-do  431-070",
        "country": "KR"
    },
    "001E93": {
        "oui_hex": "00-1E-93",
        "organization": "CiriTech Systems Inc",
        "address_1": "920 Hillview Ct",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001EA2": {
        "oui_hex": "00-1E-A2",
        "organization": "Symx Systems, Inc.",
        "address_1": "6320 NW 84th Avenue",
        "address_2": "Miami  Florida  33166",
        "country": "US"
    },
    "001EA9": {
        "oui_hex": "00-1E-A9",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001E9E": {
        "oui_hex": "00-1E-9E",
        "organization": "ddm hopt + schuler Gmbh + Co. KG",
        "address_1": "Koenigsberger Strasse 12",
        "address_2": "Rottweil  Baden-Württemberg  78626",
        "country": "DE"
    },
    "001EBE": {
        "oui_hex": "00-1E-BE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001EC3": {
        "oui_hex": "00-1E-C3",
        "organization": "Kozio, Inc.",
        "address_1": "2015 Ionosphere Street",
        "address_2": "Longmont  CO  80504",
        "country": "US"
    },
    "001EBD": {
        "oui_hex": "00-1E-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001EB9": {
        "oui_hex": "00-1E-B9",
        "organization": "Sing Fai Technology Limited",
        "address_1": "No.700, Kaohsiung University Rd., Nan-Tzu Dist.",
        "address_2": "Kaohsiung    811",
        "country": "TW"
    },
    "001EB7": {
        "oui_hex": "00-1E-B7",
        "organization": "TBTech, Co., Ltd.",
        "address_1": "1109, Hyundai Krim, 1330-18, Seocho-dong,",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "001E69": {
        "oui_hex": "00-1E-69",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290-1102",
        "country": "US"
    },
    "001E92": {
        "oui_hex": "00-1E-92",
        "organization": "JEULIN S.A.",
        "address_1": "ZI N°1",
        "address_2": "Evreux    F27019",
        "country": "FR"
    },
    "001E91": {
        "oui_hex": "00-1E-91",
        "organization": "KIMIN Electronic Co., Ltd.",
        "address_1": "293-4, Dongdan-Dong",
        "address_2": "Gumi-city  GyeongBuk  730-906",
        "country": "KR"
    },
    "001E89": {
        "oui_hex": "00-1E-89",
        "organization": "CRFS Limited",
        "address_1": "Building 7200",
        "address_2": "Waterbeach  Cambridgeshire  CB25 9TL",
        "country": "GB"
    },
    "001E86": {
        "oui_hex": "00-1E-86",
        "organization": "MEL Co.,Ltd.",
        "address_1": "Tsukagoshi 5-5-1,Warabi-shi,Saitama,Japna",
        "address_2": "Warabi  Saitama  335-0002",
        "country": "JP"
    },
    "001E88": {
        "oui_hex": "00-1E-88",
        "organization": "ANDOR SYSTEM SUPPORT CO., LTD.",
        "address_1": "Minami-Shinagawa 2-15-8",
        "address_2": "Sinagawa  Tokyo  140-0004",
        "country": "JP"
    },
    "001E0C": {
        "oui_hex": "00-1E-0C",
        "organization": "Sherwood Information Partners, Inc.",
        "address_1": "1120 W, 122nd Ave, Ste 300",
        "address_2": "Westminster  CO  80234",
        "country": "US"
    },
    "001E02": {
        "oui_hex": "00-1E-02",
        "organization": "Sougou Keikaku Kougyou Co.,Ltd.",
        "address_1": "HK2 bld. 2-21-10",
        "address_2": "Suginamiku  Tokyo  167-0053",
        "country": "JP"
    },
    "001E01": {
        "oui_hex": "00-1E-01",
        "organization": "Renesas Technology Sales Co., Ltd.",
        "address_1": "2-6-2",
        "address_2": "Chiyoda-ku  Tokyo  100-0004",
        "country": "JP"
    },
    "001DFF": {
        "oui_hex": "00-1D-FF",
        "organization": "Network Critical Solutions Ltd",
        "address_1": "12B Southview Park",
        "address_2": "Reading  Berkshire  RG45AF",
        "country": "GB"
    },
    "001E00": {
        "oui_hex": "00-1E-00",
        "organization": "Shantou Institute of Ultrasonic Instruments",
        "address_1": "No.77, Jinsha Road,",
        "address_2": "Shantou  Guangdong  515041",
        "country": "CN"
    },
    "001E54": {
        "oui_hex": "00-1E-54",
        "organization": "TOYO ELECTRIC Corporation",
        "address_1": "1-39 HIKISAWA",
        "address_2": "KASUGAI  AICHI  480-0393",
        "country": "JP"
    },
    "001E3C": {
        "oui_hex": "00-1E-3C",
        "organization": "Lyngbox Media AB",
        "address_1": "Diskettgatan 11B",
        "address_2": "Linkoping    SE-58335",
        "country": "SE"
    },
    "001E4D": {
        "oui_hex": "00-1E-4D",
        "organization": "Welkin Sciences, LLC",
        "address_1": "102 S. Tejon St, Suite 200",
        "address_2": "Colorado Springs  CO  80903",
        "country": "US"
    },
    "001E4B": {
        "oui_hex": "00-1E-4B",
        "organization": "City Theatrical",
        "address_1": "475 Barell Ave",
        "address_2": "Carlstadt  New Jersey  07072",
        "country": "US"
    },
    "001E4A": {
        "oui_hex": "00-1E-4A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E13": {
        "oui_hex": "00-1E-13",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001E0D": {
        "oui_hex": "00-1E-0D",
        "organization": "Micran Ltd.",
        "address_1": "Vershinina st. 47",
        "address_2": "Tomsk  Tomsk Region  634034",
        "country": "RU"
    },
    "001E09": {
        "oui_hex": "00-1E-09",
        "organization": "ZEFATEK Co.,LTD",
        "address_1": "326-4 Gasandong, Geumcheongu",
        "address_2": "Seoul    153-802",
        "country": "KR"
    },
    "001E06": {
        "oui_hex": "00-1E-06",
        "organization": "WIBRAIN",
        "address_1": "306 JEI Plats B/D 459-11 Gasan-dong, Geumcheon-gu",
        "address_2": "SEOUL    153-803",
        "country": "KR"
    },
    "001E2C": {
        "oui_hex": "00-1E-2C",
        "organization": "CyVerse Corporation",
        "address_1": "Shoutou Roukubankan Bldg. 4F",
        "address_2": "Shibuya-ku  Tokyo  150-0046",
        "country": "JP"
    },
    "001E26": {
        "oui_hex": "00-1E-26",
        "organization": "Digifriends Co. Ltd",
        "address_1": "Joyang B/D 6th Floor",
        "address_2": "Seoul    135-090",
        "country": "KR"
    },
    "001E23": {
        "oui_hex": "00-1E-23",
        "organization": "Electronic Educational Devices, Inc",
        "address_1": "1903 S Grant St",
        "address_2": "Denver  CO  80210",
        "country": "US"
    },
    "001DF3": {
        "oui_hex": "00-1D-F3",
        "organization": "SBS Science & Technology Co., Ltd",
        "address_1": "W2-B5/6 High-tech industrial park",
        "address_2": "ShenZhen  GuangDong  518057",
        "country": "CN"
    },
    "001DEE": {
        "oui_hex": "00-1D-EE",
        "organization": "NEXTVISION SISTEMAS DIGITAIS DE TELEVISÃO LTDA.",
        "address_1": "Alameda Rio Negro, 1030 - 19o. andar conj. 1904",
        "address_2": "Barueri  São Paulo  06454-000",
        "country": "BR"
    },
    "001DEA": {
        "oui_hex": "00-1D-EA",
        "organization": "Commtest Instruments Ltd",
        "address_1": "Level 2, 22 Moorhouse Ave",
        "address_2": "Christchurch  Canterbury  8243",
        "country": "NZ"
    },
    "001DDD": {
        "oui_hex": "00-1D-DD",
        "organization": "DAT H.K. LIMITED",
        "address_1": "Suite 1405 14/F., City Plaza 4, Tai Koo Wan Rd,",
        "address_2": "Tai Koo Shing  Hong Kong Island  064828",
        "country": "HK"
    },
    "001DE4": {
        "oui_hex": "00-1D-E4",
        "organization": "Visioneered Image Systems",
        "address_1": "10561 Garden Grove Blvd",
        "address_2": "Garden Grove  California  92843",
        "country": "US"
    },
    "001DE2": {
        "oui_hex": "00-1D-E2",
        "organization": "Radionor Communications",
        "address_1": "Ingvald Ystgaards veg 23",
        "address_2": "Trondheim  TRD  7046",
        "country": "NO"
    },
    "001DD7": {
        "oui_hex": "00-1D-D7",
        "organization": "Algolith",
        "address_1": "400 Isabey",
        "address_2": "Saint-Laurent  Qc  H4T 1V3",
        "country": "CA"
    },
    "001DC9": {
        "oui_hex": "00-1D-C9",
        "organization": "GainSpan Corp.",
        "address_1": "P.O. Box 223580",
        "address_2": "Carmel  CA  93922",
        "country": "US"
    },
    "001D86": {
        "oui_hex": "00-1D-86",
        "organization": "Shinwa Industries(China) Ltd.",
        "address_1": "8 Pingnanzhong Road, Pingnan Industrial Park, Zhongkai No.4 Road,",
        "address_2": "Huizhou City  Guangdong Province  516006",
        "country": "CN"
    },
    "001D88": {
        "oui_hex": "00-1D-88",
        "organization": "Clearwire",
        "address_1": "1475 120th Ave NE",
        "address_2": "Bellevue  Washington  98005",
        "country": "US"
    },
    "001D81": {
        "oui_hex": "00-1D-81",
        "organization": "GUANGZHOU GATEWAY ELECTRONICS CO., LTD",
        "address_1": "B20#,4F,No.9 Jiangong Road,Tianhe Software Park,Tianhe District,",
        "address_2": "GUANGZHOU  Guangdong  510665",
        "country": "CN"
    },
    "001D7D": {
        "oui_hex": "00-1D-7D",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "001DC7": {
        "oui_hex": "00-1D-C7",
        "organization": "L-3 Communications Geneva Aerospace",
        "address_1": "4240 International Parkway",
        "address_2": "Carrollton  Texas  75007",
        "country": "US"
    },
    "001D89": {
        "oui_hex": "00-1D-89",
        "organization": "VaultStor Corporation",
        "address_1": "1010 Brioso Drive",
        "address_2": "Costa Mesa  CA  92627",
        "country": "US"
    },
    "001D66": {
        "oui_hex": "00-1D-66",
        "organization": "Hyundai Telecom",
        "address_1": "Hyundai Telecom Bldg., 4273-12, Shingil-Dong, Youngdungpo-Gu,",
        "address_2": "Seoul    150-859",
        "country": "KR"
    },
    "001D77": {
        "oui_hex": "00-1D-77",
        "organization": "NSGate",
        "address_1": "Rm 1304, 39 Kirpichnaya Street",
        "address_2": "Moscow    105187",
        "country": "RU"
    },
    "001DA2": {
        "oui_hex": "00-1D-A2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D99": {
        "oui_hex": "00-1D-99",
        "organization": "Cyan Optic, Inc.",
        "address_1": "1390 N. McDowell Blvd",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "001D9B": {
        "oui_hex": "00-1D-9B",
        "organization": "Hokuyo Automatic Co., Ltd.",
        "address_1": "Niitaka 1-10-9",
        "address_2": "Osaka    532-0033",
        "country": "JP"
    },
    "001DBC": {
        "oui_hex": "00-1D-BC",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001DB6": {
        "oui_hex": "00-1D-B6",
        "organization": "BestComm Networks, Inc.",
        "address_1": "4400 E. Broadway Blvd.",
        "address_2": "Tucson  AZ  85711",
        "country": "US"
    },
    "001DAC": {
        "oui_hex": "00-1D-AC",
        "organization": "Gigamon Systems LLC",
        "address_1": "598 Gibraltar Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001D15": {
        "oui_hex": "00-1D-15",
        "organization": "Shenzhen Dolphin Electronic Co., Ltd",
        "address_1": "Building21,Baoyuan, No.1 Industrial Zone,",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "001D16": {
        "oui_hex": "00-1D-16",
        "organization": "SFR",
        "address_1": "40/42 Quai du point du jour",
        "address_2": "Boulongne Billancourt Hauts de Seine     92659",
        "country": "FR"
    },
    "001D11": {
        "oui_hex": "00-1D-11",
        "organization": "Analogue & Micro Ltd",
        "address_1": "Lakeside House",
        "address_2": "Llantarnam Industrial Park  Cwmbran  NP44 3XS",
        "country": "GB"
    },
    "001D12": {
        "oui_hex": "00-1D-12",
        "organization": "ROHM CO., LTD.",
        "address_1": "21 Saiin-Mizosaki-cho,",
        "address_2": "Kyoto-shi  KYOTO  615-8585",
        "country": "JP"
    },
    "001D47": {
        "oui_hex": "00-1D-47",
        "organization": "Covote GmbH & Co KG",
        "address_1": "Ritterhufen 30",
        "address_2": "Berlin    14165",
        "country": "DE"
    },
    "001D41": {
        "oui_hex": "00-1D-41",
        "organization": "Hardy Instruments",
        "address_1": "3860 Calle Fortunada",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "001D3D": {
        "oui_hex": "00-1D-3D",
        "organization": "Avidyne Corporation",
        "address_1": "202 West Dr",
        "address_2": "Melbourne  FL  32904",
        "country": "US"
    },
    "001D3C": {
        "oui_hex": "00-1D-3C",
        "organization": "Muscle Corporation",
        "address_1": "2-5-35, Kikawa-higashi",
        "address_2": "Osaka    532-0012",
        "country": "JP"
    },
    "001D3A": {
        "oui_hex": "00-1D-3A",
        "organization": "mh acoustics LLC",
        "address_1": "25A Summit Ave",
        "address_2": "Summit  NJ  07901",
        "country": "US"
    },
    "001D49": {
        "oui_hex": "00-1D-49",
        "organization": "Innovation Wireless Inc.",
        "address_1": "4F-1, NO.81, SHUEILI RD.",
        "address_2": "HSINCHU    30059",
        "country": "TW"
    },
    "001D46": {
        "oui_hex": "00-1D-46",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001D48": {
        "oui_hex": "00-1D-48",
        "organization": "Sensor-Technik Wiedemann GmbH",
        "address_1": "Am Bärenwald 6",
        "address_2": "Kaufbeuren  Bayern  87600",
        "country": "DE"
    },
    "001D76": {
        "oui_hex": "00-1D-76",
        "organization": "Eyeheight Ltd.",
        "address_1": "Unit 34, Park House",
        "address_2": "Watford  Herts  WD18 8PH",
        "country": "GB"
    },
    "001D7A": {
        "oui_hex": "00-1D-7A",
        "organization": "Wideband Semiconductor, Inc.",
        "address_1": "1350 Pear Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001D68": {
        "oui_hex": "00-1D-68",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "001D26": {
        "oui_hex": "00-1D-26",
        "organization": "Rockridgesound Technology Co.",
        "address_1": "Fumin Industrial Park, Houjie Town",
        "address_2": "Dong Guan  Guang Dong  523956",
        "country": "CN"
    },
    "001D35": {
        "oui_hex": "00-1D-35",
        "organization": "Viconics Electronics Inc.",
        "address_1": "9245 Langelier",
        "address_2": "Saint Leonard  Quebec  H1P3K9",
        "country": "CA"
    },
    "001D31": {
        "oui_hex": "00-1D-31",
        "organization": "HIGHPRO INTERNATIONAL R&D CO,.LTD.",
        "address_1": "3F,No.295,RuiGuang Rd,Nei Hu,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001D61": {
        "oui_hex": "00-1D-61",
        "organization": "BIJ Corporation",
        "address_1": "7F Takamizawa Building,2-7-10,",
        "address_2": "Yokohama  Kanagawa  220-0004",
        "country": "JP"
    },
    "001D5C": {
        "oui_hex": "00-1D-5C",
        "organization": "Tom Communication Industrial Co.,Ltd.",
        "address_1": "1173 Nippa-choh Kohoku-ku",
        "address_2": "Yokohama  Kanagawa  223-0057",
        "country": "JP"
    },
    "001D56": {
        "oui_hex": "00-1D-56",
        "organization": "Kramer Electronics Ltd.",
        "address_1": "3 Am VeOlamo Street",
        "address_2": "Jerusalem    95463",
        "country": "IL"
    },
    "001D4E": {
        "oui_hex": "00-1D-4E",
        "organization": "TCM Mobile LLC",
        "address_1": "9218 Metcalf,",
        "address_2": "Overland Park  Kansas  66212",
        "country": "US"
    },
    "001D21": {
        "oui_hex": "00-1D-21",
        "organization": "Alcad SL",
        "address_1": "Pol. Ind. Arreche-Ugalde, 1",
        "address_2": "Irún  Guipúzcoa  E-20305",
        "country": "ES"
    },
    "001D1C": {
        "oui_hex": "00-1D-1C",
        "organization": "Gennet s.a.",
        "address_1": "2 Mesogeion ave.",
        "address_2": "Athens  Attiki  11527",
        "country": "GR"
    },
    "001CE1": {
        "oui_hex": "00-1C-E1",
        "organization": "INDRA SISTEMAS, S.A.",
        "address_1": "Ctra. de Loeches, n.º 9",
        "address_2": "Torrejón de Ardoz  MADRID  28850",
        "country": "ES"
    },
    "001CE0": {
        "oui_hex": "00-1C-E0",
        "organization": "DASAN TPS",
        "address_1": "HUMAX Village 6F, 11-4 Sunae-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-825",
        "country": "KR"
    },
    "001CD9": {
        "oui_hex": "00-1C-D9",
        "organization": "GlobalTop Technology Inc.",
        "address_1": "16 Nan-ke 9th Rd. Science-base Industrial Park,",
        "address_2": "ShanHua  Tainan county  741",
        "country": "TW"
    },
    "001CDA": {
        "oui_hex": "00-1C-DA",
        "organization": "Exegin Technologies Limited",
        "address_1": "401 - 2071 Kingsway Avenue",
        "address_2": "Port Coquitlam  BC  V3C 6N2",
        "country": "CA"
    },
    "001CD2": {
        "oui_hex": "00-1C-D2",
        "organization": "King Champion (Hong Kong) Limited",
        "address_1": "Unit 1520, 15/F, Phase 1, Metro Centre,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "001CA6": {
        "oui_hex": "00-1C-A6",
        "organization": "Win4NET",
        "address_1": "1301 KOLON Digital Tower,",
        "address_2": "Kuro-gu  Seoul  152-848",
        "country": "KR"
    },
    "001CA9": {
        "oui_hex": "00-1C-A9",
        "organization": "Audiomatica Srl",
        "address_1": "Via Manfredi 12",
        "address_2": "Florence  Italy  50136",
        "country": "IT"
    },
    "001CA1": {
        "oui_hex": "00-1C-A1",
        "organization": "AKAMAI TECHNOLOGIES, INC.",
        "address_1": "8 CAMBRIDGE CENTER",
        "address_2": "CAMBRIDGE  MA  02142",
        "country": "US"
    },
    "001C99": {
        "oui_hex": "00-1C-99",
        "organization": "Shunra Software Ltd.",
        "address_1": "20 Hata'as St.",
        "address_2": "Kefar-Saba    44425",
        "country": "IL"
    },
    "001CF9": {
        "oui_hex": "00-1C-F9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001CF1": {
        "oui_hex": "00-1C-F1",
        "organization": "SUPoX Technology Co. , LTD.",
        "address_1": "7F, 419 , Chung San Rd. , Sec 2",
        "address_2": "Chung Ho  Taipei Hsien  235",
        "country": "TW"
    },
    "001CCE": {
        "oui_hex": "00-1C-CE",
        "organization": "By Techdesign",
        "address_1": "C/ Tomas Edison 5",
        "address_2": "Arganda del Rey  Madrid  28500",
        "country": "ES"
    },
    "001CF3": {
        "oui_hex": "00-1C-F3",
        "organization": "EVS BROADCAST EQUIPMENT",
        "address_1": "Liege Science Park",
        "address_2": "Ougree  Liege  4102",
        "country": "BE"
    },
    "001CF4": {
        "oui_hex": "00-1C-F4",
        "organization": "Media Technology Systems Inc",
        "address_1": "766 Lakefield Road",
        "address_2": "Westlake Village  CA  91377",
        "country": "US"
    },
    "001CE6": {
        "oui_hex": "00-1C-E6",
        "organization": "INNES",
        "address_1": "80 avenue des Buttes de Coësmes",
        "address_2": "RENNES    35700",
        "country": "FR"
    },
    "001CB9": {
        "oui_hex": "00-1C-B9",
        "organization": "KWANG SUNG ELECTRONICS CO., LTD.",
        "address_1": "201, WORLD VENTURE TOWN 60-24, GASAN-DONG GEUMCHUN-GU,",
        "address_2": "SEOUL    153-801",
        "country": "KR"
    },
    "001D03": {
        "oui_hex": "00-1D-03",
        "organization": "Design Solutions Inc.",
        "address_1": "81 David Love Place",
        "address_2": "Goleta  Ca  93117",
        "country": "US"
    },
    "001CA3": {
        "oui_hex": "00-1C-A3",
        "organization": "Terra",
        "address_1": "Draugystes str. 22",
        "address_2": "Kaunas    LT-51256",
        "country": "LT"
    },
    "001C90": {
        "oui_hex": "00-1C-90",
        "organization": "Empacket Corporation",
        "address_1": "2-6-3 Nishi-Gotanda",
        "address_2": "Shinagawa  Tokyo  141-0031",
        "country": "JP"
    },
    "001C8E": {
        "oui_hex": "00-1C-8E",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "701 E. Middlefield Rd.",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001C8F": {
        "oui_hex": "00-1C-8F",
        "organization": "Advanced Electronic Design, Inc.",
        "address_1": "344 John L Dietsch Blvd., Unit #2",
        "address_2": "North Attleboro  MA  02763",
        "country": "US"
    },
    "001C88": {
        "oui_hex": "00-1C-88",
        "organization": "TRANSYSTEM INC.",
        "address_1": "No. 1-2, Li-Hsin Rd 1, Science-Based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001C86": {
        "oui_hex": "00-1C-86",
        "organization": "Cranite Systems, Inc.",
        "address_1": "121 Albright Way",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "001C4F": {
        "oui_hex": "00-1C-4F",
        "organization": "MACAB AB",
        "address_1": "Vannhögsgatan 7",
        "address_2": "Trelleborg    23166",
        "country": "SE"
    },
    "001C4E": {
        "oui_hex": "00-1C-4E",
        "organization": "TASA International Limited",
        "address_1": "5FÃ‚Â£Ã‚Â¬Building2Ã‚Â£Ã‚Â¬No.1295 ,Xin Jinqiao Road,",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "001C4B": {
        "oui_hex": "00-1C-4B",
        "organization": "Gener8, Inc.",
        "address_1": "897 Independence Ave",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001C9B": {
        "oui_hex": "00-1C-9B",
        "organization": "FEIG ELECTRONIC GmbH",
        "address_1": "Lange Straße 4",
        "address_2": "Weilburg  Hessen  35781",
        "country": "DE"
    },
    "001C95": {
        "oui_hex": "00-1C-95",
        "organization": "Opticomm Corporation",
        "address_1": "6827 Nancy Ridge Dr",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001C97": {
        "oui_hex": "00-1C-97",
        "organization": "Enzytek Technology Inc.,",
        "address_1": "7F, No.35, Hsueh Fu Rd.,",
        "address_2": "Hsinchu    300,",
        "country": "TW"
    },
    "001C70": {
        "oui_hex": "00-1C-70",
        "organization": "NOVACOMM LTDA",
        "address_1": "RUA BEIJUI, 70",
        "address_2": "São Paulo    04689-000",
        "country": "BR"
    },
    "001C6E": {
        "oui_hex": "00-1C-6E",
        "organization": "Newbury Networks, Inc.",
        "address_1": "419 Boylston Street",
        "address_2": "Boston  MA  02116",
        "country": "US"
    },
    "001C6B": {
        "oui_hex": "00-1C-6B",
        "organization": "COVAX  Co. Ltd",
        "address_1": "3-27-22 kitahanada-cho kitaku",
        "address_2": "sakai-shi  oosaka  591-8002",
        "country": "JP"
    },
    "001C69": {
        "oui_hex": "00-1C-69",
        "organization": "Packet Vision Ltd",
        "address_1": "SC House",
        "address_2": "Maidenhead  Berks  SL6 4UB",
        "country": "GB"
    },
    "001C3D": {
        "oui_hex": "00-1C-3D",
        "organization": "WaveStorm",
        "address_1": "Rue d'Oradour-sur-Glâne",
        "address_2": "Paris  ÃƒÅ½le-de-France  75015",
        "country": "FR"
    },
    "001C7F": {
        "oui_hex": "00-1C-7F",
        "organization": "Check Point Software Technologies",
        "address_1": "3A Jabotinsky St.",
        "address_2": "Ramat Gan    52520",
        "country": "IL"
    },
    "001C78": {
        "oui_hex": "00-1C-78",
        "organization": "WYPLAY SAS",
        "address_1": "200 avenue de Provence",
        "address_2": "ALLAUCH  BdR  13190",
        "country": "FR"
    },
    "001C58": {
        "oui_hex": "00-1C-58",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C5A": {
        "oui_hex": "00-1C-5A",
        "organization": "Advanced Relay Corporation",
        "address_1": "1896 Columbia St",
        "address_2": "Eugene  OR  97403",
        "country": "US"
    },
    "001C65": {
        "oui_hex": "00-1C-65",
        "organization": "JoeScan, Inc.",
        "address_1": "4510 NE 68th Dr, Ste. 124",
        "address_2": "Vancouver  WA  98661",
        "country": "US"
    },
    "001C5F": {
        "oui_hex": "00-1C-5F",
        "organization": "Winland Electronics, Inc.",
        "address_1": "1950 Excel Drive",
        "address_2": "Mankato  MN  56001",
        "country": "US"
    },
    "001C40": {
        "oui_hex": "00-1C-40",
        "organization": "VDG-Security bv",
        "address_1": "Radonstraat 10-14",
        "address_2": "Zoetermeer  ZH  2718 TA",
        "country": "NL"
    },
    "001C3A": {
        "oui_hex": "00-1C-3A",
        "organization": "Element Labs, Inc.",
        "address_1": "3350 Scott Boulevard",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001C18": {
        "oui_hex": "00-1C-18",
        "organization": "Sicert S.r.L.",
        "address_1": "Via Bernardino Alimena, 128",
        "address_2": "Rome    00173",
        "country": "IT"
    },
    "001C1A": {
        "oui_hex": "00-1C-1A",
        "organization": "Thomas Instrumentation, Inc",
        "address_1": "133 Landing Rd",
        "address_2": "Cape May Court House  NJ  08210",
        "country": "US"
    },
    "001C0E": {
        "oui_hex": "00-1C-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C13": {
        "oui_hex": "00-1C-13",
        "organization": "OPTSYS TECHNOLOGY CO., LTD.",
        "address_1": "SUITE B-802 BUNDANG TECHNO PARK",
        "address_2": "SEONGNAM-SI  GYEONGGI-DO  463-760",
        "country": "KR"
    },
    "001C0B": {
        "oui_hex": "00-1C-0B",
        "organization": "SmartAnt Telecom",
        "address_1": "2F, No. 669, Sec. 4, Chung Hsing Rd., Chutung",
        "address_2": "Hsinchu    310",
        "country": "TW"
    },
    "001BD0": {
        "oui_hex": "00-1B-D0",
        "organization": "IDENTEC SOLUTIONS",
        "address_1": "Hertzstraße 10",
        "address_2": "Weinheim    69469",
        "country": "DE"
    },
    "001BCD": {
        "oui_hex": "00-1B-CD",
        "organization": "DAVISCOMMS (S) PTE LTD",
        "address_1": "Blk 70 Ubi Crescent #01-07",
        "address_2": "    408570",
        "country": "SG"
    },
    "001BCA": {
        "oui_hex": "00-1B-CA",
        "organization": "Beijing Run Technology LTD. Company",
        "address_1": "4/F, Hangtian Technology Building",
        "address_2": "  Beijing  100037",
        "country": "CN"
    },
    "001BCC": {
        "oui_hex": "00-1B-CC",
        "organization": "KINGTEK CCTV ALLIANCE CO., LTD.",
        "address_1": "5F-3, NO. 106, SEC. 3, HSIN YI ROAD",
        "address_2": "TAIPEI    106",
        "country": "TW"
    },
    "001BF4": {
        "oui_hex": "00-1B-F4",
        "organization": "KENWIN INDUSTRIAL(HK) LTD.",
        "address_1": "RM.1512 15/F SHATIN GALLERIA",
        "address_2": "",
        "country": "HK"
    },
    "001BF9": {
        "oui_hex": "00-1B-F9",
        "organization": "Intellitect Water Ltd",
        "address_1": "Suite 19, Basepoint Business Centre",
        "address_2": "Christchurch  Dorset  BH23 ^NW",
        "country": "GB"
    },
    "001BFA": {
        "oui_hex": "00-1B-FA",
        "organization": "G.i.N. mbH",
        "address_1": "Raiffeisenstraße 15",
        "address_2": "Griesheim  Hessen  64347",
        "country": "DE"
    },
    "001BF3": {
        "oui_hex": "00-1B-F3",
        "organization": "TRANSRADIO SenderSysteme Berlin AG",
        "address_1": "Mertensstrasse 63",
        "address_2": "Berlin    13587",
        "country": "DE"
    },
    "001C21": {
        "oui_hex": "00-1C-21",
        "organization": "Nucsafe Inc.",
        "address_1": "601 Oak Ridge Turnpike",
        "address_2": "Oak Ridge  Tennessee  37830",
        "country": "US"
    },
    "001C1E": {
        "oui_hex": "00-1C-1E",
        "organization": "emtrion GmbH",
        "address_1": "Alter Schlachthof 45",
        "address_2": "Karlsruhe  Baden Wuerttemberg  76131",
        "country": "DE"
    },
    "001BDE": {
        "oui_hex": "00-1B-DE",
        "organization": "Renkus-Heinz, Inc.",
        "address_1": "19201 Cook St.",
        "address_2": "Foothill Ranch  CA  92610",
        "country": "US"
    },
    "001BDB": {
        "oui_hex": "00-1B-DB",
        "organization": "Valeo VECS",
        "address_1": "2 Avenue Fernand Pouillon",
        "address_2": "CRETEIL  Ile de France  94042",
        "country": "FR"
    },
    "001BD8": {
        "oui_hex": "00-1B-D8",
        "organization": "FLIR Systems Inc",
        "address_1": "65 Challenger Road",
        "address_2": "Ridgefield Park  NJ  07660-2103",
        "country": "US"
    },
    "001BD4": {
        "oui_hex": "00-1B-D4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C2D": {
        "oui_hex": "00-1C-2D",
        "organization": "FlexRadio Systems",
        "address_1": "8900 Marybank Dr.",
        "address_2": "Austin  TX  78750",
        "country": "US"
    },
    "001C2C": {
        "oui_hex": "00-1C-2C",
        "organization": "Synapse",
        "address_1": "132 Export Circle",
        "address_2": "Huntsville  AL  35806",
        "country": "US"
    },
    "001C08": {
        "oui_hex": "00-1C-08",
        "organization": "Echo360, Inc.",
        "address_1": "11955 Freedom Drive",
        "address_2": "Reston  VA  20190",
        "country": "US"
    },
    "001BC8": {
        "oui_hex": "00-1B-C8",
        "organization": "MIURA CO.,LTD",
        "address_1": "620-1,Nakanishisoto",
        "address_2": "Matsuyama  Ehime  799-2425",
        "country": "JP"
    },
    "001BC1": {
        "oui_hex": "00-1B-C1",
        "organization": "HOLUX Technology, Inc.",
        "address_1": "1F, No. 30, R&D Rd. II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001BBC": {
        "oui_hex": "00-1B-BC",
        "organization": "Silver Peak Systems, Inc.",
        "address_1": "471 El Camino Real",
        "address_2": "Santa Clara  CA  95050",
        "country": "US"
    },
    "001B73": {
        "oui_hex": "00-1B-73",
        "organization": "DTL Broadcast Ltd",
        "address_1": "Johnson's Estate",
        "address_2": "HAYES  Middlesex  UB3 3BA",
        "country": "GB"
    },
    "001B71": {
        "oui_hex": "00-1B-71",
        "organization": "Telular Corp.",
        "address_1": "311 South Wacker Drive",
        "address_2": "Chicago  IL  60606",
        "country": "US"
    },
    "001B97": {
        "oui_hex": "00-1B-97",
        "organization": "Violin Technologies",
        "address_1": "33 Wood Ave South",
        "address_2": "Iselin  NJ  08830",
        "country": "US"
    },
    "001BA8": {
        "oui_hex": "00-1B-A8",
        "organization": "UBI&MOBI,.Inc",
        "address_1": "3F, Duido Bldg, #288-5, Yangjae-Dong",
        "address_2": "Seocho-Gu  Seoul  137-130",
        "country": "KR"
    },
    "001B81": {
        "oui_hex": "00-1B-81",
        "organization": "DATAQ Instruments, Inc.",
        "address_1": "241 Springside Drive",
        "address_2": "Akron  Ohio  44333",
        "country": "US"
    },
    "001B7D": {
        "oui_hex": "00-1B-7D",
        "organization": "CXR Anderson Jacobson",
        "address_1": "Rue de l'ornette",
        "address_2": "Abondant    28410",
        "country": "FR"
    },
    "001B79": {
        "oui_hex": "00-1B-79",
        "organization": "FAIVELEY TRANSPORT",
        "address_1": "ZI du bois de plante",
        "address_2": "LA VILLE AUX DAMES    37700",
        "country": "FR"
    },
    "001B65": {
        "oui_hex": "00-1B-65",
        "organization": "China Gridcom Co., Ltd",
        "address_1": "21/F, Huaneng Building, No. 2068 Shennan Main Road",
        "address_2": "Shenzhen  Guangdong  0086",
        "country": "CN"
    },
    "001B88": {
        "oui_hex": "00-1B-88",
        "organization": "Divinet Access Technologies Ltd",
        "address_1": "4th Floor, Media Center,",
        "address_2": "Pune  Maharashtra  411007",
        "country": "IN"
    },
    "001B83": {
        "oui_hex": "00-1B-83",
        "organization": "Finsoft Ltd",
        "address_1": "16-18 Hatton Garden",
        "address_2": "London    EC1N 8AT",
        "country": "GB"
    },
    "001BAB": {
        "oui_hex": "00-1B-AB",
        "organization": "Telchemy, Incorporated",
        "address_1": "2905 Premiere Parkway",
        "address_2": "Duluth  GA  30097",
        "country": "US"
    },
    "001BAE": {
        "oui_hex": "00-1B-AE",
        "organization": "Micro Control Systems, Inc",
        "address_1": "5580 Enterprise Parkway",
        "address_2": "Fort Myers  Florida  33905",
        "country": "US"
    },
    "001BA0": {
        "oui_hex": "00-1B-A0",
        "organization": "Awox",
        "address_1": "93, Place Pierre Duhem,",
        "address_2": "Montpellier  Herault  34000",
        "country": "FR"
    },
    "001B51": {
        "oui_hex": "00-1B-51",
        "organization": "Vector Technology Corp.",
        "address_1": "No.7, Lane12, Yajou Road.",
        "address_2": "Tucheng  Taipei  236",
        "country": "TW"
    },
    "001B54": {
        "oui_hex": "00-1B-54",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B4A": {
        "oui_hex": "00-1B-4A",
        "organization": "W&W Communications, Inc.",
        "address_1": "2903 Bunker Hill Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001AFA": {
        "oui_hex": "00-1A-FA",
        "organization": "Welch Allyn, Inc.",
        "address_1": "4619 Jordan Road",
        "address_2": "Skaneateles Falls  NY  13153-0187",
        "country": "US"
    },
    "001AF7": {
        "oui_hex": "00-1A-F7",
        "organization": "dataschalt e+a GmbH",
        "address_1": "An der Hülshorst 7-9",
        "address_2": "Lübeck    23568",
        "country": "DE"
    },
    "001AF3": {
        "oui_hex": "00-1A-F3",
        "organization": "Samyoung Electronics",
        "address_1": "146-1, sangdaewon-dong, joongwon-gu",
        "address_2": "sungnam-shi  Gyunggi-do  462-807",
        "country": "KR"
    },
    "001AEF": {
        "oui_hex": "00-1A-EF",
        "organization": "Loopcomm Technology, Inc.",
        "address_1": "18F-1, No. 150, Jian Yi Rd.,",
        "address_2": "Chung-Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001AEC": {
        "oui_hex": "00-1A-EC",
        "organization": "Keumbee Electronics Co.,Ltd.",
        "address_1": "3-26, Jangsang-dong, Sangrok-gu",
        "address_2": "Ansan-si  Kyungki-do  426-410",
        "country": "KR"
    },
    "001B44": {
        "oui_hex": "00-1B-44",
        "organization": "SanDisk Corporation",
        "address_1": "601 McCarthy Boulevard",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "001B46": {
        "oui_hex": "00-1B-46",
        "organization": "Blueone Technology Co.,Ltd",
        "address_1": "Room 309,3 Floor, 404 Building, ShangBu industrial",
        "address_2": "Shenzhen  Guangdong  518028",
        "country": "CN"
    },
    "001B40": {
        "oui_hex": "00-1B-40",
        "organization": "Network Automation mxc AB",
        "address_1": "Box 7294",
        "address_2": "Stockholm    10390",
        "country": "SE"
    },
    "001B42": {
        "oui_hex": "00-1B-42",
        "organization": "Wise & Blue",
        "address_1": "#715-3 Anyang Megavalley",
        "address_2": "Anyang-Si  Gyunggi-Do  431-767",
        "country": "KR"
    },
    "001B35": {
        "oui_hex": "00-1B-35",
        "organization": "ChongQing JINOU Science & Technology Development CO.,Ltd",
        "address_1": "Chuangyeyuan 208# Keyuan 3rd Road 106#",
        "address_2": "Chongqing    400030",
        "country": "CN"
    },
    "001B36": {
        "oui_hex": "00-1B-36",
        "organization": "Tsubata Engineering Co.,Ltd. (Head Office)",
        "address_1": "Koyanagi 1-2",
        "address_2": "Ibaraki  Osaka  567-0852",
        "country": "JP"
    },
    "001B39": {
        "oui_hex": "00-1B-39",
        "organization": "Proxicast",
        "address_1": "312 Sunnyfield Drive",
        "address_2": "Glenshaw  PA  15116",
        "country": "US"
    },
    "001B3B": {
        "oui_hex": "00-1B-3B",
        "organization": "Yi-Qing CO., LTD",
        "address_1": "310 ROOM,12F",
        "address_2": "TAIPEI    100",
        "country": "TW"
    },
    "001B20": {
        "oui_hex": "00-1B-20",
        "organization": "TPine Technology",
        "address_1": "3F, No.1, AN-I Rd,",
        "address_2": "Keelung    111",
        "country": "TW"
    },
    "001B22": {
        "oui_hex": "00-1B-22",
        "organization": "Palit Microsystems ( H.K.) Ltd.",
        "address_1": "Room 4-6,11F,Nan Fung Commercial Center",
        "address_2": "Kowloon    111",
        "country": "HK"
    },
    "001B1C": {
        "oui_hex": "00-1B-1C",
        "organization": "Coherent",
        "address_1": "1280 Blues Hills Ave.",
        "address_2": "Bloomfield  CT  06002",
        "country": "US"
    },
    "001B19": {
        "oui_hex": "00-1B-19",
        "organization": "IEEE I&M Society TC9",
        "address_1": "100 Bureau Dr., Mail Stop 8220",
        "address_2": "Gaithersburg  MD  20899-8220",
        "country": "US"
    },
    "001B64": {
        "oui_hex": "00-1B-64",
        "organization": "IsaacLandKorea Co., Ltd,",
        "address_1": "Rm 608, Hangang-Hyundai-Hyel Bldg. 2-36,",
        "address_2": "Seoul    140-871",
        "country": "KR"
    },
    "001B26": {
        "oui_hex": "00-1B-26",
        "organization": "RON-Telecom ZAO",
        "address_1": "15 A, Zarechnaya st.",
        "address_2": "Trehgorny  Chelyabinsk region  456080",
        "country": "RU"
    },
    "001B13": {
        "oui_hex": "00-1B-13",
        "organization": "Icron Technologies Corporation",
        "address_1": "221 - 4664 Lougheed Highway",
        "address_2": "Burnaby  BC  V5C 5T5",
        "country": "CA"
    },
    "001B0F": {
        "oui_hex": "00-1B-0F",
        "organization": "Petratec",
        "address_1": "12 Derech HaSharon",
        "address_2": "Kfar Saba  Sharon  44271",
        "country": "IL"
    },
    "001AA9": {
        "oui_hex": "00-1A-A9",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building, Star-net Science Plaza, Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "001AA8": {
        "oui_hex": "00-1A-A8",
        "organization": "Mamiya Digital Imaging Co., Ltd.",
        "address_1": "2-2, 1-chome, Koraku",
        "address_2": "Bunkyo-ku  Tokyo  112-0004",
        "country": "JP"
    },
    "001A99": {
        "oui_hex": "00-1A-99",
        "organization": "Smarty (HZ) Information Electronics Co., Ltd",
        "address_1": "Yonghua Industrial District,Huishen Road,Zhenlong Town",
        "address_2": "HuiZhou  GuangDong  516227",
        "country": "CN"
    },
    "001AA6": {
        "oui_hex": "00-1A-A6",
        "organization": "Telefunken Radio Communication Systems GmbH &CO.KG",
        "address_1": "Eberhard-Finckh-Strasse 55",
        "address_2": "Ulm  Baden-Wurttemberg  89075",
        "country": "DE"
    },
    "001A96": {
        "oui_hex": "00-1A-96",
        "organization": "ECLER S.A.",
        "address_1": "Motors 166-168",
        "address_2": "Barcelona    08038",
        "country": "ES"
    },
    "001A91": {
        "oui_hex": "00-1A-91",
        "organization": "FusionDynamic Ltd.",
        "address_1": "1 B.S.R. towers, 4-th floor",
        "address_2": "Ramat Gan    52573",
        "country": "IL"
    },
    "001A8C": {
        "oui_hex": "00-1A-8C",
        "organization": "Sophos Ltd",
        "address_1": "The Pentagon",
        "address_2": "Abingdon  Oxfordshire  OX14 3YP",
        "country": "GB"
    },
    "001AB3": {
        "oui_hex": "00-1A-B3",
        "organization": "VISIONITE INC.",
        "address_1": "#707 Daeryung Technotown-2 569-21",
        "address_2": "Seoul    153-771",
        "country": "KR"
    },
    "001ACA": {
        "oui_hex": "00-1A-CA",
        "organization": "Tilera Corporation",
        "address_1": "1900 West Park Drive",
        "address_2": "Westborough  MA  01581",
        "country": "US"
    },
    "001A84": {
        "oui_hex": "00-1A-84",
        "organization": "V One Multimedia Pte Ltd",
        "address_1": "Blk 54, Kallang Bahru",
        "address_2": "    339336",
        "country": "SG"
    },
    "001AB9": {
        "oui_hex": "00-1A-B9",
        "organization": "PMC",
        "address_1": "56, avenue Raspail",
        "address_2": "Saint Maur    94100",
        "country": "FR"
    },
    "001ABA": {
        "oui_hex": "00-1A-BA",
        "organization": "Caton Overseas Limited",
        "address_1": "Room 102, No. 101, Lane 91",
        "address_2": "Shanghai    200127",
        "country": "CN"
    },
    "001AD1": {
        "oui_hex": "00-1A-D1",
        "organization": "FARGO CO., LTD.",
        "address_1": "4F. KYEMYUNG B/D",
        "address_2": "SEOUL    135 885",
        "country": "KR"
    },
    "001A3A": {
        "oui_hex": "00-1A-3A",
        "organization": "Dongahelecomm",
        "address_1": "678-3,Jeil-ri,Yanggi-myun,Cheoin-gu",
        "address_2": "Yongin-si  Gyeonggi-do  449-821",
        "country": "KR"
    },
    "001A3B": {
        "oui_hex": "00-1A-3B",
        "organization": "Doah Elecom Inc.",
        "address_1": "8th fl. Century Plaza, 277-40",
        "address_2": "Seoul    133-123",
        "country": "KR"
    },
    "001A3C": {
        "oui_hex": "00-1A-3C",
        "organization": "Technowave Ltd.",
        "address_1": "Sakurai Bldg.1F,",
        "address_2": "Musashino-shi  Tokyo  180-0006",
        "country": "JP"
    },
    "001A40": {
        "oui_hex": "00-1A-40",
        "organization": "A-FOUR TECH CO., LTD.",
        "address_1": "6F, No. 108, Min-Chuan Rd.,",
        "address_2": "Hsin-Tien  Taipei  23141",
        "country": "TW"
    },
    "001A30": {
        "oui_hex": "00-1A-30",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001A7B": {
        "oui_hex": "00-1A-7B",
        "organization": "Teleco, Inc.",
        "address_1": "430 Woodruff Rd.",
        "address_2": "Greenville  SC  29607",
        "country": "US"
    },
    "001A36": {
        "oui_hex": "00-1A-36",
        "organization": "Aipermon GmbH & Co. KG",
        "address_1": "Zamdorfer Str. 100",
        "address_2": "Munich  Bavaria  D-81677",
        "country": "DE"
    },
    "001A26": {
        "oui_hex": "00-1A-26",
        "organization": "Deltanode Solutions AB",
        "address_1": "Box 92 184",
        "address_2": "Stockholm    120 09",
        "country": "SE"
    },
    "001A6D": {
        "oui_hex": "00-1A-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001A6E": {
        "oui_hex": "00-1A-6E",
        "organization": "Impro Technologies",
        "address_1": "47B Gillits Rd",
        "address_2": "Pinetown  KwaZulu-Natal  3610",
        "country": "ZA"
    },
    "001A6C": {
        "oui_hex": "00-1A-6C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001A4A": {
        "oui_hex": "00-1A-4A",
        "organization": "Qumranet Inc.",
        "address_1": "530 Lakeside Drive",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "001A3E": {
        "oui_hex": "00-1A-3E",
        "organization": "Faster Technology LLC",
        "address_1": "1812 Avenue D",
        "address_2": "Katy  Texas  77493",
        "country": "US"
    },
    "001A63": {
        "oui_hex": "00-1A-63",
        "organization": "Elster Solutions, LLC,",
        "address_1": "208 South Rogers Lane",
        "address_2": "Raleigh  NC  27610",
        "country": "US"
    },
    "001A59": {
        "oui_hex": "00-1A-59",
        "organization": "Ircona",
        "address_1": "Unit 4B-1, Corporate Park",
        "address_2": "Blanchardstown  Dublin  15",
        "country": "IE"
    },
    "001A46": {
        "oui_hex": "00-1A-46",
        "organization": "Digital Multimedia Technology Co., Ltd",
        "address_1": "Doorim Bldg, 3rd Fl, 164-21 Poi-Dong,",
        "address_2": "Seoul  Kangnam-Gu  135-960",
        "country": "KR"
    },
    "001A25": {
        "oui_hex": "00-1A-25",
        "organization": "DELTA DORE",
        "address_1": "BONNEMAIN",
        "address_2": "COMBOURG  BRETAGNE 35  35270",
        "country": "FR"
    },
    "0019FE": {
        "oui_hex": "00-19-FE",
        "organization": "SHENZHEN SEECOMM TECHNOLOGY CO.,LTD.",
        "address_1": "Room 609,404Yannan Road",
        "address_2": "ShenZhen  Guangdong",
        "country": "CN"
    },
    "0019FD": {
        "oui_hex": "00-19-FD",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001A0D": {
        "oui_hex": "00-1A-0D",
        "organization": "HandHeld entertainment, Inc.",
        "address_1": "539 Bryant Street, Suite 403",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "001A0E": {
        "oui_hex": "00-1A-0E",
        "organization": "Cheng Uei Precision Industry Co.,Ltd",
        "address_1": "Junda Industry District, Dongkeng Town,Dongguan City",
        "address_2": "DongGuan  Guang Dong  523455",
        "country": "CN"
    },
    "0019CD": {
        "oui_hex": "00-19-CD",
        "organization": "Chengdu ethercom information technology Ltd.",
        "address_1": "South Extension of Tianfu Wide Road No.7 department room 201",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "0019D9": {
        "oui_hex": "00-19-D9",
        "organization": "Zeutschel GmbH",
        "address_1": "Heerweg 2",
        "address_2": "Tübingen-Hirschau  BW  D-72070",
        "country": "DE"
    },
    "001A01": {
        "oui_hex": "00-1A-01",
        "organization": "Smiths Medical",
        "address_1": "4350 Rivergreen Parkway",
        "address_2": "Duluth  GA  30096",
        "country": "US"
    },
    "0019CA": {
        "oui_hex": "00-19-CA",
        "organization": "Broadata Communications, Inc",
        "address_1": "2545 W 237th St Ste K",
        "address_2": "Torrance  CA  90505",
        "country": "US"
    },
    "0019D3": {
        "oui_hex": "00-19-D3",
        "organization": "TRAK Microwave",
        "address_1": "4726 Eisenhower Blvd",
        "address_2": "Tampa  FL  33634",
        "country": "US"
    },
    "0019C3": {
        "oui_hex": "00-19-C3",
        "organization": "Qualitrol",
        "address_1": "Wildflower Way",
        "address_2": "Belfast  Co. Antrim  BT12 6TA",
        "country": "GB"
    },
    "0019BE": {
        "oui_hex": "00-19-BE",
        "organization": "Altai Technologies Limited",
        "address_1": "2/F, East Wing, Lakeside 2, 10 Science Park West Avenue,",
        "address_2": "Shatin  New Territories",
        "country": "HK"
    },
    "0019B4": {
        "oui_hex": "00-19-B4",
        "organization": "Intellio Ltd",
        "address_1": "Gyarmat u. 99/B",
        "address_2": "Budapest    1147",
        "country": "HU"
    },
    "0019BA": {
        "oui_hex": "00-19-BA",
        "organization": "Paradox Security Systems Ltd",
        "address_1": "780 Industrial Blvd",
        "address_2": "St-Eustache  Quebec  J7R 5V3",
        "country": "CA"
    },
    "0019A1": {
        "oui_hex": "00-19-A1",
        "organization": "LG INFORMATION & COMM.",
        "address_1": "60-39,Kasan-dong,Kumchon-ku",
        "address_2": "Seoul    153-023",
        "country": "KR"
    },
    "0019A8": {
        "oui_hex": "00-19-A8",
        "organization": "WiQuest Communications",
        "address_1": "915 Enterprise Blvd.",
        "address_2": "Allen  Texas  75013",
        "country": "US"
    },
    "0019ED": {
        "oui_hex": "00-19-ED",
        "organization": "Axesstel Inc.",
        "address_1": "6815 Flanders Sr.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0019F6": {
        "oui_hex": "00-19-F6",
        "organization": "Acconet (PTE) Ltd",
        "address_1": "No. 16 Ayer Rajah Crescent",
        "address_2": "Singapore    139965",
        "country": "SG"
    },
    "001A15": {
        "oui_hex": "00-1A-15",
        "organization": "gemalto e-Payment",
        "address_1": "6 rue de la Verrerie",
        "address_2": "Meudon    92197",
        "country": "FR"
    },
    "001968": {
        "oui_hex": "00-19-68",
        "organization": "Digital Video Networks(Shanghai) CO. LTD.",
        "address_1": "9th Floor,Hechuan Building, No.1026 YiShan Rd",
        "address_2": "Shanghai    201103",
        "country": "CN"
    },
    "00197F": {
        "oui_hex": "00-19-7F",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "00197A": {
        "oui_hex": "00-19-7A",
        "organization": "MAZeT GmbH",
        "address_1": "Goeschwitzer Str. 32",
        "address_2": "Jena    D-07745",
        "country": "DE"
    },
    "001978": {
        "oui_hex": "00-19-78",
        "organization": "Datum Systems, Inc.",
        "address_1": "3666 Tiffani Ct.",
        "address_2": "Santa Cruz  CA  95065",
        "country": "US"
    },
    "001989": {
        "oui_hex": "00-19-89",
        "organization": "Sonitrol Corporation",
        "address_1": "1707 Orlando Central Pkwy.",
        "address_2": "Orlando  FL  32809",
        "country": "US"
    },
    "00198E": {
        "oui_hex": "00-19-8E",
        "organization": "Oticon A/S",
        "address_1": "Kongebakken 9",
        "address_2": "Smørum    2765",
        "country": "DK"
    },
    "001980": {
        "oui_hex": "00-19-80",
        "organization": "Gridpoint Systems",
        "address_1": "4043 Carling Avenue, Suite 200",
        "address_2": "Ottawa  Ontario  K2K 2A3",
        "country": "CA"
    },
    "001983": {
        "oui_hex": "00-19-83",
        "organization": "CCT R&D Limited",
        "address_1": "18/F CCT Telecom Building",
        "address_2": "Fotan, Shatin  N.T.  000",
        "country": "HK"
    },
    "00194C": {
        "oui_hex": "00-19-4C",
        "organization": "Fujian Stelcom information & Technology CO.,Ltd",
        "address_1": "4F,Building A,Start Science Park, No.68,Hongshanyuan Rd",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "00194A": {
        "oui_hex": "00-19-4A",
        "organization": "TESTO AG",
        "address_1": "Testo Straße 1",
        "address_2": "Lenzkirch  Baden-Württemberg  79853",
        "country": "DE"
    },
    "00198A": {
        "oui_hex": "00-19-8A",
        "organization": "Northrop Grumman Systems Corp.",
        "address_1": "7055 Troy Hill Drive",
        "address_2": "Elkridge  Maryland  21075",
        "country": "US"
    },
    "001960": {
        "oui_hex": "00-19-60",
        "organization": "DoCoMo Systems, Inc.",
        "address_1": "Meguro Techno Bldg. 2nd Floor",
        "address_2": "Shinagawa-ku  Tokyo  141-0031",
        "country": "JP"
    },
    "00195A": {
        "oui_hex": "00-19-5A",
        "organization": "Jenaer Antriebstechnik GmbH",
        "address_1": "Buchaer Strasse 1",
        "address_2": "Jena  Thueringen  07745",
        "country": "DE"
    },
    "00196D": {
        "oui_hex": "00-19-6D",
        "organization": "Raybit Systems Korea, Inc",
        "address_1": "Dream Tower 1221",
        "address_2": "Seoul    158-718",
        "country": "KR"
    },
    "001970": {
        "oui_hex": "00-19-70",
        "organization": "Z-Com, Inc.",
        "address_1": "7F-2, NO.9, PROSPERITY 1ST RD.",
        "address_2": "HSINCHU    300",
        "country": "TW"
    },
    "001950": {
        "oui_hex": "00-19-50",
        "organization": "Harman Multimedia",
        "address_1": "8400 Balboa Blvd.",
        "address_2": "Northridge  CA  91329",
        "country": "US"
    },
    "0018EE": {
        "oui_hex": "00-18-EE",
        "organization": "Videology Imaging Solutions, Inc.",
        "address_1": "37 M Lark Industrial Parkway",
        "address_2": "Greenville  RI  02828-3001",
        "country": "US"
    },
    "0018EB": {
        "oui_hex": "00-18-EB",
        "organization": "Blue Zen Enterprises Private Limited",
        "address_1": "No 2&3 (First Floor) Kurban Ali Street",
        "address_2": "Chennai  Tamil Nadu  600002",
        "country": "IN"
    },
    "001924": {
        "oui_hex": "00-19-24",
        "organization": "LBNL  Engineering",
        "address_1": "1 Cyclotron Rd.",
        "address_2": "Berkeley  CA  94720",
        "country": "US"
    },
    "00191A": {
        "oui_hex": "00-19-1A",
        "organization": "IRLINK",
        "address_1": "HanYoung B/D 6F, 4-6",
        "address_2": "SEOUL    138-824",
        "country": "KR"
    },
    "001916": {
        "oui_hex": "00-19-16",
        "organization": "PayTec AG",
        "address_1": "Rosengartenstrasse 3",
        "address_2": "Zollikerberg  ZH  8125",
        "country": "CH"
    },
    "00190E": {
        "oui_hex": "00-19-0E",
        "organization": "Atech Technology Co., Ltd.",
        "address_1": "4 Fl., No. 103, Sec 2, Jiuzong Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001939": {
        "oui_hex": "00-19-39",
        "organization": "Gigamips",
        "address_1": "5th Floor, Yangjae Building, 261, Yangjae-Dong",
        "address_2": "Seocho-Gu  Seoul  137-130",
        "country": "KR"
    },
    "00193A": {
        "oui_hex": "00-19-3A",
        "organization": "OESOLUTIONS",
        "address_1": "Technopark, 958-3 Daechon-Dong, Buk-Gu",
        "address_2": "Gwangju  Buk-Gu  500-706",
        "country": "KR"
    },
    "0018E2": {
        "oui_hex": "00-18-E2",
        "organization": "Topdata Sistemas de Automacao Ltda",
        "address_1": "Rua Dr Carvalho Chaves, 662",
        "address_2": "Curitiba  PR  80.220-010",
        "country": "BR"
    },
    "001922": {
        "oui_hex": "00-19-22",
        "organization": "CM Comandos Lineares",
        "address_1": "Av Eng Alberto de Zagottis, 760",
        "address_2": "São Paulo  SP  04675-085",
        "country": "BR"
    },
    "00191D": {
        "oui_hex": "00-19-1D",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "00192F": {
        "oui_hex": "00-19-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001905": {
        "oui_hex": "00-19-05",
        "organization": "SCHRACK Seconet AG",
        "address_1": "Eibesbrunnergasse 18",
        "address_2": "Wien  Österreich  1122",
        "country": "AT"
    },
    "001907": {
        "oui_hex": "00-19-07",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0018FB": {
        "oui_hex": "00-18-FB",
        "organization": "Compro Technology",
        "address_1": "3/F No 12, Alley 6, Lane 45, Pao Shin Rd",
        "address_2": "Hsintien    231",
        "country": "TW"
    },
    "0018C3": {
        "oui_hex": "00-18-C3",
        "organization": "CS Corporation",
        "address_1": "CS-building, Pangyo seven venture valley 625",
        "address_2": " Seongnam-si  Gyeonggi-do  463-400",
        "country": "KR"
    },
    "0018CA": {
        "oui_hex": "00-18-CA",
        "organization": "Viprinet GmbH",
        "address_1": "Basilikastraße 3",
        "address_2": "Bingen am Rhein    55411",
        "country": "DE"
    },
    "0018C7": {
        "oui_hex": "00-18-C7",
        "organization": "Real Time Automation",
        "address_1": "2825 N Mayfair Rd Ste 11",
        "address_2": "Wauwatosa  WI  53222",
        "country": "US"
    },
    "0018BB": {
        "oui_hex": "00-18-BB",
        "organization": "Eliwell Controls srl",
        "address_1": "Via dell'Industria, 15",
        "address_2": "Pieve d'Alpago  Belluno  32010",
        "country": "IT"
    },
    "0018BF": {
        "oui_hex": "00-18-BF",
        "organization": "Essence Technology Solution, Inc.",
        "address_1": "B1, No. 207, Beisin Rd., Sec. 3",
        "address_2": "Sindian, Taipei County    231",
        "country": "TW"
    },
    "00188C": {
        "oui_hex": "00-18-8C",
        "organization": "Mobile Action Technology Inc.",
        "address_1": "5F, No. 205-3, Sec. 3, Beishin Rd.",
        "address_2": "Shindian City, Taipei    231",
        "country": "TW"
    },
    "00188F": {
        "oui_hex": "00-18-8F",
        "organization": "Montgomery Technology, Inc.",
        "address_1": "800 East Commerce Street",
        "address_2": "Greenville  AL  36037",
        "country": "US"
    },
    "001884": {
        "oui_hex": "00-18-84",
        "organization": "Fon Technology S.L.",
        "address_1": "Avda. Bruselas, n. 7, Planta 3, Alcobendas",
        "address_2": "  Madrid  28100",
        "country": "ES"
    },
    "001880": {
        "oui_hex": "00-18-80",
        "organization": "Maxim Integrated Products",
        "address_1": "160 Rio Robles",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0018D0": {
        "oui_hex": "00-18-D0",
        "organization": "AtRoad,  A Trimble Company",
        "address_1": "47071 Bayside Parkway",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "0018D2": {
        "oui_hex": "00-18-D2",
        "organization": "High-Gain Antennas LLC",
        "address_1": "11679 S. Cormorant Circle",
        "address_2": "Parker  CO  80134",
        "country": "US"
    },
    "0018D3": {
        "oui_hex": "00-18-D3",
        "organization": "TEAMCAST",
        "address_1": "Centre Espace Performance",
        "address_2": "Saint Gregoire    35769",
        "country": "FR"
    },
    "0018C6": {
        "oui_hex": "00-18-C6",
        "organization": "OPW Fuel Management Systems",
        "address_1": "6900 Santa Fe Drive",
        "address_2": "Hodgkins  Illinois  60525",
        "country": "US"
    },
    "00187C": {
        "oui_hex": "00-18-7C",
        "organization": "INTERCROSS, LLC",
        "address_1": "Novoselov str., 58/7",
        "address_2": "Ryazan    390049",
        "country": "RU"
    },
    "001870": {
        "oui_hex": "00-18-70",
        "organization": "E28 Shanghai Limited",
        "address_1": "2/F Eastern Tower",
        "address_2": "Shanghai    200001",
        "country": "CN"
    },
    "001872": {
        "oui_hex": "00-18-72",
        "organization": "Expertise Engineering",
        "address_1": "4186 Sorrento Valley Blvd Suite -J",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0018DC": {
        "oui_hex": "00-18-DC",
        "organization": "Prostar Co., Ltd.",
        "address_1": "A-703 Technotown, 250-3 Hagye-dong, Nowon-gu",
        "address_2": "Seoul    139-230",
        "country": "KR"
    },
    "0018D1": {
        "oui_hex": "00-18-D1",
        "organization": "Siemens Home & Office Comm. Devices",
        "address_1": "4849 Alpha Rd.",
        "address_2": "Dallas  Texas  75244",
        "country": "US"
    },
    "0018AA": {
        "oui_hex": "00-18-AA",
        "organization": "Protec Fire Detection plc",
        "address_1": "Protec House",
        "address_2": "Nelson  Lancashire  BB9 6LQ",
        "country": "GB"
    },
    "001896": {
        "oui_hex": "00-18-96",
        "organization": "Great Well Electronic LTD",
        "address_1": "The Third Industrial  Area",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "US"
    },
    "001890": {
        "oui_hex": "00-18-90",
        "organization": "RadioCOM, s.r.o.",
        "address_1": "Misikova 22",
        "address_2": "Bratislava    811 06",
        "country": "SK"
    },
    "0018B9": {
        "oui_hex": "00-18-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0018B8": {
        "oui_hex": "00-18-B8",
        "organization": "New Voice International AG",
        "address_1": "St. Gallerstrasse 8",
        "address_2": "Lachen  SZ  8853",
        "country": "CH"
    },
    "0018A1": {
        "oui_hex": "00-18-A1",
        "organization": "Tiqit Computers, Inc.",
        "address_1": "2215 Old Page Mill Rd",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "001812": {
        "oui_hex": "00-18-12",
        "organization": "Beijing Xinwei Telecom Technology Co., Ltd.",
        "address_1": "Xinwei Bldg., No. 7 Zhongguancun Software Park,",
        "address_2": "Haidian District  Beijing  100094",
        "country": "CN"
    },
    "00180B": {
        "oui_hex": "00-18-0B",
        "organization": "Brilliant Telecommunications",
        "address_1": "307 Orchard City Dr.",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "001861": {
        "oui_hex": "00-18-61",
        "organization": "Ooma, Inc.",
        "address_1": "555 University Avenue",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "00185B": {
        "oui_hex": "00-18-5B",
        "organization": "Network Chemistry, Inc",
        "address_1": "1700 Seaport Blvd",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "001855": {
        "oui_hex": "00-18-55",
        "organization": "Aeromaritime Systembau GmbH",
        "address_1": "Ludwig-Erhard-Str. 16",
        "address_2": "D-85375  Neufahrn",
        "country": "DE"
    },
    "001851": {
        "oui_hex": "00-18-51",
        "organization": "SWsoft",
        "address_1": "13755 Sunrise Valley Drive, Suite 600",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "001874": {
        "oui_hex": "00-18-74",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001869": {
        "oui_hex": "00-18-69",
        "organization": "KINGJIM",
        "address_1": "No.10-18,2-Chome",
        "address_2": "Chiyoda-ku  Tokyo  101-0031",
        "country": "JP"
    },
    "001856": {
        "oui_hex": "00-18-56",
        "organization": "EyeFi, Inc",
        "address_1": "149 Commonwealth Drive",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "00184E": {
        "oui_hex": "00-18-4E",
        "organization": "Lianhe Technologies, Inc.",
        "address_1": "3F, #119, DaHu ShanZhuang St.",
        "address_2": "Neihu District  Taipei City  114",
        "country": "TW"
    },
    "00184C": {
        "oui_hex": "00-18-4C",
        "organization": "Bogen Communications",
        "address_1": "50 Spring St.",
        "address_2": "Ramsey  NJ  07446",
        "country": "US"
    },
    "001826": {
        "oui_hex": "00-18-26",
        "organization": "Cale Access AB",
        "address_1": "Box 1031",
        "address_2": "Kista    SE-164 21",
        "country": "SE"
    },
    "00182D": {
        "oui_hex": "00-18-2D",
        "organization": "Artec Design",
        "address_1": "Teaduspargi 6/1",
        "address_2": "Tallinn    12618",
        "country": "EE"
    },
    "00182A": {
        "oui_hex": "00-18-2A",
        "organization": "Taiwan Video & Monitor",
        "address_1": "3F, 141 Jen Ai Rd Sec. 3",
        "address_2": "Taipei City    106",
        "country": "TW"
    },
    "00183B": {
        "oui_hex": "00-18-3B",
        "organization": "CENITS Co., Ltd.",
        "address_1": "3F, Yangjae Bldg., 264-3",
        "address_2": "Seoul    137-130",
        "country": "KR"
    },
    "00183C": {
        "oui_hex": "00-18-3C",
        "organization": "Encore Software Limited",
        "address_1": "6F Leo Complex",
        "address_2": "Bangalore  Karnataka  560025",
        "country": "IN"
    },
    "001841": {
        "oui_hex": "00-18-41",
        "organization": "High Tech Computer Corp",
        "address_1": "23 Hsin Hua Rd.",
        "address_2": "Taoyuan    330",
        "country": "TW"
    },
    "001819": {
        "oui_hex": "00-18-19",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00180C": {
        "oui_hex": "00-18-0C",
        "organization": "Optelian Access Networks",
        "address_1": "22A-1051 Baxter Road",
        "address_2": "Ottawa  Ontario  K2C 3P2",
        "country": "CA"
    },
    "001810": {
        "oui_hex": "00-18-10",
        "organization": "IPTrade S.A.",
        "address_1": "Parc Scientifique",
        "address_2": "Sart-Tilman  Wallonie  4031",
        "country": "BE"
    },
    "001809": {
        "oui_hex": "00-18-09",
        "organization": "CRESYN",
        "address_1": "8-22,Jamwon-dong",
        "address_2": "Seoul  Seocho-Gu  #137-902",
        "country": "KR"
    },
    "001804": {
        "oui_hex": "00-18-04",
        "organization": "E-TEK DIGITAL TECHNOLOGY LIMITED",
        "address_1": "UNIT1520,15/F.,TOWER 2,GRAND CENTURY PLACE,193 PRINCE EDWARD ROAD WEST,KOWLOON,",
        "address_2": "",
        "country": "HK"
    },
    "001800": {
        "oui_hex": "00-18-00",
        "organization": "UNIGRAND LTD",
        "address_1": "7F-2, No.45, Jingde St., Jhonghe City,",
        "address_2": "    235",
        "country": "TW"
    },
    "0017FD": {
        "oui_hex": "00-17-FD",
        "organization": "Amulet Hotkey",
        "address_1": "Cavalier Road",
        "address_2": "Heathfield  Devon  TQ12 6TQ",
        "country": "GB"
    },
    "0017FC": {
        "oui_hex": "00-17-FC",
        "organization": "Suprema Inc.",
        "address_1": "16F Parkview Office Tower,",
        "address_2": "Seongnam  Gyeonggi  463-863",
        "country": "KR"
    },
    "0017FB": {
        "oui_hex": "00-17-FB",
        "organization": "FA",
        "address_1": "628-7, Dungchon-Dong",
        "address_2": "Seoul  Kangseo-Ku  157-838",
        "country": "KR"
    },
    "0017D8": {
        "oui_hex": "00-17-D8",
        "organization": "Magnum Semiconductor, Inc.",
        "address_1": "591 Yosemite Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0017DA": {
        "oui_hex": "00-17-DA",
        "organization": "Spans Logic",
        "address_1": "201 San Antonio Circle",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "0017CF": {
        "oui_hex": "00-17-CF",
        "organization": "iMCA-GmbH",
        "address_1": "Dorfstrasse 28b",
        "address_2": "Itzehoe  Schleswig-Holstein  25524",
        "country": "DE"
    },
    "0017B9": {
        "oui_hex": "00-17-B9",
        "organization": "Gambro Lundia AB",
        "address_1": "BOX 10101",
        "address_2": "LUND  SkÃƒÂ¥ne  22010",
        "country": "SE"
    },
    "0017B3": {
        "oui_hex": "00-17-B3",
        "organization": "Aftek Infosys Limited",
        "address_1": "Pawan Complex",
        "address_2": "Pune  Maharashtra  411 038",
        "country": "IN"
    },
    "0017A2": {
        "oui_hex": "00-17-A2",
        "organization": "Camrivox Ltd.",
        "address_1": "The Jeffreys Building",
        "address_2": "Cambridge  Cambridgeshire  CB4 0WS",
        "country": "GB"
    },
    "00175F": {
        "oui_hex": "00-17-5F",
        "organization": "XENOLINK Communications Co., Ltd.",
        "address_1": "2nd Fl., Jungyou B/D 797-22",
        "address_2": "Seoul    135-930",
        "country": "KR"
    },
    "00175C": {
        "oui_hex": "00-17-5C",
        "organization": "SHARP CORPORATION",
        "address_1": "1, Takumi-Cho,",
        "address_2": "Sakai city  Osaka Prefecture  590-8522",
        "country": "JP"
    },
    "00179D": {
        "oui_hex": "00-17-9D",
        "organization": "Kelman Limited",
        "address_1": "Rathdown Close",
        "address_2": "Lisburn  Co. Antrim  BT28 2RB",
        "country": "GB"
    },
    "001790": {
        "oui_hex": "00-17-90",
        "organization": "HYUNDAI DIGITECH Co, Ltd.",
        "address_1": "13th Fl, Choung-Jin Bldg, 53-5",
        "address_2": "Seoul    140-719",
        "country": "KR"
    },
    "001791": {
        "oui_hex": "00-17-91",
        "organization": "LinTech GmbH",
        "address_1": "Friedrich-Engels-Str. 35",
        "address_2": "Berlin    13156",
        "country": "DE"
    },
    "001795": {
        "oui_hex": "00-17-95",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001759": {
        "oui_hex": "00-17-59",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001754": {
        "oui_hex": "00-17-54",
        "organization": "Arkino HiTOP Corporation Limited",
        "address_1": "5F., No.437, Tao Ying Rd",
        "address_2": "Taoyuan City  Taoyuan County  33068,",
        "country": "TW"
    },
    "001752": {
        "oui_hex": "00-17-52",
        "organization": "DAGS, Inc",
        "address_1": "C-510, Woolim Lion's Valley, 371-28, Gasan Dong, Geumcheon Ku",
        "address_2": "Seoul    153-786",
        "country": "KR"
    },
    "001756": {
        "oui_hex": "00-17-56",
        "organization": "Vinci Labs Oy",
        "address_1": "Finlaysoninkuja 21 A",
        "address_2": "Tampere  Länsi-Suomi  33210",
        "country": "FI"
    },
    "001777": {
        "oui_hex": "00-17-77",
        "organization": "Obsidian Research Corporation",
        "address_1": "120 - 4445 Calgary Trail NW",
        "address_2": "Edmonton  Alberta  T6H 5R7",
        "country": "CA"
    },
    "00176A": {
        "oui_hex": "00-17-6A",
        "organization": "Avago Technologies",
        "address_1": "350 West Trimble Rd",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001786": {
        "oui_hex": "00-17-86",
        "organization": "wisembed",
        "address_1": "808, hansin IT tower, 235 guro3-dong, guro-gu",
        "address_2": "Seoul    152-768",
        "country": "KR"
    },
    "001782": {
        "oui_hex": "00-17-82",
        "organization": "LoBenn Inc.",
        "address_1": "150 Katimavik Road",
        "address_2": "Ottawa  Ontario  K2L 2N2",
        "country": "CA"
    },
    "001778": {
        "oui_hex": "00-17-78",
        "organization": "Central Music Co.",
        "address_1": "0711-0712 Tower D, SOHO New Town",
        "address_2": "Beijing    100022",
        "country": "CN"
    },
    "00176B": {
        "oui_hex": "00-17-6B",
        "organization": "Kiyon, Inc.",
        "address_1": "9381 Judicial Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001799": {
        "oui_hex": "00-17-99",
        "organization": "SmarTire Systems Inc.",
        "address_1": "Suite 150",
        "address_2": "Richmond  BC  V6V 2J1",
        "country": "CA"
    },
    "00177F": {
        "oui_hex": "00-17-7F",
        "organization": "Worldsmart Retech",
        "address_1": "23 Hi-Tech Court",
        "address_2": "Eight Mile Plains  QLD  4113",
        "country": "AU"
    },
    "00176E": {
        "oui_hex": "00-17-6E",
        "organization": "DUCATI SISTEMI",
        "address_1": "VIA MARCO EMILIO LEPIDO, 182",
        "address_2": "BOLOGNA    40132",
        "country": "IT"
    },
    "001774": {
        "oui_hex": "00-17-74",
        "organization": "Elesta GmbH",
        "address_1": "Gottlieb Daimler Strasse 1",
        "address_2": "Konstanz    78467",
        "country": "DE"
    },
    "00170C": {
        "oui_hex": "00-17-0C",
        "organization": "Twig Com Ltd.",
        "address_1": "Meriniitynkatu 11",
        "address_2": "  Salo  2400",
        "country": "FI"
    },
    "00170D": {
        "oui_hex": "00-17-0D",
        "organization": "Dust Networks Inc.",
        "address_1": "30695 Huntwood Ave.",
        "address_2": "Hayward  Ca.  94544",
        "country": "US"
    },
    "00170B": {
        "oui_hex": "00-17-0B",
        "organization": "Contela, Inc.",
        "address_1": "6-8 Soonae-dong, Bundang-gu,",
        "address_2": "Sungnam  Kyunggi-do  463-825",
        "country": "KR"
    },
    "00170F": {
        "oui_hex": "00-17-0F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001704": {
        "oui_hex": "00-17-04",
        "organization": "Shinco Electronics Group Co.,Ltd",
        "address_1": "No.5 Waihuan Road",
        "address_2": "Changzhou  Jiangsu  213022",
        "country": "CN"
    },
    "001707": {
        "oui_hex": "00-17-07",
        "organization": "InGrid, Inc",
        "address_1": "920 Cassatt Rd",
        "address_2": "Berwyn  Pa  19312",
        "country": "US"
    },
    "001712": {
        "oui_hex": "00-17-12",
        "organization": "ISCO International",
        "address_1": "1001 Cambridge Drive",
        "address_2": "Elk Grove Village  IL  60007",
        "country": "US"
    },
    "0016D8": {
        "oui_hex": "00-16-D8",
        "organization": "Senea AB",
        "address_1": "Företagsallen 12",
        "address_2": "Åkersberga    18484",
        "country": "SE"
    },
    "0016D6": {
        "oui_hex": "00-16-D6",
        "organization": "TDA Tech Pty Ltd",
        "address_1": "210 / 54 Currie Street",
        "address_2": "Adelaide  South Australia  5000",
        "country": "AU"
    },
    "0016D5": {
        "oui_hex": "00-16-D5",
        "organization": "Synccom Co., Ltd",
        "address_1": "#306 Myungi e-space  218-20",
        "address_2": "Anyang-si  Kyungki-do  430-817",
        "country": "KR"
    },
    "0016C9": {
        "oui_hex": "00-16-C9",
        "organization": "NAT Seattle, Inc.",
        "address_1": "22125 17th Ave SE",
        "address_2": "Bothell  WA  98021",
        "country": "US"
    },
    "0016C6": {
        "oui_hex": "00-16-C6",
        "organization": "North Atlantic Industries",
        "address_1": "170 Wilbur Place",
        "address_2": "Bohemia  NY  11716",
        "country": "US"
    },
    "001724": {
        "oui_hex": "00-17-24",
        "organization": "Studer Professional Audio GmbH",
        "address_1": "Althardstrasse 30",
        "address_2": "Regensdorf  Zürich  CH-8105",
        "country": "CH"
    },
    "001702": {
        "oui_hex": "00-17-02",
        "organization": "Osung Midicom Co., Ltd",
        "address_1": "231-18, Dorim2-dong,",
        "address_2": "Seoul,  Youngdeungpo-gu  150-832",
        "country": "KR"
    },
    "0016F7": {
        "oui_hex": "00-16-F7",
        "organization": "L-3 Communications, Aviation Recorders",
        "address_1": "100 Cattlemen Rd.",
        "address_2": "Sarasota  FL  34232",
        "country": "US"
    },
    "00172D": {
        "oui_hex": "00-17-2D",
        "organization": "Axcen Photonics Corporation",
        "address_1": "6F, No. 119, Baujung Rd.,",
        "address_2": "Shindian City, Taipei    231",
        "country": "TW"
    },
    "001741": {
        "oui_hex": "00-17-41",
        "organization": "DEFIDEV",
        "address_1": "20 rue Raymond Marcheron",
        "address_2": "Vanves    92170",
        "country": "FR"
    },
    "001738": {
        "oui_hex": "00-17-38",
        "organization": "International Business Machines",
        "address_1": "1 Azrieli Center",
        "address_2": "Tel Aviv    67021",
        "country": "IL"
    },
    "00171E": {
        "oui_hex": "00-17-1E",
        "organization": "Theo Benning GmbH & Co. KG",
        "address_1": "Muensterstraße 135-137",
        "address_2": "Bocholt  NRW  46397",
        "country": "DE"
    },
    "0016D2": {
        "oui_hex": "00-16-D2",
        "organization": "Caspian",
        "address_1": "170 Baytech Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0016A4": {
        "oui_hex": "00-16-A4",
        "organization": "Ezurio Ltd",
        "address_1": "Unit 2",
        "address_2": "London    NW9 5HD",
        "country": "GB"
    },
    "001699": {
        "oui_hex": "00-16-99",
        "organization": "Tonic DVB Marketing Ltd",
        "address_1": "Unit B, 10/F, Summit Building,",
        "address_2": "Hung Hom  Kowloon",
        "country": "HK"
    },
    "00169B": {
        "oui_hex": "00-16-9B",
        "organization": "Alstom Transport",
        "address_1": "11, 13 avenue de Bel Air",
        "address_2": "Villeurbanne  Rhone  69100",
        "country": "FR"
    },
    "001690": {
        "oui_hex": "00-16-90",
        "organization": "J-TEK INCORPORATION",
        "address_1": "2F-1, No. 83, Sec. 2, GongDaoWu Rd.,",
        "address_2": "Hsinchu City    30070",
        "country": "TW"
    },
    "001693": {
        "oui_hex": "00-16-93",
        "organization": "PowerLink Technology Inc.",
        "address_1": "N0. 18, Alley 1, Lane 151, Sec. 1, Jhongsing Rd., Wugu Township",
        "address_2": "Taipei Hsien    248",
        "country": "TW"
    },
    "001698": {
        "oui_hex": "00-16-98",
        "organization": "T&A Mobile Phones",
        "address_1": "4/F, South Building,No.2966, Jinke Road",
        "address_2": "Pudong  Shanghai  201203",
        "country": "CN"
    },
    "001662": {
        "oui_hex": "00-16-62",
        "organization": "Liyuh Technology Ltd.",
        "address_1": "4F, No.19, Ln.221, Ganqian Rd., Neihu District",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001661": {
        "oui_hex": "00-16-61",
        "organization": "Novatium Solutions (P) Ltd",
        "address_1": "3rd Floor, Temple Towers, #672",
        "address_2": "Chennai  Tamil Nadu  600035",
        "country": "IN"
    },
    "001664": {
        "oui_hex": "00-16-64",
        "organization": "Prod-El SpA",
        "address_1": "Via Palmanova 185",
        "address_2": "Milano  MI  20132",
        "country": "IT"
    },
    "00165E": {
        "oui_hex": "00-16-5E",
        "organization": "Precision I/O",
        "address_1": "4005 Miranda Ave., Suite 210",
        "address_2": "Palo Alto  CA  94304-1232",
        "country": "US"
    },
    "001658": {
        "oui_hex": "00-16-58",
        "organization": "Fusiontech Technologies Inc.",
        "address_1": "6F, No.78, Cheng Kung Rd., Sec. 1,",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "0016A5": {
        "oui_hex": "00-16-A5",
        "organization": "Tandberg Storage ASA",
        "address_1": "Postboks 191",
        "address_2": "",
        "country": "NO"
    },
    "0016A1": {
        "oui_hex": "00-16-A1",
        "organization": "3Leaf Networks",
        "address_1": "3255-1 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001666": {
        "oui_hex": "00-16-66",
        "organization": "Quantier Communication Inc.",
        "address_1": "1F, No. 36, Industry E. Rd IV,",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "001681": {
        "oui_hex": "00-16-81",
        "organization": "Vector Informatik GmbH",
        "address_1": "Ingersheimer Str. 24",
        "address_2": "Stuttgart  Baden-Württemberg  70499",
        "country": "DE"
    },
    "00BAC0": {
        "oui_hex": "00-BA-C0",
        "organization": "Biometric Access Company",
        "address_1": "2555 North IH 35",
        "address_2": "Round Rock  Texas  78664",
        "country": "US"
    },
    "001685": {
        "oui_hex": "00-16-85",
        "organization": "Elisa Oyj",
        "address_1": "Elektroniikkatie 4",
        "address_2": "90570  Oulu",
        "country": "FI"
    },
    "001680": {
        "oui_hex": "00-16-80",
        "organization": "Bally Gaming + Systems",
        "address_1": "950 Sandhill Road",
        "address_2": "Reno  NV  89521",
        "country": "US"
    },
    "001696": {
        "oui_hex": "00-16-96",
        "organization": "QDI Technology (H.K.) Limited",
        "address_1": "16/F, Standard Chartered Bank Building 4-4A",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "0016BE": {
        "oui_hex": "00-16-BE",
        "organization": "INFRANET, Inc.",
        "address_1": "8th Floor, Cowell B/D, 66-1",
        "address_2": "Seoul    137-040",
        "country": "KR"
    },
    "0016AB": {
        "oui_hex": "00-16-AB",
        "organization": "Dansensor A/S",
        "address_1": "Roennedevej 18",
        "address_2": "Ringsted    DK-4100",
        "country": "DK"
    },
    "001653": {
        "oui_hex": "00-16-53",
        "organization": "LEGO System A/S IE Electronics Division",
        "address_1": "Aastvej 1",
        "address_2": "  Billund Kommune  7190",
        "country": "DK"
    },
    "001652": {
        "oui_hex": "00-16-52",
        "organization": "Hoatech Technologies, Inc.",
        "address_1": "1F., No.224, Guosheng St.",
        "address_2": "Zhubei  HsinChu Hsien  30244",
        "country": "TW"
    },
    "001650": {
        "oui_hex": "00-16-50",
        "organization": " Kratos EPD",
        "address_1": "Herley General Microwave Israel.",
        "address_2": "KIBBUTZ EYAL    45840",
        "country": "IL"
    },
    "0015FA": {
        "oui_hex": "00-15-FA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0015FC": {
        "oui_hex": "00-15-FC",
        "organization": "Littelfuse Startco",
        "address_1": "3714 Kinnear Place",
        "address_2": "Saskatoon  SK  S7P 0A6",
        "country": "CA"
    },
    "0015F7": {
        "oui_hex": "00-15-F7",
        "organization": "Wintecronics Ltd.",
        "address_1": "No. 716, 11F-3, Jung Jeng Rd.",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001630": {
        "oui_hex": "00-16-30",
        "organization": "Vativ Technologies",
        "address_1": "9339 Genesee Avenue",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00162F": {
        "oui_hex": "00-16-2F",
        "organization": "Geutebrück GmbH",
        "address_1": "Im Nassen 7-9",
        "address_2": "Windhagen    53578",
        "country": "DE"
    },
    "00162B": {
        "oui_hex": "00-16-2B",
        "organization": "Togami Electric Mfg.co.,Ltd.",
        "address_1": "1-1 Ohtakara-Kitamachi",
        "address_2": "  Saga.PRF  840-0802",
        "country": "JP"
    },
    "001642": {
        "oui_hex": "00-16-42",
        "organization": "Pangolin",
        "address_1": "9501 Satellite Boulevard, Suite 109",
        "address_2": "Orlando  FL  32837",
        "country": "US"
    },
    "00163B": {
        "oui_hex": "00-16-3B",
        "organization": "VertexRSI/General Dynamics",
        "address_1": "2120 Old Gatesburg Rd.",
        "address_2": "State college  PA  16803",
        "country": "US"
    },
    "001637": {
        "oui_hex": "00-16-37",
        "organization": "CITEL SpA",
        "address_1": "Via L. G. Columella, 36",
        "address_2": "Milan  MI  20128",
        "country": "IT"
    },
    "001608": {
        "oui_hex": "00-16-08",
        "organization": "Sequans Communications",
        "address_1": "19 Le Parvis de la Défense",
        "address_2": "  PARIS LA DEFENSE CEDEX  92073",
        "country": "FR"
    },
    "001624": {
        "oui_hex": "00-16-24",
        "organization": "Teneros, Inc.",
        "address_1": "215 Castro St.",
        "address_2": "Mt. View  CA  94041",
        "country": "US"
    },
    "0015F8": {
        "oui_hex": "00-15-F8",
        "organization": "Kingtronics Industrial Co. Ltd.",
        "address_1": "Penthouse, Century Centre,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "00161C": {
        "oui_hex": "00-16-1C",
        "organization": "e:cue",
        "address_1": "Friedrich-List-Strasse 23",
        "address_2": "Paderborn    33100",
        "country": "DE"
    },
    "0015B8": {
        "oui_hex": "00-15-B8",
        "organization": "Tahoe",
        "address_1": "ul. Uniwersytecka 1",
        "address_2": "Wroclaw    50951",
        "country": "PL"
    },
    "0015B6": {
        "oui_hex": "00-15-B6",
        "organization": "ShinMaywa Industries, Ltd.",
        "address_1": "1-1 Shinmeiwa-cho",
        "address_2": "Takarazuka  Hyogo  665-8550",
        "country": "JP"
    },
    "0015B0": {
        "oui_hex": "00-15-B0",
        "organization": "AUTOTELENET CO.,LTD",
        "address_1": "2F, 898-24, Hogye2-dong, Dongan-gu",
        "address_2": "Anyang-City  Kyunggi-do  431-836",
        "country": "KR"
    },
    "0015B1": {
        "oui_hex": "00-15-B1",
        "organization": "Ambient Corporation",
        "address_1": "79 Chapel St.",
        "address_2": "Newton  MA  02458",
        "country": "US"
    },
    "00159F": {
        "oui_hex": "00-15-9F",
        "organization": "Terascala, Inc.",
        "address_1": "145 Bodwell Street",
        "address_2": "Avon  MA  02322",
        "country": "US"
    },
    "00159E": {
        "oui_hex": "00-15-9E",
        "organization": "Mad Catz Interactive Inc",
        "address_1": "Units 3+4 West Point Row",
        "address_2": "Bristol  South Gloucestershire  BS32 4QG",
        "country": "US"
    },
    "0015A1": {
        "oui_hex": "00-15-A1",
        "organization": "ECA-SINTERS",
        "address_1": "5, rue Paul Mesplé",
        "address_2": "TOULOUSE  Cedex 01  31106",
        "country": "FR"
    },
    "001593": {
        "oui_hex": "00-15-93",
        "organization": "U4EA Technologies Inc.",
        "address_1": "48860 Milmont Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "001581": {
        "oui_hex": "00-15-81",
        "organization": "MAKUS Inc.",
        "address_1": "4F Daedo Bldg. 748-14 Yeoksam-dong, Kangnam-gu",
        "address_2": "  Seoul  135-080",
        "country": "US"
    },
    "00157A": {
        "oui_hex": "00-15-7A",
        "organization": "Telefin S.p.A.",
        "address_1": "Via Albere 87/A",
        "address_2": "Verona  VR  37138",
        "country": "IT"
    },
    "0015C3": {
        "oui_hex": "00-15-C3",
        "organization": "Ruf Telematik AG",
        "address_1": "Ruetistrasse 13",
        "address_2": "Schlieren  ZH  8952",
        "country": "CH"
    },
    "0015E6": {
        "oui_hex": "00-15-E6",
        "organization": "MOBILE TECHNIKA Inc.",
        "address_1": "Sotobori Sky Bld. 5th Floor",
        "address_2": "Shinjuku-ku  Tokyo  162-0845",
        "country": "JP"
    },
    "0015DB": {
        "oui_hex": "00-15-DB",
        "organization": "Canesta Inc.",
        "address_1": "965 West Maude Avenue",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "00158D": {
        "oui_hex": "00-15-8D",
        "organization": "Jennic Ltd",
        "address_1": "Furnival Street",
        "address_2": "Sheffield  Yorkshire  S1 4QT",
        "country": "US"
    },
    "001584": {
        "oui_hex": "00-15-84",
        "organization": "Schenck Process GmbH",
        "address_1": "Pallaswiesenstraße 100",
        "address_2": "Darmstadt  Hessen  64293",
        "country": "DE"
    },
    "0015CC": {
        "oui_hex": "00-15-CC",
        "organization": "UQUEST, LTD.",
        "address_1": "Sannomiya Intes Bldg. 8F",
        "address_2": "KOBE  HYOGO  651-0086",
        "country": "JP"
    },
    "0015C6": {
        "oui_hex": "00-15-C6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0015D7": {
        "oui_hex": "00-15-D7",
        "organization": "Reti Corporation",
        "address_1": "6F,No 13, Lane 120, Sec 1, Neihu Rd.,",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "0015CB": {
        "oui_hex": "00-15-CB",
        "organization": "Surf Communication Solutions Ltd.",
        "address_1": "P.O. Box 343",
        "address_2": "Yokneam    20164",
        "country": "IL"
    },
    "0015A7": {
        "oui_hex": "00-15-A7",
        "organization": "Robatech AG",
        "address_1": "Pilatusring 10",
        "address_2": "Muri  AG  5630",
        "country": "CH"
    },
    "001523": {
        "oui_hex": "00-15-23",
        "organization": "Meteor Communications Corporation",
        "address_1": "22614 66th Avenue South",
        "address_2": "Kent  WA  98032",
        "country": "US"
    },
    "001524": {
        "oui_hex": "00-15-24",
        "organization": "Numatics, Inc.",
        "address_1": "46280 Dylan Dr.",
        "address_2": "Novi  Michigan  48377",
        "country": "US"
    },
    "00151B": {
        "oui_hex": "00-15-1B",
        "organization": "Isilon Systems Inc.",
        "address_1": "3101 Western Avenue",
        "address_2": "Seattle  WA  98121",
        "country": "US"
    },
    "001573": {
        "oui_hex": "00-15-73",
        "organization": "NewSoft  Technology Corporation",
        "address_1": "3F, 19-3, SanChong RD, NanKang,",
        "address_2": "Taipei    115",
        "country": "US"
    },
    "001575": {
        "oui_hex": "00-15-75",
        "organization": "Nevis Networks Inc.",
        "address_1": "3945 Freedom Circle",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00156C": {
        "oui_hex": "00-15-6C",
        "organization": "SANE SYSTEM CO., LTD",
        "address_1": "0-2 Heungan-daero 439 beon-gil Dongan-gu",
        "address_2": "Anyang-si  Kyunggi-do  431-804",
        "country": "KR"
    },
    "00156A": {
        "oui_hex": "00-15-6A",
        "organization": "DG2L Technologies Pvt. Ltd.",
        "address_1": "AML Center 1, Gnd. Floor, 8 Mahal Indl. Est.",
        "address_2": "Mumbai  Maharashtra  400093",
        "country": "IN"
    },
    "001529": {
        "oui_hex": "00-15-29",
        "organization": "N3 Corporation",
        "address_1": "#402 GwangMyeong Techno Town",
        "address_2": "GyeongGi-Do    423-031",
        "country": "KR"
    },
    "00152D": {
        "oui_hex": "00-15-2D",
        "organization": "TenX Networks, LLC",
        "address_1": "4855 Wiley Post Way",
        "address_2": "Salt Lake City  UT  84116",
        "country": "US"
    },
    "00156F": {
        "oui_hex": "00-15-6F",
        "organization": "Xiranet Communications GmbH",
        "address_1": "Bertolt-Brecht-Allee 24",
        "address_2": "Dresden  Saxony  01309",
        "country": "US"
    },
    "001572": {
        "oui_hex": "00-15-72",
        "organization": "Red-Lemon",
        "address_1": "Unit 4, 9/F, Paramount Building",
        "address_2": "Chai Wan",
        "country": "HK"
    },
    "001567": {
        "oui_hex": "00-15-67",
        "organization": "RADWIN Inc.",
        "address_1": "900 Corporate Drive",
        "address_2": "Mahwah  NJ  07430",
        "country": "US"
    },
    "00155B": {
        "oui_hex": "00-15-5B",
        "organization": "Sampo Corporation",
        "address_1": "216 Chung Shan Road,",
        "address_2": "  Taipei Hsien  220",
        "country": "TW"
    },
    "001553": {
        "oui_hex": "00-15-53",
        "organization": "Cytyc Corporation",
        "address_1": "250 Campus Dive",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "001551": {
        "oui_hex": "00-15-51",
        "organization": "RadioPulse Inc.",
        "address_1": "2nd fl. Hans B/D, 111-55",
        "address_2": "Seoul    134-883",
        "country": "KR"
    },
    "001552": {
        "oui_hex": "00-15-52",
        "organization": "Wi-Gear Inc.",
        "address_1": "340 Church Street",
        "address_2": "San Francisco  CA  94114",
        "country": "US"
    },
    "00153E": {
        "oui_hex": "00-15-3E",
        "organization": "Q-Matic Sweden AB",
        "address_1": "Neongatan 8",
        "address_2": "Molndal    431 53",
        "country": "SE"
    },
    "001542": {
        "oui_hex": "00-15-42",
        "organization": "MICROHARD S.R.L.",
        "address_1": "Via Primo Maggio 36",
        "address_2": "San Vittore Olona  Milano  20028",
        "country": "IT"
    },
    "00154E": {
        "oui_hex": "00-15-4E",
        "organization": "IEC",
        "address_1": "3, rue de Varembé",
        "address_2": "CH - 1211  GENEVA  20",
        "country": "DE"
    },
    "001550": {
        "oui_hex": "00-15-50",
        "organization": "Nits Technology Inc",
        "address_1": "2FL. No. 8 Alley 16, Lane 235, Bauchiau Rd.,",
        "address_2": "Shindian City  Taipei Hsien  231",
        "country": "TW"
    },
    "001546": {
        "oui_hex": "00-15-46",
        "organization": "ITG Worldwide Sdn Bhd",
        "address_1": "2, Jalan AstakaU8/83",
        "address_2": "Shah Alam  Selangor Darul Ehsan  40150",
        "country": "MY"
    },
    "00155D": {
        "oui_hex": "00-15-5D",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  WA  98052-8300",
        "country": "US"
    },
    "001562": {
        "oui_hex": "00-15-62",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0014E1": {
        "oui_hex": "00-14-E1",
        "organization": "Data Display AG",
        "address_1": "Industriestraße 1",
        "address_2": "Germering  Bayern  82110",
        "country": "DE"
    },
    "0014E3": {
        "oui_hex": "00-14-E3",
        "organization": "mm-lab GmbH",
        "address_1": "Stammheimer Strasse 10",
        "address_2": "Kornwestheim",
        "country": "DE"
    },
    "0014D9": {
        "oui_hex": "00-14-D9",
        "organization": "IP Fabrics, Inc.",
        "address_1": "3720 SW 141st Avenue",
        "address_2": "Beaverton  Oregon  97006",
        "country": "US"
    },
    "0014D6": {
        "oui_hex": "00-14-D6",
        "organization": "Jeongmin Electronics Co.,Ltd.",
        "address_1": "#710, Byuksan Digital Valley 2,",
        "address_2": "Seoul    153 783",
        "country": "KR"
    },
    "0014F9": {
        "oui_hex": "00-14-F9",
        "organization": "Vantage Controls",
        "address_1": "1061 South 800 East",
        "address_2": "Orem  UT  84097",
        "country": "US"
    },
    "0014E7": {
        "oui_hex": "00-14-E7",
        "organization": "Stolinx,. Inc",
        "address_1": "3F Ohchang Bldg., 61 Yangjae-dong",
        "address_2": "Seoul    137-889",
        "country": "KR"
    },
    "0014E9": {
        "oui_hex": "00-14-E9",
        "organization": "Nortech International",
        "address_1": "32A Wiganthorpe Road",
        "address_2": "Pietermartizburg  KwaZulu Natal  3201",
        "country": "ZA"
    },
    "0014ED": {
        "oui_hex": "00-14-ED",
        "organization": "Airak, Inc.",
        "address_1": "21641 Beaumeade Circle",
        "address_2": "Ashburn  Virginia  20147",
        "country": "US"
    },
    "0014CE": {
        "oui_hex": "00-14-CE",
        "organization": "NF CORPORATION",
        "address_1": "6-3-20, Tsunashima-higashi",
        "address_2": "Yokohama  Kanagawa  223-8508",
        "country": "JP"
    },
    "0014D0": {
        "oui_hex": "00-14-D0",
        "organization": "BTI Systems Inc.",
        "address_1": "50 Northside Road",
        "address_2": "Ottawa  Ontario  K2H 5Z6",
        "country": "CA"
    },
    "001503": {
        "oui_hex": "00-15-03",
        "organization": "PROFIcomms s.r.o.",
        "address_1": "Turgenevova 5",
        "address_2": "Brno  EU/Europe  618 00",
        "country": "CZ"
    },
    "001509": {
        "oui_hex": "00-15-09",
        "organization": "Plus Technology Co., Ltd",
        "address_1": "Office #205,  Gayang Techno-town,",
        "address_2": "  Seoul  157-810",
        "country": "KR"
    },
    "0014F0": {
        "oui_hex": "00-14-F0",
        "organization": "Business Security OL AB",
        "address_1": "Box 110 65",
        "address_2": "Lund    220 11",
        "country": "SE"
    },
    "0014F2": {
        "oui_hex": "00-14-F2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001510": {
        "oui_hex": "00-15-10",
        "organization": "Techsphere Co., Ltd",
        "address_1": "4F, Wonil Bldg., 980-54, Bangbae-dong, SeoCho-gu",
        "address_2": "  Seoul  137-060",
        "country": "KR"
    },
    "001513": {
        "oui_hex": "00-15-13",
        "organization": "EFS sas",
        "address_1": "BP 34",
        "address_2": "MILLERY    F-69390",
        "country": "US"
    },
    "00148B": {
        "oui_hex": "00-14-8B",
        "organization": "Globo Electronic GmbH & Co. KG",
        "address_1": "Industriestrasse 4a",
        "address_2": "Niederlauer  Bayern  97618",
        "country": "DE"
    },
    "001490": {
        "oui_hex": "00-14-90",
        "organization": "ASP Corporation",
        "address_1": "465 Industrial Park Road",
        "address_2": "Hartwell  GA  30643",
        "country": "US"
    },
    "001484": {
        "oui_hex": "00-14-84",
        "organization": "Cermate Technologies Inc.",
        "address_1": "7F-1, No 168 Lien-Chen Rd.",
        "address_2": "Chung-Ho Dist  New Taipei City",
        "country": "TW"
    },
    "001479": {
        "oui_hex": "00-14-79",
        "organization": "NEC Magnus Communications,Ltd.",
        "address_1": " 22-23, Kaigan 3-chome",
        "address_2": "Minato-ku  Tokyo  108-0022",
        "country": "JP"
    },
    "00147B": {
        "oui_hex": "00-14-7B",
        "organization": "Iteris, Inc.",
        "address_1": "1515 S. Manchester Ave.",
        "address_2": "Anaheim  CA  92802",
        "country": "US"
    },
    "0014BB": {
        "oui_hex": "00-14-BB",
        "organization": "Open Interface North America",
        "address_1": "506 2nd Avenue, Suite 420",
        "address_2": "Seattle  WA  98104",
        "country": "US"
    },
    "001470": {
        "oui_hex": "00-14-70",
        "organization": "Prokom Software SA",
        "address_1": "Al. Jerozolimskie 65/79",
        "address_2": "Warszawa  Mazowieckie  00-697",
        "country": "PL"
    },
    "001467": {
        "oui_hex": "00-14-67",
        "organization": "ArrowSpan Inc.",
        "address_1": "4699 Old Ironsides Dr. Suite 100",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00145F": {
        "oui_hex": "00-14-5F",
        "organization": "ADITEC CO. LTD",
        "address_1": "4F Hyowon B/D, 99-5,",
        "address_2": "  Seoul  138-805",
        "country": "KR"
    },
    "001488": {
        "oui_hex": "00-14-88",
        "organization": "Akorri",
        "address_1": "11 Falcon Ridge Dr",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "00147A": {
        "oui_hex": "00-14-7A",
        "organization": "Eubus GmbH",
        "address_1": "Gollierstraße 70  Aufgang E  4.Stock",
        "address_2": "Munich  Bavaria  80339",
        "country": "DE"
    },
    "00146D": {
        "oui_hex": "00-14-6D",
        "organization": "RF Technologies",
        "address_1": "3125 N 126th Street",
        "address_2": "Brookfield  WI  53005",
        "country": "US"
    },
    "0014AC": {
        "oui_hex": "00-14-AC",
        "organization": "Bountiful WiFi",
        "address_1": "707 West 700 South",
        "address_2": "Woods Cross  Utah  84087",
        "country": "US"
    },
    "0014A8": {
        "oui_hex": "00-14-A8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0014A0": {
        "oui_hex": "00-14-A0",
        "organization": "Accsense, Inc.",
        "address_1": "460 Ward Drive",
        "address_2": "Santa Barbara  California  93111",
        "country": "US"
    },
    "001459": {
        "oui_hex": "00-14-59",
        "organization": "Moram Co., Ltd.",
        "address_1": "3F, Manwol Bldg., 1022-4",
        "address_2": "Suwon-shi  Gyounggi-do  443-813",
        "country": "KR"
    },
    "001457": {
        "oui_hex": "00-14-57",
        "organization": "T-VIPS AS",
        "address_1": "Ostensjoveien 18",
        "address_2": "  Oslo  NO-0661",
        "country": "NO"
    },
    "001453": {
        "oui_hex": "00-14-53",
        "organization": "ADVANTECH TECHNOLOGIES CO.,LTD",
        "address_1": "#1202 ACE TECHNO TOWER, 684-1",
        "address_2": "  Seoul  157-721",
        "country": "KR"
    },
    "001454": {
        "oui_hex": "00-14-54",
        "organization": "Symwave",
        "address_1": "10251 Vista Sorrento Parkway",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0013F8": {
        "oui_hex": "00-13-F8",
        "organization": "Dex Security Solutions",
        "address_1": "10 Junction Road Parktown",
        "address_2": "Johannesburg  Guteng  2000",
        "country": "ZA"
    },
    "0013F9": {
        "oui_hex": "00-13-F9",
        "organization": "Cavera Systems",
        "address_1": "2355 Oakland Rd, Suite#33",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0013F2": {
        "oui_hex": "00-13-F2",
        "organization": "Klas Ltd",
        "address_1": "Bracetown Business Park",
        "address_2": "Clonee  Co Meath",
        "country": "IE"
    },
    "0013F7": {
        "oui_hex": "00-13-F7",
        "organization": "SMC Networks, Inc.",
        "address_1": "38 Tesla",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "00144B": {
        "oui_hex": "00-14-4B",
        "organization": "Hifn, Inc.",
        "address_1": "750 University Ave",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "001441": {
        "oui_hex": "00-14-41",
        "organization": "Innovation Sound Technology Co., LTD.",
        "address_1": "Building 2th.,Cuihai Industrial Area,",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "00143C": {
        "oui_hex": "00-14-3C",
        "organization": "Rheinmetall Canada Inc.",
        "address_1": "225 boul du seminaire sud",
        "address_2": "St-Jean-sur-Richelieu  Quebec  J3B 8E9",
        "country": "CA"
    },
    "00141A": {
        "oui_hex": "00-14-1A",
        "organization": "DEICY CORPORATION",
        "address_1": "3-3-6,Sakae-cho,Hamura-shi,",
        "address_2": "  Tokyo  205-0002",
        "country": "JP"
    },
    "00141C": {
        "oui_hex": "00-14-1C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00140C": {
        "oui_hex": "00-14-0C",
        "organization": "GKB CCTV CO., LTD.",
        "address_1": "7F, No. 1, Lane 641,",
        "address_2": "Ta Ya Hsiang,  TAICHUNG  428",
        "country": "TW"
    },
    "0013FE": {
        "oui_hex": "00-13-FE",
        "organization": "GRANDTEC ELECTRONIC CORP.",
        "address_1": "8F,NO.268,Lian Cheng Rd.,Chung Ho City,",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "001435": {
        "oui_hex": "00-14-35",
        "organization": "CityCom Corp.",
        "address_1": "3F., No.532, Sec. 2,",
        "address_2": "Jhonghe City  Taipei Hsien  23557",
        "country": "TW"
    },
    "001448": {
        "oui_hex": "00-14-48",
        "organization": "Inventec Multimedia & Telecom Corporation",
        "address_1": "5F,NO.396,Sec.1 Nei-Hu Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001416": {
        "oui_hex": "00-14-16",
        "organization": "Scosche Industries, Inc.",
        "address_1": "PO Box 2901",
        "address_2": "Oxnard  CA  93034",
        "country": "US"
    },
    "001426": {
        "oui_hex": "00-14-26",
        "organization": "NL Technology",
        "address_1": "800 Turnpike Street",
        "address_2": "North Andover  MA  01845",
        "country": "US"
    },
    "0013C5": {
        "oui_hex": "00-13-C5",
        "organization": "LIGHTRON FIBER-OPTIC DEVICES INC.",
        "address_1": "51-1 Moonpyung-Dong, Taeduck-Gu",
        "address_2": "  Taejon  306-220",
        "country": "KR"
    },
    "0013C4": {
        "oui_hex": "00-13-C4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0013C2": {
        "oui_hex": "00-13-C2",
        "organization": "WACOM Co.,Ltd",
        "address_1": "2-510-1 Toyonodai Otone-machi",
        "address_2": "Kitasaitama-gun  Saitama  349-1148",
        "country": "JP"
    },
    "0013BF": {
        "oui_hex": "00-13-BF",
        "organization": "Media System Planning Corp.",
        "address_1": "4F Velco-Kuromon Bldg.",
        "address_2": "Taito-ku,  Tokyo  110-0005",
        "country": "JP"
    },
    "0013BB": {
        "oui_hex": "00-13-BB",
        "organization": "Smartvue Corporation",
        "address_1": "102 Woodmont Boulevard",
        "address_2": "Nashville  TN  37205",
        "country": "US"
    },
    "0013B5": {
        "oui_hex": "00-13-B5",
        "organization": "Wavesat",
        "address_1": "1375, Trans-Canada Highway",
        "address_2": "Dorval  Quebec  H9P 2W8",
        "country": "CA"
    },
    "0013AF": {
        "oui_hex": "00-13-AF",
        "organization": "NUMA Technology,Inc.",
        "address_1": "4F,No778,Sec 4,Patch Rd.",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "0013B0": {
        "oui_hex": "00-13-B0",
        "organization": "Jablotron",
        "address_1": "Pod Skalkou 33",
        "address_2": "Jablonec nad Nisou    46601",
        "country": "CZ"
    },
    "00139A": {
        "oui_hex": "00-13-9A",
        "organization": "K-ubique ID Corp.",
        "address_1": "Yamasan Bldg.8F,",
        "address_2": "Chuo-ku  Tokyo  103-0023",
        "country": "JP"
    },
    "00139E": {
        "oui_hex": "00-13-9E",
        "organization": "Ciara Technologies Inc.",
        "address_1": "9300 Trans Canada Highway",
        "address_2": "Saint-Laurent  Quebec  H4S 1K5",
        "country": "CA"
    },
    "00139D": {
        "oui_hex": "00-13-9D",
        "organization": "MaxLinear Hispania S.L.U.",
        "address_1": "Ronda Narcis Monturiol",
        "address_2": "Estarriol, 11D  Paterna  46980",
        "country": "ES"
    },
    "0013D5": {
        "oui_hex": "00-13-D5",
        "organization": "RuggedCom",
        "address_1": "300 Applewood Crescent (Unit 1)",
        "address_2": "Concord,   Ontario  L4K 5C7",
        "country": "CA"
    },
    "0013D6": {
        "oui_hex": "00-13-D6",
        "organization": "TII NETWORK TECHNOLOGIES, INC.",
        "address_1": "1385 AKRON STREET",
        "address_2": "COPIAGUE  NY  11726",
        "country": "US"
    },
    "0013DB": {
        "oui_hex": "00-13-DB",
        "organization": "SHOEI Electric Co.,Ltd",
        "address_1": "1-29-2,Wakabayashi",
        "address_2": "Setagaya-ku  Tokyo  154-0023",
        "country": "JP"
    },
    "0013CD": {
        "oui_hex": "00-13-CD",
        "organization": "MTI co. LTD",
        "address_1": "166-10 Karak-dong",
        "address_2": "Songpa-ku  Seoul  138-810",
        "country": "KR"
    },
    "0013D3": {
        "oui_hex": "00-13-D3",
        "organization": "MICRO-STAR INTERNATIONAL CO., LTD.",
        "address_1": "NO. 69, LI-DE ST.",
        "address_2": "JUNG-HE CITY  TAIPEI HSIEN  235",
        "country": "TW"
    },
    "0013CA": {
        "oui_hex": "00-13-CA",
        "organization": "Pico Digital",
        "address_1": "6260 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0013E6": {
        "oui_hex": "00-13-E6",
        "organization": "Technolution",
        "address_1": "Zuidelijkhalfrond 1",
        "address_2": "GOUDA  ZH  2801 DD",
        "country": "NL"
    },
    "0013DF": {
        "oui_hex": "00-13-DF",
        "organization": "Ryvor Corp.",
        "address_1": "15145 Red Hill Ave.",
        "address_2": "Tustin  CA  92780",
        "country": "US"
    },
    "00138D": {
        "oui_hex": "00-13-8D",
        "organization": "Kinghold",
        "address_1": "11F, No. 965, Jungjeng Rd.",
        "address_2": "Junghe  Taipei  235",
        "country": "TW"
    },
    "0013ED": {
        "oui_hex": "00-13-ED",
        "organization": "PSIA",
        "address_1": "517-13 Induspis 5th",
        "address_2": "SungNam  KyungGi",
        "country": "KR"
    },
    "0013B1": {
        "oui_hex": "00-13-B1",
        "organization": "Intelligent Control Systems (Asia) Pte Ltd",
        "address_1": "70 Ubi Crescent #01-12",
        "address_2": "    408570",
        "country": "SG"
    },
    "00133C": {
        "oui_hex": "00-13-3C",
        "organization": "QUINTRON SYSTEMS INC.",
        "address_1": "2105 SO. BLOSSER ROAD",
        "address_2": "SANTA MARIA  CALIFORNIA  93458",
        "country": "US"
    },
    "00133D": {
        "oui_hex": "00-13-3D",
        "organization": "Micro Memory Curtiss Wright Co",
        "address_1": "9540 Vassar Avenue",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "00133F": {
        "oui_hex": "00-13-3F",
        "organization": "Eppendorf Instrumente GmbH",
        "address_1": "Barkhausenweg 1",
        "address_2": "Hamburg  DE  22339",
        "country": "DE"
    },
    "001341": {
        "oui_hex": "00-13-41",
        "organization": "Shandong New Beiyang Information Technology Co.,Ltd",
        "address_1": "NO.11 Xinwei Road",
        "address_2": "Weihai city  Shandong  264200",
        "country": "CN"
    },
    "001330": {
        "oui_hex": "00-13-30",
        "organization": "EURO PROTECTION SURVEILLANCE",
        "address_1": "30 Rue du Doubs",
        "address_2": "STRASBOURG    67100",
        "country": "FR"
    },
    "001325": {
        "oui_hex": "00-13-25",
        "organization": "Cortina Systems Inc",
        "address_1": "840 W California Ave, Suite 100",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "001331": {
        "oui_hex": "00-13-31",
        "organization": "CellPoint Connect",
        "address_1": "Billedvej 4",
        "address_2": "Copenhagen    2100",
        "country": "DK"
    },
    "001335": {
        "oui_hex": "00-13-35",
        "organization": "VS Industry Berhad",
        "address_1": "Plo 47, Senai Ind. Est. II,",
        "address_2": "Senai  Johor  81400",
        "country": "MY"
    },
    "00132F": {
        "oui_hex": "00-13-2F",
        "organization": "Interactek",
        "address_1": "Sigmal 2 BLDG #C-319, 18 Kumi-dong",
        "address_2": "Seongnam  Kyung-gi  463-741",
        "country": "KR"
    },
    "00134C": {
        "oui_hex": "00-13-4C",
        "organization": "YDT Technology International",
        "address_1": "2F., No.218, Rueiguang Rd.,",
        "address_2": "Taipei,    114",
        "country": "TW"
    },
    "001359": {
        "oui_hex": "00-13-59",
        "organization": "ProTelevision Technologies A/S",
        "address_1": "Marielundvej 16,2",
        "address_2": "Herlev  Copenhagen  2730",
        "country": "DK"
    },
    "001350": {
        "oui_hex": "00-13-50",
        "organization": "Silver Spring Networks, Inc",
        "address_1": "575 Broadway Street",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "00137F": {
        "oui_hex": "00-13-7F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001382": {
        "oui_hex": "00-13-82",
        "organization": "Cetacea Networks Corporation",
        "address_1": "3708 West 36th Avenue",
        "address_2": "Vancouver  British Columbia  V6N 2S4",
        "country": "CA"
    },
    "001390": {
        "oui_hex": "00-13-90",
        "organization": "Termtek Computer Co., Ltd",
        "address_1": "2F, No. 100, Li De St.,",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001375": {
        "oui_hex": "00-13-75",
        "organization": "American Security Products Co.",
        "address_1": "11925 Pacific ave.",
        "address_2": "Fontana  CA  92335",
        "country": "US"
    },
    "001358": {
        "oui_hex": "00-13-58",
        "organization": "Realm Systems, Inc.",
        "address_1": "9350 South 535 East",
        "address_2": "Sandy  Utah  84070",
        "country": "US"
    },
    "0012C1": {
        "oui_hex": "00-12-C1",
        "organization": "Check Point Software Technologies",
        "address_1": "5 Ha'solelim St.",
        "address_2": "Tel Aviv    67897",
        "country": "IL"
    },
    "0012BB": {
        "oui_hex": "00-12-BB",
        "organization": "Telecommunications Industry Association TR-41 Committee",
        "address_1": "2500 Wilson Blvd., Suite 300",
        "address_2": "Arlington  VA  22201",
        "country": "US"
    },
    "0012B6": {
        "oui_hex": "00-12-B6",
        "organization": "Santa Barbara Infrared, Inc.",
        "address_1": "30 S. Calle Cesar Chavez",
        "address_2": "Santa Barbara  CA  93103",
        "country": "US"
    },
    "0012B9": {
        "oui_hex": "00-12-B9",
        "organization": "Fusion Digital Technology",
        "address_1": "Victoria Mews, 23 Millfield Road",
        "address_2": "Bingley    BD16 1PY",
        "country": "GB"
    },
    "0012B4": {
        "oui_hex": "00-12-B4",
        "organization": "Work Microwave GmbH",
        "address_1": "Raiffeisenstrasse 12",
        "address_2": "Holzkirchen    83607",
        "country": "DE"
    },
    "0012ED": {
        "oui_hex": "00-12-ED",
        "organization": "AVG Advanced Technologies",
        "address_1": "4140 Utica Ridge Road",
        "address_2": "Bettendorf  IA  52722",
        "country": "US"
    },
    "0012EA": {
        "oui_hex": "00-12-EA",
        "organization": "Trane",
        "address_1": "4833 White Bear Parkway",
        "address_2": "St. Paul  MN  55110",
        "country": "US"
    },
    "0012E7": {
        "oui_hex": "00-12-E7",
        "organization": "Projectek Networking Electronics Corp.",
        "address_1": "5F-9, No. 16, Lane 609, Sec. 5, Chungshin Rd.,",
        "address_2": "Sanchung, Taipei    241",
        "country": "TW"
    },
    "0012C3": {
        "oui_hex": "00-12-C3",
        "organization": "WIT S.A.",
        "address_1": "138 avenue Léon  Bérenger",
        "address_2": "Saint Laurent du Var  PACA  06700",
        "country": "FR"
    },
    "0012C8": {
        "oui_hex": "00-12-C8",
        "organization": "Perfect tech",
        "address_1": "3F,No.9,LANE175,NANKAN RD.,",
        "address_2": "LUJHU  TAOYUAN  338",
        "country": "TW"
    },
    "0012C6": {
        "oui_hex": "00-12-C6",
        "organization": "TGC America, Inc",
        "address_1": "2901 Tasman Drive, Suite 111",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0012CC": {
        "oui_hex": "00-12-CC",
        "organization": "Bitatek CO., LTD",
        "address_1": "6F.,No 115,Wugong 3rd Rd",
        "address_2": "Wugu District  New Taipei City  248",
        "country": "TW"
    },
    "0012FA": {
        "oui_hex": "00-12-FA",
        "organization": "THX LTD",
        "address_1": "5201 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001306": {
        "oui_hex": "00-13-06",
        "organization": "Always On Wireless",
        "address_1": "3701 Kirby Dr",
        "address_2": "Houston  TX  77098",
        "country": "US"
    },
    "0012FD": {
        "oui_hex": "00-12-FD",
        "organization": "OPTIMUS IC S.A.",
        "address_1": "NAWOJOWSKA 118",
        "address_2": "NOWY SACZ  MALOPOLSKA  33-300",
        "country": "PL"
    },
    "001305": {
        "oui_hex": "00-13-05",
        "organization": "Epicom, Inc.",
        "address_1": "PO Box 24839",
        "address_2": "Oakland  CA  94623-1839",
        "country": "US"
    },
    "0012E4": {
        "oui_hex": "00-12-E4",
        "organization": "ZIEHL industrie-electronik GmbH + Co KG",
        "address_1": "Daimlerstraße 13",
        "address_2": "Schwaebisch Hall    74523",
        "country": "DE"
    },
    "001297": {
        "oui_hex": "00-12-97",
        "organization": "O2Micro, Inc.",
        "address_1": "3118 Patrick Henry Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00129D": {
        "oui_hex": "00-12-9D",
        "organization": "First International Computer do Brasil",
        "address_1": "Rodovia BR 459",
        "address_2": "Santa Rita do Sapucaí  Minas Gerais",
        "country": "BR"
    },
    "00129C": {
        "oui_hex": "00-12-9C",
        "organization": "Yulinet",
        "address_1": "11F, Samhomoolsan B/D 275-6, Yangjae-dong",
        "address_2": "Seocho  Seoul  137-941",
        "country": "KR"
    },
    "001290": {
        "oui_hex": "00-12-90",
        "organization": "KYOWA Electric & Machinery Corp.",
        "address_1": "4-8-16,Masuizumi",
        "address_2": "Kanazawa  Ishikawa  921-8025",
        "country": "JP"
    },
    "001291": {
        "oui_hex": "00-12-91",
        "organization": "KWS Computersysteme GmbH",
        "address_1": "Carl Zeiss Str. 1",
        "address_2": "Ettlingen  BW  76275",
        "country": "DE"
    },
    "001295": {
        "oui_hex": "00-12-95",
        "organization": "Aiware Inc.",
        "address_1": "J-Tower 2F",
        "address_2": "Fuchu-shi  Tokyo  183-0044",
        "country": "JP"
    },
    "00128B": {
        "oui_hex": "00-12-8B",
        "organization": "Sensory Networks Inc",
        "address_1": "Level 6, 140 William St",
        "address_2": "East Sydney  NSW  2011",
        "country": "AU"
    },
    "00128F": {
        "oui_hex": "00-12-8F",
        "organization": "Montilio",
        "address_1": "1 maskit st.",
        "address_2": "Hertzelia    46763",
        "country": "IL"
    },
    "0012A3": {
        "oui_hex": "00-12-A3",
        "organization": "Trust International B.V.",
        "address_1": "Laan van Barcelona 600",
        "address_2": "Dordrecht  Zuid holland  3317 DD",
        "country": "NL"
    },
    "0012A7": {
        "oui_hex": "00-12-A7",
        "organization": "ISR TECHNOLOGIES Inc",
        "address_1": "1100, rue Notre-Dame Ouest",
        "address_2": "Montreal  Quebec  H3C 1K3",
        "country": "CA"
    },
    "0012AA": {
        "oui_hex": "00-12-AA",
        "organization": "IEE, Inc.",
        "address_1": "7740 Lemona Avenue",
        "address_2": "Van Nuys,  CA  91405",
        "country": "US"
    },
    "00129F": {
        "oui_hex": "00-12-9F",
        "organization": "RAE Systems",
        "address_1": "3775 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0012B5": {
        "oui_hex": "00-12-B5",
        "organization": "Vialta, Inc.",
        "address_1": "48461 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0012B1": {
        "oui_hex": "00-12-B1",
        "organization": "Dai Nippon Printing Co., Ltd",
        "address_1": "2-8-21,Akabane-minami",
        "address_2": "Kita-ku  Tokyo  115-0044",
        "country": "JP"
    },
    "001289": {
        "oui_hex": "00-12-89",
        "organization": "Advance Sterilization Products",
        "address_1": "33 Technology Drive",
        "address_2": "Irvine  California  92618",
        "country": "US"
    },
    "001284": {
        "oui_hex": "00-12-84",
        "organization": "Lab33 Srl",
        "address_1": "C.so F. Perrone 24",
        "address_2": "Genoa  GE  16152",
        "country": "IT"
    },
    "001281": {
        "oui_hex": "00-12-81",
        "organization": "March Networks S.p.A.",
        "address_1": "Via Dei Lavoratori Autobianchi n. 1,",
        "address_2": "Desio  Milano  20033",
        "country": "IT"
    },
    "00127E": {
        "oui_hex": "00-12-7E",
        "organization": "Digital Lifestyles Group, Inc.",
        "address_1": "801 South Sentous Ave.",
        "address_2": "City of Industry  CA  91748",
        "country": "US"
    },
    "00126B": {
        "oui_hex": "00-12-6B",
        "organization": "Ascalade Communications Limited",
        "address_1": "Unit 10-11, 35/F, Cable TV Tower,",
        "address_2": "",
        "country": "HK"
    },
    "001233": {
        "oui_hex": "00-12-33",
        "organization": "JRC TOKKI Co.,Ltd.",
        "address_1": "3-2-1 Shinyoshidahigashi Kohoku-ku",
        "address_2": "Yokohama  Kanagawa  223-8572",
        "country": "JP"
    },
    "00125B": {
        "oui_hex": "00-12-5B",
        "organization": "KAIMEI ELECTRONI",
        "address_1": "14-3F, NO.81,SEC. 1,HSIN-TAI-WU ROAD,HSICHIH,",
        "address_2": "TAIPEI HSIEN  HSICHIH  221",
        "country": "TW"
    },
    "001259": {
        "oui_hex": "00-12-59",
        "organization": "THERMO ELECTRON KARLSRUHE",
        "address_1": "DIESELSTRAßE 4",
        "address_2": "KARLSRUHE  Baden-Württemberg  76227",
        "country": "DE"
    },
    "00125A": {
        "oui_hex": "00-12-5A",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "00123D": {
        "oui_hex": "00-12-3D",
        "organization": "GES Co, Ltd",
        "address_1": " Room 710, Bundang Technopark, 700",
        "address_2": "Gyeonggi-Do    463-400",
        "country": "KR"
    },
    "001239": {
        "oui_hex": "00-12-39",
        "organization": "S Net Systems Inc.",
        "address_1": "10F Sungwon Bldg. Samsung-dong",
        "address_2": "Seoul    135-090",
        "country": "KR"
    },
    "00122F": {
        "oui_hex": "00-12-2F",
        "organization": "Sanei Electric Inc.",
        "address_1": "5F Taisou-Ikebukuro Bldg.",
        "address_2": "Toshima-ku  Tokyo  171-0014",
        "country": "JP"
    },
    "001230": {
        "oui_hex": "00-12-30",
        "organization": "Picaso Infocommunication CO., LTD.",
        "address_1": "3F, Suntechcity, Sangdaewon 1-dong,",
        "address_2": "Sungnam-city  Kyunggi-do  462-725",
        "country": "KR"
    },
    "001246": {
        "oui_hex": "00-12-46",
        "organization": "T.O.M TECHNOLOGY INC..",
        "address_1": "906 Woolim E-biz Center 2,",
        "address_2": "Seoul  Guro-Gu  184-1",
        "country": "KR"
    },
    "001256": {
        "oui_hex": "00-12-56",
        "organization": "LG INFORMATION & COMM.",
        "address_1": "459-9,KASAN-DONG,KUMCHON-GU,",
        "address_2": "SEOUL    153-023",
        "country": "KR"
    },
    "001214": {
        "oui_hex": "00-12-14",
        "organization": "Koenig & Bauer AG",
        "address_1": "Friedrich-Koenig-Str. 4",
        "address_2": "Wuerzburg  Bavaria  97080",
        "country": "DE"
    },
    "00120F": {
        "oui_hex": "00-12-0F",
        "organization": "IEEE 802.3",
        "address_1": "",
        "address_2": "Oban     PA34 5EJ",
        "country": "GB"
    },
    "00121D": {
        "oui_hex": "00-12-1D",
        "organization": "Netfabric Corporation",
        "address_1": "67 Federal Road",
        "address_2": "Brookfield  CT  06804",
        "country": "US"
    },
    "00120C": {
        "oui_hex": "00-12-0C",
        "organization": "CE-Infosys Pte Ltd",
        "address_1": "390 Havelock Road",
        "address_2": "    169662",
        "country": "SG"
    },
    "0011B3": {
        "oui_hex": "00-11-B3",
        "organization": "YOSHIMIYA CO.,LTD.",
        "address_1": "2-3-24 Bainan",
        "address_2": "OSAKA  OSAKA-Pref  557-0033",
        "country": "JP"
    },
    "0011B6": {
        "oui_hex": "00-11-B6",
        "organization": "Open Systems International",
        "address_1": "4101 Arrowhead Drive",
        "address_2": "Medina  MN  55340",
        "country": "US"
    },
    "0011B0": {
        "oui_hex": "00-11-B0",
        "organization": "Fortelink Inc.",
        "address_1": "42501 Albrae street suite 202",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0011AC": {
        "oui_hex": "00-11-AC",
        "organization": "Simtec Electronics",
        "address_1": "Avondale Drive",
        "address_2": "Tarleton  Lancashire  PR4 6AX",
        "country": "GB"
    },
    "0011AD": {
        "oui_hex": "00-11-AD",
        "organization": "Shanghai Ruijie Technology",
        "address_1": "27F, 420 Jiangning Rd.",
        "address_2": "Shanghai    200041",
        "country": "CN"
    },
    "0011CD": {
        "oui_hex": "00-11-CD",
        "organization": "Axsun Technologies",
        "address_1": "1 Fortune Drive",
        "address_2": "Billerica  MA  02460",
        "country": "US"
    },
    "0011C5": {
        "oui_hex": "00-11-C5",
        "organization": "TEN Technology",
        "address_1": "555 East Ocean Blvd.",
        "address_2": "Long Beach  CA  90802",
        "country": "US"
    },
    "0011BE": {
        "oui_hex": "00-11-BE",
        "organization": "AGP Telecom Co. Ltd",
        "address_1": "9F, 134 Chung-Hsiao E. RD",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "0011BA": {
        "oui_hex": "00-11-BA",
        "organization": "Elexol Pty Ltd",
        "address_1": "Level 2 / 146 Bundall Road",
        "address_2": "Bundall  Queensland  4217",
        "country": "AU"
    },
    "0011BC": {
        "oui_hex": "00-11-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0011A8": {
        "oui_hex": "00-11-A8",
        "organization": "Quest Technologies",
        "address_1": "1060 Corporate Center Drive",
        "address_2": "Oconomowoc  Wisconsin  53066",
        "country": "US"
    },
    "0011A1": {
        "oui_hex": "00-11-A1",
        "organization": "VISION NETWARE CO.,LTD",
        "address_1": "Ace Twin Tower (2), #709",
        "address_2": "Seoul  Guro-Gu  152-050",
        "country": "KR"
    },
    "0011E2": {
        "oui_hex": "00-11-E2",
        "organization": "Hua Jung Components Co., Ltd.",
        "address_1": "5F, No.13, Lane 120, Sec.1, Nei Hu Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0011DA": {
        "oui_hex": "00-11-DA",
        "organization": "Vivaas Technology Inc.",
        "address_1": "15F, No. 10, Sec 1, Pei-Hsin Rd.,",
        "address_2": "Hsin-Tien city  Taipei Hsien,  231",
        "country": "TW"
    },
    "0011DD": {
        "oui_hex": "00-11-DD",
        "organization": "FROMUS TEC. Co., Ltd.",
        "address_1": "2F 896-8 Hogye2-dong Dongan-Gu",
        "address_2": "    431-836",
        "country": "KR"
    },
    "0011EB": {
        "oui_hex": "00-11-EB",
        "organization": "Innovative Integration",
        "address_1": "2390A Ward Avenue",
        "address_2": "Simi Valley  CA  93065",
        "country": "US"
    },
    "0011EA": {
        "oui_hex": "00-11-EA",
        "organization": "IWICS Inc.",
        "address_1": "19125 North Creek Parkway",
        "address_2": "Bothell  WA  98011",
        "country": "US"
    },
    "0011E4": {
        "oui_hex": "00-11-E4",
        "organization": "Danelec Electronics A/S",
        "address_1": "Blokken 44",
        "address_2": "Birkeroed  Copenhagen  3460",
        "country": "DK"
    },
    "0011E1": {
        "oui_hex": "00-11-E1",
        "organization": "Arcelik A.S",
        "address_1": "Cumhuriyet Mah., E5 Yan Yol, No:1,",
        "address_2": "Istanbul    34520",
        "country": "TR"
    },
    "0011FB": {
        "oui_hex": "00-11-FB",
        "organization": "Heidelberg Engineering GmbH",
        "address_1": "Tiergartenstraße 15",
        "address_2": "Heidelberg  Baden-Württemberg  69121",
        "country": "DE"
    },
    "0011D6": {
        "oui_hex": "00-11-D6",
        "organization": "HandEra, Inc.",
        "address_1": "2859 104th St.",
        "address_2": "Des Moines  IA  50322",
        "country": "US"
    },
    "0011CA": {
        "oui_hex": "00-11-CA",
        "organization": "Long Range Systems, Inc.",
        "address_1": "4550 Excel Parkway",
        "address_2": "Addison  Texas  75001",
        "country": "US"
    },
    "0011EF": {
        "oui_hex": "00-11-EF",
        "organization": "Conitec Datensysteme GmbH",
        "address_1": "Dieselstraße 11c",
        "address_2": "Dieburg  Hessen  64807",
        "country": "DE"
    },
    "00114F": {
        "oui_hex": "00-11-4F",
        "organization": "US Digital Television, Inc",
        "address_1": "5807 N. Andrews Way",
        "address_2": "Fort Lauderdale  FL  33309",
        "country": "US"
    },
    "001182": {
        "oui_hex": "00-11-82",
        "organization": "IMI Norgren Ltd",
        "address_1": "PO Box 22",
        "address_2": "Lichfield  Staffordshire  WS13 6SB",
        "country": "GB"
    },
    "00117A": {
        "oui_hex": "00-11-7A",
        "organization": "Singim International Corp.",
        "address_1": "6F-2, No. 190, Sec. 2 Chung Hsin Road,",
        "address_2": "Hsin Tien City    231",
        "country": "TW"
    },
    "001148": {
        "oui_hex": "00-11-48",
        "organization": "Prolon Control Systems",
        "address_1": "Herstedvesterstraede 56",
        "address_2": "Albertslund    DK-2620",
        "country": "DK"
    },
    "001140": {
        "oui_hex": "00-11-40",
        "organization": "Nanometrics Inc.",
        "address_1": "250 Herzberg Rd.",
        "address_2": "Kanata  Ontario  K2K 2A1",
        "country": "CA"
    },
    "001144": {
        "oui_hex": "00-11-44",
        "organization": "Assurance Technology Corp",
        "address_1": "6304 Potomac Avenue",
        "address_2": "Alexandria  Virginia  22307",
        "country": "US"
    },
    "001163": {
        "oui_hex": "00-11-63",
        "organization": "SYSTEM SPA DEPT. ELECTRONICS",
        "address_1": "VIA GHIAROLA VECCHIA 73",
        "address_2": "FIORANO MODENESE  MODENA  I-41042",
        "country": "IT"
    },
    "00118F": {
        "oui_hex": "00-11-8F",
        "organization": "EUTECH INSTRUMENTS PTE. LTD.",
        "address_1": "Blk 55,Ayer Rajah Crescent, #04-16/24.",
        "address_2": "    139949",
        "country": "SG"
    },
    "00118D": {
        "oui_hex": "00-11-8D",
        "organization": "Hanchang System Corp.",
        "address_1": "1058-2, Shinkil-dong, Danwon-gu,",
        "address_2": "Ansan-si  Gyeonggi-do  425-839",
        "country": "KR"
    },
    "00115F": {
        "oui_hex": "00-11-5F",
        "organization": "ITX Security Co., Ltd.",
        "address_1": "9F Kolon Digital Tower Aston Bldg. 505-14",
        "address_2": "Gasan-dong Geumcheon-gu  SEOUL  153-803",
        "country": "KR"
    },
    "001153": {
        "oui_hex": "00-11-53",
        "organization": "Trident Tek, Inc.",
        "address_1": "8041 Cessna Ave #200",
        "address_2": "Gaithersburg  MD  20879",
        "country": "US"
    },
    "001172": {
        "oui_hex": "00-11-72",
        "organization": "COTRON CORPORATION",
        "address_1": "12FL,No.150,Sec.4,Cheng-De Rd",
        "address_2": "Taipei City    111",
        "country": "TW"
    },
    "0011A0": {
        "oui_hex": "00-11-A0",
        "organization": "Vtech Engineering Canada Ltd",
        "address_1": "200-7671 Alderbridge Way",
        "address_2": "Richmond  BC  V6X 1Z9",
        "country": "CA"
    },
    "00119B": {
        "oui_hex": "00-11-9B",
        "organization": "Telesynergy Research Inc.",
        "address_1": "4F, No. 49, Tung Hsin Rd.,",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001191": {
        "oui_hex": "00-11-91",
        "organization": "CTS-Clima Temperatur Systeme GmbH",
        "address_1": "Lotzenäcker 21",
        "address_2": "Hechingen  Baden-Württemberg  72379",
        "country": "DE"
    },
    "001189": {
        "oui_hex": "00-11-89",
        "organization": "Aerotech Inc",
        "address_1": "101 Zeta Drive",
        "address_2": "Pittsburgh  PA  15238",
        "country": "US"
    },
    "000FFB": {
        "oui_hex": "00-0F-FB",
        "organization": "Nippon Denso Industry Co., Ltd.",
        "address_1": "3-14-19",
        "address_2": "Shibaura, Minato-ku  Tokyo,  108-8560",
        "country": "JP"
    },
    "000FF2": {
        "oui_hex": "00-0F-F2",
        "organization": "Loud Technologies Inc.",
        "address_1": "16220 Wood-Red Rd. NE",
        "address_2": "Woodinville  WA  98072",
        "country": "US"
    },
    "000FF1": {
        "oui_hex": "00-0F-F1",
        "organization": "nex-G Systems Pte.Ltd",
        "address_1": "25 Kallang Ave",
        "address_2": "    339416",
        "country": "SG"
    },
    "001101": {
        "oui_hex": "00-11-01",
        "organization": "CET Technologies Pte Ltd",
        "address_1": "100 Jurong East Street 21",
        "address_2": "    609602",
        "country": "SG"
    },
    "000FFF": {
        "oui_hex": "00-0F-FF",
        "organization": "Control4",
        "address_1": "11734 S. Election Drive",
        "address_2": "Draper  UT  84020",
        "country": "US"
    },
    "000FFC": {
        "oui_hex": "00-0F-FC",
        "organization": "Merit Li-Lin Ent.",
        "address_1": "No. 20 Wu-Long 6 Rd.",
        "address_2": "Wu-Ku  Taipei  242",
        "country": "TW"
    },
    "001113": {
        "oui_hex": "00-11-13",
        "organization": "Fraunhofer FOKUS",
        "address_1": "Kaiserin-Augusta-Allee 31",
        "address_2": "Berlin    10589",
        "country": "DE"
    },
    "001112": {
        "oui_hex": "00-11-12",
        "organization": "Honeywell CMSS",
        "address_1": "8323 Lindbergh Ct",
        "address_2": "Sarasota  FL  34243",
        "country": "US"
    },
    "000FE0": {
        "oui_hex": "00-0F-E0",
        "organization": "NComputing Co.,Ltd.",
        "address_1": "6th Fl, JEI-Platz B/D",
        "address_2": "Seoul  Gasan-dong Geumcheon-Gu  459-11",
        "country": "KR"
    },
    "000FE3": {
        "oui_hex": "00-0F-E3",
        "organization": "Damm Cellular Systems A/S",
        "address_1": "Moellegade 68",
        "address_2": "Soenderborg    DK-6400",
        "country": "DK"
    },
    "001128": {
        "oui_hex": "00-11-28",
        "organization": "Streamit",
        "address_1": "Flight Forum 3543",
        "address_2": "  Eindhoven  5657 DW",
        "country": "NL"
    },
    "00113F": {
        "oui_hex": "00-11-3F",
        "organization": "Alcatel DI",
        "address_1": "ZI lavoisier",
        "address_2": "EU  Normandie  76260",
        "country": "FR"
    },
    "001137": {
        "oui_hex": "00-11-37",
        "organization": "AICHI ELECTRIC CO., LTD.",
        "address_1": "1",
        "address_2": "kasugai city  aichi pref.  486-8666",
        "country": "JP"
    },
    "000FF3": {
        "oui_hex": "00-0F-F3",
        "organization": "Jung Myoung Communications&Technology",
        "address_1": "1th FL., Dong IL Bldg.107 Yangjae-Dong",
        "address_2": "Seocho-Ku  Seoul  137-130",
        "country": "KR"
    },
    "00113A": {
        "oui_hex": "00-11-3A",
        "organization": "SHINBORAM",
        "address_1": "4F DAHNWORLD BUILDING, 154-11 SAMSUNG-DONG",
        "address_2": "SEOUL    135-879",
        "country": "KR"
    },
    "000F89": {
        "oui_hex": "00-0F-89",
        "organization": "Winnertec System Co., Ltd.",
        "address_1": "#405, 4th Floor. Ace-Techno Tower III, 197-48,",
        "address_2": "Seoul    152-766",
        "country": "KR"
    },
    "000FA4": {
        "oui_hex": "00-0F-A4",
        "organization": "Sprecher Automation GmbH",
        "address_1": "Franckstrasse 51",
        "address_2": "Linz  Oberösterreich  4018",
        "country": "AT"
    },
    "000FA6": {
        "oui_hex": "00-0F-A6",
        "organization": "S2 Security Corporation",
        "address_1": "6 Abbott Road",
        "address_2": "Wellesley  MA  02481",
        "country": "US"
    },
    "000FAA": {
        "oui_hex": "00-0F-AA",
        "organization": "Nexus Technologies",
        "address_1": "10 National Ave.",
        "address_2": "Fletcher  NC  28732",
        "country": "US"
    },
    "000FA8": {
        "oui_hex": "00-0F-A8",
        "organization": "Photometrics, Inc.",
        "address_1": "3440 E Britannia Drive",
        "address_2": "Tucson  AZ  85706-5006",
        "country": "US"
    },
    "000FBD": {
        "oui_hex": "00-0F-BD",
        "organization": "MRV Communications (Networks) LTD",
        "address_1": "P.O Box 614",
        "address_2": "Yokneam    20692",
        "country": "IL"
    },
    "000FB4": {
        "oui_hex": "00-0F-B4",
        "organization": "Timespace Technology",
        "address_1": "Blackstone Road",
        "address_2": "Huntingdon  Cambridgeshire  PE29 6TT",
        "country": "GB"
    },
    "000F9D": {
        "oui_hex": "00-0F-9D",
        "organization": "DisplayLink (UK) Ltd",
        "address_1": "Mount Pleasant House",
        "address_2": "Cambridge  Cambridgeshire  CB3 0RN",
        "country": "GB"
    },
    "000FC5": {
        "oui_hex": "00-0F-C5",
        "organization": "KeyMed Ltd",
        "address_1": "KeyMed House",
        "address_2": "Southend on Sea  Essex  SS2 5QH",
        "country": "GB"
    },
    "000FBF": {
        "oui_hex": "00-0F-BF",
        "organization": "DGT Sp. z o.o.",
        "address_1": "ul. Jaskowa Dolina 15",
        "address_2": "Gdansk  woj. pomorskie  80-252",
        "country": "PL"
    },
    "000F92": {
        "oui_hex": "00-0F-92",
        "organization": "Microhard Systems Inc.",
        "address_1": "#17, 2135-32Ave NE",
        "address_2": "Calgary  AB  T2E6Z3",
        "country": "CA"
    },
    "000FCB": {
        "oui_hex": "00-0F-CB",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "000FD5": {
        "oui_hex": "00-0F-D5",
        "organization": "Schwechat - RISE",
        "address_1": "Am Concorde Park 2A",
        "address_2": "Schwechat    2320",
        "country": "AT"
    },
    "000F67": {
        "oui_hex": "00-0F-67",
        "organization": "West Instruments",
        "address_1": "Unit 5, The Hyde, Lower Bevendean",
        "address_2": "Brighton  East Sussex  BN2 4JU",
        "country": "GB"
    },
    "000F6E": {
        "oui_hex": "00-0F-6E",
        "organization": "BBox",
        "address_1": "Gyar u. 2. (115)",
        "address_2": "Budaors    H-2040",
        "country": "HU"
    },
    "000F6F": {
        "oui_hex": "00-0F-6F",
        "organization": "FTA Communication Technologies",
        "address_1": "11, rue Pierre Werner",
        "address_2": "Betzdorf    L-6832",
        "country": "LU"
    },
    "000F63": {
        "oui_hex": "00-0F-63",
        "organization": "Obzerv Technologies",
        "address_1": "400 Jean Lesage",
        "address_2": "Quebec  QC  G1K8W1",
        "country": "CA"
    },
    "000F21": {
        "oui_hex": "00-0F-21",
        "organization": "Scientific Atlanta, Inc",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  Ga  30042",
        "country": "US"
    },
    "000F11": {
        "oui_hex": "00-0F-11",
        "organization": "Prodrive B.V.",
        "address_1": "P.O. 28030",
        "address_2": "Eindhoven    5602 JA",
        "country": "NL"
    },
    "000F13": {
        "oui_hex": "00-0F-13",
        "organization": "Nisca corporation",
        "address_1": "430-1",
        "address_2": "Masuho-Cho  Yamanashi-Ken  400-0593",
        "country": "JP"
    },
    "000F14": {
        "oui_hex": "00-0F-14",
        "organization": "Mindray Co., Ltd.",
        "address_1": "Mindray Building, Keji 12th Road South",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "000F65": {
        "oui_hex": "00-0F-65",
        "organization": "icube Corp.",
        "address_1": "Olympia Center 2F,828-10,Yeoksam-dong,Kangnam-ku",
        "address_2": "Seoul  South  135-935",
        "country": "KR"
    },
    "000F5D": {
        "oui_hex": "00-0F-5D",
        "organization": "Genexis BV",
        "address_1": "Lodewijktraat 1A",
        "address_2": "5652 AC  Eindhoven",
        "country": "SE"
    },
    "000F58": {
        "oui_hex": "00-0F-58",
        "organization": "Adder Technology Limited",
        "address_1": "Technology House",
        "address_2": "Bar Hill  Cambridgeshire  CB3 8SQ",
        "country": "GB"
    },
    "000F12": {
        "oui_hex": "00-0F-12",
        "organization": "Panasonic Europe Ltd.",
        "address_1": "Hesebergweg 49-51",
        "address_2": "Peine    D-31228",
        "country": "DE"
    },
    "000F0E": {
        "oui_hex": "00-0F-0E",
        "organization": "WaveSplitter Technologies, Inc.",
        "address_1": "2248 North First Street",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000F0C": {
        "oui_hex": "00-0F-0C",
        "organization": "SYNCHRONIC ENGINEERING",
        "address_1": "25 CAP DARNETAL",
        "address_2": "DARNETAL  FRANCE  76160",
        "country": "FR"
    },
    "000F0B": {
        "oui_hex": "00-0F-0B",
        "organization": "Kentima Technologies AB",
        "address_1": "Box 174",
        "address_2": "Staffanstorp  Skåne  245 44",
        "country": "SE"
    },
    "000F46": {
        "oui_hex": "00-0F-46",
        "organization": "SINAR AG",
        "address_1": "Stadtweg 24",
        "address_2": "Feuerthalen  ZH  CH-8245",
        "country": "CH"
    },
    "000F41": {
        "oui_hex": "00-0F-41",
        "organization": "Zipher Ltd",
        "address_1": "7 Faraday Building",
        "address_2": "Nottingham  Nottinghamshire  NG7 2QP",
        "country": "GB"
    },
    "000F4D": {
        "oui_hex": "00-0F-4D",
        "organization": "TalkSwitch",
        "address_1": "1545 Carling Ave",
        "address_2": "Ottawa  Ontario  K1Z 8P9",
        "country": "CA"
    },
    "000F71": {
        "oui_hex": "00-0F-71",
        "organization": "Sanmei Electronics Co.,Ltd",
        "address_1": "2-2-1,Seikai,Shimizu",
        "address_2": "Shizuoka    424-0924",
        "country": "JP"
    },
    "000F6B": {
        "oui_hex": "00-0F-6B",
        "organization": "GateWare Communications GmbH",
        "address_1": "Allersberger Strasse 185 F",
        "address_2": "Nuernberg  Bavaria  D-90461",
        "country": "DE"
    },
    "000ED5": {
        "oui_hex": "00-0E-D5",
        "organization": "COPAN Systems Inc.",
        "address_1": "2605 Trade Centre Ave.",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "000ECA": {
        "oui_hex": "00-0E-CA",
        "organization": "WTSS Inc",
        "address_1": "5999 Avenida Encinas",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "000ECC": {
        "oui_hex": "00-0E-CC",
        "organization": "Tableau, LLC",
        "address_1": "N8 W22195 Johnson Drive, Suite 100",
        "address_2": "Waukesha  WI  53186",
        "country": "US"
    },
    "000ECB": {
        "oui_hex": "00-0E-CB",
        "organization": "VineSys Technology",
        "address_1": "3350 Scott Blvd. building 15-03",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000ED2": {
        "oui_hex": "00-0E-D2",
        "organization": "Filtronic plc",
        "address_1": "The Waterfront",
        "address_2": "Saltaire  W Yorks  BD18 3TT",
        "country": "GB"
    },
    "000EC8": {
        "oui_hex": "00-0E-C8",
        "organization": "Zoran Corporation",
        "address_1": "1390 Kifer Rd.",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "000ED9": {
        "oui_hex": "00-0E-D9",
        "organization": "Aksys, Ltd.",
        "address_1": "2 Marriott Drive",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "000EB4": {
        "oui_hex": "00-0E-B4",
        "organization": "GUANGZHOU GAOKE COMMUNICATIONS TECHNOLOGY CO.LTD.",
        "address_1": "AVE. 398 ZHONGSHAN",
        "address_2": "GUANGZHOU  GUANGDONG  510660",
        "country": "CN"
    },
    "000EB1": {
        "oui_hex": "00-0E-B1",
        "organization": "Newcotech,Ltd",
        "address_1": "Anyang Megavally 715-3",
        "address_2": "Anyang City  Gueonggi-Do  431-160",
        "country": "KR"
    },
    "000EA9": {
        "oui_hex": "00-0E-A9",
        "organization": "Shanghai Xun Shi Communications Equipment Ltd. Co.",
        "address_1": "Hi-Tech King World, Unit C603",
        "address_2": "Shanghai    200001",
        "country": "CN"
    },
    "000EB6": {
        "oui_hex": "00-0E-B6",
        "organization": "Riverbed Technology, Inc.",
        "address_1": " 680 Folsom St.",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "000EB7": {
        "oui_hex": "00-0E-B7",
        "organization": "Knovative, Inc.",
        "address_1": "11245 West Bernardo Court",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "000EFA": {
        "oui_hex": "00-0E-FA",
        "organization": "Optoway Technology Incorporation",
        "address_1": "No. 38, Kuang Fu South Road",
        "address_2": "Hu Kou  Hsin Chu  303",
        "country": "TW"
    },
    "000EFD": {
        "oui_hex": "00-0E-FD",
        "organization": "FUJINON CORPORATION",
        "address_1": "1-324 UETAKE, KITA-KU,",
        "address_2": "SAITAMA CITY  SAITAMA  331-9624",
        "country": "JP"
    },
    "000EF5": {
        "oui_hex": "00-0E-F5",
        "organization": "iPAC Technology Co., Ltd.",
        "address_1": "6F, No. 30, Shingjung Road, Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000EFB": {
        "oui_hex": "00-0E-FB",
        "organization": "Macey Enterprises",
        "address_1": "P.O. Box 7267",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "000F09": {
        "oui_hex": "00-0F-09",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000EDC": {
        "oui_hex": "00-0E-DC",
        "organization": "Tellion INC.",
        "address_1": "5th Fl. BONA Venture Town",
        "address_2": "Seoul  Seocho-gu.  137-719",
        "country": "KR"
    },
    "000ECD": {
        "oui_hex": "00-0E-CD",
        "organization": "SKOV A/S",
        "address_1": "Hedelund 4",
        "address_2": "Roslev    DK-7870",
        "country": "DK"
    },
    "000EDB": {
        "oui_hex": "00-0E-DB",
        "organization": "XiNCOM Corp.",
        "address_1": "2840 Industrial Ave.",
        "address_2": "Hubbard  OR  97032",
        "country": "US"
    },
    "000EDD": {
        "oui_hex": "00-0E-DD",
        "organization": "SHURE INCORPORATED",
        "address_1": "5800 W. TOUHY AVE.",
        "address_2": "NILES  IL  60714",
        "country": "US"
    },
    "000EC2": {
        "oui_hex": "00-0E-C2",
        "organization": "Lowrance Electronics, Inc.",
        "address_1": "12000 E. Skelly Drive",
        "address_2": "Tulsa  OK  74128",
        "country": "US"
    },
    "000EA3": {
        "oui_hex": "00-0E-A3",
        "organization": "CNCR-IT CO.,LTD,HangZhou P.R.CHINA",
        "address_1": "Yinjiang mansion NO.5F Wenyi Road",
        "address_2": "HangZhou  ZheJiang  310012",
        "country": "CN"
    },
    "000EA2": {
        "oui_hex": "00-0E-A2",
        "organization": "McAfee, Inc",
        "address_1": "350 SW 12th Avenue",
        "address_2": "Deerfield Beach  FL  33442",
        "country": "US"
    },
    "000E9B": {
        "oui_hex": "00-0E-9B",
        "organization": "Ambit Microsystems Corporation",
        "address_1": "5F-1, 5 Hsin-An Rd. Science-Based Industrial Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000E78": {
        "oui_hex": "00-0E-78",
        "organization": "Amtelco",
        "address_1": "4800 Curtin Drive",
        "address_2": "McFarland  WI  53558",
        "country": "US"
    },
    "000E71": {
        "oui_hex": "00-0E-71",
        "organization": "Gemstar Technology Development Ltd.",
        "address_1": "Unit 201, Stulex house, 698 prince edward road east, san po kong, Kolwoon",
        "address_2": "Hong Kong    852",
        "country": "HK"
    },
    "000E70": {
        "oui_hex": "00-0E-70",
        "organization": "in2 Networks",
        "address_1": "320 W  200 S",
        "address_2": "SLC  UT  84101",
        "country": "US"
    },
    "000E37": {
        "oui_hex": "00-0E-37",
        "organization": "Harms & Wende GmbH & Co.KG",
        "address_1": "Grossmoorkehre 9",
        "address_2": "Hamburg    D-21079",
        "country": "DE"
    },
    "000E31": {
        "oui_hex": "00-0E-31",
        "organization": "Olympus Soft Imaging Solutions GmbH",
        "address_1": "Johann-Krane-Weg 39",
        "address_2": "  Münster  48149",
        "country": "DE"
    },
    "000E2F": {
        "oui_hex": "00-0E-2F",
        "organization": "Roche Diagnostics GmbH",
        "address_1": "Roche Diabetes Care Insulin Delivery Systems",
        "address_2": "D-68305 Mannheim",
        "country": "DE"
    },
    "000E2A": {
        "oui_hex": "00-0E-2A",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000E9E": {
        "oui_hex": "00-0E-9E",
        "organization": "Topfield Co., Ltd",
        "address_1": "4th floor, Deoksan Bldg 260-4, Seohyun-dong",
        "address_2": "Seongnam  Bundang-Ku  463-824",
        "country": "KR"
    },
    "000E41": {
        "oui_hex": "00-0E-41",
        "organization": "NIHON MECHATRONICS CO.,LTD.",
        "address_1": "9-6 SHIOMIDAI, MIYAMAE-KU",
        "address_2": "KAWASAKI-SHI  KANAGAWA-KEN  216-0013",
        "country": "JP"
    },
    "000E3C": {
        "oui_hex": "00-0E-3C",
        "organization": "Transact Technologies Inc",
        "address_1": "20 Bomax Drive",
        "address_2": "Ithaca  New York  14850",
        "country": "US"
    },
    "000E63": {
        "oui_hex": "00-0E-63",
        "organization": "Lemke Diagnostics GmbH",
        "address_1": "Radeburger Str. 47",
        "address_2": "Volkersdorf  Saxony  01468",
        "country": "DE"
    },
    "000E5B": {
        "oui_hex": "00-0E-5B",
        "organization": "ParkerVision - Direct2Data",
        "address_1": "9432 Baymeadows Way",
        "address_2": "Jacksonville  FL  32246",
        "country": "US"
    },
    "000E60": {
        "oui_hex": "00-0E-60",
        "organization": "360SUN Digital Broadband Corporation",
        "address_1": "2F-2, No.2, Jianba Rd.,",
        "address_2": "Chung Ho  Taipei  235",
        "country": "TW"
    },
    "000E54": {
        "oui_hex": "00-0E-54",
        "organization": "AlphaCell Wireless Ltd.",
        "address_1": "22 Zarhin street",
        "address_2": "Raanana    43662",
        "country": "IL"
    },
    "000E4E": {
        "oui_hex": "00-0E-4E",
        "organization": "Waveplus Technology Co., Ltd.",
        "address_1": "347 HsinHu 2nd Rd., NeiHu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000E4A": {
        "oui_hex": "00-0E-4A",
        "organization": "Changchun Huayu WEBPAD Co.,LTD",
        "address_1": "4370 Gaoxin Road, High-Tech",
        "address_2": "Changchun  Jilin  130012",
        "country": "CN"
    },
    "000E93": {
        "oui_hex": "00-0E-93",
        "organization": "Milénio 3 Sistemas Electrónicos, Lda.",
        "address_1": "Edifício Via Norte, R. Espido 164C S403",
        "address_2": "Maia  Minho  4470-177",
        "country": "PT"
    },
    "000E8D": {
        "oui_hex": "00-0E-8D",
        "organization": "Systems in Progress Holding GmbH",
        "address_1": "Exerzierplatzstrasse 85",
        "address_2": "Graz  Styria  8051",
        "country": "AT"
    },
    "000E76": {
        "oui_hex": "00-0E-76",
        "organization": "GEMSOC INNOVISION INC.",
        "address_1": "9F,No.516,Sec,1Neihu Rd.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000E7D": {
        "oui_hex": "00-0E-7D",
        "organization": "Electronics Line 3000 Ltd.",
        "address_1": "2 Granit St.",
        "address_2": "Petah Tikva  Kiryar Arie  449130",
        "country": "IL"
    },
    "000E2C": {
        "oui_hex": "00-0E-2C",
        "organization": "Netcodec co.",
        "address_1": "401 Daeion S/W Center, 48 Jangdong",
        "address_2": "Daejon    305-715",
        "country": "KR"
    },
    "000E23": {
        "oui_hex": "00-0E-23",
        "organization": "Incipient, Inc.",
        "address_1": "230 Third Ave.",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "000E25": {
        "oui_hex": "00-0E-25",
        "organization": "Hannae Technology Co., Ltd",
        "address_1": "4F, Hyunjin Bldg., #798-30, Yeoksam-Dong",
        "address_2": "SEOUL    135-080",
        "country": "KR"
    },
    "000E20": {
        "oui_hex": "00-0E-20",
        "organization": "ACCESS Systems Americas, Inc.",
        "address_1": "1188 East Arques Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "000E21": {
        "oui_hex": "00-0E-21",
        "organization": "MTU Friedrichshafen GmbH",
        "address_1": "Maybachplatz 1",
        "address_2": "Friedrichshafen  Baden Wuertemberg  88040",
        "country": "DE"
    },
    "000DD4": {
        "oui_hex": "00-0D-D4",
        "organization": "Symantec Corporation",
        "address_1": "275 2nd Ave",
        "address_2": "Waltham  MA  02541",
        "country": "US"
    },
    "000DD2": {
        "oui_hex": "00-0D-D2",
        "organization": "Simrad Optronics ASA",
        "address_1": "Ensjøveienn 23B",
        "address_2": "PO Box 6114 Etterstad  NO-0602 Oslo",
        "country": "NO"
    },
    "000DD1": {
        "oui_hex": "00-0D-D1",
        "organization": "Stryker Corporation",
        "address_1": "4100 E Milham",
        "address_2": "Kalamazoo  MI  49001",
        "country": "US"
    },
    "000DD7": {
        "oui_hex": "00-0D-D7",
        "organization": "Bright",
        "address_1": "1-12-44 Aobadai",
        "address_2": "Kashiwa-shi  Chiba-ken  277-0055",
        "country": "JP"
    },
    "000DD9": {
        "oui_hex": "00-0D-D9",
        "organization": "Anton Paar GmbH",
        "address_1": "Anton-Paar-Strasse 20",
        "address_2": "Graz    8054",
        "country": "AT"
    },
    "000DDC": {
        "oui_hex": "00-0D-DC",
        "organization": "VAC",
        "address_1": "20F, N0. 456, Sec. 4, Hsin Yi Rd.,",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "000DE0": {
        "oui_hex": "00-0D-E0",
        "organization": "ICPDAS Co.,LTD",
        "address_1": " No. 111, Kuang-Fu N. Rd., Hsin-Chu Indu",
        "address_2": "HSINCHU    303",
        "country": "TW"
    },
    "000DE3": {
        "oui_hex": "00-0D-E3",
        "organization": "AT Sweden AB",
        "address_1": "P.O. Box 1166",
        "address_2": "Kista  Stockholm  SE-164 26",
        "country": "SE"
    },
    "000DEA": {
        "oui_hex": "00-0D-EA",
        "organization": "Kingtel Telecommunication Corp.",
        "address_1": "147 Kang Ning St.",
        "address_2": "Hsi Chih City  Taipei Hsien  221",
        "country": "TW"
    },
    "000DED": {
        "oui_hex": "00-0D-ED",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000DE4": {
        "oui_hex": "00-0D-E4",
        "organization": "DIGINICS, Inc.",
        "address_1": "178-7 Poi-dong",
        "address_2": "Kangnam-gu  Seoul  135-961",
        "country": "KR"
    },
    "000E09": {
        "oui_hex": "00-0E-09",
        "organization": "Shenzhen Coship Software Co.,LTD.",
        "address_1": "7/F,Block A,W2 Bldg,Hi-Tech Industrial Park,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "000E05": {
        "oui_hex": "00-0E-05",
        "organization": "WIRELESS MATRIX CORP.",
        "address_1": "UNIT 1A-3751 NORTH FRASER WAY",
        "address_2": "BURNABY  BC  V5J 5G4",
        "country": "CA"
    },
    "000E22": {
        "oui_hex": "00-0E-22",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000E1C": {
        "oui_hex": "00-0E-1C",
        "organization": "Hach Company",
        "address_1": "5600 Lindbergh Drive",
        "address_2": "Loveland  CO  80538",
        "country": "US"
    },
    "000E02": {
        "oui_hex": "00-0E-02",
        "organization": "Advantech AMT Inc.",
        "address_1": "657 Orly Ave.",
        "address_2": "Dorval  Quebec  H9P 1G1",
        "country": "CA"
    },
    "000DC9": {
        "oui_hex": "00-0D-C9",
        "organization": "THALES Elektronik Systeme GmbH",
        "address_1": "Fritz-Ludwig-Str. 1",
        "address_2": "Koblenz    56070",
        "country": "DE"
    },
    "000D81": {
        "oui_hex": "00-0D-81",
        "organization": "Pepperl+Fuchs GmbH",
        "address_1": "Lilienthalstraße 200",
        "address_2": "Mannheim    68307",
        "country": "DE"
    },
    "000D7A": {
        "oui_hex": "00-0D-7A",
        "organization": "DiGATTO Asia Pacific Pte Ltd",
        "address_1": "190 Mddle Road, #19-05 Fortune Center",
        "address_2": "    188979",
        "country": "SG"
    },
    "000D77": {
        "oui_hex": "00-0D-77",
        "organization": "FalconStor Software",
        "address_1": "125 Baylis Rd",
        "address_2": "Melville  NY  11747",
        "country": "US"
    },
    "000D76": {
        "oui_hex": "00-0D-76",
        "organization": "Hokuto Denshi Co,. Ltd.",
        "address_1": "3-7 Odori Nishi 16-Chome Chuoku",
        "address_2": "Sapporo  Hokkaido  060-0042",
        "country": "JP"
    },
    "000D7B": {
        "oui_hex": "00-0D-7B",
        "organization": "Consensys Computers Inc.",
        "address_1": "215 Shields Ct.",
        "address_2": "Markham  ON  L3R 8V2",
        "country": "CA"
    },
    "000D8F": {
        "oui_hex": "00-0D-8F",
        "organization": "King Tsushin Kogyo Co., LTD.",
        "address_1": " 1-10-1 Edanishi Aobaku",
        "address_2": "  Yokohama  225-0014",
        "country": "JP"
    },
    "000D89": {
        "oui_hex": "00-0D-89",
        "organization": "Bils Technology Inc",
        "address_1": "508 S River Oaks Drive",
        "address_2": "Indialantic  FL  32903",
        "country": "US"
    },
    "000D86": {
        "oui_hex": "00-0D-86",
        "organization": "Huber + Suhner AG",
        "address_1": "Degersheimerstrasse 14",
        "address_2": "9100  Herisau",
        "country": "CH"
    },
    "000DC8": {
        "oui_hex": "00-0D-C8",
        "organization": "AirMagnet, Inc",
        "address_1": "830 E. Arques Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "000DBE": {
        "oui_hex": "00-0D-BE",
        "organization": "Bel Fuse Europe Ltd.,UK",
        "address_1": "45/46 Riverside 2",
        "address_2": "Rochester  Kent  ME2 4DP",
        "country": "GB"
    },
    "000DBC": {
        "oui_hex": "00-0D-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000D9F": {
        "oui_hex": "00-0D-9F",
        "organization": "RF Micro Devices",
        "address_1": "2191 Zanker Road",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000DA5": {
        "oui_hex": "00-0D-A5",
        "organization": "Fabric7 Systems, Inc",
        "address_1": "1300 Crittenden Lane",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "000DC5": {
        "oui_hex": "00-0D-C5",
        "organization": "EchoStar Global B.V.",
        "address_1": "Schuilenburglaan 5a",
        "address_2": "Almelo  Overijssel  7604BJ",
        "country": "NL"
    },
    "000D99": {
        "oui_hex": "00-0D-99",
        "organization": "Orbital Sciences Corp.; Launch Systems Group",
        "address_1": "3380 S. Price Rd.",
        "address_2": "Chandler,  AZ  85248",
        "country": "US"
    },
    "000D6C": {
        "oui_hex": "00-0D-6C",
        "organization": "M-Audio",
        "address_1": "45 E ST Joseph St.",
        "address_2": "Arcadia  CA  91006",
        "country": "US"
    },
    "000D70": {
        "oui_hex": "00-0D-70",
        "organization": "Datamax Corporation",
        "address_1": "4501 Parkway Commerce Blvd",
        "address_2": "Orlando  FL  32808",
        "country": "US"
    },
    "000D59": {
        "oui_hex": "00-0D-59",
        "organization": "Amity Systems, Inc.",
        "address_1": "888 Tasman Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000D4E": {
        "oui_hex": "00-0D-4E",
        "organization": "NDR Co.,LTD.",
        "address_1": "Sumitomo seimei minatomachi MT BLDG",
        "address_2": "Osak  Kinki  550-0015",
        "country": "JP"
    },
    "000D50": {
        "oui_hex": "00-0D-50",
        "organization": "Galazar Networks",
        "address_1": "35 Fitzgerald Ave",
        "address_2": "Ottawa  ON  K2H 1E6",
        "country": "CA"
    },
    "000D17": {
        "oui_hex": "00-0D-17",
        "organization": "Turbo Networks Co.Ltd",
        "address_1": "2F,No 1223, Chung Cheng Rd.",
        "address_2": "Tao Yuan    330",
        "country": "TW"
    },
    "000D18": {
        "oui_hex": "00-0D-18",
        "organization": "Mega-Trend Electronics CO., LTD.",
        "address_1": "Tong Fu Yu Ind., Ku Keng Village, Guan Lan",
        "address_2": "Shengzhen  Guang Dong  518110",
        "country": "CN"
    },
    "000D20": {
        "oui_hex": "00-0D-20",
        "organization": "ASAHIKASEI TECHNOSYSTEM CO.,LTD.",
        "address_1": "Kanda Jinbocho 1-105",
        "address_2": "Chiyoda-ku  Tokyo  101-8101",
        "country": "JP"
    },
    "000D49": {
        "oui_hex": "00-0D-49",
        "organization": "Triton Systems of Delaware, Inc.",
        "address_1": "522 E. Railroad St.",
        "address_2": "Long Beach  MS  39560",
        "country": "US"
    },
    "000D48": {
        "oui_hex": "00-0D-48",
        "organization": "AEWIN Technologies Co., Ltd.",
        "address_1": "7F, No. 2, Lane 47, Sec. 3, Nan-Gang Rd.",
        "address_2": "TAIPEI    115",
        "country": "TW"
    },
    "000D24": {
        "oui_hex": "00-0D-24",
        "organization": "SENTEC E&E CO., LTD.",
        "address_1": "No. 32. Gong5 Rd.",
        "address_2": "Lungtan  Taoyuan  325",
        "country": "TW"
    },
    "000D22": {
        "oui_hex": "00-0D-22",
        "organization": "Unitronics LTD",
        "address_1": "Unitronics Building",
        "address_2": "Ben Gurion Airport    70100",
        "country": "IL"
    },
    "000D14": {
        "oui_hex": "00-0D-14",
        "organization": "Vtech Innovation LP dba Advanced American Telephones",
        "address_1": "203-600 Parsippany Rd",
        "address_2": "Parsippany  NJ  07054",
        "country": "US"
    },
    "000D5B": {
        "oui_hex": "00-0D-5B",
        "organization": "Smart Empire Investments Limited",
        "address_1": "Suite 2001-2006,Level 20 Landmark North",
        "address_2": "Xin Jie  Hong Kong  00852",
        "country": "CN"
    },
    "000D3A": {
        "oui_hex": "00-0D-3A",
        "organization": "Microsoft Corp.",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Wa.  98052",
        "country": "US"
    },
    "000D30": {
        "oui_hex": "00-0D-30",
        "organization": "IceFyre Semiconductor",
        "address_1": "Suite 300",
        "address_2": "Kanata  Ontario  K2K 3C9",
        "country": "CA"
    },
    "000D31": {
        "oui_hex": "00-0D-31",
        "organization": "Compellent Technologies, Inc.",
        "address_1": "7625 Smetana Lane",
        "address_2": "Eden Prairie  Minnesota  55344",
        "country": "US"
    },
    "000D2C": {
        "oui_hex": "00-0D-2C",
        "organization": "Net2Edge Limited",
        "address_1": "Kulite House Stroudley Road",
        "address_2": "Basingstoke  Hampshire  RG24 8UG",
        "country": "GB"
    },
    "000D25": {
        "oui_hex": "00-0D-25",
        "organization": "SANDEN CORPORATION",
        "address_1": "20 Kotobuki-cho",
        "address_2": "Isesaki-shi  Gunma  372-8502",
        "country": "JP"
    },
    "000D6F": {
        "oui_hex": "00-0D-6F",
        "organization": "Ember Corporation",
        "address_1": "343 Congress St",
        "address_2": "Boston  Ma  02210",
        "country": "US"
    },
    "000D5E": {
        "oui_hex": "00-0D-5E",
        "organization": "NEC Personal Products",
        "address_1": "6-80, Shimohanazawa 2-Chome",
        "address_2": "Yonezawa-shi  Yamagata  992-8520",
        "country": "JP"
    },
    "000D3F": {
        "oui_hex": "00-0D-3F",
        "organization": "VTI Instruments Corporation",
        "address_1": "5425 Warner Road, Suite 13",
        "address_2": "Valley View  OH  44125",
        "country": "US"
    },
    "000CE3": {
        "oui_hex": "00-0C-E3",
        "organization": "Option International N.V.",
        "address_1": "Kolonel Begaultlaan 45",
        "address_2": "Leuven  Brabant  3012",
        "country": "BE"
    },
    "000CE7": {
        "oui_hex": "00-0C-E7",
        "organization": "MediaTek Inc.",
        "address_1": "1F, No. 13, Innovation Road 1,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000CE8": {
        "oui_hex": "00-0C-E8",
        "organization": "GuangZhou AnJuBao Co., Ltd",
        "address_1": "HeiQiaoTang TangXia TianHe",
        "address_2": "GuangZhou  GuangDong  510665",
        "country": "CN"
    },
    "000CE4": {
        "oui_hex": "00-0C-E4",
        "organization": "NeuroCom International, Inc.",
        "address_1": "9570 SE Lawnfield Rd",
        "address_2": "Clackamas  OR  97015",
        "country": "US"
    },
    "000CB5": {
        "oui_hex": "00-0C-B5",
        "organization": "Premier Technolgies, Inc",
        "address_1": "PO Box 159",
        "address_2": "Long Lake  MN  55356",
        "country": "US"
    },
    "000CB6": {
        "oui_hex": "00-0C-B6",
        "organization": "NANJING SEU MOBILE & INTERNET TECHNOLOGY CO.,LTD",
        "address_1": "5th floor,Building 5,ChangJiangHou Street No.6",
        "address_2": "Nanjing  Jiangsu  210018",
        "country": "CN"
    },
    "000CC3": {
        "oui_hex": "00-0C-C3",
        "organization": "BeWAN systems",
        "address_1": "16 rue du Moulin des Bruyères Courbevoie",
        "address_2": "Courbevoie  Hauts de Seine  92400",
        "country": "FR"
    },
    "000CB4": {
        "oui_hex": "00-0C-B4",
        "organization": "AutoCell Laboratories, Inc.",
        "address_1": "174 Concord Street",
        "address_2": "Peterborough,  New Hampshire  03458",
        "country": "US"
    },
    "000CB1": {
        "oui_hex": "00-0C-B1",
        "organization": "Salland Engineering (Europe) BV",
        "address_1": "Bedrijvenpark Berkum",
        "address_2": "Zwolle  OV  8024 HA",
        "country": "NL"
    },
    "000CBC": {
        "oui_hex": "00-0C-BC",
        "organization": "Iscutum",
        "address_1": "#899-6 Ho-Gye Dong, Dong-An Gu",
        "address_2": "An-Yang City  Kyong-Gi Do  431-080",
        "country": "KR"
    },
    "000D04": {
        "oui_hex": "00-0D-04",
        "organization": "Foxboro Eckardt Development GmbH",
        "address_1": "Glockenstrasse 52",
        "address_2": "Stuttgart  Baden-Württemberg  70376",
        "country": "DE"
    },
    "000D08": {
        "oui_hex": "00-0D-08",
        "organization": "AboveCable, Inc.",
        "address_1": "8403 Colesville Road, #825",
        "address_2": "Silver Spring  MD  20910",
        "country": "US"
    },
    "000D05": {
        "oui_hex": "00-0D-05",
        "organization": "cybernet manufacturing inc.",
        "address_1": "5 holland",
        "address_2": "irvine  ca  92618",
        "country": "US"
    },
    "000CFE": {
        "oui_hex": "00-0C-FE",
        "organization": "Grand Electronic Co., Ltd",
        "address_1": "Room 1710, Block B Lucky tower, No.3 Don",
        "address_2": "Beijing    100027",
        "country": "CN"
    },
    "000D0E": {
        "oui_hex": "00-0D-0E",
        "organization": "Inqnet Systems, Inc.",
        "address_1": "321 NKIC Center,",
        "address_2": "Seoul    120-100",
        "country": "KR"
    },
    "000D11": {
        "oui_hex": "00-0D-11",
        "organization": "DENTSPLY - Gendex",
        "address_1": "901 West Oakton Street",
        "address_2": "Des Plaines  IL  60018-1884",
        "country": "US"
    },
    "000CC8": {
        "oui_hex": "00-0C-C8",
        "organization": "Xytronix Research & Design, Inc.",
        "address_1": "1488 East 2300 North",
        "address_2": "North Logan  UT  84341-1627",
        "country": "US"
    },
    "000CCA": {
        "oui_hex": "00-0C-CA",
        "organization": "HGST a Western Digital Company",
        "address_1": "3403 Yerba Buena Road",
        "address_2": "San Jose  CA  95135",
        "country": "US"
    },
    "000CD0": {
        "oui_hex": "00-0C-D0",
        "organization": "Symetrix",
        "address_1": "6408 216th St SW",
        "address_2": "Mountlake Terrace  WA  98043",
        "country": "US"
    },
    "000CD9": {
        "oui_hex": "00-0C-D9",
        "organization": "Itcare Co., Ltd",
        "address_1": "408 KT Seocho, 1001-1 Bangbae-dong,",
        "address_2": "Seoul    137-850",
        "country": "KR"
    },
    "000CD5": {
        "oui_hex": "00-0C-D5",
        "organization": "Passave Inc.",
        "address_1": "1557 Jasper Dr.",
        "address_2": "Sunnyvale  CA  94087",
        "country": "US"
    },
    "000CD2": {
        "oui_hex": "00-0C-D2",
        "organization": "Schaffner EMV AG",
        "address_1": "Nordstrasse 1",
        "address_2": "Luterbach    CH-4542",
        "country": "CH"
    },
    "000A07": {
        "oui_hex": "00-0A-07",
        "organization": "WebWayOne Ltd",
        "address_1": "11 Kingfisher Court,",
        "address_2": "Newbury  Berkshire  RG14 5SJ",
        "country": "GB"
    },
    "000CB0": {
        "oui_hex": "00-0C-B0",
        "organization": "Star Semiconductor Corporation",
        "address_1": "6F, No.17, Li-Hsin Rd",
        "address_2": "Hsinchu City    300",
        "country": "TW"
    },
    "000C34": {
        "oui_hex": "00-0C-34",
        "organization": "Vixen Co., Ltd.",
        "address_1": "5-17-3 Higashitokorozawa",
        "address_2": "Tokorozawa  Saitama  359-0021",
        "country": "JP"
    },
    "000C58": {
        "oui_hex": "00-0C-58",
        "organization": "M&S Systems",
        "address_1": "2861 Congressman Lane",
        "address_2": "Dallas  TX  75220",
        "country": "US"
    },
    "000C51": {
        "oui_hex": "00-0C-51",
        "organization": "Scientific Technologies Inc.",
        "address_1": "6550 Dumbarton Circle",
        "address_2": "Fremont  CA  94560",
        "country": "US"
    },
    "000C73": {
        "oui_hex": "00-0C-73",
        "organization": "TELSON ELECTRONICS CO., LTD",
        "address_1": "Telson Venture Tower., 949-3 Dogok-Dong",
        "address_2": "Seoul  Kangnam-Ku  135-739",
        "country": "KR"
    },
    "000C65": {
        "oui_hex": "00-0C-65",
        "organization": "Sunin Telecom",
        "address_1": "1025-5 Dokok-Ri, Wabu-Eub",
        "address_2": "Namyangju-City  Kyunggi-Do  472-900",
        "country": "KR"
    },
    "000C6C": {
        "oui_hex": "00-0C-6C",
        "organization": "Eve Systems GmbH",
        "address_1": "Rotkreuzplatz 1",
        "address_2": "Munich    80634",
        "country": "DE"
    },
    "000C6F": {
        "oui_hex": "00-0C-6F",
        "organization": "Amtek system co.,LTD.",
        "address_1": "14F-11,No.79,Sec. 1 ,Hsin Tai Wu Rd.,",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "000C7E": {
        "oui_hex": "00-0C-7E",
        "organization": "Tellium Incorporated",
        "address_1": "2 Crescent Place",
        "address_2": "Oceanport  New Jersey  07757",
        "country": "US"
    },
    "000C87": {
        "oui_hex": "00-0C-87",
        "organization": "AMD",
        "address_1": "4555 Great America Pkwy",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000C98": {
        "oui_hex": "00-0C-98",
        "organization": "LETEK Communications Inc.",
        "address_1": "Taeyang Bd. 2nd Floor, 2486",
        "address_2": "SongNam  Kyunggi-do  462-824",
        "country": "KR"
    },
    "000C8E": {
        "oui_hex": "00-0C-8E",
        "organization": "Mentor Engineering Inc",
        "address_1": "2891 Sunridge Way NE",
        "address_2": "Calgary  Alberta  T1Y7K7",
        "country": "CA"
    },
    "000CA2": {
        "oui_hex": "00-0C-A2",
        "organization": "Harmonic Video Network",
        "address_1": "10 Ha'amal st. Park Afek",
        "address_2": "Rosh Ha'ayin    48092",
        "country": "IL"
    },
    "000CA4": {
        "oui_hex": "00-0C-A4",
        "organization": "Prompttec Product Management GmbH",
        "address_1": "Mariatrosterstr. 41",
        "address_2": "Graz  AUSTRIA  A-8043",
        "country": "AT"
    },
    "000C5B": {
        "oui_hex": "00-0C-5B",
        "organization": "HANWANG TECHNOLOGY CO.,LTD",
        "address_1": "8F,Automation Building,95 Zhongguancun,",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "000C60": {
        "oui_hex": "00-0C-60",
        "organization": "ACM Systems",
        "address_1": "3034 Gold Canal Drive",
        "address_2": "Rancho Cordova  CA  95670",
        "country": "US"
    },
    "000C83": {
        "oui_hex": "00-0C-83",
        "organization": "Logical Solutions",
        "address_1": "100T Washington Street",
        "address_2": "Milford  CT  06460",
        "country": "US"
    },
    "000C96": {
        "oui_hex": "00-0C-96",
        "organization": "OQO, Inc.",
        "address_1": "1800 Illinois Street",
        "address_2": "San Francisco  CA  94124",
        "country": "US"
    },
    "000C08": {
        "oui_hex": "00-0C-08",
        "organization": "HUMEX Technologies Corp.",
        "address_1": "5F, No.5, Lane 44, Szu Wei Rd. Taan Taip",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "000C0D": {
        "oui_hex": "00-0C-0D",
        "organization": "Communications & Power Industries / Satcom Division",
        "address_1": "811 Hansen Way MS S-600",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "000C04": {
        "oui_hex": "00-0C-04",
        "organization": "Tecnova",
        "address_1": "1486 St. Paul Ave.",
        "address_2": "Gurnee  Illinois  60031",
        "country": "US"
    },
    "000C01": {
        "oui_hex": "00-0C-01",
        "organization": "Abatron AG",
        "address_1": "Lettenstrasse 9",
        "address_2": "Rotkreuz    CH-6343",
        "country": "CH"
    },
    "000C39": {
        "oui_hex": "00-0C-39",
        "organization": "Sentinel Wireless Inc.",
        "address_1": "439 S. Union St.",
        "address_2": "South Lawrence  MA  01843",
        "country": "US"
    },
    "000C33": {
        "oui_hex": "00-0C-33",
        "organization": "Compucase Enterprise Co. Ltd.",
        "address_1": "225 Lane 54, An Ho Road, Section 2nd.",
        "address_2": "Tainan City    70942",
        "country": "TW"
    },
    "000C36": {
        "oui_hex": "00-0C-36",
        "organization": "SHARP TAKAYA ELECTRONICS INDUSTRY CO.,LTD.",
        "address_1": "3121-1 Satomi Satosho-cho",
        "address_2": "Asakuchi-gun  Okayama  719-0301",
        "country": "JP"
    },
    "000BF6": {
        "oui_hex": "00-0B-F6",
        "organization": "Nitgen Co., Ltd",
        "address_1": "4th FL. 1337-31 Seocho-dong, Seocho-ku",
        "address_2": "Seoul    137-860",
        "country": "KR"
    },
    "000BFD": {
        "oui_hex": "00-0B-FD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BFA": {
        "oui_hex": "00-0B-FA",
        "organization": "EXEMYS SRL",
        "address_1": "LOYOLA 680",
        "address_2": "CAPITAL FEDERAL  BS AS  C1414",
        "country": "AR"
    },
    "000BF4": {
        "oui_hex": "00-0B-F4",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000BFB": {
        "oui_hex": "00-0B-FB",
        "organization": "D-NET International Corporation",
        "address_1": "15, Wu-Chuan 5th Road, Wu-Ku Industrial",
        "address_2": "Taipei  Hsieh    248",
        "country": "US"
    },
    "000C1D": {
        "oui_hex": "00-0C-1D",
        "organization": "Mettler & Fuchs AG",
        "address_1": "Querstrasse 17",
        "address_2": "CH-8951  Fahrweid",
        "country": "CH"
    },
    "000C1E": {
        "oui_hex": "00-0C-1E",
        "organization": "Global Cache",
        "address_1": "160 East California Street",
        "address_2": "Jacksonville  OR  97530",
        "country": "US"
    },
    "000C1A": {
        "oui_hex": "00-0C-1A",
        "organization": "Quest Technical Solutions Inc.",
        "address_1": "4110 Mourning Dove Crt.",
        "address_2": "Melbourne  FL  32934",
        "country": "US"
    },
    "000C24": {
        "oui_hex": "00-0C-24",
        "organization": "ANATOR",
        "address_1": "44, rue d'Estienne d'Orves",
        "address_2": "sartrouville  yvelines  78500",
        "country": "FR"
    },
    "000C19": {
        "oui_hex": "00-0C-19",
        "organization": "Telio Communications GmbH",
        "address_1": "Elbchaussee 1",
        "address_2": "Hamburg    22765",
        "country": "DE"
    },
    "000C13": {
        "oui_hex": "00-0C-13",
        "organization": "MediaQ",
        "address_1": "2975 San Ysidro Way",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "000C06": {
        "oui_hex": "00-0C-06",
        "organization": "Nixvue Systems  Pte Ltd",
        "address_1": "30 Loyang Way, #07-02",
        "address_2": "Singapore  Singapore  S508769",
        "country": "SG"
    },
    "000C2D": {
        "oui_hex": "00-0C-2D",
        "organization": "FullWave Technology Co., Ltd.",
        "address_1": "7F-6, No.26, TaiYuan St.,",
        "address_2": "JuBei  Hsin Chu  302",
        "country": "TW"
    },
    "000C26": {
        "oui_hex": "00-0C-26",
        "organization": "Weintek Labs. Inc.",
        "address_1": "3F, No.910, Chung Cheng Rd.",
        "address_2": "Chung Ho city  Taipei Hsien  236",
        "country": "TW"
    },
    "000C2B": {
        "oui_hex": "00-0C-2B",
        "organization": "ELIAS Technology, Inc.",
        "address_1": "3F, 1015, Yung-An Road,",
        "address_2": "Taoyuan City  Taoyuan  330",
        "country": "TW"
    },
    "000BF0": {
        "oui_hex": "00-0B-F0",
        "organization": "MoTEX Products Co., Ltd.",
        "address_1": "C.P.O.Box 6912",
        "address_2": "Chong-gu  Seoul  82",
        "country": "KR"
    },
    "000BF1": {
        "oui_hex": "00-0B-F1",
        "organization": "LAP Laser Applikations",
        "address_1": "Zeppelinstraße 23",
        "address_2": "Lüneburg  Niedersachsen  21337",
        "country": "DE"
    },
    "000BEE": {
        "oui_hex": "00-0B-EE",
        "organization": "inc.jet, Incorporated",
        "address_1": "One Winnenden Road",
        "address_2": "Norwich  CT  06360",
        "country": "US"
    },
    "000B8D": {
        "oui_hex": "00-0B-8D",
        "organization": "Avvio Networks",
        "address_1": "11 Donovan Dr",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "000B85": {
        "oui_hex": "00-0B-85",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000B7F": {
        "oui_hex": "00-0B-7F",
        "organization": "Align Engineering LLC",
        "address_1": "245 Highlands Drive",
        "address_2": "Friday Harbor   WA  98250",
        "country": "US"
    },
    "000BA6": {
        "oui_hex": "00-0B-A6",
        "organization": "Miyakawa Electric Works Ltd.",
        "address_1": "2-1-6,",
        "address_2": "Yokohama  Kanagawa  222-0001",
        "country": "JP"
    },
    "000B93": {
        "oui_hex": "00-0B-93",
        "organization": "Ritter Elektronik",
        "address_1": "Leverkuser Straße 65",
        "address_2": "Remscheid  NRW  42897",
        "country": "DE"
    },
    "000B9B": {
        "oui_hex": "00-0B-9B",
        "organization": "Sirius System Co, Ltd.",
        "address_1": "3-27 Funado-cho",
        "address_2": "Ashiya  Hyogo  659-0093",
        "country": "JP"
    },
    "000BE2": {
        "oui_hex": "00-0B-E2",
        "organization": "Lumenera Corporation",
        "address_1": "2520B St. Laurent Blvd.",
        "address_2": "Ottawa  Ontario  K1B 4R8",
        "country": "CA"
    },
    "000BE1": {
        "oui_hex": "00-0B-E1",
        "organization": "Nokia NET Product Operations",
        "address_1": "313 Fairchild Drive",
        "address_2": "Mountain View  California  94043",
        "country": "US"
    },
    "000BA8": {
        "oui_hex": "00-0B-A8",
        "organization": "HANBACK ELECTRONICS CO., LTD.",
        "address_1": "306-7, Galma-dong, Seo-gu",
        "address_2": "Daejeon    302-171",
        "country": "KR"
    },
    "000BA9": {
        "oui_hex": "00-0B-A9",
        "organization": "CloudShield Technologies, Inc.",
        "address_1": "212 Gilbraltar Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000BA1": {
        "oui_hex": "00-0B-A1",
        "organization": "Fujikura Solutions Ltd.",
        "address_1": "1565-6,Shirakusadai,Fukaya-shi",
        "address_2": "Saitama-ken    369-1106",
        "country": "JP"
    },
    "000B8E": {
        "oui_hex": "00-0B-8E",
        "organization": "Ascent Corporation",
        "address_1": "2-16-19, Kawaraya-machi, Chuo-Ku,",
        "address_2": "Osaka-City  Osaka-Pref  542-0066",
        "country": "JP"
    },
    "000B8F": {
        "oui_hex": "00-0B-8F",
        "organization": "AKITA ELECTRONICS SYSTEMS CO.,LTD.",
        "address_1": "85,AZA USHIRONO,AIKAWA,YUWA-MACHI",
        "address_2": "KAWABE-GUN  AKITA-KEN  010-1231",
        "country": "JP"
    },
    "000BCB": {
        "oui_hex": "00-0B-CB",
        "organization": "Fagor Automation , S. Coop",
        "address_1": "San Andres s/n",
        "address_2": "  Guipuzcoa  20500",
        "country": "ES"
    },
    "000BC8": {
        "oui_hex": "00-0B-C8",
        "organization": "AirFlow Networks",
        "address_1": "444 Castro St",
        "address_2": "Mountain View  Ca  94041",
        "country": "US"
    },
    "000BCE": {
        "oui_hex": "00-0B-CE",
        "organization": "Free2move AB",
        "address_1": "Sperlingsgatan 7",
        "address_2": "Halmstad  Halland  30248",
        "country": "SE"
    },
    "000BCF": {
        "oui_hex": "00-0B-CF",
        "organization": "AGFA NDT INC.",
        "address_1": "50 Industrial Park Road",
        "address_2": "Lewistown  PA  17044",
        "country": "US"
    },
    "000BC3": {
        "oui_hex": "00-0B-C3",
        "organization": "Multiplex, Inc.",
        "address_1": "5000 Hadley Rd.",
        "address_2": "S. Plainfield  NJ  07040",
        "country": "US"
    },
    "000BBE": {
        "oui_hex": "00-0B-BE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BE0": {
        "oui_hex": "00-0B-E0",
        "organization": "SercoNet Ltd.",
        "address_1": "16 Ha'haroshet st.",
        "address_2": "Ra'anana    43657",
        "country": "IL"
    },
    "000BBD": {
        "oui_hex": "00-0B-BD",
        "organization": "Connexionz Limited",
        "address_1": "1 Show Place",
        "address_2": "Christchurch",
        "country": "NZ"
    },
    "000B40": {
        "oui_hex": "00-0B-40",
        "organization": "Cambridge Industries Group (CIG)",
        "address_1": "2560 Junction Avenue",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "000B44": {
        "oui_hex": "00-0B-44",
        "organization": "Concord IDea Corp.",
        "address_1": "4118 14th Ave., Unit 4",
        "address_2": "Markham  Ontario  L3R 0J3",
        "country": "CA"
    },
    "000B42": {
        "oui_hex": "00-0B-42",
        "organization": "commax Co., Ltd.",
        "address_1": "513-11, Sangdaewon-Dong, Jungwon-Ku",
        "address_2": "Sungnam-City  Kyunggi-Do  462-120",
        "country": "KR"
    },
    "000B47": {
        "oui_hex": "00-0B-47",
        "organization": "Advanced Energy",
        "address_1": "1625 Sharp Point Drive",
        "address_2": "Fort Collins  Colorado  80525",
        "country": "US"
    },
    "000B81": {
        "oui_hex": "00-0B-81",
        "organization": "Kaparel Corporation",
        "address_1": "97 Randall Drive",
        "address_2": "Waterloo  Ontario  N2V-1C5",
        "country": "CA"
    },
    "000B82": {
        "oui_hex": "00-0B-82",
        "organization": "Grandstream Networks, Inc.",
        "address_1": "1297 Beacon Street",
        "address_2": "Brookline  MA  02446",
        "country": "US"
    },
    "000B6E": {
        "oui_hex": "00-0B-6E",
        "organization": "Neff Instrument Corp.",
        "address_1": "700 South Myrtle Ave.",
        "address_2": "Monrovia  CA  91016",
        "country": "US"
    },
    "000B72": {
        "oui_hex": "00-0B-72",
        "organization": "Lawo AG",
        "address_1": "Am Oberwald 8",
        "address_2": "Rastatt  Baden-Württemberg  76437",
        "country": "DE"
    },
    "000B31": {
        "oui_hex": "00-0B-31",
        "organization": "Yantai ZhiYang Scientific and technology industry CO., LTD",
        "address_1": "5F-4, NO. 64, Gong-Jian Rd.",
        "address_2": "Hsi-Chih City  Taipei County  221",
        "country": "CN"
    },
    "000B2F": {
        "oui_hex": "00-0B-2F",
        "organization": "bplan GmbH",
        "address_1": "Industriestrasse 23b",
        "address_2": "Steinbach  Hessen  61449",
        "country": "DE"
    },
    "000B3D": {
        "oui_hex": "00-0B-3D",
        "organization": "CONTAL OK Ltd.",
        "address_1": "Frana Mraza 2/289",
        "address_2": "Zilina    01124",
        "country": "SK"
    },
    "000B4E": {
        "oui_hex": "00-0B-4E",
        "organization": "VertexRSI, General Dynamics SatCOM Technologies, Inc.",
        "address_1": "3750 W. Loop 281",
        "address_2": "Longview  TX  75604",
        "country": "US"
    },
    "000B4D": {
        "oui_hex": "00-0B-4D",
        "organization": "Emuzed",
        "address_1": "46750 Lakeview Boulevard",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "000B24": {
        "oui_hex": "00-0B-24",
        "organization": "AirLogic",
        "address_1": "807-1, Bundangtechnopark D, 151,",
        "address_2": "Sungnam-Si  Kyungki-Do  463-760",
        "country": "KR"
    },
    "000B78": {
        "oui_hex": "00-0B-78",
        "organization": "TAIFATECH INC.",
        "address_1": "8F-1 No.289, Sec.2  Guangfu Rd.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000B6C": {
        "oui_hex": "00-0B-6C",
        "organization": "Sychip Inc.",
        "address_1": "2805 N. Dallas Parkway Suite 400",
        "address_2": "Plano  Texas  75093",
        "country": "US"
    },
    "0091D6": {
        "oui_hex": "00-91-D6",
        "organization": "Crystal Group, Inc.",
        "address_1": "850 Kacena Rd.",
        "address_2": "Hiawatha  IA  52233",
        "country": "US"
    },
    "000B5A": {
        "oui_hex": "00-0B-5A",
        "organization": "HyperEdge",
        "address_1": "333 Pierce Road Suite #200",
        "address_2": "Itasca  IL  60143",
        "country": "US"
    },
    "000B0F": {
        "oui_hex": "00-0B-0F",
        "organization": "Bosch Rexroth",
        "address_1": "Luchthavenweg 20",
        "address_2": "Eindhoven  Noord Brabant  NL5657 EB",
        "country": "NL"
    },
    "000B0C": {
        "oui_hex": "00-0B-0C",
        "organization": "Agile Systems Inc.",
        "address_1": "575 Kumpf Drive",
        "address_2": "Waterloo  Ontario  N2V 1K3",
        "country": "CA"
    },
    "000B0A": {
        "oui_hex": "00-0B-0A",
        "organization": "dBm Optics",
        "address_1": "300 S. Public Road",
        "address_2": "Lafayette  Colorado  80026",
        "country": "US"
    },
    "000B09": {
        "oui_hex": "00-0B-09",
        "organization": "Ifoundry Systems Singapore",
        "address_1": "Block 1, Unit 101B, Innovation Centre, 1",
        "address_2": "    637722",
        "country": "SG"
    },
    "000B1D": {
        "oui_hex": "00-0B-1D",
        "organization": "LayerZero Power Systems, Inc.",
        "address_1": "3559 Townley Road",
        "address_2": "Shaker Heights  OH  44122-5156",
        "country": "US"
    },
    "000B19": {
        "oui_hex": "00-0B-19",
        "organization": "Vernier Networks, Inc.",
        "address_1": "490 E. Middlefield Road",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "000B16": {
        "oui_hex": "00-0B-16",
        "organization": "Communication Machinery Corporation",
        "address_1": "402 E. Gutierrez St.",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "000B12": {
        "oui_hex": "00-0B-12",
        "organization": "NURI Telecom Co., Ltd.",
        "address_1": "B-10F Woolim Lion's Valley 371-28",
        "address_2": "Geuncheon-gu  Seoul  153-803",
        "country": "KR"
    },
    "000AC5": {
        "oui_hex": "00-0A-C5",
        "organization": "Color Kinetics",
        "address_1": "10 Milk Street",
        "address_2": "Boston  Masachusetts  02108",
        "country": "US"
    },
    "000ABD": {
        "oui_hex": "00-0A-BD",
        "organization": "Rupprecht & Patashnick Co.",
        "address_1": "25 Corporate Circle",
        "address_2": "Albany  NY  12203",
        "country": "US"
    },
    "000ACB": {
        "oui_hex": "00-0A-CB",
        "organization": "XPAK MSA Group",
        "address_1": "Care of: Molex Fiber Optics",
        "address_2": "Downers Grove  IL  60515",
        "country": "US"
    },
    "000AD5": {
        "oui_hex": "00-0A-D5",
        "organization": "Brainchild Electronic Co., Ltd.",
        "address_1": "No.209, Chung Yang Rd.,",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "000AD6": {
        "oui_hex": "00-0A-D6",
        "organization": "BeamReach Networks",
        "address_1": "755 North Mathilda Ave",
        "address_2": "Sunnyvale  California  94086",
        "country": "US"
    },
    "000AFE": {
        "oui_hex": "00-0A-FE",
        "organization": "NovaPal Ltd",
        "address_1": "Floor 6",
        "address_2": "Ealing  London  W5 2ST",
        "country": "GB"
    },
    "000AFD": {
        "oui_hex": "00-0A-FD",
        "organization": "Kentec Electronics",
        "address_1": "620 Allendale Rd",
        "address_2": "King of Prussia  PA  19406",
        "country": "US"
    },
    "000AEF": {
        "oui_hex": "00-0A-EF",
        "organization": "OTRUM ASA",
        "address_1": "Brattekleiv",
        "address_2": "Færvik    N-4818",
        "country": "NO"
    },
    "000AE5": {
        "oui_hex": "00-0A-E5",
        "organization": "ScottCare Corporation",
        "address_1": "4791 West 150th Street",
        "address_2": "Cleveland  Ohio  44135",
        "country": "US"
    },
    "000AB0": {
        "oui_hex": "00-0A-B0",
        "organization": "LOYTEC electronics GmbH",
        "address_1": "Stolzenthalergasse 24/3",
        "address_2": "Vienna    1080",
        "country": "AT"
    },
    "000AB5": {
        "oui_hex": "00-0A-B5",
        "organization": "Digital Electronic Network",
        "address_1": "8 rue du sacré  coeur",
        "address_2": "Saint Laurent sur Sevre  Vendee  85290",
        "country": "FR"
    },
    "000AD2": {
        "oui_hex": "00-0A-D2",
        "organization": "JEPICO Corporation",
        "address_1": "Nishi-shinjyuku2-7-1",
        "address_2": "Shinjyuku-ku  Tokyo  163-0729",
        "country": "JP"
    },
    "000A98": {
        "oui_hex": "00-0A-98",
        "organization": "M+F Gwinner GmbH & Co",
        "address_1": "Weidenbaumsweg 91 a",
        "address_2": "Hamburg    21029",
        "country": "DE"
    },
    "000A9B": {
        "oui_hex": "00-0A-9B",
        "organization": "TB Group Inc",
        "address_1": " 4F NREG Hongo 3-chome Bldg., 3-26-6, Hngo, Bunkyo-ku,",
        "address_2": "Tokyo    113-003",
        "country": "JP"
    },
    "000A6C": {
        "oui_hex": "00-0A-6C",
        "organization": "Walchem Corporation",
        "address_1": "5 Boynton Road",
        "address_2": "Holliston  MA  01746",
        "country": "US"
    },
    "000A5F": {
        "oui_hex": "00-0A-5F",
        "organization": "almedio inc.",
        "address_1": "32-13, sakae-cho 2 chome",
        "address_2": "higashimurayama-shi  tokyo  189-0013",
        "country": "JP"
    },
    "000A6B": {
        "oui_hex": "00-0A-6B",
        "organization": "Tadiran Telecom Business Systems LTD",
        "address_1": "18 Hasivim St.",
        "address_2": "Petach Tikva    49105",
        "country": "IL"
    },
    "000A61": {
        "oui_hex": "00-0A-61",
        "organization": "Cellinx Systems Inc.",
        "address_1": "408 Woosung Character199 officetel",
        "address_2": "Seoul    135-856",
        "country": "KR"
    },
    "000A78": {
        "oui_hex": "00-0A-78",
        "organization": "OLITEC",
        "address_1": "B.P. 592",
        "address_2": "NANCY cedex    54009",
        "country": "FR"
    },
    "000AA9": {
        "oui_hex": "00-0A-A9",
        "organization": "Brooks Automation GmbH",
        "address_1": "Goeschwitzer Strasse 25",
        "address_2": "Jena  Thuringia  07745",
        "country": "DE"
    },
    "000AA5": {
        "oui_hex": "00-0A-A5",
        "organization": "MAXLINK INDUSTRIES LIMITED",
        "address_1": "29A SHENZHEN SPECIAL ZONE",
        "address_2": "SHENZHEN  GUANGDONG  518009",
        "country": "CN"
    },
    "000AA2": {
        "oui_hex": "00-0A-A2",
        "organization": "SYSTEK INC.",
        "address_1": "JCOM BUILDING 402, OJEON-DONG 124-4,",
        "address_2": "UIWANG-SI  GYUNGGI-DO  437-070",
        "country": "KR"
    },
    "000A5B": {
        "oui_hex": "00-0A-5B",
        "organization": "Power-One as",
        "address_1": "P.O. Box 1543",
        "address_2": "Drammen    3007",
        "country": "NO"
    },
    "000A55": {
        "oui_hex": "00-0A-55",
        "organization": "MARKEM Corporation",
        "address_1": "150 Congress Street",
        "address_2": "Keene  NH  03431",
        "country": "US"
    },
    "000A73": {
        "oui_hex": "00-0A-73",
        "organization": "Scientific Atlanta",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  Ga  30042",
        "country": "US"
    },
    "000A69": {
        "oui_hex": "00-0A-69",
        "organization": "SUNNY bell Technology Co., Ltd.",
        "address_1": "#502 BUWON B/D 107-45 BANPO-DONG",
        "address_2": "SEOUL    137-806",
        "country": "KR"
    },
    "000A84": {
        "oui_hex": "00-0A-84",
        "organization": "Rainsun Enterprise Co., Ltd.",
        "address_1": "No.14-3 , Lane 235, Ho-Chen Road",
        "address_2": "ShinDian City  TAIPEI  231",
        "country": "TW"
    },
    "000A7E": {
        "oui_hex": "00-0A-7E",
        "organization": "The Advantage Group",
        "address_1": "1610 Des Peres Road",
        "address_2": "St. Louis  MO  63131",
        "country": "US"
    },
    "000A4C": {
        "oui_hex": "00-0A-4C",
        "organization": "Molecular Devices Corporation",
        "address_1": "1311 Orleans Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000A4D": {
        "oui_hex": "00-0A-4D",
        "organization": "Noritz Corporation",
        "address_1": "5 Minami-Futami,",
        "address_2": "Akashi-shi  Hyogo  674-0093",
        "country": "JP"
    },
    "000A91": {
        "oui_hex": "00-0A-91",
        "organization": "HemoCue AB",
        "address_1": "Box 1204",
        "address_2": "Ängelholm  Skåne län   26223",
        "country": "SE"
    },
    "0009F2": {
        "oui_hex": "00-09-F2",
        "organization": "Cohu, Inc., Electronics Division",
        "address_1": "3912 Calle Fortunada",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "0009E9": {
        "oui_hex": "00-09-E9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0009DC": {
        "oui_hex": "00-09-DC",
        "organization": "Galaxis Technology AG",
        "address_1": "Steinmetzstraße 7",
        "address_2": "Lübeck  Schleswig-Holstein  23556",
        "country": "DE"
    },
    "000A3A": {
        "oui_hex": "00-0A-3A",
        "organization": "J-THREE INTERNATIONAL Holding Co., Ltd.",
        "address_1": "No. 1, Yu-3 Rd., Youth Industrial Park",
        "address_2": "Yang-mei, Taoyuan Hsien    326",
        "country": "TW"
    },
    "000A47": {
        "oui_hex": "00-0A-47",
        "organization": "Allied Vision Technologies",
        "address_1": "Taschenweg 2a",
        "address_2": "Stadtroda  Thüringen  07646",
        "country": "DE"
    },
    "000A3C": {
        "oui_hex": "00-0A-3C",
        "organization": "Enerpoint Ltd.",
        "address_1": "Kaivopuistontie 33",
        "address_2": "Rauma    26100",
        "country": "FI"
    },
    "000A44": {
        "oui_hex": "00-0A-44",
        "organization": "Avery Dennison Deutschland GmbH",
        "address_1": "Ohmstraße 3",
        "address_2": "Eching    85386",
        "country": "DE"
    },
    "0009F8": {
        "oui_hex": "00-09-F8",
        "organization": "UNIMO TECHNOLOGY CO., LTD.",
        "address_1": "BANGBAE DONG 479-12",
        "address_2": "SEOUL    137-820",
        "country": "KR"
    },
    "0009FF": {
        "oui_hex": "00-09-FF",
        "organization": "X.net 2000 GmbH",
        "address_1": "Koenigsberger Str. 2c",
        "address_2": "Reinheim    64354",
        "country": "DE"
    },
    "000A03": {
        "oui_hex": "00-0A-03",
        "organization": "ENDESA SERVICIOS, S.L.",
        "address_1": "AVGDA PARAL.LEL, 51",
        "address_2": "BARCELONA    08004",
        "country": "ES"
    },
    "0009FE": {
        "oui_hex": "00-09-FE",
        "organization": "Daisy Technologies, Inc.",
        "address_1": "1209 Orange Street",
        "address_2": "City of Wilmington  DE  19801",
        "country": "US"
    },
    "000A28": {
        "oui_hex": "00-0A-28",
        "organization": "Motorola",
        "address_1": "600 N. US Hwy 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "000A29": {
        "oui_hex": "00-0A-29",
        "organization": "Pan Dacom Networking AG",
        "address_1": "Dreieich Plaza 1B",
        "address_2": "Dreieich  Hessen  D-63303",
        "country": "DE"
    },
    "0009EB": {
        "oui_hex": "00-09-EB",
        "organization": "HuMANDATA LTD.",
        "address_1": "1-2-10",
        "address_2": "Ibaraki  Osaka  567-0034",
        "country": "JP"
    },
    "0009E8": {
        "oui_hex": "00-09-E8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0009ED": {
        "oui_hex": "00-09-ED",
        "organization": "CipherOptics",
        "address_1": "701 Corporate Center Drive",
        "address_2": "Raleigh  North Carolina  27607",
        "country": "US"
    },
    "000A40": {
        "oui_hex": "00-0A-40",
        "organization": "Crown Audio -- Harmanm International",
        "address_1": "1718 W. Mishawaka Rd",
        "address_2": "Elkhart  IN  46517",
        "country": "US"
    },
    "000A26": {
        "oui_hex": "00-0A-26",
        "organization": "CEIA S.p.A.",
        "address_1": "Zona Industriale di Viciomaggio 54",
        "address_2": "Arezzo  AR  52040",
        "country": "IT"
    },
    "000A1D": {
        "oui_hex": "00-0A-1D",
        "organization": "Optical Communications Products Inc.",
        "address_1": "20961 Knapp St.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "000A16": {
        "oui_hex": "00-0A-16",
        "organization": "Lassen Research",
        "address_1": "31695 Forward Road",
        "address_2": "Manton  CA  96059",
        "country": "US"
    },
    "000A18": {
        "oui_hex": "00-0A-18",
        "organization": "Vichel Inc.",
        "address_1": "3F Jang Bldg. 92-6 Yangjae-dong, Secho-g",
        "address_2": "Seoul    137-130",
        "country": "KR"
    },
    "000A06": {
        "oui_hex": "00-0A-06",
        "organization": "Teledex LLC",
        "address_1": "6311 San Ignacio Avenue",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "0009A9": {
        "oui_hex": "00-09-A9",
        "organization": "Ikanos Communications",
        "address_1": "47709 Fremont Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00099F": {
        "oui_hex": "00-09-9F",
        "organization": "VIDEX INC.",
        "address_1": "1105 NE Circle Blvd",
        "address_2": "Corvallis  OR  97330",
        "country": "US"
    },
    "0009A2": {
        "oui_hex": "00-09-A2",
        "organization": "Interface Co., Ltd.",
        "address_1": "2-5-12-201 Kyonancho",
        "address_2": "Musashino-city  Tokyo  180-0023",
        "country": "JP"
    },
    "0009A1": {
        "oui_hex": "00-09-A1",
        "organization": "Telewise Communications, Inc.",
        "address_1": "2050 Ringwood Avenue",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00097D": {
        "oui_hex": "00-09-7D",
        "organization": "SecWell Networks Oy",
        "address_1": "P.O.BOX 174",
        "address_2": "Tampere    33101",
        "country": "FI"
    },
    "000976": {
        "oui_hex": "00-09-76",
        "organization": "Datasoft ISDN Systems GmbH",
        "address_1": "Schillerplatz 3",
        "address_2": "St. Poelten  Lower Austria  3100",
        "country": "AT"
    },
    "0009C6": {
        "oui_hex": "00-09-C6",
        "organization": "Visionics Corporation",
        "address_1": "5600 Rowland Road",
        "address_2": "Minnetonka  MN  55343",
        "country": "US"
    },
    "0009D1": {
        "oui_hex": "00-09-D1",
        "organization": "SERANOA NETWORKS INC",
        "address_1": "CONCORD OFFICE CENTER",
        "address_2": "CONCORD  MA  01742",
        "country": "US"
    },
    "0009CE": {
        "oui_hex": "00-09-CE",
        "organization": "SpaceBridge Semiconductor Corp.",
        "address_1": "115 rue Champlain",
        "address_2": "Hull  Quebec  J8X3R1",
        "country": "CA"
    },
    "0009B8": {
        "oui_hex": "00-09-B8",
        "organization": "Entise Systems",
        "address_1": "10095 Judy Avenue",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0009AF": {
        "oui_hex": "00-09-AF",
        "organization": "e-generis",
        "address_1": "13 rue du chene germain",
        "address_2": "cesson sevigne    35510",
        "country": "FR"
    },
    "0009AD": {
        "oui_hex": "00-09-AD",
        "organization": "HYUNDAI SYSCOMM, INC.",
        "address_1": "SAN 136-1, AMI-RI, BUBAL-EUB",
        "address_2": "ICHON  KYOUNGKI-DO  467-701",
        "country": "KR"
    },
    "0009BD": {
        "oui_hex": "00-09-BD",
        "organization": "Epygi Technologies, Ltd.",
        "address_1": "5040 Addison Circle",
        "address_2": "Addison  Texas  75001",
        "country": "US"
    },
    "0009C2": {
        "oui_hex": "00-09-C2",
        "organization": "Onity, Inc.",
        "address_1": "2232 Northmont Parkway",
        "address_2": "Duluth  GA  30096",
        "country": "US"
    },
    "0009C3": {
        "oui_hex": "00-09-C3",
        "organization": "NETAS",
        "address_1": "Alemdag Cad. No 171",
        "address_2": "ISTANBUL    81244",
        "country": "TR"
    },
    "0009B5": {
        "oui_hex": "00-09-B5",
        "organization": "3J Tech. Co., Ltd.",
        "address_1": "342 Fushing N. Rd., 2F, Taipei, Taiwan",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "000982": {
        "oui_hex": "00-09-82",
        "organization": "Loewe Opta GmbH",
        "address_1": "Industriestrasse 11",
        "address_2": "Kronach    96317",
        "country": "DE"
    },
    "000983": {
        "oui_hex": "00-09-83",
        "organization": "GlobalTop Technology, Inc.",
        "address_1": " #16 Nan-Ke 9th Road",
        "address_2": "Tainan    741",
        "country": "TW"
    },
    "0009DD": {
        "oui_hex": "00-09-DD",
        "organization": "Mavin Technology Inc.",
        "address_1": "Room 305, Bldg. 52 No. 195-28",
        "address_2": "Chutung, Hsinchu    310",
        "country": "TW"
    },
    "00097A": {
        "oui_hex": "00-09-7A",
        "organization": "Louis Design Labs.",
        "address_1": "2F,NO 4, Lane 497, Chung-Cheng Rd.,Hsin-",
        "address_2": "Hsin-Tien  Taipei Hsien  231",
        "country": "TW"
    },
    "00096B": {
        "oui_hex": "00-09-6B",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "00096D": {
        "oui_hex": "00-09-6D",
        "organization": "Powernet Technologies Corp.",
        "address_1": "371-51, Gasan-Dong Kumchon-Gu,",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "000964": {
        "oui_hex": "00-09-64",
        "organization": "Hi-Techniques, Inc.",
        "address_1": "2515 Frazier Ave.",
        "address_2": "Madison  WI  53713-1505",
        "country": "US"
    },
    "000965": {
        "oui_hex": "00-09-65",
        "organization": "HyunJu Computer Co., Ltd.",
        "address_1": "222-22, Hyunju B/D, Guro 3 Dong, Gurogu",
        "address_2": "Seoul    152-848",
        "country": "KR"
    },
    "000939": {
        "oui_hex": "00-09-39",
        "organization": "ShibaSoku Co.,Ltd.",
        "address_1": "6-8 Shinbashi 4-chome",
        "address_2": "Minato-ku  Tokyo  105-0004",
        "country": "JP"
    },
    "000933": {
        "oui_hex": "00-09-33",
        "organization": "Ophit Co.Ltd.",
        "address_1": "3F. Suntechnovil, 5-27  Mangpo-Dong ,",
        "address_2": "Kyungki-Do    137-070",
        "country": "KR"
    },
    "000932": {
        "oui_hex": "00-09-32",
        "organization": "Omnilux",
        "address_1": "130 W. Union St.",
        "address_2": "Pasadena  CA  91103",
        "country": "US"
    },
    "00091C": {
        "oui_hex": "00-09-1C",
        "organization": "CacheVision, Inc",
        "address_1": "1990 Concourse Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00091A": {
        "oui_hex": "00-09-1A",
        "organization": "Macat Optics & Electronics Co., Ltd.",
        "address_1": "15/F., Macat Center, No. 63 Macat Road",
        "address_2": "Huizhou  Guangdong  516001",
        "country": "CN"
    },
    "00091B": {
        "oui_hex": "00-09-1B",
        "organization": "Digital Generation Inc.",
        "address_1": "5F, Ho-Sam B/D, #30-3, Bongchun6-Dong",
        "address_2": "Kwanak-Ku,  Seoul  151-089",
        "country": "KR"
    },
    "000929": {
        "oui_hex": "00-09-29",
        "organization": "Sanyo Industries (UK) Limited",
        "address_1": "School Road",
        "address_2": "Lowestoft  Suffolk  NR33 9NA",
        "country": "GB"
    },
    "000928": {
        "oui_hex": "00-09-28",
        "organization": "Telecore",
        "address_1": "1800 North Glenville",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "00092E": {
        "oui_hex": "00-09-2E",
        "organization": "B&Tech System Inc.",
        "address_1": "#601, Seo-Jung B/D, 830-24, Youksam-Dong",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00096F": {
        "oui_hex": "00-09-6F",
        "organization": "Beijing Zhongqing Elegant Tech. Corp.,Limited",
        "address_1": "Rm.508, A-Building, Shangdi Digital Scie",
        "address_2": "Beijing    100084",
        "country": "CN"
    },
    "00095E": {
        "oui_hex": "00-09-5E",
        "organization": "Masstech Group Inc.",
        "address_1": "2 East Beaver Creek Rd.",
        "address_2": "Richmond Hill  Ontario  L4B 2N3",
        "country": "CA"
    },
    "00094F": {
        "oui_hex": "00-09-4F",
        "organization": "elmegt GmbH & Co. KG",
        "address_1": "Kommunikationstechnik",
        "address_2": "Peine  Niedersachsen  D-31228",
        "country": "DE"
    },
    "000943": {
        "oui_hex": "00-09-43",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000902": {
        "oui_hex": "00-09-02",
        "organization": "Redline Communications Inc.",
        "address_1": "302 Town Centre Blvd",
        "address_2": "Markham  ON  L3R 0E8",
        "country": "CA"
    },
    "0008FA": {
        "oui_hex": "00-08-FA",
        "organization": "KEB Automation KG",
        "address_1": "Südstraße 38",
        "address_2": "Barntrup  NRW  D-32683",
        "country": "DE"
    },
    "000959": {
        "oui_hex": "00-09-59",
        "organization": "Sitecsoft",
        "address_1": "7th Gugu BD. 145-18 Samsung-Dong",
        "address_2": "Seoul  Seoul  135-090",
        "country": "KR"
    },
    "000957": {
        "oui_hex": "00-09-57",
        "organization": "Supercaller, Inc.",
        "address_1": "101 Saginaw Drive",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "0008D2": {
        "oui_hex": "00-08-D2",
        "organization": "ZOOM Networks Inc.",
        "address_1": "13F,XinLuDao Building,No.1175,Nanshan Ro",
        "address_2": "Shen Zhen  GuangDong Province  518052",
        "country": "US"
    },
    "0008C5": {
        "oui_hex": "00-08-C5",
        "organization": "Liontech Co., Ltd.",
        "address_1": "306, Wooyoung Techno Center, 273-15,",
        "address_2": "Seoul    133-831",
        "country": "KR"
    },
    "0008AC": {
        "oui_hex": "00-08-AC",
        "organization": "Eltromat GmbH",
        "address_1": "Herforder Straße 249-251",
        "address_2": "Leopoldshöhe  Nordrhein-Westfalen  33818",
        "country": "DE"
    },
    "0008AA": {
        "oui_hex": "00-08-AA",
        "organization": "KARAM",
        "address_1": "98-3,  Hankangro 2-KA, Yongsan",
        "address_2": "Seoul    140-012",
        "country": "KR"
    },
    "0008AB": {
        "oui_hex": "00-08-AB",
        "organization": "EnerLinx.com, Inc.",
        "address_1": "3965 South Woodhill Lane",
        "address_2": "New Berlin  WI  53151",
        "country": "US"
    },
    "0008AD": {
        "oui_hex": "00-08-AD",
        "organization": "Toyo-Linx Co., Ltd.",
        "address_1": "Hirakawa-Cho, Chiyada-ku,",
        "address_2": "Tokyo    102-0093",
        "country": "JP"
    },
    "0008F2": {
        "oui_hex": "00-08-F2",
        "organization": "C&S Technology",
        "address_1": "C&S Venture Bldg., NonHyun-Dong,",
        "address_2": "SEOUL    135-829",
        "country": "KR"
    },
    "0008EA": {
        "oui_hex": "00-08-EA",
        "organization": "Motion Control Engineering, Inc",
        "address_1": "11380 White Rock Road",
        "address_2": "Rancho Cordova  CA  95742",
        "country": "US"
    },
    "0008ED": {
        "oui_hex": "00-08-ED",
        "organization": "ST&T Instrument Corp.",
        "address_1": "16 Shing-Gong Road, Yung-Kung Industrial",
        "address_2": "Yung-Kung  Tainan  710",
        "country": "TW"
    },
    "000888": {
        "oui_hex": "00-08-88",
        "organization": "OULLIM Information Technology Inc,.",
        "address_1": "a-10th FL,. IT Venture Tower,",
        "address_2": "Seoul    138-803",
        "country": "KR"
    },
    "000885": {
        "oui_hex": "00-08-85",
        "organization": "EMS Dr. Thomas Wünsche",
        "address_1": "Sonnenhang 3",
        "address_2": "",
        "country": "DE"
    },
    "000872": {
        "oui_hex": "00-08-72",
        "organization": "Sorenson Communications",
        "address_1": "4192 South Riverboat Road",
        "address_2": "Salt Lake City  UT  84123",
        "country": "US"
    },
    "00089A": {
        "oui_hex": "00-08-9A",
        "organization": "Alcatel Microelectronics",
        "address_1": "Excelsiorlaan 44-46",
        "address_2": "B-1930 Zavantem",
        "country": "BE"
    },
    "0008A1": {
        "oui_hex": "00-08-A1",
        "organization": "CNet Technology Inc.",
        "address_1": "No.15, Park Avenue II, Science-Based Ind",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "000893": {
        "oui_hex": "00-08-93",
        "organization": "LE INFORMATION COMMUNICATION INC.",
        "address_1": "Rm, 4501, DA-Dong Chungang Circulation C",
        "address_2": "Seoul    152-721",
        "country": "KR"
    },
    "0008B0": {
        "oui_hex": "00-08-B0",
        "organization": "BKtel communications GmbH",
        "address_1": "Benzstraße 4",
        "address_2": "41836 Hückelhoven-Baal  NRW  41836",
        "country": "DE"
    },
    "0008CA": {
        "oui_hex": "00-08-CA",
        "organization": "TwinHan Technology Co.,Ltd",
        "address_1": "13F-6,No 79,Sec 1,Hsin Tai Wu RD.,Hsi-Ch",
        "address_2": "Taipei Hsien    221",
        "country": "TW"
    },
    "0008B6": {
        "oui_hex": "00-08-B6",
        "organization": "RouteFree, Inc.",
        "address_1": "3400 Hillview Ave., Building 5",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "0008D8": {
        "oui_hex": "00-08-D8",
        "organization": "Dowkey Microwave",
        "address_1": "4822 McGrath Street",
        "address_2": "Ventura  Ca  93003",
        "country": "US"
    },
    "0008DF": {
        "oui_hex": "00-08-DF",
        "organization": "Alistel Inc.",
        "address_1": "Midori Bldg. 2F",
        "address_2": "Yokohama  Kanagawa  222-0001",
        "country": "JP"
    },
    "0008DB": {
        "oui_hex": "00-08-DB",
        "organization": "Corrigent Systems",
        "address_1": "126 Yigal Alon",
        "address_2": "Tel Aviv    67443",
        "country": "IL"
    },
    "00087C": {
        "oui_hex": "00-08-7C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000879": {
        "oui_hex": "00-08-79",
        "organization": "CEM Corporation",
        "address_1": "P.O. Box 200",
        "address_2": "Matthews  NC  28106",
        "country": "US"
    },
    "00087D": {
        "oui_hex": "00-08-7D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000875": {
        "oui_hex": "00-08-75",
        "organization": "Acorp Electronics Corp.",
        "address_1": "8F, No.111-6,Shing Teh Rd,",
        "address_2": "San Chung  Taipei Hsien  241",
        "country": "TW"
    },
    "000816": {
        "oui_hex": "00-08-16",
        "organization": "Bluelon ApS",
        "address_1": "Nattergalevej 6",
        "address_2": "",
        "country": "DK"
    },
    "000811": {
        "oui_hex": "00-08-11",
        "organization": "VOIX Corporation",
        "address_1": "1991-3 4th Floor Top's Venture Tower",
        "address_2": "Seoul    138-090",
        "country": "KR"
    },
    "000806": {
        "oui_hex": "00-08-06",
        "organization": "Raonet Systems, Inc.",
        "address_1": "West Wing 14F, IT Venture Tower 78",
        "address_2": "Seoul    138-803",
        "country": "KR"
    },
    "00086F": {
        "oui_hex": "00-08-6F",
        "organization": "Resources Computer Network Ltd.",
        "address_1": "Rm 324, Tech Centre, 72 Tat Chee Ave.,",
        "address_2": "",
        "country": "HK"
    },
    "000867": {
        "oui_hex": "00-08-67",
        "organization": "Uptime Devices",
        "address_1": "11724 Dunfries Lane",
        "address_2": "Austin  Texas  78754",
        "country": "US"
    },
    "0007F8": {
        "oui_hex": "00-07-F8",
        "organization": "ITDevices, Inc.",
        "address_1": "606 110th Ave. NE",
        "address_2": "Bellevue  WA  98004",
        "country": "US"
    },
    "0007F3": {
        "oui_hex": "00-07-F3",
        "organization": "Thinkengine Networks",
        "address_1": "100 Nickerson Road",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "00081C": {
        "oui_hex": "00-08-1C",
        "organization": "@pos.com",
        "address_1": "3051 North First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00081E": {
        "oui_hex": "00-08-1E",
        "organization": "Repeatit AB",
        "address_1": "Farogatan 7",
        "address_2": "",
        "country": "SE"
    },
    "000856": {
        "oui_hex": "00-08-56",
        "organization": "Gamatronic Electronic Industries Ltd.",
        "address_1": "Hartum Street 14",
        "address_2": "",
        "country": "IL"
    },
    "000853": {
        "oui_hex": "00-08-53",
        "organization": "Schleicher GmbH & Co. Relaiswerke KG",
        "address_1": "Pichelswerderstrasse 3-5",
        "address_2": "",
        "country": "DE"
    },
    "000826": {
        "oui_hex": "00-08-26",
        "organization": "Colorado Med Tech",
        "address_1": "6175 Longbow Dr.",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "00085E": {
        "oui_hex": "00-08-5E",
        "organization": "PCO AG",
        "address_1": "Donaupark 11",
        "address_2": "",
        "country": "DE"
    },
    "00079A": {
        "oui_hex": "00-07-9A",
        "organization": "Verint Systems Inc",
        "address_1": "1800 Berlier, Suite 440",
        "address_2": "Laval,   Quebec  H7L 4S4",
        "country": "CA"
    },
    "000774": {
        "oui_hex": "00-07-74",
        "organization": "GuangZhou Thinker Technology Co. Ltd.",
        "address_1": "109 Zhongshan Ave., Tianhe District",
        "address_2": "    510630",
        "country": "CN"
    },
    "000798": {
        "oui_hex": "00-07-98",
        "organization": "Selea SRL",
        "address_1": "Via A. Moro No. 69",
        "address_2": "",
        "country": "IT"
    },
    "000791": {
        "oui_hex": "00-07-91",
        "organization": "International Data Communications, Inc.",
        "address_1": "47873 Fremont Blvd.",
        "address_2": "Fremont  CA  04538",
        "country": "US"
    },
    "0007EE": {
        "oui_hex": "00-07-EE",
        "organization": "telco Informationssysteme GmbH",
        "address_1": "Schulstrasse 38",
        "address_2": "",
        "country": "DE"
    },
    "0007E2": {
        "oui_hex": "00-07-E2",
        "organization": "Bitworks, Inc.",
        "address_1": "#1 Bitworks Way",
        "address_2": "Prairie Grove  AR  72753",
        "country": "US"
    },
    "0007E6": {
        "oui_hex": "00-07-E6",
        "organization": "edgeflow Canada Inc.",
        "address_1": "329 March Road",
        "address_2": "    K2K 2E1",
        "country": "CA"
    },
    "0007E5": {
        "oui_hex": "00-07-E5",
        "organization": "Coup Corporation",
        "address_1": "1-24-4 Marusen 2nd Bld. 4F,",
        "address_2": "Tokyo",
        "country": "JP"
    },
    "0007DE": {
        "oui_hex": "00-07-DE",
        "organization": "eCopilt AB",
        "address_1": "Veddestavagen 24",
        "address_2": "",
        "country": "SE"
    },
    "0007C8": {
        "oui_hex": "00-07-C8",
        "organization": "Brain21, Inc.",
        "address_1": "19F Mesa B/D, 204 Hoihyun-Dong",
        "address_2": "Seoul    100-051",
        "country": "KR"
    },
    "0007C5": {
        "oui_hex": "00-07-C5",
        "organization": "Gcom, Inc.",
        "address_1": "1800 Woodfield Dr.",
        "address_2": "Savoy  IL  61874",
        "country": "US"
    },
    "0007C1": {
        "oui_hex": "00-07-C1",
        "organization": "Overture Networks, Inc.",
        "address_1": "637 Davis Drive",
        "address_2": "Morrisville  NC  227560",
        "country": "US"
    },
    "0007A7": {
        "oui_hex": "00-07-A7",
        "organization": "A-Z Inc.",
        "address_1": "5-5-17 Kamikoushien",
        "address_2": "",
        "country": "JP"
    },
    "0007A6": {
        "oui_hex": "00-07-A6",
        "organization": "Leviton Manufacturing Co., Inc.",
        "address_1": "4330 Michoud Blvd",
        "address_2": "New Orleans  LA  70129",
        "country": "US"
    },
    "0007A3": {
        "oui_hex": "00-07-A3",
        "organization": "Ositis Software, Inc.",
        "address_1": "6120 Stoneridge Mall Road",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "0007C2": {
        "oui_hex": "00-07-C2",
        "organization": "Netsys Telecom",
        "address_1": "4F, KyungNam B/D, 830-48, YeokSam-Dong",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "00078F": {
        "oui_hex": "00-07-8F",
        "organization": "Emkay Innovative Products",
        "address_1": "53, Pao Hsing Rd., Hsintien City",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000782": {
        "oui_hex": "00-07-82",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "0007AE": {
        "oui_hex": "00-07-AE",
        "organization": "Britestream Networks, Inc.",
        "address_1": "12401 Research Blvd.",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0007B1": {
        "oui_hex": "00-07-B1",
        "organization": "Equator Technologies",
        "address_1": "1300 White Oaks Rd.",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "0005F9": {
        "oui_hex": "00-05-F9",
        "organization": "TOA Corporation",
        "address_1": "2-1 Takamatsu-cho,",
        "address_2": "Hyogo    665-0043",
        "country": "JP"
    },
    "0007CA": {
        "oui_hex": "00-07-CA",
        "organization": "Creatix Polymedia Ges Fur Kommunikaitonssysteme",
        "address_1": "Heinrich-Barth-Straße 3",
        "address_2": "",
        "country": "DE"
    },
    "0007DF": {
        "oui_hex": "00-07-DF",
        "organization": "Vbrick Systems Inc.",
        "address_1": "12 Beaumont Road",
        "address_2": "Wallingford  CT  06492",
        "country": "US"
    },
    "000744": {
        "oui_hex": "00-07-44",
        "organization": "Unico, Inc.",
        "address_1": "3725 Nicholson Rd.",
        "address_2": "Franksville  WI  53126",
        "country": "US"
    },
    "000749": {
        "oui_hex": "00-07-49",
        "organization": "CENiX Inc.",
        "address_1": "5141 California Avenue",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "00073D": {
        "oui_hex": "00-07-3D",
        "organization": "Nanjing Postel Telecommunications Co., Ltd.",
        "address_1": "No. 187, ShengZhou Road,",
        "address_2": "    210004",
        "country": "CN"
    },
    "000739": {
        "oui_hex": "00-07-39",
        "organization": "Scotty Group Austria Gmbh",
        "address_1": "Teslastrasse 4",
        "address_2": "8074 Grambach    8074",
        "country": "AT"
    },
    "00074E": {
        "oui_hex": "00-07-4E",
        "organization": "IPFRONT Inc",
        "address_1": "4F ALT Bldg.,",
        "address_2": "  Tokyo  101-0021",
        "country": "JP"
    },
    "000752": {
        "oui_hex": "00-07-52",
        "organization": "Rhythm Watch Co., Ltd.",
        "address_1": "321 Shinshukushinden, Showa-Machi,",
        "address_2": "    344-0196",
        "country": "JP"
    },
    "00074F": {
        "oui_hex": "00-07-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000743": {
        "oui_hex": "00-07-43",
        "organization": "Chelsio Communications",
        "address_1": "170 S. Whismon Rd.",
        "address_2": "Mountain View  CA  94041-1512",
        "country": "US"
    },
    "000747": {
        "oui_hex": "00-07-47",
        "organization": "Mecalc",
        "address_1": "PO Box 7958",
        "address_2": "",
        "country": "ZA"
    },
    "000779": {
        "oui_hex": "00-07-79",
        "organization": "Sungil Telecom Co., Ltd.",
        "address_1": "#321, Gongdan-Dong,",
        "address_2": "    730-030",
        "country": "KR"
    },
    "00077E": {
        "oui_hex": "00-07-7E",
        "organization": "Elrest GmbH",
        "address_1": "Leibnizstraße 10",
        "address_2": "",
        "country": "DE"
    },
    "000778": {
        "oui_hex": "00-07-78",
        "organization": "GERSTEL GmbH & Co. KG",
        "address_1": "Eberhard-Gerstel-Platz 1",
        "address_2": "Mülheim an der Ruhr",
        "country": "DE"
    },
    "00076D": {
        "oui_hex": "00-07-6D",
        "organization": "Flexlight Networks",
        "address_1": "15 Atir Yeda St.",
        "address_2": "",
        "country": "IL"
    },
    "000730": {
        "oui_hex": "00-07-30",
        "organization": "Hutchison OPTEL Telecom Technology Co., Ltd.",
        "address_1": "No. 28 Xinwai Street",
        "address_2": "Beijing",
        "country": "CN"
    },
    "000722": {
        "oui_hex": "00-07-22",
        "organization": "The Nielsen Company",
        "address_1": "501 Brooker Creek Blvd.",
        "address_2": "Oldsmar  FL  34677",
        "country": "US"
    },
    "000760": {
        "oui_hex": "00-07-60",
        "organization": "TOMIS Information & Telecom Corp.",
        "address_1": "Youngdeungpo telephone office - extensio",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000735": {
        "oui_hex": "00-07-35",
        "organization": "Flarion Technologies, Inc.",
        "address_1": "135 Route 202/206 South",
        "address_2": "Bedminster  NJ  07921",
        "country": "US"
    },
    "00075E": {
        "oui_hex": "00-07-5E",
        "organization": "Ametek Power Instruments",
        "address_1": "4050 NW 121 Avenue",
        "address_2": "Coral Springs  FL  33065",
        "country": "US"
    },
    "00071F": {
        "oui_hex": "00-07-1F",
        "organization": "European Systems Integration",
        "address_1": "455 Promenade Des Anglas",
        "address_2": "",
        "country": "FR"
    },
    "000721": {
        "oui_hex": "00-07-21",
        "organization": "Formac Elektronik GmbH",
        "address_1": "Dofstraße 33",
        "address_2": "",
        "country": "DE"
    },
    "000786": {
        "oui_hex": "00-07-86",
        "organization": "Wireless Networks Inc.",
        "address_1": "#300, 3016 Fifth Ave. NE",
        "address_2": "    T2A 6K4",
        "country": "CA"
    },
    "0006BC": {
        "oui_hex": "00-06-BC",
        "organization": "Macrolink, Inc.",
        "address_1": "1500 N Kellogg Dr.",
        "address_2": "Anaheim  CA  92807",
        "country": "US"
    },
    "0006C2": {
        "oui_hex": "00-06-C2",
        "organization": "Smartmatic Corporation",
        "address_1": "6400 Congress Ave., Suite 1300",
        "address_2": "Boca Raton  FL  33487",
        "country": "US"
    },
    "000654": {
        "oui_hex": "00-06-54",
        "organization": "Winpresa Building Automation Technologies GmbH",
        "address_1": "Vivenotgasse 53/2",
        "address_2": "",
        "country": "AT"
    },
    "0006B4": {
        "oui_hex": "00-06-B4",
        "organization": "Vorne Industries, Inc.",
        "address_1": "1445 Industrial Dr.",
        "address_2": "Itasca  IL  60143-1849",
        "country": "US"
    },
    "0006AE": {
        "oui_hex": "00-06-AE",
        "organization": "Himachal Futuristic Communications Ltd",
        "address_1": "8, Commercial Complex",
        "address_2": "New Dehli    110048",
        "country": "IN"
    },
    "0006E5": {
        "oui_hex": "00-06-E5",
        "organization": "Fujian Newland Computer Ltd. Co.",
        "address_1": "141F Sunshine Holiday Hotel",
        "address_2": "Fuzhou Fujian    350005",
        "country": "CN"
    },
    "0006DE": {
        "oui_hex": "00-06-DE",
        "organization": "Flash Technology",
        "address_1": "P.O. Box 681509",
        "address_2": "Franklin  TN  37068",
        "country": "US"
    },
    "0006DF": {
        "oui_hex": "00-06-DF",
        "organization": "AIDONIC Corporation",
        "address_1": "2-7-10 Otsuka, Bunkyo-ku,",
        "address_2": "  Tokyo,  112-0012",
        "country": "JP"
    },
    "0006DD": {
        "oui_hex": "00-06-DD",
        "organization": "AT & T Laboratories - Cambridge Ltd",
        "address_1": "24a Trumpington Street",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "0006F0": {
        "oui_hex": "00-06-F0",
        "organization": "Digeo, Inc.",
        "address_1": "8815 122nd Ave., NE",
        "address_2": "Kirkland  WA  98033",
        "country": "US"
    },
    "000700": {
        "oui_hex": "00-07-00",
        "organization": "Zettamedia Korea",
        "address_1": "Suite 1008, Kumkang Venturetel, 1108",
        "address_2": "Kyounggido,",
        "country": "KR"
    },
    "0006C5": {
        "oui_hex": "00-06-C5",
        "organization": "INNOVI Technologies Limited",
        "address_1": "31st Floor, China Online Centre",
        "address_2": "  Wanchai",
        "country": "HK"
    },
    "0006C6": {
        "oui_hex": "00-06-C6",
        "organization": "lesswire AG",
        "address_1": "Im Technologiepark 25",
        "address_2": "",
        "country": "DE"
    },
    "0006B7": {
        "oui_hex": "00-06-B7",
        "organization": "TELEM GmbH",
        "address_1": "Lise-Meitner-Allee 31",
        "address_2": "",
        "country": "DE"
    },
    "0006EF": {
        "oui_hex": "00-06-EF",
        "organization": "Maxxan Systems, Inc.",
        "address_1": "107 Bonaventura Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0006E9": {
        "oui_hex": "00-06-E9",
        "organization": "Intime Corp.",
        "address_1": "324-4, Yangjae-dong, 2F",
        "address_2": "",
        "country": "KR"
    },
    "0006EA": {
        "oui_hex": "00-06-EA",
        "organization": "ELZET80 Mikrocomputer GmbH&Co. KG",
        "address_1": "Theaterplatz 9",
        "address_2": "",
        "country": "DE"
    },
    "000708": {
        "oui_hex": "00-07-08",
        "organization": "Bitrage Inc.",
        "address_1": "100 Southpark Blvd.",
        "address_2": "Saint Augustine  FL  32086",
        "country": "US"
    },
    "000712": {
        "oui_hex": "00-07-12",
        "organization": "JAL Information Technology",
        "address_1": "Network Solution Dep. JAL-Tamachi Bldg.",
        "address_2": "Tokyo",
        "country": "JP"
    },
    "000713": {
        "oui_hex": "00-07-13",
        "organization": "IP One, Inc.",
        "address_1": "Sammi Bldg., 1004",
        "address_2": "Seoul,    135-083",
        "country": "KR"
    },
    "000707": {
        "oui_hex": "00-07-07",
        "organization": "Interalia Inc.",
        "address_1": "4110-79th Street N.W.",
        "address_2": "    T3B 5C2",
        "country": "CA"
    },
    "0006F2": {
        "oui_hex": "00-06-F2",
        "organization": "Platys Communications",
        "address_1": "3150A Coronado Dr.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0006FA": {
        "oui_hex": "00-06-FA",
        "organization": "IP SQUARE Co, Ltd.",
        "address_1": "1-9-11, Hakataekihigashi,",
        "address_2": "Fukuoka    812-0013",
        "country": "JP"
    },
    "000703": {
        "oui_hex": "00-07-03",
        "organization": "CSEE Transport",
        "address_1": "4, avenue du CANADA",
        "address_2": "",
        "country": "FR"
    },
    "000706": {
        "oui_hex": "00-07-06",
        "organization": "Sanritz Corporation",
        "address_1": "1-30-13, Narimasu,",
        "address_2": "    175-0094",
        "country": "JP"
    },
    "0006D1": {
        "oui_hex": "00-06-D1",
        "organization": "Tahoe Networks, Inc.",
        "address_1": "3052 Orchard Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0006D4": {
        "oui_hex": "00-06-D4",
        "organization": "Interactive Objects, Inc.",
        "address_1": "12600 SE 38th St.",
        "address_2": "Bellevue  WA  98006",
        "country": "US"
    },
    "0006CA": {
        "oui_hex": "00-06-CA",
        "organization": "American Computer & Digital Components, Inc. (ACDC)",
        "address_1": "440 Cloverleaf Drive",
        "address_2": "Baldwin Park  CA  91706",
        "country": "US"
    },
    "0006CE": {
        "oui_hex": "00-06-CE",
        "organization": "DATENO",
        "address_1": "Rue Amiral Berenger",
        "address_2": "",
        "country": "FR"
    },
    "00068E": {
        "oui_hex": "00-06-8E",
        "organization": "HID Corporation",
        "address_1": "9292 Jeronimo Road",
        "address_2": "Irvine  CA  92618-1905",
        "country": "US"
    },
    "00068A": {
        "oui_hex": "00-06-8A",
        "organization": "NeuronNet Co. Ltd. R&D Center",
        "address_1": "735-34 Dasung Bldg., Yuksam-dong,",
        "address_2": "",
        "country": "KR"
    },
    "000685": {
        "oui_hex": "00-06-85",
        "organization": "NetNearU Corporation",
        "address_1": "2908 Finfeather Road",
        "address_2": "Bryan  TX  77801",
        "country": "US"
    },
    "000650": {
        "oui_hex": "00-06-50",
        "organization": "Tiburon Networks, Inc.",
        "address_1": "200 Minuteman Rd.",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "00065E": {
        "oui_hex": "00-06-5E",
        "organization": "Photuris, Inc.",
        "address_1": "20 Corporate Place South",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "00067F": {
        "oui_hex": "00-06-7F",
        "organization": "Digeo, Inc.",
        "address_1": "8815 122nd Avenue NE",
        "address_2": "Kirkland  WA  98033",
        "country": "US"
    },
    "000683": {
        "oui_hex": "00-06-83",
        "organization": "Bravara Communications, Inc.",
        "address_1": "2650 East Bayshore Road",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "000655": {
        "oui_hex": "00-06-55",
        "organization": "Yipee, Inc.",
        "address_1": "555 International Drive",
        "address_2": "Williamsville  NY  14221",
        "country": "US"
    },
    "000676": {
        "oui_hex": "00-06-76",
        "organization": "Novra Technologies Inc.",
        "address_1": "900-330 St. Mary Avenue",
        "address_2": "Winnipeg  Manitoba  R3C 3Z5",
        "country": "CA"
    },
    "000664": {
        "oui_hex": "00-06-64",
        "organization": "Fostex Corporation",
        "address_1": "3-2-35, Musashino, Akishima,",
        "address_2": "Tokyo    196-0021",
        "country": "JP"
    },
    "00067A": {
        "oui_hex": "00-06-7A",
        "organization": "JMP Systems",
        "address_1": "3rd Fl. Shinwha Bldg.,",
        "address_2": "Seocho-ku  Seoul,",
        "country": "KR"
    },
    "000673": {
        "oui_hex": "00-06-73",
        "organization": "TKH Security Solutions USA",
        "address_1": "12920 Cloverleaf Center Drive",
        "address_2": "Germantown  MD  20874",
        "country": "US"
    },
    "00069B": {
        "oui_hex": "00-06-9B",
        "organization": "AVT Audio Video Technologies GmbH",
        "address_1": "Rathsbergstraße 17",
        "address_2": "",
        "country": "DE"
    },
    "000693": {
        "oui_hex": "00-06-93",
        "organization": "Flexus Computer Technology, Inc.",
        "address_1": "8F-2, No.5, Alley22, Lane 513,",
        "address_2": "Taipei 114",
        "country": "TW"
    },
    "00065D": {
        "oui_hex": "00-06-5D",
        "organization": "Heidelberg Web Systems",
        "address_1": "121 Technology Dr.",
        "address_2": "Durham  NH  03824",
        "country": "US"
    },
    "0006B0": {
        "oui_hex": "00-06-B0",
        "organization": "Comtech EF Data Corp.",
        "address_1": "2114 W. 7th St.",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "000696": {
        "oui_hex": "00-06-96",
        "organization": "Advent Networks",
        "address_1": "9600 Great Hills Tr.",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0005D7": {
        "oui_hex": "00-05-D7",
        "organization": "Vista Imaging, Inc.",
        "address_1": "521 Taylor Way",
        "address_2": "San Carlos  CA  94070",
        "country": "US"
    },
    "0005DB": {
        "oui_hex": "00-05-DB",
        "organization": "PSI Nentec GmbH",
        "address_1": "Greschbachstraße12",
        "address_2": "Karlsruhe    76229",
        "country": "DE"
    },
    "0005DD": {
        "oui_hex": "00-05-DD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000628": {
        "oui_hex": "00-06-28",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00061D": {
        "oui_hex": "00-06-1D",
        "organization": "MIP Telecom, Inc.",
        "address_1": "3rd Floor, Sangil BLDG,",
        "address_2": "Seoul    151-069",
        "country": "KR"
    },
    "000619": {
        "oui_hex": "00-06-19",
        "organization": "Connection Technology Systems",
        "address_1": "18F-6, No. 79, Sec. 1,",
        "address_2": "Hsinchih  Taipei,",
        "country": "TW"
    },
    "000640": {
        "oui_hex": "00-06-40",
        "organization": "White Rock Networks",
        "address_1": "Suite #900",
        "address_2": "Dallas  TX  75252",
        "country": "US"
    },
    "000644": {
        "oui_hex": "00-06-44",
        "organization": "NextGen Business Solutions, Inc",
        "address_1": "KKS Higashi-Sapporo Bldg.3-5-3-24, Higashi-Sapporo",
        "address_2": "Shiroishi-ku, Sapporo-city  Hokkaido  003-0003",
        "country": "JP"
    },
    "000645": {
        "oui_hex": "00-06-45",
        "organization": "Meisei Electric Co. Ltd.",
        "address_1": "249-1, Moriya-kou, Moriya",
        "address_2": "    302-0192",
        "country": "JP"
    },
    "A06A00": {
        "oui_hex": "A0-6A-00",
        "organization": "Verilink Corporation",
        "address_1": "127 Jetplex Circle",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "0005F8": {
        "oui_hex": "00-05-F8",
        "organization": "Real Time Access, Inc.",
        "address_1": "455 N. Canyons Pkwy.",
        "address_2": "Livermore  CA  94550",
        "country": "US"
    },
    "0005EB": {
        "oui_hex": "00-05-EB",
        "organization": "Blue Ridge Networks, Inc.",
        "address_1": "14120 Parke Long Court",
        "address_2": "Chantilly  VA  20151",
        "country": "US"
    },
    "0005E8": {
        "oui_hex": "00-05-E8",
        "organization": "TurboWave, Inc.",
        "address_1": "555 South State",
        "address_2": "Orem  UT  84058",
        "country": "US"
    },
    "0005F6": {
        "oui_hex": "00-05-F6",
        "organization": "Young Chang Co. Ltd.",
        "address_1": "1432 Main Street",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "0005FC": {
        "oui_hex": "00-05-FC",
        "organization": "Schenck Pegasus Corp.",
        "address_1": "2890 John R Road",
        "address_2": "Troy  MI  48083",
        "country": "US"
    },
    "00063A": {
        "oui_hex": "00-06-3A",
        "organization": "Dura Micro, Inc.",
        "address_1": "13580 Fifth Street",
        "address_2": "Chino  CA  91710",
        "country": "US"
    },
    "000632": {
        "oui_hex": "00-06-32",
        "organization": "Mesco Engineering GmbH",
        "address_1": "Wiesentalstraße 74",
        "address_2": "",
        "country": "DE"
    },
    "000634": {
        "oui_hex": "00-06-34",
        "organization": "GTE Airfone Inc.",
        "address_1": "2809 Butterfield",
        "address_2": "Oakbrook  IL  60522",
        "country": "US"
    },
    "00060C": {
        "oui_hex": "00-06-0C",
        "organization": "Melco Industries, Inc.",
        "address_1": "1575 W. 124th Ave.",
        "address_2": "Denver  CO  80234",
        "country": "US"
    },
    "00060E": {
        "oui_hex": "00-06-0E",
        "organization": "IGYS Systems, Inc.",
        "address_1": "7373 Lincoln Way",
        "address_2": "Garden Grove  CA  92841",
        "country": "US"
    },
    "000614": {
        "oui_hex": "00-06-14",
        "organization": "Prism Holdings",
        "address_1": "P.O. Box 901,",
        "address_2": "Gauteng",
        "country": "ZA"
    },
    "000608": {
        "oui_hex": "00-06-08",
        "organization": "At-Sky SAS",
        "address_1": "ZI Athelia 3, Voi Atlas",
        "address_2": "",
        "country": "FR"
    },
    "0005C3": {
        "oui_hex": "00-05-C3",
        "organization": "Pacific Instruments, Inc.",
        "address_1": "4080 Pike Lane",
        "address_2": "Concord  CA  94520",
        "country": "US"
    },
    "0005B9": {
        "oui_hex": "00-05-B9",
        "organization": "Airvana, Inc.",
        "address_1": "25 Industrial Ave.",
        "address_2": "Chlemsford  MA  01824",
        "country": "US"
    },
    "0005BC": {
        "oui_hex": "00-05-BC",
        "organization": "Resource Data Management Ltd",
        "address_1": "80 Johnstone Avenue,",
        "address_2": "Scotland    G52 4NZ",
        "country": "GB"
    },
    "0005BE": {
        "oui_hex": "00-05-BE",
        "organization": "Kongsberg Seatex AS",
        "address_1": "Pirsenteret",
        "address_2": "",
        "country": "NO"
    },
    "0005BD": {
        "oui_hex": "00-05-BD",
        "organization": "ROAX BV",
        "address_1": "Sterrenbergweg 29",
        "address_2": "",
        "country": "NL"
    },
    "0005C1": {
        "oui_hex": "00-05-C1",
        "organization": "A-Kyung Motion, Inc.",
        "address_1": "54-10, Munjung-Dong",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0005B4": {
        "oui_hex": "00-05-B4",
        "organization": "Aceex Corporation",
        "address_1": "2F, No. 2, Alley 1, Sze-Wei Lane",
        "address_2": "    23138",
        "country": "TW"
    },
    "000598": {
        "oui_hex": "00-05-98",
        "organization": "CRONOS S.r.l.",
        "address_1": "Via cavour 58/A",
        "address_2": "",
        "country": "IT"
    },
    "0005B7": {
        "oui_hex": "00-05-B7",
        "organization": "Arbor Technology Corp.",
        "address_1": "5F, No. 738, Zhong Zheng Rd.,",
        "address_2": "",
        "country": "TW"
    },
    "00059B": {
        "oui_hex": "00-05-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00057E": {
        "oui_hex": "00-05-7E",
        "organization": "Eckelmann Steuerungstechnik GmbH",
        "address_1": "Berliner Strasse 161",
        "address_2": "",
        "country": "DE"
    },
    "000580": {
        "oui_hex": "00-05-80",
        "organization": "FibroLAN Ltd.",
        "address_1": "2 Hacarmel st., POB 544",
        "address_2": "Yokneam Illit    20692",
        "country": "IL"
    },
    "000582": {
        "oui_hex": "00-05-82",
        "organization": "ClearCube Technology",
        "address_1": "8834 Capital of Texas Hwy,",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0005D9": {
        "oui_hex": "00-05-D9",
        "organization": "Techno Valley, Inc.",
        "address_1": "ASIC Venture Town 5F,",
        "address_2": "Seoul    135-072",
        "country": "KR"
    },
    "0005DC": {
        "oui_hex": "00-05-DC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0005D0": {
        "oui_hex": "00-05-D0",
        "organization": "Solinet Systems",
        "address_1": "1200-180 Elgin St.",
        "address_2": "    K2P 2K3",
        "country": "CA"
    },
    "00059F": {
        "oui_hex": "00-05-9F",
        "organization": "Yotta Networks, Inc.",
        "address_1": "2201 Avenue K",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "000587": {
        "oui_hex": "00-05-87",
        "organization": "Locus, Incorporated",
        "address_1": "5540 Research Park Drive",
        "address_2": "Madison  WI  53711",
        "country": "US"
    },
    "000590": {
        "oui_hex": "00-05-90",
        "organization": "Swissvoice Ltd.",
        "address_1": "Ziegelmattstrasse 1",
        "address_2": "",
        "country": "CH"
    },
    "000595": {
        "oui_hex": "00-05-95",
        "organization": "Alesis Corporation",
        "address_1": "1633 26th Street",
        "address_2": "Santa Monica  CA  90404",
        "country": "US"
    },
    "000578": {
        "oui_hex": "00-05-78",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000572": {
        "oui_hex": "00-05-72",
        "organization": "Deonet Co., Ltd.",
        "address_1": "#127-5 Jinyoung B/D 3th F,",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000576": {
        "oui_hex": "00-05-76",
        "organization": "NSM Technology Ltd.",
        "address_1": "22 Floor, Times Tower",
        "address_2": "Koloon",
        "country": "HK"
    },
    "00056A": {
        "oui_hex": "00-05-6A",
        "organization": "Heuft Systemtechnik GmbH",
        "address_1": "Brohltalstr 31-33",
        "address_2": "Deutschland",
        "country": "DE"
    },
    "000568": {
        "oui_hex": "00-05-68",
        "organization": "Piltofish Networks AB",
        "address_1": "Stora Badhusgatan 18-20",
        "address_2": "",
        "country": "SE"
    },
    "0005B6": {
        "oui_hex": "00-05-B6",
        "organization": "INSYS Microelectronics GmbH",
        "address_1": "Hermann-Köhl-Straße 22",
        "address_2": "",
        "country": "DE"
    },
    "000555": {
        "oui_hex": "00-05-55",
        "organization": "Japan Cash Machine Co., Ltd.",
        "address_1": "No. 3-15, 2-chome, Nishiwaki,",
        "address_2": "    547-0035",
        "country": "JP"
    },
    "000552": {
        "oui_hex": "00-05-52",
        "organization": "Xycotec Computer GmbH",
        "address_1": "Karl-Heinz-Beckurts-Str. 4",
        "address_2": "",
        "country": "DE"
    },
    "00054A": {
        "oui_hex": "00-05-4A",
        "organization": "Ario Data Networks, Inc.",
        "address_1": "2890 Zanker Road, Suite 203",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000548": {
        "oui_hex": "00-05-48",
        "organization": "Disco Corporation",
        "address_1": "13-11 Omori-Kita 2-chome",
        "address_2": "Ota-ku  Tokyo  143-8580",
        "country": "JP"
    },
    "0004F7": {
        "oui_hex": "00-04-F7",
        "organization": "Omega Band, Inc.",
        "address_1": "9020-I Capital of Texas Hghwy N",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "0004EE": {
        "oui_hex": "00-04-EE",
        "organization": "Lincoln Electric Company",
        "address_1": "22801 St. Clair Avenue",
        "address_2": "Cleveland  OH  44117-1199",
        "country": "US"
    },
    "0004F0": {
        "oui_hex": "00-04-F0",
        "organization": "International Computers, Ltd",
        "address_1": "1 Wenlock Way",
        "address_2": "    UK",
        "country": "GB"
    },
    "000527": {
        "oui_hex": "00-05-27",
        "organization": "SJ Tek Co. Ltd",
        "address_1": "Ho gae Dong 976-5, Dong An Ku,",
        "address_2": "",
        "country": "KR"
    },
    "000529": {
        "oui_hex": "00-05-29",
        "organization": "Shanghai Broadan Communication Technology Co., Ltd",
        "address_1": "15F, Suntime International Mansion",
        "address_2": "    200122",
        "country": "CN"
    },
    "00052C": {
        "oui_hex": "00-05-2C",
        "organization": "Supreme Magic Corporation",
        "address_1": "Sun Towers Center Bldg., 13F",
        "address_2": "    154-0024",
        "country": "JP"
    },
    "00053E": {
        "oui_hex": "00-05-3E",
        "organization": "KID Systeme GmbH",
        "address_1": "Luneburger Schanze 30",
        "address_2": "",
        "country": "DE"
    },
    "00053F": {
        "oui_hex": "00-05-3F",
        "organization": "VisionTek, Inc.",
        "address_1": "1175 Lakeside Dr.",
        "address_2": "Gurnee  IL  60031",
        "country": "US"
    },
    "00053D": {
        "oui_hex": "00-05-3D",
        "organization": "Agere Systems",
        "address_1": "1371 McCarthy Blvd.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "000500": {
        "oui_hex": "00-05-00",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000519": {
        "oui_hex": "00-05-19",
        "organization": "Siemens Building Technologies AG,",
        "address_1": "Cerberus Division",
        "address_2": "",
        "country": "CH"
    },
    "00050D": {
        "oui_hex": "00-05-0D",
        "organization": "Midstream Technologies, Inc.",
        "address_1": "777 108th Ave. NE",
        "address_2": "Bellevue  WA  98004-5140",
        "country": "US"
    },
    "000534": {
        "oui_hex": "00-05-34",
        "organization": "Northstar Engineering Ltd.",
        "address_1": "P.O. Box 40",
        "address_2": "",
        "country": "GB"
    },
    "000535": {
        "oui_hex": "00-05-35",
        "organization": "Chip PC Ltd.",
        "address_1": "20 A.L. Motzkin St.",
        "address_2": "Tirat Carmel    39100",
        "country": "IL"
    },
    "000507": {
        "oui_hex": "00-05-07",
        "organization": "Fine Appliance Corp.",
        "address_1": "7Fl., No. 499,",
        "address_2": "",
        "country": "TW"
    },
    "0004FD": {
        "oui_hex": "00-04-FD",
        "organization": "Japan Control Engineering Co., Ltd.",
        "address_1": "1-5-1, Higashiamagawa, Takatsuki-shi",
        "address_2": "",
        "country": "JP"
    },
    "000562": {
        "oui_hex": "00-05-62",
        "organization": "Digital View Limited",
        "address_1": "2201 Nan Yang Plaza,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "0004E5": {
        "oui_hex": "00-04-E5",
        "organization": "Glonet Systems, Inc.",
        "address_1": "11Fl., Jeil Bldg., 94-46, 7Ka",
        "address_2": "",
        "country": "KR"
    },
    "0004D2": {
        "oui_hex": "00-04-D2",
        "organization": "Adcon Telemetry GmbH",
        "address_1": "Inkustraße 24",
        "address_2": "",
        "country": "AT"
    },
    "0004D3": {
        "oui_hex": "00-04-D3",
        "organization": "Toyokeiki Co., Ltd.",
        "address_1": "Wada 3967-10, Matsumoto-City",
        "address_2": "",
        "country": "JP"
    },
    "0004AA": {
        "oui_hex": "00-04-AA",
        "organization": "Jetstream Communications",
        "address_1": "5400 Hellyer Avenue",
        "address_2": "San Jose  CA  95138-1005",
        "country": "US"
    },
    "0004A0": {
        "oui_hex": "00-04-A0",
        "organization": "Verity Instruments, Inc.",
        "address_1": "2901 Eisenhower St.",
        "address_2": "Carrollton  TX  75007",
        "country": "US"
    },
    "00049E": {
        "oui_hex": "00-04-9E",
        "organization": "Wirelink Co., Ltd.",
        "address_1": "11F, Geoseong B/D 541, Dowha-Dong,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00049A": {
        "oui_hex": "00-04-9A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000479": {
        "oui_hex": "00-04-79",
        "organization": "Radius Co., Ltd.",
        "address_1": "1-48-11, Itabashi",
        "address_2": "",
        "country": "JP"
    },
    "0004B0": {
        "oui_hex": "00-04-B0",
        "organization": "ELESIGN Co., Ltd.",
        "address_1": "9Fl. TaeKyoung Bldg.,",
        "address_2": "  R.O.  KOREA",
        "country": "KR"
    },
    "0004AB": {
        "oui_hex": "00-04-AB",
        "organization": "Mavenir Inc.",
        "address_1": "1700 International Parkway",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0004A7": {
        "oui_hex": "00-04-A7",
        "organization": "FabiaTech Corporation",
        "address_1": "4F-3, No. 18, Lane 609",
        "address_2": "Taipei  Hsien,  TAIWAN R.O.C",
        "country": "TW"
    },
    "000498": {
        "oui_hex": "00-04-98",
        "organization": "Mahi Networks",
        "address_1": "1039 N. McDowell Blvd.",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "000497": {
        "oui_hex": "00-04-97",
        "organization": "MacroSystem Digital Video AG",
        "address_1": "Schoellinger Feld 28",
        "address_2": "",
        "country": "DE"
    },
    "0004D5": {
        "oui_hex": "00-04-D5",
        "organization": "Hitachi Information & Communication Engineering, Ltd.",
        "address_1": "Queen's Tower B21F, 2-3-3, Minatomirai,",
        "address_2": "Nishi-ku,  Yokohama,  220-6121",
        "country": "JP"
    },
    "0004CA": {
        "oui_hex": "00-04-CA",
        "organization": "FreeMs Corp.",
        "address_1": "Shinhan Bldg. 6F,",
        "address_2": "Seoul  150-736  KOREA",
        "country": "KR"
    },
    "000488": {
        "oui_hex": "00-04-88",
        "organization": "Eurotherm Controls",
        "address_1": "741F Miller Drive",
        "address_2": "Lessburg  VA  20175",
        "country": "US"
    },
    "000485": {
        "oui_hex": "00-04-85",
        "organization": "PicoLight",
        "address_1": "4665 Nautilus Court South",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "0004DA": {
        "oui_hex": "00-04-DA",
        "organization": "Relax Technology, Inc.",
        "address_1": "DBA/ Granite Digital",
        "address_2": "Union City  CA  94587",
        "country": "US"
    },
    "0004C5": {
        "oui_hex": "00-04-C5",
        "organization": "ASE Technologies, USA",
        "address_1": "6721 Baum Dr.",
        "address_2": "Knoxville  TN  37919",
        "country": "US"
    },
    "000436": {
        "oui_hex": "00-04-36",
        "organization": "ELANsat Technologies, Inc.",
        "address_1": "No. 11, Lane 19, Pateh Road,",
        "address_2": "Hsinchu  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "000432": {
        "oui_hex": "00-04-32",
        "organization": "Voyetra Turtle Beach, Inc.",
        "address_1": "150 Clearbrook Road, Suite 162",
        "address_2": "Elmsford  NY  10523",
        "country": "US"
    },
    "000435": {
        "oui_hex": "00-04-35",
        "organization": "InfiNet LLC",
        "address_1": "Serafimy Deryabinoy str. 24",
        "address_2": "Yekaterinburg    620149",
        "country": "RU"
    },
    "000437": {
        "oui_hex": "00-04-37",
        "organization": "Powin Information Technology, Inc.",
        "address_1": "8F, No. 70, Zhou-Z St.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00040C": {
        "oui_hex": "00-04-0C",
        "organization": "Kanno Works, Ltd.",
        "address_1": "1-5-25 Kamitomino,",
        "address_2": "",
        "country": "JP"
    },
    "000408": {
        "oui_hex": "00-04-08",
        "organization": "Sanko Electronics Co., Ltd.",
        "address_1": "3-802 ueda tenpaku-ku",
        "address_2": "  nagoya",
        "country": "JP"
    },
    "000407": {
        "oui_hex": "00-04-07",
        "organization": "Topcon Positioning Systems, Inc.",
        "address_1": "5758 W. Las Positas Blvd.",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "000409": {
        "oui_hex": "00-04-09",
        "organization": "Cratos Networks",
        "address_1": "313 Littleton Road",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "000455": {
        "oui_hex": "00-04-55",
        "organization": "ANTARA.net",
        "address_1": "747 Camden Ave.",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "000457": {
        "oui_hex": "00-04-57",
        "organization": "Universal Access Technology, Inc.",
        "address_1": "2 Fl., No. 5, Alley 22,",
        "address_2": "Nei Hu  Taipei,  TAIWAN 114",
        "country": "TW"
    },
    "00044D": {
        "oui_hex": "00-04-4D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000454": {
        "oui_hex": "00-04-54",
        "organization": "Quadriga UK",
        "address_1": "Baird House",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "000448": {
        "oui_hex": "00-04-48",
        "organization": "Polaroid Corporation",
        "address_1": "300 Baker Avenue",
        "address_2": "Concord  MA  01742",
        "country": "US"
    },
    "000447": {
        "oui_hex": "00-04-47",
        "organization": "Acrowave Systems Co., Ltd.",
        "address_1": "Maru B/D 86-6, Nonhyun-Dong",
        "address_2": "KOREA  zip:  135-818",
        "country": "KR"
    },
    "00043E": {
        "oui_hex": "00-04-3E",
        "organization": "Telencomm",
        "address_1": "2551 Walsh Avenue",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "00046D": {
        "oui_hex": "00-04-6D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000466": {
        "oui_hex": "00-04-66",
        "organization": "ARMITEL Co.",
        "address_1": "F5, Doman Plaza 353-4,",
        "address_2": "Republic  of  KOREA",
        "country": "KR"
    },
    "0003E2": {
        "oui_hex": "00-03-E2",
        "organization": "Comspace Corporation",
        "address_1": "955 Freeport Pkwy",
        "address_2": "Coppell  TX  75019",
        "country": "US"
    },
    "0003FF": {
        "oui_hex": "00-03-FF",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  WA  98052",
        "country": "US"
    },
    "000414": {
        "oui_hex": "00-04-14",
        "organization": "Umezawa Musen Denki Co., Ltd.",
        "address_1": "14-3, Minami 1, Nishi 8,",
        "address_2": "Hokkaido  JAPAN  060-0061",
        "country": "JP"
    },
    "000428": {
        "oui_hex": "00-04-28",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000386": {
        "oui_hex": "00-03-86",
        "organization": "Ho Net, Inc.",
        "address_1": "Venture Company Center",
        "address_2": "  KOREA  442-760",
        "country": "KR"
    },
    "00037D": {
        "oui_hex": "00-03-7D",
        "organization": "Stellcom",
        "address_1": "10525 Vista Sorrento Parkway",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000383": {
        "oui_hex": "00-03-83",
        "organization": "Metera Networks, Inc.",
        "address_1": "1202 Richardson Dr.",
        "address_2": "Richardson  TX  75080",
        "country": "US"
    },
    "0003CC": {
        "oui_hex": "00-03-CC",
        "organization": "Momentum Computer, Inc.",
        "address_1": "1815 Aston Avenue",
        "address_2": "Carlsbad  CA  92008-7310",
        "country": "US"
    },
    "0003D7": {
        "oui_hex": "00-03-D7",
        "organization": "NextNet Wireless, Inc.",
        "address_1": "9555 James Ave. So.",
        "address_2": "Bloomington  MN  55431",
        "country": "US"
    },
    "0003D3": {
        "oui_hex": "00-03-D3",
        "organization": "Internet Energy Systems, Inc.",
        "address_1": "4218 Trumbo Ct.",
        "address_2": "Fairfax  VA  22033",
        "country": "US"
    },
    "0003CD": {
        "oui_hex": "00-03-CD",
        "organization": "Clovertech, Inc.",
        "address_1": "3-1-5 Naka-cho Musashino-shi",
        "address_2": "Tokyo  180-0006",
        "country": "JP"
    },
    "00038B": {
        "oui_hex": "00-03-8B",
        "organization": "PLUS-ONE I&T, Inc.",
        "address_1": "7F, A-San Venture Tower,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00038C": {
        "oui_hex": "00-03-8C",
        "organization": "Total Impact",
        "address_1": "295 Willis Ave.",
        "address_2": "Camarillo  CA  93010",
        "country": "US"
    },
    "0003EE": {
        "oui_hex": "00-03-EE",
        "organization": "MKNet Corporation",
        "address_1": "711-B Charcot Ave.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0003EA": {
        "oui_hex": "00-03-EA",
        "organization": "Mega System Technologies, Inc.",
        "address_1": "2F, No. 41, Lane 76,",
        "address_2": "Taipei  Taipei  TAIWAN",
        "country": "TW"
    },
    "0003E6": {
        "oui_hex": "00-03-E6",
        "organization": "Entone, Inc.",
        "address_1": "2755 Campus Dr Ste 235",
        "address_2": "San Mateo  CA   94403",
        "country": "US"
    },
    "0003A9": {
        "oui_hex": "00-03-A9",
        "organization": "AXCENT Media AG",
        "address_1": "Technologiepark 13",
        "address_2": "",
        "country": "DE"
    },
    "00039F": {
        "oui_hex": "00-03-9F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000390": {
        "oui_hex": "00-03-90",
        "organization": "Digital Video Communications, Inc.",
        "address_1": "500 W. Cummings Park",
        "address_2": "Woburn  MA  07801",
        "country": "US"
    },
    "0003B5": {
        "oui_hex": "00-03-B5",
        "organization": "Entra Technology Co.",
        "address_1": "Fl. 3, No. 5, Alley 2,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000364": {
        "oui_hex": "00-03-64",
        "organization": "Scenix Semiconductor, Inc.",
        "address_1": "1330 Charleston Rd.",
        "address_2": "Mountainview  CA  94043",
        "country": "US"
    },
    "00035E": {
        "oui_hex": "00-03-5E",
        "organization": "Metropolitan Area Networks, Inc.",
        "address_1": "1299 Pennsylvania Avenue, NW",
        "address_2": "Washington  DC  20004",
        "country": "US"
    },
    "00035C": {
        "oui_hex": "00-03-5C",
        "organization": "Saint Song Corp.",
        "address_1": "4F, No. 12, Lane 94, Tsao Ti Wzi",
        "address_2": "    222",
        "country": "TW"
    },
    "00035D": {
        "oui_hex": "00-03-5D",
        "organization": "Bosung Hi-Net Co., Ltd.",
        "address_1": "Youngil B/O 2F,",
        "address_2": "    137-130",
        "country": "KR"
    },
    "000379": {
        "oui_hex": "00-03-79",
        "organization": "Proscend Communications, Inc.",
        "address_1": "2F, No.36, Industry E. Rd. IV,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00036F": {
        "oui_hex": "00-03-6F",
        "organization": "Telsey SPA",
        "address_1": "Viale Dell Industria, 1",
        "address_2": "DiTreviso-",
        "country": "IT"
    },
    "000372": {
        "oui_hex": "00-03-72",
        "organization": "ULAN",
        "address_1": "5F-3, No. 31-1, Lane 169,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000334": {
        "oui_hex": "00-03-34",
        "organization": "Newport Electronics",
        "address_1": "2229 So. Yale St.",
        "address_2": "Santa Ana  CA  92704",
        "country": "US"
    },
    "00033A": {
        "oui_hex": "00-03-3A",
        "organization": "Silicon Wave, Inc.",
        "address_1": "6256 Greenwich Drive",
        "address_2": "San Diego  CA  92122",
        "country": "US"
    },
    "000332": {
        "oui_hex": "00-03-32",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00030E": {
        "oui_hex": "00-03-0E",
        "organization": "Core Communications Co., Ltd.",
        "address_1": "3F Shopping Center Bd. of",
        "address_2": "Seoul (121-050)    (121-050)",
        "country": "KR"
    },
    "000312": {
        "oui_hex": "00-03-12",
        "organization": "TRsystems GmbH",
        "address_1": "Eglishalde 16",
        "address_2": " Trossingen  Baden-Wuerttemberg  D-78647",
        "country": "DE"
    },
    "000341": {
        "oui_hex": "00-03-41",
        "organization": "Axon Digital Design",
        "address_1": "Lange Wagenstraat 55",
        "address_2": "",
        "country": "NL"
    },
    "008037": {
        "oui_hex": "00-80-37",
        "organization": "Ericsson Group",
        "address_1": "Telefonaktiebolaget",
        "address_2": "",
        "country": "SE"
    },
    "00033D": {
        "oui_hex": "00-03-3D",
        "organization": "ILSHin Lab",
        "address_1": "KCS B/D 228-13 Young Dap-Dong",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000366": {
        "oui_hex": "00-03-66",
        "organization": "ASM Pacific Technology",
        "address_1": "12/F Watson Centre",
        "address_2": "Kwai Chung",
        "country": "HK"
    },
    "000362": {
        "oui_hex": "00-03-62",
        "organization": "Vodtel Communications, Inc.",
        "address_1": "12F, No 166 Chien-Yi Road",
        "address_2": "    235",
        "country": "TW"
    },
    "00034D": {
        "oui_hex": "00-03-4D",
        "organization": "Chiaro Networks, Ltd.",
        "address_1": "P.O. Box 832427",
        "address_2": "Richardson  TX  75083-2427",
        "country": "US"
    },
    "000322": {
        "oui_hex": "00-03-22",
        "organization": "IDIS Co., Ltd.",
        "address_1": "7th Floor, 646-7 Yuksam-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "00031D": {
        "oui_hex": "00-03-1D",
        "organization": "Taiwan Commate Computer, Inc.",
        "address_1": "8F, No. 94, Sec 1,",
        "address_2": "",
        "country": "TW"
    },
    "000326": {
        "oui_hex": "00-03-26",
        "organization": "Iwasaki Information Systems Co., Ltd.",
        "address_1": "3361 Oshi",
        "address_2": "",
        "country": "JP"
    },
    "000290": {
        "oui_hex": "00-02-90",
        "organization": "Woorigisool, Inc.",
        "address_1": "Yoopoong Bldg.",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "000292": {
        "oui_hex": "00-02-92",
        "organization": "Logic Innovations, Inc.",
        "address_1": "6205 Lusk Blvd.",
        "address_2": "San Diego  CA  92121-2731",
        "country": "US"
    },
    "000286": {
        "oui_hex": "00-02-86",
        "organization": "Occam Networks",
        "address_1": "4183 State Street",
        "address_2": "Santa Barbara  CA  93110",
        "country": "US"
    },
    "0002D2": {
        "oui_hex": "00-02-D2",
        "organization": "Workstation AG",
        "address_1": "Schaffhauserstrasse 55",
        "address_2": "",
        "country": "CH"
    },
    "0002CD": {
        "oui_hex": "00-02-CD",
        "organization": "TeleDream, Inc.",
        "address_1": "Shinhwa Bldg., 940-10 Daechi-Dong",
        "address_2": "",
        "country": "KR"
    },
    "0002D0": {
        "oui_hex": "00-02-D0",
        "organization": "Comdial Corporation",
        "address_1": "1180 Seminole Trail",
        "address_2": "Charlottesville  VA  22901",
        "country": "US"
    },
    "0002CC": {
        "oui_hex": "00-02-CC",
        "organization": "M.C.C.I",
        "address_1": "3520 Krums Corners Rd.",
        "address_2": "Ithaca  NY  14850",
        "country": "US"
    },
    "0002B0": {
        "oui_hex": "00-02-B0",
        "organization": "Hokubu Communication & Industrial Co., Ltd.",
        "address_1": "Fushiogami-aza-oki 27-1",
        "address_2": "Fukushima    960-8514",
        "country": "JP"
    },
    "0002AA": {
        "oui_hex": "00-02-AA",
        "organization": "PLcom Co., Ltd.",
        "address_1": "Hosung B/D, #1083-1, Hogye-Dong",
        "address_2": "  South  Korea",
        "country": "KR"
    },
    "0002B5": {
        "oui_hex": "00-02-B5",
        "organization": "Avnet, Inc.",
        "address_1": "2211 S. 47th Street",
        "address_2": "Phoenix  AZ  85034",
        "country": "US"
    },
    "0002B4": {
        "oui_hex": "00-02-B4",
        "organization": "DAPHNE",
        "address_1": "101 Chaussee De Binche",
        "address_2": "",
        "country": "BE"
    },
    "0002AC": {
        "oui_hex": "00-02-AC",
        "organization": "3PAR data",
        "address_1": "4209 Technology Drive",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0002D9": {
        "oui_hex": "00-02-D9",
        "organization": "Reliable Controls",
        "address_1": "120 Hallowell Road",
        "address_2": "Victoria,   B.C.  V9A 7K2",
        "country": "CA"
    },
    "0002EF": {
        "oui_hex": "00-02-EF",
        "organization": "CCC Network Systems Group Ltd.",
        "address_1": "13 Farnborough Business Centre",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "0002E8": {
        "oui_hex": "00-02-E8",
        "organization": "E.D.&A.",
        "address_1": "Energielaan 16",
        "address_2": "",
        "country": "BE"
    },
    "0002F2": {
        "oui_hex": "00-02-F2",
        "organization": "eDevice, Inc.",
        "address_1": "420 Lexington Avenue",
        "address_2": "New York  NY  10170",
        "country": "US"
    },
    "00029D": {
        "oui_hex": "00-02-9D",
        "organization": "Merix Corp.",
        "address_1": "Jin-Su Building, 49-16",
        "address_2": "Seoul  Seoul  KOREA",
        "country": "KR"
    },
    "0002C5": {
        "oui_hex": "00-02-C5",
        "organization": "Evertz Microsystems Ltd.",
        "address_1": "5292 John Lucas Drive",
        "address_2": "  Ontario  L7L 5Z9",
        "country": "CA"
    },
    "00024A": {
        "oui_hex": "00-02-4A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000249": {
        "oui_hex": "00-02-49",
        "organization": "Aviv Infocom Co, Ltd.",
        "address_1": "962-5, Kwanyang-Dong, Dongan-Gu,",
        "address_2": "  Korea  (ROK)",
        "country": "KR"
    },
    "000245": {
        "oui_hex": "00-02-45",
        "organization": "Lampus Co, Ltd.",
        "address_1": "6th Bldg., Samgong,",
        "address_2": "Korea  Korea  137-044",
        "country": "KR"
    },
    "000232": {
        "oui_hex": "00-02-32",
        "organization": "Avision, Inc.",
        "address_1": "No. 20, Creation Rd. 1,",
        "address_2": "Hsinchu  Taiwan,  R.O.C.",
        "country": "TW"
    },
    "000235": {
        "oui_hex": "00-02-35",
        "organization": "Paragon Networks International",
        "address_1": "61 Commerce Drive",
        "address_2": "Brookfield  CT  06804",
        "country": "US"
    },
    "000237": {
        "oui_hex": "00-02-37",
        "organization": "Cosmo Research Corp.",
        "address_1": "Cosmo Bldg, 3-148-5",
        "address_2": "",
        "country": "KW"
    },
    "000228": {
        "oui_hex": "00-02-28",
        "organization": "Necsom, Ltd.",
        "address_1": "Necsom Ltd. c/o Koirsto",
        "address_2": "",
        "country": "FI"
    },
    "000246": {
        "oui_hex": "00-02-46",
        "organization": "All-Win Tech Co., Ltd.",
        "address_1": "11F, No. 111-7, Hsing De Rd.,",
        "address_2": "Taipei Hsien  Taiwan,  R.O.C.",
        "country": "TW"
    },
    "00023A": {
        "oui_hex": "00-02-3A",
        "organization": "ZSK Stickmaschinen GmbH",
        "address_1": "Magdeburger Straße 38-40",
        "address_2": "",
        "country": "DE"
    },
    "00027F": {
        "oui_hex": "00-02-7F",
        "organization": "ask-technologies.com",
        "address_1": "36 Wellington Business Park",
        "address_2": "",
        "country": "GB"
    },
    "00027E": {
        "oui_hex": "00-02-7E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001095": {
        "oui_hex": "00-10-95",
        "organization": "Thomson Inc.",
        "address_1": "101 West 103rd Street",
        "address_2": "Indianapolis  IN  46290-1102",
        "country": "US"
    },
    "00025D": {
        "oui_hex": "00-02-5D",
        "organization": "Calix Networks",
        "address_1": "1035 North McDowell Blvd.",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "00027B": {
        "oui_hex": "00-02-7B",
        "organization": "Amplify Net, Inc.",
        "address_1": "47381 Bayside Parkway",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000273": {
        "oui_hex": "00-02-73",
        "organization": "Coriolis Networks",
        "address_1": "330 Codmanhill Road",
        "address_2": "Boxborough  MA  01719",
        "country": "US"
    },
    "000257": {
        "oui_hex": "00-02-57",
        "organization": "Microcom Corp.",
        "address_1": "8333A Green Meadows Dr. N.",
        "address_2": "Westerville  OH  43081",
        "country": "US"
    },
    "000253": {
        "oui_hex": "00-02-53",
        "organization": "Televideo, Inc.",
        "address_1": "2345 Harris Way",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00026F": {
        "oui_hex": "00-02-6F",
        "organization": "Senao International Co., Ltd.",
        "address_1": "2F, No. 531, Chung-Cheng Rd.,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "000230": {
        "oui_hex": "00-02-30",
        "organization": "Intersoft Electronics",
        "address_1": "Lammerdries 27",
        "address_2": "",
        "country": "BE"
    },
    "00021C": {
        "oui_hex": "00-02-1C",
        "organization": "Network Elements, Inc.",
        "address_1": "9782 SW Nimbus Avenue",
        "address_2": "Beaverton  OR  97008",
        "country": "US"
    },
    "00020C": {
        "oui_hex": "00-02-0C",
        "organization": "Metro-Optix",
        "address_1": "2201 Avenue K",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "000216": {
        "oui_hex": "00-02-16",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000214": {
        "oui_hex": "00-02-14",
        "organization": "DTVRO",
        "address_1": "813 Daegong Bldg.,",
        "address_2": "KOREA  KOREA  135-080",
        "country": "KR"
    },
    "00020F": {
        "oui_hex": "00-02-0F",
        "organization": "AATR",
        "address_1": "306 Chemin des Miroirs",
        "address_2": "",
        "country": "FR"
    },
    "0001C3": {
        "oui_hex": "00-01-C3",
        "organization": "Acromag, Inc.",
        "address_1": "30765 S. Wixom Road",
        "address_2": "Wixom  MI  48393",
        "country": "US"
    },
    "0001C2": {
        "oui_hex": "00-01-C2",
        "organization": "ARK Research Corp.",
        "address_1": "1198 Saratoga Ave. #11D",
        "address_2": "San Jose  CA  95129",
        "country": "US"
    },
    "0001EA": {
        "oui_hex": "00-01-EA",
        "organization": "Cirilium Corp.",
        "address_1": "1615 S. 52nd Street",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "0001E0": {
        "oui_hex": "00-01-E0",
        "organization": "Fast Systems, Inc.",
        "address_1": "87-9 Yang-Jae, Seo-Cho,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001AC": {
        "oui_hex": "00-01-AC",
        "organization": "Sitara Networks, Inc.",
        "address_1": "60 Hickory Drive",
        "address_2": "Waltham  MA  02451",
        "country": "US"
    },
    "0001ED": {
        "oui_hex": "00-01-ED",
        "organization": "SETA Corp.",
        "address_1": "Ariake Frontier Bldg. B",
        "address_2": "  JAPAN  135-0063",
        "country": "JP"
    },
    "0001F6": {
        "oui_hex": "00-01-F6",
        "organization": "Association of Musical Electronics Industry",
        "address_1": "Ito Bldg. 4th Floor 2-16-9 Misaki-cho,",
        "address_2": "",
        "country": "JP"
    },
    "0001CB": {
        "oui_hex": "00-01-CB",
        "organization": "EVR",
        "address_1": "12 Raul Wallenberg St.",
        "address_2": "  Tel Aviv  69719",
        "country": "IL"
    },
    "0001D6": {
        "oui_hex": "00-01-D6",
        "organization": "manroland AG",
        "address_1": "Stadtbachstraße 1",
        "address_2": "",
        "country": "DE"
    },
    "0001AD": {
        "oui_hex": "00-01-AD",
        "organization": "Coach Master International  d.b.a. CMI Worldwide, Inc.",
        "address_1": "600 Stewart Street",
        "address_2": "Seattle  WA  98101",
        "country": "US"
    },
    "000188": {
        "oui_hex": "00-01-88",
        "organization": "LXCO Technologies ag",
        "address_1": "Gimmerstraße 69",
        "address_2": "",
        "country": "DE"
    },
    "00019B": {
        "oui_hex": "00-01-9B",
        "organization": "Kyoto Microcomputer Co., Ltd.",
        "address_1": "2-44 nakayama oe nishikyo-ku",
        "address_2": "kyoto",
        "country": "JP"
    },
    "00017F": {
        "oui_hex": "00-01-7F",
        "organization": "Experience Music Project",
        "address_1": "110 -110th Avenue NE - Ste. #400",
        "address_2": "Bellevue  WA  98004",
        "country": "US"
    },
    "00015A": {
        "oui_hex": "00-01-5A",
        "organization": "Digital Video Broadcasting",
        "address_1": "DVB, % European Broadcasting Union",
        "address_2": "",
        "country": "CH"
    },
    "00012A": {
        "oui_hex": "00-01-2A",
        "organization": "Telematica Sistems Inteligente",
        "address_1": "Rua Miguel Casagrande, 200",
        "address_2": "São Paulo",
        "country": "BR"
    },
    "000166": {
        "oui_hex": "00-01-66",
        "organization": "TC GROUP A/S",
        "address_1": "Sindalsvej 34",
        "address_2": "Risskov    DK-8240",
        "country": "DK"
    },
    "000176": {
        "oui_hex": "00-01-76",
        "organization": "Orient Silver Enterprises",
        "address_1": "8740 White Oak Avenue",
        "address_2": "Rancho Cucamonga  CA  91730",
        "country": "US"
    },
    "000158": {
        "oui_hex": "00-01-58",
        "organization": "Electro Industries/Gauge Tech",
        "address_1": "1800 Shames Drive",
        "address_2": "Westbury  NY  11590",
        "country": "US"
    },
    "00012D": {
        "oui_hex": "00-01-2D",
        "organization": "Komodo Technology",
        "address_1": "170 Knowles Drive",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "000148": {
        "oui_hex": "00-01-48",
        "organization": "X-traWeb Inc.",
        "address_1": "6750 West 93rd Street - Ste. #210",
        "address_2": "Overland Park  KS  66212",
        "country": "US"
    },
    "000187": {
        "oui_hex": "00-01-87",
        "organization": "I2SE GmbH",
        "address_1": "Friedrich-Ebert-Str. 61",
        "address_2": "Leipzig    04109",
        "country": "DE"
    },
    "000180": {
        "oui_hex": "00-01-80",
        "organization": "AOpen, Inc.",
        "address_1": "6F, 88, Sec.1, Hsin Tai",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000197": {
        "oui_hex": "00-01-97",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00019A": {
        "oui_hex": "00-01-9A",
        "organization": "LEUNIG GmbH",
        "address_1": "Wilhelm-Ostwald-Str. 17",
        "address_2": "",
        "country": "DE"
    },
    "000159": {
        "oui_hex": "00-01-59",
        "organization": "S1 Corporation",
        "address_1": "R&D Center, S1 Bldg.",
        "address_2": "  KOREA  135-010",
        "country": "KR"
    },
    "000171": {
        "oui_hex": "00-01-71",
        "organization": "Allied Data Technologies",
        "address_1": "Pascalweg 1,",
        "address_2": "  THE",
        "country": "NL"
    },
    "0030AC": {
        "oui_hex": "00-30-AC",
        "organization": "Systeme Lauer GmbH & Co., Ltd.",
        "address_1": "Kelterstrasse 59",
        "address_2": "72669 Unterensingen",
        "country": "DE"
    },
    "0030FB": {
        "oui_hex": "00-30-FB",
        "organization": "AZS Technology AG",
        "address_1": "Steinbeisstrasse 2-4",
        "address_2": "72510 Stetten A.K.M.",
        "country": "DE"
    },
    "0030AE": {
        "oui_hex": "00-30-AE",
        "organization": "Times N System, Inc.",
        "address_1": "1826 Kramer Lane - Ste.",
        "address_2": "Austin  TX  78758",
        "country": "US"
    },
    "003003": {
        "oui_hex": "00-30-03",
        "organization": "Phasys Ltd.",
        "address_1": "#100-9404 41st Avenue",
        "address_2": "Edmonton  Alberta T6X 1R2",
        "country": "CA"
    },
    "0030E2": {
        "oui_hex": "00-30-E2",
        "organization": "GARNET SYSTEMS CO., LTD.",
        "address_1": "Sungwon Bldg. 545-7",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00013A": {
        "oui_hex": "00-01-3A",
        "organization": "SHELCAD COMMUNICATIONS, LTD.",
        "address_1": "P.O. Box 8513",
        "address_2": "",
        "country": "IL"
    },
    "000140": {
        "oui_hex": "00-01-40",
        "organization": "Sendtek Corporation",
        "address_1": "12F-3, 333, Sec.1",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "000123": {
        "oui_hex": "00-01-23",
        "organization": "Schneider Electric Japan Holdings Ltd.",
        "address_1": "Schneider Electric Osaka Building",
        "address_2": "4-4-9 Kitahama  Chuo-ku, Osaka  541-0041",
        "country": "JP"
    },
    "000125": {
        "oui_hex": "00-01-25",
        "organization": "YAESU MUSEN CO., LTD.",
        "address_1": "Tennozu Parkside Building",
        "address_2": "Shinagawa-ku, Tokyo 140-0002",
        "country": "JP"
    },
    "000126": {
        "oui_hex": "00-01-26",
        "organization": "PAC Labs",
        "address_1": "3079 Kilgore Road",
        "address_2": "Rancho Cordova  CA  95670",
        "country": "US"
    },
    "00011B": {
        "oui_hex": "00-01-1B",
        "organization": "Unizone Technologies, Inc.",
        "address_1": "5Floor HaeSung Bldg.",
        "address_2": "SeoCho-Ku  Seoul",
        "country": "KR"
    },
    "00011D": {
        "oui_hex": "00-01-1D",
        "organization": "Centillium Communications",
        "address_1": "47211 Lakeview Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00011F": {
        "oui_hex": "00-01-1F",
        "organization": "RC Networks, Inc.",
        "address_1": "6727 Flanders Drive - Ste. #212",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00B080": {
        "oui_hex": "00-B0-80",
        "organization": "Mannesmann Ipulsys B.V.",
        "address_1": "Bordewijklaan 18",
        "address_2": "2591 XR The Hague",
        "country": "NL"
    },
    "00B01E": {
        "oui_hex": "00-B0-1E",
        "organization": "Rantic Labs, Inc.",
        "address_1": "702 Brazos,  Suite #500",
        "address_2": "Austin  TX  78701",
        "country": "US"
    },
    "00B0F0": {
        "oui_hex": "00-B0-F0",
        "organization": "CALY NETWORKS",
        "address_1": "295 Santa Anna Court",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "00B09A": {
        "oui_hex": "00-B0-9A",
        "organization": "Morrow Technologies Corp.",
        "address_1": "2300 Tall Pines Drive",
        "address_2": "Largo  FL  33771-5342",
        "country": "US"
    },
    "00302E": {
        "oui_hex": "00-30-2E",
        "organization": "Hoft & Wessel AG",
        "address_1": "Rotenburger Strasse 20",
        "address_2": "30659 Hannover",
        "country": "DE"
    },
    "0030ED": {
        "oui_hex": "00-30-ED",
        "organization": "Expert Magnetics Corp.",
        "address_1": "12/F., Unit D, MTG Bldg., 1-3, Nakase",
        "address_2": "Mihama-ku, Chiba-city, 261-8501",
        "country": "JP"
    },
    "00300F": {
        "oui_hex": "00-30-0F",
        "organization": "IMT - Information Management T",
        "address_1": "Gewerbestrasse 8",
        "address_2": "CH-9470 Buchs",
        "country": "CH"
    },
    "003082": {
        "oui_hex": "00-30-82",
        "organization": "TAIHAN ELECTRIC WIRE CO., LTD.",
        "address_1": "Communication Engineering Team",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0030A9": {
        "oui_hex": "00-30-A9",
        "organization": "Netiverse, Inc.",
        "address_1": "100 Century Center Court",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "0030FE": {
        "oui_hex": "00-30-FE",
        "organization": "DSA GmbH",
        "address_1": "Pascalstraße 28",
        "address_2": "52076 Aachen",
        "country": "DE"
    },
    "0030C4": {
        "oui_hex": "00-30-C4",
        "organization": "Canon Imaging Systems Inc.",
        "address_1": "1-24 Yoneyama, Chuo-ku",
        "address_2": "Niigata-shi  Niigata  950-0916",
        "country": "JP"
    },
    "00304D": {
        "oui_hex": "00-30-4D",
        "organization": "ESI",
        "address_1": "3701 E. Plano Parkway",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "081443": {
        "oui_hex": "08-14-43",
        "organization": "UNIBRAIN S.A.",
        "address_1": "84, ETHNIKIS ANTISTASEOS",
        "address_2": "",
        "country": "GR"
    },
    "00B009": {
        "oui_hex": "00-B0-09",
        "organization": "Grass Valley, A Belden Brand",
        "address_1": "3499, Douglas B. Floreani",
        "address_2": "Montreal  Quebec  H4S 2C6",
        "country": "CA"
    },
    "00B0AC": {
        "oui_hex": "00-B0-AC",
        "organization": "SIAE-Microelettronica S.p.A.",
        "address_1": "Via Michelangelo Buonarroti, 21",
        "address_2": "20093 Cologno M. (Ml)",
        "country": "IT"
    },
    "003023": {
        "oui_hex": "00-30-23",
        "organization": "COGENT COMPUTER SYSTEMS, INC.",
        "address_1": "10 RIVER ROAD - STE. #205",
        "address_2": "UXBRIDGE  MA  01569",
        "country": "US"
    },
    "003090": {
        "oui_hex": "00-30-90",
        "organization": "CYRA TECHNOLOGIES, INC.",
        "address_1": "8000 CAPWELL DRIVE",
        "address_2": "OAKLAND  CA  94621",
        "country": "US"
    },
    "0030A7": {
        "oui_hex": "00-30-A7",
        "organization": "SCHWEITZER ENGINEERING",
        "address_1": "LABORATORIES, INC.",
        "address_2": "PULLMAN  WA  99163",
        "country": "US"
    },
    "00307C": {
        "oui_hex": "00-30-7C",
        "organization": "ADID SA",
        "address_1": "70 RU ANATOLE FRANCE",
        "address_2": "92 300 LEVALLOIS-PERRET CEDEX",
        "country": "FR"
    },
    "003055": {
        "oui_hex": "00-30-55",
        "organization": "Renesas Technology America, Inc.",
        "address_1": "450 Holger Way",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00302F": {
        "oui_hex": "00-30-2F",
        "organization": "GE Aviation System",
        "address_1": "3290 Patterson Ave., S.E.",
        "address_2": "Grand Rapids  MI  49512",
        "country": "US"
    },
    "00300E": {
        "oui_hex": "00-30-0E",
        "organization": "Klotz Digital AG",
        "address_1": "Hans-Stiessbergerstraße 2A",
        "address_2": "D-85540 Haar",
        "country": "DE"
    },
    "0030D5": {
        "oui_hex": "00-30-D5",
        "organization": "DResearch GmbH",
        "address_1": "Otto-Schmirgal-Str.3",
        "address_2": "10319 Berlin",
        "country": "DE"
    },
    "003018": {
        "oui_hex": "00-30-18",
        "organization": "Jetway Information Co., Ltd.",
        "address_1": "4F, No. 168, LI THE ST.",
        "address_2": "Chung Ho City 235  Taipei",
        "country": "TW"
    },
    "00309F": {
        "oui_hex": "00-30-9F",
        "organization": "AMBER NETWORKS",
        "address_1": "2475 AUGUSTINE DR.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0030A8": {
        "oui_hex": "00-30-A8",
        "organization": "OL'E COMMUNICATIONS, INC.",
        "address_1": "1962 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "0030D1": {
        "oui_hex": "00-30-D1",
        "organization": "INOVA CORPORATION",
        "address_1": "110 AVON STREET",
        "address_2": "CHARLOTTESVILE  VA  22902",
        "country": "US"
    },
    "0030BB": {
        "oui_hex": "00-30-BB",
        "organization": "CacheFlow, Inc.",
        "address_1": "650 Almanor Drive",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "0030AF": {
        "oui_hex": "00-30-AF",
        "organization": "Honeywell GmbH",
        "address_1": "Boeblinger Str. 17",
        "address_2": "D-71098 Schoenaich",
        "country": "DE"
    },
    "0030AA": {
        "oui_hex": "00-30-AA",
        "organization": "AXUS MICROSYSTEMS, INC.",
        "address_1": "2F-4, NO.18/N. 609, SEC. 5",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "003089": {
        "oui_hex": "00-30-89",
        "organization": "Spectrapoint Wireless, LLC",
        "address_1": "1125 E. Collins Blvd.",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "00309A": {
        "oui_hex": "00-30-9A",
        "organization": "ASTRO TERRA CORP.",
        "address_1": "11526 SORRENTO VALLEY ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "003087": {
        "oui_hex": "00-30-87",
        "organization": "VEGA GRIESHABER KG",
        "address_1": "AM HOHENSTEIN 113",
        "address_2": "",
        "country": "DE"
    },
    "003062": {
        "oui_hex": "00-30-62",
        "organization": "IP Video Networks Inc",
        "address_1": "6650 Lusk Blvd",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00302D": {
        "oui_hex": "00-30-2D",
        "organization": "QUANTUM BRIDGE COMMUNICATIONS",
        "address_1": "ONE HIGH STREET",
        "address_2": "NORTH ANDOVER  MA  01845",
        "country": "US"
    },
    "0030CB": {
        "oui_hex": "00-30-CB",
        "organization": "OMNI FLOW COMPUTERS, INC.",
        "address_1": "10701 CORPORATE DRIVE-STE.#300",
        "address_2": "STAFFORD  TX  77477",
        "country": "US"
    },
    "00306B": {
        "oui_hex": "00-30-6B",
        "organization": "CMOS SYSTEMS, INC.",
        "address_1": "23440 HAWTHORNE BLVD-STE #290",
        "address_2": "TORRANCE  CA  90505",
        "country": "US"
    },
    "0030AD": {
        "oui_hex": "00-30-AD",
        "organization": "SHANGHAI COMMUNICATION",
        "address_1": "TECHNOLOGIES CENTER",
        "address_2": "  P.R.",
        "country": "CN"
    },
    "0030CF": {
        "oui_hex": "00-30-CF",
        "organization": "TWO TECHNOLOGIES, INC.",
        "address_1": "419 SARGON WAY",
        "address_2": "HORSHAM  PA  19044",
        "country": "US"
    },
    "0030B2": {
        "oui_hex": "00-30-B2",
        "organization": "L-3 Sonoma EO",
        "address_1": "428 Aviation Blvd",
        "address_2": "Santa Rosa  CA  95403",
        "country": "US"
    },
    "003035": {
        "oui_hex": "00-30-35",
        "organization": "Corning Incorporated",
        "address_1": "Data Center",
        "address_2": "Corning  NY  14831",
        "country": "US"
    },
    "00307F": {
        "oui_hex": "00-30-7F",
        "organization": "IRLAN LTD.",
        "address_1": "1 HATAMAR STREET",
        "address_2": "",
        "country": "IL"
    },
    "00D015": {
        "oui_hex": "00-D0-15",
        "organization": "UNIVEX MICROTECHNOLOGY CORP.",
        "address_1": "2, TZE-CHIANG 3RD ROAD",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00D048": {
        "oui_hex": "00-D0-48",
        "organization": "ECTON, INC.",
        "address_1": "5168 CAMPUS DRIVE",
        "address_2": "PLYMOUTH MEETING  PA  19462",
        "country": "US"
    },
    "00D0A5": {
        "oui_hex": "00-D0-A5",
        "organization": "AMERICAN ARIUM",
        "address_1": "14281 CHAMBERS ROAD",
        "address_2": "TUSTIN  CA  92780",
        "country": "US"
    },
    "00305D": {
        "oui_hex": "00-30-5D",
        "organization": "DIGITRA SYSTEMS, INC.",
        "address_1": "8-61, GAWOL-DONG",
        "address_2": "  KOREA  140-150",
        "country": "KR"
    },
    "003036": {
        "oui_hex": "00-30-36",
        "organization": "RMP ELEKTRONIKSYSTEME GMBH",
        "address_1": "HANNS-MARTIN-SCHLE'R-STR.12-14",
        "address_2": "",
        "country": "DE"
    },
    "00D0CF": {
        "oui_hex": "00-D0-CF",
        "organization": "MORETON BAY",
        "address_1": "12/97 JIJAWS STREET",
        "address_2": "",
        "country": "AU"
    },
    "00D07F": {
        "oui_hex": "00-D0-7F",
        "organization": "STRATEGY & TECHNOLOGY, LIMITED",
        "address_1": "Suite 4.2, Clifton Heights",
        "address_2": "  Bristol  BS8 1EJ",
        "country": "GB"
    },
    "0030E6": {
        "oui_hex": "00-30-E6",
        "organization": "Draeger Medical Systems, Inc.",
        "address_1": "6 Tech Drive",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "0030BD": {
        "oui_hex": "00-30-BD",
        "organization": "BELKIN COMPONENTS",
        "address_1": "501 WEST WALNUT STREET",
        "address_2": "COMPTON  CA  90220",
        "country": "US"
    },
    "003007": {
        "oui_hex": "00-30-07",
        "organization": "OPTI, INC.",
        "address_1": "1440 MCCARTHY BLVD.",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "00D0C2": {
        "oui_hex": "00-D0-C2",
        "organization": "BALTHAZAR TECHNOLOGY AB",
        "address_1": "ANKDAMMSGATAN 24",
        "address_2": "",
        "country": "SE"
    },
    "00D022": {
        "oui_hex": "00-D0-22",
        "organization": "INCREDIBLE TECHNOLOGIES, INC.",
        "address_1": "1600 HICKS ROAD",
        "address_2": "ROLLING MEADOWS  IL  60008",
        "country": "US"
    },
    "00D071": {
        "oui_hex": "00-D0-71",
        "organization": "ECHELON CORP.",
        "address_1": "2901 Patrick Henry Dr.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00D04F": {
        "oui_hex": "00-D0-4F",
        "organization": "BITRONICS, INC.",
        "address_1": "P.O. BOX 22290",
        "address_2": "LEHIGH VALLEY  PA  18002-2290",
        "country": "US"
    },
    "00D069": {
        "oui_hex": "00-D0-69",
        "organization": "TECHNOLOGIC SYSTEMS",
        "address_1": "16610 E. LASER DRIVE-STE. #10",
        "address_2": "FOUNTAIN HILLS  AZ  85268",
        "country": "US"
    },
    "00D090": {
        "oui_hex": "00-D0-90",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D0F5": {
        "oui_hex": "00-D0-F5",
        "organization": "ORANGE MICRO, INC.",
        "address_1": "1400 N. LAKEVIEW AVE.",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "00D0E9": {
        "oui_hex": "00-D0-E9",
        "organization": "Advantage Century Telecommunication Corp.",
        "address_1": "4F, 41, Tunghsin Rd.",
        "address_2": "Taipei",
        "country": "TW"
    },
    "00D094": {
        "oui_hex": "00-D0-94",
        "organization": "Seeion Control LLC",
        "address_1": "117 Stephanie Lane",
        "address_2": "vista  CA  92084-5316",
        "country": "US"
    },
    "00D0FB": {
        "oui_hex": "00-D0-FB",
        "organization": "TEK MICROSYSTEMS, INCORPORATED",
        "address_1": "ONE NORTH AVENUE",
        "address_2": "BURLINGTON  MA  01803",
        "country": "US"
    },
    "00D066": {
        "oui_hex": "00-D0-66",
        "organization": "WINTRISS ENGINEERING CORP.",
        "address_1": "6344 FERRIS SQUARE",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00D082": {
        "oui_hex": "00-D0-82",
        "organization": "IOWAVE INC.",
        "address_1": "1010 WISCONSIN AVENUE",
        "address_2": "WASHINGTON  DC  20007",
        "country": "US"
    },
    "00D081": {
        "oui_hex": "00-D0-81",
        "organization": "RTD Embedded Technologies, Inc.",
        "address_1": "103 Innovation Blvd.",
        "address_2": "State College  PA  16803",
        "country": "US"
    },
    "00D002": {
        "oui_hex": "00-D0-02",
        "organization": "DITECH CORPORATION",
        "address_1": "825 EAST MIDDLEFIELD RD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00D085": {
        "oui_hex": "00-D0-85",
        "organization": "OTIS ELEVATOR COMPANY",
        "address_1": "5 FARM SPRINGS RD.",
        "address_2": "FARMINGTON  CT  06032",
        "country": "US"
    },
    "00D011": {
        "oui_hex": "00-D0-11",
        "organization": "PRISM VIDEO, INC.",
        "address_1": "15851 DALLAS PARKWAY-STE.#1060",
        "address_2": "ADDISON  TX  75001",
        "country": "US"
    },
    "00D0DF": {
        "oui_hex": "00-D0-DF",
        "organization": "KUZUMI ELECTRONICS, INC.",
        "address_1": "28-6 IIJIMA-CHYO, SAKAE-KU",
        "address_2": "",
        "country": "JP"
    },
    "00D09B": {
        "oui_hex": "00-D0-9B",
        "organization": "SPECTEL LTD.",
        "address_1": "21 STILLORGAN INDUSTRIAL PARK",
        "address_2": "",
        "country": "IE"
    },
    "00D067": {
        "oui_hex": "00-D0-67",
        "organization": "CAMPIO COMMUNICATIONS",
        "address_1": "2033 GATEWAY PL, SUITE #600",
        "address_2": "SAN JOSE  CA  95110",
        "country": "US"
    },
    "00D058": {
        "oui_hex": "00-D0-58",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D032": {
        "oui_hex": "00-D0-32",
        "organization": "YANO ELECTRIC CO., LTD.",
        "address_1": "7-3-1 IBUKIDAIHIGASHIMACHI",
        "address_2": "",
        "country": "JP"
    },
    "00D0F1": {
        "oui_hex": "00-D0-F1",
        "organization": "SEGA ENTERPRISES, LTD.",
        "address_1": "12-14 HIGASHIKOUJIYA 2-CHOME",
        "address_2": "",
        "country": "JP"
    },
    "00D03A": {
        "oui_hex": "00-D0-3A",
        "organization": "ZONEWORX, INC.",
        "address_1": "40925 COUNTY CENTER DRIVE",
        "address_2": "TEMECULA  CA  92592",
        "country": "US"
    },
    "00D001": {
        "oui_hex": "00-D0-01",
        "organization": "VST TECHNOLOGIES, INC.",
        "address_1": "125 NAGOG PARK",
        "address_2": "ACTON  MA  01720",
        "country": "US"
    },
    "00503E": {
        "oui_hex": "00-50-3E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "005020": {
        "oui_hex": "00-50-20",
        "organization": "MEDIASTAR CO., LTD.",
        "address_1": "3FL, SOHUN BLDG.",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00D075": {
        "oui_hex": "00-D0-75",
        "organization": "ALARIS MEDICAL SYSTEMS, INC.",
        "address_1": "P.O. BOX 85335",
        "address_2": "SAN DIEGO  CA  92121-2733",
        "country": "US"
    },
    "00D04C": {
        "oui_hex": "00-D0-4C",
        "organization": "EUROTEL TELECOM LTD.",
        "address_1": "CANISTER HOUSE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00D0E1": {
        "oui_hex": "00-D0-E1",
        "organization": "AVIONITEK ISRAEL INC.",
        "address_1": "1 ETGAR STREET",
        "address_2": "",
        "country": "IL"
    },
    "00D008": {
        "oui_hex": "00-D0-08",
        "organization": "MACTELL CORPORATION",
        "address_1": "7000 CAMERON ROAD",
        "address_2": "AUSTIN  TX  78752",
        "country": "US"
    },
    "00D0D9": {
        "oui_hex": "00-D0-D9",
        "organization": "DEDICATED MICROCOMPUTERS",
        "address_1": "1 Thellow Heath Park",
        "address_2": "Northwich    CW9 6JB",
        "country": "GB"
    },
    "00D00B": {
        "oui_hex": "00-D0-0B",
        "organization": "RHK TECHNOLOGY, INC.",
        "address_1": "1050 EAST MAPLE ROAD",
        "address_2": "TROY  MI  48083",
        "country": "US"
    },
    "00D09C": {
        "oui_hex": "00-D0-9C",
        "organization": "KAPADIA COMMUNICATIONS",
        "address_1": "3925 WEST BROKER LANE",
        "address_2": "AUSTIN  TX  78759",
        "country": "US"
    },
    "00D0F3": {
        "oui_hex": "00-D0-F3",
        "organization": "SOLARI DI UDINE SPA",
        "address_1": "VIA GINO PIERI 29",
        "address_2": "",
        "country": "IT"
    },
    "00D039": {
        "oui_hex": "00-D0-39",
        "organization": "UTILICOM, INC.",
        "address_1": "323 LOVE PLACE",
        "address_2": "SANTA BARBARA  CA  93112-3289",
        "country": "US"
    },
    "00D0A0": {
        "oui_hex": "00-D0-A0",
        "organization": "MIPS DENMARK",
        "address_1": "LAUTRUPVANG 2B",
        "address_2": "DK  -",
        "country": "DK"
    },
    "00D00A": {
        "oui_hex": "00-D0-0A",
        "organization": "LANACCESS TELECOM S.A.",
        "address_1": "GRAN VIA 8-10  4  1",
        "address_2": "",
        "country": "ES"
    },
    "00D01C": {
        "oui_hex": "00-D0-1C",
        "organization": "SBS TECHNOLOGIES,",
        "address_1": "CONNECTIVITY PRODUCTS",
        "address_2": "ST. PAUL  MN  55121-1245",
        "country": "US"
    },
    "00D0D5": {
        "oui_hex": "00-D0-D5",
        "organization": "GRUNDIG AG",
        "address_1": "KURGARTENSGTREET 37",
        "address_2": "",
        "country": "DE"
    },
    "00D041": {
        "oui_hex": "00-D0-41",
        "organization": "AMIGO TECHNOLOGY CO., LTD.",
        "address_1": "4F-1B, NO.12, LANE 609, SEC.5,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00D09D": {
        "oui_hex": "00-D0-9D",
        "organization": "VERIS INDUSTRIES",
        "address_1": "10831 SW CASCADE",
        "address_2": "PORTLAND  OR  97223",
        "country": "US"
    },
    "00D06D": {
        "oui_hex": "00-D0-6D",
        "organization": "ACRISON, INC.",
        "address_1": "20 EMPIRE BLVD.",
        "address_2": "MOONACHIE  NJ  07074",
        "country": "US"
    },
    "00D02B": {
        "oui_hex": "00-D0-2B",
        "organization": "JETCELL, INC.",
        "address_1": "173 CONSTITUTION DRIVE",
        "address_2": "MENLO PARK  CA  94025-1106",
        "country": "US"
    },
    "00D062": {
        "oui_hex": "00-D0-62",
        "organization": "DIGIGRAM",
        "address_1": "PARC DE PRE MILLIET",
        "address_2": "",
        "country": "FR"
    },
    "00D08D": {
        "oui_hex": "00-D0-8D",
        "organization": "PHOENIX GROUP, INC.",
        "address_1": "123 MARCUS BLVD.",
        "address_2": "HAUPPAUGE  NY  11788",
        "country": "US"
    },
    "00D03D": {
        "oui_hex": "00-D0-3D",
        "organization": "GALILEO TECHNOLOGY, LTD.",
        "address_1": "MOSHAV MANOF",
        "address_2": "",
        "country": "IL"
    },
    "0050C6": {
        "oui_hex": "00-50-C6",
        "organization": "LOOP TELECOMMUNICATION INTERNATIONAL, INC.",
        "address_1": "7F, No. 8, Hsin Ann Road",
        "address_2": "Hsinchu    -",
        "country": "TW"
    },
    "00509F": {
        "oui_hex": "00-50-9F",
        "organization": "HORIZON COMPUTER",
        "address_1": "TRINITY BLDG. 4-22-7",
        "address_2": " TOKYO 106",
        "country": "JP"
    },
    "0050A5": {
        "oui_hex": "00-50-A5",
        "organization": "CAPITOL BUSINESS SYSTEMS, LTD.",
        "address_1": "43/44 RIVERSIDE",
        "address_2": "ROCHESTER, KENT  England ME2 4DP",
        "country": "GB"
    },
    "005000": {
        "oui_hex": "00-50-00",
        "organization": "NEXO COMMUNICATIONS, INC.",
        "address_1": "2ND FL., 160, MINGCHU ROAD",
        "address_2": "HSINCHU CITY",
        "country": "TW"
    },
    "005090": {
        "oui_hex": "00-50-90",
        "organization": "DCTRI",
        "address_1": "NO.40 XUE YUAN RD",
        "address_2": "",
        "country": "CN"
    },
    "00503B": {
        "oui_hex": "00-50-3B",
        "organization": "MEDIAFIRE CORPORATION",
        "address_1": "11317 FREDERICK AVENUE",
        "address_2": "BELTSVILLE  MD  20705",
        "country": "US"
    },
    "005046": {
        "oui_hex": "00-50-46",
        "organization": "MENICX INTERNATIONAL CO., LTD.",
        "address_1": "NO.9, MING TSUN ROAD",
        "address_2": "TAIWAN 310  TAIWAN 310  R.O.C.",
        "country": "TW"
    },
    "005041": {
        "oui_hex": "00-50-41",
        "organization": "Coretronic Corporation",
        "address_1": "NO.11, LI HSIN RD.",
        "address_2": "",
        "country": "TW"
    },
    "0050B0": {
        "oui_hex": "00-50-B0",
        "organization": "TECHNOLOGY ATLANTA CORPORATION",
        "address_1": "500 Sugar Mill Road",
        "address_2": "Atlanta  GA  30350",
        "country": "US"
    },
    "0050DD": {
        "oui_hex": "00-50-DD",
        "organization": "SERRA SOLDADURA, S.A.",
        "address_1": "POL. IND. ZONA FRANCA,",
        "address_2": "",
        "country": "ES"
    },
    "005063": {
        "oui_hex": "00-50-63",
        "organization": "OY COMSEL SYSTEM AB",
        "address_1": "TEGELBRUKSGATAN 5-7",
        "address_2": "FIN-65100 VASA",
        "country": "FI"
    },
    "00508D": {
        "oui_hex": "00-50-8D",
        "organization": "ABIT COMPUTER CORPORATION",
        "address_1": "3F-7, NO. 79, SEC.1",
        "address_2": "TAIPEI HSIEN",
        "country": "TW"
    },
    "0050A0": {
        "oui_hex": "00-50-A0",
        "organization": "DELTA COMPUTER SYSTEMS, INC.",
        "address_1": "11719 NE 95TH STREET - STE.",
        "address_2": "VANCOUVER  WA  98682-2444",
        "country": "US"
    },
    "005066": {
        "oui_hex": "00-50-66",
        "organization": "AtecoM GmbH advanced telecomunication modules",
        "address_1": "KAISERSTR. 100",
        "address_2": "D-52134 HERZOGENRATH",
        "country": "DE"
    },
    "005059": {
        "oui_hex": "00-50-59",
        "organization": "iBAHN",
        "address_1": "10757 S. River Front Parkway",
        "address_2": "South Jordan  UT  84095",
        "country": "US"
    },
    "0050D9": {
        "oui_hex": "00-50-D9",
        "organization": "ENGETRON-ENGENHARIA ELETRONICA IND. e COM. LTDA",
        "address_1": "VIA SOCRATES M. BITTENCOURT, 1099",
        "address_2": "32010-010 Contagem MG",
        "country": "BR"
    },
    "005001": {
        "oui_hex": "00-50-01",
        "organization": "YAMASHITA SYSTEMS CORP.",
        "address_1": "5-7-12 IKEGAMI",
        "address_2": "OTA-KU TOKYO",
        "country": "JP"
    },
    "005067": {
        "oui_hex": "00-50-67",
        "organization": "AEROCOMM, INC.",
        "address_1": "13256 W. 98TH STREET",
        "address_2": "LENEXA  KS  66215",
        "country": "US"
    },
    "0050B6": {
        "oui_hex": "00-50-B6",
        "organization": "GOOD WAY IND. CO., LTD.",
        "address_1": "5F, NO.8, ALLEY 6,",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00504B": {
        "oui_hex": "00-50-4B",
        "organization": "BARCONET N.V.",
        "address_1": "LUIPAARDSTRAAT 12",
        "address_2": "",
        "country": "BE"
    },
    "0050EA": {
        "oui_hex": "00-50-EA",
        "organization": "XEL COMMUNICATIONS, INC.",
        "address_1": "17101 E. OHIO DRIVE",
        "address_2": "AURORA  CO  80017",
        "country": "US"
    },
    "0050C8": {
        "oui_hex": "00-50-C8",
        "organization": "Addonics Technologies, Inc.",
        "address_1": "1918 Junction Ave.,",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0050C4": {
        "oui_hex": "00-50-C4",
        "organization": "IMD",
        "address_1": "HERBSTRASSE 8",
        "address_2": "D-82178 PUCHHEIM",
        "country": "DE"
    },
    "005089": {
        "oui_hex": "00-50-89",
        "organization": "SAFETY MANAGEMENT SYSTEMS",
        "address_1": "Burgemeester Burgerslaan 40",
        "address_2": "NH Rosmalen    5245",
        "country": "NL"
    },
    "0050F4": {
        "oui_hex": "00-50-F4",
        "organization": "SIGMATEK GMBH & CO. KG",
        "address_1": "A-5112 LAMPRECHTSHAUSEN,",
        "address_2": "",
        "country": "AT"
    },
    "005021": {
        "oui_hex": "00-50-21",
        "organization": "EIS INTERNATIONAL, INC.",
        "address_1": "1351 WASHINGTON BLVD.",
        "address_2": "STAMFORD  CT  06902",
        "country": "US"
    },
    "00505E": {
        "oui_hex": "00-50-5E",
        "organization": "DIGITEK MICROLOGIC S.A.",
        "address_1": "SANT JOAN DE LA SALLE 6",
        "address_2": "",
        "country": "ES"
    },
    "0050E8": {
        "oui_hex": "00-50-E8",
        "organization": "NOMADIX INC.",
        "address_1": "2701 OCEAN PARK BLVD.-STE.#231",
        "address_2": "SANTA MONICA  CA  90405",
        "country": "US"
    },
    "0050AE": {
        "oui_hex": "00-50-AE",
        "organization": "FDK Co., Ltd",
        "address_1": "2281 Washizu",
        "address_2": "Shizuoka-ken  431-0495",
        "country": "JP"
    },
    "0050E7": {
        "oui_hex": "00-50-E7",
        "organization": "PARADISE INNOVATIONS (ASIA)",
        "address_1": "PTE. LTD.",
        "address_2": "  SINGAPORE  554914",
        "country": "SG"
    },
    "0050FB": {
        "oui_hex": "00-50-FB",
        "organization": "VSK ELECTRONICS",
        "address_1": "VENETIELAAN 39",
        "address_2": "",
        "country": "BE"
    },
    "009073": {
        "oui_hex": "00-90-73",
        "organization": "GAIO TECHNOLOGY",
        "address_1": "OAK-YOKOHAMA BLDG.",
        "address_2": "NISHI-KU YOKOHAMA-CITY  Kanagawa",
        "country": "JP"
    },
    "00907B": {
        "oui_hex": "00-90-7B",
        "organization": "E-TECH, INC.",
        "address_1": "30, R&D ROAD 2",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "009081": {
        "oui_hex": "00-90-81",
        "organization": "ALOHA NETWORKS, INC.",
        "address_1": "1001A O'REILLY AVENUE",
        "address_2": "SAN FRANCISCO  CA  94129-0472",
        "country": "US"
    },
    "00901C": {
        "oui_hex": "00-90-1C",
        "organization": "mps Software Gmbh",
        "address_1": "LUDWIGSTR 36",
        "address_2": "85551 KIRCHHEIM",
        "country": "DE"
    },
    "005086": {
        "oui_hex": "00-50-86",
        "organization": "TELKOM SA, LTD.",
        "address_1": "TELKOM LABORATORY",
        "address_2": "PRETORIA",
        "country": "ZA"
    },
    "00501A": {
        "oui_hex": "00-50-1A",
        "organization": "IQinVision",
        "address_1": "33122 Valle Road",
        "address_2": "San Juan Capistrano  CA  92675-4853",
        "country": "US"
    },
    "00508F": {
        "oui_hex": "00-50-8F",
        "organization": "ASITA TECHNOLOGIES INT'L LTD.",
        "address_1": "UNIT 2 BALLYBRIT BUSINESS PARK",
        "address_2": "",
        "country": "IE"
    },
    "005015": {
        "oui_hex": "00-50-15",
        "organization": "BRIGHT STAR ENGINEERING",
        "address_1": "19 ENFIELD DRIVE",
        "address_2": "ANDOVER  MA  01810",
        "country": "US"
    },
    "005057": {
        "oui_hex": "00-50-57",
        "organization": "BROADBAND ACCESS SYSTEMS",
        "address_1": "48 South Park St #208",
        "address_2": "Montclair  NJ  01752",
        "country": "US"
    },
    "005088": {
        "oui_hex": "00-50-88",
        "organization": "AMANO CORPORATION",
        "address_1": "275, MAMEDO-CHO",
        "address_2": "222-8558",
        "country": "JP"
    },
    "005031": {
        "oui_hex": "00-50-31",
        "organization": "AEROFLEX LABORATORIES, INC.",
        "address_1": "35 SOUTH SERVICE ROAD",
        "address_2": "PLAINVIEW  NY  11803",
        "country": "US"
    },
    "0090DB": {
        "oui_hex": "00-90-DB",
        "organization": "NEXT LEVEL COMMUNICATIONS",
        "address_1": "6085 STATE FARM DRIVE",
        "address_2": "ROHNERT PARK  CA  94928",
        "country": "US"
    },
    "009056": {
        "oui_hex": "00-90-56",
        "organization": "TELESTREAM, INC.",
        "address_1": "848 GOLD FLAT RD., SUITE 1",
        "address_2": "NEVADA CITY  CA  95959",
        "country": "US"
    },
    "009068": {
        "oui_hex": "00-90-68",
        "organization": "DVT CORP.",
        "address_1": "1670 OAKBROOK DR. - STE. #330",
        "address_2": "NORCROSS  GA  30093",
        "country": "US"
    },
    "00905E": {
        "oui_hex": "00-90-5E",
        "organization": "RAULAND-BORG CORPORATION",
        "address_1": "3450 W. OAKTON ST.",
        "address_2": "SKOKIE  IL  60076",
        "country": "US"
    },
    "0090AF": {
        "oui_hex": "00-90-AF",
        "organization": "J. MORITA MFG. CORP.",
        "address_1": "680 HIGASHIHAMA MINAMI-CHO",
        "address_2": "FUSHIMI-KU, KYOTO  612-8213",
        "country": "JP"
    },
    "005003": {
        "oui_hex": "00-50-03",
        "organization": "Xrite Inc",
        "address_1": "4300 44TH Street, S.E.",
        "address_2": "Grand Rapids  MI  49512",
        "country": "US"
    },
    "0050D3": {
        "oui_hex": "00-50-D3",
        "organization": "DIGITAL AUDIO PROCESSING PTY. LTD.",
        "address_1": "PO BOX 40",
        "address_2": "NSW 2138",
        "country": "AU"
    },
    "0050AD": {
        "oui_hex": "00-50-AD",
        "organization": "CommUnique Wireless Corp.",
        "address_1": "1070 MARINA VILLAGE PARKWAY",
        "address_2": "ALAMEDA  CA  94501",
        "country": "US"
    },
    "0050AF": {
        "oui_hex": "00-50-AF",
        "organization": "INTERGON, INC.",
        "address_1": "5800 RANCHESTER DRIVE",
        "address_2": "HOUSTON  TX  77036",
        "country": "US"
    },
    "009034": {
        "oui_hex": "00-90-34",
        "organization": "IMAGIC, INC.",
        "address_1": "235 West Road #7",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "0090AA": {
        "oui_hex": "00-90-AA",
        "organization": "INDIGO ACTIVE VISION SYSTEMS LIMITED",
        "address_1": "THE EDINBURGH TECHNOPOLE",
        "address_2": "Edinburgh EH26 OPJ",
        "country": "GB"
    },
    "00905B": {
        "oui_hex": "00-90-5B",
        "organization": "RAYMOND AND LAE ENGINEERING",
        "address_1": "208 COMMERCE DR.,  UNIT #3C",
        "address_2": "FORT COLLINS  CO  80524",
        "country": "US"
    },
    "0090BC": {
        "oui_hex": "00-90-BC",
        "organization": "TELEMANN CO., LTD.",
        "address_1": "6F DONGSIN BLDG.",
        "address_2": "SEOUL, 135-270",
        "country": "KR"
    },
    "00900A": {
        "oui_hex": "00-90-0A",
        "organization": "PROTON ELECTRONIC INDUSTRIAL CO., LTD.",
        "address_1": "",
        "address_2": "PANCHIAO, Taipei County",
        "country": "TW"
    },
    "0090F8": {
        "oui_hex": "00-90-F8",
        "organization": "MEDIATRIX TELECOM",
        "address_1": "4229 GARLOCK",
        "address_2": "QUEBEC J1L 2C8",
        "country": "CA"
    },
    "009010": {
        "oui_hex": "00-90-10",
        "organization": "SIMULATION LABORATORIES, INC.",
        "address_1": "10078 TYLER PLACE #A",
        "address_2": "IJAMSVILLE  MD  21754",
        "country": "US"
    },
    "0090C6": {
        "oui_hex": "00-90-C6",
        "organization": "OPTIM SYSTEMS, INC.",
        "address_1": "8201 GREENSBORO DR.-STE. #1000",
        "address_2": "MCLEAN  VA  22102",
        "country": "US"
    },
    "00902E": {
        "oui_hex": "00-90-2E",
        "organization": "NAMCO LIMITED",
        "address_1": "1-1-32 SHIN-URASHIMA-CHO",
        "address_2": "KANAGAWA 221-0031",
        "country": "JP"
    },
    "009037": {
        "oui_hex": "00-90-37",
        "organization": "ACUCOMM, INC.",
        "address_1": "4633 OLD IRONSIDES - STE #310",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "009078": {
        "oui_hex": "00-90-78",
        "organization": "MER TELEMANAGEMENT SOLUTIONS, LTD.",
        "address_1": "5 HATSOREF STR.",
        "address_2": "HOLON",
        "country": "IL"
    },
    "0090B8": {
        "oui_hex": "00-90-B8",
        "organization": "ROHDE & SCHWARZ GMBH & CO. KG",
        "address_1": "POSTFACH: 80 14 69/ABT.: 3CK",
        "address_2": "D-81614 MUNCHEN",
        "country": "DE"
    },
    "00901A": {
        "oui_hex": "00-90-1A",
        "organization": "UNISPHERE SOLUTIONS",
        "address_1": "5 CARLISLE ROAD",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "0090B5": {
        "oui_hex": "00-90-B5",
        "organization": "NIKON CORPORATION",
        "address_1": "Electronic Imaging Division, Designing D",
        "address_2": "TOKYO 140-8601",
        "country": "JP"
    },
    "009005": {
        "oui_hex": "00-90-05",
        "organization": "PROTECH SYSTEMS CO., LTD.",
        "address_1": "5F, NO. 34, LANE 80, SEC. 3",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "009059": {
        "oui_hex": "00-90-59",
        "organization": "TELECOM DEVICE K.K.",
        "address_1": "SANMIYANAGA BLDG. 3F, 1-5-12",
        "address_2": "  TOKYO 107",
        "country": "JP"
    },
    "0090CA": {
        "oui_hex": "00-90-CA",
        "organization": "ACCORD VIDEO TELECOMMUNICATIONS, LTD.",
        "address_1": "10, MARTIN GEHL STR, PO BOX 3564",
        "address_2": "Petach-Tikva 49130",
        "country": "IL"
    },
    "0090E9": {
        "oui_hex": "00-90-E9",
        "organization": "JANZ COMPUTER AG",
        "address_1": "Im Dörener Feld 8",
        "address_2": "D-33100  Paderborn",
        "country": "DE"
    },
    "0090EB": {
        "oui_hex": "00-90-EB",
        "organization": "SENTRY TELECOM SYSTEMS",
        "address_1": "8664 COMMERCE COURT",
        "address_2": "BURNABY  BC V5A 4N7",
        "country": "CA"
    },
    "0090FE": {
        "oui_hex": "00-90-FE",
        "organization": "ELECOM CO., LTD.  (LANEED DIV.)",
        "address_1": "TOKYU BANCHO BLDG.",
        "address_2": "Chiyoda-ku  TOKYO  102-0081",
        "country": "JP"
    },
    "0090BB": {
        "oui_hex": "00-90-BB",
        "organization": "TAINET COMMUNICATION SYSTEM Corp.",
        "address_1": "3 FL, NO. 6, ALLEY 23, LANE 91 SEC. 1",
        "address_2": "Taipei",
        "country": "TW"
    },
    "009090": {
        "oui_hex": "00-90-90",
        "organization": "I-BUS",
        "address_1": "9174 SKY PARK COURT",
        "address_2": "SAN DIEGO  CA  92123",
        "country": "US"
    },
    "0090D5": {
        "oui_hex": "00-90-D5",
        "organization": "EUPHONIX, INC.",
        "address_1": "220 PORTAGE AVE.",
        "address_2": "PALO ALTO  CA  94306",
        "country": "US"
    },
    "00904A": {
        "oui_hex": "00-90-4A",
        "organization": "CONCUR SYSTEM TECHNOLOGIES",
        "address_1": "2525 WALLINGWOOD DR.-STE. #804",
        "address_2": "AUSTIN  TX  78746",
        "country": "US"
    },
    "00908F": {
        "oui_hex": "00-90-8F",
        "organization": "AUDIO CODES LTD.",
        "address_1": "3A NETANYAHU STREET",
        "address_2": "OR YEHUDA 60256",
        "country": "IL"
    },
    "00909E": {
        "oui_hex": "00-90-9E",
        "organization": "Critical IO, LLC",
        "address_1": "485 E. 17th Street",
        "address_2": "Costa Mesa  CA  92627",
        "country": "US"
    },
    "001092": {
        "oui_hex": "00-10-92",
        "organization": "NETCORE INC.",
        "address_1": "12F-2, 537, SEC.2",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "00101C": {
        "oui_hex": "00-10-1C",
        "organization": "OHM TECHNOLOGIES INTL, LLC",
        "address_1": "4 EXECUTIVE CIRCLE, Suite 185",
        "address_2": "IRVINE  CA  92614",
        "country": "US"
    },
    "001046": {
        "oui_hex": "00-10-46",
        "organization": "ALCORN MCBRIDE INC.",
        "address_1": "3300 S. HIAWASSEE  #105",
        "address_2": "ORLANDO  FL  32835",
        "country": "US"
    },
    "001028": {
        "oui_hex": "00-10-28",
        "organization": "COMPUTER TECHNICA, INC.",
        "address_1": "3-5-19 HIGASHINAKA HAKATA-KU",
        "address_2": "FUKUOKA  816",
        "country": "JP"
    },
    "0010B7": {
        "oui_hex": "00-10-B7",
        "organization": "COYOTE TECHNOLOGIES, LLC",
        "address_1": "4360 PARK TERRACE DRIVE",
        "address_2": "WESTLAKE VILLAGE  CA  91361",
        "country": "US"
    },
    "0090E5": {
        "oui_hex": "00-90-E5",
        "organization": "TEKNEMA, INC.",
        "address_1": "2656 E. BAYSHORE ROAD",
        "address_2": "PALO ALTO  CA  94303",
        "country": "US"
    },
    "0090F4": {
        "oui_hex": "00-90-F4",
        "organization": "LIGHTNING INSTRUMENTATION",
        "address_1": "BOVERESSES 50",
        "address_2": "1010 LAUSANNE",
        "country": "CH"
    },
    "009074": {
        "oui_hex": "00-90-74",
        "organization": "ARGON NETWORKS, INC.",
        "address_1": "25 PORTER ROAD",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "00909F": {
        "oui_hex": "00-90-9F",
        "organization": "DIGI-DATA CORPORATION",
        "address_1": "7165 Columbia Gateway Drive",
        "address_2": "Columbia  MD  21045",
        "country": "US"
    },
    "00903B": {
        "oui_hex": "00-90-3B",
        "organization": "TriEMS Research Lab, Inc.",
        "address_1": "1275 N. TUSTIN AVENUE",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "0010C9": {
        "oui_hex": "00-10-C9",
        "organization": "MITSUBISHI ELECTRONICS LOGISTIC SUPPORT CO.",
        "address_1": "",
        "address_2": "Kamakura-city, Kanagawa 247",
        "country": "JP"
    },
    "000400": {
        "oui_hex": "00-04-00",
        "organization": "LEXMARK INTERNATIONAL, INC.",
        "address_1": "740 NEW CIRCLE ROAD",
        "address_2": "LEXINGTON  KY  40550",
        "country": "US"
    },
    "0010C5": {
        "oui_hex": "00-10-C5",
        "organization": "PROTOCOL TECHNOLOGIES, INC.",
        "address_1": "4 FIRST STREET",
        "address_2": "BRIDGEWATER  MA  02324",
        "country": "US"
    },
    "00101A": {
        "oui_hex": "00-10-1A",
        "organization": "PictureTel Corp.",
        "address_1": "100 MINUTEMAN ROAD, MS641",
        "address_2": "ANDOVER  MA  01810",
        "country": "US"
    },
    "001047": {
        "oui_hex": "00-10-47",
        "organization": "ECHO ELETRIC CO. LTD.",
        "address_1": "NO.6-17-1-602 Higashi Hongou",
        "address_2": "Yokohama City    226",
        "country": "JP"
    },
    "00903F": {
        "oui_hex": "00-90-3F",
        "organization": "AZTEC RADIOMEDIA",
        "address_1": "31, RUE DU CHEMINDEFER",
        "address_2": "67200 STRASBOURG",
        "country": "FR"
    },
    "001043": {
        "oui_hex": "00-10-43",
        "organization": "A2 CORPORATION",
        "address_1": "6-14-11 YUTAKA-CHO",
        "address_2": "TOKYO",
        "country": "JP"
    },
    "0010A5": {
        "oui_hex": "00-10-A5",
        "organization": "OXFORD INSTRUMENTS",
        "address_1": "Halifax Road",
        "address_2": "Buckinghamshire    HP12 3SE",
        "country": "GB"
    },
    "0010D7": {
        "oui_hex": "00-10-D7",
        "organization": "ARGOSY RESEARCH INC.",
        "address_1": "NO. 44, LANE 411, CHUNG HUA RD",
        "address_2": "",
        "country": "TW"
    },
    "00102C": {
        "oui_hex": "00-10-2C",
        "organization": "Lasat Networks A/S",
        "address_1": "Skalhuse 13",
        "address_2": "SK-9240 Nibe",
        "country": "DK"
    },
    "0010FD": {
        "oui_hex": "00-10-FD",
        "organization": "COCOM A/S",
        "address_1": "TELETONVEJ 8",
        "address_2": "DK 2860 SOBORG",
        "country": "DK"
    },
    "009019": {
        "oui_hex": "00-90-19",
        "organization": "HERMES ELECTRONICS CO., LTD.",
        "address_1": "3-2-12 YUSHIMA, BUNKYO-KU",
        "address_2": "TOKYO, 113-0034",
        "country": "JP"
    },
    "0090D8": {
        "oui_hex": "00-90-D8",
        "organization": "WHITECROSS SYSTEMS",
        "address_1": "3A WATERSIDE PARK, COOKHAM RD",
        "address_2": "BERKSHIRE RG12 1RB",
        "country": "GB"
    },
    "00104E": {
        "oui_hex": "00-10-4E",
        "organization": "CEOLOGIC",
        "address_1": "ZA DE PISSALOOP",
        "address_2": "78192 TRAPPES",
        "country": "FR"
    },
    "0010C2": {
        "oui_hex": "00-10-C2",
        "organization": "WILLNET, INC.",
        "address_1": "JOWA-TAKANAWA  BLDG. 8F",
        "address_2": "TOKYO",
        "country": "JP"
    },
    "001040": {
        "oui_hex": "00-10-40",
        "organization": "INTERMEC CORPORATION",
        "address_1": "6001 36TH AVE WEST",
        "address_2": "EVERETT  WA  98203-9280",
        "country": "US"
    },
    "00102E": {
        "oui_hex": "00-10-2E",
        "organization": "NETWORK SYSTEMS & TECHNOLOGIES PVT. LTD.",
        "address_1": "PLOT NO. 2, COCHIN EXPORT PROCESSING  ZO",
        "address_2": "KAKKANAD, COCHIN 682 030",
        "country": "IN"
    },
    "0010B0": {
        "oui_hex": "00-10-B0",
        "organization": "MERIDIAN TECHNOLOGY CORP.",
        "address_1": "11 MCBRIDE CORP. CENTER DR.",
        "address_2": "CHESTERFIELD  MD  63005",
        "country": "US"
    },
    "001021": {
        "oui_hex": "00-10-21",
        "organization": "ENCANTO NETWORKS, INC.",
        "address_1": "2953 BUNKER HILL LANE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "001064": {
        "oui_hex": "00-10-64",
        "organization": "DNPG, LLC",
        "address_1": "20 North Wentworth Avenue",
        "address_2": "Londonderry  NH  03053",
        "country": "US"
    },
    "001074": {
        "oui_hex": "00-10-74",
        "organization": "ATEN INTERNATIONAL CO., LTD.",
        "address_1": "12F, NO.101, SUNG CHIANG RD.",
        "address_2": "TAIPEI, 10428",
        "country": "TW"
    },
    "00109E": {
        "oui_hex": "00-10-9E",
        "organization": "AWARE, INC.",
        "address_1": "ONE OAK PARK",
        "address_2": "BEDFORD  MA  01730",
        "country": "US"
    },
    "001005": {
        "oui_hex": "00-10-05",
        "organization": "UEC COMMERCIAL",
        "address_1": "P.O. BOX 54,",
        "address_2": "4300 DURBAN",
        "country": "ZA"
    },
    "0010B8": {
        "oui_hex": "00-10-B8",
        "organization": "ISHIGAKI COMPUTER SYSTEM CO.",
        "address_1": "1-1-1, KYOBASHI,",
        "address_2": "Tokyo",
        "country": "JP"
    },
    "00108B": {
        "oui_hex": "00-10-8B",
        "organization": "LASERANIMATION SOLLINGER GMBH",
        "address_1": "CRELLESTR. 19/20",
        "address_2": "D 10827 BERLIN",
        "country": "DE"
    },
    "0010C7": {
        "oui_hex": "00-10-C7",
        "organization": "DATA TRANSMISSION NETWORK",
        "address_1": "9110 W. DODGE RD. - STE.#200",
        "address_2": "OMAHA  NE  68114",
        "country": "US"
    },
    "001070": {
        "oui_hex": "00-10-70",
        "organization": "CARADON TREND LTD.",
        "address_1": "P.O. BOX 34, HORSHAM",
        "address_2": "WEST SUSSEX, RH12 2YF  ENGLAND",
        "country": "GB"
    },
    "0010BA": {
        "oui_hex": "00-10-BA",
        "organization": "MARTINHO-DAVIS SYSTEMS, INC.",
        "address_1": "1260 OLD INNES ROAD",
        "address_2": "OTTAWA, ONTARIO K1B 3V3",
        "country": "CA"
    },
    "0010B4": {
        "oui_hex": "00-10-B4",
        "organization": "ATMOSPHERE NETWORKS",
        "address_1": "10460 BANDLEY DRIVE",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "0004AC": {
        "oui_hex": "00-04-AC",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "001067": {
        "oui_hex": "00-10-67",
        "organization": "Ericsson",
        "address_1": "250 Holger Way",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00E07D": {
        "oui_hex": "00-E0-7D",
        "organization": "NETRONIX, INC.",
        "address_1": "340 THOR PLACE",
        "address_2": "BREA  CA  92821",
        "country": "US"
    },
    "00E028": {
        "oui_hex": "00-E0-28",
        "organization": "APTIX CORPORATION",
        "address_1": "2880 N. FIRST STREET",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00E08C": {
        "oui_hex": "00-E0-8C",
        "organization": "NEOPARADIGM LABS, INC.",
        "address_1": "1735 N. FIRST ST.,  STE #108",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "00E0A1": {
        "oui_hex": "00-E0-A1",
        "organization": "HIMA PAUL HILDEBRANDT GmbH Co. KG",
        "address_1": "POSTBOX 1261",
        "address_2": "D-68777 BRUEHL NEAR MANNHEIM",
        "country": "DE"
    },
    "00E088": {
        "oui_hex": "00-E0-88",
        "organization": "LTX-Credence CORPORATION",
        "address_1": "825 UNIVERSITY AVENUE",
        "address_2": "NORWOOD  MA  02062-2643",
        "country": "US"
    },
    "00E05D": {
        "oui_hex": "00-E0-5D",
        "organization": "UNITEC CO., LTD.",
        "address_1": "KISOGAWA-CHO  ICHINOTORI 24",
        "address_2": "HAGURI-GUN AICHI 493",
        "country": "JP"
    },
    "00E05E": {
        "oui_hex": "00-E0-5E",
        "organization": "JAPAN AVIATION ELECTRONICS INDUSTRY, LTD.",
        "address_1": "",
        "address_2": "TOKYO 196  JAPAN",
        "country": "JP"
    },
    "00E09D": {
        "oui_hex": "00-E0-9D",
        "organization": "SARNOFF CORPORATION",
        "address_1": "CN 5300",
        "address_2": "PRINCETON  NJ  08543-5300",
        "country": "US"
    },
    "00E058": {
        "oui_hex": "00-E0-58",
        "organization": "PHASE ONE DENMARK A/S",
        "address_1": "ROSKILDEVEJ 39",
        "address_2": "DK-2000 FREDERIKSBERG",
        "country": "DK"
    },
    "00E076": {
        "oui_hex": "00-E0-76",
        "organization": "DEVELOPMENT CONCEPTS, INC.",
        "address_1": "1000 N. BROAD STREET",
        "address_2": "LANSDALE  PA  19446",
        "country": "US"
    },
    "00E0F8": {
        "oui_hex": "00-E0-F8",
        "organization": "DICNA CONTROL AB",
        "address_1": "STENYXEGATAN 21 C",
        "address_2": "213 76 MALMOE",
        "country": "SE"
    },
    "00E0DF": {
        "oui_hex": "00-E0-DF",
        "organization": "KEYMILE GmbH",
        "address_1": "Wohlenbergstraße 3",
        "address_2": "30179  Hannover",
        "country": "DE"
    },
    "00E0F2": {
        "oui_hex": "00-E0-F2",
        "organization": "ARLOTTO COMNET, INC.",
        "address_1": "7F-4,55,TUNG-KUANG ROAD",
        "address_2": "HSIN-CHU, 300",
        "country": "TW"
    },
    "00E0E1": {
        "oui_hex": "00-E0-E1",
        "organization": "G2 NETWORKS, INC.",
        "address_1": "142 SO. SANTA CRUZ AVE.",
        "address_2": "LOS GATOS  CA  95030-6702",
        "country": "US"
    },
    "00E03D": {
        "oui_hex": "00-E0-3D",
        "organization": "FOCON ELECTRONIC SYSTEMS A/S",
        "address_1": "DAMVANG, PO BOX 269",
        "address_2": "DK-6400 SONDERBORG",
        "country": "DK"
    },
    "00E046": {
        "oui_hex": "00-E0-46",
        "organization": "BENTLY NEVADA CORP.",
        "address_1": "PO BOX 157",
        "address_2": "MINDEN  NV  89423",
        "country": "US"
    },
    "00E07B": {
        "oui_hex": "00-E0-7B",
        "organization": "BAY NETWORKS",
        "address_1": "125 NAGOG PARK",
        "address_2": "ACTON  MA  01720",
        "country": "US"
    },
    "00E01D": {
        "oui_hex": "00-E0-1D",
        "organization": "WebTV NETWORKS, INC.",
        "address_1": "305 LYTTON AVE.",
        "address_2": "PALO ALTO  CA  94301",
        "country": "US"
    },
    "00E0CD": {
        "oui_hex": "00-E0-CD",
        "organization": "SAAB SENSIS CORPORATION",
        "address_1": "85 Collamer Crossings",
        "address_2": "East Syracuse  NY  13057",
        "country": "US"
    },
    "00E08D": {
        "oui_hex": "00-E0-8D",
        "organization": "PRESSURE SYSTEMS, INC.",
        "address_1": "34 RESEARCH DRIVE",
        "address_2": "HAMPTON  VA  23666",
        "country": "US"
    },
    "00E019": {
        "oui_hex": "00-E0-19",
        "organization": "ING. GIORDANO ELETTRONICA",
        "address_1": "VIA PIETRO COSSA  115/12",
        "address_2": "10146-TORINO",
        "country": "IT"
    },
    "00E047": {
        "oui_hex": "00-E0-47",
        "organization": "InFocus Corporation",
        "address_1": "27500 SW Parkway Avenue",
        "address_2": "Wilsonville  OR  97070-8238",
        "country": "US"
    },
    "00E0C3": {
        "oui_hex": "00-E0-C3",
        "organization": "SAKAI SYSTEM DEVELOPMENT CORP.",
        "address_1": "PORTUS CENTER BLD., 4-45-1",
        "address_2": "OSAKA-FU, 590",
        "country": "JP"
    },
    "00E092": {
        "oui_hex": "00-E0-92",
        "organization": "ADMTEK INCORPORATED",
        "address_1": "1962 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "00E0FF": {
        "oui_hex": "00-E0-FF",
        "organization": "SECURITY DYNAMICS TECHNOLOGIES, Inc.",
        "address_1": "20 CROSBY DRIVE",
        "address_2": "BEDFORD  MA  01730",
        "country": "US"
    },
    "00E0AB": {
        "oui_hex": "00-E0-AB",
        "organization": "DIMAT S.A.",
        "address_1": "C/BISCAIA 383 3",
        "address_2": "08023  BARCELONA",
        "country": "ES"
    },
    "00E030": {
        "oui_hex": "00-E0-30",
        "organization": "MELITA INTERNATIONAL CORP.",
        "address_1": "5051 PEACHTREE CORNERS CIRCLE",
        "address_2": "NORCROSS  GA  30092",
        "country": "US"
    },
    "00E033": {
        "oui_hex": "00-E0-33",
        "organization": "E.E.P.D. GmbH",
        "address_1": "ROEMER-STRASSE 4",
        "address_2": "85229 MARKT INDERSDORF",
        "country": "DE"
    },
    "00E0A2": {
        "oui_hex": "00-E0-A2",
        "organization": "MICROSLATE INC.",
        "address_1": "9625 IGNACE - STE. D",
        "address_2": "BROSSARD  QC J4Y 2P3",
        "country": "CA"
    },
    "00E079": {
        "oui_hex": "00-E0-79",
        "organization": "A.T.N.R.",
        "address_1": "BP 966",
        "address_2": "91976 COURTABOEUF",
        "country": "FR"
    },
    "00E075": {
        "oui_hex": "00-E0-75",
        "organization": "Verilink Corporation",
        "address_1": "127 Jetplex Circle",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "006039": {
        "oui_hex": "00-60-39",
        "organization": "SanCom Technology, Inc.",
        "address_1": "7719 WOOD HOLLOW DRIVE",
        "address_2": "AUSTIN  TX  78731",
        "country": "US"
    },
    "006049": {
        "oui_hex": "00-60-49",
        "organization": "VINA TECHNOLOGIES",
        "address_1": "6 UNION SQUARE - STE F",
        "address_2": "UNION CITY  CA  94587",
        "country": "US"
    },
    "00608D": {
        "oui_hex": "00-60-8D",
        "organization": "UNIPULSE CORP.",
        "address_1": "2-7, SENGENDAI-NISHI",
        "address_2": "SAITAMA 343",
        "country": "JO"
    },
    "00E02E": {
        "oui_hex": "00-E0-2E",
        "organization": "SPC ELECTRONICS CORPORATION",
        "address_1": "2-1-3 SHIBASAKI, CHOFU-SHI",
        "address_2": "TOKYO, 182",
        "country": "JP"
    },
    "00E09A": {
        "oui_hex": "00-E0-9A",
        "organization": "Positron Inc.",
        "address_1": "5101 Buchan Street",
        "address_2": "Montreal,  Québec  H4P 2R9",
        "country": "CA"
    },
    "00E03E": {
        "oui_hex": "00-E0-3E",
        "organization": "ALFATECH, INC.",
        "address_1": "SHIN-OSAKA EITO BLDG.",
        "address_2": "OSAKA",
        "country": "JP"
    },
    "006099": {
        "oui_hex": "00-60-99",
        "organization": "SBE, Inc.",
        "address_1": "4000 Executive Parkway",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "0060B3": {
        "oui_hex": "00-60-B3",
        "organization": "Z-COM, INC.",
        "address_1": "7F-2, NO.9, PROSPERITY 1ST RD.",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "006002": {
        "oui_hex": "00-60-02",
        "organization": "SCREEN SUBTITLING SYSTEMS, LTD",
        "address_1": "THE OLD RECTORY",
        "address_2": "CLAYDON  IPSWICH  IP6 OEQ",
        "country": "GB"
    },
    "006089": {
        "oui_hex": "00-60-89",
        "organization": "XATA",
        "address_1": "151 EAST CLIFF ROAD-STE.#10",
        "address_2": "BURNSVILLE  MN  55337",
        "country": "US"
    },
    "006021": {
        "oui_hex": "00-60-21",
        "organization": "DSC CORPORATION",
        "address_1": "RECRUIT-SHINOHTSUKA BLDG.,",
        "address_2": "TOKYO 170",
        "country": "JP"
    },
    "0060B8": {
        "oui_hex": "00-60-B8",
        "organization": "CORELIS Inc.",
        "address_1": "12607 Hiddencreek Way",
        "address_2": "Cerritos  CA  90703",
        "country": "US"
    },
    "00E0AA": {
        "oui_hex": "00-E0-AA",
        "organization": "ELECTROSONIC LTD.",
        "address_1": "HAWLEY MILL, HAWLEY RD.",
        "address_2": "DARTFORD, KENT DA2 7SY",
        "country": "GB"
    },
    "00E010": {
        "oui_hex": "00-E0-10",
        "organization": "HESS SB-AUTOMATENBAU GmbH",
        "address_1": "HINDENBURGSTRASSE 27-29",
        "address_2": "D-71106 MAGSTADT",
        "country": "DE"
    },
    "00E0D2": {
        "oui_hex": "00-E0-D2",
        "organization": "VERSANET COMMUNICATIONS, INC.",
        "address_1": "628 N. DIAMOND BAR BLVD.",
        "address_2": "DIAMOND BAR  CA  91765",
        "country": "US"
    },
    "0060CE": {
        "oui_hex": "00-60-CE",
        "organization": "ACCLAIM COMMUNICATIONS",
        "address_1": "5000 OLD IRONSIDES DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "006036": {
        "oui_hex": "00-60-36",
        "organization": "AIT Austrian Institute of Technology GmbH",
        "address_1": "Donau-City-Straße 1",
        "address_2": "Vienna    1220",
        "country": "AT"
    },
    "00608E": {
        "oui_hex": "00-60-8E",
        "organization": "HE ELECTRONICS, TECHNOLOGIE & SYSTEMTECHNIK GmbH",
        "address_1": "AM GNEISENAUFLOT 8",
        "address_2": " D-66538 NEUNHIRCHEN",
        "country": "DE"
    },
    "00601A": {
        "oui_hex": "00-60-1A",
        "organization": "KEITHLEY INSTRUMENTS",
        "address_1": "30500 BAINBRIDGE RD.",
        "address_2": "SOLON  OH  44139",
        "country": "US"
    },
    "00606A": {
        "oui_hex": "00-60-6A",
        "organization": "MITSUBISHI WIRELESS COMMUNICATIONS. INC.",
        "address_1": "2001 CHERRY DRIVE",
        "address_2": "BRASELTON  GA  30517",
        "country": "US"
    },
    "0060AD": {
        "oui_hex": "00-60-AD",
        "organization": "MegaChips Corporation",
        "address_1": "4-1-6,Miyahara",
        "address_2": "  Osaka  532-0003",
        "country": "JP"
    },
    "006055": {
        "oui_hex": "00-60-55",
        "organization": "CORNELL UNIVERSITY",
        "address_1": "729 Rhodes Hall",
        "address_2": "ITHACA  NY  14850-4902",
        "country": "US"
    },
    "00606D": {
        "oui_hex": "00-60-6D",
        "organization": "DIGITAL EQUIPMENT CORP.",
        "address_1": "550 KING STREET",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "0060B9": {
        "oui_hex": "00-60-B9",
        "organization": "NEC Platforms, Ltd",
        "address_1": "2-6-1,Kitamikata,Takatsu-ku",
        "address_2": "Kawasaki    213-8511",
        "country": "JP"
    },
    "00609C": {
        "oui_hex": "00-60-9C",
        "organization": "Perkin-Elmer Incorporated",
        "address_1": "710 Bridgeport Ave.",
        "address_2": "Shelton  CT  06484",
        "country": "US"
    },
    "0060CF": {
        "oui_hex": "00-60-CF",
        "organization": "ALTEON NETWORKS, INC.",
        "address_1": "50 GREAT OAKS BLVD.",
        "address_2": "SAN JOSE  CA  95119",
        "country": "US"
    },
    "006075": {
        "oui_hex": "00-60-75",
        "organization": "PENTEK, INC.",
        "address_1": "1 PARK WAY",
        "address_2": "UPPER SADDLE RIVER  NJ  07458",
        "country": "US"
    },
    "0060B7": {
        "oui_hex": "00-60-B7",
        "organization": "CHANNELMATIC, INC.",
        "address_1": "1700 GILLESPIE WAY",
        "address_2": "EL CAJON  CA  92020-0901",
        "country": "US"
    },
    "006006": {
        "oui_hex": "00-60-06",
        "organization": "SOTEC CO., LTD",
        "address_1": "YOKOHAMA BASHAMICHI BLDG.,",
        "address_2": "YOKOHAMA  231",
        "country": "JP"
    },
    "0060BA": {
        "oui_hex": "00-60-BA",
        "organization": "SAHARA NETWORKS, INC.",
        "address_1": "335 HIGHLAND AVE.",
        "address_2": "CHESHIRE  CT  06410",
        "country": "US"
    },
    "006098": {
        "oui_hex": "00-60-98",
        "organization": "HT COMMUNICATIONS",
        "address_1": "4480 SHOPPING LANE",
        "address_2": "SIMI VALLEY  CA  93063",
        "country": "US"
    },
    "0060DE": {
        "oui_hex": "00-60-DE",
        "organization": "Kayser-Threde GmbH",
        "address_1": "Wolfratshauser Str. 48",
        "address_2": "D-81379  Munich",
        "country": "DE"
    },
    "0060D0": {
        "oui_hex": "00-60-D0",
        "organization": "SNMP RESEARCH INCORPORATED",
        "address_1": "3001 KIMBERLIN HEIGHTS ROAD",
        "address_2": "KNOXVILLE  TN  37920-9716",
        "country": "US"
    },
    "006015": {
        "oui_hex": "00-60-15",
        "organization": "NET2NET CORPORATION",
        "address_1": "131 COOLIDGE STREET",
        "address_2": "HUDSON  MA  01749",
        "country": "US"
    },
    "00609D": {
        "oui_hex": "00-60-9D",
        "organization": "PMI FOOD EQUIPMENT GROUP",
        "address_1": "701 RIDGE AVENUE",
        "address_2": "TROY  OH  45374",
        "country": "US"
    },
    "0060A2": {
        "oui_hex": "00-60-A2",
        "organization": "NIHON UNISYS LIMITED CO.",
        "address_1": "P.O. BOX 135",
        "address_2": "SHINONOME 1-10-9",
        "country": "JP"
    },
    "006084": {
        "oui_hex": "00-60-84",
        "organization": "DIGITAL VIDEO",
        "address_1": "4920 AVALON RIDGE PKWY",
        "address_2": "NORCROSS  GA  30092",
        "country": "US"
    },
    "00602D": {
        "oui_hex": "00-60-2D",
        "organization": "ALERTON TECHNOLOGIES, INC.",
        "address_1": "6670 185TH AVE. N.E.",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "0060F8": {
        "oui_hex": "00-60-F8",
        "organization": "Loran International Technologies Inc.",
        "address_1": "955 GREEN VALLEY CRESCENT",
        "address_2": "OTTAWA, ONTARIO K2C 3V4",
        "country": "CA"
    },
    "006078": {
        "oui_hex": "00-60-78",
        "organization": "POWER MEASUREMENT LTD.",
        "address_1": "2195 KEATING CROSS ROAD",
        "address_2": "SAANICHTON, B.C. V8M 2A5",
        "country": "CA"
    },
    "0060E8": {
        "oui_hex": "00-60-E8",
        "organization": "HITACHI COMPUTER PRODUCTS (AMERICA), INC.",
        "address_1": "3101 TASMAN DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0060F6": {
        "oui_hex": "00-60-F6",
        "organization": "NEXTEST COMMUNICATIONS PRODUCTS, INC.",
        "address_1": "TWO MID AMERICA PLAZA, STE.500",
        "address_2": "OAKBROOK TERRACE  IL  60181",
        "country": "US"
    },
    "006072": {
        "oui_hex": "00-60-72",
        "organization": "VXL INSTRUMENTS, LIMITED",
        "address_1": "PLOT NO. 17, KONAPPANA AGRAHARA",
        "address_2": "BANGALORE -  561 229",
        "country": "IN"
    },
    "006051": {
        "oui_hex": "00-60-51",
        "organization": "QUALITY SEMICONDUCTOR",
        "address_1": "851 MARTIN AVENUE",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "006092": {
        "oui_hex": "00-60-92",
        "organization": "MICRO/SYS, INC.",
        "address_1": "3447 OCEAN VIEW BLVD.",
        "address_2": "GLENDALE  CA  91208",
        "country": "US"
    },
    "00609E": {
        "oui_hex": "00-60-9E",
        "organization": "ASC X3 - INFORMATION TECHNOLOGY STANDARDS SECRETARIATS",
        "address_1": "1250 EYE STREET NW - STE #200",
        "address_2": "WASHINGTON  DC  20005",
        "country": "US"
    },
    "006010": {
        "oui_hex": "00-60-10",
        "organization": "NETWORK MACHINES, INC.",
        "address_1": "255 OLD NEW BRUNSWICK RD., # N320",
        "address_2": "PISCATAWAY  NJ  08854",
        "country": "US"
    },
    "006044": {
        "oui_hex": "00-60-44",
        "organization": "LITTON/POLY-SCIENTIFIC",
        "address_1": "2200 SOUTH MAIN STREET",
        "address_2": "BLACKSBURG  VA  24060",
        "country": "US"
    },
    "006004": {
        "oui_hex": "00-60-04",
        "organization": "COMPUTADORES MODULARES SA",
        "address_1": "AVDA MONTESIERRA S/N",
        "address_2": "41020-SEVILLA",
        "country": "ES"
    },
    "0060E2": {
        "oui_hex": "00-60-E2",
        "organization": "QUEST ENGINEERING & DEVELOPMENT",
        "address_1": "1345 EAST ROCK WREN ROAD",
        "address_2": "PHOENIX  AZ  85048",
        "country": "US"
    },
    "0060B4": {
        "oui_hex": "00-60-B4",
        "organization": "GLENAYRE R&D INC.",
        "address_1": "1570 KOOTENAY STREET",
        "address_2": "VANCOUVER, BC V5K 5B8",
        "country": "CA"
    },
    "00A01D": {
        "oui_hex": "00-A0-1D",
        "organization": "Red Lion Controls, LP",
        "address_1": "20 Willow Springs Circle",
        "address_2": "York  NY  17402",
        "country": "US"
    },
    "00A0A6": {
        "oui_hex": "00-A0-A6",
        "organization": "M.I. SYSTEMS, K.K.",
        "address_1": "2-7-12-308 Satsukigaoka",
        "address_2": "Ikeda-Shi  Osaka  563-0029",
        "country": "JP"
    },
    "00A051": {
        "oui_hex": "00-A0-51",
        "organization": "ANGIA COMMUNICATIONS. INC.",
        "address_1": "441 EAST BAY BLVD.",
        "address_2": "PROVO  UTAH  84606",
        "country": "US"
    },
    "00A013": {
        "oui_hex": "00-A0-13",
        "organization": "TELTREND LTD.",
        "address_1": "RINGWAY HOUSE, BELL ROAD",
        "address_2": "BASINGSTOKE HAMPSHIRE RG24 8F",
        "country": "GB"
    },
    "00A0B9": {
        "oui_hex": "00-A0-B9",
        "organization": "EAGLE TECHNOLOGY, INC.",
        "address_1": "6800 ORANGETHORPE AVE.UNIT",
        "address_2": "BUENA PARK  CA  90620",
        "country": "US"
    },
    "00A019": {
        "oui_hex": "00-A0-19",
        "organization": "NEBULA CONSULTANTS, INC.",
        "address_1": "1449 DUNCAN DRIVE",
        "address_2": "DELTA, BC V4L 1R5",
        "country": "CA"
    },
    "00A0ED": {
        "oui_hex": "00-A0-ED",
        "organization": "Brooks Automation, Inc.",
        "address_1": "15 Elizabeth Drive",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "0060CA": {
        "oui_hex": "00-60-CA",
        "organization": "HARMONIC SYSTEMS INCORPORATED",
        "address_1": "199 1ST STREET - STE #302",
        "address_2": "LOS ALTOS  CA  94022",
        "country": "US"
    },
    "006024": {
        "oui_hex": "00-60-24",
        "organization": "GRADIENT TECHNOLOGIES, INC.",
        "address_1": "2 MOUNT ROYAL AVENUE",
        "address_2": "MARLBORO  MA  01752",
        "country": "US"
    },
    "0060AF": {
        "oui_hex": "00-60-AF",
        "organization": "PACIFIC MICRO DATA, INC.",
        "address_1": "16751 MILLIKAN AVENUE",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "006038": {
        "oui_hex": "00-60-38",
        "organization": "Nortel Networks",
        "address_1": "Global Operations Engineering",
        "address_2": "Brampton  ON  l6T 5P6 Cana",
        "country": "CA"
    },
    "00604F": {
        "oui_hex": "00-60-4F",
        "organization": "Tattile SRL",
        "address_1": "552-51 AJIGAURA",
        "address_2": "IBARAKI, 311-12",
        "country": "JP"
    },
    "00A0D0": {
        "oui_hex": "00-A0-D0",
        "organization": "TEN X TECHNOLOGY, INC.",
        "address_1": "13091 POND SPRINGS ROAD, Suite B-200",
        "address_2": "AUSTIN  TX  78729",
        "country": "US"
    },
    "00A0BC": {
        "oui_hex": "00-A0-BC",
        "organization": "VIASAT, INCORPORATED",
        "address_1": "6155 El Camino Real",
        "address_2": "Carlsbad  Ca  92009",
        "country": "US"
    },
    "00A05B": {
        "oui_hex": "00-A0-5B",
        "organization": "MARQUIP, INC.",
        "address_1": "1245 E. WASHINGTON AVE.",
        "address_2": "MADISON  WI  53703",
        "country": "US"
    },
    "00A08C": {
        "oui_hex": "00-A0-8C",
        "organization": "MultiMedia LANs, Inc.",
        "address_1": "5600 EXECUTIVE CENTER DRIVE",
        "address_2": "CHARLOTTE  NC  28212",
        "country": "US"
    },
    "00A058": {
        "oui_hex": "00-A0-58",
        "organization": "GLORY, LTD.",
        "address_1": "1-3-1 SHIMOTENO, HIMEJI",
        "address_2": "HYOGO PREF. 670",
        "country": "JP"
    },
    "00A077": {
        "oui_hex": "00-A0-77",
        "organization": "FUJITSU NEXION, INC.",
        "address_1": "289 GREAT ROAD",
        "address_2": "ACTON  MA  01720-4739",
        "country": "US"
    },
    "00A0A0": {
        "oui_hex": "00-A0-A0",
        "organization": "COMPACT DATA, LTD.",
        "address_1": "58 DITTON WALK",
        "address_2": "CAMBRIDGE CB5 8QE",
        "country": "GB"
    },
    "00A038": {
        "oui_hex": "00-A0-38",
        "organization": "EMAIL ELECTRONICS",
        "address_1": "P.O. BOX 154",
        "address_2": "MOOROOLBARK, 3138",
        "country": "AU"
    },
    "00A065": {
        "oui_hex": "00-A0-65",
        "organization": "Symantec Corporation",
        "address_1": "20330 Stevens Creek Blvd.",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00A0A3": {
        "oui_hex": "00-A0-A3",
        "organization": "RELIABLE POWER METERS",
        "address_1": "400 BLOSSOM HILL ROAD",
        "address_2": "LOS GATOS  CA  95032-4511",
        "country": "US"
    },
    "00A01B": {
        "oui_hex": "00-A0-1B",
        "organization": "PREMISYS COMMUNICATIONS, INC.",
        "address_1": "48664 MILMONT DRIVE",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00A055": {
        "oui_hex": "00-A0-55",
        "organization": "Data Device Corporation",
        "address_1": "105 Wilbur Place",
        "address_2": "Bohemia  NY  11716",
        "country": "US"
    },
    "00A074": {
        "oui_hex": "00-A0-74",
        "organization": "PERCEPTION TECHNOLOGY",
        "address_1": "40 SHAWMUT ROAD",
        "address_2": "CANTON  MA  02021-1409",
        "country": "US"
    },
    "00A07F": {
        "oui_hex": "00-A0-7F",
        "organization": "GSM-SYNTEL, LTD.",
        "address_1": "VICTORIA WORKS, QUEENS MILL RD",
        "address_2": "HD1  3PG  ENGLAND",
        "country": "GB"
    },
    "00A029": {
        "oui_hex": "00-A0-29",
        "organization": "COULTER CORPORATION",
        "address_1": "11800 S.W. 147TH AVE.",
        "address_2": "MIAMI  FL  33196",
        "country": "US"
    },
    "00A087": {
        "oui_hex": "00-A0-87",
        "organization": "Microsemi Corporation",
        "address_1": "400 March Road",
        "address_2": "Ontario    K2K 3H4",
        "country": "CA"
    },
    "00A043": {
        "oui_hex": "00-A0-43",
        "organization": "AMERICAN TECHNOLOGY LABS, INC.",
        "address_1": "115 WEST 3RD STREET",
        "address_2": "STEVENSVILLE  MT  59870",
        "country": "US"
    },
    "00A042": {
        "oui_hex": "00-A0-42",
        "organization": "SPUR PRODUCTS CORP.",
        "address_1": "9288 W. EMERALD STREET",
        "address_2": "BOISE  ID  83704",
        "country": "US"
    },
    "00A0C1": {
        "oui_hex": "00-A0-C1",
        "organization": "ORTIVUS MEDICAL AB",
        "address_1": "BOX 513",
        "address_2": "",
        "country": "SE"
    },
    "00A04F": {
        "oui_hex": "00-A0-4F",
        "organization": "AMERITEC CORP.",
        "address_1": "760 ARROW GRAND CIRCLE",
        "address_2": "COVINA  CA  91722",
        "country": "US"
    },
    "00A0CF": {
        "oui_hex": "00-A0-CF",
        "organization": "SOTAS, INC.",
        "address_1": "2 RESEARCH PLACE, STE.",
        "address_2": "ROCKVILLE  MD  20850",
        "country": "US"
    },
    "00A072": {
        "oui_hex": "00-A0-72",
        "organization": "OVATION SYSTEMS LTD.",
        "address_1": "GREAT HASELEY TRAD. EST.",
        "address_2": "  ENGLAND",
        "country": "GB"
    },
    "00A082": {
        "oui_hex": "00-A0-82",
        "organization": "NKT ELEKTRONIK A/S",
        "address_1": "NKT ALLE 85",
        "address_2": "",
        "country": "DK"
    },
    "00A0F0": {
        "oui_hex": "00-A0-F0",
        "organization": "TORONTO MICROELECTRONICS INC.",
        "address_1": "5149 BRADCO BOULEVARD",
        "address_2": "    L4W 2A6",
        "country": "CA"
    },
    "00A0D7": {
        "oui_hex": "00-A0-D7",
        "organization": "KASTEN CHASE APPLIED RESEARCH",
        "address_1": "5100 ORBITOR DRIVE",
        "address_2": "    L4W 4Z4",
        "country": "CA"
    },
    "00A0F1": {
        "oui_hex": "00-A0-F1",
        "organization": "MTI",
        "address_1": "4905 E. LA PALMA AVENUE",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "00A0B3": {
        "oui_hex": "00-A0-B3",
        "organization": "ZYKRONIX",
        "address_1": "7248 SOUTH TUCSON WAY",
        "address_2": "ENGLEWOOD  CO  80112",
        "country": "US"
    },
    "00A0FF": {
        "oui_hex": "00-A0-FF",
        "organization": "TELLABS OPERATIONS, INC.",
        "address_1": "1000 REMINGTON BLVD.",
        "address_2": "    60440",
        "country": "US"
    },
    "00A0E5": {
        "oui_hex": "00-A0-E5",
        "organization": "NHC COMMUNICATIONS",
        "address_1": "5450 COTE DE LIESSE",
        "address_2": "MONTREAL,  QUEBEC  H4P 1A5",
        "country": "CA"
    },
    "00A036": {
        "oui_hex": "00-A0-36",
        "organization": "APPLIED NETWORK TECHNOLOGY",
        "address_1": "319 LITTLETON ROAD--STE #101",
        "address_2": "WESTFORD  MA  01886-4133",
        "country": "US"
    },
    "00A0D2": {
        "oui_hex": "00-A0-D2",
        "organization": "ALLIED TELESIS INTERNATIONAL CORPORATION",
        "address_1": "950 KIFER ROAD",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00A09B": {
        "oui_hex": "00-A0-9B",
        "organization": "QPSX COMMUNICATIONS, LTD.",
        "address_1": "33 RICHARDSON STREET",
        "address_2": "Western    00000",
        "country": "AU"
    },
    "00A000": {
        "oui_hex": "00-A0-00",
        "organization": "CENTILLION NETWORKS, INC.",
        "address_1": "359 RAVENDALE DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00A08A": {
        "oui_hex": "00-A0-8A",
        "organization": "BROOKTROUT TECHNOLOGY, INC.",
        "address_1": "144 GOULD STREET- SUITE #200",
        "address_2": "NEEDHAM  MA  02194",
        "country": "US"
    },
    "00A07B": {
        "oui_hex": "00-A0-7B",
        "organization": "DAWN COMPUTER INCORPORATION",
        "address_1": "6 KEXUEYUAN SOUTH ROAD",
        "address_2": "",
        "country": "CN"
    },
    "00A05C": {
        "oui_hex": "00-A0-5C",
        "organization": "INVENTORY CONVERSION, INC./",
        "address_1": "NEKOTECH DIVISION",
        "address_2": "HAMPTON  NH  03842",
        "country": "US"
    },
    "00200F": {
        "oui_hex": "00-20-0F",
        "organization": "EBRAINS Inc",
        "address_1": "Tachibana Bldg",
        "address_2": "Taito-ku  Tokyo  110-0003",
        "country": "JP"
    },
    "00A0D3": {
        "oui_hex": "00-A0-D3",
        "organization": "INSTEM COMPUTER SYSTEMS, LTD.",
        "address_1": "WALTON INDUSTRIAL ESTATE",
        "address_2": "",
        "country": "GB"
    },
    "00A0B4": {
        "oui_hex": "00-A0-B4",
        "organization": "TEXAS MICROSYSTEMS, INC.",
        "address_1": "5959 CORPORATE DRIVE",
        "address_2": "HOUSTON  TX  77036",
        "country": "US"
    },
    "00A060": {
        "oui_hex": "00-A0-60",
        "organization": "ACER PERIPHERALS, INC.",
        "address_1": "9F, 135 CHIAN KUO N. RD. SEC 2",
        "address_2": "",
        "country": "TW"
    },
    "00A083": {
        "oui_hex": "00-A0-83",
        "organization": "ASIMMPHONY TURKEY",
        "address_1": "ELECTRONICS, LTD.",
        "address_2": "    V7C 4N1",
        "country": "CA"
    },
    "00A0AA": {
        "oui_hex": "00-A0-AA",
        "organization": "SPACELABS MEDICAL",
        "address_1": "5150 220 Ave SE",
        "address_2": "Issaquah  WA  98027",
        "country": "US"
    },
    "00A03B": {
        "oui_hex": "00-A0-3B",
        "organization": "TOSHIN ELECTRIC CO., LTD.",
        "address_1": "3FL. RIVER-STONE 3RD. BLG.234",
        "address_2": "  213",
        "country": "JP"
    },
    "00A0F3": {
        "oui_hex": "00-A0-F3",
        "organization": "STAUBLI",
        "address_1": "183 RUE DES USINES",
        "address_2": "",
        "country": "FR"
    },
    "0020DF": {
        "oui_hex": "00-20-DF",
        "organization": "KYOSAN ELECTRIC MFG. CO., LTD.",
        "address_1": "2-29, HEIAN-CHO, TSURUMI-KU",
        "address_2": "",
        "country": "JP"
    },
    "0020C7": {
        "oui_hex": "00-20-C7",
        "organization": "AKAI Professional M.I. Corp.",
        "address_1": "1-3, Hiranuma 1-Chome,",
        "address_2": "  220-0023",
        "country": "JP"
    },
    "00A004": {
        "oui_hex": "00-A0-04",
        "organization": "NETPOWER, INC.",
        "address_1": "545 OAKMEAD PARKWAY",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "002029": {
        "oui_hex": "00-20-29",
        "organization": "TELEPROCESSING PRODUCTS, INC.",
        "address_1": "4565 E. INDUSTRIAL STREET",
        "address_2": "SIMI VALLEY  CA  93063",
        "country": "US"
    },
    "002069": {
        "oui_hex": "00-20-69",
        "organization": "ISDN SYSTEMS CORPORATION",
        "address_1": "8320 OLD COURTHOUSE RD.",
        "address_2": "VIENNA  VA  22182",
        "country": "US"
    },
    "00208B": {
        "oui_hex": "00-20-8B",
        "organization": "LAPIS TECHNOLOGIES, INC.",
        "address_1": "1100 MARINA VILLAGE PKWY",
        "address_2": "ALAMEDA  CA  94501",
        "country": "US"
    },
    "00202B": {
        "oui_hex": "00-20-2B",
        "organization": "ADVANCED TELECOMMUNICATIONS MODULES, LTD.",
        "address_1": "",
        "address_2": "Cambridge CB3 OBL",
        "country": "GB"
    },
    "00206B": {
        "oui_hex": "00-20-6B",
        "organization": "KONICA MINOLTA HOLDINGS, INC.",
        "address_1": "1-6-1, Marunouchi,",
        "address_2": "Tokyo    100-0005",
        "country": "JP"
    },
    "002004": {
        "oui_hex": "00-20-04",
        "organization": "YAMATAKE-HONEYWELL CO., LTD.",
        "address_1": "54 SUZUKAWA, ISEHARA",
        "address_2": "KANAGAWA 259-11",
        "country": "JP"
    },
    "002015": {
        "oui_hex": "00-20-15",
        "organization": "ACTIS COMPUTER SA",
        "address_1": "16 CHEMIN DES AULX",
        "address_2": "",
        "country": "CH"
    },
    "002099": {
        "oui_hex": "00-20-99",
        "organization": "BON ELECTRIC CO., LTD.",
        "address_1": "4-4 28, MIZUDO-CHO",
        "address_2": "HYOGO  HYOGO",
        "country": "JP"
    },
    "0020F9": {
        "oui_hex": "00-20-F9",
        "organization": "PARALINK NETWORKS, INC.",
        "address_1": "4F, NO. 27, SEC.3, PATEH RD.",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "002092": {
        "oui_hex": "00-20-92",
        "organization": "CHESS ENGINEERING B.V.",
        "address_1": "NIEUWE GRACHT 74",
        "address_2": "",
        "country": "NL"
    },
    "002043": {
        "oui_hex": "00-20-43",
        "organization": "NEURON COMPANY LIMITED",
        "address_1": "15 KWAI YI ROAD,  BLOCK 2,",
        "address_2": "KWAI CHUNG,   N.T.",
        "country": "HK"
    },
    "002071": {
        "oui_hex": "00-20-71",
        "organization": "IBR GMBH",
        "address_1": "KOHLERSTR. 45",
        "address_2": "D-46286 DORSTEN",
        "country": "DE"
    },
    "00207C": {
        "oui_hex": "00-20-7C",
        "organization": "AUTEC GMBH",
        "address_1": "BAHNHOFSTR. 57",
        "address_2": "55234 FRAMERSHEIM",
        "country": "DE"
    },
    "002057": {
        "oui_hex": "00-20-57",
        "organization": "TITZE DATENTECHNIK GmbH",
        "address_1": "DIESELSTRASSE 10",
        "address_2": "DS-71272 RENNINGEN-2",
        "country": "DE"
    },
    "0020E5": {
        "oui_hex": "00-20-E5",
        "organization": "APEX DATA, INC.",
        "address_1": "6624 OWENS DRIVE",
        "address_2": "PLEASANTON  CA  94588",
        "country": "US"
    },
    "002087": {
        "oui_hex": "00-20-87",
        "organization": "MEMOTEC, INC.",
        "address_1": "7755 Henri-Bourassa",
        "address_2": "MONTREAL, QUEBEC     H4S 1P7",
        "country": "CA"
    },
    "0020BC": {
        "oui_hex": "00-20-BC",
        "organization": "Long Reach Networks Pty Ltd",
        "address_1": "Unit 3, 118-122 Bowden St",
        "address_2": "MEADOWBANK NSW 2114",
        "country": "AU"
    },
    "00C0C0": {
        "oui_hex": "00-C0-C0",
        "organization": "SHORE MICROSYSTEMS, INC.",
        "address_1": "23 POCAHONTAS AVENUE",
        "address_2": "OCEANPORT  NJ  07757",
        "country": "US"
    },
    "00C00C": {
        "oui_hex": "00-C0-0C",
        "organization": "RELIA TECHNOLGIES",
        "address_1": "1F., NO. 24, INDUSTRY E. 9TH",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00C073": {
        "oui_hex": "00-C0-73",
        "organization": "XEDIA CORPORATION",
        "address_1": "301 BALLARDVALE STREET",
        "address_2": "WILMINGTON  MA  01887",
        "country": "US"
    },
    "00C0D4": {
        "oui_hex": "00-C0-D4",
        "organization": "AXON NETWORKS, INC.",
        "address_1": "104 SPRUCE STREET",
        "address_2": "WATERTOWN  MA  02172",
        "country": "US"
    },
    "00C0CD": {
        "oui_hex": "00-C0-CD",
        "organization": "COMELTA, S.A.",
        "address_1": "AVDA. PARC TECNOLOGIC, 4",
        "address_2": "",
        "country": "ES"
    },
    "0020ED": {
        "oui_hex": "00-20-ED",
        "organization": "GIGA-BYTE TECHNOLOGY CO., LTD.",
        "address_1": "365 CLOVERLEAF",
        "address_2": "BALDWIN PARK  CA  91706",
        "country": "US"
    },
    "002085": {
        "oui_hex": "00-20-85",
        "organization": "Eaton Corporation",
        "address_1": "8380 Capital Blvd.",
        "address_2": "RALEIGH  NC  27616",
        "country": "US"
    },
    "0020CD": {
        "oui_hex": "00-20-CD",
        "organization": "HYBRID NETWORKS, INC.",
        "address_1": "10201 BUBB ROAD",
        "address_2": "CUPERTINO  CA  95014-4167",
        "country": "US"
    },
    "00202E": {
        "oui_hex": "00-20-2E",
        "organization": "DAYSTAR DIGITAL",
        "address_1": "5556 ATLANTA HIGHWAY",
        "address_2": "FLOWERY BRANCH  GA  30542",
        "country": "US"
    },
    "0020B3": {
        "oui_hex": "00-20-B3",
        "organization": "Tattile SRL",
        "address_1": "3 APOLLO PLACE",
        "address_2": "",
        "country": "AU"
    },
    "0020EE": {
        "oui_hex": "00-20-EE",
        "organization": "GTECH CORPORATION",
        "address_1": "55 TECHNOLOGY WAY",
        "address_2": "WEST GREENWICH  RI  02817",
        "country": "US"
    },
    "00204C": {
        "oui_hex": "00-20-4C",
        "organization": "MITRON COMPUTER PTE LTD.",
        "address_1": "1020 HOUGANG AVENUE 1 #03-3504",
        "address_2": "  SINGAPORE  1953",
        "country": "SG"
    },
    "002017": {
        "oui_hex": "00-20-17",
        "organization": "ORBOTECH",
        "address_1": "INDUSTRIAL ZONE",
        "address_2": "",
        "country": "IL"
    },
    "002093": {
        "oui_hex": "00-20-93",
        "organization": "LANDINGS TECHNOLOGY CORP.",
        "address_1": "163 WATER STREET",
        "address_2": "EXETER  NH  03833",
        "country": "US"
    },
    "002063": {
        "oui_hex": "00-20-63",
        "organization": "WIPRO INFOTECH LTD.",
        "address_1": "UNITS 47-48, SDF BLOCK VII",
        "address_2": "",
        "country": ""
    },
    "002016": {
        "oui_hex": "00-20-16",
        "organization": "SHOWA ELECTRIC WIRE & CABLE CO",
        "address_1": "NO. 20-25, SEISHIN 8-CHOME",
        "address_2": "  229",
        "country": "JP"
    },
    "00204D": {
        "oui_hex": "00-20-4D",
        "organization": "INOVIS GMBH",
        "address_1": "HANNS-BRAUN STRASSE 50",
        "address_2": "",
        "country": "DE"
    },
    "00205F": {
        "oui_hex": "00-20-5F",
        "organization": "GAMMADATA COMPUTER GMBH",
        "address_1": "GUTENBERGSTR. 13",
        "address_2": "",
        "country": "DE"
    },
    "00201F": {
        "oui_hex": "00-20-1F",
        "organization": "BEST POWER TECHNOLOGY, INC.",
        "address_1": "P.O. BOX 280",
        "address_2": "NECEDAH  WI  54646",
        "country": "US"
    },
    "0020B6": {
        "oui_hex": "00-20-B6",
        "organization": "AGILE NETWORKS, INC.",
        "address_1": "200 BAKER AVENUE",
        "address_2": "CONCORD  MA  01742",
        "country": "US"
    },
    "0020D1": {
        "oui_hex": "00-20-D1",
        "organization": "MICROCOMPUTER SYSTEMS (M) SDN.",
        "address_1": "23-25, JALAN JEJAKA TUJUH",
        "address_2": "",
        "country": "MY"
    },
    "0020CE": {
        "oui_hex": "00-20-CE",
        "organization": "LOGICAL DESIGN GROUP, INC.",
        "address_1": "6301 CHAPEL HILL ROAD",
        "address_2": "RALEIGH  NC  27607",
        "country": "US"
    },
    "002014": {
        "oui_hex": "00-20-14",
        "organization": "GLOBAL VIEW CO., LTD.",
        "address_1": "4F, NO. 23, LANE 306",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0020C2": {
        "oui_hex": "00-20-C2",
        "organization": "TEXAS MEMORY SYSTEMS, INC.",
        "address_1": "11200 WESTHEIMER RD-STE#1000",
        "address_2": "HOUSTON  TX  77042",
        "country": "US"
    },
    "00C0F3": {
        "oui_hex": "00-C0-F3",
        "organization": "NETWORK COMMUNICATIONS CORP.",
        "address_1": "5501 GREEN VALLEY DRIVE",
        "address_2": "BLOOMINGTON  MN  55437-1085",
        "country": "US"
    },
    "002056": {
        "oui_hex": "00-20-56",
        "organization": "NEOPRODUCTS",
        "address_1": "25 CHAPMAN STREET",
        "address_2": "",
        "country": "AU"
    },
    "002042": {
        "oui_hex": "00-20-42",
        "organization": "DATAMETRICS CORP.",
        "address_1": "8966 COMANCHE AVE.",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "002078": {
        "oui_hex": "00-20-78",
        "organization": "RUNTOP, INC.",
        "address_1": "5/F, NO. 10, ALLEY 8, LANE 45",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "002006": {
        "oui_hex": "00-20-06",
        "organization": "GARRETT COMMUNICATIONS, INC.",
        "address_1": "48531 WARMSPRINGS BLVD.",
        "address_2": "FREMONT  CA  94539",
        "country": "US"
    },
    "002024": {
        "oui_hex": "00-20-24",
        "organization": "PACIFIC COMMUNICATION SCIENCES",
        "address_1": "9645 SCRANTON ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00205D": {
        "oui_hex": "00-20-5D",
        "organization": "NANOMATIC OY",
        "address_1": "PUISTOLAN RAITTI 4",
        "address_2": "",
        "country": "FI"
    },
    "00C005": {
        "oui_hex": "00-C0-05",
        "organization": "LIVINGSTON ENTERPRISES, INC.",
        "address_1": "6920 KOLL CENTER PARKWAY #220",
        "address_2": "PLEASANTON  CA  94566",
        "country": "US"
    },
    "00C077": {
        "oui_hex": "00-C0-77",
        "organization": "DAEWOO TELECOM LTD.",
        "address_1": "PRODUCTS DESIGN DEPT. 1",
        "address_2": "SEOUL  SEOUL  KOREA",
        "country": "KR"
    },
    "00C0C8": {
        "oui_hex": "00-C0-C8",
        "organization": "MICRO BYTE PTY. LTD.",
        "address_1": "197 SHERBOURNE RD.",
        "address_2": "  AUSTRALIA  3094",
        "country": "AU"
    },
    "00C069": {
        "oui_hex": "00-C0-69",
        "organization": "Axxcelera Broadband Wireless",
        "address_1": "111 Castilian Drive",
        "address_2": "Santa Barbara  CA  93117",
        "country": "US"
    },
    "00C067": {
        "oui_hex": "00-C0-67",
        "organization": "UNITED BARCODE INDUSTRIES",
        "address_1": "12240 INDIAN CREEK COURT",
        "address_2": "BELTSVILLE  MD  20705",
        "country": "US"
    },
    "00C0A3": {
        "oui_hex": "00-C0-A3",
        "organization": "DUAL ENTERPRISES CORPORATION",
        "address_1": "9TH FLOOR 48 NAN-KANG ROAD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00C018": {
        "oui_hex": "00-C0-18",
        "organization": "LANART CORPORATION",
        "address_1": "145 ROSEMARY STREET",
        "address_2": "NEEDHAM  MA  02194",
        "country": "US"
    },
    "009D8E": {
        "oui_hex": "00-9D-8E",
        "organization": "CARDIAC RECORDERS, INC.",
        "address_1": "34 SCARBORO ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00BB01": {
        "oui_hex": "00-BB-01",
        "organization": "OCTOTHORPE CORP.",
        "address_1": "285 WEST GREEN STREET",
        "address_2": "PASADENA  CA  91105",
        "country": "US"
    },
    "00C033": {
        "oui_hex": "00-C0-33",
        "organization": "TELEBIT COMMUNICATIONS APS",
        "address_1": "SKANDERBORGVEJ 234",
        "address_2": "",
        "country": "DK"
    },
    "00C090": {
        "oui_hex": "00-C0-90",
        "organization": "PRAIM S.R.L.",
        "address_1": "VIA MACCANI, 169",
        "address_2": "    ITALY",
        "country": ""
    },
    "00C0DE": {
        "oui_hex": "00-C0-DE",
        "organization": "ZCOMM, INC.",
        "address_1": "1050 C EAST DUANE AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00C013": {
        "oui_hex": "00-C0-13",
        "organization": "NETRIX",
        "address_1": "13595 DULLES TECHNOLOGY DRIVE",
        "address_2": "HERNDON  VA  22071",
        "country": "US"
    },
    "00C06B": {
        "oui_hex": "00-C0-6B",
        "organization": "OSI PLUS CORPORATION",
        "address_1": "2-1-23 NAKAMEGURO",
        "address_2": "",
        "country": "JP"
    },
    "00C04C": {
        "oui_hex": "00-C0-4C",
        "organization": "DEPARTMENT OF FOREIGN AFFAIRS",
        "address_1": "& TRADE",
        "address_2": "",
        "country": "AU"
    },
    "00C07C": {
        "oui_hex": "00-C0-7C",
        "organization": "HIGHTECH INFORMATION",
        "address_1": "SYSTEM LTD.",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "00C0B8": {
        "oui_hex": "00-C0-B8",
        "organization": "FRASER'S HILL LTD.",
        "address_1": "27502 W. GILL ROAD",
        "address_2": "MORRISTOWN  AZ  85342",
        "country": "US"
    },
    "00C062": {
        "oui_hex": "00-C0-62",
        "organization": "IMPULSE TECHNOLOGY",
        "address_1": "210 DAHLONEGA ST.#204",
        "address_2": "CUMMING  GA  30130",
        "country": "US"
    },
    "00C0EC": {
        "oui_hex": "00-C0-EC",
        "organization": "DAUPHIN TECHNOLOGY",
        "address_1": "450 EISENHOWER LANE NORTH",
        "address_2": "LOMBARD  IL  60148",
        "country": "US"
    },
    "00C086": {
        "oui_hex": "00-C0-86",
        "organization": "THE LYNK CORPORATION",
        "address_1": "101 QUEENS DRIVE",
        "address_2": "KING OF PRUSSIA  PA  19406",
        "country": "US"
    },
    "00C058": {
        "oui_hex": "00-C0-58",
        "organization": "DATAEXPERT CORP.",
        "address_1": "1156 SONOPRA COURTN-KANG RD.",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00C0D0": {
        "oui_hex": "00-C0-D0",
        "organization": "RATOC SYSTEM INC.",
        "address_1": "ASAHI NAMBA BLDG.",
        "address_2": "  556",
        "country": "JP"
    },
    "00C0BF": {
        "oui_hex": "00-C0-BF",
        "organization": "TECHNOLOGY CONCEPTS, LTD.",
        "address_1": "GRANGE ESTATE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00C0BA": {
        "oui_hex": "00-C0-BA",
        "organization": "NETVANTAGE",
        "address_1": "201 CONTINENTAL BLVD.-STE.#201",
        "address_2": "EL SECUNDO  CA  90245",
        "country": "US"
    },
    "00C05E": {
        "oui_hex": "00-C0-5E",
        "organization": "VARI-LITE, INC.",
        "address_1": "201 REGAL ROW",
        "address_2": "DALLAS  TX  75247",
        "country": "US"
    },
    "00C0D5": {
        "oui_hex": "00-C0-D5",
        "organization": "Werbeagentur Jürgen Siebert",
        "address_1": "Im Klostergarten 8",
        "address_2": "D-50321 Brühl",
        "country": "DE"
    },
    "00C063": {
        "oui_hex": "00-C0-63",
        "organization": "MORNING STAR TECHNOLOGIES, INC",
        "address_1": "1760 ZOLLINGER ROAD",
        "address_2": "COLUMBUS  OH  43221",
        "country": "US"
    },
    "00C021": {
        "oui_hex": "00-C0-21",
        "organization": "NETEXPRESS",
        "address_1": "989 EAST HILLSDALE BLVD.",
        "address_2": "FOSTER CITY  CA  94404-2113",
        "country": "US"
    },
    "00C0DB": {
        "oui_hex": "00-C0-DB",
        "organization": "IPC CORPORATION (PTE) LTD.",
        "address_1": "122 EUNOS AVE., 7 #05-10",
        "address_2": "  SINGAPORE  1440",
        "country": "SG"
    },
    "00C09B": {
        "oui_hex": "00-C0-9B",
        "organization": "RELIANCE COMM/TEC, R-TEC",
        "address_1": "SYSTEMS INC.",
        "address_2": "BEDFORD  TX  76021",
        "country": "US"
    },
    "00C06A": {
        "oui_hex": "00-C0-6A",
        "organization": "ZAHNER-ELEKTRIK GMBH & CO. KG",
        "address_1": "P.O. BOX 1846",
        "address_2": "",
        "country": "DE"
    },
    "00C0E3": {
        "oui_hex": "00-C0-E3",
        "organization": "OSITECH COMMUNICATIONS, INC.",
        "address_1": "679 SOUTHGATE DRIVE",
        "address_2": "CANADA  N1G  4S2",
        "country": "CA"
    },
    "00C0FE": {
        "oui_hex": "00-C0-FE",
        "organization": "APTEC COMPUTER SYSTEMS, INC.",
        "address_1": "P.O. BOX 6750",
        "address_2": "PORTLAND  OR  97228-6750",
        "country": "US"
    },
    "00C016": {
        "oui_hex": "00-C0-16",
        "organization": "ELECTRONIC THEATRE CONTROLS",
        "address_1": "3030 LAURA LANE",
        "address_2": "MIDDLETON  WI  53562",
        "country": "US"
    },
    "00C0BC": {
        "oui_hex": "00-C0-BC",
        "organization": "TELECOM AUSTRALIA/CSSC",
        "address_1": "LOCKED BAG 8812",
        "address_2": "",
        "country": "AU"
    },
    "00C0C1": {
        "oui_hex": "00-C0-C1",
        "organization": "QUAD/GRAPHICS, INC.",
        "address_1": "N63 W23075 HWY 74",
        "address_2": "SUSSEX  WI  53089",
        "country": "US"
    },
    "00C089": {
        "oui_hex": "00-C0-89",
        "organization": "TELINDUS DISTRIBUTION",
        "address_1": "GELDENAAKSEBAAN 335",
        "address_2": "",
        "country": "BE"
    },
    "00C0B0": {
        "oui_hex": "00-C0-B0",
        "organization": "GCC TECHNOLOGIES,INC.",
        "address_1": "580 WINTER STREET",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "00C00A": {
        "oui_hex": "00-C0-0A",
        "organization": "MICRO CRAFT",
        "address_1": "2-4-3 NISHIFURUMATSU",
        "address_2": "",
        "country": "JP"
    },
    "00C074": {
        "oui_hex": "00-C0-74",
        "organization": "TOYODA AUTOMATIC LOOM",
        "address_1": "WORKS, LTD.",
        "address_2": "  448",
        "country": "JP"
    },
    "00404E": {
        "oui_hex": "00-40-4E",
        "organization": "FLUENT, INC.",
        "address_1": "594 WORCESTER ROAD-STE.#308",
        "address_2": "NATICK  MA  01760",
        "country": "US"
    },
    "00408D": {
        "oui_hex": "00-40-8D",
        "organization": "THE GOODYEAR TIRE & RUBBER CO.",
        "address_1": "1144 EAST MARKET STREET",
        "address_2": "AKRON  OH  44316",
        "country": "US"
    },
    "00401B": {
        "oui_hex": "00-40-1B",
        "organization": "PRINTER SYSTEMS CORP.",
        "address_1": "207 PERRY PARKWAY",
        "address_2": "GAITHERSBURG  MD  20877-2142",
        "country": "US"
    },
    "0040A3": {
        "oui_hex": "00-40-A3",
        "organization": "MICROUNITY SYSTEMS ENGINEERING",
        "address_1": "255 CASPIAN DRIVE",
        "address_2": "SUNNYVALE  CA  94089-1015",
        "country": "US"
    },
    "0040B3": {
        "oui_hex": "00-40-B3",
        "organization": "ParTech Inc.",
        "address_1": "8383 Seneca Turnpike",
        "address_2": "NEW HARTFORD  NY  13413",
        "country": "US"
    },
    "00401D": {
        "oui_hex": "00-40-1D",
        "organization": "INVISIBLE SOFTWARE, INC.",
        "address_1": "1142 CHESS DRIVE",
        "address_2": "FOSTER CITY  CA  94404",
        "country": "US"
    },
    "00C0CA": {
        "oui_hex": "00-C0-CA",
        "organization": "ALFA, INC.",
        "address_1": "11-1, INDUSTRY EAST ROAD IV",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "00C06C": {
        "oui_hex": "00-C0-6C",
        "organization": "SVEC COMPUTER CORP.",
        "address_1": "3F, 531-1 CHUNG CHENG RD.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0040FF": {
        "oui_hex": "00-40-FF",
        "organization": "TELEBIT CORPORATION",
        "address_1": "1315 CHESAPEAKE TERRACE",
        "address_2": "SUNNYVALE  CA  94089-1100",
        "country": "US"
    },
    "00401F": {
        "oui_hex": "00-40-1F",
        "organization": "COLORGRAPH LTD",
        "address_1": "UNIT 2, MARS HOUSE",
        "address_2": "RG7 4QW -  UNITED  KINGDOM",
        "country": "GB"
    },
    "0040AF": {
        "oui_hex": "00-40-AF",
        "organization": "DIGITAL PRODUCTS, INC.",
        "address_1": "411 WAVERLY OAKS ROAD",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "0040F7": {
        "oui_hex": "00-40-F7",
        "organization": "Polaroid Corporation",
        "address_1": "300 Baker Avenue",
        "address_2": "Concord  MA  01742",
        "country": "US"
    },
    "004037": {
        "oui_hex": "00-40-37",
        "organization": "SEA-ILAN, INC.",
        "address_1": "14602 NORTH US HIGHWAY #31",
        "address_2": "CARMEL  IN  46032",
        "country": "US"
    },
    "00C026": {
        "oui_hex": "00-C0-26",
        "organization": "LANS TECHNOLOGY CO., LTD.",
        "address_1": "153 MINTSU RD. 2F, TAOYUAN,",
        "address_2": "TAIWAN  R.  O. C.",
        "country": "TW"
    },
    "00407E": {
        "oui_hex": "00-40-7E",
        "organization": "EVERGREEN SYSTEMS, INC.",
        "address_1": "120 LANDING COURT-SUITE",
        "address_2": "NOVATO  CA  94945",
        "country": "US"
    },
    "0040F9": {
        "oui_hex": "00-40-F9",
        "organization": "COMBINET",
        "address_1": "333 W. EL CAMINO REAL-STE#310",
        "address_2": "SUNNYVALE  CA  94087",
        "country": "US"
    },
    "00C06F": {
        "oui_hex": "00-C0-6F",
        "organization": "KOMATSU LTD.",
        "address_1": "2597 SHINOMIYA HIRATSUKA-SHI",
        "address_2": "",
        "country": "JP"
    },
    "00C0A7": {
        "oui_hex": "00-C0-A7",
        "organization": "SEEL LTD.",
        "address_1": "3 YOUNG SQUARE",
        "address_2": "    SCOTLAND",
        "country": "GB"
    },
    "00C04A": {
        "oui_hex": "00-C0-4A",
        "organization": "GROUP 2000 AG",
        "address_1": "P.O. BOX 331",
        "address_2": "",
        "country": "CH"
    },
    "004054": {
        "oui_hex": "00-40-54",
        "organization": "CONNECTION MACHINES SERVICES",
        "address_1": "12 HENSHAW STREET",
        "address_2": "WOBURN  MA  01801-466664",
        "country": "US"
    },
    "004004": {
        "oui_hex": "00-40-04",
        "organization": "ICM CO. LTD.",
        "address_1": "4-2-9 NIHONBASHI NANIWA-KU",
        "address_2": "",
        "country": "JP"
    },
    "004058": {
        "oui_hex": "00-40-58",
        "organization": "KRONOS, INC.",
        "address_1": "400 FIFTH AVENUE",
        "address_2": "WALTHAM  MA  02154",
        "country": "US"
    },
    "004018": {
        "oui_hex": "00-40-18",
        "organization": "ADOBE SYSTEMS, INC.",
        "address_1": "1585 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00404A": {
        "oui_hex": "00-40-4A",
        "organization": "WEST AUSTRALIAN DEPARTMENT",
        "address_1": "OF EMPLOYMENT (DEVET)",
        "address_2": "  WESTERN",
        "country": "AU"
    },
    "00403C": {
        "oui_hex": "00-40-3C",
        "organization": "FORKS, INC.",
        "address_1": "1-27-4 IRIYA,",
        "address_2": "  110",
        "country": "JP"
    },
    "004042": {
        "oui_hex": "00-40-42",
        "organization": "N.A.T. GMBH",
        "address_1": "GOETHESTR. 2",
        "address_2": "",
        "country": "DE"
    },
    "0040F2": {
        "oui_hex": "00-40-F2",
        "organization": "JANICH & KLASS COMPUTERTECHNIK",
        "address_1": "ZUM ALTEN ZOLLHAUS 20",
        "address_2": "",
        "country": "DE"
    },
    "0040A2": {
        "oui_hex": "00-40-A2",
        "organization": "KINGSTAR TECHNOLOGY INC.",
        "address_1": "1-3F, NO. 185, SEC. 3,",
        "address_2": "TAIPEI  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "0040DC": {
        "oui_hex": "00-40-DC",
        "organization": "TRITEC ELECTRONIC GMBH",
        "address_1": "ROBERT KOCH STR. 35",
        "address_2": "",
        "country": "DE"
    },
    "004060": {
        "oui_hex": "00-40-60",
        "organization": "COMENDEC LTD",
        "address_1": "ENTERPRISE WAY,",
        "address_2": "BIRMINGHAM  BIRMINGHAM  ENGLAND",
        "country": "GB"
    },
    "004056": {
        "oui_hex": "00-40-56",
        "organization": "MCM JAPAN LTD.",
        "address_1": "SYUUKAEN BLD. 2-11-1",
        "address_2": "",
        "country": "JP"
    },
    "004030": {
        "oui_hex": "00-40-30",
        "organization": "GK COMPUTER",
        "address_1": "BASLER STRASSE 103",
        "address_2": "",
        "country": "DE"
    },
    "004040": {
        "oui_hex": "00-40-40",
        "organization": "RING ACCESS, INC.",
        "address_1": "957-R INDUSTRIAL ROAD",
        "address_2": "SAN CARLOS  CA  94070",
        "country": "US"
    },
    "008057": {
        "oui_hex": "00-80-57",
        "organization": "ADSOFT, LTD.",
        "address_1": "Im Baumgarten 6",
        "address_2": "  MOHLIN  CH-4313",
        "country": "CH"
    },
    "0080BB": {
        "oui_hex": "00-80-BB",
        "organization": "HUGHES LAN SYSTEMS",
        "address_1": "1225 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00403D": {
        "oui_hex": "00-40-3D",
        "organization": "Teradata Corporation",
        "address_1": "17095 Via Del Campo",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "0040D0": {
        "oui_hex": "00-40-D0",
        "organization": "MITAC INTERNATIONAL CORP.",
        "address_1": "8TH FL. 585 MING SHENG E. RD.",
        "address_2": "",
        "country": "TW"
    },
    "0040AB": {
        "oui_hex": "00-40-AB",
        "organization": "ROLAND DG CORPORATION",
        "address_1": "1227 OKUBO-CHO, HAMAMATSU-SHI",
        "address_2": "  432",
        "country": "JP"
    },
    "0040B6": {
        "oui_hex": "00-40-B6",
        "organization": "COMPUTERM  CORPORATION",
        "address_1": "111 WOOD STREET",
        "address_2": "PITTSBURGH  PA  15222",
        "country": "US"
    },
    "0040A6": {
        "oui_hex": "00-40-A6",
        "organization": "Cray, Inc.",
        "address_1": "655F LONE OAK DRIVE",
        "address_2": "EAGAN  MN  55121",
        "country": "US"
    },
    "00403E": {
        "oui_hex": "00-40-3E",
        "organization": "RASTER OPS CORPORATION",
        "address_1": "2500 WALSH AVENUE",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "004046": {
        "oui_hex": "00-40-46",
        "organization": "UDC RESEARCH LIMITED",
        "address_1": "8A KING WAN INDUSTRIAL BLDG.",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "00C0D7": {
        "oui_hex": "00-C0-D7",
        "organization": "TAIWAN TRADING CENTER DBA",
        "address_1": "TTC COMPUTER PRODUCTS",
        "address_2": "IRVING  TX  75038",
        "country": "US"
    },
    "0040DA": {
        "oui_hex": "00-40-DA",
        "organization": "TELSPEC LTD",
        "address_1": "LANCASTER PARKER ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0040C7": {
        "oui_hex": "00-40-C7",
        "organization": "RUBY TECH CORPORATION",
        "address_1": "6F-1, NO.3, LANE 250,",
        "address_2": "TAIPEI  TAIWAN,  R.O.C.",
        "country": "TW"
    },
    "004052": {
        "oui_hex": "00-40-52",
        "organization": "STAR TECHNOLOGIES, INC.",
        "address_1": "515 SHAW ROAD",
        "address_2": "STERLING  VA  22075",
        "country": "US"
    },
    "00402E": {
        "oui_hex": "00-40-2E",
        "organization": "PRECISION SOFTWARE, INC.",
        "address_1": "600 S FEDERAL HWY STE",
        "address_2": "DEERFIELD BEACH  FL  33441-4193",
        "country": "US"
    },
    "00402B": {
        "oui_hex": "00-40-2B",
        "organization": "TRIGEM COMPUTER, INC.",
        "address_1": "KISUNG B/D 4F, 784-6",
        "address_2": "SEOUL  KOREA  135-080",
        "country": "KR"
    },
    "00401A": {
        "oui_hex": "00-40-1A",
        "organization": "FUJI ELECTRIC CO., LTD.",
        "address_1": "NEW YURAKUCHO BLDG",
        "address_2": "",
        "country": "JP"
    },
    "00405F": {
        "oui_hex": "00-40-5F",
        "organization": "AFE COMPUTERS LTD.",
        "address_1": "62 ANCHORAGE ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "004080": {
        "oui_hex": "00-40-80",
        "organization": "ATHENIX CORPORATION",
        "address_1": "675 ALMANOR AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "004051": {
        "oui_hex": "00-40-51",
        "organization": "Garbee and Garbee",
        "address_1": "4390 Darr Circle",
        "address_2": "Colorado Springs  CO  80908",
        "country": "US"
    },
    "00407A": {
        "oui_hex": "00-40-7A",
        "organization": "SOCIETE D'EXPLOITATION DU CNIT",
        "address_1": "2 GLACE DE LA DEFENSE 92053",
        "address_2": "",
        "country": "FR"
    },
    "004031": {
        "oui_hex": "00-40-31",
        "organization": "KOKUSAI ELECTRIC CO., LTD",
        "address_1": "2-1 YASUUCHI",
        "address_2": "TOYAMA  939-23",
        "country": "JP"
    },
    "0040D3": {
        "oui_hex": "00-40-D3",
        "organization": "KIMPSION INTERNATIONAL CORP.",
        "address_1": "4701 PATRICK HENRY DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0040EE": {
        "oui_hex": "00-40-EE",
        "organization": "OPTIMEM",
        "address_1": "297 N. BERNARDO AVENUE",
        "address_2": "MOUNTAIN VIEW  CA  94043-5205",
        "country": "US"
    },
    "004025": {
        "oui_hex": "00-40-25",
        "organization": "MOLECULAR DYNAMICS",
        "address_1": "880 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086-4536",
        "country": "US"
    },
    "004067": {
        "oui_hex": "00-40-67",
        "organization": "OMNIBYTE CORPORATION",
        "address_1": "245 WEST ROOSEVELT ROAD",
        "address_2": "WEST CHICAGO  IL  60185",
        "country": "US"
    },
    "0040C3": {
        "oui_hex": "00-40-C3",
        "organization": "FISCHER AND PORTER CO.",
        "address_1": "125 E. COUNTY LINE ROAD",
        "address_2": "WARMINSTER  PA  18974",
        "country": "US"
    },
    "0040EC": {
        "oui_hex": "00-40-EC",
        "organization": "MIKASA SYSTEM ENGINEERING",
        "address_1": "CO., LTD.",
        "address_2": "",
        "country": "JP"
    },
    "00802F": {
        "oui_hex": "00-80-2F",
        "organization": "NATIONAL INSTRUMENTS CORP.",
        "address_1": "11500 North Mopac Expressway",
        "address_2": "AUSTIN  TX  78759-3504",
        "country": "US"
    },
    "008054": {
        "oui_hex": "00-80-54",
        "organization": "FRONTIER TECHNOLOGIES CORP.",
        "address_1": "10201 NO. PT. WASHINGTON ROAD",
        "address_2": "MEQUON  WI  53092",
        "country": "US"
    },
    "008053": {
        "oui_hex": "00-80-53",
        "organization": "INTELLICOM, INC.",
        "address_1": "20415 NORDHOFF STREET",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "008026": {
        "oui_hex": "00-80-26",
        "organization": "NETWORK PRODUCTS CORPORATION",
        "address_1": "1440 WEST COLORADO BLVD.",
        "address_2": "PASADENA  CA  91105",
        "country": "US"
    },
    "0080B0": {
        "oui_hex": "00-80-B0",
        "organization": "ADVANCED INFORMATION",
        "address_1": "TECHNOLOGY, INC.",
        "address_2": "",
        "country": "JP"
    },
    "0080FA": {
        "oui_hex": "00-80-FA",
        "organization": "RWT GMBH",
        "address_1": "TALANGERSTR. 5-7",
        "address_2": "  WEST",
        "country": "DE"
    },
    "0080FD": {
        "oui_hex": "00-80-FD",
        "organization": "EXSCEED CORPRATION",
        "address_1": "1-15-12, KITAKASE, SAIWAI-KU",
        "address_2": "",
        "country": "JP"
    },
    "0080FE": {
        "oui_hex": "00-80-FE",
        "organization": "AZURE TECHNOLOGIES, INC.",
        "address_1": "63 SOUTH STREET",
        "address_2": "HOPKINTON  MA  01748-2212",
        "country": "US"
    },
    "00803C": {
        "oui_hex": "00-80-3C",
        "organization": "TVS ELECTRONICS LTD",
        "address_1": "44, MILLER ROAD",
        "address_2": "",
        "country": "IN"
    },
    "008046": {
        "oui_hex": "00-80-46",
        "organization": "Tattile SRL",
        "address_1": "DEPT. OF ELECTRICAL ENGIN'ING",
        "address_2": "",
        "country": "CA"
    },
    "004002": {
        "oui_hex": "00-40-02",
        "organization": "PERLE SYSTEMS LIMITED",
        "address_1": "60 RENFREW DRIVE",
        "address_2": "CANADA  L3R  0E1",
        "country": "CA"
    },
    "004049": {
        "oui_hex": "00-40-49",
        "organization": "Roche Diagnostics International Ltd.",
        "address_1": "FORRENSTRASSE",
        "address_2": "ROTKREUZ  ZG  6343",
        "country": "CH"
    },
    "004029": {
        "oui_hex": "00-40-29",
        "organization": "Compex",
        "address_1": "",
        "address_2": "",
        "country": "US"
    },
    "00409E": {
        "oui_hex": "00-40-9E",
        "organization": "CONCURRENT TECHNOLOGIES  LTD.",
        "address_1": "654 THE CRESCENT",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0080AD": {
        "oui_hex": "00-80-AD",
        "organization": "CNET TECHNOLOGY, INC.",
        "address_1": "2199 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00800E": {
        "oui_hex": "00-80-0E",
        "organization": "ATLANTIX CORPORATION",
        "address_1": "5401 NW BROKENSOUND BLVD.",
        "address_2": "BOCA RATON  FL  33431",
        "country": "US"
    },
    "0080AB": {
        "oui_hex": "00-80-AB",
        "organization": "DUKANE NETWORK INTEGRATION",
        "address_1": "2900 DUKANE DRIVE",
        "address_2": "ST. CHARLES  IL  60174",
        "country": "US"
    },
    "0080F1": {
        "oui_hex": "00-80-F1",
        "organization": "OPUS SYSTEMS",
        "address_1": "3000 CORONADO DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "008029": {
        "oui_hex": "00-80-29",
        "organization": "EAGLE TECHNOLOGY, INC.",
        "address_1": "6800 ORANGETHORPE AVE.UNIT",
        "address_2": "BUENA PARK  CA  90620",
        "country": "US"
    },
    "008072": {
        "oui_hex": "00-80-72",
        "organization": "MICROPLEX SYSTEMS LTD.",
        "address_1": "301-2071 Kingsway",
        "address_2": "Port Coquitlam  BC  V3C6N2",
        "country": "CA"
    },
    "004001": {
        "oui_hex": "00-40-01",
        "organization": "Zero One Technology Co. Ltd.",
        "address_1": "10 Fl., No. 8, Lane 360, Sec 1,",
        "address_2": "Neihu Dist.,  Taipei City  114",
        "country": "TW"
    },
    "004071": {
        "oui_hex": "00-40-71",
        "organization": "ATM COMPUTER GMBH",
        "address_1": "BUCKLESTR. 1-5,POSTFACH 101043",
        "address_2": "",
        "country": "DE"
    },
    "008011": {
        "oui_hex": "00-80-11",
        "organization": "DIGITAL SYSTEMS INT'L. INC.",
        "address_1": "7659 178TH PL. NE",
        "address_2": "REDMOND  WA  98073-0908",
        "country": "US"
    },
    "008034": {
        "oui_hex": "00-80-34",
        "organization": "SMT GOUPIL",
        "address_1": "3 RUE DES ARCHIVES",
        "address_2": "",
        "country": "FR"
    },
    "0080E4": {
        "oui_hex": "00-80-E4",
        "organization": "NORTHWEST DIGITAL SYSTEMS, INC",
        "address_1": "P.O. BOX 15288",
        "address_2": "SEATTLE  WA  98115",
        "country": "US"
    },
    "0080EC": {
        "oui_hex": "00-80-EC",
        "organization": "SUPERCOMPUTING SOLUTIONS, INC.",
        "address_1": "6175 NANCY RIDGE BLVD.",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00802C": {
        "oui_hex": "00-80-2C",
        "organization": "THE SAGE GROUP PLC",
        "address_1": "SAGE HOUSE, BENTON PARK ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0080D6": {
        "oui_hex": "00-80-D6",
        "organization": "NUVOTECH, INC.",
        "address_1": "2015 BRIDGEWAY, SUITE 204",
        "address_2": "SAUSALITO  CA  94965",
        "country": "US"
    },
    "00800A": {
        "oui_hex": "00-80-0A",
        "organization": "JAPAN COMPUTER CORP.",
        "address_1": "L. K. BLDG. HIGASHI KANDA",
        "address_2": "",
        "country": "JP"
    },
    "00804B": {
        "oui_hex": "00-80-4B",
        "organization": "EAGLE TECHNOLOGIES PTY.LTD.",
        "address_1": "70 KEYS ROAD",
        "address_2": "",
        "country": "AU"
    },
    "0080C8": {
        "oui_hex": "00-80-C8",
        "organization": "D-LINK SYSTEMS, INC.",
        "address_1": "53 Discover Dr.",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "008012": {
        "oui_hex": "00-80-12",
        "organization": "INTEGRATED MEASUREMENT SYSTEMS",
        "address_1": "9525 SW GEMINI DRIVE",
        "address_2": "BEAVERTON  OR  97005",
        "country": "US"
    },
    "008027": {
        "oui_hex": "00-80-27",
        "organization": "ADAPTIVE SYSTEMS, INC.",
        "address_1": "1400 N.W. COMPTON DRIVE",
        "address_2": "BEAVERTON  OR  97006",
        "country": "US"
    },
    "0080FC": {
        "oui_hex": "00-80-FC",
        "organization": "AVATAR CORPORATION",
        "address_1": "65 SOUTH STREET",
        "address_2": "HOPKINTON  MA  01748",
        "country": "US"
    },
    "008016": {
        "oui_hex": "00-80-16",
        "organization": "WANDEL AND GOLTERMANN",
        "address_1": "1030 SWABIA COURT",
        "address_2": "  NC  27709",
        "country": "US"
    },
    "0080A2": {
        "oui_hex": "00-80-A2",
        "organization": "CREATIVE ELECTRONIC SYSTEMS",
        "address_1": "Avenue Eugène-Lance 38bis",
        "address_2": "",
        "country": "CH"
    },
    "0080CC": {
        "oui_hex": "00-80-CC",
        "organization": "MICROWAVE BYPASS SYSTEMS",
        "address_1": "25 BRAINTREE HILL OFFICE PARK",
        "address_2": "BRAINTREE  MA  02184",
        "country": "US"
    },
    "0080A5": {
        "oui_hex": "00-80-A5",
        "organization": "SPEED INTERNATIONAL",
        "address_1": "1320 ARBOLITA DR.",
        "address_2": "LA HABRA  CA  90631",
        "country": "US"
    },
    "008079": {
        "oui_hex": "00-80-79",
        "organization": "MICROBUS DESIGNS LTD.",
        "address_1": "TREADAWAY HILL",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "000079": {
        "oui_hex": "00-00-79",
        "organization": "NETWORTH INCORPORATED",
        "address_1": "8404 ESTERS BOULEVARD",
        "address_2": "IRVING  TX  75063",
        "country": "US"
    },
    "000091": {
        "oui_hex": "00-00-91",
        "organization": "ANRITSU CORPORATION",
        "address_1": "1800, ONNA",
        "address_2": "",
        "country": "JP"
    },
    "000075": {
        "oui_hex": "00-00-75",
        "organization": "Nortel Networks",
        "address_1": "Global Operations Engineering",
        "address_2": "Brampton  ON  l6T 5P6 Cana",
        "country": "CA"
    },
    "0000A5": {
        "oui_hex": "00-00-A5",
        "organization": "Tattile SRL",
        "address_1": "P.O. BOX 17220",
        "address_2": "BOULDER  CO  80308-7220",
        "country": "US"
    },
    "000036": {
        "oui_hex": "00-00-36",
        "organization": "ATARI CORPORATION",
        "address_1": "1196 BORREGAS AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0000F8": {
        "oui_hex": "00-00-F8",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "00805C": {
        "oui_hex": "00-80-5C",
        "organization": "AGILIS CORPORATION",
        "address_1": "1101 SAN ANTONIO ROAD",
        "address_2": "Mountain View  CA  94043-1008",
        "country": "US"
    },
    "0080C5": {
        "oui_hex": "00-80-C5",
        "organization": "NOVELLCO DE MEXICO",
        "address_1": "CONSTITUYENTES NO. 907",
        "address_2": "11950 MEXICO  11950 MEXICO  D.F.",
        "country": "MX"
    },
    "008078": {
        "oui_hex": "00-80-78",
        "organization": "PRACTICAL PERIPHERALS, INC.",
        "address_1": "375 CONEJO RIDGE AVENUE",
        "address_2": "THOUSAND OAKS  CA  91361",
        "country": "US"
    },
    "0080F6": {
        "oui_hex": "00-80-F6",
        "organization": "SYNERGY MICROSYSTEMS",
        "address_1": "9605 SCRANTON ROAD-STE #700",
        "address_2": "SAN DIEGO  CA  92121-1773",
        "country": "US"
    },
    "00807B": {
        "oui_hex": "00-80-7B",
        "organization": "ARTEL COMMUNICATIONS CORP.",
        "address_1": "22 KANE INDUSTRIAL DRIVE",
        "address_2": "HUDSON  MA  01749",
        "country": "US"
    },
    "008014": {
        "oui_hex": "00-80-14",
        "organization": "ESPRIT SYSTEMS",
        "address_1": "14F, NO. 1, SEC. 4",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0080B7": {
        "oui_hex": "00-80-B7",
        "organization": "STELLAR COMPUTER",
        "address_1": "95 WELLS AVENUE",
        "address_2": "NEWTON  MA  02159",
        "country": ""
    },
    "0000ED": {
        "oui_hex": "00-00-ED",
        "organization": "APRIL",
        "address_1": "60, RUE DE CARTALE",
        "address_2": "",
        "country": "FR"
    },
    "0000A3": {
        "oui_hex": "00-00-A3",
        "organization": "NETWORK APPLICATION TECHNOLOGY",
        "address_1": "1686 DELL AVENUE",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "000039": {
        "oui_hex": "00-00-39",
        "organization": "TOSHIBA CORPORATION",
        "address_1": "COMPUTER DIVISION",
        "address_2": "TOKYO  105",
        "country": "JP"
    },
    "00003C": {
        "oui_hex": "00-00-3C",
        "organization": "AUSPEX SYSTEMS INC.",
        "address_1": "5200 GREAT AMERICA PKWY",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00007E": {
        "oui_hex": "00-00-7E",
        "organization": "CLUSTRIX CORPORATION",
        "address_1": "960 HAMLIN COURT",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "0000CB": {
        "oui_hex": "00-00-CB",
        "organization": "COMPU-SHACK ELECTRONIC GMBH",
        "address_1": "RINGSTR. 56 - 58, 5450 NEUWIED",
        "address_2": "  WEST",
        "country": "DE"
    },
    "000013": {
        "oui_hex": "00-00-13",
        "organization": "CAMEX",
        "address_1": "75 KNEELAND STREET",
        "address_2": "BOSTON  MA  02111",
        "country": "US"
    },
    "000095": {
        "oui_hex": "00-00-95",
        "organization": "SONY TEKTRONIX CORP.",
        "address_1": "P.O. BOX 5209 TOKYO INT'L",
        "address_2": "",
        "country": "JP"
    },
    "000057": {
        "oui_hex": "00-00-57",
        "organization": "SCITEX CORPORATION LTD.",
        "address_1": "P.O. BOX 330",
        "address_2": "",
        "country": "IL"
    },
    "0000D6": {
        "oui_hex": "00-00-D6",
        "organization": "PUNCH LINE HOLDING",
        "address_1": "P.O. BOX 391708",
        "address_2": "  SOUTH  AFRICA",
        "country": "ZA"
    },
    "00009E": {
        "oui_hex": "00-00-9E",
        "organization": "MARLI S.A.",
        "address_1": "CHEMIN TAVERNEY 3",
        "address_2": "",
        "country": "CH"
    },
    "000042": {
        "oui_hex": "00-00-42",
        "organization": "METIER MANAGEMENT SYSTEMS LTD.",
        "address_1": "3 FOUNDATION STREET",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00007D": {
        "oui_hex": "00-00-7D",
        "organization": "Oracle Corporation",
        "address_1": "17 Network Circle",
        "address_2": "Menlo Park  CA  95025",
        "country": "US"
    },
    "000096": {
        "oui_hex": "00-00-96",
        "organization": "MARCONI ELECTRONICS LTD.",
        "address_1": "BROWNS LANE, THE AIRPORT",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00005E": {
        "oui_hex": "00-00-5E",
        "organization": "ICANN, IANA Department",
        "address_1": "INTERNET ASS'NED NOS.AUTHORITY",
        "address_2": "Los Angeles  CA  90094-2536",
        "country": "US"
    },
    "000038": {
        "oui_hex": "00-00-38",
        "organization": "CSS LABS",
        "address_1": "2134 SOUTH RIPCHEY",
        "address_2": "SANTA ANA  CA  92705",
        "country": "US"
    },
    "000044": {
        "oui_hex": "00-00-44",
        "organization": "CASTELLE CORPORATION",
        "address_1": "3255-3 SCOTT BOULEVARD",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0000CE": {
        "oui_hex": "00-00-CE",
        "organization": "MEGADATA CORP.",
        "address_1": "35 ORVILLE DRIVE",
        "address_2": "BOHEMIA  NY  11716",
        "country": "US"
    },
    "00007B": {
        "oui_hex": "00-00-7B",
        "organization": "RESEARCH MACHINES",
        "address_1": "P.O. BOX 75",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00000F": {
        "oui_hex": "00-00-0F",
        "organization": "NEXT, INC.",
        "address_1": "3475 DEER CREEK ROAD",
        "address_2": "PALO ALTO  CA  94304",
        "country": "US"
    },
    "0000BB": {
        "oui_hex": "00-00-BB",
        "organization": "TRI-DATA",
        "address_1": "505 EAST MIDDLEFIELD ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043-4082",
        "country": "US"
    },
    "00001A": {
        "oui_hex": "00-00-1A",
        "organization": "ADVANCED MICRO DEVICES",
        "address_1": "P.O. BOX 3453",
        "address_2": "SUNNYVALE  CA  94088",
        "country": "US"
    },
    "00007F": {
        "oui_hex": "00-00-7F",
        "organization": "LINOTYPE-HELL AG",
        "address_1": "POSTFACH 56 60",
        "address_2": "",
        "country": "DE"
    },
    "000060": {
        "oui_hex": "00-00-60",
        "organization": "KONTRON ELEKTRONIK GMBH",
        "address_1": "OSKAR-VON-MILLER-STR. 1",
        "address_2": "",
        "country": "DE"
    },
    "08006F": {
        "oui_hex": "08-00-6F",
        "organization": "PHILIPS APELDOORN B.V.",
        "address_1": "P.O. BOX 105",
        "address_2": "  THE",
        "country": "NL"
    },
    "000040": {
        "oui_hex": "00-00-40",
        "organization": "APPLICON, INC.",
        "address_1": "4251 PLYMOUTH RD 48015",
        "address_2": "ANN ARBOR  MI  48106-0986",
        "country": "US"
    },
    "00005D": {
        "oui_hex": "00-00-5D",
        "organization": "CS TELECOM",
        "address_1": "4-16 AVENUE DU GENERAL LECLERC",
        "address_2": "",
        "country": "FR"
    },
    "000012": {
        "oui_hex": "00-00-12",
        "organization": "INFORMATION TECHNOLOGY LIMITED",
        "address_1": "MAYLANDS AVE. HEMEL HEMPSTEAD",
        "address_2": "  HERTS  ENGLAND",
        "country": "GB"
    },
    "00008A": {
        "oui_hex": "00-00-8A",
        "organization": "DATAHOUSE INFORMATION SYSTEMS",
        "address_1": "DIRECTOR OF OPERATIONS",
        "address_2": "GU34  3QW  ENGLAND",
        "country": "GB"
    },
    "000032": {
        "oui_hex": "00-00-32",
        "organization": "Marconi plc",
        "address_1": "28 ELSTREE WAY, BOREHAMWOOD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "000085": {
        "oui_hex": "00-00-85",
        "organization": "CANON INC.",
        "address_1": "DVTECH. DEV. CENTER DEPT.12",
        "address_2": "",
        "country": "JP"
    },
    "00004A": {
        "oui_hex": "00-00-4A",
        "organization": "ADC CODENOLL TECHNOLOGY CORP.",
        "address_1": "200 CORPORATE BLVD. SO.",
        "address_2": "YONKERS  NY  10701",
        "country": "US"
    },
    "08008F": {
        "oui_hex": "08-00-8F",
        "organization": "CHIPCOM CORPORATION",
        "address_1": "SOUTHBOROUGH OFFICE",
        "address_2": "SOUTHBOROUGH  MA  01772-1886",
        "country": "US"
    },
    "00006A": {
        "oui_hex": "00-00-6A",
        "organization": "COMPUTER CONSOLES INC.",
        "address_1": "COMPUTER PRODUCTS DIVISION",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "08003E": {
        "oui_hex": "08-00-3E",
        "organization": "CODEX CORPORATION",
        "address_1": "50 EAST COMMERCE DRIVE",
        "address_2": "SCHAUMBURG  IL  60173",
        "country": "US"
    },
    "080040": {
        "oui_hex": "08-00-40",
        "organization": "FERRANTI COMPUTER SYS. LIMITED",
        "address_1": "WYTHENSHAWE DIVISION",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "08003A": {
        "oui_hex": "08-00-3A",
        "organization": "ORCATECH INC.",
        "address_1": "2680 QUEENSVIEW DRIVE",
        "address_2": "CANADA  K2B  8H6",
        "country": "CA"
    },
    "08003D": {
        "oui_hex": "08-00-3D",
        "organization": "CADNETIX CORPORATIONS",
        "address_1": "5797 CENTRAL AVENUE",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "080038": {
        "oui_hex": "08-00-38",
        "organization": "BULL S.A.S.",
        "address_1": "rue Jean Jaures B.P.68",
        "address_2": "Les Clayes sous Bois    78430",
        "country": "FR"
    },
    "080073": {
        "oui_hex": "08-00-73",
        "organization": "TECMAR INC.",
        "address_1": "6225 COCHRAN ROAD",
        "address_2": "SOLON  OH  44139",
        "country": "US"
    },
    "080072": {
        "oui_hex": "08-00-72",
        "organization": "XEROX CORP UNIV GRANT PROGRAM",
        "address_1": "ZEROX SYSTEMS INSTITUTE",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "08006A": {
        "oui_hex": "08-00-6A",
        "organization": "AT&T",
        "address_1": "3300 E Renner Road",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "08007A": {
        "oui_hex": "08-00-7A",
        "organization": "INDATA",
        "address_1": "GJERDRUMS VEI 12 C",
        "address_2": "",
        "country": "NO"
    },
    "080079": {
        "oui_hex": "08-00-79",
        "organization": "THE DROID WORKS",
        "address_1": "P.O. BOX CS 8180",
        "address_2": "SAN RAFAEL  CA  94912",
        "country": "US"
    },
    "08004D": {
        "oui_hex": "08-00-4D",
        "organization": "CORVUS SYSTEMS INC.",
        "address_1": "2100 CORVUS DRIVE",
        "address_2": "SAN JOSE  CA  95124",
        "country": "US"
    },
    "08002F": {
        "oui_hex": "08-00-2F",
        "organization": "PRIME COMPUTER INC.",
        "address_1": "100 CROSBY DRIVE",
        "address_2": "BEDFORD  MA  01730-1402",
        "country": "US"
    },
    "08002C": {
        "oui_hex": "08-00-2C",
        "organization": "BRITTON LEE INC.",
        "address_1": "14600 WINCHESTER BLVD",
        "address_2": "LOS GATOS  CA  95030",
        "country": "US"
    },
    "080062": {
        "oui_hex": "08-00-62",
        "organization": "General Dynamics",
        "address_1": "",
        "address_2": "Fort Worth  TX",
        "country": "US"
    },
    "08005C": {
        "oui_hex": "08-00-5C",
        "organization": "FOUR PHASE SYSTEMS",
        "address_1": "2001 LOGIC DRIVE",
        "address_2": "SAN JOSE  CA  95124-3452",
        "country": "US"
    },
    "08005A": {
        "oui_hex": "08-00-5A",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "080052": {
        "oui_hex": "08-00-52",
        "organization": "INSYSTEC",
        "address_1": "450 LAKEMONT AVENUE",
        "address_2": "WINTER PARK  FL  32792",
        "country": "US"
    },
    "08001E": {
        "oui_hex": "08-00-1E",
        "organization": "APOLLO COMPUTER INC.",
        "address_1": "15 ELIZABETH DRIVE",
        "address_2": "CHELMSFORD  MA  01824",
        "country": "US"
    },
    "080019": {
        "oui_hex": "08-00-19",
        "organization": "GENERAL ELECTRIC CORPORATION",
        "address_1": "1285 BOSTON AVENUE",
        "address_2": "BRIDGEPORT  CT  06602",
        "country": "US"
    },
    "027001": {
        "oui_hex": "02-70-01",
        "organization": "RACAL-DATACOM",
        "address_1": "LAN INTERNETWORKING DIVISION",
        "address_2": "BOXBOROUGH  MA  01719",
        "country": "US"
    },
    "08000E": {
        "oui_hex": "08-00-0E",
        "organization": "NCR CORPORATION",
        "address_1": "WORLD HEADQUARTERS",
        "address_2": "DAYTON  OH  45479",
        "country": "US"
    },
    "00DD09": {
        "oui_hex": "00-DD-09",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "000002": {
        "oui_hex": "00-00-02",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "000003": {
        "oui_hex": "00-00-03",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "000006": {
        "oui_hex": "00-00-06",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "080001": {
        "oui_hex": "08-00-01",
        "organization": "COMPUTERVISION CORPORATION",
        "address_1": "14 CROSBY DRIVE MS 5-1",
        "address_2": "BEDFORD  MA  01730",
        "country": "US"
    },
    "080005": {
        "oui_hex": "08-00-05",
        "organization": "SYMBOLICS INC.",
        "address_1": "257 VASSAR STREET",
        "address_2": "CAMBRIDGE  MA  02139",
        "country": "US"
    },
    "00DD07": {
        "oui_hex": "00-DD-07",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "000008": {
        "oui_hex": "00-00-08",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "00003D": {
        "oui_hex": "00-00-3D",
        "organization": "UNISYS",
        "address_1": "MS8-010",
        "address_2": "SAN JOSE  CA  95150-6685",
        "country": "US"
    },
    "00DD0D": {
        "oui_hex": "00-DD-0D",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "080064": {
        "oui_hex": "08-00-64",
        "organization": "Sitasys AG",
        "address_1": "Freiburgstrasse 251",
        "address_2": "",
        "country": "CH"
    },
    "080002": {
        "oui_hex": "08-00-02",
        "organization": "BRIDGE COMMUNICATIONS INC.",
        "address_1": "2081 STIERLING ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "08001A": {
        "oui_hex": "08-00-1A",
        "organization": "TIARA/ 10NET",
        "address_1": "7777 WASHINGTON VILLAGE DRIVE",
        "address_2": "DAYTON  OHIO  45459-3957",
        "country": "US"
    },
    "08008B": {
        "oui_hex": "08-00-8B",
        "organization": "PYRAMID TECHNOLOGY CORP.",
        "address_1": "1295 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "080012": {
        "oui_hex": "08-00-12",
        "organization": "BELL ATLANTIC INTEGRATED SYST.",
        "address_1": "40 TALL PINE DRIVE",
        "address_2": "SUDBURY  MA  01776",
        "country": "US"
    },
    "14A1BF": {
        "oui_hex": "14-A1-BF",
        "organization": "ASSA ABLOY Korea Co., Ltd Unilock",
        "address_1": "10f of JEI PLATZ Bldg., 186, Gasandigital 1-ro",
        "address_2": "Geumcheon-gu  Seoul  08502",
        "country": "KR"
    },
    "9483C4": {
        "oui_hex": "94-83-C4",
        "organization": "GL Technologies (Hong Kong) Limited",
        "address_1": "103B Enterprise Place, 5W Science Park",
        "address_2": "NT    00000",
        "country": "HK"
    },
    "00000B": {
        "oui_hex": "00-00-0B",
        "organization": "MATRIX CORPORATION",
        "address_1": "1203 NEW HOPE ROAD",
        "address_2": "RALEIGH  NORTH CAROLINA   276",
        "country": "US"
    },
    "00009B": {
        "oui_hex": "00-00-9B",
        "organization": "INFORMATION INTERNATIONAL, INC",
        "address_1": "5F., THE 7TH INDUSTRY BLDG.",
        "address_2": "  JAPAN  150",
        "country": "JP"
    },
    "9C93B0": {
        "oui_hex": "9C-93-B0",
        "organization": "Megatronix (Beijing) Technology Co., Ltd.",
        "address_1": "Floor11,Building C, Rongxin Center Chungyuan Road 34#, chaoyang distric, Beijing, P.R.China",
        "address_2": "Beijing  Beijing  100012",
        "country": "CN"
    },
    "64AEF1": {
        "oui_hex": "64-AE-F1",
        "organization": "Qingdao Hisense Electronics Co.,Ltd.",
        "address_1": "Qianwangang Roard 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "080016": {
        "oui_hex": "08-00-16",
        "organization": "BARRISTER INFO SYS CORP",
        "address_1": "ONE TECHNOLOGY CENTER",
        "address_2": "BUFFALO  NY  14203",
        "country": "US"
    },
    "44CB8B": {
        "oui_hex": "44-CB-8B",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "B4055D": {
        "oui_hex": "B4-05-5D",
        "organization": "Inspur Electronic Information Industry Co.,Ltd.",
        "address_1": "No 224 Shanda Road",
        "address_2": "Jinan  Shandong  250013",
        "country": "CN"
    },
    "984827": {
        "oui_hex": "98-48-27",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D4F5EF": {
        "oui_hex": "D4-F5-EF",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "28BD89": {
        "oui_hex": "28-BD-89",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "EC1BBD": {
        "oui_hex": "EC-1B-BD",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin    78735",
        "country": "US"
    },
    "D8A315": {
        "oui_hex": "D8-A3-15",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "80647A": {
        "oui_hex": "80-64-7A",
        "organization": "Ola Sense Inc",
        "address_1": "764 Avenue A",
        "address_2": "Redondo Beach    90277",
        "country": "US"
    },
    "70F82B": {
        "oui_hex": "70-F8-2B",
        "organization": "DWnet Technologies(Suzhou) Corporation",
        "address_1": "No.8,Tangzhuang Road, Suzhou Industrial Park, Jiangsu, China",
        "address_2": "Suzhou    21500",
        "country": "CN"
    },
    "142475": {
        "oui_hex": "14-24-75",
        "organization": "4DReplay, Inc",
        "address_1": "1286 Folsom Street",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "10DCB6": {
        "oui_hex": "10-DC-B6",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F89E28": {
        "oui_hex": "F8-9E-28",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco    94158",
        "country": "US"
    },
    "F8C4F3": {
        "oui_hex": "F8-C4-F3",
        "organization": "Shanghai Infinity Wireless Technologies Co.,Ltd.",
        "address_1": "Room 522, Building A, No.1687 Changyang Road, Yangpu District, Shanghai",
        "address_2": "Shanghai  Shanghai  200082",
        "country": "CN"
    },
    "D4772B": {
        "oui_hex": "D4-77-2B",
        "organization": "Nanjing Ztlink Network Technology Co.,Ltd",
        "address_1": "No.0 Mozhou East Road , Jiangning Economic & Technological Development Zone, Jiangning District",
        "address_2": "Nanjing  Jiangsu  211111",
        "country": "CN"
    },
    "64F9C0": {
        "oui_hex": "64-F9-C0",
        "organization": "ANALOG DEVICES",
        "address_1": "32990 ALVARADO NILES RD",
        "address_2": "UNION CITY  CA  94587",
        "country": "US"
    },
    "18D0C5": {
        "oui_hex": "18-D0-C5",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "34ED1B": {
        "oui_hex": "34-ED-1B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BCA511": {
        "oui_hex": "BC-A5-11",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000A7B": {
        "oui_hex": "00-0A-7B",
        "organization": "Cornelius Consult",
        "address_1": "Im Vogelsang 21",
        "address_2": "Hattingen  NRW  45527",
        "country": "DE"
    },
    "C4E90A": {
        "oui_hex": "C4-E9-0A",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "C4447D": {
        "oui_hex": "C4-44-7D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "30E98E": {
        "oui_hex": "30-E9-8E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "748B34": {
        "oui_hex": "74-8B-34",
        "organization": "Shanghai Smart System Technology Co., Ltd",
        "address_1": "Room 902C-1, 560 Shengxia Road, Zhangjiang Hi-Tech Park, Shanghai 201203, China",
        "address_2": "Shanghai  Shanghai  201210",
        "country": "CN"
    },
    "ACBD70": {
        "oui_hex": "AC-BD-70",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C02E26": {
        "oui_hex": "C0-2E-26",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "34D262": {
        "oui_hex": "34-D2-62",
        "organization": "SZ DJI TECHNOLOGY CO.,LTD",
        "address_1": "6/F,HKUST SZ IER Bldg,9 Yuexing 1st Rd",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0812A5": {
        "oui_hex": "08-12-A5",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "807FF8": {
        "oui_hex": "80-7F-F8",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "440377": {
        "oui_hex": "44-03-77",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "002487": {
        "oui_hex": "00-24-87",
        "organization": "Transact Campus, Inc.",
        "address_1": "22601 North 19th Avenue",
        "address_2": "Phoenix  AZ  85027",
        "country": "US"
    },
    "B4E9A3": {
        "oui_hex": "B4-E9-A3",
        "organization": "port industrial automation GmbH",
        "address_1": "Regensburger Str. 7b",
        "address_2": "Halle (S.)    06132",
        "country": "DE"
    },
    "38E8EE": {
        "oui_hex": "38-E8-EE",
        "organization": "Nanjing Youkuo Electric Technology Co., Ltd",
        "address_1": "100 Jiangjun Road,Jiangning",
        "address_2": "Nanjing  Jiangsu  211100",
        "country": "CN"
    },
    "90B8E0": {
        "oui_hex": "90-B8-E0",
        "organization": "SHENZHEN YANRAY TECHNOLOGY CO.,LTD",
        "address_1": "5A, 4th Building, Huafengzhenbao Industrial Park, Beihuan Road, Shiyan Street, Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "9CF531": {
        "oui_hex": "9C-F5-31",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "80E455": {
        "oui_hex": "80-E4-55",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "2C4CC6": {
        "oui_hex": "2C-4C-C6",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "7C210D": {
        "oui_hex": "7C-21-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4CBC72": {
        "oui_hex": "4C-BC-72",
        "organization": "Primex Wireless",
        "address_1": "965 Wells Street",
        "address_2": "Lake Geneva  WI  53147",
        "country": "US"
    },
    "6802B8": {
        "oui_hex": "68-02-B8",
        "organization": "Compal Broadband Networks, Inc.",
        "address_1": "13F., No.1, Taiyuan 1st St.",
        "address_2": "Zhubei City  Hsinchu County  30265",
        "country": "TW"
    },
    "3463D4": {
        "oui_hex": "34-63-D4",
        "organization": "BIONIX SUPPLYCHAIN TECHNOLOGIES SLU",
        "address_1": "Poligono Pocomaco Avenida Primera Parcela B3 Nave F",
        "address_2": "La Coruña  La Coruña  15190",
        "country": "ES"
    },
    "08F7E9": {
        "oui_hex": "08-F7-E9",
        "organization": "HRCP Research and Development Partnership",
        "address_1": "1-24-2 Taito, Taito-ku",
        "address_2": "Tokyo    1100016",
        "country": "JP"
    },
    "8CBA25": {
        "oui_hex": "8C-BA-25",
        "organization": "UNIONMAN TECHNOLOGY CO.,LTD",
        "address_1": "No.5,Huitai Road,Huinan High-Tech Park,Huiao Highway",
        "address_2": "Huizhou  Guangdong  516025",
        "country": "CN"
    },
    "D49E3B": {
        "oui_hex": "D4-9E-3B",
        "organization": "Guangzhou Shiyuan Electronic Technology Company Limited",
        "address_1": "No.6, 4th Yunpu Road, Yunpu industry District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "DCDCE2": {
        "oui_hex": "DC-DC-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A0AC69": {
        "oui_hex": "A0-AC-69",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1089FB": {
        "oui_hex": "10-89-FB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DC4BDD": {
        "oui_hex": "DC-4B-DD",
        "organization": "Shenzhen SuperElectron Technology Co.,Ltd.",
        "address_1": "1213-1214, haosheng business center, dongbin road, nanshan street, nanshan district, shenzhen city",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C0B5CD": {
        "oui_hex": "C0-B5-CD",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "4C5077": {
        "oui_hex": "4C-50-77",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "502DBB": {
        "oui_hex": "50-2D-BB",
        "organization": "GD Midea Air-Conditioning Equipment Co.,Ltd.",
        "address_1": "Midea Global Innovation Center,Beijiao Town,Shunde",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "84EA97": {
        "oui_hex": "84-EA-97",
        "organization": "Shenzhen iComm Semiconductor Co., Ltd.",
        "address_1": "Room 501A,Block B,Digital Building,Garden City,No.1079 Nanhai Road,Nanshan District",
        "address_2": "Shenzhen    518067",
        "country": "CN"
    },
    "5C3A3D": {
        "oui_hex": "5C-3A-3D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "30FD65": {
        "oui_hex": "30-FD-65",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CA1AE": {
        "oui_hex": "7C-A1-AE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C22FB": {
        "oui_hex": "3C-22-FB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "58EAFC": {
        "oui_hex": "58-EA-FC",
        "organization": "ELL-IoT Inc",
        "address_1": "32 Journey",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "9013DA": {
        "oui_hex": "90-13-DA",
        "organization": "Athom B.V.",
        "address_1": "Rigtersbleek-Zandvoort 10",
        "address_2": "Enschede    7521BE",
        "country": "NL"
    },
    "14115D": {
        "oui_hex": "14-11-5D",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E4F327": {
        "oui_hex": "E4-F3-27",
        "organization": "ATOL LLC",
        "address_1": "Bolshaya Novodmitrovskaya str., 14, build 4",
        "address_2": "Moscow    127015",
        "country": "RU"
    },
    "6819AC": {
        "oui_hex": "68-19-AC",
        "organization": "Guangzhou Xianyou Intelligent Technogoly CO., LTD",
        "address_1": "No.32 Xixiu Road, Xiuquan Street,Huadu District",
        "address_2": "Guangzhou  Guangdong  510800",
        "country": "CN"
    },
    "E82E0C": {
        "oui_hex": "E8-2E-0C",
        "organization": "NETINT Technologies Inc.",
        "address_1": "#306, 3500 Gilmore Way",
        "address_2": "Burnaby  BC  V5G0B8",
        "country": "CA"
    },
    "1892A4": {
        "oui_hex": "18-92-A4",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "10082C": {
        "oui_hex": "10-08-2C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B0735D": {
        "oui_hex": "B0-73-5D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F0B4D2": {
        "oui_hex": "F0-B4-D2",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "5C3A45": {
        "oui_hex": "5C-3A-45",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "A03C31": {
        "oui_hex": "A0-3C-31",
        "organization": "Shenzhen Belon Technology CO.,LTD",
        "address_1": "Tsinghua Information",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "A897CD": {
        "oui_hex": "A8-97-CD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "404C77": {
        "oui_hex": "40-4C-77",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "2CE310": {
        "oui_hex": "2C-E3-10",
        "organization": "Stratacache",
        "address_1": "40 N Main St, Suite 2600",
        "address_2": "Dayton  OH  45423",
        "country": "US"
    },
    "0022A0": {
        "oui_hex": "00-22-A0",
        "organization": "APTIV SERVICES US, LLC",
        "address_1": "5725 Innovation Drive",
        "address_2": "Troy  MI  48098",
        "country": "US"
    },
    "A4307A": {
        "oui_hex": "A4-30-7A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "FC8E5B": {
        "oui_hex": "FC-8E-5B",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "142A14": {
        "oui_hex": "14-2A-14",
        "organization": "ShenZhen Selenview Digital Technology Co.,Ltd",
        "address_1": "615,Block A,Huafeng internet Creative Park,107 Gonghe Industrial Road,Baoan District,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "D87E76": {
        "oui_hex": "D8-7E-76",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "384B5B": {
        "oui_hex": "38-4B-5B",
        "organization": "ZTRON TECHNOLOGY LIMITED",
        "address_1": "12/F,JunZi Plaza, Qiaoxiang Road, Futian District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B86142": {
        "oui_hex": "B8-61-42",
        "organization": "Beijing Tricolor Technology Co., Ltd",
        "address_1": "Room 808, Building 1, Yard 39, Linfeng 2nd Road, Haidian",
        "address_2": "Beijing    102206",
        "country": "CN"
    },
    "200A0D": {
        "oui_hex": "20-0A-0D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E47C65": {
        "oui_hex": "E4-7C-65",
        "organization": "Sunstar Communication Technology  Co., Ltd",
        "address_1": "4F,Building D1, Mould Industrial Park, No.199 of Xiqu Ave,West High-tech Zone",
        "address_2": "Chengdu  Sichuan  611731",
        "country": "CN"
    },
    "9C54DA": {
        "oui_hex": "9C-54-DA",
        "organization": "SkyBell Technologies Inc.",
        "address_1": "1 Jenner",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "4C494F": {
        "oui_hex": "4C-49-4F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C4741E": {
        "oui_hex": "C4-74-1E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00D078": {
        "oui_hex": "00-D0-78",
        "organization": "Eltex of Sweden AB",
        "address_1": "Södra Portgatan 19",
        "address_2": "OSBY  Skåne  283 50",
        "country": "SE"
    },
    "5C78F8": {
        "oui_hex": "5C-78-F8",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B827C5": {
        "oui_hex": "B8-27-C5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "DC8983": {
        "oui_hex": "DC-89-83",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5CCB99": {
        "oui_hex": "5C-CB-99",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D46075": {
        "oui_hex": "D4-60-75",
        "organization": "Baidu Online Network Technology (Beijing) Co., Ltd",
        "address_1": "Baidu Campus, No.10 Shangdi 10th Street, Haidian District",
        "address_2": " Beijing    100085",
        "country": "CN"
    },
    "78C5F8": {
        "oui_hex": "78-C5-F8",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "D45D64": {
        "oui_hex": "D4-5D-64",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "90B144": {
        "oui_hex": "90-B1-44",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "48DD0C": {
        "oui_hex": "48-DD-0C",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "940C98": {
        "oui_hex": "94-0C-98",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E8FBE9": {
        "oui_hex": "E8-FB-E9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38EC0D": {
        "oui_hex": "38-EC-0D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "58278C": {
        "oui_hex": "58-27-8C",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "140AC5": {
        "oui_hex": "14-0A-C5",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "2083F8": {
        "oui_hex": "20-83-F8",
        "organization": "Advanced Digital Broadcast SA",
        "address_1": "Route de Lausanne 319",
        "address_2": "Bellevue    CH-1293",
        "country": "SZ"
    },
    "C8C750": {
        "oui_hex": "C8-C7-50",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "2CDCD7": {
        "oui_hex": "2C-DC-D7",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "34E3DA": {
        "oui_hex": "34-E3-DA",
        "organization": "Hoval Aktiengesellschaft",
        "address_1": "Austrasse 70",
        "address_2": "Vaduz    9490",
        "country": "LI"
    },
    "E0BB9E": {
        "oui_hex": "E0-BB-9E",
        "organization": "Seiko Epson Corporation",
        "address_1": "2070 Kotobuki Koaka",
        "address_2": "Matsumoto-shi  Nagano-ken  399-8702",
        "country": "JP"
    },
    "48D24F": {
        "oui_hex": "48-D2-4F",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "E4AAEC": {
        "oui_hex": "E4-AA-EC",
        "organization": "Tianjin Hualai Technology Co., Ltd",
        "address_1": "Overseas Chinese business building No. 10, Jinping Road, Nankai District, Tianjin",
        "address_2": "TIANJIN    300190",
        "country": "CN"
    },
    "94BE46": {
        "oui_hex": "94-BE-46",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "ACF8CC": {
        "oui_hex": "AC-F8-CC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8C5A25": {
        "oui_hex": "8C-5A-25",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "483FDA": {
        "oui_hex": "48-3F-DA",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "6C5D3A": {
        "oui_hex": "6C-5D-3A",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND    98052",
        "country": "US"
    },
    "C853E1": {
        "oui_hex": "C8-53-E1",
        "organization": "Beijing Bytedance Network Technology Co., Ltd",
        "address_1": "No.1 Building, Zhonghang Square, West Road of the Northern 3rd Circuit, Haidian Distrct",
        "address_2": "Beijing  Beijing  100098",
        "country": "CN"
    },
    "CCD42E": {
        "oui_hex": "CC-D4-2E",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "14169D": {
        "oui_hex": "14-16-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "48A2E6": {
        "oui_hex": "48-A2-E6",
        "organization": "Resideo",
        "address_1": "2 Corporate Center Dr.",
        "address_2": "Melville  NY  11747",
        "country": "US"
    },
    "90E2FC": {
        "oui_hex": "90-E2-FC",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "048C16": {
        "oui_hex": "04-8C-16",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "98DD5B": {
        "oui_hex": "98-DD-5B",
        "organization": "TAKUMI JAPAN LTD",
        "address_1": "3-9-3 Uchiyama building 7F Nishishinbashi",
        "address_2": "Minato-ku Tokyo  Tokyo  1050003",
        "country": "JP"
    },
    "B09575": {
        "oui_hex": "B0-95-75",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F008D1": {
        "oui_hex": "F0-08-D1",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "B4B055": {
        "oui_hex": "B4-B0-55",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "14AE85": {
        "oui_hex": "14-AE-85",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "5894B2": {
        "oui_hex": "58-94-B2",
        "organization": "BrainCo",
        "address_1": "????????????????1107?",
        "address_2": "???  ???  518000",
        "country": "CN"
    },
    "645CF3": {
        "oui_hex": "64-5C-F3",
        "organization": "ParanTek Inc.",
        "address_1": "3F, 40-15 Gilju-Ro, 411 Beon-Gil",
        "address_2": "Wonmi-Gu, Bucheon City  Gyeonggi-Do  14488",
        "country": "KR"
    },
    "8C3B32": {
        "oui_hex": "8C-3B-32",
        "organization": "Microfan B.V.",
        "address_1": "Industriestraat 23",
        "address_2": "Horst  Limburg  5961 PH",
        "country": "NL"
    },
    "D0D3E0": {
        "oui_hex": "D0-D3-E0",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "FC3964": {
        "oui_hex": "FC-39-64",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "90749D": {
        "oui_hex": "90-74-9D",
        "organization": "IRay Technology Co., Ltd.",
        "address_1": "11th Guiyang St.,",
        "address_2": "Yantai  Shandong  264000",
        "country": "CN"
    },
    "540DF9": {
        "oui_hex": "54-0D-F9",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "006619": {
        "oui_hex": "00-66-19",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B0CCFE": {
        "oui_hex": "B0-CC-FE",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3C5CF1": {
        "oui_hex": "3C-5C-F1",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "E490FD": {
        "oui_hex": "E4-90-FD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D06544": {
        "oui_hex": "D0-65-44",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84AB1A": {
        "oui_hex": "84-AB-1A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "186F2D": {
        "oui_hex": "18-6F-2D",
        "organization": "Shenzhen Sundray Technologies Company Limited",
        "address_1": "5th Floor, Block A4, Nanshan ipark,NO.1001 Xue Yuan Road, Nanshan District, Shenzhen 518055, P.R. China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F84FAD": {
        "oui_hex": "F8-4F-AD",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "4C0A3D": {
        "oui_hex": "4C-0A-3D",
        "organization": "ADNACOM INC.",
        "address_1": "200-5050 Kingsway",
        "address_2": "Burnaby  BC  V5H 4H2",
        "country": "CA"
    },
    "206D31": {
        "oui_hex": "20-6D-31",
        "organization": "FIREWALLA INC",
        "address_1": "75 E. Santa Clara St. STE 600",
        "address_2": "San Jose  CA  95113",
        "country": "US"
    },
    "A84122": {
        "oui_hex": "A8-41-22",
        "organization": "China Mobile (Hangzhou) Information Technology Co.,Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "14472D": {
        "oui_hex": "14-47-2D",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "6CDDBC": {
        "oui_hex": "6C-DD-BC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC7F76": {
        "oui_hex": "CC-7F-76",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3C806B": {
        "oui_hex": "3C-80-6B",
        "organization": "Hunan Voc Acoustics Technology Co., Ltd.",
        "address_1": "State Industrialpark, Jiulong Development Zone, Yanling County",
        "address_2": "Zhuzhou  Hunan  412500",
        "country": "CN"
    },
    "60DE35": {
        "oui_hex": "60-DE-35",
        "organization": "GITSN, Inc.",
        "address_1": " #601~602, Daerung Post Tower 1, 288, Digital-ro",
        "address_2": "Guro-gu  Seoul  08390",
        "country": "KR"
    },
    "28317E": {
        "oui_hex": "28-31-7E",
        "organization": "Hongkong Nano IC Technologies Co., Ltd",
        "address_1": " Rm. 19C, Lockhart Ctr., 301-307 Lockhart Rd., Wan Chai, Hong Kong.",
        "address_2": "Hongkong    999077",
        "country": "CN"
    },
    "40BC68": {
        "oui_hex": "40-BC-68",
        "organization": "Wuhan Funshion Online Technologies Co.,Ltd",
        "address_1": "5th Floor,Financial Port Building A9,No.77 Optical Valley Avenue, East Lake High-Tech Development Zone, Wuhan",
        "address_2": "Wuhan  CN/Hubei  430000",
        "country": "CN"
    },
    "B802A4": {
        "oui_hex": "B8-02-A4",
        "organization": "Aeonsemi, Inc.",
        "address_1": "Cassia Court, Suite 716, 10 Market Street",
        "address_2": "Camana Bay  Grand Cayman  KY1-9006",
        "country": "KY"
    },
    "E48326": {
        "oui_hex": "E4-83-26",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "447654": {
        "oui_hex": "44-76-54",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CD9A0": {
        "oui_hex": "7C-D9-A0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F033E5": {
        "oui_hex": "F0-33-E5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B8CEF6": {
        "oui_hex": "B8-CE-F6",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "9405BB": {
        "oui_hex": "94-05-BB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "DC9840": {
        "oui_hex": "DC-98-40",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND    98052",
        "country": "US"
    },
    "B4F18C": {
        "oui_hex": "B4-F1-8C",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C432D1": {
        "oui_hex": "C4-32-D1",
        "organization": "Farlink Technology Limited",
        "address_1": "Flat A&B,9/F,Wing Cheong Factory Building,121 King Lam Street,Cheung Sha Wan,Hong Kong.",
        "address_2": "Hongkong    0000",
        "country": "HK"
    },
    "C8D778": {
        "oui_hex": "C8-D7-78",
        "organization": "BSH Hausgeraete GmbH",
        "address_1": "Im Gewerbepark B10",
        "address_2": "Regensburg    93059",
        "country": "DE"
    },
    "1869D8": {
        "oui_hex": "18-69-D8",
        "organization": "HANGZHOU AIXIANGJI TECHNOLOGY CO., LTD",
        "address_1": "7 Floor, 3 Blvd., More Centre, 87 Gudun Rd., Xihu District",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "8C5FAD": {
        "oui_hex": "8C-5F-AD",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "ACC25D": {
        "oui_hex": "AC-C2-5D",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "8C0C87": {
        "oui_hex": "8C-0C-87",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "CC418E": {
        "oui_hex": "CC-41-8E",
        "organization": "MSA Innovation",
        "address_1": "1100 Cranberry Woods Road",
        "address_2": "Cranberry Township  PA  16066",
        "country": "US"
    },
    "CCA7C1": {
        "oui_hex": "CC-A7-C1",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "388479": {
        "oui_hex": "38-84-79",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco    94158",
        "country": "US"
    },
    "6849B2": {
        "oui_hex": "68-49-B2",
        "organization": "CARLO GAVAZZI LTD",
        "address_1": "BLB042, Bulebel Industrial Estate",
        "address_2": "Zejtun     ZTN 3000",
        "country": "MT"
    },
    "7C9EBD": {
        "oui_hex": "7C-9E-BD",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "1C0219": {
        "oui_hex": "1C-02-19",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "C095DA": {
        "oui_hex": "C0-95-DA",
        "organization": "NXP India Private Limited",
        "address_1": "1st Floor, Muttha Towers, Don Bosco Marg, Off Airport Road, Yerwada",
        "address_2": "Pune  Maharashtra  411006",
        "country": "IN"
    },
    "9C611D": {
        "oui_hex": "9C-61-1D",
        "organization": "Panasonic Corporation of North America",
        "address_1": "1200 Ridgeway Ave",
        "address_2": "Rochester  NY  14615",
        "country": "US"
    },
    "B42200": {
        "oui_hex": "B4-22-00",
        "organization": "Brother Industries, LTD.",
        "address_1": "15-1, Naeshirocho, Mizuho-ku",
        "address_2": "NAGOYA    4678561",
        "country": "JP"
    },
    "487AFF": {
        "oui_hex": "48-7A-FF",
        "organization": "ESSYS",
        "address_1": "gaetbeol-ro",
        "address_2": "Incheon    21999",
        "country": "KR"
    },
    "D0B45D": {
        "oui_hex": "D0-B4-5D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "8836CF": {
        "oui_hex": "88-36-CF",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "009EEE": {
        "oui_hex": "00-9E-EE",
        "organization": "Positivo Tecnologia S.A.",
        "address_1": "João Bettega, 5200",
        "address_2": "Curitiba  Paraná  81350-000",
        "country": "BR"
    },
    "A4C54E": {
        "oui_hex": "A4-C5-4E",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "D4BBE6": {
        "oui_hex": "D4-BB-E6",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "40B6E7": {
        "oui_hex": "40-B6-E7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "9C5D12": {
        "oui_hex": "9C-5D-12",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "F09CE9": {
        "oui_hex": "F0-9C-E9",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "C413E2": {
        "oui_hex": "C4-13-E2",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "90B832": {
        "oui_hex": "90-B8-32",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "C8675E": {
        "oui_hex": "C8-67-5E",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "402F86": {
        "oui_hex": "40-2F-86",
        "organization": "LG Innotek",
        "address_1": "26, Hanamsandan 5beon-ro",
        "address_2": "Gwangju  Gwangsan-gu  506-731",
        "country": "KR"
    },
    "D422CD": {
        "oui_hex": "D4-22-CD",
        "organization": "Xsens Technologies B.V.",
        "address_1": "Pantheon 6-a",
        "address_2": "Enschede    7521 PR",
        "country": "NL"
    },
    "F4EB9F": {
        "oui_hex": "F4-EB-9F",
        "organization": "Ellu Company 2019 SL",
        "address_1": "Paseo de la Castellana 144 14B",
        "address_2": "Madrid  Madrid  28046",
        "country": "ES"
    },
    "E898C2": {
        "oui_hex": "E8-98-C2",
        "organization": "ZETLAB Company",
        "address_1": "Savelkinsky passage, 4",
        "address_2": "Zelenograd  Moscow  124482",
        "country": "RU"
    },
    "64DDE9": {
        "oui_hex": "64-DD-E9",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "D41AC8": {
        "oui_hex": "D4-1A-C8",
        "organization": "Nippon Printer Engineering",
        "address_1": "2660 Katsuyama",
        "address_2": "Fujikawaguchiko-town  Yamanashi-Pref.  401-0310",
        "country": "JP"
    },
    "5061F6": {
        "oui_hex": "50-61-F6",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "0C817D": {
        "oui_hex": "0C-81-7D",
        "organization": "EEP Elektro-Elektronik Pranjic GmbH",
        "address_1": "Am Luftschacht 21",
        "address_2": "Gelsenkirchen    45886",
        "country": "DE"
    },
    "000C32": {
        "oui_hex": "00-0C-32",
        "organization": "Avionic Design GmbH",
        "address_1": "Wragekamp 10",
        "address_2": "Hamburg    22397",
        "country": "DE"
    },
    "000A0D": {
        "oui_hex": "00-0A-0D",
        "organization": "Amphenol",
        "address_1": "Holzhauser Strasse 175",
        "address_2": "Berlin    13509",
        "country": "DE"
    },
    "001BED": {
        "oui_hex": "00-1B-ED",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000CDB": {
        "oui_hex": "00-0C-DB",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000480": {
        "oui_hex": "00-04-80",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "B04502": {
        "oui_hex": "B0-45-02",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "1C1FF1": {
        "oui_hex": "1C-1F-F1",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "609C9F": {
        "oui_hex": "60-9C-9F",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000088": {
        "oui_hex": "00-00-88",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0060DF": {
        "oui_hex": "00-60-DF",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "006069": {
        "oui_hex": "00-60-69",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000533": {
        "oui_hex": "00-05-33",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "F45420": {
        "oui_hex": "F4-54-20",
        "organization": "TELLESCOM INDUSTRIA E COMERCIO EM TELECOMUNICACAO",
        "address_1": "Av. Buriti, 1900 – Setor B – Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075-000",
        "country": "BR"
    },
    "4C4088": {
        "oui_hex": "4C-40-88",
        "organization": "SANSHIN ELECTRONICS CO.,LTD.",
        "address_1": "4-4-12, Shiba, Minato-ku,",
        "address_2": "Tokyo    108-8404",
        "country": "JP"
    },
    "04F5F4": {
        "oui_hex": "04-F5-F4",
        "organization": "Proxim Wireless",
        "address_1": "2114 Ringwood Ave",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "C8BCE5": {
        "oui_hex": "C8-BC-E5",
        "organization": "Sense Things Japan INC.",
        "address_1": "3-5-7 Kawaramachi,Chuo-ku",
        "address_2": "Osaka    541-0048",
        "country": "JP"
    },
    "E8B470": {
        "oui_hex": "E8-B4-70",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "B4EF1C": {
        "oui_hex": "B4-EF-1C",
        "organization": "360 AI Technology Co.Ltd",
        "address_1": "MTK Building B?No.6 Jiuxianqiao Road, Chaoyang District, Beijing, P.R.C.",
        "address_2": "Beijing  Beijing  100015",
        "country": "CN"
    },
    "14DE39": {
        "oui_hex": "14-DE-39",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B8F009": {
        "oui_hex": "B8-F0-09",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "2468B0": {
        "oui_hex": "24-68-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FC71FA": {
        "oui_hex": "FC-71-FA",
        "organization": "Trane Technologies",
        "address_1": "6200 Troup Hwy.",
        "address_2": "Tyler  TX  75707",
        "country": "US"
    },
    "CCBE59": {
        "oui_hex": "CC-BE-59",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "84A3B5": {
        "oui_hex": "84-A3-B5",
        "organization": "Propulsion systems",
        "address_1": "Dooren 72",
        "address_2": "Merchtem  Vlaams brabant  1785",
        "country": "BE"
    },
    "9CEDFA": {
        "oui_hex": "9C-ED-FA",
        "organization": "EVUlution AG",
        "address_1": "Via da Clalt 12",
        "address_2": "Poschiavo  GR  7742",
        "country": "CH"
    },
    "9C19C2": {
        "oui_hex": "9C-19-C2",
        "organization": "Dongguan Liesheng Electronic Co., Ltd.",
        "address_1": "F5, Building B, North Block, Gaosheng Tech Park, No. 84 Zhongli Road, Nancheng District, Dongguan Ci",
        "address_2": "dongguan   guangdong  523000",
        "country": "CN"
    },
    "D46761": {
        "oui_hex": "D4-67-61",
        "organization": "XonTel Technology Co.",
        "address_1": "XonTel, Borj ALadel Tower, Fahad Al-Salem St Fl 21",
        "address_2": "Kuwait    0000",
        "country": "KW"
    },
    "74CBF3": {
        "oui_hex": "74-CB-F3",
        "organization": "Lava international limited",
        "address_1": "A-154D, Sector-63",
        "address_2": "Noida  Uttar Pradesh  201301",
        "country": "IN"
    },
    "E44122": {
        "oui_hex": "E4-41-22",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "1C1338": {
        "oui_hex": "1C-13-38",
        "organization": "Kimball Electronics Group, LLC",
        "address_1": "1205 Kimball Blvd",
        "address_2": "Jasper  IN  47546",
        "country": "US"
    },
    "30FCEB": {
        "oui_hex": "30-FC-EB",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "EC63ED": {
        "oui_hex": "EC-63-ED",
        "organization": "Hyundai Autoever Corp.",
        "address_1": "38, Teheran-ro 114-gil",
        "address_2": "Gangnam-gu, Seoul    06176",
        "country": "KR"
    },
    "18DFC1": {
        "oui_hex": "18-DF-C1",
        "organization": "Aetheros",
        "address_1": "909 Montgomery Street, Suite 104",
        "address_2": "San Francisco    94133",
        "country": "US"
    },
    "B05CDA": {
        "oui_hex": "B0-5C-DA",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "F0D14F": {
        "oui_hex": "F0-D1-4F",
        "organization": "LINEAR LLC",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "2479EF": {
        "oui_hex": "24-79-EF",
        "organization": "Greenpacket Berhad, Taiwan",
        "address_1": "B-23A-3, The Ascent Paradigm, No. 1, Jalan SS7/26A, Kelana Jaya, 47301 Petaling Jaya",
        "address_2": "Petaling Jaya  Selangor  47301",
        "country": "MY"
    },
    "60AAEF": {
        "oui_hex": "60-AA-EF",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "BC26A1": {
        "oui_hex": "BC-26-A1",
        "organization": "FACTORY FIVE Corporation",
        "address_1": "3-391-1, Kamikitadai,",
        "address_2": " Higashiyamato  Tokyo  207-0023",
        "country": "JP"
    },
    "001168": {
        "oui_hex": "00-11-68",
        "organization": "HomeLogic LLC",
        "address_1": "5919 Sea Otter Place",
        "address_2": "Carlsbad  CA  92010",
        "country": "US"
    },
    "2CD066": {
        "oui_hex": "2C-D0-66",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "DCBD7A": {
        "oui_hex": "DC-BD-7A",
        "organization": "Guangzhou Shiyuan Electronic Technology Company Limited",
        "address_1": "No.6, 4th Yunpu Road, Yunpu industry District",
        "address_2": "Guangzhou  Guangdong  510530",
        "country": "CN"
    },
    "FCBC0E": {
        "oui_hex": "FC-BC-0E",
        "organization": "Zhejiang Cainiao Supply Chain Management Co., Ltd",
        "address_1": "Block B1, XIXI center, No.588 West Wenyi Road, Xihu District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "9016BA": {
        "oui_hex": "90-16-BA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D44649": {
        "oui_hex": "D4-46-49",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D0F3F5": {
        "oui_hex": "D0-F3-F5",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "9400B0": {
        "oui_hex": "94-00-B0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C83DFC": {
        "oui_hex": "C8-3D-FC",
        "organization": "AlphaTheta Corporation",
        "address_1": "6F,Yokohama i-Mark Place, 4-4-5 Minatomirai, Nishi-ku",
        "address_2": "Yokohama  Kanagawa  220-0012",
        "country": "JP"
    },
    "E01995": {
        "oui_hex": "E0-19-95",
        "organization": "Nutanix",
        "address_1": "1740 Technology Drive Ste #150",
        "address_2": "San Jose  CA  95110",
        "country": "US"
    },
    "AC2334": {
        "oui_hex": "AC-23-34",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "002B67": {
        "oui_hex": "00-2B-67",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "F8BC0E": {
        "oui_hex": "F8-BC-0E",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "B85776": {
        "oui_hex": "B8-57-76",
        "organization": "lignex1",
        "address_1": "354-25, Sanhodae-ro",
        "address_2": "Gumi-si  Gyeongsangbuk-do, Korea  39262",
        "country": "KR"
    },
    "2400FA": {
        "oui_hex": "24-00-FA",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  311100",
        "country": "CN"
    },
    "50E039": {
        "oui_hex": "50-E0-39",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "F85128": {
        "oui_hex": "F8-51-28",
        "organization": "SimpliSafe",
        "address_1": "294 Washington St",
        "address_2": "Boston  MA  02108",
        "country": "US"
    },
    "D8DC40": {
        "oui_hex": "D8-DC-40",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "805FC5": {
        "oui_hex": "80-5F-C5",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C4DBE": {
        "oui_hex": "3C-4D-BE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48262C": {
        "oui_hex": "48-26-2C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC1F09": {
        "oui_hex": "AC-1F-09",
        "organization": "shenzhen RAKwireless technology  Co.,Ltd",
        "address_1": "Room 506, Bldg B, New Compark, Pingshan First Road, Taoyuan Street,Nanshan District",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "BC13A8": {
        "oui_hex": "BC-13-A8",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "10F920": {
        "oui_hex": "10-F9-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9077EE": {
        "oui_hex": "90-77-EE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3C13CC": {
        "oui_hex": "3C-13-CC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "94E3EE": {
        "oui_hex": "94-E3-EE",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "147DDA": {
        "oui_hex": "14-7D-DA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C4910C": {
        "oui_hex": "C4-91-0C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "206980": {
        "oui_hex": "20-69-80",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "645D86": {
        "oui_hex": "64-5D-86",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "181DEA": {
        "oui_hex": "18-1D-EA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "185680": {
        "oui_hex": "18-56-80",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A0A4C5": {
        "oui_hex": "A0-A4-C5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F4D108": {
        "oui_hex": "F4-D1-08",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "207918": {
        "oui_hex": "20-79-18",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A86DAA": {
        "oui_hex": "A8-6D-AA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6C9961": {
        "oui_hex": "6C-99-61",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "6432A8": {
        "oui_hex": "64-32-A8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "801934": {
        "oui_hex": "80-19-34",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "40A3CC": {
        "oui_hex": "40-A3-CC",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E4A7A0": {
        "oui_hex": "E4-A7-A0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "04D3B0": {
        "oui_hex": "04-D3-B0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "50C709": {
        "oui_hex": "50-C7-09",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "806D97": {
        "oui_hex": "80-6D-97",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "8CE468": {
        "oui_hex": "8C-E4-68",
        "organization": "Guangzhou Sageran Technology Co., Ltd.",
        "address_1": "Room 1902, Ruian Guangzhou Center, 374 Beijing Road, Yuexiu District",
        "address_2": "Guangzhou  Guangdong  510030",
        "country": "CN"
    },
    "F4C114": {
        "oui_hex": "F4-C1-14",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "C8B29B": {
        "oui_hex": "C8-B2-9B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6C6A77": {
        "oui_hex": "6C-6A-77",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A4B1C1": {
        "oui_hex": "A4-B1-C1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "342EB7": {
        "oui_hex": "34-2E-B7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "8CC681": {
        "oui_hex": "8C-C6-81",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "CCF9E4": {
        "oui_hex": "CC-F9-E4",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "3C58C2": {
        "oui_hex": "3C-58-C2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E45E37": {
        "oui_hex": "E4-5E-37",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "380025": {
        "oui_hex": "38-00-25",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "907841": {
        "oui_hex": "90-78-41",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "58A023": {
        "oui_hex": "58-A0-23",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D4D252": {
        "oui_hex": "D4-D2-52",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "24418C": {
        "oui_hex": "24-41-8C",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "60F262": {
        "oui_hex": "60-F2-62",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C0B883": {
        "oui_hex": "C0-B8-83",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C809A8": {
        "oui_hex": "C8-09-A8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2848E7": {
        "oui_hex": "28-48-E7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "E4268B": {
        "oui_hex": "E4-26-8B",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C0E3A0": {
        "oui_hex": "C0-E3-A0",
        "organization": "Renesas Electronics (Penang) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "44680C": {
        "oui_hex": "44-68-0C",
        "organization": "Wacom Co.,Ltd.",
        "address_1": "Sumitomo Fudosan Shinjuku Grand Tower 31F,8-17-1",
        "address_2": "Nishi-shinjuku,Shinjuku-ku  Tokyo  160-6131",
        "country": "JP"
    },
    "980E24": {
        "oui_hex": "98-0E-24",
        "organization": "Phytium Technology Co.,Ltd.",
        "address_1": "Building5,XinAn Business Square,Haiyuan Middle Road Binhai New District,",
        "address_2": "Tianjin    300450",
        "country": "CN"
    },
    "A830BC": {
        "oui_hex": "A8-30-BC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1C98C1": {
        "oui_hex": "1C-98-C1",
        "organization": "CLOUD NETWORK TECHNOLOGY SINGAPORE PTE. LTD.",
        "address_1": "B22 Building,NO.51 Tongle Road, Shajing Town, Jiangnan District, Nanning, Guangxi Province, China",
        "address_2": "Nanning  Guangxi  530007",
        "country": "CN"
    },
    "A09B17": {
        "oui_hex": "A0-9B-17",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "0063DE": {
        "oui_hex": "00-63-DE",
        "organization": "CLOUDWALK TECHNOLOGY CO.,LTD",
        "address_1": "Five Floors of Block 106, West Jinkai Avenue, Yubei District",
        "address_2": "Chongqing  Chongqing  401120",
        "country": "CN"
    },
    "60A423": {
        "oui_hex": "60-A4-23",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "7846D4": {
        "oui_hex": "78-46-D4",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E43EC6": {
        "oui_hex": "E4-3E-C6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "38881E": {
        "oui_hex": "38-88-1E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2CDB07": {
        "oui_hex": "2C-DB-07",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "988D46": {
        "oui_hex": "98-8D-46",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E06CA6": {
        "oui_hex": "E0-6C-A6",
        "organization": "Creotech Instruments S.A.",
        "address_1": "ul. Gen. L. Okulickiego 7/9",
        "address_2": "Piaseczno  Mazovia  05-500",
        "country": "PL"
    },
    "6888A1": {
        "oui_hex": "68-88-A1",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "001EB2": {
        "oui_hex": "00-1E-B2",
        "organization": "LG Innotek",
        "address_1": "Hanyang Univ. 1271, Sa-dong, Sangrok-gu",
        "address_2": "Ansan-si  Gyeonggi-do  426-791",
        "country": "KR"
    },
    "C086B3": {
        "oui_hex": "C0-86-B3",
        "organization": "Shenzhen Voxtech Co., Ltd.",
        "address_1": "Floors 1-4,Factory Building 26,Shancheng Industrial Park,Shiyan Street,Bao'an District,Shenzhen, Guangdong,China",
        "address_2": "Shenzhen     518000",
        "country": "CN"
    },
    "44ADB1": {
        "oui_hex": "44-AD-B1",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "4401BB": {
        "oui_hex": "44-01-BB",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268? Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "58F2FC": {
        "oui_hex": "58-F2-FC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "507043": {
        "oui_hex": "50-70-43",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "A0D83D": {
        "oui_hex": "A0-D8-3D",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D01411": {
        "oui_hex": "D0-14-11",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "3C53D7": {
        "oui_hex": "3C-53-D7",
        "organization": "CEDES AG",
        "address_1": "Kantonsstrasse 14",
        "address_2": "Landquart    7302",
        "country": "CH"
    },
    "00E5E4": {
        "oui_hex": "00-E5-E4",
        "organization": "Sichuan Tianyi Comheart Telecom Co., Ltd.",
        "address_1": "No.198,First Section,Snow Mountain Avenue, Jinyuan Town, Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "CN"
    },
    "643AEA": {
        "oui_hex": "64-3A-EA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E8136E": {
        "oui_hex": "E8-13-6E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4CAE13": {
        "oui_hex": "4C-AE-13",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4C2EFE": {
        "oui_hex": "4C-2E-FE",
        "organization": "Shenzhen Comnect Technology Co.,LTD",
        "address_1": "G Zone, 3/F, Building 1, Baisha High-Tech Park, No. 3011, Shahe Road West, XiLi Street, Nanshan District",
        "address_2": "Shenzhen    518055",
        "country": "CN"
    },
    "E0B260": {
        "oui_hex": "E0-B2-60",
        "organization": "TENO NETWORK TECHNOLOGIES COMPANY LIMITED",
        "address_1": "RM 1302, 13/F CHEONG K BLDG 84-86 DES VOEUX RD CENTRAL  HONG KONG",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "482335": {
        "oui_hex": "48-23-35",
        "organization": "Dialog Semiconductor Hellas SA",
        "address_1": "Achileos 8 & Katsoni Str",
        "address_2": "Kalithea, Athens    17674",
        "country": "GR"
    },
    "E8DA20": {
        "oui_hex": "E8-DA-20",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "10BC97": {
        "oui_hex": "10-BC-97",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "7CF9A0": {
        "oui_hex": "7C-F9-A0",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "6CA4D1": {
        "oui_hex": "6C-A4-D1",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "DCD444": {
        "oui_hex": "DC-D4-44",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A446B4": {
        "oui_hex": "A4-46-B4",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0CC844": {
        "oui_hex": "0C-C8-44",
        "organization": "Cambridge Mobile Telematics, Inc.",
        "address_1": "One Broadway, 14th Floor",
        "address_2": "Cambridge  MA  02142",
        "country": "US"
    },
    "EC6C9A": {
        "oui_hex": "EC-6C-9A",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "346D9C": {
        "oui_hex": "34-6D-9C",
        "organization": "Carrier Corporation",
        "address_1": "6304 Thompson Rd",
        "address_2": "East Syracuse  NY  13057",
        "country": "US"
    },
    "8C85C1": {
        "oui_hex": "8C-85-C1",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "20A171": {
        "oui_hex": "20-A1-71",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "782B64": {
        "oui_hex": "78-2B-64",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "D4F756": {
        "oui_hex": "D4-F7-56",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "54AB3A": {
        "oui_hex": "54-AB-3A",
        "organization": "Quanta Computer Inc.",
        "address_1": "No.211, Wen Hwa 2nd Rd., Kuei Shan Hsiang, Tao Yuan Shien, Taiwan, R. O. C.",
        "address_2": "Taoyuan  Taiwan  33377",
        "country": "TW"
    },
    "E89A8F": {
        "oui_hex": "E8-9A-8F",
        "organization": "Quanta Computer Inc.",
        "address_1": "211, Wen Hwa 2nd Rd.,Kuei Shan, Tao Yuan",
        "address_2": "TAIPEI    33377",
        "country": "TW"
    },
    "E0693A": {
        "oui_hex": "E0-69-3A",
        "organization": "Innophase Inc.",
        "address_1": "6815 Flanders Drive Suite 150",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "24FD0D": {
        "oui_hex": "24-FD-0D",
        "organization": "Intelbras",
        "address_1": "BR 101, KM 210",
        "address_2": "São Jose  Santa Catarina  88104-800",
        "country": "BR"
    },
    "5488DE": {
        "oui_hex": "54-88-DE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3CE3E7": {
        "oui_hex": "3C-E3-E7",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "40AA56": {
        "oui_hex": "40-AA-56",
        "organization": "China Dragon Technology Limited",
        "address_1": "B4 Bldg.Haoshan 1st Industry Park,",
        "address_2": "Shenzhen  Guangdong  518104",
        "country": "CN"
    },
    "68545A": {
        "oui_hex": "68-54-5A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001E31": {
        "oui_hex": "00-1E-31",
        "organization": "infomark",
        "address_1": "5F.,Geown Bldg.,1360-53",
        "address_2": "Seoul  Seocho-dong,Seocho-gu  137-863",
        "country": "KR"
    },
    "CC47BD": {
        "oui_hex": "CC-47-BD",
        "organization": "Rhombus Systems",
        "address_1": "770 L St, Suite 1480",
        "address_2": "Sacramento  CA  95814",
        "country": "US"
    },
    "345594": {
        "oui_hex": "34-55-94",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building, Star-net Science Plaza, Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "4C93A6": {
        "oui_hex": "4C-93-A6",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "7C8AE1": {
        "oui_hex": "7C-8A-E1",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "54E4A9": {
        "oui_hex": "54-E4-A9",
        "organization": "BHR Tech GmbH",
        "address_1": "Georg-Franz-Koller-Straße 18",
        "address_2": "Bisamberg    2102",
        "country": "AT"
    },
    "208058": {
        "oui_hex": "20-80-58",
        "organization": "Ciena Corporation",
        "address_1": "7035 Ridge Road",
        "address_2": "Hanover  MD  21076",
        "country": "US"
    },
    "684AAE": {
        "oui_hex": "68-4A-AE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "60D755": {
        "oui_hex": "60-D7-55",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A445CD": {
        "oui_hex": "A4-45-CD",
        "organization": "IoT Diagnostics",
        "address_1": "10052 Commerce Park Drive",
        "address_2": "Cincinnati  OH  45246",
        "country": "US"
    },
    "946269": {
        "oui_hex": "94-62-69",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D0DD49": {
        "oui_hex": "D0-DD-49",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C863FC": {
        "oui_hex": "C8-63-FC",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "1CCCD6": {
        "oui_hex": "1C-CC-D6",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "A8C252": {
        "oui_hex": "A8-C2-52",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A04147": {
        "oui_hex": "A0-41-47",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "1CAECB": {
        "oui_hex": "1C-AE-CB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4CF19E": {
        "oui_hex": "4C-F1-9E",
        "organization": "Groupe Atlantic",
        "address_1": "Ideal Boilers, National Ave",
        "address_2": "Hull  East Yorkshire  HU5 4JB",
        "country": "GB"
    },
    "2036D7": {
        "oui_hex": "20-36-D7",
        "organization": "Shanghai Reacheng  Communication Technology Co.,Ltd",
        "address_1": "No. 80, Lane 1505 Zuchongzhi Road",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "68070A": {
        "oui_hex": "68-07-0A",
        "organization": "TPVision Europe B.V",
        "address_1": "Prins Bernhardplein 200",
        "address_2": "Amsterdam  Noord-Holland  1097 JB",
        "country": "NL"
    },
    "4CEBBD": {
        "oui_hex": "4C-EB-BD",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "7CC926": {
        "oui_hex": "7C-C9-26",
        "organization": "Wuhan GreeNet Information Service Co.,Ltd.",
        "address_1": "4-6F, Building 2, Phase 6, Optical Valley Software Park, East Lake High-Tech Development Zone",
        "address_2": "Wuhan    430000",
        "country": "CN"
    },
    "5C75AF": {
        "oui_hex": "5C-75-AF",
        "organization": "Fitbit, Inc.",
        "address_1": "199 Fremont Street, 14th Fl",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "38BAB0": {
        "oui_hex": "38-BA-B0",
        "organization": "Broadcom",
        "address_1": "1320 Ridder Park",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "70879E": {
        "oui_hex": "70-87-9E",
        "organization": "Beken Corporation",
        "address_1": "Building 41, Capital of Tech Leaders, 1387 Zhangdong Road, Zhangjiang High-Tech Park, Pudong New District",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "B45062": {
        "oui_hex": "B4-50-62",
        "organization": "EmBestor Technology Inc.",
        "address_1": "7F, No.1, Chin-Shan 8th St",
        "address_2": "Hsin-Chu, Taiwan    300",
        "country": "TW"
    },
    "044A6C": {
        "oui_hex": "04-4A-6C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "38FB14": {
        "oui_hex": "38-FB-14",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F0E4A2": {
        "oui_hex": "F0-E4-A2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C5189": {
        "oui_hex": "7C-51-89",
        "organization": "SG Wireless Limited",
        "address_1": "RM 504 5/F Sun Fung Industrial Building 8-12 Ma Kok Street",
        "address_2": "Tsuen Wan    NA",
        "country": "HK"
    },
    "1063C8": {
        "oui_hex": "10-63-C8",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "582059": {
        "oui_hex": "58-20-59",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "90272B": {
        "oui_hex": "90-27-2B",
        "organization": "Algorab S.r.l.",
        "address_1": "Via Luigi Negrelli, 21/13",
        "address_2": "Lavis  TN  38015",
        "country": "IT"
    },
    "4CBCB4": {
        "oui_hex": "4C-BC-B4",
        "organization": "ABB SpA - DIN Rail",
        "address_1": "V.le dell'industria 18",
        "address_2": "Vittuone  Milan  20010",
        "country": "IT"
    },
    "94D505": {
        "oui_hex": "94-D5-05",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "74E1B6": {
        "oui_hex": "74-E1-B6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24A52C": {
        "oui_hex": "24-A5-2C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "482759": {
        "oui_hex": "48-27-59",
        "organization": "Levven Electronics Ltd.",
        "address_1": "9741 54 Ave NW",
        "address_2": "Edmonton  Alberta  T6E 5J4",
        "country": "CA"
    },
    "AC7713": {
        "oui_hex": "AC-77-13",
        "organization": "Honeywell Safety Products (Shanghai) Co.,Ltd",
        "address_1": "430 Li Bing Road Zhang Jiang Hi-Tech ParkPudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "08849D": {
        "oui_hex": "08-84-9D",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "90BDE6": {
        "oui_hex": "90-BD-E6",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "7th Floor, Hongye Building, No.1801 Hongmei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "18A4A9": {
        "oui_hex": "18-A4-A9",
        "organization": "Vanu Inc.",
        "address_1": "81 Hartwell Ave",
        "address_2": "Lexington  MA  02421",
        "country": "US"
    },
    "80E82C": {
        "oui_hex": "80-E8-2C",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "D4ADBD": {
        "oui_hex": "D4-AD-BD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2440AE": {
        "oui_hex": "24-40-AE",
        "organization": "NIIC Technology Co., Ltd.",
        "address_1": "Room 8218, Building 3#B, No. 268 Furong Road, Jingkai District",
        "address_2": "Hefei    230601",
        "country": "CN"
    },
    "F40E01": {
        "oui_hex": "F4-0E-01",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1495CE": {
        "oui_hex": "14-95-CE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "50DE06": {
        "oui_hex": "50-DE-06",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5CD135": {
        "oui_hex": "5C-D1-35",
        "organization": "Xtreme Power Systems",
        "address_1": "2440 Kiowa Blvd. N. #102",
        "address_2": "Lake Havasu City  AZ  86403",
        "country": "US"
    },
    "7869D4": {
        "oui_hex": "78-69-D4",
        "organization": "Shenyang Vibrotech Instruments Inc.",
        "address_1": "No 23-2 Yunfeng St. Tiexi Dist.",
        "address_2": "Shenyang   Liaoning  110021",
        "country": "CN"
    },
    "082697": {
        "oui_hex": "08-26-97",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "CCCCCC": {
        "oui_hex": "CC-CC-CC",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "CC660A": {
        "oui_hex": "CC-66-0A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FC1D43": {
        "oui_hex": "FC-1D-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64CB9F": {
        "oui_hex": "64-CB-9F",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "4CFBFE": {
        "oui_hex": "4C-FB-FE",
        "organization": "Sercomm Japan Corporation",
        "address_1": "8F, 3-1, YuanQu St., NanKang, Taipei 115, Taiwan",
        "address_2": "Taipei     115",
        "country": "TW"
    },
    "C0CBF1": {
        "oui_hex": "C0-CB-F1",
        "organization": "Mobiwire Mobiles (NingBo) Co., LTD",
        "address_1": "No.999 Dacheng East Road, Fenghua District, Ningbo City , Zhejiang Province, PRC",
        "address_2": "Ningbo  Zhejiang  315500",
        "country": "CN"
    },
    "FC7D6C": {
        "oui_hex": "FC-7D-6C",
        "organization": "HYESUNG TECHWIN Co., Ltd",
        "address_1": "#1509,545,Dunchon-daero, Jungwon-gu",
        "address_2": "Seongnam   Gyeonggi-do  13215",
        "country": "KR"
    },
    "E47E9A": {
        "oui_hex": "E4-7E-9A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "2C16BD": {
        "oui_hex": "2C-16-BD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "30A889": {
        "oui_hex": "30-A8-89",
        "organization": "DECIMATOR DESIGN",
        "address_1": "UNIT 5 / 11 PRECISION PLACE",
        "address_2": "VINEYARD  NSW  2765",
        "country": "AU"
    },
    "B4A2EB": {
        "oui_hex": "B4-A2-EB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "1CD5E2": {
        "oui_hex": "1C-D5-E2",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "0024E9": {
        "oui_hex": "00-24-E9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3Dong, Yeongtong-Gu",
        "address_2": "Suwon City  Geyonggi Do  443-742",
        "country": "KR"
    },
    "683B78": {
        "oui_hex": "68-3B-78",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F860F0": {
        "oui_hex": "F8-60-F0",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "5CA1E0": {
        "oui_hex": "5C-A1-E0",
        "organization": "EmbedWay Technologies",
        "address_1": "6F, Building 8, No 2388, Chenhang Rd, Shanghai",
        "address_2": "Shanghai    201114",
        "country": "CN"
    },
    "84D412": {
        "oui_hex": "84-D4-12",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "68AB09": {
        "oui_hex": "68-AB-09",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "F4CE36": {
        "oui_hex": "F4-CE-36",
        "organization": "Nordic Semiconductor ASA",
        "address_1": "Otto Nielsens veg 12",
        "address_2": "Trondheim    NO-7052",
        "country": "NO"
    },
    "B46077": {
        "oui_hex": "B4-60-77",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "00F620": {
        "oui_hex": "00-F6-20",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "F43328": {
        "oui_hex": "F4-33-28",
        "organization": "CIMCON Lighting Inc.",
        "address_1": "35 Crosby Drive",
        "address_2": "Bedford  MA  01730",
        "country": "US"
    },
    "7C942A": {
        "oui_hex": "7C-94-2A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1CB796": {
        "oui_hex": "1C-B7-96",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3847BC": {
        "oui_hex": "38-47-BC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "549209": {
        "oui_hex": "54-92-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "745909": {
        "oui_hex": "74-59-09",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5C5AC7": {
        "oui_hex": "5C-5A-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3CB74B": {
        "oui_hex": "3C-B7-4B",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "00EDB8": {
        "oui_hex": "00-ED-B8",
        "organization": "KYOCERA Corporation",
        "address_1": "30 Hoji",
        "address_2": "Kitami,  Hokkaido  099-1595",
        "country": "JP"
    },
    "9C99CD": {
        "oui_hex": "9C-99-CD",
        "organization": "Voippartners",
        "address_1": "Via di Passolombardo 35",
        "address_2": "Rome     00133",
        "country": "IT"
    },
    "C4C603": {
        "oui_hex": "C4-C6-03",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BCA13A": {
        "oui_hex": "BC-A1-3A",
        "organization": "SES-imagotag",
        "address_1": "St.-Peter-Gürtel 10b",
        "address_2": "Graz    8010",
        "country": "AT"
    },
    "2823F5": {
        "oui_hex": "28-23-F5",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhangtang Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "F010AB": {
        "oui_hex": "F0-10-AB",
        "organization": "China Mobile (Hangzhou) Information Technology Co., Ltd.",
        "address_1": "No. 1600 Yuhang Tong Road, Wuchang Street, Yuhang District",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "B4DC09": {
        "oui_hex": "B4-DC-09",
        "organization": "Guangzhou Dawei Communication Co.,Ltd",
        "address_1": "Zone A 906#, International Business Incubator, No.3 Juquan Road, Huangpu District",
        "address_2": "Guangzhou  Guangdong  510660",
        "country": "CN"
    },
    "98865D": {
        "oui_hex": "98-86-5D",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai",
        "address_2": "Shanghai     201206",
        "country": "CN"
    },
    "7CB59B": {
        "oui_hex": "7C-B5-9B",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "2C4F52": {
        "oui_hex": "2C-4F-52",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "68A03E": {
        "oui_hex": "68-A0-3E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "B8C385": {
        "oui_hex": "B8-C3-85",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan     523808",
        "country": "CN"
    },
    "4CE9E4": {
        "oui_hex": "4C-E9-E4",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "ACDB48": {
        "oui_hex": "AC-DB-48",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C80D32": {
        "oui_hex": "C8-0D-32",
        "organization": "Holoplot GmbH",
        "address_1": "Ringbahnstr. 12, Hof A2",
        "address_2": "Berlin    12099",
        "country": "DE"
    },
    "D05794": {
        "oui_hex": "D0-57-94",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "04D9F5": {
        "oui_hex": "04-D9-F5",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "B891C9": {
        "oui_hex": "B8-91-C9",
        "organization": "Handreamnet",
        "address_1": "#1203 Ace High-end Tower II, 61, Digital-ro 26-gil, Guro-Gu",
        "address_2": "Seoul    08389",
        "country": "KR"
    },
    "C8A776": {
        "oui_hex": "C8-A7-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A400E2": {
        "oui_hex": "A4-00-E2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B4C4FC": {
        "oui_hex": "B4-C4-FC",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C8D69D": {
        "oui_hex": "C8-D6-9D",
        "organization": "Arab International Optronics",
        "address_1": "El Salam St.",
        "address_2": "El Salam City   Cairo  11371",
        "country": "EG"
    },
    "405BD8": {
        "oui_hex": "40-5B-D8",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "54EC2F": {
        "oui_hex": "54-EC-2F",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2899C7": {
        "oui_hex": "28-99-C7",
        "organization": "LINDSAY BROADBAND INC",
        "address_1": "2035 2 FISHER DRIVE",
        "address_2": "PETERBOROUGH  Ontario  K9J 6X6",
        "country": "CA"
    },
    "FCBD67": {
        "oui_hex": "FC-BD-67",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00257E": {
        "oui_hex": "00-25-7E",
        "organization": "NEW POS TECHNOLOGY LIMITED",
        "address_1": "6FRM, 6F, China Economic Trade Building",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "F8AE27": {
        "oui_hex": "F8-AE-27",
        "organization": "John Deere Electronic Solutions",
        "address_1": "1441 44th St N",
        "address_2": "Fargo  ND  58102",
        "country": "US"
    },
    "7445CE": {
        "oui_hex": "74-45-CE",
        "organization": "CRESYN",
        "address_1": "8-22,Jamwon-dong",
        "address_2": "Seoul  Seocho-Gu  #137-902",
        "country": "KR"
    },
    "C4F7D5": {
        "oui_hex": "C4-F7-D5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "1C6499": {
        "oui_hex": "1C-64-99",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "10DC4A": {
        "oui_hex": "10-DC-4A",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "88EF16": {
        "oui_hex": "88-EF-16",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8CA96F": {
        "oui_hex": "8C-A9-6F",
        "organization": "D&M Holdings Inc.",
        "address_1": "D&M Building, 2-1 Nisshin-cho",
        "address_2": "Kawasaki-shi  Kanagawa    210-8569",
        "country": "JP"
    },
    "7CD661": {
        "oui_hex": "7C-D6-61",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "B0FD0B": {
        "oui_hex": "B0-FD-0B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "98B8BA": {
        "oui_hex": "98-B8-BA",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "0CE99A": {
        "oui_hex": "0C-E9-9A",
        "organization": "ATLS ALTEC",
        "address_1": "3 RUE DE LA GUIVERNONE ZI DU VERT GALANT",
        "address_2": "ST OUEN L AUMONE    95310",
        "country": "FR"
    },
    "4C11AE": {
        "oui_hex": "4C-11-AE",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "8C89FA": {
        "oui_hex": "8C-89-FA",
        "organization": "Zhejiang Hechuan Technology Co., Ltd.",
        "address_1": "No. 9, Fucai Road, Longyou Industrial Zone",
        "address_2": "Quzhou  Zhejiang  324000",
        "country": "CN"
    },
    "4CBC48": {
        "oui_hex": "4C-BC-48",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "80D04A": {
        "oui_hex": "80-D0-4A",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "48D875": {
        "oui_hex": "48-D8-75",
        "organization": "China TransInfo Technology Co., Ltd",
        "address_1": "Qianfang Building, Phase I, Zhongguancun Software Park, 8 Wangxi Road, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "D4789B": {
        "oui_hex": "D4-78-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "483FE9": {
        "oui_hex": "48-3F-E9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "143CC3": {
        "oui_hex": "14-3C-C3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A8E544": {
        "oui_hex": "A8-E5-44",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1820D5": {
        "oui_hex": "18-20-D5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3050FD": {
        "oui_hex": "30-50-FD",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0040BC": {
        "oui_hex": "00-40-BC",
        "organization": "ALGORITHMICS LTD.",
        "address_1": "3 DRAYTON PARK",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "004065": {
        "oui_hex": "00-40-65",
        "organization": "GTE SPACENET",
        "address_1": "1700 OLD MEADOW ROAD",
        "address_2": "MCLEAN  VA  22102",
        "country": "US"
    },
    "88E64B": {
        "oui_hex": "88-E6-4B",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D8D090": {
        "oui_hex": "D8-D0-90",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "50C4DD": {
        "oui_hex": "50-C4-DD",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "0084ED": {
        "oui_hex": "00-84-ED",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "E002A5": {
        "oui_hex": "E0-02-A5",
        "organization": "ABB Robotics",
        "address_1": "Hydrovägen 10",
        "address_2": "Västerås    721 68",
        "country": "SE"
    },
    "F42E7F": {
        "oui_hex": "F4-2E-7F",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B4CC04": {
        "oui_hex": "B4-CC-04",
        "organization": "Piranti",
        "address_1": "126, Beolmal-ro",
        "address_2": "Dongan-gu, Anyang-si, Gyeonggi-do    14057",
        "country": "KR"
    },
    "B8D526": {
        "oui_hex": "B8-D5-26",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "F0B968": {
        "oui_hex": "F0-B9-68",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "04E56E": {
        "oui_hex": "04-E5-6E",
        "organization": "THUB Co., ltd.",
        "address_1": "#607 2, Busandaehak-ro 63beon-gil, Geumjeong-gu",
        "address_2": "Busan    46241",
        "country": "KR"
    },
    "1C7F2C": {
        "oui_hex": "1C-7F-2C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "88BCC1": {
        "oui_hex": "88-BC-C1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1CBFCE": {
        "oui_hex": "1C-BF-CE",
        "organization": "Shenzhen Century Xinyang Technology Co., Ltd",
        "address_1": "3F, North Building, Bantian High-tech industrial Zone, No. 2 of Bell Road",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "F83002": {
        "oui_hex": "F8-30-02",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A8A159": {
        "oui_hex": "A8-A1-59",
        "organization": "ASRock Incorporation",
        "address_1": "2F., No. 37, Sec. 2, Jhongyang S. Rd., Beitou District,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "ECADE0": {
        "oui_hex": "EC-AD-E0",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "78DA07": {
        "oui_hex": "78-DA-07",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "44A61E": {
        "oui_hex": "44-A6-1E",
        "organization": "INGRAM MICRO SERVICES",
        "address_1": "100 CHEMIN DE BAILLOT",
        "address_2": "MONTAUBAN    82000",
        "country": "FR"
    },
    "38D2CA": {
        "oui_hex": "38-D2-CA",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District, Shenzhen Guangdong province",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "109E3A": {
        "oui_hex": "10-9E-3A",
        "organization": "Zhejiang Tmall Technology Co., Ltd.",
        "address_1": "Ali Center,No.3331 Keyuan South RD (Shenzhen bay), Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "904DC3": {
        "oui_hex": "90-4D-C3",
        "organization": "Flonidan A/S",
        "address_1": "Islandsvej 29",
        "address_2": "Horsens    8700",
        "country": "DK"
    },
    "000DF1": {
        "oui_hex": "00-0D-F1",
        "organization": "IONIX INC.",
        "address_1": "Ssangyong IT Twin Tower 604, 442-17, Sangdaewon-dong, Jungwon-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  462-120",
        "country": "KR"
    },
    "00077C": {
        "oui_hex": "00-07-7C",
        "organization": "Westermo Network Technologies AB",
        "address_1": "Stora Sundby",
        "address_2": "Sweden    SE-640 40",
        "country": "SE"
    },
    "8C426D": {
        "oui_hex": "8C-42-6D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "90F891": {
        "oui_hex": "90-F8-91",
        "organization": "Kaonmedia CO., LTD.",
        "address_1": "884-3, Seongnam-daero, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13517",
        "country": "KR"
    },
    "445D5E": {
        "oui_hex": "44-5D-5E",
        "organization": "SHENZHEN Coolkit Technology CO.,LTD",
        "address_1": "B09 2nd Floor, T6 ArtZone XiLi, Nanshan Dist",
        "address_2": "shenzhen  guangdong  518110",
        "country": "CN"
    },
    "50AD71": {
        "oui_hex": "50-AD-71",
        "organization": "Tessolve Semiconductor Private Limited",
        "address_1": "Plot No: 31, P2, Electronic City Phase II, Electronic City",
        "address_2": "Bengaluru  Karnataka  560100",
        "country": "IN"
    },
    "202AC5": {
        "oui_hex": "20-2A-C5",
        "organization": "Petite-En",
        "address_1": "1, Gwanak-ro, Gwanak-gu",
        "address_2": "Seoul    08826",
        "country": "KR"
    },
    "A8BF3C": {
        "oui_hex": "A8-BF-3C",
        "organization": "HDV Phoelectron Technology Limited",
        "address_1": " Room 1103, Hang Seng Mongkok Building, 677 Nathan Road,Mongkok",
        "address_2": "Kowloon  Hong Kong  518103",
        "country": "CN"
    },
    "D4F527": {
        "oui_hex": "D4-F5-27",
        "organization": "SIEMENS AG",
        "address_1": "Oestliche Rheinbrückenstraße 50",
        "address_2": "Karlsruhe  Baden-Württemberg  76181",
        "country": "DE"
    },
    "B8B2F8": {
        "oui_hex": "B8-B2-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98460A": {
        "oui_hex": "98-46-0A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B85D0A": {
        "oui_hex": "B8-5D-0A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7C9A1D": {
        "oui_hex": "7C-9A-1D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "103025": {
        "oui_hex": "10-30-25",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70ACD7": {
        "oui_hex": "70-AC-D7",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "5462E2": {
        "oui_hex": "54-62-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "149D99": {
        "oui_hex": "14-9D-99",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "147BAC": {
        "oui_hex": "14-7B-AC",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "906D05": {
        "oui_hex": "90-6D-05",
        "organization": "BXB ELECTRONICS CO., LTD",
        "address_1": "6F.-1, NO.288-5, Xinya Rd., Qianzhen Dist.",
        "address_2": "Kaohsiung    80673",
        "country": "TW"
    },
    "D4BBC8": {
        "oui_hex": "D4-BB-C8",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "489507": {
        "oui_hex": "48-95-07",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "24BF74": {
        "oui_hex": "24-BF-74",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "CCDC55": {
        "oui_hex": "CC-DC-55",
        "organization": "Dragonchip Limited",
        "address_1": "Room 601-2, 6/F, IC Development Centre, No. 6 Science Park West Avenue, Hong Kong Science Park, Shatin, N.T.",
        "address_2": "Hong Kong    NA",
        "country": "HK"
    },
    "28FFB2": {
        "oui_hex": "28-FF-B2",
        "organization": "Toshiba Corp.",
        "address_1": "1-1 Shibaura 1-Chome, Minato-Ku",
        "address_2": "Tokyo    105-8001",
        "country": "JP"
    },
    "1C60D2": {
        "oui_hex": "1C-60-D2",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "F4B5AA": {
        "oui_hex": "F4-B5-AA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "E8ACAD": {
        "oui_hex": "E8-AC-AD",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0836C9": {
        "oui_hex": "08-36-C9",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "745BC5": {
        "oui_hex": "74-5B-C5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9440C9": {
        "oui_hex": "94-40-C9",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "A041A7": {
        "oui_hex": "A0-41-A7",
        "organization": "NL Ministry of Defense",
        "address_1": "PO Box 10000",
        "address_2": "  Noord Holland  1780 CA Den Helder",
        "country": "NL"
    },
    "E446DA": {
        "oui_hex": "E4-46-DA",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "1C12B0": {
        "oui_hex": "1C-12-B0",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "4CC8A1": {
        "oui_hex": "4C-C8-A1",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "4CBC98": {
        "oui_hex": "4C-BC-98",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2CF432": {
        "oui_hex": "2C-F4-32",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "647366": {
        "oui_hex": "64-73-66",
        "organization": "Shenzhen Siera Technology Ltd",
        "address_1": "Room 2039, Shenhai Building, Wanzhong Village, Bulong Road, Minzhi, Longhua district,  City: Shenzhen",
        "address_2": "Shenzhen  Guangdong  518131",
        "country": "CN"
    },
    "041EFA": {
        "oui_hex": "04-1E-FA",
        "organization": "BISSELL Homecare, Inc.",
        "address_1": "2345 Walker Ave NW",
        "address_2": "Grand Rapids  MI  49544",
        "country": "US"
    },
    "D85575": {
        "oui_hex": "D8-55-75",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D411A3": {
        "oui_hex": "D4-11-A3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "04BA8D": {
        "oui_hex": "04-BA-8D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "744D28": {
        "oui_hex": "74-4D-28",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "00A085": {
        "oui_hex": "00-A0-85",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "E05A9F": {
        "oui_hex": "E0-5A-9F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8C5AF8": {
        "oui_hex": "8C-5A-F8",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "D45800": {
        "oui_hex": "D4-58-00",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "90842B": {
        "oui_hex": "90-84-2B",
        "organization": "LEGO System A/S",
        "address_1": "Aastvej 1",
        "address_2": "Billund    DK-7190",
        "country": "DK"
    },
    "00267E": {
        "oui_hex": "00-26-7E",
        "organization": "PARROT SA",
        "address_1": "174 Quai de Jemmapes",
        "address_2": "Paris    75010",
        "country": "FR"
    },
    "2C557C": {
        "oui_hex": "2C-55-7C",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "F4BCDA": {
        "oui_hex": "F4-BC-DA",
        "organization": "Shenzhen Jingxun Software Telecommunication Technology Co.,Ltd",
        "address_1": "3/F,A5 Building Zhiyuan Community No.1001,Xueyuan Road Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "000915": {
        "oui_hex": "00-09-15",
        "organization": "CAS Corp.",
        "address_1": "#19, Ganap-Ri",
        "address_2": "Yangju-Gun  Kyunggi-Do  482-841",
        "country": "KR"
    },
    "58D9C3": {
        "oui_hex": "58-D9-C3",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "2C73A0": {
        "oui_hex": "2C-73-A0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "443E07": {
        "oui_hex": "44-3E-07",
        "organization": "Electrolux",
        "address_1": "Corso Lino Zanussi 24",
        "address_2": "Porcia  PORDENONE  33080",
        "country": "IT"
    },
    "8485E6": {
        "oui_hex": "84-85-E6",
        "organization": "Guangdong Asano Technology CO.,Ltd.",
        "address_1": "Changsheng Road, Songxia Industrial Park, Songgang, Shishan Town, Nanhai",
        "address_2": " Foshan   Guangdong, China.  528200",
        "country": "CN"
    },
    "3C8375": {
        "oui_hex": "3C-83-75",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "000AA8": {
        "oui_hex": "00-0A-A8",
        "organization": "ePipe Pty. Ltd.",
        "address_1": "P.O. Box 1428",
        "address_2": "Brisbane  Queensland  4066",
        "country": "AU"
    },
    "0029C2": {
        "oui_hex": "00-29-C2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "187C0B": {
        "oui_hex": "18-7C-0B",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D47B35": {
        "oui_hex": "D4-7B-35",
        "organization": "NEO Monitors AS",
        "address_1": "PoBox 384",
        "address_2": "Loerenskog  Loerenskog  1471",
        "country": "NO"
    },
    "000878": {
        "oui_hex": "00-08-78",
        "organization": "Benchmark Storage Innovations",
        "address_1": "3122 Sterling Circle",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "6CF37F": {
        "oui_hex": "6C-F3-7F",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "140708": {
        "oui_hex": "14-07-08",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "78A7EB": {
        "oui_hex": "78-A7-EB",
        "organization": "1MORE",
        "address_1": "TianliaoBuilding F14",
        "address_2": "New Materials Industrial Park,Xueyuan Blvd  Shenzhen, Nanshan District  518005",
        "country": "CN"
    },
    "485D36": {
        "oui_hex": "48-5D-36",
        "organization": "Verizon",
        "address_1": "One Verizon Way",
        "address_2": "Basking Ridge  NJ  07030",
        "country": "US"
    },
    "20C047": {
        "oui_hex": "20-C0-47",
        "organization": "Verizon",
        "address_1": "One Verizon Way",
        "address_2": "Basking Ridge    07030",
        "country": "US"
    },
    "346B46": {
        "oui_hex": "34-6B-46",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "7C604A": {
        "oui_hex": "7C-60-4A",
        "organization": "Avelon",
        "address_1": "Bändliweg 20",
        "address_2": "Zurich    8048",
        "country": "CH"
    },
    "186472": {
        "oui_hex": "18-64-72",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "84D47E": {
        "oui_hex": "84-D4-7E",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "24DEC6": {
        "oui_hex": "24-DE-C6",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0017A0": {
        "oui_hex": "00-17-A0",
        "organization": "RoboTech srl",
        "address_1": "Via Mazzini 82",
        "address_2": "Sarzana (SP)    I-19038",
        "country": "IT"
    },
    "103D0A": {
        "oui_hex": "10-3D-0A",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "942790": {
        "oui_hex": "94-27-90",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "A41791": {
        "oui_hex": "A4-17-91",
        "organization": "Shenzhen Decnta Technology Co.,LTD.",
        "address_1": "F13,No.02,Building Shangqi,Nanhaidadao 4050 Nanshan District,Shenzhen,P.R.China",
        "address_2": "shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "34DAB7": {
        "oui_hex": "34-DA-B7",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "109C70": {
        "oui_hex": "10-9C-70",
        "organization": "Prusa Research s.r.o.",
        "address_1": "Partyzanska 188/7a",
        "address_2": "Prague    17000",
        "country": "CZ"
    },
    "E84C56": {
        "oui_hex": "E8-4C-56",
        "organization": "INTERCEPT SERVICES LIMITED",
        "address_1": "Bates Mill, Colne Road",
        "address_2": "Huddersfield  North Yorkshire  HD1 3AG",
        "country": "GB"
    },
    "A41908": {
        "oui_hex": "A4-19-08",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "38AFD0": {
        "oui_hex": "38-AF-D0",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "80D336": {
        "oui_hex": "80-D3-36",
        "organization": "CERN",
        "address_1": "CH-1211",
        "address_2": "GENEVE  SUISSE/SWITZ  023",
        "country": "CH"
    },
    "64255E": {
        "oui_hex": "64-25-5E",
        "organization": "Observint Technologies, Inc.",
        "address_1": "11000 N Mopac Expressway Suite 300",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "90940A": {
        "oui_hex": "90-94-0A",
        "organization": "Analog Devices, Inc",
        "address_1": "Unit 2200, Airport Business Park, Kinsale Road",
        "address_2": "Cork    T12 X36X",
        "country": "IE"
    },
    "40B076": {
        "oui_hex": "40-B0-76",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "D43D39": {
        "oui_hex": "D4-3D-39",
        "organization": "Dialog Semiconductor",
        "address_1": "B-7F, SiliconPark, 35, Pangyo-ro 255beon-gil, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13486",
        "country": "KR"
    },
    "0014A5": {
        "oui_hex": "00-14-A5",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road",
        "address_2": "Hukou, Hsinchu    303",
        "country": "TW"
    },
    "C0B5D7": {
        "oui_hex": "C0-B5-D7",
        "organization": "CHONGQING FUGUI ELECTRONICS CO.,LTD.",
        "address_1": "Building D21,No.1, East Zone 1st Road,Xiyong Town,Shapingba District",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D4AD71": {
        "oui_hex": "D4-AD-71",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "702B1D": {
        "oui_hex": "70-2B-1D",
        "organization": "E-Domus International Limited",
        "address_1": "1st Floor",
        "address_2": "London    W1W 7BL",
        "country": "GB"
    },
    "F085C1": {
        "oui_hex": "F0-85-C1",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A,6/F,Baotian Rd3,Xixiang Town,Baoan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "60380E": {
        "oui_hex": "60-38-0E",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi",
        "address_2": "Soma-city  Fukushima  976-8501",
        "country": "JP"
    },
    "FC62B9": {
        "oui_hex": "FC-62-B9",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "kakuda-city  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "0002C7": {
        "oui_hex": "00-02-C7",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi, Sama-City,",
        "address_2": "Sama    00000",
        "country": "JP"
    },
    "001E3D": {
        "oui_hex": "00-1E-3D",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "1-2-1, Okinouchi,",
        "address_2": "Soma-city,  Fukushima-pref.,  976-8501",
        "country": "JP"
    },
    "28A183": {
        "oui_hex": "28-A1-83",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "4CDD7D": {
        "oui_hex": "4C-DD-7D",
        "organization": "LHP Telematics LLC",
        "address_1": "17406 Tiller Ct. STE 100",
        "address_2": "westfield  IN  46074",
        "country": "US"
    },
    "48F07B": {
        "oui_hex": "48-F0-7B",
        "organization": "ALPS ELECTRIC CO., LTD.",
        "address_1": "6-1",
        "address_2": "Kakuda  Miyagi-Pref  981-1595",
        "country": "JP"
    },
    "B8BC5B": {
        "oui_hex": "B8-BC-5B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "108EBA": {
        "oui_hex": "10-8E-BA",
        "organization": "Molekule",
        "address_1": "1184 Harrison Street",
        "address_2": "San Francisco    94103",
        "country": "US"
    },
    "4C218C": {
        "oui_hex": "4C-21-8C",
        "organization": "Panasonic India Private limited",
        "address_1": "12th floor, Ambience tower, Ambience Island",
        "address_2": "Gurgaon  Haryana  122002",
        "country": "IN"
    },
    "2C4E7D": {
        "oui_hex": "2C-4E-7D",
        "organization": "Chunghua Intelligent Network Equipment Inc.",
        "address_1": "2F-3, No.5, Sec. 3, New Taipei Blvd.,, XinZhung Dist,",
        "address_2": "New Taipei City  選擇州  242",
        "country": "TW"
    },
    "A4F465": {
        "oui_hex": "A4-F4-65",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "4C917A": {
        "oui_hex": "4C-91-7A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F48CEB": {
        "oui_hex": "F4-8C-EB",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "743A65": {
        "oui_hex": "74-3A-65",
        "organization": "NEC Corporation",
        "address_1": "7-1, Shiba 5-chome, Minato-ku",
        "address_2": "Tokyo    108-8001",
        "country": "JP"
    },
    "00255C": {
        "oui_hex": "00-25-5C",
        "organization": "NEC Corporation",
        "address_1": "1753, Shimonumabe, Nakahara-Ku, Kawasaki",
        "address_2": "Kanagawa    211-8666",
        "country": "JP"
    },
    "684F64": {
        "oui_hex": "68-4F-64",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "CC70ED": {
        "oui_hex": "CC-70-ED",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "907E30": {
        "oui_hex": "90-7E-30",
        "organization": "LARS",
        "address_1": "Swierkowa 14",
        "address_2": "Niepruszewo    64-320",
        "country": "PL"
    },
    "84EB3E": {
        "oui_hex": "84-EB-3E",
        "organization": "Vivint Smart Home",
        "address_1": "4931 N. 300 W.",
        "address_2": "Provo  UT  84604",
        "country": "US"
    },
    "00A0D5": {
        "oui_hex": "00-A0-D5",
        "organization": "Sierra Wireless",
        "address_1": "13811 Wireless Way",
        "address_2": "Richmond  RICHMOND B.C.  V6V 3A4",
        "country": "CA"
    },
    "18BB26": {
        "oui_hex": "18-BB-26",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "18B905": {
        "oui_hex": "18-B9-05",
        "organization": "Hong Kong Bouffalo Lab Limited",
        "address_1": "RM 1903, 19/F Lee Garden One 33 Hysan Avenue, Causeway Bay",
        "address_2": "HongKong    999077",
        "country": "HK"
    },
    "ECF0FE": {
        "oui_hex": "EC-F0-FE",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "94A40C": {
        "oui_hex": "94-A4-0C",
        "organization": "Diehl Metering GmbH",
        "address_1": "Industriestrasse 13",
        "address_2": "Ansbach    91522",
        "country": "DE"
    },
    "70B317": {
        "oui_hex": "70-B3-17",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B00247": {
        "oui_hex": "B0-02-47",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "3F.,No.15-1 Zhonghua Road,Hsinchu Industrial Park, Hukou,Hsinchu",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "BCE796": {
        "oui_hex": "BC-E7-96",
        "organization": "Wireless CCTV Ltd",
        "address_1": "charles Babbage house",
        "address_2": "Rochdale  Greater Manchester  ol164nw",
        "country": "GB"
    },
    "948FCF": {
        "oui_hex": "94-8F-CF",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A8F5DD": {
        "oui_hex": "A8-F5-DD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "44D3AD": {
        "oui_hex": "44-D3-AD",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F, H-3 Building, Qiao Cheng Eastern Industrial Park, Overseas Chinese Town, Shenzhen",
        "address_2": "Shenzhen   guangdong  518053",
        "country": "CN"
    },
    "9C8275": {
        "oui_hex": "9C-82-75",
        "organization": "Yichip Microelectronics (Hangzhou) Co.,Ltd",
        "address_1": "Room 401, Building 15, No.498 Guoshoujing Road, Pudong Software Park",
        "address_2": "Shanghai    200120",
        "country": "CN"
    },
    "5CCBCA": {
        "oui_hex": "5C-CB-CA",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building, Star-net Science Plaza, Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "28E98E": {
        "oui_hex": "28-E9-8E",
        "organization": "Mitsubishi Electric Corporation",
        "address_1": "2-7-3 Marunouchi Chiyoda-ku",
        "address_2": "Tokyo    100-8310",
        "country": "JP"
    },
    "34F8E7": {
        "oui_hex": "34-F8-E7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B0907E": {
        "oui_hex": "B0-90-7E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2C7360": {
        "oui_hex": "2C-73-60",
        "organization": "Earda Technologies co Ltd",
        "address_1": "Block A,Lianfeng Creative Park, #2 Jisheng Rd., Nansha District",
        "address_2": "Guangzhou  Guangdong  511455",
        "country": "CN"
    },
    "508CF5": {
        "oui_hex": "50-8C-F5",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "1C549E": {
        "oui_hex": "1C-54-9E",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "E4CA12": {
        "oui_hex": "E4-CA-12",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D49E05": {
        "oui_hex": "D4-9E-05",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "585FF6": {
        "oui_hex": "58-5F-F6",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "40B30E": {
        "oui_hex": "40-B3-0E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "04CE7E": {
        "oui_hex": "04-CE-7E",
        "organization": "NXP France Semiconductors France",
        "address_1": "Parc les Algorithmes,Saint Aubin",
        "address_2": "Gif sur Yvette    91193",
        "country": "FR"
    },
    "C09AD0": {
        "oui_hex": "C0-9A-D0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "94B01F": {
        "oui_hex": "94-B0-1F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98CC4D": {
        "oui_hex": "98-CC-4D",
        "organization": "Shenzhen mantunsci co., LTD",
        "address_1": "3 floor, 3 environmental protection industrial park, Nanshan District",
        "address_2": "Shenzhen   Guangdong  518000",
        "country": "CN"
    },
    "C01B23": {
        "oui_hex": "C0-1B-23",
        "organization": "SICHUAN TIANYI COMHEART TELECOM CO.,LTD",
        "address_1": "NO.198 FIRST SECTION,SNOW MOUNTAIN AVENUE, JINYUAN TOWN, DAYI COUNTY,",
        "address_2": "CHENGDU  SICHUAN  611330",
        "country": "CN"
    },
    "B8C74A": {
        "oui_hex": "B8-C7-4A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "D8CE3A": {
        "oui_hex": "D8-CE-3A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "102C6B": {
        "oui_hex": "10-2C-6B",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "3F.,No.15-1 Zhonghua Road,Hsinchu Industrial Park, Hukou,Hsinchu, Taiwan (R.O.C.)",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "7485C4": {
        "oui_hex": "74-85-C4",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "94F6D6": {
        "oui_hex": "94-F6-D6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F82D7C": {
        "oui_hex": "F8-2D-7C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0BAE4": {
        "oui_hex": "D0-BA-E4",
        "organization": "Shanghai MXCHIP Information Technology Co., Ltd.",
        "address_1": "Room 811,Tongpu Building",
        "address_2": "Shanghai  Shanghai  200333",
        "country": "CN"
    },
    "48D35D": {
        "oui_hex": "48-D3-5D",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "80FBF0": {
        "oui_hex": "80-FB-F0",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "7th Floor, Hongye Building, No.1801 Hongmei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "C0132B": {
        "oui_hex": "C0-13-2B",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "0CB4A4": {
        "oui_hex": "0C-B4-A4",
        "organization": "Xintai Automobile Intelligent Network Technology",
        "address_1": "Room3703E Changfu Jinmao Building，Shihua Road",
        "address_2": "Futian Duty Free Zone，Fubao Street，Futian District  Shenzhen City  518000",
        "country": "CN"
    },
    "90633B": {
        "oui_hex": "90-63-3B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "FCAAB6": {
        "oui_hex": "FC-AA-B6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C82E47": {
        "oui_hex": "C8-2E-47",
        "organization": "Suzhou SmartChip Semiconductor Co., LTD",
        "address_1": "9A,Science Plaza,1355 JinJiHu Avenue, Suzhou Industrial Park,",
        "address_2": "Suzhou   Jiangsu  215021",
        "country": "CN"
    },
    "C02250": {
        "oui_hex": "C0-22-50",
        "organization": "Koss Corporation",
        "address_1": "4129 N. Port Washington Ave.",
        "address_2": "Milwaukee  WI  53212",
        "country": "US"
    },
    "A0B549": {
        "oui_hex": "A0-B5-49",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "001F5A": {
        "oui_hex": "00-1F-5A",
        "organization": "Beckwith Electric Co.",
        "address_1": "6190 118th Ave No",
        "address_2": "Largo  Florida  33773",
        "country": "US"
    },
    "985D82": {
        "oui_hex": "98-5D-82",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "2453BF": {
        "oui_hex": "24-53-BF",
        "organization": "Enernet",
        "address_1": "1007 B-dong, Hyundai Knowledge Industry Center, 70 Dusan-ro, Geumcheon-gu, Seoul, KOREA",
        "address_2": "SEOUL    08584",
        "country": "KR"
    },
    "043385": {
        "oui_hex": "04-33-85",
        "organization": "Nanchang BlackShark Co.,Ltd.",
        "address_1": "Room 319, Jiaoqiao Town Office Building, Economic and Technical development zone, Nanchang City, Jiangxi Province.",
        "address_2": "Nanchang    330013",
        "country": "CN"
    },
    "84E5D8": {
        "oui_hex": "84-E5-D8",
        "organization": "Guangdong UNIPOE IoT Technology Co.,Ltd.",
        "address_1": "11th Fl., BLDG. B1, Guangda WE Valley, Songshan Lake District",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A8BC9C": {
        "oui_hex": "A8-BC-9C",
        "organization": "Cloud Light Technology Limited",
        "address_1": "3/F, 6 Science Park East Avenue Hong Kong Science Park Shatin, N.T., Hong Kong",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "A89042": {
        "oui_hex": "A8-90-42",
        "organization": "Beijing Wanwei Intelligent Technology Co., Ltd.",
        "address_1": "Room 616, Section 1, Cuicing, No. 1 Shanyuan Street, Haidian District",
        "address_2": "Beijing  Beijing  100000",
        "country": "CN"
    },
    "18BE92": {
        "oui_hex": "18-BE-92",
        "organization": "Delta Networks, Inc.",
        "address_1": "256 Yang Guang Street, Neihu",
        "address_2": "Taipei  Taiwan  11491",
        "country": "TW"
    },
    "90C54A": {
        "oui_hex": "90-C5-4A",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "BC7596": {
        "oui_hex": "BC-75-96",
        "organization": "Beijing Broadwit Technology Co., Ltd.",
        "address_1": "Beijing Changping District Beijing International Information Industry Base Jizhida Building 3rd Floor Southeast",
        "address_2": "Beijing  Beijing  10000",
        "country": "CN"
    },
    "1C34DA": {
        "oui_hex": "1C-34-DA",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "2CA02F": {
        "oui_hex": "2C-A0-2F",
        "organization": "Veroguard Systems Pty Ltd",
        "address_1": "PO Box 5003",
        "address_2": "Clayton  VIC  3168",
        "country": "AU"
    },
    "6C5C3D": {
        "oui_hex": "6C-5C-3D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "782327": {
        "oui_hex": "78-23-27",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "DCF756": {
        "oui_hex": "DC-F7-56",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "68A47D": {
        "oui_hex": "68-A4-7D",
        "organization": "Sun Cupid Technology (HK) LTD",
        "address_1": "16/F, CEO Tower, 77 Wing Hong Street, Kowloon",
        "address_2": "Hong Kong    00000",
        "country": "HK"
    },
    "184B0D": {
        "oui_hex": "18-4B-0D",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "D41243": {
        "oui_hex": "D4-12-43",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "48A6B8": {
        "oui_hex": "48-A6-B8",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "B87826": {
        "oui_hex": "B8-78-26",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "DCCBA8": {
        "oui_hex": "DC-CB-A8",
        "organization": "Explora Technologies Inc",
        "address_1": "360, Franquet Street",
        "address_2": "Quebec    G1P 4N3",
        "country": "CA"
    },
    "C07878": {
        "oui_hex": "C0-78-78",
        "organization": "FLEXTRONICS MANUFACTURING(ZHUHAI)CO.,LTD.",
        "address_1": "Xin Qing Science & Technology Industrial Park,Jin An Town,Doumen ,Zhuhai,Guangdong,PRC",
        "address_2": "Zhuhai  Guangdong  519180",
        "country": "CN"
    },
    "E4B97A": {
        "oui_hex": "E4-B9-7A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "34DAC1": {
        "oui_hex": "34-DA-C1",
        "organization": "SAE Technologies Development(Dongguan) Co., Ltd.",
        "address_1": "Winnerway Industrial Area,Nancheng",
        "address_2": "Dongguan City  Guangdong Province  523087",
        "country": "CN"
    },
    "705DCC": {
        "oui_hex": "70-5D-CC",
        "organization": "EFM Networks",
        "address_1": "6F, Benposra II 1197-1 Bojeong Giheung Gu",
        "address_2": "Yong In  Kyunggi do  446913",
        "country": "KR"
    },
    "D092FA": {
        "oui_hex": "D0-92-FA",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "E85AD1": {
        "oui_hex": "E8-5A-D1",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "A823FE": {
        "oui_hex": "A8-23-FE",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "E05D5C": {
        "oui_hex": "E0-5D-5C",
        "organization": "Oy Everon Ab",
        "address_1": "Teräskatu 8",
        "address_2": "Turku    20520",
        "country": "FI"
    },
    "688F2E": {
        "oui_hex": "68-8F-2E",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "E046E5": {
        "oui_hex": "E0-46-E5",
        "organization": "Gosuncn Technology Group Co., Ltd.",
        "address_1": "6F, 2819 KaiChuang Blvd., Science Town, Huangpu District",
        "address_2": "Guangzhou City   Guangdong  510530",
        "country": "CN"
    },
    "1C599B": {
        "oui_hex": "1C-59-9B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D4BD1E": {
        "oui_hex": "D4-BD-1E",
        "organization": "5VT Technologies,Taiwan LTd.",
        "address_1": "6F,No.19-9,SanChong Rd.,Nangang Dist,",
        "address_2": "Taipei    11501",
        "country": "TW"
    },
    "BC9B68": {
        "oui_hex": "BC-9B-68",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "CCD4A1": {
        "oui_hex": "CC-D4-A1",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "08BA5F": {
        "oui_hex": "08-BA-5F",
        "organization": "Qingdao Hisense Electronics Co.,Ltd.",
        "address_1": "Qianwangang Roard 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "10DFFC": {
        "oui_hex": "10-DF-FC",
        "organization": "Siemens AG",
        "address_1": "Siemensstrasse 10",
        "address_2": "Regensburg    93055",
        "country": "DE"
    },
    "847F3D": {
        "oui_hex": "84-7F-3D",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "C4FDE6": {
        "oui_hex": "C4-FD-E6",
        "organization": "DRTECH",
        "address_1": "29, Dunchon-daero 541beon-gil, Jungwon-gu",
        "address_2": "Seongnam  Gyeonggi-do  13216",
        "country": "KR"
    },
    "CC988B": {
        "oui_hex": "CC-98-8B",
        "organization": "SONY Visual Products Inc.",
        "address_1": "2-10-1 Osaki",
        "address_2": "Shinagawa-ku  Tokyo  141-8610",
        "country": "JP"
    },
    "30E3D6": {
        "oui_hex": "30-E3-D6",
        "organization": "Spotify USA Inc.",
        "address_1": "45 West 18th Street",
        "address_2": "New York  NY  10011",
        "country": "US"
    },
    "9CA525": {
        "oui_hex": "9C-A5-25",
        "organization": "Shandong USR IOT Technology Limited",
        "address_1": "Floor 11,Building 1,No.1166 Xinluo  Street,Gaoxin District,Jinan,Shandong,250101,China",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "E0456D": {
        "oui_hex": "E0-45-6D",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "283926": {
        "oui_hex": "28-39-26",
        "organization": "CyberTAN Technology Inc.",
        "address_1": "99 Park Ave III, Hsinchu Science Park",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "8CFCA0": {
        "oui_hex": "8C-FC-A0",
        "organization": "Shenzhen Smart Device Technology Co., LTD.",
        "address_1": "SSMEC Building,Gao Xin Nan First Avenue Hi-Tech Park South,Nanshan",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "1C427D": {
        "oui_hex": "1C-42-7D",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "806933": {
        "oui_hex": "80-69-33",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "BC26C7": {
        "oui_hex": "BC-26-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BC5EA1": {
        "oui_hex": "BC-5E-A1",
        "organization": "PsiKick, Inc.",
        "address_1": "2348 Walsh Ave",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "944F4C": {
        "oui_hex": "94-4F-4C",
        "organization": "Sound United LLC",
        "address_1": "One Viper Way",
        "address_2": "Vista  CA  92081",
        "country": "US"
    },
    "981888": {
        "oui_hex": "98-18-88",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "18810E": {
        "oui_hex": "18-81-0E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "608C4A": {
        "oui_hex": "60-8C-4A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "74B587": {
        "oui_hex": "74-B5-87",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCB6D8": {
        "oui_hex": "FC-B6-D8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3C6A2C": {
        "oui_hex": "3C-6A-2C",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "241B7A": {
        "oui_hex": "24-1B-7A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8CFE57": {
        "oui_hex": "8C-FE-57",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0A600": {
        "oui_hex": "C0-A6-00",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "18E829": {
        "oui_hex": "18-E8-29",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "E0C286": {
        "oui_hex": "E0-C2-86",
        "organization": "Aisai Communication Technology Co., Ltd.",
        "address_1": "Room 2610 Asia Trade Centre,",
        "address_2": "Kwai Chung  N.T.  852",
        "country": "HK"
    },
    "7405A5": {
        "oui_hex": "74-05-A5",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "286DCD": {
        "oui_hex": "28-6D-CD",
        "organization": "Beijing Winner Microelectronics Co.,Ltd.",
        "address_1": "Floor 18, YinDu Building, No.67 FuCheng Road, HaiDian District",
        "address_2": "Beijing    100142",
        "country": "CN"
    },
    "541031": {
        "oui_hex": "54-10-31",
        "organization": "SMARTO",
        "address_1": "25 QUAI GALLIENI",
        "address_2": "SURESNES  HAUT DE SEINE  92150",
        "country": "FR"
    },
    "44A466": {
        "oui_hex": "44-A4-66",
        "organization": "GROUPE LDLC",
        "address_1": "Groupe LDLC - 2 rue des Erables",
        "address_2": "LIMONEST  Rhone  69760",
        "country": "FR"
    },
    "D80D17": {
        "oui_hex": "D8-0D-17",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "18C2BF": {
        "oui_hex": "18-C2-BF",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "E81CBA": {
        "oui_hex": "E8-1C-BA",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  null  94086",
        "country": "US"
    },
    "F0B014": {
        "oui_hex": "F0-B0-14",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "1889A0": {
        "oui_hex": "18-89-A0",
        "organization": "Wuhan Funshion Online Technologies Co.,Ltd",
        "address_1": "5th Floor,Financial Port Building A9,No.77 Optical Valley Avenue, East Lake High-Tech Development Zone, Wuhan",
        "address_2": "Wuhan  CN/Hubei  430000",
        "country": "CN"
    },
    "0C2A86": {
        "oui_hex": "0C-2A-86",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "FC61E9": {
        "oui_hex": "FC-61-E9",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "405662": {
        "oui_hex": "40-56-62",
        "organization": "GuoTengShengHua Electronics LTD.",
        "address_1": "1st floor,No. 15 of Tech North 2nd Road,Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "E4DB6D": {
        "oui_hex": "E4-DB-6D",
        "organization": "Beijing Xiaomi Electronics Co., Ltd.",
        "address_1": "Building C, QingHe ShunShiJiaYe Technology Park, #66 ZhuFang Rd, HaiDian District",
        "address_2": "Beijing  Beijing  10085",
        "country": "CN"
    },
    "00A0D1": {
        "oui_hex": "00-A0-D1",
        "organization": "INVENTEC CORPORATION",
        "address_1": "INVENTEC BUILDING",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0018CC": {
        "oui_hex": "00-18-CC",
        "organization": "AXIOHM SAS",
        "address_1": "1 RUE D'ARCUEIL",
        "address_2": "MONTROUGE    92120",
        "country": "FR"
    },
    "001827": {
        "oui_hex": "00-18-27",
        "organization": "NEC UNIFIED SOLUTIONS NEDERLAND B.V.",
        "address_1": "ANTON PHILIPSWEG 1",
        "address_2": "HILVERSUM  NH  1223KZ",
        "country": "NL"
    },
    "009004": {
        "oui_hex": "00-90-04",
        "organization": "3COM EUROPE LTD",
        "address_1": "3COM CENTRE, BOUNDARY WAY",
        "address_2": "HERTS.  HP2 7YU    00000",
        "country": "GB"
    },
    "00068C": {
        "oui_hex": "00-06-8C",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "02608C": {
        "oui_hex": "02-60-8C",
        "organization": "3COM",
        "address_1": "5400 BAYFRONT PLAZA",
        "address_2": "SANTA CLARA  CA  95052",
        "country": "US"
    },
    "00D0D8": {
        "oui_hex": "00-D0-D8",
        "organization": "3COM",
        "address_1": "2133 LEGHORN STREET",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "18937F": {
        "oui_hex": "18-93-7F",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "A43523": {
        "oui_hex": "A4-35-23",
        "organization": "Guangdong Donyan Network Technologies Co.,Ltd.",
        "address_1": "No.6,Kejizhong Road,Chuangye Building,Hi-tech Zone",
        "address_2": "Shantou  Guangdong  515000",
        "country": "CN"
    },
    "B4A94F": {
        "oui_hex": "B4-A9-4F",
        "organization": "MERCURY CORPORATION",
        "address_1": "90, Gajaeul-ro, Seo-gu",
        "address_2": "INCHEON    22830",
        "country": "KR"
    },
    "803AF4": {
        "oui_hex": "80-3A-F4",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "48A0F8": {
        "oui_hex": "48-A0-F8",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "F85E3C": {
        "oui_hex": "F8-5E-3C",
        "organization": "SHENZHEN ZHIBOTONG ELECTRONICS CO.,LTD",
        "address_1": "4F,Bldg A2,Hedian Industrial Park,NO.8 Shijing Rd,Guanlan,Longhua District,ShenZhen,China",
        "address_2": "shengzhen    518110",
        "country": "CN"
    },
    "283E76": {
        "oui_hex": "28-3E-76",
        "organization": "Common Networks",
        "address_1": "1390 Market St. Suite 820",
        "address_2": "San Francisco  CA  94102",
        "country": "US"
    },
    "DC3979": {
        "oui_hex": "DC-39-79",
        "organization": "Cisco Systems, Inc",
        "address_1": "280 Hope Street",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "58D56E": {
        "oui_hex": "58-D5-6E",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "0C5331": {
        "oui_hex": "0C-53-31",
        "organization": "ETH Zurich",
        "address_1": "Dept. Computer Science, Universitätstr. 6",
        "address_2": "Zurich  ZH  8092",
        "country": "CH"
    },
    "DC9088": {
        "oui_hex": "DC-90-88",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "54812D": {
        "oui_hex": "54-81-2D",
        "organization": "PAX Computer Technology(Shenzhen) Ltd.",
        "address_1": "4/F, No.3 Building, Software Park, Second Central Science-Tech Road, High-Tech",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "0C9A42": {
        "oui_hex": "0C-9A-42",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "000809": {
        "oui_hex": "00-08-09",
        "organization": "Systemonic AG",
        "address_1": "Am Waldschloesschen 1",
        "address_2": "",
        "country": "DE"
    },
    "8C41F4": {
        "oui_hex": "8C-41-F4",
        "organization": "IPmotion GmbH",
        "address_1": "Ludwig-Rinn-Straße 8-16",
        "address_2": "Heuchelheim  Hessen  35452",
        "country": "DE"
    },
    "704F08": {
        "oui_hex": "70-4F-08",
        "organization": "Shenzhen Huisheng Information Technology Co., Ltd.",
        "address_1": " Room 4A-205, Software Industry Base, Yuehai St",
        "address_2": "Nanshan District, Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "8835C1": {
        "oui_hex": "88-35-C1",
        "organization": "OI ELECTRIC CO.,LTD",
        "address_1": "7-3-16 KIKUNA",
        "address_2": "YOKOHAMA  KANAGAWA-KEN  222-0011",
        "country": "JP"
    },
    "3042A1": {
        "oui_hex": "30-42-A1",
        "organization": "ilumisys Inc. DBA Toggled",
        "address_1": "1820 E. Big Beaver Road",
        "address_2": "Troy  MI  48083",
        "country": "US"
    },
    "0026B7": {
        "oui_hex": "00-26-B7",
        "organization": "Kingston Technology Company, Inc.",
        "address_1": "17600 Newhope St.",
        "address_2": "Fountain Valley  CA  92708",
        "country": "US"
    },
    "28D0CB": {
        "oui_hex": "28-D0-CB",
        "organization": "Cambridge Communication Systems Ltd",
        "address_1": "Victory House, Vision Park, Chivers Way, Histon",
        "address_2": "Cambridge    CB24 9ZR",
        "country": "GB"
    },
    "4062EA": {
        "oui_hex": "40-62-EA",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "4C0FC7": {
        "oui_hex": "4C-0F-C7",
        "organization": "Earda Technologies co Ltd",
        "address_1": "5/F,Block 2 East area,Haosheng Industrial Park,",
        "address_2": "Guangzhou  Guangdong  511400",
        "country": "CN"
    },
    "80A796": {
        "oui_hex": "80-A7-96",
        "organization": "Neurotek LLC",
        "address_1": "3180 18th St, Ste 200",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "CC2119": {
        "oui_hex": "CC-21-19",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "302303": {
        "oui_hex": "30-23-03",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  null  90094",
        "country": "US"
    },
    "9CF6DD": {
        "oui_hex": "9C-F6-DD",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "001E80": {
        "oui_hex": "00-1E-80",
        "organization": "Icotera A/S",
        "address_1": "Vibeholms Allé 16",
        "address_2": "Brøndby    2605",
        "country": "DK"
    },
    "48881E": {
        "oui_hex": "48-88-1E",
        "organization": "EthoSwitch LLC",
        "address_1": "1298 Evans Road",
        "address_2": "Wall Township   NJ  07719",
        "country": "US"
    },
    "3C71BF": {
        "oui_hex": "3C-71-BF",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "000393": {
        "oui_hex": "00-03-93",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0000C3": {
        "oui_hex": "00-00-C3",
        "organization": "Harris Corporation",
        "address_1": "1025 West NASA Blvd",
        "address_2": "Melbourne  FL  32919",
        "country": "US"
    },
    "304B07": {
        "oui_hex": "30-4B-07",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "345ABA": {
        "oui_hex": "34-5A-BA",
        "organization": "tcloud intelligence",
        "address_1": "Bao'an District, No. 400 Xiangshan Avenue",
        "address_2": "ShenZhen  GuangDong  518105",
        "country": "CN"
    },
    "502FA8": {
        "oui_hex": "50-2F-A8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "902BD2": {
        "oui_hex": "90-2B-D2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "08D59D": {
        "oui_hex": "08-D5-9D",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "C08359": {
        "oui_hex": "C0-83-59",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "EC83D5": {
        "oui_hex": "EC-83-D5",
        "organization": "GIRD Systems Inc",
        "address_1": "11260 Chester Road, Ste. 600",
        "address_2": "Cincinnati  OH  45246",
        "country": "US"
    },
    "14942F": {
        "oui_hex": "14-94-2F",
        "organization": "USYS CO.,LTD.",
        "address_1": "#911, SeoulTechnoPark, 232, Gongneung-ro, Nowon-gu",
        "address_2": "Seoul    KS013",
        "country": "KR"
    },
    "FCB10D": {
        "oui_hex": "FC-B1-0D",
        "organization": "Shenzhen Tian Kun Technology Co.,LTD.",
        "address_1": "Layer 8,Nanyuan Maple Building,No.1088 Nanshan Avenue,Nanshan Street,Nanshan District,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518048",
        "country": "CN"
    },
    "20F77C": {
        "oui_hex": "20-F7-7C",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "001EEC": {
        "oui_hex": "00-1E-EC",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street",
        "address_2": "KUNSHAN CITY  SUZHOU PROVINCE  215300",
        "country": "CN"
    },
    "F0761C": {
        "oui_hex": "F0-76-1C",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 15, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "0004AE": {
        "oui_hex": "00-04-AE",
        "organization": "Sullair Corporation",
        "address_1": "3700 East Michigan Blvd",
        "address_2": "Michigan City  IN  46360",
        "country": "US"
    },
    "00451D": {
        "oui_hex": "00-45-1D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A0D635": {
        "oui_hex": "A0-D6-35",
        "organization": "WBS Technology",
        "address_1": "Unit32, 2 Slough Ave, Slough Business Park",
        "address_2": "Silverwater  New South Wales  2128",
        "country": "AU"
    },
    "34800D": {
        "oui_hex": "34-80-0D",
        "organization": "Cavium Inc",
        "address_1": "15485 Sand Canyon Ave",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "B44BD6": {
        "oui_hex": "B4-4B-D6",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D8912A": {
        "oui_hex": "D8-91-2A",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "3C427E": {
        "oui_hex": "3C-42-7E",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "000BA3": {
        "oui_hex": "00-0B-A3",
        "organization": "Siemens AG",
        "address_1": "Werner-von-Siemens-Straße 65",
        "address_2": "Erlangen  Bavaria  91052",
        "country": "DE"
    },
    "000C8A": {
        "oui_hex": "00-0C-8A",
        "organization": "Bose Corporation",
        "address_1": "Automotive Systems Division (ASD)",
        "address_2": "Stow  MA  01775-9102",
        "country": "US"
    },
    "243A82": {
        "oui_hex": "24-3A-82",
        "organization": "IRTS",
        "address_1": "639 BD DES ARMARIS, IRTS",
        "address_2": "TOULON  Provence Alpes Cotes d'Azur  83100",
        "country": "FR"
    },
    "880907": {
        "oui_hex": "88-09-07",
        "organization": "MKT Systemtechnik GmbH & Co. KG",
        "address_1": "Hasskampstraße 75-77",
        "address_2": "Bünde  NRW  32257",
        "country": "DE"
    },
    "58A48E": {
        "oui_hex": "58-A4-8E",
        "organization": "PixArt Imaging Inc.",
        "address_1": "No.5, Innovation Road 1, HsinChu Science Park,",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "30D659": {
        "oui_hex": "30-D6-59",
        "organization": "Merging Technologies SA",
        "address_1": "Le Verney 4",
        "address_2": "Puidoux  Outside the U.S or Canada  1070",
        "country": "CH"
    },
    "702AD5": {
        "oui_hex": "70-2A-D5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "889765": {
        "oui_hex": "88-97-65",
        "organization": "exands",
        "address_1": "RM2202 , No. 666 Gubei road",
        "address_2": "shanghai    200336",
        "country": "CN"
    },
    "386E88": {
        "oui_hex": "38-6E-88",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "B88584": {
        "oui_hex": "B8-85-84",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "40EEDD": {
        "oui_hex": "40-EE-DD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B01886": {
        "oui_hex": "B0-18-86",
        "organization": "SmarDTV",
        "address_1": "Route de Genève 22",
        "address_2": "Cheseaux    CH-1033",
        "country": "CH"
    },
    "AC751D": {
        "oui_hex": "AC-75-1D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "289E97": {
        "oui_hex": "28-9E-97",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "001525": {
        "oui_hex": "00-15-25",
        "organization": "Chamberlain Access Solutions",
        "address_1": "8271 E. Gelding Drive",
        "address_2": "Scottsdale  AZ  85260",
        "country": "US"
    },
    "001EB0": {
        "oui_hex": "00-1E-B0",
        "organization": "ImesD Electronica S.L.",
        "address_1": "d'Entença 81",
        "address_2": "Barcelona    08015",
        "country": "ES"
    },
    "641C67": {
        "oui_hex": "64-1C-67",
        "organization": "DIGIBRAS INDUSTRIA DO BRASILS/A",
        "address_1": "Rua Tambaqui, 180-B - MANAUS - AM ¨C BRAZIL",
        "address_2": "manaus  MANAUS  69075-210",
        "country": "BR"
    },
    "60058A": {
        "oui_hex": "60-05-8A",
        "organization": "Hitachi Metals, Ltd.",
        "address_1": "Shinagawa Season Terrace, 2-70, Konan 1-chome",
        "address_2": "Minato-ku  Tokyo  108-8224",
        "country": "JP"
    },
    "BC22FB": {
        "oui_hex": "BC-22-FB",
        "organization": "RF Industries",
        "address_1": "PO Box 5",
        "address_2": "Welland  SA  5007",
        "country": "AU"
    },
    "0080B6": {
        "oui_hex": "00-80-B6",
        "organization": "Mercury Systems – Trusted Mission Solutions, Inc.",
        "address_1": "6681 OWENS DRIVE",
        "address_2": "PLEASONTON  CA  94588",
        "country": "US"
    },
    "08512E": {
        "oui_hex": "08-51-2E",
        "organization": "Orion Diagnostica Oy",
        "address_1": "Koivu-Mankkaan tie 6",
        "address_2": "Espoo    02100",
        "country": "FI"
    },
    "98A404": {
        "oui_hex": "98-A4-04",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "00CC3F": {
        "oui_hex": "00-CC-3F",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "74B91E": {
        "oui_hex": "74-B9-1E",
        "organization": "Nanjing Bestway Automation System Co., Ltd",
        "address_1": "#50 Baoxiang Road, Jiangning Bin Jiang Economic Development Zone",
        "address_2": "nanjing  jiangsu  211161",
        "country": "CN"
    },
    "A019B2": {
        "oui_hex": "A0-19-B2",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "8C15C7": {
        "oui_hex": "8C-15-C7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "60FA9D": {
        "oui_hex": "60-FA-9D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "DC9914": {
        "oui_hex": "DC-99-14",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "4C3FD3": {
        "oui_hex": "4C-3F-D3",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B05365": {
        "oui_hex": "B0-53-65",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "308841": {
        "oui_hex": "30-88-41",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou,Industrial Park",
        "address_2": "Anzhou,Industrial Park  Sichuan  621000",
        "country": "CN"
    },
    "44EFCF": {
        "oui_hex": "44-EF-CF",
        "organization": "UGENE SOLUTION inc.",
        "address_1": "A-1508, 1509, 583, Yangcheon-ro, Gangseo-gu",
        "address_2": "Seoul    KS013",
        "country": "KR"
    },
    "304596": {
        "oui_hex": "30-45-96",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C0F4E6": {
        "oui_hex": "C0-F4-E6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "74EB80": {
        "oui_hex": "74-EB-80",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CE0DC": {
        "oui_hex": "0C-E0-DC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D868C3": {
        "oui_hex": "D8-68-C3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C493D9": {
        "oui_hex": "C4-93-D9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A82BB9": {
        "oui_hex": "A8-2B-B9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "ACFD93": {
        "oui_hex": "AC-FD-93",
        "organization": "WEIFANG GOERTEK ELECTRONICS CO.,LTD",
        "address_1": "Gaoxin 2 Road,Free Trade Zone,Weifang,Shandong,261205,P.R.China",
        "address_2": "Weifang  Shandong  261205",
        "country": "CN"
    },
    "68572D": {
        "oui_hex": "68-57-2D",
        "organization": "HANGZHOU AIXIANGJI TECHNOLOGY CO., LTD",
        "address_1": "7 Floor, 3 Blvd., More Centre, 87 Gudun Rd., Xihu District",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "00B8C2": {
        "oui_hex": "00-B8-C2",
        "organization": "Heights Telecom T ltd",
        "address_1": "Moshe Lerer 15",
        "address_2": "Nes Ziona     7404996",
        "country": "IL"
    },
    "F4BF80": {
        "oui_hex": "F4-BF-80",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "000E8F": {
        "oui_hex": "00-0E-8F",
        "organization": "Sercomm Corporation.",
        "address_1": "3F,No.81,Yu-Yih Rd.,Chu-Nan Chen",
        "address_2": "Miao-Lih Hsuan    115",
        "country": "TW"
    },
    "A0E617": {
        "oui_hex": "A0-E6-17",
        "organization": "MATIS",
        "address_1": "2/F,Hatchobori MIYATA Bldg.,1-8-2,",
        "address_2": "Shintomi,Chuo-Ku,  Tokyo  104-0041",
        "country": "JP"
    },
    "7001B5": {
        "oui_hex": "70-01-B5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F49": {
        "oui_hex": "00-1F-49",
        "organization": "Manhattan TV Ltd",
        "address_1": "3 Phoenix Park,",
        "address_2": "London    NW2 7LN",
        "country": "GB"
    },
    "88D652": {
        "oui_hex": "88-D6-52",
        "organization": "AMERGINT Technologies",
        "address_1": "2315 Briargate Pkwy, Suite 100",
        "address_2": "Colorado Springs  CO  80920",
        "country": "US"
    },
    "FC90FA": {
        "oui_hex": "FC-90-FA",
        "organization": "Independent Technologies",
        "address_1": "1960 Ridgeview Rd",
        "address_2": "Blair  NE  68008",
        "country": "US"
    },
    "D0B214": {
        "oui_hex": "D0-B2-14",
        "organization": "PoeWit Inc",
        "address_1": "2307 Sea Island Dr",
        "address_2": "Fort Lauderdale  FL  33301",
        "country": "US"
    },
    "C42456": {
        "oui_hex": "C4-24-56",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B4B686": {
        "oui_hex": "B4-B6-86",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "4CEDFB": {
        "oui_hex": "4C-ED-FB",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "7C2EBD": {
        "oui_hex": "7C-2E-BD",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "6CAF15": {
        "oui_hex": "6C-AF-15",
        "organization": "Webasto SE",
        "address_1": "Kraillinger Straße 5",
        "address_2": "Stockdorf  Bayern  82131",
        "country": "DE"
    },
    "E4E130": {
        "oui_hex": "E4-E1-30",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "0C2138": {
        "oui_hex": "0C-21-38",
        "organization": "Hengstler GmbH",
        "address_1": "Uhlandstrasse49",
        "address_2": "Aldingen  BW  78554",
        "country": "DE"
    },
    "E46059": {
        "oui_hex": "E4-60-59",
        "organization": "Pingtek Co., Ltd.",
        "address_1": "5F., No.786, Zhongzheng Rd., Zhonghe Dist.",
        "address_2": "New Taipei City    235",
        "country": "TW"
    },
    "E0191D": {
        "oui_hex": "E0-19-1D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "68D1BA": {
        "oui_hex": "68-D1-BA",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "1C1AC0": {
        "oui_hex": "1C-1A-C0",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3078C2": {
        "oui_hex": "30-78-C2",
        "organization": "Innowireless / QUCELL Networks",
        "address_1": "Innowireless Bldg.  190 Seohyeon-ro",
        "address_2": "Bundang-gu, Seongnam-si  Gyeonggi-do  13590",
        "country": "KR"
    },
    "4050B5": {
        "oui_hex": "40-50-B5",
        "organization": "Shenzhen New Species Technology Co., Ltd.",
        "address_1": "Room 1827,Building R&D,EVOC intelligence valley,No 11,Gao xin west road,Guangming New District",
        "address_2": "Shenzhen    518107",
        "country": "CN"
    },
    "3C15FB": {
        "oui_hex": "3C-15-FB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CC934A": {
        "oui_hex": "CC-93-4A",
        "organization": "Sierra Wireless",
        "address_1": "1381 Wireless Way",
        "address_2": "Richmond BC   CA   V6V 3A4",
        "country": "GB"
    },
    "00CFC0": {
        "oui_hex": "00-CF-C0",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "DC330D": {
        "oui_hex": "DC-33-0D",
        "organization": "QING DAO HAIER TELECOM CO.,LTD.",
        "address_1": "No 1  Haier road,Hi-tech Zone，Qingdao，PR.China",
        "address_2": "Qingdao  Shandong  266101",
        "country": "CN"
    },
    "688975": {
        "oui_hex": "68-89-75",
        "organization": "nuoxc",
        "address_1": "龙岗区横岗街道西坑社区西坑梧岗路9号2栋",
        "address_2": "深圳市  广东省  518173",
        "country": "CN"
    },
    "40F04E": {
        "oui_hex": "40-F0-4E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "0021F2": {
        "oui_hex": "00-21-F2",
        "organization": "EASY3CALL Technology Limited",
        "address_1": "Room 1903-6, 19/F., HING YIP Commercial Centre",
        "address_2": "Hong Kong    999077",
        "country": "CN"
    },
    "0015C4": {
        "oui_hex": "00-15-C4",
        "organization": "FLOVEL CO., LTD.",
        "address_1": "The Tachihi building No,3 hall, 6-1, Sakae-cho,",
        "address_2": "Tokyo    190-0003",
        "country": "US"
    },
    "0011E6": {
        "oui_hex": "00-11-E6",
        "organization": "Scientific Atlanta",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  Ga  30042",
        "country": "US"
    },
    "24F128": {
        "oui_hex": "24-F1-28",
        "organization": "Telstra",
        "address_1": "231 Elisabeth St",
        "address_2": "SYDNEY  NSW  2000",
        "country": "AU"
    },
    "E0383F": {
        "oui_hex": "E0-38-3F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D47226": {
        "oui_hex": "D4-72-26",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "40831D": {
        "oui_hex": "40-83-1D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DCD3A2": {
        "oui_hex": "DC-D3-A2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5C1DD9": {
        "oui_hex": "5C-1D-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "800588": {
        "oui_hex": "80-05-88",
        "organization": "Ruijie Networks Co.,LTD",
        "address_1": "20# Building,Star-net Science Plaza,Juyuanzhou, 618 Jinshan Road",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "F00E1D": {
        "oui_hex": "F0-0E-1D",
        "organization": "Megafone Limited",
        "address_1": "Unit 702,7/F,Bankok Bank Building,NO.18 Bonham Strand West",
        "address_2": "Hong Kong    999077",
        "country": "HK"
    },
    "88AE07": {
        "oui_hex": "88-AE-07",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "68FEF7": {
        "oui_hex": "68-FE-F7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC35EE": {
        "oui_hex": "AC-35-EE",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "881196": {
        "oui_hex": "88-11-96",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E40EEE": {
        "oui_hex": "E4-0E-EE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "28D997": {
        "oui_hex": "28-D9-97",
        "organization": "Yuduan Mobile Co., Ltd.",
        "address_1": "Room 401 No 84 Lane 887 Zuchongzhi Rd.",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "301F9A": {
        "oui_hex": "30-1F-9A",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0C2C54": {
        "oui_hex": "0C-2C-54",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D4C19E": {
        "oui_hex": "D4-C1-9E",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "70695A": {
        "oui_hex": "70-69-5A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00BF77": {
        "oui_hex": "00-BF-77",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D07714": {
        "oui_hex": "D0-77-14",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "30B7D4": {
        "oui_hex": "30-B7-D4",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "B481BF": {
        "oui_hex": "B4-81-BF",
        "organization": "Meta-Networks, LLC",
        "address_1": "Office 106C, 5/2, Varshavskaya street",
        "address_2": "Saint-Petersburg  Saint-Petersburg  196128",
        "country": "RU"
    },
    "946AB0": {
        "oui_hex": "94-6A-B0",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "4818FA": {
        "oui_hex": "48-18-FA",
        "organization": "Nocsys",
        "address_1": "1F, No. 63 Building, No. 421 Hong Cao Road, Xuhui District",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "587A6A": {
        "oui_hex": "58-7A-6A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "A038F8": {
        "oui_hex": "A0-38-F8",
        "organization": "OURA Health Oy",
        "address_1": "Elektroniikkatie 3",
        "address_2": "Oulu    90590",
        "country": "FI"
    },
    "687924": {
        "oui_hex": "68-79-24",
        "organization": "ELS-GmbH & Co. KG",
        "address_1": "Dammstrasse 21",
        "address_2": "Werther  NRW  33824",
        "country": "DE"
    },
    "28FD80": {
        "oui_hex": "28-FD-80",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0CAE7D": {
        "oui_hex": "0C-AE-7D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "304511": {
        "oui_hex": "30-45-11",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E81AAC": {
        "oui_hex": "E8-1A-AC",
        "organization": "ORFEO SOUNDWORKS Inc.",
        "address_1": "612, 11-41, Simin-daero 327beon-gil, Dongan-gu",
        "address_2": "Anyang    14055",
        "country": "KR"
    },
    "000758": {
        "oui_hex": "00-07-58",
        "organization": "DragonWave Inc.",
        "address_1": "600-411 Leggett Drive,",
        "address_2": "Kanata,  Ontario  K2K 3C9",
        "country": "CA"
    },
    "F0FCC8": {
        "oui_hex": "F0-FC-C8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F8DF15": {
        "oui_hex": "F8-DF-15",
        "organization": "Sunitec Enterprise Co.,Ltd",
        "address_1": "3F.,No.98-1,Mincyuan Rd.Sindian City",
        "address_2": "Taipei County 231    231141",
        "country": "CN"
    },
    "001DB5": {
        "oui_hex": "00-1D-B5",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "B02680": {
        "oui_hex": "B0-26-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D49398": {
        "oui_hex": "D4-93-98",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  N.A.  24101",
        "country": "FI"
    },
    "001937": {
        "oui_hex": "00-19-37",
        "organization": "CommerceGuard AB",
        "address_1": "Gustavslundsv 151A",
        "address_2": "BROMMA    16714",
        "country": "SE"
    },
    "FC7C02": {
        "oui_hex": "FC-7C-02",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "A8610A": {
        "oui_hex": "A8-61-0A",
        "organization": "ARDUINO AG",
        "address_1": "Corso San Gottardo 6A",
        "address_2": "Chiasso    6830",
        "country": "CH"
    },
    "6097DD": {
        "oui_hex": "60-97-DD",
        "organization": "MicroSys Electronics GmbH",
        "address_1": "Muehlweg 1",
        "address_2": "Sauerlach    82054",
        "country": "DE"
    },
    "047970": {
        "oui_hex": "04-79-70",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A057E3": {
        "oui_hex": "A0-57-E3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1CB044": {
        "oui_hex": "1C-B0-44",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "AC17C8": {
        "oui_hex": "AC-17-C8",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  null  94158",
        "country": "US"
    },
    "F4844C": {
        "oui_hex": "F4-84-4C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B4F2E8": {
        "oui_hex": "B4-F2-E8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3C574F": {
        "oui_hex": "3C-57-4F",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "D49CF4": {
        "oui_hex": "D4-9C-F4",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "8C1645": {
        "oui_hex": "8C-16-45",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "689861": {
        "oui_hex": "68-98-61",
        "organization": "Beacon Inc",
        "address_1": "82-1, Anyangcheondong-ro, Dongan-gu",
        "address_2": "anyang  Gyeonggi-do  14042",
        "country": "KR"
    },
    "609813": {
        "oui_hex": "60-98-13",
        "organization": "Shanghai Visking Digital Technology Co. LTD",
        "address_1": "Room 1301, Building A8, No.1688 Guoquan North Road, Yangpu District",
        "address_2": "Shanghai    200082",
        "country": "CN"
    },
    "506B4B": {
        "oui_hex": "50-6B-4B",
        "organization": "Mellanox Technologies, Inc.",
        "address_1": "350 Oakmead Parkway, Suite 100",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "B41C30": {
        "oui_hex": "B4-1C-30",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "705AAC": {
        "oui_hex": "70-5A-AC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2C9569": {
        "oui_hex": "2C-95-69",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A039EE": {
        "oui_hex": "A0-39-EE",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "E4CB59": {
        "oui_hex": "E4-CB-59",
        "organization": "Beijing Loveair Science and Technology Co. Ltd.",
        "address_1": "103,Block B, Kelin Building, No.107, Dongsi North Street, Dongcheng District,",
        "address_2": " Beijing    100000",
        "country": "CN"
    },
    "B4E62D": {
        "oui_hex": "B4-E6-2D",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "847460": {
        "oui_hex": "84-74-60",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "4C82CF": {
        "oui_hex": "4C-82-CF",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "285767": {
        "oui_hex": "28-57-67",
        "organization": "Dish Technologies Corp",
        "address_1": "94 Inverness Terrace E",
        "address_2": "Englewood  CO  80112",
        "country": "US"
    },
    "70169F": {
        "oui_hex": "70-16-9F",
        "organization": "EtherCAT Technology Group",
        "address_1": "Ostendstr. 196",
        "address_2": "NUremberg    90482",
        "country": "DE"
    },
    "68EF43": {
        "oui_hex": "68-EF-43",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D02B20": {
        "oui_hex": "D0-2B-20",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C61F6": {
        "oui_hex": "2C-61-F6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D4A33D": {
        "oui_hex": "D4-A3-3D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0766F": {
        "oui_hex": "F0-76-6F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4098AD": {
        "oui_hex": "40-98-AD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C4D73": {
        "oui_hex": "6C-4D-73",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1CA0B8": {
        "oui_hex": "1C-A0-B8",
        "organization": "Hon Hai Precision Ind. Co., Ltd.",
        "address_1": "GuangDongShenZhen",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "D88466": {
        "oui_hex": "D8-84-66",
        "organization": "Extreme Networks, Inc.",
        "address_1": "145 Rio Robles",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000496": {
        "oui_hex": "00-04-96",
        "organization": "Extreme Networks, Inc.",
        "address_1": "3585 Monroe Street",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "00E02B": {
        "oui_hex": "00-E0-2B",
        "organization": "Extreme Networks, Inc.",
        "address_1": "10460 BANDLEY DRIVE",
        "address_2": "CUPERINT0  CA  95014",
        "country": "US"
    },
    "5C0E8B": {
        "oui_hex": "5C-0E-8B",
        "organization": "Extreme Networks, Inc.",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "7467F7": {
        "oui_hex": "74-67-F7",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1 Zebra Plaza",
        "address_2": "Holtsville  NY  11742",
        "country": "US"
    },
    "E43022": {
        "oui_hex": "E4-30-22",
        "organization": "Hanwha Techwin Security Vietnam",
        "address_1": "Plot O-2, Que Vo industrial park (Expanded area),",
        "address_2": "Nam Son Commune, Bac Ninh City  Bac Ninh Province  000",
        "country": "VN"
    },
    "044F17": {
        "oui_hex": "04-4F-17",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "5C4A1F": {
        "oui_hex": "5C-4A-1F",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "E48F34": {
        "oui_hex": "E4-8F-34",
        "organization": "Vodafone Italia S.p.A.",
        "address_1": "Via Lorenteggio nr. 240",
        "address_2": "Milan  Italy  20147",
        "country": "IT"
    },
    "685ACF": {
        "oui_hex": "68-5A-CF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0CA8A7": {
        "oui_hex": "0C-A8-A7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0672F": {
        "oui_hex": "B0-67-2F",
        "organization": "Bowers & Wilkins",
        "address_1": "900 Middlefield Rd Floor 4",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "10CD6E": {
        "oui_hex": "10-CD-6E",
        "organization": "FISYS",
        "address_1": "303 Expotel, 44, Dunsan-daero 117beon-gil, Seo-gu, Daejeon, Korea",
        "address_2": "Daejeon, Korea    KS015",
        "country": "KR"
    },
    "D86375": {
        "oui_hex": "D8-63-75",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "D89C67": {
        "oui_hex": "D8-9C-67",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "64209F": {
        "oui_hex": "64-20-9F",
        "organization": "Tilgin AB",
        "address_1": "Finlandsgatan 40",
        "address_2": "Kista    16474",
        "country": "SE"
    },
    "A43E51": {
        "oui_hex": "A4-3E-51",
        "organization": "ANOV FRANCE",
        "address_1": "100 CHEMIN DE BAILLOT",
        "address_2": "MONTAUBAN    82000",
        "country": "FR"
    },
    "702605": {
        "oui_hex": "70-26-05",
        "organization": "SONY Visual Products Inc.",
        "address_1": "2-10-1 Osaki",
        "address_2": "Shinagawa-ku  Tokyo  141-8610",
        "country": "JP"
    },
    "0090F1": {
        "oui_hex": "00-90-F1",
        "organization": "Seagate Cloud Systems Inc",
        "address_1": "6305 El Camino Real",
        "address_2": "Carlsbad  CA  92009",
        "country": "US"
    },
    "845A81": {
        "oui_hex": "84-5A-81",
        "organization": "ffly4u",
        "address_1": "3, avenue Didier Daurat",
        "address_2": "Toulouse    31400",
        "country": "FR"
    },
    "CC81DA": {
        "oui_hex": "CC-81-DA",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "00806C": {
        "oui_hex": "00-80-6C",
        "organization": "Secure Systems & Services",
        "address_1": "24, Chemin de la Pouranque",
        "address_2": "F-13752  LES PENNES MIRABEAU  CS30084",
        "country": "FR"
    },
    "007263": {
        "oui_hex": "00-72-63",
        "organization": "Netcore Technology Inc.",
        "address_1": "ORIENTAL CYBERPORT,HIGHTECH 6 ROAD",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "1C27DD": {
        "oui_hex": "1C-27-DD",
        "organization": "Datang Gohighsec(zhejiang)Information Technology Co.,Ltd.",
        "address_1": "Beiwu Innovation park, #23 Beiwu Villiage Road",
        "address_2": "Beijing  Beijing  100000",
        "country": "CN"
    },
    "B8C8EB": {
        "oui_hex": "B8-C8-EB",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "80C5F2": {
        "oui_hex": "80-C5-F2",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "64F88A": {
        "oui_hex": "64-F8-8A",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "68DB54": {
        "oui_hex": "68-DB-54",
        "organization": "Phicomm (Shanghai) Co., Ltd.",
        "address_1": "3666 SiXian Rd.,Songjiang District",
        "address_2": "Shanghai  Shanghai  201616",
        "country": "CN"
    },
    "B45253": {
        "oui_hex": "B4-52-53",
        "organization": "Seagate Technology",
        "address_1": "1280 Disc Drive",
        "address_2": "Shakopee  MN  55379",
        "country": "US"
    },
    "0011C6": {
        "oui_hex": "00-11-C6",
        "organization": "Seagate Technology",
        "address_1": "M/S NW1F01",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "001D38": {
        "oui_hex": "00-1D-38",
        "organization": "Seagate Technology",
        "address_1": "M/S NW1F01",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "005013": {
        "oui_hex": "00-50-13",
        "organization": "Seagate Cloud Systems Inc",
        "address_1": "7420 E. Dry Creek Parkway",
        "address_2": "Longmont  CO  80503",
        "country": "US"
    },
    "C8DF84": {
        "oui_hex": "C8-DF-84",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "240D6C": {
        "oui_hex": "24-0D-6C",
        "organization": "SMND",
        "address_1": "16-39, LS-ro 91 beon-gil, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  14119",
        "country": "KR"
    },
    "48555C": {
        "oui_hex": "48-55-5C",
        "organization": "Wu Qi Technologies,Inc.",
        "address_1": "Xiantao street data on the 19th East Road",
        "address_2": "Chongqing City   Yubei District  401120",
        "country": "CN"
    },
    "18F0E4": {
        "oui_hex": "18-F0-E4",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources , No.68 Qinghe Middle Street , Haidian District",
        "address_2": "Beijing  Beijing  100089",
        "country": "CN"
    },
    "588A5A": {
        "oui_hex": "58-8A-5A",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "9C8C6E": {
        "oui_hex": "9C-8C-6E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "DC4F22": {
        "oui_hex": "DC-4F-22",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "F86CE1": {
        "oui_hex": "F8-6C-E1",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "1C7328": {
        "oui_hex": "1C-73-28",
        "organization": "Connected Home",
        "address_1": "19-22, Rathbone Place",
        "address_2": "London    W1T 1HY",
        "country": "GB"
    },
    "D8E004": {
        "oui_hex": "D8-E0-04",
        "organization": "Vodia Networks Inc",
        "address_1": "33 Broad St",
        "address_2": "Boston  MA  02109",
        "country": "US"
    },
    "2CFDAB": {
        "oui_hex": "2C-FD-AB",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "30B4B8": {
        "oui_hex": "30-B4-B8",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "380E4D": {
        "oui_hex": "38-0E-4D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3873EA": {
        "oui_hex": "38-73-EA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "4C5262": {
        "oui_hex": "4C-52-62",
        "organization": "Fujitsu Technology Solutions GmbH",
        "address_1": "Buergermeister-Ulrich-Strasse 100",
        "address_2": "Augsburg  Bayern  86199",
        "country": "DE"
    },
    "803BF6": {
        "oui_hex": "80-3B-F6",
        "organization": "LOOK EASY INTERNATIONAL LIMITED",
        "address_1": "4th Floor, No. 551, Guang-Fu South Road",
        "address_2": "Taipei  Xinyi District  11074",
        "country": "TW"
    },
    "30EB1F": {
        "oui_hex": "30-EB-1F",
        "organization": "Skylab M&C Technology Co.,Ltd",
        "address_1": "6 Floor,No.9 Building,Lijincheng Scientific&Technical park,Gongye East Road,Longhua District",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "549A4C": {
        "oui_hex": "54-9A-4C",
        "organization": "GUANGDONG HOMECARE TECHNOLOGY CO.,LTD.",
        "address_1": "8F,12#, Taihua Industrial Park, Hangkong Rd., Gushu， Baoan District",
        "address_2": "Shenzhen  Guangdong  518128",
        "country": "CN"
    },
    "EC1D8B": {
        "oui_hex": "EC-1D-8B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "EC7097": {
        "oui_hex": "EC-70-97",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5819F8": {
        "oui_hex": "58-19-F8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D07FC4": {
        "oui_hex": "D0-7F-C4",
        "organization": "Ou Wei Technology Co.，Ltd. of Shenzhen City",
        "address_1": "Registered Address: Room 201, Block D, Huahan Innovation Park, Langshan Road, Xili Street, Nanshan District,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "1479F3": {
        "oui_hex": "14-79-F3",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "0CCEF6": {
        "oui_hex": "0C-CE-F6",
        "organization": "Guizhou Fortuneship Technology Co., Ltd",
        "address_1": "2nd Floor, Factory Building 4, Hi-Tech Industrial Park, Xinpu Economic Development Zone, Xinpu New District",
        "address_2": "Zunyi City  Guizhou Province  56300",
        "country": "CN"
    },
    "1806FF": {
        "oui_hex": "18-06-FF",
        "organization": "Acer Computer(Shanghai) Limited.",
        "address_1": "Room1806-20, No.769, Jiujiang Road, Huangpu District",
        "address_2": "Shanghai    200000",
        "country": "CN"
    },
    "C4CD82": {
        "oui_hex": "C4-CD-82",
        "organization": "Hangzhou Lowan Information Technology Co., Ltd.",
        "address_1": "502 Building B, United Mansion, No.2 Zijinghua Road",
        "address_2": "Hangzhou  Zhejiang  310023",
        "country": "CN"
    },
    "30FB94": {
        "oui_hex": "30-FB-94",
        "organization": "Shanghai Fangzhiwei Information Technology CO.,Ltd.",
        "address_1": "The 17th  Building A Unit,No. 1688 Lianhang Road,Minhang District,Shanghai City",
        "address_2": "Shanghai    201100",
        "country": "CN"
    },
    "0023A0": {
        "oui_hex": "00-23-A0",
        "organization": "Hana CNS Co., LTD.",
        "address_1": "Taejang-dong 1720-52 Taejang-NongGong-Danji",
        "address_2": "Wonju  Gangwon-do  220-962",
        "country": "KR"
    },
    "F406A5": {
        "oui_hex": "F4-06-A5",
        "organization": "Hangzhou Bianfeng Networking Technology Co., Ltd.",
        "address_1": "BlockC，2F，Building B，Paradise Software Park",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "A4B52E": {
        "oui_hex": "A4-B5-2E",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "3CA581": {
        "oui_hex": "3C-A5-81",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "34E911": {
        "oui_hex": "34-E9-11",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "64CBA3": {
        "oui_hex": "64-CB-A3",
        "organization": "Pointmobile",
        "address_1": "B-9F kabul Great Valley, 32, Digital-ro 9-gil, Geumcheon-gu",
        "address_2": "Seoul  Seoul  08512",
        "country": "KR"
    },
    "ECFABC": {
        "oui_hex": "EC-FA-BC",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "08BA22": {
        "oui_hex": "08-BA-22",
        "organization": "Swaive Corporation",
        "address_1": "3565 Kettmann Road",
        "address_2": "San Jose  CA  95121",
        "country": "US"
    },
    "28C13C": {
        "oui_hex": "28-C1-3C",
        "organization": "Hon Hai Precision Ind. Co., Ltd.",
        "address_1": "GuangDongShenZhen",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "B0ECE1": {
        "oui_hex": "B0-EC-E1",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "60E78A": {
        "oui_hex": "60-E7-8A",
        "organization": "UNISEM",
        "address_1": "10-7,Jangjinam-gil,Dongtan-meyeon",
        "address_2": "Hwaseong-si  Gyeonggi-do  18510",
        "country": "KR"
    },
    "282986": {
        "oui_hex": "28-29-86",
        "organization": "APC by Schneider Electric",
        "address_1": "800 Federal St.",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "707DB9": {
        "oui_hex": "70-7D-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "08BEAC": {
        "oui_hex": "08-BE-AC",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "248BE0": {
        "oui_hex": "24-8B-E0",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "002424": {
        "oui_hex": "00-24-24",
        "organization": "Ace Axis Limited",
        "address_1": "602 Delta Business Park, Welton Road",
        "address_2": "Swindon    SN5 7XP",
        "country": "GB"
    },
    "50C9A0": {
        "oui_hex": "50-C9-A0",
        "organization": "SKIPPER AS",
        "address_1": "Enebakkvn 150",
        "address_2": "Oslo    0612",
        "country": "NO"
    },
    "7483EF": {
        "oui_hex": "74-83-EF",
        "organization": "Arista Networks",
        "address_1": "5453 Great America Parkway",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00E0F6": {
        "oui_hex": "00-E0-F6",
        "organization": "DECISION EUROPE",
        "address_1": "3, rue de Lattre de Tassigny",
        "address_2": "85170 SAINT DENIS LA CHEVASSE",
        "country": "FR"
    },
    "CC2DE0": {
        "oui_hex": "CC-2D-E0",
        "organization": "Routerboard.com",
        "address_1": "Mikrotikls SIA",
        "address_2": "Riga  Riga  LV1009",
        "country": "LV"
    },
    "00BF61": {
        "oui_hex": "00-BF-61",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "7867D7": {
        "oui_hex": "78-67-D7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B8C111": {
        "oui_hex": "B8-C1-11",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "1046B4": {
        "oui_hex": "10-46-B4",
        "organization": "FormericaOE",
        "address_1": "5F-11, No.38, Taiyuan Street",
        "address_2": " Zhubei City   Hsinchu County  302",
        "country": "TW"
    },
    "9CE33F": {
        "oui_hex": "9C-E3-3F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "386B1C": {
        "oui_hex": "38-6B-1C",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "DC5583": {
        "oui_hex": "DC-55-83",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "001248": {
        "oui_hex": "00-12-48",
        "organization": "Dell EMC",
        "address_1": "176 South Street",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "006048": {
        "oui_hex": "00-60-48",
        "organization": "Dell EMC",
        "address_1": "171 SOUTH ST.,",
        "address_2": "HOPKINTON  MA  01748",
        "country": "US"
    },
    "7CC95A": {
        "oui_hex": "7C-C9-5A",
        "organization": "Dell EMC",
        "address_1": "176 South Street",
        "address_2": "Hopkinton  MA  01748",
        "country": "US"
    },
    "D00401": {
        "oui_hex": "D0-04-01",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "742857": {
        "oui_hex": "74-28-57",
        "organization": "Mayfield Robotics",
        "address_1": "400 Convention Way",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "589043": {
        "oui_hex": "58-90-43",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "B4A382": {
        "oui_hex": "B4-A3-82",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "9C9C40": {
        "oui_hex": "9C-9C-40",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "A407B6": {
        "oui_hex": "A4-07-B6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "40498A": {
        "oui_hex": "40-49-8A",
        "organization": "Synapticon GmbH",
        "address_1": "Daimlerstr. 26",
        "address_2": "Schönaich    71101",
        "country": "DE"
    },
    "389D92": {
        "oui_hex": "38-9D-92",
        "organization": "Seiko Epson Corporation",
        "address_1": "2070 Kotobuki Koaka",
        "address_2": "Matsumoto-shi  Nagano-ken  399-8702",
        "country": "JP"
    },
    "8C0F83": {
        "oui_hex": "8C-0F-83",
        "organization": "Angie Hospitality LLC",
        "address_1": "12465 S Fort St, Ste 300",
        "address_2": "Draper  UT  84020-9021",
        "country": "US"
    },
    "DC68EB": {
        "oui_hex": "DC-68-EB",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "E8361D": {
        "oui_hex": "E8-36-1D",
        "organization": "Sense Labs, Inc.",
        "address_1": "485 Massachusetts Ave",
        "address_2": "Cambridge  MA  02139",
        "country": "US"
    },
    "087808": {
        "oui_hex": "08-78-08",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "887598": {
        "oui_hex": "88-75-98",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C0174D": {
        "oui_hex": "C0-17-4D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "20F19E": {
        "oui_hex": "20-F1-9E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C89F42": {
        "oui_hex": "C8-9F-42",
        "organization": "VDII Innovation AB",
        "address_1": "Nedre Holländaregatan 5",
        "address_2": "Helsingborg    25225",
        "country": "SE"
    },
    "7091F3": {
        "oui_hex": "70-91-F3",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "080069": {
        "oui_hex": "08-00-69",
        "organization": "Silicon Graphics",
        "address_1": "2011 N. SHORELINE BLVD.",
        "address_2": "MOUNTAIN VIEW  CA  94039-7311",
        "country": "US"
    },
    "002291": {
        "oui_hex": "00-22-91",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "10FCB6": {
        "oui_hex": "10-FC-B6",
        "organization": "mirusystems CO.,LTD",
        "address_1": "#1001, 2-dong, Pangoyo seven venture valley, 228-gil, Pangyo-ro",
        "address_2": "Bundang-gu, Seongnam-si, Gyeonggi-do    13487",
        "country": "KR"
    },
    "04D6AA": {
        "oui_hex": "04-D6-AA",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "50A83A": {
        "oui_hex": "50-A8-3A",
        "organization": "S Mobile Devices Limited",
        "address_1": "Unit B-303, 3rd Floor, Tower-B, Plot No-7,Advant IT Park Ltd , Sector-142",
        "address_2": "NOIDA  Uttar Pradesh  201301",
        "country": "IN"
    },
    "6405E9": {
        "oui_hex": "64-05-E9",
        "organization": "Shenzhen WayOS Technology Crop., Ltd.",
        "address_1": "F18, Yousong Business Building, Longhua New District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "A07099": {
        "oui_hex": "A0-70-99",
        "organization": "Beijing Huacan Electronics Co., Ltd",
        "address_1": "NO.122, Room 2006, 20/F, Qingyun Contemporary Tower, Building 9, Manting Fangyuan Residential District, Qing Yun Li, Hai Dian District",
        "address_2": "Beijing    100036",
        "country": "CN"
    },
    "48D6D5": {
        "oui_hex": "48-D6-D5",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0C5842": {
        "oui_hex": "0C-58-42",
        "organization": "DME Micro",
        "address_1": "unit 310 Lakeside 1, 8 Science Park West Ave, Shatin",
        "address_2": "Hong Kong    Hong Kong",
        "country": "HK"
    },
    "B810D4": {
        "oui_hex": "B8-10-D4",
        "organization": "Masimo Corporation",
        "address_1": "40 Parker",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "BC825D": {
        "oui_hex": "BC-82-5D",
        "organization": "MITSUMI ELECTRIC CO.,LTD.",
        "address_1": "2-11-2, Tsurumaki",
        "address_2": "Tama-shi  Tokyo  206-8567",
        "country": "JP"
    },
    "D0666D": {
        "oui_hex": "D0-66-6D",
        "organization": "Shenzhen Bus-Lan Technology Co., Ltd.",
        "address_1": "928-931 Chuangke Building, 72-1 South Huanguan Rd, Guan Lan Jie Dao, Longhua District",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "08152F": {
        "oui_hex": "08-15-2F",
        "organization": "Samsung Electronics Co., Ltd. ARTIK",
        "address_1": "1-1, Samsungjeonja-ro",
        "address_2": "Hwaseong-si  Gyeonggi-do  18448",
        "country": "KR"
    },
    "F4F5DB": {
        "oui_hex": "F4-F5-DB",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "F4E204": {
        "oui_hex": "F4-E2-04",
        "organization": "Traqueur",
        "address_1": "1, rue Royale",
        "address_2": "Saint-Cloud    92210",
        "country": "FR"
    },
    "CC2237": {
        "oui_hex": "CC-22-37",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "38D620": {
        "oui_hex": "38-D6-20",
        "organization": "Limidea Concept Pte. Ltd.",
        "address_1": "101 Cecil Street #09-07, Tong Eng Building",
        "address_2": "Singapore  Singapore  069533",
        "country": "SG"
    },
    "74F91A": {
        "oui_hex": "74-F9-1A",
        "organization": "Onface",
        "address_1": "#1408, Mario Tower, 30Gil-28, Digital-ro, Guro-gu",
        "address_2": "Seoul    08389",
        "country": "KR"
    },
    "A434F1": {
        "oui_hex": "A4-34-F1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "186024": {
        "oui_hex": "18-60-24",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "BC3D85": {
        "oui_hex": "BC-3D-85",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "2054FA": {
        "oui_hex": "20-54-FA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "38378B": {
        "oui_hex": "38-37-8B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "745C4B": {
        "oui_hex": "74-5C-4B",
        "organization": "GN Audio A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK-2750",
        "country": "DK"
    },
    "00149D": {
        "oui_hex": "00-14-9D",
        "organization": "Sound ID Inc.",
        "address_1": "3430 West Bayshore Road",
        "address_2": "Palo Alto  California  94303",
        "country": "US"
    },
    "A8E824": {
        "oui_hex": "A8-E8-24",
        "organization": "INIM ELECTRONICS S.R.L.",
        "address_1": "VIA DEI LAVORATORI 10 - FRAZIONE CENTOBUCHI",
        "address_2": "MONTEPRANDONE  ASCOLI PICENO  63076",
        "country": "IT"
    },
    "104963": {
        "oui_hex": "10-49-63",
        "organization": "HARTING K.K.",
        "address_1": "1-7-9, Shin-Yokohama, Kohoku-ku",
        "address_2": "Yokohama-city  Kanagawa  222-0033",
        "country": "JP"
    },
    "8CD48E": {
        "oui_hex": "8C-D4-8E",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "642B8A": {
        "oui_hex": "64-2B-8A",
        "organization": "ALL BEST Industrial Co., Ltd.",
        "address_1": "6F., No.210-20, Sec. 3, Zhongyang Rd., Tucheng Dist.,",
        "address_2": "New Taipei City    23680",
        "country": "TW"
    },
    "B8EE0E": {
        "oui_hex": "B8-EE-0E",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "ECD09F": {
        "oui_hex": "EC-D0-9F",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "78E103": {
        "oui_hex": "78-E1-03",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "000659": {
        "oui_hex": "00-06-59",
        "organization": "EAL (Apeldoorn) B.V.",
        "address_1": "Molenmakershoek 14",
        "address_2": "Apeldoorn    7328JK",
        "country": "NL"
    },
    "E4EC10": {
        "oui_hex": "E4-EC-10",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu  Ou  90590",
        "country": "FI"
    },
    "002692": {
        "oui_hex": "00-26-92",
        "organization": "Mitsubishi Electric Corporation",
        "address_1": "2-7-3 Marunouchi",
        "address_2": "Chiyoda-ku  Tokyo  100-8310",
        "country": "JP"
    },
    "8CC121": {
        "oui_hex": "8C-C1-21",
        "organization": "Panasonic Corporation AVC Networks Company",
        "address_1": "1-15 Matsuo-cho",
        "address_2": "Kadoma  Osaka  571-8504",
        "country": "JP"
    },
    "EC0441": {
        "oui_hex": "EC-04-41",
        "organization": "ShenZhen TIGO Semiconductor Co., Ltd.",
        "address_1": "Room B6-709, Funian Plaza, No.3 Shihua Road, Futian Bonded Area",
        "address_2": "shenzhen  China / Guangdong  518048",
        "country": "CN"
    },
    "ACBE75": {
        "oui_hex": "AC-BE-75",
        "organization": "Ufine Technologies Co.,Ltd.",
        "address_1": "46, Geumgok-dong, Bundang-gu",
        "address_2": "Seong-nam-si  Gyeonggi-do  463-804",
        "country": "KR"
    },
    "00C08F": {
        "oui_hex": "00-C0-8F",
        "organization": "Panasonic Electric Works Co., Ltd.",
        "address_1": "Tsu-Factory",
        "address_2": "Mie-ken  514-8555  0000",
        "country": "JP"
    },
    "B0350B": {
        "oui_hex": "B0-35-0B",
        "organization": "MOBIWIRE MOBILES (NINGBO) CO.,LTD",
        "address_1": "No.999,Dacheng East Road,",
        "address_2": "Fenghua  Zhejiang  315500",
        "country": "CN"
    },
    "28A6AC": {
        "oui_hex": "28-A6-AC",
        "organization": "seca gmbh & co. kg",
        "address_1": "Hammer Steindamm 3-25",
        "address_2": "Hamburg  Germany  22089",
        "country": "DE"
    },
    "A8BE27": {
        "oui_hex": "A8-BE-27",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C0A53E": {
        "oui_hex": "C0-A5-3E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "444E6D": {
        "oui_hex": "44-4E-6D",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "90B1E0": {
        "oui_hex": "90-B1-E0",
        "organization": "Beijing Nebula Link Technology Co., Ltd",
        "address_1": "Room 1201, Building C, Caizhi International Plaza, Haidian District",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "6C090A": {
        "oui_hex": "6C-09-0A",
        "organization": "GEMATICA SRL",
        "address_1": "Via Diocleziano, 107",
        "address_2": "NAPOLI    80125",
        "country": "IT"
    },
    "70E1FD": {
        "oui_hex": "70-E1-FD",
        "organization": "FLEXTRONICS",
        "address_1": "Carretera Base Aerea 5850 int 4",
        "address_2": "Zapopan  Jalisco  45136",
        "country": "MX"
    },
    "74E60F": {
        "oui_hex": "74-E6-0F",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "001AA7": {
        "oui_hex": "00-1A-A7",
        "organization": "Torian Wireless",
        "address_1": "204 Johnston Street",
        "address_2": "Collingwood  Victoria  3066",
        "country": "AU"
    },
    "0CB459": {
        "oui_hex": "0C-B4-59",
        "organization": "Marketech International Corp.",
        "address_1": "10F.,NO.3-2,Yuancyu St.,Nangang Dist.",
        "address_2": "Taipei    11503",
        "country": "TW"
    },
    "8014A8": {
        "oui_hex": "80-14-A8",
        "organization": "Guangzhou V-SOLUTION Electronic Technology Co., Ltd.",
        "address_1": "Room 406,Originality Building B3, NO.162 Science Avenue,Science Town",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "409BCD": {
        "oui_hex": "40-9B-CD",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "002EC7": {
        "oui_hex": "00-2E-C7",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "488EEF": {
        "oui_hex": "48-8E-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "547595": {
        "oui_hex": "54-75-95",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "C47154": {
        "oui_hex": "C4-71-54",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "586163": {
        "oui_hex": "58-61-63",
        "organization": "Quantum Networks (SG) Pte. Ltd.",
        "address_1": "8, UBI ROAD, 2 ZERVEX #08-10,",
        "address_2": "Singapore    408538",
        "country": "SG"
    },
    "EC3DFD": {
        "oui_hex": "EC-3D-FD",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "94D029": {
        "oui_hex": "94-D0-29",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "308454": {
        "oui_hex": "30-84-54",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "5C0339": {
        "oui_hex": "5C-03-39",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F82819": {
        "oui_hex": "F8-28-19",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "0015E5": {
        "oui_hex": "00-15-E5",
        "organization": "Cheertek Inc.",
        "address_1": "No.2, Du-Sing First Road, Science-Based Industrial Park,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "50E971": {
        "oui_hex": "50-E9-71",
        "organization": "Jibo, Inc.",
        "address_1": "230 Congress Street",
        "address_2": "Boston  MA  02110",
        "country": "US"
    },
    "30F77F": {
        "oui_hex": "30-F7-7F",
        "organization": "S Mobile Devices Limited",
        "address_1": "Unit B-303, 3rd Floor, Tower-B, Plot No-7,Advant IT Park Ltd , Sector-142",
        "address_2": "NOIDA  Uttar Pradesh  201301",
        "country": "IN"
    },
    "D86C63": {
        "oui_hex": "D8-6C-63",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "0840F3": {
        "oui_hex": "08-40-F3",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "94FBB2": {
        "oui_hex": "94-FB-B2",
        "organization": "SHENZHEN GONGJIN ELECTRONICS CO.,LT",
        "address_1": "No.1, Songgang Avenue, Songgang Street, Bao’an District",
        "address_2": "Shenzhen  Guangdong  518105",
        "country": "CN"
    },
    "001E99": {
        "oui_hex": "00-1E-99",
        "organization": "Vantanol Industrial Corporation",
        "address_1": "9F, NO 31 . Shin-Tai Road",
        "address_2": "Jubei City  Shinchu  302",
        "country": "TW"
    },
    "58B633": {
        "oui_hex": "58-B6-33",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "5C5181": {
        "oui_hex": "5C-51-81",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "608E08": {
        "oui_hex": "60-8E-08",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "543D37": {
        "oui_hex": "54-3D-37",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2CE6CC": {
        "oui_hex": "2C-E6-CC",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00227F": {
        "oui_hex": "00-22-7F",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "74911A": {
        "oui_hex": "74-91-1A",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "00C05D": {
        "oui_hex": "00-C0-5D",
        "organization": "L&N TECHNOLOGIES",
        "address_1": "2899 AGOURA ROAD #196",
        "address_2": "WESTLAKE VILLAGE  CA  91361-3200",
        "country": "US"
    },
    "58C583": {
        "oui_hex": "58-C5-83",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "18204C": {
        "oui_hex": "18-20-4C",
        "organization": "Kummler+Matter AG",
        "address_1": "Hohlstrasse 176",
        "address_2": "Zürich    8004",
        "country": "CH"
    },
    "18D225": {
        "oui_hex": "18-D2-25",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "18B430": {
        "oui_hex": "18-B4-30",
        "organization": "Nest Labs Inc.",
        "address_1": "3400 Hillview Ave.",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "30B164": {
        "oui_hex": "30-B1-64",
        "organization": "Power Electronics International Inc.",
        "address_1": "561-8 Plate Drive",
        "address_2": "East Dundee    60118",
        "country": "US"
    },
    "F88A3C": {
        "oui_hex": "F8-8A-3C",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "A40450": {
        "oui_hex": "A4-04-50",
        "organization": "nFore Technology Inc.",
        "address_1": "5F, NO 31, Ln 258, Rulguang Rd",
        "address_2": "Taipei  Neihu District  11491",
        "country": "TW"
    },
    "FC5A1D": {
        "oui_hex": "FC-5A-1D",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "94147A": {
        "oui_hex": "94-14-7A",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "3817E1": {
        "oui_hex": "38-17-E1",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "9828A6": {
        "oui_hex": "98-28-A6",
        "organization": "COMPAL INFORMATION (KUNSHAN) CO., LTD.",
        "address_1": "NO. 25, THE 3RD Street KUNSHAN EXPORT PROCESSING ZONE",
        "address_2": "KUNSHAN  SUZHOU  215300",
        "country": "CN"
    },
    "943FC2": {
        "oui_hex": "94-3F-C2",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "681DEF": {
        "oui_hex": "68-1D-EF",
        "organization": "Shenzhen CYX Technology Co., Ltd.",
        "address_1": "2/F, Bldg. 6, Guangxi Industrial Park, Jianshe Rd.,  Longhua New Dist., Shenzhen",
        "address_2": "Shenzhen    518109",
        "country": "CN"
    },
    "B40016": {
        "oui_hex": "B4-00-16",
        "organization": " INGENICO TERMINALS SAS",
        "address_1": "28-32 BOULEVARD DE GRENELLE",
        "address_2": "PARIS    75015",
        "country": "FR"
    },
    "AC203E": {
        "oui_hex": "AC-20-3E",
        "organization": "Wuhan Tianyu Information Industry Co., Ltd.",
        "address_1": "HUST Industry Park, East-Lake Development Zone",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "B01F29": {
        "oui_hex": "B0-1F-29",
        "organization": "Helvetia INC.",
        "address_1": "8-11 tokaichi-nishimachi, kitaku",
        "address_2": "Okayama  okayama  7000856",
        "country": "JP"
    },
    "880F10": {
        "oui_hex": "88-0F-10",
        "organization": "Huami Information Technology Co.,Ltd.",
        "address_1": "Room 1201 Building A4, National Animation Industry Base",
        "address_2": "Hefei  Anhui  230088",
        "country": "CN"
    },
    "14612F": {
        "oui_hex": "14-61-2F",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "00309D": {
        "oui_hex": "00-30-9D",
        "organization": "Nimble Microsystems, Inc.",
        "address_1": "50 Church Street - 5th Floor",
        "address_2": "Cambridge  MA  02138",
        "country": "US"
    },
    "8C210A": {
        "oui_hex": "8C-21-0A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan",
        "address_2": "shenzhen  guangdong Province  518057",
        "country": "CN"
    },
    "4C189A": {
        "oui_hex": "4C-18-9A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "CC4B73": {
        "oui_hex": "CC-4B-73",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "0015DC": {
        "oui_hex": "00-15-DC",
        "organization": "KT&C Co., Ltd.",
        "address_1": "487-4, KT&C Bldg.",
        "address_2": "GangSeo-Ku  Seoul  157-849",
        "country": "KR"
    },
    "00187D": {
        "oui_hex": "00-18-7D",
        "organization": "Armorlink Co .Ltd",
        "address_1": "No. 515 of Xinzhuang Industry Park Shenfu Road",
        "address_2": "Shanghai Province  Shanghai  201108",
        "country": "CN"
    },
    "F430B9": {
        "oui_hex": "F4-30-B9",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0019F0": {
        "oui_hex": "00-19-F0",
        "organization": "UNIONMAN TECHNOLOGY CO.,LTD",
        "address_1": "18F, HUAYANG TOWER,YANDAYI ROAD",
        "address_2": "HUIZHOU  GUANGDONG  516007",
        "country": "CN"
    },
    "C8DB26": {
        "oui_hex": "C8-DB-26",
        "organization": "Logitech",
        "address_1": "7700 Gateway Blvd",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "A40E2B": {
        "oui_hex": "A4-0E-2B",
        "organization": "Facebook Inc",
        "address_1": "1 Hacker Way",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "AC4E2E": {
        "oui_hex": "AC-4E-2E",
        "organization": "Shenzhen JingHanDa Electronics Co.Ltd",
        "address_1": "5th Floor,No 4 ,Road 1,ShangXue Technology industrial Park,LongGang district,ShenZhen,GuangDong,China",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "4C910C": {
        "oui_hex": "4C-91-0C",
        "organization": " Lanix Internacional, S.A. de C.V.",
        "address_1": "Carretera Nogales Km8.5",
        "address_2": "Hermosillo  Sonora  83160",
        "country": "MX"
    },
    "A47886": {
        "oui_hex": "A4-78-86",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "0403D6": {
        "oui_hex": "04-03-D6",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "5C1A6F": {
        "oui_hex": "5C-1A-6F",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "5/F,Building 8, 2388 ChenHang Road, MinHang District",
        "address_2": "shanghai    201114",
        "country": "CN"
    },
    "3C4CD0": {
        "oui_hex": "3C-4C-D0",
        "organization": "CERAGON NETWORKS",
        "address_1": "24 RAUEL WALLENBERG STREET",
        "address_2": "TEL-AVIV    96719",
        "country": "IL"
    },
    "F40E83": {
        "oui_hex": "F4-0E-83",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "98F7D7": {
        "oui_hex": "98-F7-D7",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "B4BFF6": {
        "oui_hex": "B4-BF-F6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2C3AE8": {
        "oui_hex": "2C-3A-E8",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "88BD78": {
        "oui_hex": "88-BD-78",
        "organization": "Flaircomm Microelectronics,Inc.",
        "address_1": "7F, Guomai Building, Guomai Science and Technology Park,  116 East JiangBin Road,",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "58C5CB": {
        "oui_hex": "58-C5-CB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "206BE7": {
        "oui_hex": "20-6B-E7",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "182CB4": {
        "oui_hex": "18-2C-B4",
        "organization": "Nectarsoft Co., Ltd.",
        "address_1": "330, Seongam-ro, Mapo-gu",
        "address_2": "Seoul  Seoul  03920",
        "country": "KR"
    },
    "54C9DF": {
        "oui_hex": "54-C9-DF",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "74F61C": {
        "oui_hex": "74-F6-1C",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "B8FFB3": {
        "oui_hex": "B8-FF-B3",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "EC237B": {
        "oui_hex": "EC-23-7B",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A0C9A0": {
        "oui_hex": "A0-C9-A0",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "982DBA": {
        "oui_hex": "98-2D-BA",
        "organization": "Fibergate Inc.",
        "address_1": "KDX Shibadaimon.Bld 2F 2-10-12 Shibadaimon",
        "address_2": "Tokyo  Minato-ku  1050012",
        "country": "JP"
    },
    "84C0EF": {
        "oui_hex": "84-C0-EF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "00A38E": {
        "oui_hex": "00-A3-8E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0D55E": {
        "oui_hex": "E0-D5-5E",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "A040A0": {
        "oui_hex": "A0-40-A0",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000D2B": {
        "oui_hex": "00-0D-2B",
        "organization": "Racal Instruments",
        "address_1": "4 Goodyear Street",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "004066": {
        "oui_hex": "00-40-66",
        "organization": "APRESIA Systems Ltd",
        "address_1": " Tsukuba Network Technical Center, Tsukuba Network",
        "address_2": "Tsuchiura-shi  Ibaraki-ken  300-0026",
        "country": "JP"
    },
    "48A74E": {
        "oui_hex": "48-A7-4E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "BC8AE8": {
        "oui_hex": "BC-8A-E8",
        "organization": "QING DAO HAIER TELECOM CO.,LTD.",
        "address_1": "No 1 Haier Road Hi-tech Zone",
        "address_2": "Qingdao    266000",
        "country": "CN"
    },
    "F4DE0C": {
        "oui_hex": "F4-DE-0C",
        "organization": "ESPOD Ltd.",
        "address_1": "6 Marjanishvili St. (Green Building) | 0102 Tbilisi | Georgia",
        "address_2": "Tbilisi  Tbilisi  0102",
        "country": "GE"
    },
    "3C5282": {
        "oui_hex": "3C-52-82",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "08ED02": {
        "oui_hex": "08-ED-02",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E8FDE8": {
        "oui_hex": "E8-FD-E8",
        "organization": "CeLa Link Corporation",
        "address_1": "401-1, Partners Tower1, Gasan digital 1-ro 83, Geumcheon-gu",
        "address_2": "Seoul    08589",
        "country": "KR"
    },
    "28C63F": {
        "oui_hex": "28-C6-3F",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "88CC45": {
        "oui_hex": "88-CC-45",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "600837": {
        "oui_hex": "60-08-37",
        "organization": "ivvi Scientific(Nanchang)Co.Ltd",
        "address_1": "Coolpad Cyber Harbor,2nd Mengxi Road,Hi-TechIndustrial Park(North),NanShan District,ShenZhen,P.R.C.",
        "address_2": "shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "EC363F": {
        "oui_hex": "EC-36-3F",
        "organization": "Markov Corporation",
        "address_1": "650 Vaqueros Avenue, Suite A",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "5804CB": {
        "oui_hex": "58-04-CB",
        "organization": "Tianjin Huisun Technology Co.,Ltd.",
        "address_1": "4/f, Building 3, No 1 Haitai Huake Street (outside Ring Road)",
        "address_2": "  Tianjin  300384",
        "country": "CN"
    },
    "60D7E3": {
        "oui_hex": "60-D7-E3",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "1893D7": {
        "oui_hex": "18-93-D7",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A8B86E": {
        "oui_hex": "A8-B8-6E",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "CC90E8": {
        "oui_hex": "CC-90-E8",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "7C4F7D": {
        "oui_hex": "7C-4F-7D",
        "organization": "Sawwave",
        "address_1": "SKn TechnoPark 1207",
        "address_2": "SeongNam-Si  Gyenggi-do  13207",
        "country": "KR"
    },
    "9CAC6D": {
        "oui_hex": "9C-AC-6D",
        "organization": "Universal Electronics, Inc.",
        "address_1": "201 E. Sandpointe Ave",
        "address_2": "Santa Ana  CA  92707",
        "country": "US"
    },
    "08EA40": {
        "oui_hex": "08-EA-40",
        "organization": "SHENZHEN BILIAN ELECTRONIC CO.，LTD",
        "address_1": "NO.268， Fuqian Rd, Jutang community, Guanlan Town, Longhua New district",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "00D095": {
        "oui_hex": "00-D0-95",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "Calabasas  CA  91301",
        "country": "US"
    },
    "0020DA": {
        "oui_hex": "00-20-DA",
        "organization": "Alcatel-Lucent Enterprise",
        "address_1": "26801 West Agoura Road",
        "address_2": "CALABASAS  CA  91301",
        "country": "US"
    },
    "6C5976": {
        "oui_hex": "6C-59-76",
        "organization": "Shanghai Tricheer Technology Co.,Ltd.",
        "address_1": "Rm 907, Building 1, Lane 399, Shengxia Road,Zhangjiang Hi-Tech Park,Pudong District,Shanghai",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "7C7B8B": {
        "oui_hex": "7C-7B-8B",
        "organization": "Control Concepts, Inc.",
        "address_1": "18760 Lake Dr. East",
        "address_2": "Chanhassen  MN  55317",
        "country": "US"
    },
    "84A9C4": {
        "oui_hex": "84-A9-C4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A0086F": {
        "oui_hex": "A0-08-6F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "34CE00": {
        "oui_hex": "34-CE-00",
        "organization": "XIAOMI Electronics,CO.,LTD",
        "address_1": "Xiaomi Building, No.68 Qinghe Middle Street",
        "address_2": "Haidian District  Beijing  100085",
        "country": "CN"
    },
    "D06F82": {
        "oui_hex": "D0-6F-82",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A0F479": {
        "oui_hex": "A0-F4-79",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "844765": {
        "oui_hex": "84-47-65",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C4FF1F": {
        "oui_hex": "C4-FF-1F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A0C4A5": {
        "oui_hex": "A0-C4-A5",
        "organization": "SYGN HOUSE CO.,LTD",
        "address_1": "2-9-14 Tamagawa-denenchofu",
        "address_2": "Setagaya-ku  Tokyo  1580085",
        "country": "JP"
    },
    "B83765": {
        "oui_hex": "B8-37-65",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "345BBB": {
        "oui_hex": "34-5B-BB",
        "organization": "GD Midea Air-Conditioning Equipment Co.,Ltd.",
        "address_1": "Midea Global Innovation Center,Beijiao Town,Shunde",
        "address_2": "Foshan  Guangdong  528311",
        "country": "CN"
    },
    "C40BCB": {
        "oui_hex": "C4-0B-CB",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "84AFEC": {
        "oui_hex": "84-AF-EC",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bld.,30-20,Ohsu 3-chome,Naka-ku",
        "address_2": "Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "5CC6E9": {
        "oui_hex": "5C-C6-E9",
        "organization": "Edifier International",
        "address_1": "Suit 2207, 22nd floor, Tower II, Lippo centre, 89 Queensway",
        "address_2": "Hong Kong    070",
        "country": "CN"
    },
    "98DDEA": {
        "oui_hex": "98-DD-EA",
        "organization": "Infinix mobility limited",
        "address_1": "RMS 05-15, 13A/F SOUTH TOWER WORLD FINANCE CTR HARBOUR CITY 17 CANTON RD TST KLN HONG KONG",
        "address_2": "HongKong  HongKong  999077",
        "country": "HK"
    },
    "001D44": {
        "oui_hex": "00-1D-44",
        "organization": "Krohne",
        "address_1": "Ludwig-Krohne-Str. 5",
        "address_2": "Duisburg    47058",
        "country": "DE"
    },
    "A8A198": {
        "oui_hex": "A8-A1-98",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "E0C0D1": {
        "oui_hex": "E0-C0-D1",
        "organization": "CK Telecom (Shenzhen) Limited",
        "address_1": "Floor 9th, Building 4C,Software Industry Base, Xuefu Road, Hi-Tech Park, Nanshan Dist.",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00219E": {
        "oui_hex": "00-21-9E",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "ACB57D": {
        "oui_hex": "AC-B5-7D",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "D4619D": {
        "oui_hex": "D4-61-9D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0498B": {
        "oui_hex": "D0-49-8B",
        "organization": "ZOOM SERVER",
        "address_1": "North keyuan Road",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "0827CE": {
        "oui_hex": "08-27-CE",
        "organization": "NAGANO KEIKI CO., LTD.",
        "address_1": "2150 IKUTA",
        "address_2": "UEDA  NAGANO  386-0411",
        "country": "JP"
    },
    "C0D3C0": {
        "oui_hex": "C0-D3-C0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "948BC1": {
        "oui_hex": "94-8B-C1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "14568E": {
        "oui_hex": "14-56-8E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "14BD61": {
        "oui_hex": "14-BD-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "54E061": {
        "oui_hex": "54-E0-61",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "503A7D": {
        "oui_hex": "50-3A-7D",
        "organization": "AlphaTech PLC Int’l Co., Ltd.",
        "address_1": "13F., No.618, Sec. 7, New Taipei Blvd., Xinzhuang Dist.,",
        "address_2": "New Taipei City    24260",
        "country": "TW"
    },
    "F4C4D6": {
        "oui_hex": "F4-C4-D6",
        "organization": "Shenzhen Xinfa Electronic Co.,ltd",
        "address_1": "No 57, Baoli Road, Buji Town",
        "address_2": "Longgang District  Shenzhen, Guangdong   518112",
        "country": "CN"
    },
    "6837E9": {
        "oui_hex": "68-37-E9",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "2CA17D": {
        "oui_hex": "2C-A1-7D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "D83214": {
        "oui_hex": "D8-32-14",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "10954B": {
        "oui_hex": "10-95-4B",
        "organization": "Megabyte Ltd.",
        "address_1": "Unit 507, 5/F, Building 12W, NO.12 Science Park Avenue, Hong Kong Science Park, Shatin, New Territories",
        "address_2": "Hong Kong    NA",
        "country": "HK"
    },
    "D8325A": {
        "oui_hex": "D8-32-5A",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "9CDA3E": {
        "oui_hex": "9C-DA-3E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "283F69": {
        "oui_hex": "28-3F-69",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "002CC8": {
        "oui_hex": "00-2C-C8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C0028D": {
        "oui_hex": "C0-02-8D",
        "organization": "WINSTAR Display CO.,Ltd",
        "address_1": "1F., No.77, Ln. 188, Pinghe S. Rd., Daya Dist., Taichung City 428, Taiwan (R.O.C.)",
        "address_2": "Taichung City    428",
        "country": "TW"
    },
    "E89FEC": {
        "oui_hex": "E8-9F-EC",
        "organization": "CHENGDU KT ELECTRONIC HI-TECH CO.,LTD",
        "address_1": "No.9, 3rd Wuke Road, Wuhou District",
        "address_2": "Chengdu  Sichuan Province  610045",
        "country": "CN"
    },
    "802689": {
        "oui_hex": "80-26-89",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "F8AB05": {
        "oui_hex": "F8-AB-05",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "7C5049": {
        "oui_hex": "7C-50-49",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E47DEB": {
        "oui_hex": "E4-7D-EB",
        "organization": "Shanghai Notion Information Technology CO.,LTD.",
        "address_1": "Room 201,Building 3,NO 289,Bisheng Rd,Pudong district,Shanghai,China",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "C4B9CD": {
        "oui_hex": "C4-B9-CD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D461FE": {
        "oui_hex": "D4-61-FE",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "2C4D54": {
        "oui_hex": "2C-4D-54",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "349672": {
        "oui_hex": "34-96-72",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "64B473": {
        "oui_hex": "64-B4-73",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "7451BA": {
        "oui_hex": "74-51-BA",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "6CB4A7": {
        "oui_hex": "6C-B4-A7",
        "organization": "Landauer, Inc.",
        "address_1": "2 Science Road",
        "address_2": "Glenwood  IL  60425",
        "country": "US"
    },
    "7802F8": {
        "oui_hex": "78-02-F8",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "00238A": {
        "oui_hex": "00-23-8A",
        "organization": "Ciena Corporation",
        "address_1": "920 Elkridge Landing",
        "address_2": "Linthicum  MD  21090",
        "country": "US"
    },
    "001081": {
        "oui_hex": "00-10-81",
        "organization": "DPS, INC.",
        "address_1": "4922 EAST YALE AVENUE",
        "address_2": "FRESNO  CA  93727",
        "country": "US"
    },
    "40F385": {
        "oui_hex": "40-F3-85",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "887873": {
        "oui_hex": "88-78-73",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F87588": {
        "oui_hex": "F8-75-88",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F44C7F": {
        "oui_hex": "F4-4C-7F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "28A24B": {
        "oui_hex": "28-A2-4B",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "080027": {
        "oui_hex": "08-00-27",
        "organization": "PCS Systemtechnik GmbH",
        "address_1": "600 Suffold St",
        "address_2": "Lowell  MA  01854",
        "country": "US"
    },
    "F8A5C5": {
        "oui_hex": "F8-A5-C5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7C5A1C": {
        "oui_hex": "7C-5A-1C",
        "organization": "Sophos Ltd",
        "address_1": "The Pentagon",
        "address_2": "Abingdon  Oxfordshire  OX14 3YP",
        "country": "GB"
    },
    "B0F1EC": {
        "oui_hex": "B0-F1-EC",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road Hsinchu Industrial Park, Hukou",
        "address_2": "Hsinchu  Taiwan ROC.  30352",
        "country": "TW"
    },
    "542B57": {
        "oui_hex": "54-2B-57",
        "organization": "Night Owl SP",
        "address_1": "4720 Radio Rd",
        "address_2": "Naples  FL  34104",
        "country": "US"
    },
    "501E2D": {
        "oui_hex": "50-1E-2D",
        "organization": "StreamUnlimited Engineering GmbH",
        "address_1": "Gutheil-Schoder-Gasse 10",
        "address_2": "Vienna    1100",
        "country": "AT"
    },
    "E45D51": {
        "oui_hex": "E4-5D-51",
        "organization": "SFR",
        "address_1": "12 rue jean-philippe Rameau CS 80001",
        "address_2": "La plaine saint denis   FRANCE  93634",
        "country": "FR"
    },
    "EC01EE": {
        "oui_hex": "EC-01-EE",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "6049C1": {
        "oui_hex": "60-49-C1",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "702084": {
        "oui_hex": "70-20-84",
        "organization": "Hon Hai Precision Ind. Co., Ltd.",
        "address_1": "GuangDongShenZhen",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "CN"
    },
    "9C6650": {
        "oui_hex": "9C-66-50",
        "organization": "Glodio Technolies Co.,Ltd Tianjin Branch",
        "address_1": "Room 904, No.1-2 LanYuan Road, HuaYuan Industrial Area",
        "address_2": "TianJin  TianJin  300384",
        "country": "CN"
    },
    "A0A33B": {
        "oui_hex": "A0-A3-3B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C67A2": {
        "oui_hex": "7C-67-A2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00E05A": {
        "oui_hex": "00-E0-5A",
        "organization": "GALEA NETWORK SECURITY",
        "address_1": "2 PLACE du COMMERCE - STE #320",
        "address_2": "BROSSARD, QUEBEC J4W 2T8",
        "country": "CA"
    },
    "48A380": {
        "oui_hex": "48-A3-80",
        "organization": "Gionee Communication Equipment Co.,Ltd.",
        "address_1": "21/F,Times Technology Building,No. 7028,Shennan Avenue,Futian District",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "94652D": {
        "oui_hex": "94-65-2D",
        "organization": "OnePlus Technology (Shenzhen) Co., Ltd",
        "address_1": "18C02, 18C03, 18C04 ,18C05,TAIRAN BUILDING,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "1CB857": {
        "oui_hex": "1C-B8-57",
        "organization": "Becon Technologies Co,.Ltd.",
        "address_1": "Room C405-A Induckwon IT Vally, 40, Imiro",
        "address_2": "Uiwang city  Kyunggi-do  16006",
        "country": "KR"
    },
    "682737": {
        "oui_hex": "68-27-37",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "F06E32": {
        "oui_hex": "F0-6E-32",
        "organization": "MICROTEL INNOVATION S.R.L.",
        "address_1": "Via Armentera 8",
        "address_2": "BORGO VALSUGANA  TN  38051",
        "country": "IT"
    },
    "54C415": {
        "oui_hex": "54-C4-15",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "3CF862": {
        "oui_hex": "3C-F8-62",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2816AD": {
        "oui_hex": "28-16-AD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0060D3": {
        "oui_hex": "00-60-D3",
        "organization": "AT&T",
        "address_1": "3300 E Renner Road",
        "address_2": "Richardson  TX  75082",
        "country": "US"
    },
    "848DC7": {
        "oui_hex": "84-8D-C7",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "001992": {
        "oui_hex": "00-19-92",
        "organization": "Adtran Inc",
        "address_1": "901 Explorer Blvd.",
        "address_2": "Huntsville  AL  35806-2807",
        "country": "US"
    },
    "045D4B": {
        "oui_hex": "04-5D-4B",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "78AF58": {
        "oui_hex": "78-AF-58",
        "organization": "GIMASI SA",
        "address_1": "Via Luigi Lavizzari 18",
        "address_2": "Mendrisio  TI  6850",
        "country": "CH"
    },
    "90505A": {
        "oui_hex": "90-50-5A",
        "organization": "unGlue, Inc",
        "address_1": "7150 Helmsdale Circle",
        "address_2": "West Hils  CA  91307",
        "country": "US"
    },
    "8C9351": {
        "oui_hex": "8C-93-51",
        "organization": "Jigowatts Inc.",
        "address_1": "5892-5 Endo",
        "address_2": "Fujisawa  Kanagawa  252-0816",
        "country": "JP"
    },
    "D838FC": {
        "oui_hex": "D8-38-FC",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "3478D7": {
        "oui_hex": "34-78-D7",
        "organization": "Gionee Communication Equipment Co.,Ltd.",
        "address_1": "21/F,Times Technology Building,No. 7028,Shennan Avenue,Futian District",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "5CCCA0": {
        "oui_hex": "5C-CC-A0",
        "organization": "Gridwiz Inc.",
        "address_1": "4F, 25 Sanun-ro 208beon-gil, Bundang-gu",
        "address_2": "Seongnam  Gyeonggi  13460",
        "country": "KR"
    },
    "6831FE": {
        "oui_hex": "68-31-FE",
        "organization": "Teladin Co.,Ltd.",
        "address_1": "Digital-ro 33 gil, Guro-gu",
        "address_2": "Seoul    08377",
        "country": "KR"
    },
    "5800E3": {
        "oui_hex": "58-00-E3",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "2C0BE9": {
        "oui_hex": "2C-0B-E9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C43018": {
        "oui_hex": "C4-30-18",
        "organization": "MCS Logic Inc.",
        "address_1": "6F. Samho Center B Bldg., 275-6,Yangjae-Dong, Secho-Ku,Seoul",
        "address_2": "Seoul    137-941",
        "country": "KR"
    },
    "D0FF98": {
        "oui_hex": "D0-FF-98",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B0E5ED": {
        "oui_hex": "B0-E5-ED",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C486E9": {
        "oui_hex": "C4-86-E9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "000AE4": {
        "oui_hex": "00-0A-E4",
        "organization": "Wistron Corporation",
        "address_1": "21F, No. 88, Section 1, Hsin Tai  Wu Rd.",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "344B3D": {
        "oui_hex": "34-4B-3D",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "FC3CE9": {
        "oui_hex": "FC-3C-E9",
        "organization": "Tsingtong Technologies Co, Ltd.",
        "address_1": "Rm A03-72, Floor B1, Building 1, No.13 Dazhongsi, Haidian District",
        "address_2": "Beijing    100098",
        "country": "CN"
    },
    "A408F5": {
        "oui_hex": "A4-08-F5",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "00B091": {
        "oui_hex": "00-B0-91",
        "organization": "Transmeta Corp.",
        "address_1": "3940 Freedom Circle",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "ACC662": {
        "oui_hex": "AC-C6-62",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "886B44": {
        "oui_hex": "88-6B-44",
        "organization": "Sunnovo International Limited",
        "address_1": "1717 Haitai Building",
        "address_2": "Beijing  Beijing  100083",
        "country": "CN"
    },
    "A4580F": {
        "oui_hex": "A4-58-0F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "C8F733": {
        "oui_hex": "C8-F7-33",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "E0A700": {
        "oui_hex": "E0-A7-00",
        "organization": "Verkada Inc",
        "address_1": "325 Sharon Park Drive, Suite 519",
        "address_2": "Menlo Park    94025",
        "country": "US"
    },
    "58404E": {
        "oui_hex": "58-40-4E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0C5F3": {
        "oui_hex": "D0-C5-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC9FEF": {
        "oui_hex": "BC-9F-EF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "20AB37": {
        "oui_hex": "20-AB-37",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60F445": {
        "oui_hex": "60-F4-45",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "48F97C": {
        "oui_hex": "48-F9-7C",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "40B93C": {
        "oui_hex": "40-B9-3C",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "C0BFC0": {
        "oui_hex": "C0-BF-C0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9CD9CB": {
        "oui_hex": "9C-D9-CB",
        "organization": "Lesira Manufacturing Pty Ltd",
        "address_1": "34 Gemsbok Street",
        "address_2": "Pretoria  Gauteng  0186",
        "country": "ZA"
    },
    "94E979": {
        "oui_hex": "94-E9-79",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "A03D6F": {
        "oui_hex": "A0-3D-6F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A0E0AF": {
        "oui_hex": "A0-E0-AF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "187532": {
        "oui_hex": "18-75-32",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO., LTD",
        "address_1": "FL12, TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "4CB81C": {
        "oui_hex": "4C-B8-1C",
        "organization": "SAM Electronics GmbH",
        "address_1": "Behringstr. 120",
        "address_2": "Hamburg  Hamburg  22763",
        "country": "DE"
    },
    "003048": {
        "oui_hex": "00-30-48",
        "organization": "Super Micro Computer, Inc.",
        "address_1": "2051 Junction Avenue",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "44D244": {
        "oui_hex": "44-D2-44",
        "organization": "Seiko Epson Corporation",
        "address_1": "80 Harashinden",
        "address_2": "Shiojiri-shi  Nagano-ken  399-0785",
        "country": "JP"
    },
    "A08CF8": {
        "oui_hex": "A0-8C-F8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7CF95C": {
        "oui_hex": "7C-F9-5C",
        "organization": "U.I. Lapp GmbH",
        "address_1": "Schulze-Delitzsch-Strasse 25",
        "address_2": "Stuttgart    70565",
        "country": "DE"
    },
    "101331": {
        "oui_hex": "10-13-31",
        "organization": "Technicolor",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem - Belgium    B-2650",
        "country": "BE"
    },
    "A4E6B1": {
        "oui_hex": "A4-E6-B1",
        "organization": "Shanghai Joindata Technology Co.,Ltd.",
        "address_1": "26F,Building1,No428,South Yanggao Road,Pudong District",
        "address_2": "Shanghai  Shanghai  200127",
        "country": "CN"
    },
    "C09C04": {
        "oui_hex": "C0-9C-04",
        "organization": "Shaanxi GuoLian Digital TV Technology Co.,Ltd.",
        "address_1": "No. 15, the first Gaoxin road Hi-tech development district",
        "address_2": "Xi'an  Shaanxi  710075",
        "country": "CN"
    },
    "ACD657": {
        "oui_hex": "AC-D6-57",
        "organization": "Shaanxi GuoLian Digital TV Technology Co.,Ltd.",
        "address_1": "Chief Building, Fifth Yannan Road, Qujiang New District",
        "address_2": "xi'an  shaanxi  71000",
        "country": "CN"
    },
    "007686": {
        "oui_hex": "00-76-86",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "8C2FA6": {
        "oui_hex": "8C-2F-A6",
        "organization": "Solid Optics B.V.",
        "address_1": "Huchtstraat 35",
        "address_2": "Almere    1327EC",
        "country": "NL"
    },
    "8C192D": {
        "oui_hex": "8C-19-2D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "00ACE0": {
        "oui_hex": "00-AC-E0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "007532": {
        "oui_hex": "00-75-32",
        "organization": "INID BV",
        "address_1": "Mariettahof 27",
        "address_2": "Haarlem  NH  2033WS",
        "country": "NL"
    },
    "6473E2": {
        "oui_hex": "64-73-E2",
        "organization": "Arbiter Systems, Inc.",
        "address_1": "1324 Vendels Circle",
        "address_2": "Paso Robles  California  93446",
        "country": "US"
    },
    "88C626": {
        "oui_hex": "88-C6-26",
        "organization": "Logitech, Inc",
        "address_1": "4700 NW Camas Meadows Dr",
        "address_2": "Camas  WA  98607",
        "country": "US"
    },
    "D0608C": {
        "oui_hex": "D0-60-8C",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "AC233F": {
        "oui_hex": "AC-23-3F",
        "organization": "Shenzhen Minew Technologies Co., Ltd.",
        "address_1": "H Building, Gangzhilong Science Park, QInglong Road",
        "address_2": "Shenzhen    518109",
        "country": "CN"
    },
    "7C03C9": {
        "oui_hex": "7C-03-C9",
        "organization": "Shenzhen YOUHUA Technology Co., Ltd",
        "address_1": "Room 407 Shenzhen University-town Business Park,Lishan Road,Taoyuan Street,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "B8E937": {
        "oui_hex": "B8-E9-37",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "E45D52": {
        "oui_hex": "E4-5D-52",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "0023F7": {
        "oui_hex": "00-23-F7",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "3C80AA": {
        "oui_hex": "3C-80-AA",
        "organization": "Ransnet Singapore Pte Ltd",
        "address_1": "114, Lavender Street, #08-83, CT Hub 2",
        "address_2": "Singapore  Singapore  338729",
        "country": "SG"
    },
    "B49691": {
        "oui_hex": "B4-96-91",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C82158": {
        "oui_hex": "C8-21-58",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2420C7": {
        "oui_hex": "24-20-C7",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "D4C8B0": {
        "oui_hex": "D4-C8-B0",
        "organization": "Prime Electronics & Satellitics Inc.",
        "address_1": "69,Tung-Yuan Rd",
        "address_2": "Chung-Li City  Tao-Yuan County  32000",
        "country": "TW"
    },
    "446AB7": {
        "oui_hex": "44-6A-B7",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "701CE7": {
        "oui_hex": "70-1C-E7",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "9C2A70": {
        "oui_hex": "9C-2A-70",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "703D15": {
        "oui_hex": "70-3D-15",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "E49E12": {
        "oui_hex": "E4-9E-12",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "0481AE": {
        "oui_hex": "04-81-AE",
        "organization": "Clack Corporation",
        "address_1": "4462 Duraform Lane",
        "address_2": "Windsor  WI  53598",
        "country": "US"
    },
    "9C13AB": {
        "oui_hex": "9C-13-AB",
        "organization": "Chanson Water Co., Ltd.",
        "address_1": "2F, No.88-11, Sec 1, Guangfu Rd, Sanchong Dist.",
        "address_2": "New Taipei City  Taiwan  241",
        "country": "TW"
    },
    "98E476": {
        "oui_hex": "98-E4-76",
        "organization": "Zentan",
        "address_1": "10F-3, No. 260, Sec.2 New Taipei Blvd., Sanchong District",
        "address_2": "New Taipei City    24158",
        "country": "TW"
    },
    "14A51A": {
        "oui_hex": "14-A5-1A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "047503": {
        "oui_hex": "04-75-03",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3CEF8C": {
        "oui_hex": "3C-EF-8C",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "NO.1199 Bin An Road,Binjiang District,HangZhou,P.R.China",
        "address_2": "HangZhou  ZheJiang  310053",
        "country": "CN"
    },
    "FC372B": {
        "oui_hex": "FC-37-2B",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "A4D9A4": {
        "oui_hex": "A4-D9-A4",
        "organization": "neXus ID Solutions AB",
        "address_1": "Telefonvägen 26",
        "address_2": "Stockholm    12626",
        "country": "SE"
    },
    "484D7E": {
        "oui_hex": "48-4D-7E",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "D4E90B": {
        "oui_hex": "D4-E9-0B",
        "organization": "CVT CO.,LTD",
        "address_1": "Secho gu BangBae 3 dong 1001-1",
        "address_2": "seoul  KangNam  KS013",
        "country": "KR"
    },
    "CCB0DA": {
        "oui_hex": "CC-B0-DA",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "7CCC1F": {
        "oui_hex": "7C-CC-1F",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "18F292": {
        "oui_hex": "18-F2-92",
        "organization": "Shannon Systems",
        "address_1": "Suite 1801,Wentong Building,739 Kunming Road, Yangpu, Shanghai",
        "address_2": "Shanghai    200000",
        "country": "CN"
    },
    "8CEA1B": {
        "oui_hex": "8C-EA-1B",
        "organization": "Edgecore Networks Corporation",
        "address_1": "1 Creation RD 3.",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "E02CF3": {
        "oui_hex": "E0-2C-F3",
        "organization": "MRS Electronic GmbH",
        "address_1": "Klaus-Gutsch-Str. 7",
        "address_2": "Rottweil    78628",
        "country": "DE"
    },
    "50B363": {
        "oui_hex": "50-B3-63",
        "organization": "Digitron da Amazonia S/A",
        "address_1": "Av. Eng. Luis Carlos Berrini , 1297",
        "address_2": "São Paulo  São Paulo  04571010",
        "country": "BR"
    },
    "2C0E3D": {
        "oui_hex": "2C-0E-3D",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "58E16C": {
        "oui_hex": "58-E1-6C",
        "organization": "Ying Hua Information Technology (Shanghai)Co., LTD",
        "address_1": "Room 37 ,Building 13b, No. 4 , lane 600, Tianshan Road ,Changning District Shanghai",
        "address_2": "Shanghai    201210",
        "country": "CN"
    },
    "9C7DA3": {
        "oui_hex": "9C-7D-A3",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4C64F": {
        "oui_hex": "A4-C6-4F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "CCFD17": {
        "oui_hex": "CC-FD-17",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "DC9FDB": {
        "oui_hex": "DC-9F-DB",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "002722": {
        "oui_hex": "00-27-22",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "91 E Tasman Dr",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00156D": {
        "oui_hex": "00-15-6D",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "495 Montague Expwy.",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00D78F": {
        "oui_hex": "00-D7-8F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2CBABA": {
        "oui_hex": "2C-BA-BA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "40D3AE": {
        "oui_hex": "40-D3-AE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2CDD95": {
        "oui_hex": "2C-DD-95",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "88E87F": {
        "oui_hex": "88-E8-7F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9CF48E": {
        "oui_hex": "9C-F4-8E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5CF7E6": {
        "oui_hex": "5C-F7-E6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B853AC": {
        "oui_hex": "B8-53-AC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "203CAE": {
        "oui_hex": "20-3C-AE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A03BE3": {
        "oui_hex": "A0-3B-E3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4C3275": {
        "oui_hex": "4C-32-75",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "487A55": {
        "oui_hex": "48-7A-55",
        "organization": "ALE International",
        "address_1": "32 avenue Kléber",
        "address_2": "Colombes    92700",
        "country": "FR"
    },
    "001EAE": {
        "oui_hex": "00-1E-AE",
        "organization": "Continental Automotive Systems Inc.",
        "address_1": "21440 West Lake Cook Road",
        "address_2": "Deer Park  IL  60010",
        "country": "US"
    },
    "502B73": {
        "oui_hex": "50-2B-73",
        "organization": "Tenda Technology Co.,Ltd.Dongguan branch",
        "address_1": "Room 79,Yuanyi Road,Dalang Town,Dongguan Guangdong 523770",
        "address_2": "Dongguan  Guangdong  523770",
        "country": "CN"
    },
    "04BA36": {
        "oui_hex": "04-BA-36",
        "organization": "Li Seng Technology Ltd",
        "address_1": "Rm901, 9/F Shiu Fung Hong Building, 239-241 Wing Lok Street, Hong Kong",
        "address_2": "Hong Kong    0000",
        "country": "HK"
    },
    "107223": {
        "oui_hex": "10-72-23",
        "organization": "TELLESCOM INDUSTRIA E COMERCIO EM TELECOMUNICACAO",
        "address_1": "Av. Buriti, 1900 – Setor B – Distrito Industrial",
        "address_2": "Manaus  Amazonas  69075-000",
        "country": "BR"
    },
    "E0686D": {
        "oui_hex": "E0-68-6D",
        "organization": "Raybased AB",
        "address_1": "A Odhners Gata 41",
        "address_2": "Västra Frölunda    42130",
        "country": "SE"
    },
    "1861C7": {
        "oui_hex": "18-61-C7",
        "organization": "lemonbeat GmbH",
        "address_1": "Deutsche Str. 5",
        "address_2": "Dortmund    44339",
        "country": "DE"
    },
    "9CDC71": {
        "oui_hex": "9C-DC-71",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "B4F81E": {
        "oui_hex": "B4-F8-1E",
        "organization": "Kinova",
        "address_1": "6110, rue Doris-Lussier,",
        "address_2": "Boisbriand  Qc  J7H 0E8",
        "country": "CA"
    },
    "D03DC3": {
        "oui_hex": "D0-3D-C3",
        "organization": "AQ Corporation",
        "address_1": "205, Saneop-ro 155beon-gil, Gwonseon-gu",
        "address_2": "Suwon  Gyeonggi-do  16648",
        "country": "KR"
    },
    "EC01E2": {
        "oui_hex": "EC-01-E2",
        "organization": "FOXCONN INTERCONNECT TECHNOLOGY",
        "address_1": "66-1, Chungshan Rd., Tucheng Dist.",
        "address_2": "New Taipei City  Taiwan (R.O.C.)    23680",
        "country": "TW"
    },
    "B4E782": {
        "oui_hex": "B4-E7-82",
        "organization": "Vivalnk",
        "address_1": "4655 Old Ironsides Dr, #390",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "4409B8": {
        "oui_hex": "44-09-B8",
        "organization": "Salcomp (Shenzhen) CO., LTD.",
        "address_1": "Salcomp Road, Furong Industrial Area, Xinqiao, Shajing, Baoan District",
        "address_2": "Shenzhen  Guangdong  518125",
        "country": "CN"
    },
    "3816D1": {
        "oui_hex": "38-16-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0176A": {
        "oui_hex": "D0-17-6A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D48890": {
        "oui_hex": "D4-88-90",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "5492BE": {
        "oui_hex": "54-92-BE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "205D47": {
        "oui_hex": "20-5D-47",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "10C60C": {
        "oui_hex": "10-C6-0C",
        "organization": "Domino UK Ltd",
        "address_1": "Trafalgar Way",
        "address_2": "Cambridge  Cambridgeshire  CB23 8TU",
        "country": "GB"
    },
    "043110": {
        "oui_hex": "04-31-10",
        "organization": "Inspur Group Co., Ltd.",
        "address_1": "No.1036 Langchao Rd.",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "949AA9": {
        "oui_hex": "94-9A-A9",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "ACAB2E": {
        "oui_hex": "AC-AB-2E",
        "organization": "Beijing LasNubes Technology Co., Ltd.",
        "address_1": "Chao-Yang-Bei-Lu No. 103, Room 1109-1110",
        "address_2": "Beijing    100025",
        "country": "CN"
    },
    "600B03": {
        "oui_hex": "60-0B-03",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "A0AB1B": {
        "oui_hex": "A0-AB-1B",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "D842E2": {
        "oui_hex": "D8-42-E2",
        "organization": "Canary Connect, Inc.",
        "address_1": "132 East 43rd Street",
        "address_2": "New York    10017",
        "country": "US"
    },
    "C8B21E": {
        "oui_hex": "C8-B2-1E",
        "organization": "CHIPSEA TECHNOLOGIES (SHENZHEN) CORP.",
        "address_1": "9F,BLOCK A,GARDEN CITY DIGITAL BUILDING,NO.1079 NANHAI ROAD,NANSHAN DISTRICT",
        "address_2": "SHEN ZHEN  GUANG DONG  518000",
        "country": "CN"
    },
    "000678": {
        "oui_hex": "00-06-78",
        "organization": "D&M Holdings Inc.",
        "address_1": "D&M Building, 2-1 Nisshin-cho",
        "address_2": "Kawasaki-shi  Kanagawa   210-8569",
        "country": "JP"
    },
    "E0286D": {
        "oui_hex": "E0-28-6D",
        "organization": "AVM Audiovisuelles Marketing und Computersysteme GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin  Berlin  10559",
        "country": "DE"
    },
    "884CCF": {
        "oui_hex": "88-4C-CF",
        "organization": "Pulzze Systems, Inc",
        "address_1": "1290-B Reamwood Ave",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "500959": {
        "oui_hex": "50-09-59",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "E41218": {
        "oui_hex": "E4-12-18",
        "organization": "ShenZhen Rapoo Technology Co., Ltd.",
        "address_1": "22,Jinxiu Road East,Pingshan District,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518122",
        "country": "CN"
    },
    "001984": {
        "oui_hex": "00-19-84",
        "organization": "ESTIC Corporation",
        "address_1": "2-5-9 Hashibahigashino-cho",
        "address_2": "Moriguchi  Osaka  570-0031",
        "country": "JP"
    },
    "001628": {
        "oui_hex": "00-16-28",
        "organization": "Magicard Ltd",
        "address_1": "Hampshire Road",
        "address_2": "Weymouth  Dorset  DT4 9XD",
        "country": "GB"
    },
    "702E22": {
        "oui_hex": "70-2E-22",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C8E776": {
        "oui_hex": "C8-E7-76",
        "organization": "PTCOM Technology",
        "address_1": "NO.189-8, SEC. 3, NANJING E. RD., ZHONGSHAN DIST.",
        "address_2": "Taipei    10488",
        "country": "TW"
    },
    "000278": {
        "oui_hex": "00-02-78",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Mae-tan-dong,",
        "address_2": "Suwon  Suwon  KOREA",
        "country": "KR"
    },
    "002399": {
        "oui_hex": "00-23-99",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3dong, yeongtong-gu, Suwon-city",
        "address_2": "suwon    443-742",
        "country": "KR"
    },
    "0017C9": {
        "oui_hex": "00-17-C9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan-3Dong, Yeongtong-Gu",
        "address_2": "Suwon  Geyonggi-Do  443-742",
        "country": "KR"
    },
    "906EBB": {
        "oui_hex": "90-6E-BB",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "18F46A": {
        "oui_hex": "18-F4-6A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "4C0F6E": {
        "oui_hex": "4C-0F-6E",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "78E400": {
        "oui_hex": "78-E4-00",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00212F": {
        "oui_hex": "00-21-2F",
        "organization": "Phoebe Micro Inc.",
        "address_1": "47606 Kato Rd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "3859F9": {
        "oui_hex": "38-59-F9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "EC55F9": {
        "oui_hex": "EC-55-F9",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C4731E": {
        "oui_hex": "C4-73-1E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "416, Maetan 3dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyeonggi-Do  443742",
        "country": "KR"
    },
    "5C0A5B": {
        "oui_hex": "5C-0A-5B",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon    443-743",
        "country": "US"
    },
    "7CE9D3": {
        "oui_hex": "7C-E9-D3",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "1C3E84": {
        "oui_hex": "1C-3E-84",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "B8763F": {
        "oui_hex": "B8-76-3F",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "60F494": {
        "oui_hex": "60-F4-94",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "8056F2": {
        "oui_hex": "80-56-F2",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "7CF854": {
        "oui_hex": "7C-F8-54",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "415, Maetan-3dong, Yeongtong-gu, Suwon-City Gyeonggi-do 443-742",
        "address_2": "Suwon    443-742",
        "country": "KR"
    },
    "001B98": {
        "oui_hex": "00-1B-98",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "GUMI  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "001A8A": {
        "oui_hex": "00-1A-8A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi-City  Gyeong-Buk  730-350",
        "country": "KR"
    },
    "3C5A37": {
        "oui_hex": "3C-5A-37",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F49F54": {
        "oui_hex": "F4-9F-54",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "34C3AC": {
        "oui_hex": "34-C3-AC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44F459": {
        "oui_hex": "44-F4-59",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00265D": {
        "oui_hex": "00-26-5D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CCF9E8": {
        "oui_hex": "CC-F9-E8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D857EF": {
        "oui_hex": "D8-57-EF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "18E2C2": {
        "oui_hex": "18-E2-C2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9852B1": {
        "oui_hex": "98-52-B1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E440E2": {
        "oui_hex": "E4-40-E2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "103B59": {
        "oui_hex": "10-3B-59",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D890E8": {
        "oui_hex": "D8-90-E8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C462EA": {
        "oui_hex": "C4-62-EA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "14F42A": {
        "oui_hex": "14-F4-2A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0808C2": {
        "oui_hex": "08-08-C2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CCFE3C": {
        "oui_hex": "CC-FE-3C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "28BAB5": {
        "oui_hex": "28-BA-B5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "182666": {
        "oui_hex": "18-26-66",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "30D6C9": {
        "oui_hex": "30-D6-C9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "CC07AB": {
        "oui_hex": "CC-07-AB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "002567": {
        "oui_hex": "00-25-67",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BCB1F3": {
        "oui_hex": "BC-B1-F3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1C62B8": {
        "oui_hex": "1C-62-B8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B43A28": {
        "oui_hex": "B4-3A-28",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "78A873": {
        "oui_hex": "78-A8-73",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "001C43": {
        "oui_hex": "00-1C-43",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0023D6": {
        "oui_hex": "00-23-D6",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E4121D": {
        "oui_hex": "E4-12-1D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44D6E1": {
        "oui_hex": "44-D6-E1",
        "organization": "Snuza International Pty. Ltd.",
        "address_1": "Unit 11, Roeland Square, Roeland Street",
        "address_2": "Cape Town  Western Cape  8001",
        "country": "ZA"
    },
    "FC9114": {
        "oui_hex": "FC-91-14",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "486DBB": {
        "oui_hex": "48-6D-BB",
        "organization": "Vestel Elektronik San ve Tic. A.Ş.",
        "address_1": "Organize san",
        "address_2": "Manisa  Turket  45030",
        "country": "TR"
    },
    "002A10": {
        "oui_hex": "00-2A-10",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00A289": {
        "oui_hex": "00-A2-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "44E9DD": {
        "oui_hex": "44-E9-DD",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "000F5E": {
        "oui_hex": "00-0F-5E",
        "organization": "Veo",
        "address_1": "910 Rincon Circle",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001328": {
        "oui_hex": "00-13-28",
        "organization": "Westech Korea Inc.,",
        "address_1": "548-9, Gajwa3-Dong,Seo-ku,",
        "address_2": "Incheon    404-817",
        "country": "KR"
    },
    "B8BF83": {
        "oui_hex": "B8-BF-83",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "8C6102": {
        "oui_hex": "8C-61-02",
        "organization": "Beijing Baofengmojing Technologies Co., Ltd",
        "address_1": "7/F, Tower C, Zhizhen Plaza, No.7 Zhichun Rd, Haidian District",
        "address_2": "Beijing    100191",
        "country": "CN"
    },
    "548CA0": {
        "oui_hex": "54-8C-A0",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "7C79E8": {
        "oui_hex": "7C-79-E8",
        "organization": "PayRange Inc.",
        "address_1": "700 NE Multnomah St. Ste 1400",
        "address_2": "Portland  OR  97232",
        "country": "US"
    },
    "A43111": {
        "oui_hex": "A4-31-11",
        "organization": "ZIV",
        "address_1": "Polígono Parque Tecnológico, 210",
        "address_2": "ZAMUDIO  VIZCAYA  48170",
        "country": "ES"
    },
    "008073": {
        "oui_hex": "00-80-73",
        "organization": "DWB ASSOCIATES",
        "address_1": "9360 SW GEMINI DRIVE",
        "address_2": "BEAVERTON  OR  97005-7151",
        "country": "US"
    },
    "80A1D7": {
        "oui_hex": "80-A1-D7",
        "organization": "Shanghai DareGlobal Technologies Co.,Ltd",
        "address_1": "22F,Info Tech Building,No.1555,Kongjiang Rd.",
        "address_2": "Shanghai    200092",
        "country": "CN"
    },
    "EC1F72": {
        "oui_hex": "EC-1F-72",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93 Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "8C0D76": {
        "oui_hex": "8C-0D-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "84BE52": {
        "oui_hex": "84-BE-52",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "849FB5": {
        "oui_hex": "84-9F-B5",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4CAA0": {
        "oui_hex": "A4-CA-A0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "84E0F4": {
        "oui_hex": "84-E0-F4",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D83062": {
        "oui_hex": "D8-30-62",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D0E54D": {
        "oui_hex": "D0-E5-4D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A0C562": {
        "oui_hex": "A0-C5-62",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "8496D8": {
        "oui_hex": "84-96-D8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0026D9": {
        "oui_hex": "00-26-D9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E8508B": {
        "oui_hex": "E8-50-8B",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "F8042E": {
        "oui_hex": "F8-04-2E",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "00D037": {
        "oui_hex": "00-D0-37",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "84E058": {
        "oui_hex": "84-E0-58",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "707630": {
        "oui_hex": "70-76-30",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "04BBF9": {
        "oui_hex": "04-BB-F9",
        "organization": "Pavilion Data Systems Inc",
        "address_1": "2560 N 1st St, #220",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "E4BEED": {
        "oui_hex": "E4-BE-ED",
        "organization": "Netcore Technology Inc.",
        "address_1": "ORIENTAL CYBERPORT,HIGHTECH 6 ROAD",
        "address_2": "Shenzhen    518057",
        "country": "CN"
    },
    "58FB84": {
        "oui_hex": "58-FB-84",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00A00E": {
        "oui_hex": "00-A0-0E",
        "organization": "NetAlly",
        "address_1": "310 Littleton Road",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "00C017": {
        "oui_hex": "00-C0-17",
        "organization": "NetAlly",
        "address_1": "2075 Research Parkway",
        "address_2": "Colorado Springs  CO  80920",
        "country": "US"
    },
    "5CB066": {
        "oui_hex": "5C-B0-66",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "BC8AA3": {
        "oui_hex": "BC-8A-A3",
        "organization": "NHN Entertainment",
        "address_1": "Play Museum, 629 Sampyeong-dong, Bundang-gu",
        "address_2": "Seongnam-si, Gyeonggi-do    463-400",
        "country": "KR"
    },
    "A8BD27": {
        "oui_hex": "A8-BD-27",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "345760": {
        "oui_hex": "34-57-60",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "C0D391": {
        "oui_hex": "C0-D3-91",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D49B5C": {
        "oui_hex": "D4-9B-5C",
        "organization": "Chongqing Miedu Technology Co., Ltd.",
        "address_1": "7-602 No.118 DaPing Main Street Yuzhong District",
        "address_2": "Chongqing    400000",
        "country": "CN"
    },
    "E8EB11": {
        "oui_hex": "E8-EB-11",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "44BFE3": {
        "oui_hex": "44-BF-E3",
        "organization": "Shenzhen Longtech Electronics Co.,Ltd",
        "address_1": "No.148 Zhengfeng Industrial Area Donghuan RD Huangpu Village Shaijing Town Baoan District",
        "address_2": "Shenzhen  Guangdong  518125",
        "country": "CN"
    },
    "3C6FEA": {
        "oui_hex": "3C-6F-EA",
        "organization": "Panasonic India Pvt. Ltd.",
        "address_1": "12th Floor, Ambience Tower, Ambience Island, NH - 8",
        "address_2": "Gurgaon  Haryana  122002",
        "country": "IN"
    },
    "002261": {
        "oui_hex": "00-22-61",
        "organization": "Frontier Silicon Ltd",
        "address_1": "137 Euston Road",
        "address_2": "London    NW12AA",
        "country": "GB"
    },
    "001988": {
        "oui_hex": "00-19-88",
        "organization": "Wi2Wi, Inc",
        "address_1": "2107 N. 1st Street",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "18DC56": {
        "oui_hex": "18-DC-56",
        "organization": "Yulong Computer Telecommunication Scientific (Shenzhen) Co.,Ltd",
        "address_1": "8/F.high Tech Plaza,TianAn Cyberpark,Chegongmiao",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "0016F2": {
        "oui_hex": "00-16-F2",
        "organization": "Dmobile System Co., Ltd.",
        "address_1": "2F, No.13-20, Sec.6, Mincyuan E.Rd,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "34074F": {
        "oui_hex": "34-07-4F",
        "organization": "AccelStor, Inc.",
        "address_1": "10F, No. 465, Sec. 6, Zhongxiao E. Rd., Nangang Dist.",
        "address_2": "Taipei City    11557",
        "country": "TW"
    },
    "B4A984": {
        "oui_hex": "B4-A9-84",
        "organization": "Symantec Corporation",
        "address_1": "350 Ellis Street",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "B0B28F": {
        "oui_hex": "B0-B2-8F",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "441441": {
        "oui_hex": "44-14-41",
        "organization": "AudioControl Inc.",
        "address_1": "22410 70Th Ave West, STE 1",
        "address_2": "Mountlake Terrace  WA  98043",
        "country": "US"
    },
    "C88D83": {
        "oui_hex": "C8-8D-83",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "00E011": {
        "oui_hex": "00-E0-11",
        "organization": "UNIDEN CORPORATION",
        "address_1": "2-12-7 Hatchobori,",
        "address_2": "Chuo-ku  Tokyo  104-8512",
        "country": "JP"
    },
    "002555": {
        "oui_hex": "00-25-55",
        "organization": "Visonic Technologies 1993 Ltd.",
        "address_1": "23 Habarzel st'",
        "address_2": "Tel - Aviv    69710",
        "country": "IL"
    },
    "58986F": {
        "oui_hex": "58-98-6F",
        "organization": "Revolution Display",
        "address_1": "912 Ruberta Ave",
        "address_2": "Glendale  CA  91201",
        "country": "US"
    },
    "C81FBE": {
        "oui_hex": "C8-1F-BE",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "203DB2": {
        "oui_hex": "20-3D-B2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "48D539": {
        "oui_hex": "48-D5-39",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "001F9A": {
        "oui_hex": "00-1F-9A",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75082-4399",
        "country": "US"
    },
    "000A0E": {
        "oui_hex": "00-0A-0E",
        "organization": "Invivo Research Inc.",
        "address_1": "12601 Research Parkway",
        "address_2": "Orlando  Florida  32826",
        "country": "US"
    },
    "001660": {
        "oui_hex": "00-16-60",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001E7E": {
        "oui_hex": "00-1E-7E",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "001365": {
        "oui_hex": "00-13-65",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000438": {
        "oui_hex": "00-04-38",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "000EC0": {
        "oui_hex": "00-0E-C0",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "D84FB8": {
        "oui_hex": "D8-4F-B8",
        "organization": "LG ELECTRONICS",
        "address_1": "84 Wanam-ro Seongsan-gu",
        "address_2": "Changwon-si  Gyeongsangnam-do  642-713",
        "country": "KR"
    },
    "000AEB": {
        "oui_hex": "00-0A-EB",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Hi-Tech Park R1-B3",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "2C3731": {
        "oui_hex": "2C-37-31",
        "organization": "SHENZHEN YIFANG DIGITAL TECHNOLOGY CO.,LTD.",
        "address_1": "Building # 22 and #23, Zone 5, Bai Wang Xin Industrial Park, Song Bai Road",
        "address_2": "ShenZhen  GUANGDONG  518108",
        "country": "CN"
    },
    "60EE5C": {
        "oui_hex": "60-EE-5C",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "6488FF": {
        "oui_hex": "64-88-FF",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "35 East Mianxing Road,High-Tech Park,",
        "address_2": "MianYang  SiChuan  621000",
        "country": "CN"
    },
    "002162": {
        "oui_hex": "00-21-62",
        "organization": "Nortel Networks",
        "address_1": "8200 Dixie Rd",
        "address_2": "Brampton  Ontario  0000",
        "country": "CA"
    },
    "02E6D3": {
        "oui_hex": "02-E6-D3",
        "organization": "NIXDORF COMPUTER CORP.",
        "address_1": "NIXDORF TECHNOLOGY CENTER",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0016B9": {
        "oui_hex": "00-16-B9",
        "organization": "ProCurve Networking by HP",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "C4084A": {
        "oui_hex": "C4-08-4A",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "000801": {
        "oui_hex": "00-08-01",
        "organization": "HighSpeed Surfing Inc.",
        "address_1": "44790 S. Grimmer Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000772": {
        "oui_hex": "00-07-72",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "E03005": {
        "oui_hex": "E0-30-05",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "3C404F": {
        "oui_hex": "3C-40-4F",
        "organization": "GUANGDONG PISEN ELECTRONICS CO.,LTD",
        "address_1": "Building C,Liuyue Jintang Industry Zone",
        "address_2": "Shenzhen  Guangdong  518173",
        "country": "CN"
    },
    "0CA402": {
        "oui_hex": "0C-A4-02",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "600 March Drive",
        "address_2": "Kanata  Ontario  K2K2E6",
        "country": "CA"
    },
    "A0F3E4": {
        "oui_hex": "A0-F3-E4",
        "organization": "Alcatel-Lucent IPD",
        "address_1": "600 March Drive",
        "address_2": "Kanata  Ontario  K2K2E6",
        "country": "CA"
    },
    "84DBFC": {
        "oui_hex": "84-DB-FC",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "7CFC3C": {
        "oui_hex": "7C-FC-3C",
        "organization": "Visteon Corporation",
        "address_1": "One Village Center Drive",
        "address_2": "Van Buren Twp  MI  48111",
        "country": "US"
    },
    "981E0F": {
        "oui_hex": "98-1E-0F",
        "organization": "Jeelan (Shanghai Jeelan Technology Information Inc",
        "address_1": "Room 302,Building 17, No.658, Jinzhong Road",
        "address_2": "shanghai    200052",
        "country": "CN"
    },
    "4888CA": {
        "oui_hex": "48-88-CA",
        "organization": "Motorola (Wuhan) Mobility Technologies Communication Co., Ltd.",
        "address_1": "No.19, Gaoxin 4th Road, Wuhan East Lake High-tech Zone, Wuhan",
        "address_2": "Wuhan  Hubei  430000",
        "country": "CN"
    },
    "385610": {
        "oui_hex": "38-56-10",
        "organization": "CANDY HOUSE, Inc.",
        "address_1": "119 University Ave.",
        "address_2": "Palo Alto  CA  94301",
        "country": "US"
    },
    "00A742": {
        "oui_hex": "00-A7-42",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00AA70": {
        "oui_hex": "00-AA-70",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "F895C7": {
        "oui_hex": "F8-95-C7",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "84D931": {
        "oui_hex": "84-D9-31",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "00116E": {
        "oui_hex": "00-11-6E",
        "organization": "Peplink International Ltd.",
        "address_1": "17/F., Park Building",
        "address_2": "Cheung Sha Wan  Kowloon  0000",
        "country": "HK"
    },
    "540955": {
        "oui_hex": "54-09-55",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "001E75": {
        "oui_hex": "00-1E-75",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "001C62": {
        "oui_hex": "00-1C-62",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "505527": {
        "oui_hex": "50-55-27",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "88C9D0": {
        "oui_hex": "88-C9-D0",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "C041F6": {
        "oui_hex": "C0-41-F6",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1,Cheongho-Ri,Jinwi-Myeon",
        "address_2": "Pyeongtaek  Gyeonggi-Do  451-713",
        "country": "KR"
    },
    "8C3AE3": {
        "oui_hex": "8C-3A-E3",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "90A46A": {
        "oui_hex": "90-A4-6A",
        "organization": "SISNET CO., LTD",
        "address_1": "1409, SJ Technoville 60-19, Gasan-dong, Geumcheon-Gu",
        "address_2": "Seoul    KS013",
        "country": "KR"
    },
    "14E7C8": {
        "oui_hex": "14-E7-C8",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "ECCD6D": {
        "oui_hex": "EC-CD-6D",
        "organization": "Allied Telesis, Inc.",
        "address_1": "3041 Orchard Parkway",
        "address_2": "San Jose    95134",
        "country": "US"
    },
    "18339D": {
        "oui_hex": "18-33-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "146102": {
        "oui_hex": "14-61-02",
        "organization": "Alpine Electronics, Inc.",
        "address_1": "20-1, Yoshima Industrial Park",
        "address_2": "Iwaki  Fukushima  970-1192",
        "country": "JP"
    },
    "54276C": {
        "oui_hex": "54-27-6C",
        "organization": "Jiangsu Houge Technology Corp.",
        "address_1": "No.20 Xizhang North Road, Fenghuang Town",
        "address_2": "Zhangjiagang  Jiangsu  215614",
        "country": "CN"
    },
    "9CA3A9": {
        "oui_hex": "9C-A3-A9",
        "organization": "Guangzhou Juan Optical and Electronical Tech Joint Stock Co., Ltd",
        "address_1": "NO.9, street 3, HengLing industrial zone, Tangdong, tianhe district",
        "address_2": "Guangzhou  Guangdong  510000",
        "country": "CN"
    },
    "7CC709": {
        "oui_hex": "7C-C7-09",
        "organization": "SHENZHEN RF-LINK TECHNOLOGY CO.,LTD.",
        "address_1": "Bldg56A, 6/F, Baotian Rd3, Baoan District, Shenzhen, P.R.C",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "A03E6B": {
        "oui_hex": "A0-3E-6B",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9802D8": {
        "oui_hex": "98-02-D8",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "64FB81": {
        "oui_hex": "64-FB-81",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0821EF": {
        "oui_hex": "08-21-EF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "34145F": {
        "oui_hex": "34-14-5F",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "2C265F": {
        "oui_hex": "2C-26-5F",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D0052A": {
        "oui_hex": "D0-05-2A",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "E4509A": {
        "oui_hex": "E4-50-9A",
        "organization": "HW Communications Ltd",
        "address_1": "Parkfield",
        "address_2": "Lancaster    LA1 4TZ",
        "country": "GB"
    },
    "702900": {
        "oui_hex": "70-29-00",
        "organization": "Shenzhen ChipTrip Technology Co,Ltd",
        "address_1": "The 8th floor of  VIA Technology Building  NO. 9966 Shennan road , Nanshan Distict  Shenzhen",
        "address_2": "Shenzhen    518000",
        "country": "CN"
    },
    "ECAAA0": {
        "oui_hex": "EC-AA-A0",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "00E0DD": {
        "oui_hex": "00-E0-DD",
        "organization": "Zenith Electronics Corporation",
        "address_1": "1000 MILWAUKEE AVENUE",
        "address_2": "GLENVIEW  IL  60025",
        "country": "US"
    },
    "50CE75": {
        "oui_hex": "50-CE-75",
        "organization": "Measy Electronics Co., Ltd.",
        "address_1": "#1506, Block B, Hai Song Bldg, Tairan 9th Road",
        "address_2": "Shenzhen  Guang Dong   518040",
        "country": "CN"
    },
    "00045B": {
        "oui_hex": "00-04-5B",
        "organization": "Techsan Electronics Co., Ltd.",
        "address_1": "North Wing",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0007BA": {
        "oui_hex": "00-07-BA",
        "organization": "UTStarcom Inc",
        "address_1": "1275 Harbor Bay PKWY",
        "address_2": "Alameda  CA  94502",
        "country": "US"
    },
    "90A210": {
        "oui_hex": "90-A2-10",
        "organization": "United Telecoms Ltd",
        "address_1": "18A/19,Doddanekundi Industrial Area,",
        "address_2": "Bangalore  Karanataka  560048",
        "country": "IN"
    },
    "6C0B84": {
        "oui_hex": "6C-0B-84",
        "organization": "Universal Global Scientific Industrial Co., Ltd.",
        "address_1": "141, Lane 351, TaiPing Road, Sec.1",
        "address_2": "Tsao-Tuen   Nan-Tou  54261",
        "country": "TW"
    },
    "001597": {
        "oui_hex": "00-15-97",
        "organization": "AETA AUDIO SYSTEMS",
        "address_1": "18-22, avenue Edouard Herriot",
        "address_2": "Le Plessis Robinson    92350",
        "country": "FR"
    },
    "002397": {
        "oui_hex": "00-23-97",
        "organization": "Westell Technologies Inc.",
        "address_1": "750 N Commons Dr",
        "address_2": "Aurora  IL  60504",
        "country": "US"
    },
    "60E3AC": {
        "oui_hex": "60-E3-AC",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "90F052": {
        "oui_hex": "90-F0-52",
        "organization": "MEIZU Technology Co., Ltd.",
        "address_1": "MEIZU Tech Bldg., Technology & Innovation Coast",
        "address_2": "Zhuhai  Guangdong  519085",
        "country": "CN"
    },
    "001639": {
        "oui_hex": "00-16-39",
        "organization": "Ubiquam Co., Ltd.",
        "address_1": "Technovill 4F,272-3 Yatap3",
        "address_2": "Seongnam  Kyeonggi  463-836",
        "country": "KR"
    },
    "000C29": {
        "oui_hex": "00-0C-29",
        "organization": "VMware, Inc.",
        "address_1": "3401 Hillview Avenue",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "000569": {
        "oui_hex": "00-05-69",
        "organization": "VMware, Inc.",
        "address_1": "3401 Hillview Avenue",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "000B0E": {
        "oui_hex": "00-0B-0E",
        "organization": "Trapeze Networks",
        "address_1": "5753 W. Las Positas Blvd",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "8CFDF0": {
        "oui_hex": "8C-FD-F0",
        "organization": "Qualcomm Inc.",
        "address_1": "5775 Morehouse Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C4BB4C": {
        "oui_hex": "C4-BB-4C",
        "organization": "Zebra Information Tech Co. Ltd",
        "address_1": "Room 415, No.569 Anchi Road, JiaDing District",
        "address_2": "Shanghai    201804",
        "country": "CN"
    },
    "98CF53": {
        "oui_hex": "98-CF-53",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "D4A148": {
        "oui_hex": "D4-A1-48",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D065CA": {
        "oui_hex": "D0-65-CA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "486B2C": {
        "oui_hex": "48-6B-2C",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "6C25B9": {
        "oui_hex": "6C-25-B9",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "2C282D": {
        "oui_hex": "2C-28-2D",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "4813F3": {
        "oui_hex": "48-13-F3",
        "organization": "BBK EDUCATIONAL ELECTRONICS CORP.,LTD.",
        "address_1": " LiWu INDUSTRIAL PARK,Wusha,Chang'an",
        "address_2": "Dong Guan   Guang Dong  523860",
        "country": "CN"
    },
    "00409F": {
        "oui_hex": "00-40-9F",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield,  MA  02048",
        "country": "US"
    },
    "00001F": {
        "oui_hex": "00-00-1F",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield  MA  02048",
        "country": "US"
    },
    "00A012": {
        "oui_hex": "00-A0-12",
        "organization": "Telco Systems, Inc.",
        "address_1": "15 Berkshire Road",
        "address_2": "Mansfield  MA  02048",
        "country": "US"
    },
    "8CEBC6": {
        "oui_hex": "8C-EB-C6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B08900": {
        "oui_hex": "B0-89-00",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "78CB68": {
        "oui_hex": "78-CB-68",
        "organization": "DAEHAP HYPER-TECH",
        "address_1": "302,Galmachiro,Woolim Lions Valley 5-cha #A-810,Jungwon-Gu",
        "address_2": "Seongnam,  Gyeonggido  445-918",
        "country": "KR"
    },
    "34ED0B": {
        "oui_hex": "34-ED-0B",
        "organization": " Shanghai XZ-COM.CO.,Ltd.",
        "address_1": "11th Floor,B Building ,No.100 Qinzhou  Road  ,Shanghai",
        "address_2": "shanghai  shanghai  200235",
        "country": "CN"
    },
    "F0DEF1": {
        "oui_hex": "F0-DE-F1",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "168KunShan,",
        "address_2": "JiangSu    215300",
        "country": "CN"
    },
    "F80F41": {
        "oui_hex": "F8-0F-41",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "Torch High-tech Industrial Development Zone,",
        "address_2": "ZhongShan  Guangdong  528437",
        "country": "CN"
    },
    "3C970E": {
        "oui_hex": "3C-97-0E",
        "organization": "Wistron InfoComm(Kunshan)Co.,Ltd.",
        "address_1": "168# First Avence,",
        "address_2": "Kunshan  JiangSu  215300",
        "country": "CN"
    },
    "30144A": {
        "oui_hex": "30-14-4A",
        "organization": "Wistron Neweb Corporation",
        "address_1": "20 Park Avenue II, Hsin Science Park, Hsinchu 308, Taiwan",
        "address_2": "HsinChu  Taiwan  308",
        "country": "TW"
    },
    "4C0BBE": {
        "oui_hex": "4C-0B-BE",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "0C2576": {
        "oui_hex": "0C-25-76",
        "organization": "LONGCHEER TELECOMMUNICATION LIMITED",
        "address_1": "Building 1,No.401,Caobao Rd",
        "address_2": "Shanghai  Xuhui District  200233",
        "country": "CN"
    },
    "D8D43C": {
        "oui_hex": "D8-D4-3C",
        "organization": "Sony Corporation",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "D44165": {
        "oui_hex": "D4-41-65",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "E4029B": {
        "oui_hex": "E4-02-9B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DC1AC5": {
        "oui_hex": "DC-1A-C5",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong  523860",
        "country": "CN"
    },
    "F45EAB": {
        "oui_hex": "F4-5E-AB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "A8FCB7": {
        "oui_hex": "A8-FC-B7",
        "organization": "Consolidated Resource Imaging",
        "address_1": "2943 S Wilson CT NW",
        "address_2": "Grand Rapids  MI  49534",
        "country": "US"
    },
    "00C000": {
        "oui_hex": "00-C0-00",
        "organization": "LANOPTICS, LTD.",
        "address_1": "P.O. BOX 184",
        "address_2": "ISRAEL  ISRAEL  10551",
        "country": "IL"
    },
    "845181": {
        "oui_hex": "84-51-81",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0C287": {
        "oui_hex": "B0-C2-87",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "CC3540": {
        "oui_hex": "CC-35-40",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "8C04FF": {
        "oui_hex": "8C-04-FF",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "FC94E3": {
        "oui_hex": "FC-94-E3",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "B88D12": {
        "oui_hex": "B8-8D-12",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90EF68": {
        "oui_hex": "90-EF-68",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "C816BD": {
        "oui_hex": "C8-16-BD",
        "organization": "Qingdao Hisense Communications Co.,Ltd.",
        "address_1": "Qianwangang Road 218",
        "address_2": "Qingdao  Shandong  266510",
        "country": "CN"
    },
    "00EBD5": {
        "oui_hex": "00-EB-D5",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "C48F07": {
        "oui_hex": "C4-8F-07",
        "organization": "Shenzhen Yihao Hulian Science and Technology Co., Ltd.",
        "address_1": "Room A, Floor 6, Building 210, Tairan Industry and Trade Park, Che Kung Temple, Futian District, Shenzhen, Guangdong Province",
        "address_2": "ShenZhen  Guangdong  518000",
        "country": "CN"
    },
    "DC7834": {
        "oui_hex": "DC-78-34",
        "organization": "LOGICOM SA",
        "address_1": "55 Rue de Lisbonne",
        "address_2": "PARIS    75008",
        "country": "FR"
    },
    "CCCC81": {
        "oui_hex": "CC-CC-81",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "6C9522": {
        "oui_hex": "6C-95-22",
        "organization": "Scalys",
        "address_1": "Lansinkesweg 4",
        "address_2": "Hengelo    7553 AE",
        "country": "NL"
    },
    "B456B9": {
        "oui_hex": "B4-56-B9",
        "organization": "Teraspek Technologies Co.,Ltd",
        "address_1": "14th floor,Block C,Beijing International Building, Zhongguancun South Street, Beijng, China, 100081",
        "address_2": "Beijing    100081",
        "country": "CN"
    },
    "9CDD1F": {
        "oui_hex": "9C-DD-1F",
        "organization": "Intelligent Steward Co.,Ltd",
        "address_1": "Room 508-598 XiTianGeZhuang Town Government Office Building,8# XiTong Road ,Economic Development District ,MiYun County ,BeiJing City",
        "address_2": "BeiJing City     101509",
        "country": "CN"
    },
    "3C6816": {
        "oui_hex": "3C-68-16",
        "organization": "VXi Corporation",
        "address_1": "271 Locust Street",
        "address_2": "Dover  NH  03820",
        "country": "US"
    },
    "E811CA": {
        "oui_hex": "E8-11-CA",
        "organization": "SHANDONG KAER ELECTRIC.CO.,LTD",
        "address_1": "No.58, Dalian Road, Weihai, 264209 Shandong Province, P.R.China",
        "address_2": "Weihai  Shandong  264209",
        "country": "CN"
    },
    "70288B": {
        "oui_hex": "70-28-8B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "348A7B": {
        "oui_hex": "34-8A-7B",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D0577B": {
        "oui_hex": "D0-57-7B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "78009E": {
        "oui_hex": "78-00-9E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "ACC33A": {
        "oui_hex": "AC-C3-3A",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54F201": {
        "oui_hex": "54-F2-01",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C4A366": {
        "oui_hex": "C4-A3-66",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "6073BC": {
        "oui_hex": "60-73-BC",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "7C3548": {
        "oui_hex": "7C-35-48",
        "organization": "Transcend Information",
        "address_1": "No.70, XingZhong Rd., NeiHu Dist.,",
        "address_2": "Taipei  Taiwan  114",
        "country": "TW"
    },
    "18B169": {
        "oui_hex": "18-B1-69",
        "organization": "Sonicwall",
        "address_1": "2001 Logic Drive",
        "address_2": "San Jose  CA  95124-3452",
        "country": "US"
    },
    "444450": {
        "oui_hex": "44-44-50",
        "organization": "OttoQ",
        "address_1": "20370 Town Center Lane, Suite 205",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "50F5DA": {
        "oui_hex": "50-F5-DA",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "101212": {
        "oui_hex": "10-12-12",
        "organization": "Vivo International Corporation Pty Ltd",
        "address_1": "9-13 Bibby Street,",
        "address_2": "NSW  Chiswick  2046",
        "country": "AU"
    },
    "C85B76": {
        "oui_hex": "C8-5B-76",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "78FFCA": {
        "oui_hex": "78-FF-CA",
        "organization": "TECNO MOBILE LIMITED",
        "address_1": "ROOMS 05-15, 13A/F., SOUTH TOWER, WORLD FINANCE CENTRE, HARBOUR CITY, 17 CANTON ROAD, TSIM SHA TSUI, KOWLOON, HONG KONG",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "046565": {
        "oui_hex": "04-65-65",
        "organization": "Testop",
        "address_1": "808, Hanshin IT tower, 272 digital-ro",
        "address_2": "Guro-gu  Seoul  KS013",
        "country": "KR"
    },
    "A8BB50": {
        "oui_hex": "A8-BB-50",
        "organization": "WiZ IoT Company Limited",
        "address_1": "148 Electric Road",
        "address_2": "Hong Kong    0000",
        "country": "HK"
    },
    "08C021": {
        "oui_hex": "08-C0-21",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "600810": {
        "oui_hex": "60-08-10",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "48435A": {
        "oui_hex": "48-43-5A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8C8EF2": {
        "oui_hex": "8C-8E-F2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "90B0ED": {
        "oui_hex": "90-B0-ED",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F03EBF": {
        "oui_hex": "F0-3E-BF",
        "organization": "GOGORO TAIWAN LIMITED",
        "address_1": "No.33 Dinghu Rd.",
        "address_2": "GuiShan Dist.  Taoyuan  333",
        "country": "TW"
    },
    "3C92DC": {
        "oui_hex": "3C-92-DC",
        "organization": "Octopod Technology Co. Ltd.",
        "address_1": "822 Lane Zhennan Road",
        "address_2": "Shanghai    200331",
        "country": "CN"
    },
    "1000FD": {
        "oui_hex": "10-00-FD",
        "organization": "LaonPeople",
        "address_1": "402-3, Bundang Techno Park B, 148",
        "address_2": "Sungnam-si  Gyeonggi-do  463-760",
        "country": "KR"
    },
    "C47C8D": {
        "oui_hex": "C4-7C-8D",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "745C9F": {
        "oui_hex": "74-5C-9F",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "8C99E6": {
        "oui_hex": "8C-99-E6",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "449F7F": {
        "oui_hex": "44-9F-7F",
        "organization": "DataCore Software Corporation",
        "address_1": "6300 NW 5th Way",
        "address_2": "Fort Lauderdale  FL  33309",
        "country": "US"
    },
    "848319": {
        "oui_hex": "84-83-19",
        "organization": "Hangzhou Zero Zero Technology Co., Ltd.",
        "address_1": "Bldg 13&14, Dream Town, Hangzhou, Zhejiang",
        "address_2": "Hangzhou  Zhejiang  310000",
        "country": "CN"
    },
    "A81559": {
        "oui_hex": "A8-15-59",
        "organization": "Breathometer, Inc.",
        "address_1": "863 Mitten Road, Suite 104",
        "address_2": "Burlingame  CA  94010",
        "country": "US"
    },
    "70BAEF": {
        "oui_hex": "70-BA-EF",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District,",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "586AB1": {
        "oui_hex": "58-6A-B1",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "466 Changhe Road, Binjiang District,",
        "address_2": "Hangzhou  Zhejiang, P.R.China  310052",
        "country": "CN"
    },
    "009006": {
        "oui_hex": "00-90-06",
        "organization": "Hamamatsu Photonics K.K.",
        "address_1": "812 JOKO-CHO",
        "address_2": "HAMAMATSU    431-3196",
        "country": "JP"
    },
    "001AF4": {
        "oui_hex": "00-1A-F4",
        "organization": "Handreamnet",
        "address_1": "#1209 MarioTower, 28",
        "address_2": "Seoul    152-741",
        "country": "KR"
    },
    "04D3CF": {
        "oui_hex": "04-D3-CF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4882F2": {
        "oui_hex": "48-82-F2",
        "organization": "Appel Elektronik GmbH",
        "address_1": "Ludwig-Rinn-Str.10",
        "address_2": "Heuchelheim  Hessen  35452",
        "country": "DE"
    },
    "78B84B": {
        "oui_hex": "78-B8-4B",
        "organization": "SICHUAN TIANYI COMHEART TELECOMCO.,LTD",
        "address_1": "FL12,TowerB,Tianyi international Hotel,No.2 West Section One, Second Ring Road,",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "7CB0C2": {
        "oui_hex": "7C-B0-C2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001793": {
        "oui_hex": "00-17-93",
        "organization": "Tigi Corporation",
        "address_1": "2070 Chain Bridge road",
        "address_2": "Vienna  Va  22182",
        "country": "US"
    },
    "000358": {
        "oui_hex": "00-03-58",
        "organization": "Hanyang Digitech Co.Ltd",
        "address_1": "13F, Acetwintower2, 212-30, Guro-Dong",
        "address_2": "Seoul    12304",
        "country": "KR"
    },
    "C4CAD9": {
        "oui_hex": "C4-CA-D9",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "5866BA": {
        "oui_hex": "58-66-BA",
        "organization": "Hangzhou H3C Technologies Co., Limited",
        "address_1": "310 Liuhe Road, Zhijiang Science Park",
        "address_2": "Hangzhou  Zhejiang,   310053",
        "country": "CN"
    },
    "E0C79D": {
        "oui_hex": "E0-C7-9D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "4C0B3A": {
        "oui_hex": "4C-0B-3A",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "E42D02": {
        "oui_hex": "E4-2D-02",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "0CBD51": {
        "oui_hex": "0C-BD-51",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "4000E0": {
        "oui_hex": "40-00-E0",
        "organization": "Derek(Shaoguan)Limited",
        "address_1": "Gaojiling,Taiping Town, Shixing County",
        "address_2": "Shaoguan  Guangdong  512500",
        "country": "CN"
    },
    "FCBC9C": {
        "oui_hex": "FC-BC-9C",
        "organization": "Vimar Spa",
        "address_1": "Viale Vicenza 14",
        "address_2": "Marostica  Vicenza  36063",
        "country": "IT"
    },
    "149ECF": {
        "oui_hex": "14-9E-CF",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "E80959": {
        "oui_hex": "E8-09-59",
        "organization": "Guoguang Electric Co.,Ltd",
        "address_1": "No.8 Jinghu Road, Xinhua Street, Huadu Reg",
        "address_2": "Guangzhou  Guangdong  510800",
        "country": "CN"
    },
    "D89403": {
        "oui_hex": "D8-94-03",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "E00EDA": {
        "oui_hex": "E0-0E-DA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "D0A4B1": {
        "oui_hex": "D0-A4-B1",
        "organization": "Sonifex Ltd.",
        "address_1": "61 Station Road",
        "address_2": "Irthlingborough  Northamptonshire  NN9 5QE",
        "country": "GB"
    },
    "F49EEF": {
        "oui_hex": "F4-9E-EF",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "C4F081": {
        "oui_hex": "C4-F0-81",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "801382": {
        "oui_hex": "80-13-82",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94FE22": {
        "oui_hex": "94-FE-22",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F4CC55": {
        "oui_hex": "F4-CC-55",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "50DD4F": {
        "oui_hex": "50-DD-4F",
        "organization": "Automation Components, Inc",
        "address_1": "2305 Pleasant View Rd",
        "address_2": "Middleton  WI  53562",
        "country": "US"
    },
    "341FE4": {
        "oui_hex": "34-1F-E4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0024F4": {
        "oui_hex": "00-24-F4",
        "organization": "Kaminario, Ltd.",
        "address_1": "Yatam Industrial Park",
        "address_2": "Yokneam  ISRAEL  20692",
        "country": "IL"
    },
    "001A29": {
        "oui_hex": "00-1A-29",
        "organization": "Johnson Outdoors Marine Electronics d/b/a Minnkota",
        "address_1": "1220 Old Alpharetta Rd",
        "address_2": "Alpharetta  GA  30041",
        "country": "US"
    },
    "0090AE": {
        "oui_hex": "00-90-AE",
        "organization": "ITALTEL S.p.A/RF-UP-I",
        "address_1": "LOCALITA' BOSCHETTO",
        "address_2": "67100 L'AQUILA    na",
        "country": "IT"
    },
    "00177D": {
        "oui_hex": "00-17-7D",
        "organization": "IDT Technology Limited",
        "address_1": "Block C, 9/F, Kaiser Estate, Phase I",
        "address_2": "na    na",
        "country": "HK"
    },
    "00A045": {
        "oui_hex": "00-A0-45",
        "organization": "PHOENIX CONTACT Electronics GmbH",
        "address_1": "POSTFACH 1341",
        "address_2": "lower saxony    D-31812",
        "country": "DE"
    },
    "002378": {
        "oui_hex": "00-23-78",
        "organization": "GN Netcom A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK - 2750",
        "country": "DK"
    },
    "50C971": {
        "oui_hex": "50-C9-71",
        "organization": "GN Netcom A/S",
        "address_1": "Lautrupbjerg 7",
        "address_2": "Ballerup    DK - 2750",
        "country": "DK"
    },
    "F0407B": {
        "oui_hex": "F0-40-7B",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "94885E": {
        "oui_hex": "94-88-5E",
        "organization": "Surfilter Network Technology Co., Ltd.",
        "address_1": "6/f,2 Building,Kejizhong Rd2,Software Park,High-Tech District,Nanshan,Shenzhen,China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C825E1": {
        "oui_hex": "C8-25-E1",
        "organization": "Lemobile Information Technology (Beijing) Co., Ltd",
        "address_1": "WENHUAYING NORTH (No.1, LINKONG 2nd St), GAOLIYING, SHUNYI DISTRICT, BEIJING",
        "address_2": "Beijing  Beijing  101300",
        "country": "CN"
    },
    "945089": {
        "oui_hex": "94-50-89",
        "organization": "SimonsVoss Technologies GmbH",
        "address_1": "Feringastr. 4",
        "address_2": "Unterfoehring  Bavaria  85774",
        "country": "DE"
    },
    "042AE2": {
        "oui_hex": "04-2A-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0B6F5": {
        "oui_hex": "E0-B6-F5",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0090FA": {
        "oui_hex": "00-90-FA",
        "organization": "Emulex Corporation",
        "address_1": "3333 Susan Street",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "00E0D5": {
        "oui_hex": "00-E0-D5",
        "organization": "Emulex Corporation",
        "address_1": "3333 Susan Street",
        "address_2": "Costa Mesa  CA  92626",
        "country": "US"
    },
    "001035": {
        "oui_hex": "00-10-35",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "6F, NO. 88, SEC. 6",
        "address_2": "Shih Lin  TAIPEI  00000",
        "country": "TW"
    },
    "000AE6": {
        "oui_hex": "00-0A-E6",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No.22, Alley 38, Lane 91, Sec. 1, Nei Hu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "7427EA": {
        "oui_hex": "74-27-EA",
        "organization": "Elitegroup Computer Systems Co.,Ltd.",
        "address_1": "No. 239, Sec. 2, Ti Ding Blvd.,",
        "address_2": "Taipei    11493",
        "country": "US"
    },
    "649968": {
        "oui_hex": "64-99-68",
        "organization": "Elentec",
        "address_1": "401-13 Chunggye-Ri",
        "address_2": "Dongtan-Myun  Kyunggi  445-811",
        "country": "KR"
    },
    "00409C": {
        "oui_hex": "00-40-9C",
        "organization": "TRANSWARE",
        "address_1": "21, RUE DU 8 MAI 1945",
        "address_2": "",
        "country": "FR"
    },
    "B01BD2": {
        "oui_hex": "B0-1B-D2",
        "organization": "Le Shi Zhi Xin Electronic Technology (Tianjin) Limited",
        "address_1": ",Le Shi Building, No.105 Yaojiayuan Road,Chaoyang District,Beijing,China",
        "address_2": "beijing  beijing  100025",
        "country": "CN"
    },
    "54489C": {
        "oui_hex": "54-48-9C",
        "organization": "CDOUBLES ELECTRONICS CO. LTD.",
        "address_1": "11F.-6, No. 7,Sec. 3, New Taipei Blvd., Xinzhuang Dist.",
        "address_2": "New Taipei City    24250",
        "country": "TW"
    },
    "E4A1E6": {
        "oui_hex": "E4-A1-E6",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "84002D": {
        "oui_hex": "84-00-2D",
        "organization": "PEGATRON CORPORATION",
        "address_1": "No. 76, Ligong St., Beitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "408256": {
        "oui_hex": "40-82-56",
        "organization": "Continental Automotive GmbH",
        "address_1": "VD=-Strasse 1",
        "address_2": "Babenhausen  Garmany  64832",
        "country": "DE"
    },
    "5CC7D7": {
        "oui_hex": "5C-C7-D7",
        "organization": "AZROAD TECHNOLOGY COMPANY LIMITED",
        "address_1": "Block B2, No.14 Jian'an rd. Shajing, Bao'an District,",
        "address_2": "Shenzhen    518104",
        "country": "CN"
    },
    "986B3D": {
        "oui_hex": "98-6B-3D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E0071B": {
        "oui_hex": "E0-07-1B",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "1CABC0": {
        "oui_hex": "1C-AB-C0",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "1C3ADE": {
        "oui_hex": "1C-3A-DE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "002360": {
        "oui_hex": "00-23-60",
        "organization": "Lookit Technology Co., Ltd",
        "address_1": "FL 8 Seashore Mansion",
        "address_2": "Shenzhen  Guangdong  518100",
        "country": "CN"
    },
    "84FEDC": {
        "oui_hex": "84-FE-DC",
        "organization": "Borqs Beijing Ltd.",
        "address_1": "Tower A, Building B23, Universal Business Park, No.10 Jiuxianqiao Road",
        "address_2": "Chaoyang District  Beijing  100015",
        "country": "CN"
    },
    "608334": {
        "oui_hex": "60-83-34",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E47E66": {
        "oui_hex": "E4-7E-66",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94DBDA": {
        "oui_hex": "94-DB-DA",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "54D9E4": {
        "oui_hex": "54-D9-E4",
        "organization": "BRILLIANTTS CO., LTD",
        "address_1": "Daewangpangyo-ro",
        "address_2": "Seongnam-si    13494",
        "country": "KR"
    },
    "F462D0": {
        "oui_hex": "F4-62-D0",
        "organization": "Not for Radio, LLC",
        "address_1": "425 Front St",
        "address_2": "Lititz  PA  17543",
        "country": "US"
    },
    "98DED0": {
        "oui_hex": "98-DE-D0",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "508965": {
        "oui_hex": "50-89-65",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "005BA1": {
        "oui_hex": "00-5B-A1",
        "organization": "shanghai huayuan chuangxin software CO., LTD.",
        "address_1": "Room D13 , Floor 13,Lane 1006, Jinshajiang road,putuo District",
        "address_2": "Shanghai  Shanghai  200333",
        "country": "CN"
    },
    "58D67A": {
        "oui_hex": "58-D6-7A",
        "organization": "TCPlink",
        "address_1": "Daerungpost tower 1-cha 1720, 288 digital-ro,Guro-gu",
        "address_2": "seoul    08390",
        "country": "KR"
    },
    "98072D": {
        "oui_hex": "98-07-2D",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "F0C77F": {
        "oui_hex": "F0-C7-7F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "000AC2": {
        "oui_hex": "00-0A-C2",
        "organization": "Wuhan FiberHome Digital Technology Co.,Ltd.",
        "address_1": "No.88 YouKeyuan Road,Hongshan District,W",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "10DA43": {
        "oui_hex": "10-DA-43",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B805AB": {
        "oui_hex": "B8-05-AB",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "789682": {
        "oui_hex": "78-96-82",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D467E7": {
        "oui_hex": "D4-67-E7",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "E42F26": {
        "oui_hex": "E4-2F-26",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "04C1B9": {
        "oui_hex": "04-C1-B9",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan City  Hubei Province  430074",
        "country": "CN"
    },
    "C4BED4": {
        "oui_hex": "C4-BE-D4",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "D017C2": {
        "oui_hex": "D0-17-C2",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "349971": {
        "oui_hex": "34-99-71",
        "organization": "Quanta Storage Inc.",
        "address_1": "3F. No.188, Wenhua 2nd Rd",
        "address_2": "Taoyuan City  Guishan District  33383",
        "country": "TW"
    },
    "9C52F8": {
        "oui_hex": "9C-52-F8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC13DB": {
        "oui_hex": "EC-13-DB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "5CF286": {
        "oui_hex": "5C-F2-86",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "E8FD72": {
        "oui_hex": "E8-FD-72",
        "organization": "SHANGHAI LINGUO TECHNOLOGY CO., LTD.",
        "address_1": "No.2,277 Lane,Yongdeng Road,Putuo District,Shanghai,China",
        "address_2": "Shanghai  Shanghai  200000",
        "country": "CN"
    },
    "98BB1E": {
        "oui_hex": "98-BB-1E",
        "organization": "BYD Precision Manufacture Company Ltd.",
        "address_1": "7/Floor, Building 5#, No3000 LongDong Avenue, Pudong District",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "AC5F3E": {
        "oui_hex": "AC-5F-3E",
        "organization": "SAMSUNG ELECTRO-MECHANICS(THAILAND)",
        "address_1": "93Moo5T. Bangsamak SEMTHAI, WELLGROW INDUSTRIAL ESTATE",
        "address_2": "Bangpakong  Chachoengsao  24180",
        "country": "TH"
    },
    "546D52": {
        "oui_hex": "54-6D-52",
        "organization": "TOPVIEW OPTRONICS CORP.",
        "address_1": "No.8, Wuquan Rd., New Taipei Industrial Park, Wugu District",
        "address_2": " New Taipei City     24886",
        "country": "TW"
    },
    "04C103": {
        "oui_hex": "04-C1-03",
        "organization": "Clover Network, Inc.",
        "address_1": "415 N Mathilda Ave",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "280C28": {
        "oui_hex": "28-0C-28",
        "organization": "Unigen DataStorage Corporation",
        "address_1": "11F.-6, No.251, Fuxing 1st St., Zhubei City, Hsinchu County 302, Taiwan (R.O.C.)",
        "address_2": "Zhubei City    30271",
        "country": "TW"
    },
    "A4BF01": {
        "oui_hex": "A4-BF-01",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "208B37": {
        "oui_hex": "20-8B-37",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "08BE77": {
        "oui_hex": "08-BE-77",
        "organization": "Green Electronics",
        "address_1": "47801 Fremont Blvd",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "509EA7": {
        "oui_hex": "50-9E-A7",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A88195": {
        "oui_hex": "A8-81-95",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "88ADD2": {
        "oui_hex": "88-AD-D2",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "00CCFC": {
        "oui_hex": "00-CC-FC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019C5": {
        "oui_hex": "00-19-C5",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "001315": {
        "oui_hex": "00-13-15",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "1C234F": {
        "oui_hex": "1C-23-4F",
        "organization": "EDMI  Europe Ltd",
        "address_1": "The Grainger  Suite, Dobson House",
        "address_2": "Newcastle upon Tyne    NE3 3PF",
        "country": "GB"
    },
    "A444D1": {
        "oui_hex": "A4-44-D1",
        "organization": " Wingtech Group (HongKong）Limited",
        "address_1": " FLAT/RM 1903 19/F PODIUM PLAZA 5HANOI ROAD TSIM SHA TSUI",
        "address_2": "Hong Kong  Hong Kong  999077",
        "country": "HK"
    },
    "006CFD": {
        "oui_hex": "00-6C-FD",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "545AA6": {
        "oui_hex": "54-5A-A6",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "FC1A11": {
        "oui_hex": "FC-1A-11",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "001A57": {
        "oui_hex": "00-1A-57",
        "organization": "Matrix Design Group, LLC",
        "address_1": "5741 Prospect Dr.",
        "address_2": "Newburgh  IN  47630",
        "country": "US"
    },
    "A0C589": {
        "oui_hex": "A0-C5-89",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "001E1E": {
        "oui_hex": "00-1E-1E",
        "organization": "Honeywell Life Safety",
        "address_1": "12 Clintonville Road",
        "address_2": "Northford  CT  0422",
        "country": "US"
    },
    "002340": {
        "oui_hex": "00-23-40",
        "organization": "MiXTelematics",
        "address_1": "Blaauwklip Office Park 2",
        "address_2": "Stellenbosch  Western Cape  7600",
        "country": "ZA"
    },
    "B48B19": {
        "oui_hex": "B4-8B-19",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "38FDFE": {
        "oui_hex": "38-FD-FE",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "2C09CB": {
        "oui_hex": "2C-09-CB",
        "organization": "COBS AB",
        "address_1": "Box 9242",
        "address_2": "Goteborg    40095",
        "country": "SE"
    },
    "BCEC5D": {
        "oui_hex": "BC-EC-5D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28A02B": {
        "oui_hex": "28-A0-2B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A84481": {
        "oui_hex": "A8-44-81",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  NA  24101",
        "country": "FI"
    },
    "8844F6": {
        "oui_hex": "88-44-F6",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo  NA  24101",
        "country": "FI"
    },
    "F44D17": {
        "oui_hex": "F4-4D-17",
        "organization": "GOLDCARD HIGH-TECH CO.,LTD.",
        "address_1": "No.158, Jinqiao Stree,Economic&Technological Development Area,",
        "address_2": "Hangzhou   Zhejiang  310018",
        "country": "CN"
    },
    "38B8EB": {
        "oui_hex": "38-B8-EB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9897D1": {
        "oui_hex": "98-97-D1",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "B83241": {
        "oui_hex": "B8-32-41",
        "organization": "Wuhan Tianyu Information Industry Co., Ltd.",
        "address_1": "HUST Industry Park, East-Lake Development Zone",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "0060DC": {
        "oui_hex": "00-60-DC",
        "organization": "NEC Magnus Communications,Ltd.",
        "address_1": "18 Nihon-odori,Naka-ku",
        "address_2": "Yokohama, Kanagawa    231-0021",
        "country": "JP"
    },
    "907282": {
        "oui_hex": "90-72-82",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "001C35": {
        "oui_hex": "00-1C-35",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001C9A": {
        "oui_hex": "00-1C-9A",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001CD6": {
        "oui_hex": "00-1C-D6",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001CD4": {
        "oui_hex": "00-1C-D4",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001D98": {
        "oui_hex": "00-1D-98",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001DE9": {
        "oui_hex": "00-1D-E9",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001E3A": {
        "oui_hex": "00-1E-3A",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "002548": {
        "oui_hex": "00-25-48",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0022FC": {
        "oui_hex": "00-22-FC",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0022FD": {
        "oui_hex": "00-22-FD",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "0021AA": {
        "oui_hex": "00-21-AA",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001D6E": {
        "oui_hex": "00-1D-6E",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen  V  DK-1790",
        "country": "DK"
    },
    "0023B4": {
        "oui_hex": "00-23-B4",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001370": {
        "oui_hex": "00-13-70",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "9C1874": {
        "oui_hex": "9C-18-74",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790V",
        "country": "DK"
    },
    "001BAF": {
        "oui_hex": "00-1B-AF",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "C8D10B": {
        "oui_hex": "C8-D1-0B",
        "organization": "Nokia Corporation",
        "address_1": "Joensuunkatu 7",
        "address_2": "Salo    24101",
        "country": "FI"
    },
    "5CC6D0": {
        "oui_hex": "5C-C6-D0",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001A9A": {
        "oui_hex": "00-1A-9A",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "CC6DA0": {
        "oui_hex": "CC-6D-A0",
        "organization": "Roku, Inc.",
        "address_1": "12980 Saratoga Ave.",
        "address_2": "Saratoga  CA  95070",
        "country": "US"
    },
    "0016E4": {
        "oui_hex": "00-16-E4",
        "organization": "VANGUARD SECURITY ENGINEERING CORP.",
        "address_1": "3, LANE 32, KSO CHING RD.",
        "address_2": "YANGMEI  TAOYUAN  326",
        "country": "US"
    },
    "3C8970": {
        "oui_hex": "3C-89-70",
        "organization": "Neosfar",
        "address_1": "101 W. Broadway, Suite 300",
        "address_2": "San Diego  CA  92101",
        "country": "US"
    },
    "001742": {
        "oui_hex": "00-17-42",
        "organization": "FUJITSU LIMITED",
        "address_1": "403, Kosugi-cho 1-chome, Nakahara-ku",
        "address_2": "Kawasaki  Kanagawa  211-0063",
        "country": "JP"
    },
    "001999": {
        "oui_hex": "00-19-99",
        "organization": "Fujitsu Technology Solutions GmbH",
        "address_1": "Buergermeister-Ulrich-Strasse 100",
        "address_2": "Augsburg    86199",
        "country": "DE"
    },
    "005A39": {
        "oui_hex": "00-5A-39",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "A089E4": {
        "oui_hex": "A0-89-E4",
        "organization": "Skyworth Digital Technology(Shenzhen) Co.,Ltd",
        "address_1": "7F,Block A,Skyworth Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "78CA83": {
        "oui_hex": "78-CA-83",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "0C1167": {
        "oui_hex": "0C-11-67",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "74EAE8": {
        "oui_hex": "74-EA-E8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "F88E85": {
        "oui_hex": "F8-8E-85",
        "organization": "Comtrend Corporation",
        "address_1": "3F-1, 10 Lane 609, Chongxin Road, Section 5,",
        "address_2": "New Taipei City,  Taiwan  24159",
        "country": "TW"
    },
    "02CF1C": {
        "oui_hex": "02-CF-1C",
        "organization": "Communication Machinery Corporation",
        "address_1": "1226 ANACAPA",
        "address_2": "SANTA BARBARA  CA  93101",
        "country": "US"
    },
    "0090F5": {
        "oui_hex": "00-90-F5",
        "organization": "CLEVO CO.",
        "address_1": "35, WU-GON 6TH ROAD",
        "address_2": "TAIPEI HSIEN    12345",
        "country": "TW"
    },
    "0030FF": {
        "oui_hex": "00-30-FF",
        "organization": "DataFab Systems Inc.",
        "address_1": "ROOM #1910, 19F, NO. 333",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "000FF6": {
        "oui_hex": "00-0F-F6",
        "organization": "DARFON LIGHTING CORP",
        "address_1": "31, Lane17, Zihciang N. Road",
        "address_2": "Taoyuan    333",
        "country": "TW"
    },
    "002100": {
        "oui_hex": "00-21-00",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No.1 Jen Ai Road, Hsinchu Industrial Park,",
        "address_2": "Hukou,  Hsinchu  303",
        "country": "TW"
    },
    "50F520": {
        "oui_hex": "50-F5-20",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "64B310": {
        "oui_hex": "64-B3-10",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A4EBD3": {
        "oui_hex": "A4-EB-D3",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C81073": {
        "oui_hex": "C8-10-73",
        "organization": "CENTURY OPTICOMM CO.,LTD",
        "address_1": "WEITUO COMMUNITY,HECHUAN INDUSTRIAL PARK, HECHUAN DISTRICT,CHONGQING,CHINA",
        "address_2": "Chongqing    401121",
        "country": "CN"
    },
    "343759": {
        "oui_hex": "34-37-59",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "FC2F40": {
        "oui_hex": "FC-2F-40",
        "organization": "Calxeda, Inc.",
        "address_1": "7000 North Mopac Expressway",
        "address_2": "Austin  TX  78731",
        "country": "US"
    },
    "BC620E": {
        "oui_hex": "BC-62-0E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "74A528": {
        "oui_hex": "74-A5-28",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "5CF6DC": {
        "oui_hex": "5C-F6-DC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "0026E4": {
        "oui_hex": "00-26-E4",
        "organization": "Canal +",
        "address_1": "48 quai du point du jour",
        "address_2": "Boulogne-Billancourt    92659",
        "country": "FR"
    },
    "000117": {
        "oui_hex": "00-01-17",
        "organization": "Canal +",
        "address_1": "23 Rue LeBlanc",
        "address_2": "75906 Paris Cedex 15    12345",
        "country": "FR"
    },
    "E01D3B": {
        "oui_hex": "E0-1D-3B",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "22 Floor, Qilai Tower, #889 Yishan Road",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "70C76F": {
        "oui_hex": "70-C7-6F",
        "organization": "INNO S",
        "address_1": "215beon-gil, 119",
        "address_2": "Guri-si  Gyeonggi-do  471-060",
        "country": "KR"
    },
    "38192F": {
        "oui_hex": "38-19-2F",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "B8C68E": {
        "oui_hex": "B8-C6-8E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "04FE31": {
        "oui_hex": "04-FE-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "4CBCA5": {
        "oui_hex": "4C-BC-A5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "D831CF": {
        "oui_hex": "D8-31-CF",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "188331": {
        "oui_hex": "18-83-31",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "9C65B0": {
        "oui_hex": "9C-65-B0",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "8455A5": {
        "oui_hex": "84-55-A5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A87C01": {
        "oui_hex": "A8-7C-01",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B0D09C": {
        "oui_hex": "B0-D0-9C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "50C8E5": {
        "oui_hex": "50-C8-E5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1,Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "0020D4": {
        "oui_hex": "00-20-D4",
        "organization": "Cabletron Systems, Inc.",
        "address_1": "35 INDUSTRIAL WAY",
        "address_2": "ROHESTER  NH  03866-5005",
        "country": "US"
    },
    "00E03A": {
        "oui_hex": "00-E0-3A",
        "organization": "Cabletron Systems, Inc.",
        "address_1": "35 INDUSTRIAL WAY - BLDG. #36",
        "address_2": "ROCHESTER  NH  03867",
        "country": "US"
    },
    "0010E7": {
        "oui_hex": "00-10-E7",
        "organization": "Breezecom, Ltd.",
        "address_1": "PO Box 13139",
        "address_2": "Tel-Aviv    12345",
        "country": "IL"
    },
    "9492BC": {
        "oui_hex": "94-92-BC",
        "organization": "SYNTECH(HK) TECHNOLOGY LIMITED",
        "address_1": "Unit No.1,12/F.,Perfect Industrial Building,31 Tai Yau Street, San Po Kong, Kowloon, Hong Kong 999077",
        "address_2": "Kowloon    999077",
        "country": "HK"
    },
    "001D19": {
        "oui_hex": "00-1D-19",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F., No. 9 , Park Avenue II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0012BF": {
        "oui_hex": "00-12-BF",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "507E5D": {
        "oui_hex": "50-7E-5D",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "7C4FB5": {
        "oui_hex": "7C-4F-B5",
        "organization": "Arcadyan Technology Corporation",
        "address_1": "4F, No. 9, Park Avenue II ,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00223F": {
        "oui_hex": "00-22-3F",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000FB5": {
        "oui_hex": "00-0F-B5",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00095B": {
        "oui_hex": "00-09-5B",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001A4F": {
        "oui_hex": "00-1A-4F",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "001C4A": {
        "oui_hex": "00-1C-4A",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "00150C": {
        "oui_hex": "00-15-0C",
        "organization": "AVM GmbH",
        "address_1": "Alt-Moabit 95",
        "address_2": "Berlin    10559",
        "country": "DE"
    },
    "0026FF": {
        "oui_hex": "00-26-FF",
        "organization": "BlackBerry RTS",
        "address_1": "440 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 5W9",
        "country": "CA"
    },
    "A4E4B8": {
        "oui_hex": "A4-E4-B8",
        "organization": "BlackBerry RTS",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "003067": {
        "oui_hex": "00-30-67",
        "organization": "BIOSTAR Microtech Int'l Corp.",
        "address_1": "2FL. NO. 108-2 MIN CHUAN ROAD",
        "address_2": "HSIN TIEN CITY, TAIPEI HSIEN    12345",
        "country": "TW"
    },
    "F40B93": {
        "oui_hex": "F4-0B-93",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "1C69A5": {
        "oui_hex": "1C-69-A5",
        "organization": "BlackBerry RTS",
        "address_1": "451 Phillip Street",
        "address_2": "Waterloo  ON  N2L 3X2",
        "country": "CA"
    },
    "94EBCD": {
        "oui_hex": "94-EB-CD",
        "organization": "BlackBerry RTS",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L3W8",
        "country": "CA"
    },
    "28C68E": {
        "oui_hex": "28-C6-8E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "04A151": {
        "oui_hex": "04-A1-51",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F87394": {
        "oui_hex": "F8-73-94",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "204E7F": {
        "oui_hex": "20-4E-7F",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "C03F0E": {
        "oui_hex": "C0-3F-0E",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0026F2": {
        "oui_hex": "00-26-F2",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00138F": {
        "oui_hex": "00-13-8F",
        "organization": "Asiarock Technology Limited",
        "address_1": "P.O. Box957, Offshore Incorporations Centre",
        "address_2": "Road Town  Tortola  12345",
        "country": "VG"
    },
    "803773": {
        "oui_hex": "80-37-73",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A42B8C": {
        "oui_hex": "A4-2B-8C",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CC7D37": {
        "oui_hex": "CC-7D-37",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A47AA4": {
        "oui_hex": "A4-7A-A4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001700": {
        "oui_hex": "00-17-00",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0016B5": {
        "oui_hex": "00-16-B5",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0015A8": {
        "oui_hex": "00-15-A8",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00159A": {
        "oui_hex": "00-15-9A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001180": {
        "oui_hex": "00-11-80",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000B06": {
        "oui_hex": "00-0B-06",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00D088": {
        "oui_hex": "00-D0-88",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00128A": {
        "oui_hex": "00-12-8A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "002375": {
        "oui_hex": "00-23-75",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0023A3": {
        "oui_hex": "00-23-A3",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001ADB": {
        "oui_hex": "00-1A-DB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001F7E": {
        "oui_hex": "00-1F-7E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0011AE": {
        "oui_hex": "00-11-AE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "94CCB9": {
        "oui_hex": "94-CC-B9",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "3C438E": {
        "oui_hex": "3C-43-8E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0024C1": {
        "oui_hex": "00-24-C1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0025F2": {
        "oui_hex": "00-25-F2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0025F1": {
        "oui_hex": "00-25-F1",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001404": {
        "oui_hex": "00-14-04",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001AAD": {
        "oui_hex": "00-1A-AD",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0026BA": {
        "oui_hex": "00-26-BA",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00230B": {
        "oui_hex": "00-23-0B",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "74E7C6": {
        "oui_hex": "74-E7-C6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001C12": {
        "oui_hex": "00-1C-12",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "5C338E": {
        "oui_hex": "5C-33-8E",
        "organization": "Alpha Networks Inc.",
        "address_1": "No.8 Li-shing Seventh Road,Science-based",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "000941": {
        "oui_hex": "00-09-41",
        "organization": "Allied Telesis R&D Center K.K.",
        "address_1": "Technical Center/No.2 TOC Bldg.",
        "address_2": "Shinagawa-ku    141-0031",
        "country": "US"
    },
    "28E347": {
        "oui_hex": "28-E3-47",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "446D57": {
        "oui_hex": "44-6D-57",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "9CB70D": {
        "oui_hex": "9C-B7-0D",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "68A3C4": {
        "oui_hex": "68-A3-C4",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "70F1A1": {
        "oui_hex": "70-F1-A1",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo,Taipei Hsien,Taiwan,",
        "address_2": "TaiPei  TaiWan  23585",
        "country": "TW"
    },
    "8400D2": {
        "oui_hex": "84-00-D2",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "303926": {
        "oui_hex": "30-39-26",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "00EB2D": {
        "oui_hex": "00-EB-2D",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "B4527D": {
        "oui_hex": "B4-52-7D",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "00D9D1": {
        "oui_hex": "00-D9-D1",
        "organization": "Sony Interactive Entertainment Inc.",
        "address_1": "1-7-1 Konan",
        "address_2": "Minato-ku  Tokyo  108-0075",
        "country": "JP"
    },
    "B00594": {
        "oui_hex": "B0-05-94",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F,90,Chien 1 Road,ChungHo",
        "address_2": "New Taipei City  Taipei  23585",
        "country": "TW"
    },
    "EC086B": {
        "oui_hex": "EC-08-6B",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "94A1A2": {
        "oui_hex": "94-A1-A2",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road",
        "address_2": "Hukou  Hsinchu  30352",
        "country": "TW"
    },
    "00014A": {
        "oui_hex": "00-01-4A",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec, 5-1-2 Kitashinagawa",
        "address_2": "Tokyo    141-0001",
        "country": "JP"
    },
    "001EDC": {
        "oui_hex": "00-1E-DC",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001D28": {
        "oui_hex": "00-1D-28",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "001813": {
        "oui_hex": "00-18-13",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "402BA1": {
        "oui_hex": "40-2B-A1",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "983B16": {
        "oui_hex": "98-3B-16",
        "organization": "AMPAK Technology, Inc.",
        "address_1": "No.1,Jen Ai Road",
        "address_2": "Hsinchu    30352",
        "country": "TW"
    },
    "409558": {
        "oui_hex": "40-95-58",
        "organization": "Aisino Corporation",
        "address_1": "No.18A, Xingshikou Road,",
        "address_2": "Beijing    100195",
        "country": "CN"
    },
    "182861": {
        "oui_hex": "18-28-61",
        "organization": "AirTies Wireless Networks",
        "address_1": "Gulbahar Mahallesi, Avni Diligil Sokak",
        "address_2": "ISTANBUL  ISTANBUL  34394",
        "country": "TR"
    },
    "6C71D9": {
        "oui_hex": "6C-71-D9",
        "organization": "AzureWave Technology Inc.",
        "address_1": "9F.,No.92,Baozhong Rd",
        "address_2": "Xindian District  New Taipei City  231",
        "country": "TW"
    },
    "D0E782": {
        "oui_hex": "D0-E7-82",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd",
        "address_2": ". New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "6CADF8": {
        "oui_hex": "6C-AD-F8",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd",
        "address_2": ". New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "A81D16": {
        "oui_hex": "A8-1D-16",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "34C3D2": {
        "oui_hex": "34-C3-D2",
        "organization": "FN-LINK TECHNOLOGY LIMITED",
        "address_1": "A Building,HuiXin industial park,No 31, YongHe road, Fuyong town, Bao'an District",
        "address_2": "SHENZHEN  GUANGDONG  518100",
        "country": "CN"
    },
    "54F6C5": {
        "oui_hex": "54-F6-C5",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building, Star-net Science Plaza, Juyuanzhou,",
        "address_2": "FUZHOU  FUJIAN  350002",
        "country": "CN"
    },
    "D0D412": {
        "oui_hex": "D0-D4-12",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 336",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "0026B8": {
        "oui_hex": "00-26-B8",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0026FC": {
        "oui_hex": "00-26-FC",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F., No.22, Dalin Rd.,",
        "address_2": "Taoyuan City,  Taoyuan County  330",
        "country": "TW"
    },
    "0015AF": {
        "oui_hex": "00-15-AF",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No.94, Baozhong Rd., Xindian",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "74F06D": {
        "oui_hex": "74-F0-6D",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd., Xindian",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "44D832": {
        "oui_hex": "44-D8-32",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd., Xindian",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "E0B9A5": {
        "oui_hex": "E0-B9-A5",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baoshong Rd.",
        "address_2": "Xindian City, Taipei County    231",
        "country": "TW"
    },
    "781881": {
        "oui_hex": "78-18-81",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No.94 Baozhong Rd.,",
        "address_2": "Xindian, Taipei    23144",
        "country": "TW"
    },
    "B046FC": {
        "oui_hex": "B0-46-FC",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "E04136": {
        "oui_hex": "E0-41-36",
        "organization": "MitraStar Technology Corp.",
        "address_1": "No. 6, Innovation Road II,",
        "address_2": "Hsinchu  Taiwan  300",
        "country": "TW"
    },
    "001CA2": {
        "oui_hex": "00-1C-A2",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "002233": {
        "oui_hex": "00-22-33",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO    20126",
        "country": "IT"
    },
    "3039F2": {
        "oui_hex": "30-39-F2",
        "organization": "ADB Broadband Italia",
        "address_1": "VIALE SARCA 222",
        "address_2": "MILANO     20126",
        "country": "IT"
    },
    "0017C2": {
        "oui_hex": "00-17-C2",
        "organization": "ADB Broadband Italia",
        "address_1": "v.Sarca 222",
        "address_2": "Milano    20126",
        "country": "IT"
    },
    "689C5E": {
        "oui_hex": "68-9C-5E",
        "organization": "AcSiP Technology Corp.",
        "address_1": "3F., No.22, Dalin Rd.",
        "address_2": "Taoyuan  Taoyuan County  33067",
        "country": "TW"
    },
    "9C0E4A": {
        "oui_hex": "9C-0E-4A",
        "organization": "Shenzhen Vastking Electronic Co.,Ltd.",
        "address_1": "2/F Building 6,ZhengZhong Industrial Park,Qiaotou Community,Fuyong,Baoan,ShenZhen China",
        "address_2": "Shenzhen  Guangdong  518103",
        "country": "CN"
    },
    "A85840": {
        "oui_hex": "A8-58-40",
        "organization": "Cambridge Industries(Group) Co.,Ltd.",
        "address_1": "5/F,Building 8, 2388 ChenHang Road, MinHang District",
        "address_2": "shanghai    201114",
        "country": "CN"
    },
    "A0D37A": {
        "oui_hex": "A0-D3-7A",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "8896F2": {
        "oui_hex": "88-96-F2",
        "organization": "Valeo Schalter und Sensoren GmbH",
        "address_1": "Laiernstrasse 12",
        "address_2": "Bietigheim-Bissingen  Germany  74321",
        "country": "DE"
    },
    "001073": {
        "oui_hex": "00-10-73",
        "organization": "TECHNOBOX, INC.",
        "address_1": "140 Mount Holly Bypass",
        "address_2": "Lumberton  NJ  08048-1114",
        "country": "US"
    },
    "20934D": {
        "oui_hex": "20-93-4D",
        "organization": "FUJIAN STAR-NET COMMUNICATION CO.,LTD",
        "address_1": "19-22# Building,,Star-net Science Plaza",
        "address_2": "Fuzhou  Fujian  350002",
        "country": "CN"
    },
    "009027": {
        "oui_hex": "00-90-27",
        "organization": "Intel Corporation",
        "address_1": "HF1-06",
        "address_2": "HILLSBORO  OR  97124",
        "country": "US"
    },
    "C48508": {
        "oui_hex": "C4-85-08",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6805CA": {
        "oui_hex": "68-05-CA",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "247703": {
        "oui_hex": "24-77-03",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "74E50B": {
        "oui_hex": "74-E5-0B",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B80305": {
        "oui_hex": "B8-03-05",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "00A0C9": {
        "oui_hex": "00-A0-C9",
        "organization": "Intel Corporation",
        "address_1": "5200 NE ELAM YOUNG PARKWAY",
        "address_2": "HILLSBORO  OR  97124",
        "country": "US"
    },
    "141877": {
        "oui_hex": "14-18-77",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "E09796": {
        "oui_hex": "E0-97-96",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "1C4024": {
        "oui_hex": "1C-40-24",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "18FB7B": {
        "oui_hex": "18-FB-7B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "F8B156": {
        "oui_hex": "F8-B1-56",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "141AA3": {
        "oui_hex": "14-1A-A3",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 Merchandise Mart Plaza, Suite 1800",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "3407FB": {
        "oui_hex": "34-07-FB",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "A4A1C2": {
        "oui_hex": "A4-A1-C2",
        "organization": "Ericsson AB",
        "address_1": "Torshamnsgatan 36",
        "address_2": "Stockholm    SE-164 80",
        "country": "SE"
    },
    "00065B": {
        "oui_hex": "00-06-5B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "842B2B": {
        "oui_hex": "84-2B-2B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock     78682",
        "country": "US"
    },
    "F04DA2": {
        "oui_hex": "F0-4D-A2",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way, MS RR5-45",
        "address_2": "Round Rock     78682",
        "country": "US"
    },
    "E0DB55": {
        "oui_hex": "E0-DB-55",
        "organization": "Dell Inc.",
        "address_1": "One Dell way",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "000F1F": {
        "oui_hex": "00-0F-1F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "24B6FD": {
        "oui_hex": "24-B6-FD",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "74E6E2": {
        "oui_hex": "74-E6-E2",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "34E6D7": {
        "oui_hex": "34-E6-D7",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "001EC9": {
        "oui_hex": "00-1E-C9",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "002170": {
        "oui_hex": "00-21-70",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "00219B": {
        "oui_hex": "00-21-9B",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "B8AC6F": {
        "oui_hex": "B8-AC-6F",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way,  MS RR5-45",
        "address_2": "Round Rock    78682",
        "country": "US"
    },
    "8CA982": {
        "oui_hex": "8C-A9-82",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "BC7737": {
        "oui_hex": "BC-77-37",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1430C6": {
        "oui_hex": "14-30-C6",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "600 North US Highway 45",
        "address_2": "Libertyville  IL  60048",
        "country": "US"
    },
    "D8FC93": {
        "oui_hex": "D8-FC-93",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D4AE52": {
        "oui_hex": "D4-AE-52",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "28162E": {
        "oui_hex": "28-16-2E",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "F81897": {
        "oui_hex": "F8-18-97",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose    95131",
        "country": "US"
    },
    "94C150": {
        "oui_hex": "94-C1-50",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "5CF821": {
        "oui_hex": "5C-F8-21",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "88074B": {
        "oui_hex": "88-07-4B",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "000D72": {
        "oui_hex": "00-0D-72",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001288": {
        "oui_hex": "00-12-88",
        "organization": "2Wire Inc",
        "address_1": "1704 Automation Parkway",
        "address_2": "San Jose  CA  94538",
        "country": "US"
    },
    "00789E": {
        "oui_hex": "00-78-9E",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "E8BE81": {
        "oui_hex": "E8-BE-81",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  Hauts de Seine  92848",
        "country": "FR"
    },
    "681590": {
        "oui_hex": "68-15-90",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 ROUTE DE L'EMPEREUR",
        "address_2": "RUEIL MALMAISON CEDEX  Choisissez l'état / la province  92848",
        "country": "FR"
    },
    "F4EB38": {
        "oui_hex": "F4-EB-38",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "15 Avenue Ambroise  Croizat",
        "address_2": "DOMERAT  Allier  03410",
        "country": "FR"
    },
    "001BBF": {
        "oui_hex": "00-1B-BF",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "14 Rue Paul Dautier",
        "address_2": "VÃƒÂ©lizy    78457",
        "country": "FR"
    },
    "002569": {
        "oui_hex": "00-25-69",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "Le Ponnant de Paris",
        "address_2": "CEDEX  Paris  75512",
        "country": "FR"
    },
    "141FBA": {
        "oui_hex": "14-1F-BA",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "807B85": {
        "oui_hex": "80-7B-85",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "CC1BE0": {
        "oui_hex": "CC-1B-E0",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "F40E11": {
        "oui_hex": "F4-0E-11",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "10F681": {
        "oui_hex": "10-F6-81",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "00217C": {
        "oui_hex": "00-21-7C",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001FB3": {
        "oui_hex": "00-1F-B3",
        "organization": "2Wire Inc",
        "address_1": "1764 Automation Parkway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "002275": {
        "oui_hex": "00-22-75",
        "organization": "Belkin International Inc.",
        "address_1": "12045 E. Waterfront Drive",
        "address_2": "Playa Vista  CA  90094",
        "country": "US"
    },
    "0057D2": {
        "oui_hex": "00-57-D2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "3C6716": {
        "oui_hex": "3C-67-16",
        "organization": "Lily Robotics",
        "address_1": "75 Boardman Pl",
        "address_2": "San Francisco  CA  94103",
        "country": "US"
    },
    "00D0BD": {
        "oui_hex": "00-D0-BD",
        "organization": "Lattice Semiconductor Corp. (LPA)",
        "address_1": "2115 O’Nel Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001F3A": {
        "oui_hex": "00-1F-3A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C8A030": {
        "oui_hex": "C8-A0-30",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "78C5E5": {
        "oui_hex": "78-C5-E5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0CFD37": {
        "oui_hex": "0C-FD-37",
        "organization": "SUSE Linux GmbH",
        "address_1": "Maxfeldstraße 5",
        "address_2": "Nürnberg  Bavaria  90409",
        "country": "DE"
    },
    "2C228B": {
        "oui_hex": "2C-22-8B",
        "organization": "CTR SRL",
        "address_1": "Via Lario 33",
        "address_2": "Cantù  Cantù (CO)  22063",
        "country": "IT"
    },
    "0C6F9C": {
        "oui_hex": "0C-6F-9C",
        "organization": "Shaw Communications Inc.",
        "address_1": "Suite 900, 630 3rd Avenue S.W.",
        "address_2": "CALGARY  ALBERTA  T2P 4L4",
        "country": "CA"
    },
    "0017E4": {
        "oui_hex": "00-17-E4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "04E451": {
        "oui_hex": "04-E4-51",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "505663": {
        "oui_hex": "50-56-63",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "883314": {
        "oui_hex": "88-33-14",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "647BD4": {
        "oui_hex": "64-7B-D4",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D8952F": {
        "oui_hex": "D8-95-2F",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "B8FFFE": {
        "oui_hex": "B8-FF-FE",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "2CE412": {
        "oui_hex": "2C-E4-12",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250 route de l'Empereur",
        "address_2": "RUEIL MALMAISON CEDEX  Hauts de Seine  92848",
        "country": "FR"
    },
    "44C15C": {
        "oui_hex": "44-C1-5C",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "0022A5": {
        "oui_hex": "00-22-A5",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard, MS 8723",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "E043DB": {
        "oui_hex": "E0-43-DB",
        "organization": "Shenzhen ViewAt Technology Co.,Ltd.",
        "address_1": "9A,Microprofit,6th Gaoxin South Road, High-Tech Industrial Park, Nanshan, Shenzhen, CHINA.",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "3CCF5B": {
        "oui_hex": "3C-CF-5B",
        "organization": "ICOMM HK LIMITED",
        "address_1": "SUITES 2302-6, 23/F GREAT EAGLE CTR 23 HARBOUR RD",
        "address_2": "WANCHAI    NA",
        "country": "HK"
    },
    "2405F5": {
        "oui_hex": "24-05-F5",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "3C3556": {
        "oui_hex": "3C-35-56",
        "organization": "Cognitec Systems GmbH",
        "address_1": "Großenhainer Str. 101",
        "address_2": "Dresden  Saxony  01127",
        "country": "DE"
    },
    "3C9066": {
        "oui_hex": "3C-90-66",
        "organization": "SmartRG, Inc.",
        "address_1": "501 SE Columbia Shores Blvd",
        "address_2": "Vancouver  WA  98661",
        "country": "US"
    },
    "000D88": {
        "oui_hex": "00-0D-88",
        "organization": "D-Link Corporation",
        "address_1": "No.8, Li-Hsing 7 Road, Science-Based Ind",
        "address_2": "Hsinchu    30077",
        "country": "TW"
    },
    "001195": {
        "oui_hex": "00-11-95",
        "organization": "D-Link Corporation",
        "address_1": "2F No. 233-2, Pao-Chiao Road",
        "address_2": "Taipei  Taiwan  0000",
        "country": "TW"
    },
    "001346": {
        "oui_hex": "00-13-46",
        "organization": "D-Link Corporation",
        "address_1": "2F, No.233-2, Pao-Chiao Road",
        "address_2": "Hsin-Tien,  Taipei  231",
        "country": "TW"
    },
    "78E3B5": {
        "oui_hex": "78-E3-B5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "78ACC0": {
        "oui_hex": "78-AC-C0",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "68B599": {
        "oui_hex": "68-B5-99",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "1CC1DE": {
        "oui_hex": "1C-C1-DE",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "B8A386": {
        "oui_hex": "B8-A3-86",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "1C7EE5": {
        "oui_hex": "1C-7E-E5",
        "organization": "D-Link International",
        "address_1": "1 International Business Park, #03-12, The Synergy",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "1CBDB9": {
        "oui_hex": "1C-BD-B9",
        "organization": "D-Link International",
        "address_1": "1 INTERNATIONAL  BUSINESS  PARK,",
        "address_2": "SINGAPORE    609917",
        "country": "SG"
    },
    "00142F": {
        "oui_hex": "00-14-2F",
        "organization": "Savvius",
        "address_1": "1340 Treat Boulevard, Suite 500",
        "address_2": "Walnut Creek  CA  94597",
        "country": "US"
    },
    "28BC18": {
        "oui_hex": "28-BC-18",
        "organization": "SourcingOverseas Co. Ltd",
        "address_1": "2F., No.616, Sec.5, Zhongshan N. Rd., Shilin Dist.,",
        "address_2": "Taipei City    111",
        "country": "TW"
    },
    "94ABDE": {
        "oui_hex": "94-AB-DE",
        "organization": "OMX Technology - FZE",
        "address_1": "Dubai Silicon Oasis - THUB - 1-D-OFF-124",
        "address_2": "Dubai    65673",
        "country": "AE"
    },
    "9CDFB1": {
        "oui_hex": "9C-DF-B1",
        "organization": "Shenzhen Crave Communication Co., LTD",
        "address_1": "F3,8Building,DongFangMing IndustryZone,No.83 DabaoRD.,33 District BaoAn",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "ACCF85": {
        "oui_hex": "AC-CF-85",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "3871DE": {
        "oui_hex": "38-71-DE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7081EB": {
        "oui_hex": "70-81-EB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00738D": {
        "oui_hex": "00-73-8D",
        "organization": "Shenzhen TINNO Mobile Technology Corp.",
        "address_1": "4/F.,H-3 Building,OCT Eastern lndustrial Park. NO.1 XiangShan East Road.",
        "address_2": "GuangDong    518053",
        "country": "US"
    },
    "34BA75": {
        "oui_hex": "34-BA-75",
        "organization": "Everest Networks, Inc",
        "address_1": "2933 Bunker Hill Ln., Suite 100",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "7C18CD": {
        "oui_hex": "7C-18-CD",
        "organization": "E-TRON Co.,Ltd.",
        "address_1": "66-11, Nonhyeon 2-dong, Gangnam-gu",
        "address_2": "Seoul    06049",
        "country": "KR"
    },
    "00E0FC": {
        "oui_hex": "00-E0-FC",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "KEFA ROAD, SCIENCE-BASED INDUSTRIAL PARK",
        "address_2": "SHENZHEN 518057    12345",
        "country": "CN"
    },
    "6416F0": {
        "oui_hex": "64-16-F0",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 2, Zone B,Huawei Industrial Park,Bantian, Longgang District",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "F40304": {
        "oui_hex": "F4-03-04",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Pkwy",
        "address_2": "Mt. View  CA  94043",
        "country": "US"
    },
    "546009": {
        "oui_hex": "54-60-09",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "A47733": {
        "oui_hex": "A4-77-33",
        "organization": "Google, Inc.",
        "address_1": "1600 Ampitheatre Parkway",
        "address_2": "Mountain View    94043",
        "country": "US"
    },
    "807ABF": {
        "oui_hex": "80-7A-BF",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "78F882": {
        "oui_hex": "78-F8-82",
        "organization": "LG Electronics (Mobile Communications)",
        "address_1": "60-39, Gasan-dong, Geumcheon-gu",
        "address_2": "Seoul    153-801",
        "country": "KR"
    },
    "C02C7A": {
        "oui_hex": "C0-2C-7A",
        "organization": "Shenzhen Horn Audio Co.,Ltd.",
        "address_1": "Block17,Tongfuyu lnd.Zone,Dalang,Baoan",
        "address_2": "Shenzhen  Guang Dong   518109",
        "country": "CN"
    },
    "1CCB99": {
        "oui_hex": "1C-CB-99",
        "organization": "TCT mobile ltd",
        "address_1": "No.86 hechang 7th road, zhongkai, Hi-Tech District",
        "address_2": "Hui Zhou  Guang Dong  516006",
        "country": "CN"
    },
    "A42BB0": {
        "oui_hex": "A4-2B-B0",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "188B45": {
        "oui_hex": "18-8B-45",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "606944": {
        "oui_hex": "60-69-44",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B0C69A": {
        "oui_hex": "B0-C6-9A",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "2C6BF5": {
        "oui_hex": "2C-6B-F5",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C42F90": {
        "oui_hex": "C4-2F-90",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.469,Jianghui Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "F4CA24": {
        "oui_hex": "F4-CA-24",
        "organization": "FreeBit Co., Ltd.",
        "address_1": "E.Space Tower 3-6 Maruyama-Cho",
        "address_2": "Shibuya-ku  Tokyo  150-0044",
        "country": "JP"
    },
    "00D0B7": {
        "oui_hex": "00-D0-B7",
        "organization": "Intel Corporation",
        "address_1": "5200 NE ELAM YOUNG PARKWAY",
        "address_2": "HILLSBORO  OR  97124",
        "country": "US"
    },
    "001DD6": {
        "oui_hex": "00-1D-D6",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "903EAB": {
        "oui_hex": "90-3E-AB",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "306023": {
        "oui_hex": "30-60-23",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "14ABF0": {
        "oui_hex": "14-AB-F0",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0014F6": {
        "oui_hex": "00-14-F6",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "901ACA": {
        "oui_hex": "90-1A-CA",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "C83FB4": {
        "oui_hex": "C8-3F-B4",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E0B70A": {
        "oui_hex": "E0-B7-0A",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001DCE": {
        "oui_hex": "00-1D-CE",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0013E8": {
        "oui_hex": "00-13-E8",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "0013CE": {
        "oui_hex": "00-13-CE",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "2C768A": {
        "oui_hex": "2C-76-8A",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "C8348E": {
        "oui_hex": "C8-34-8E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "4C3488": {
        "oui_hex": "4C-34-88",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "1002B5": {
        "oui_hex": "10-02-B5",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "004026": {
        "oui_hex": "00-40-26",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "4CE676": {
        "oui_hex": "4C-E6-76",
        "organization": "BUFFALO.INC",
        "address_1": "AKAMONDORI Bldg., 30-20,Ohsu 3-chome",
        "address_2": "Naka-ku,Nagoya  Aichi Pref.  460-8315",
        "country": "JP"
    },
    "000BCD": {
        "oui_hex": "00-0B-CD",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "000F20": {
        "oui_hex": "00-0F-20",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "00110A": {
        "oui_hex": "00-11-0A",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "B8B81E": {
        "oui_hex": "B8-B8-1E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B46D83": {
        "oui_hex": "B4-6D-83",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "000E35": {
        "oui_hex": "00-0E-35",
        "organization": "Intel Corporation",
        "address_1": "2111 NE 25th Ave",
        "address_2": "Hillsboro  OR  97123",
        "country": "US"
    },
    "0007E9": {
        "oui_hex": "00-07-E9",
        "organization": "Intel Corporation",
        "address_1": "2111 NE 25th Avenue",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "001708": {
        "oui_hex": "00-17-08",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "0017A4": {
        "oui_hex": "00-17-A4",
        "organization": "Hewlett Packard",
        "address_1": "20555 State Highway 249",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "C005C2": {
        "oui_hex": "C0-05-C2",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0030C1": {
        "oui_hex": "00-30-C1",
        "organization": "Hewlett Packard",
        "address_1": "11000 WOLFE ROAD",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "0080A0": {
        "oui_hex": "00-80-A0",
        "organization": "Hewlett Packard",
        "address_1": "ALAMEDA RIO NEGRO,",
        "address_2": "houston  tx  77070",
        "country": "BR"
    },
    "D48564": {
        "oui_hex": "D4-85-64",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "24BE05": {
        "oui_hex": "24-BE-05",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive W",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "FC3FDB": {
        "oui_hex": "FC-3F-DB",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston  TX  77070",
        "country": "US"
    },
    "308D99": {
        "oui_hex": "30-8D-99",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "5820B1": {
        "oui_hex": "58-20-B1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "9457A5": {
        "oui_hex": "94-57-A5",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "000EB3": {
        "oui_hex": "00-0E-B3",
        "organization": "Hewlett Packard",
        "address_1": "2580 55th Street",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "080009": {
        "oui_hex": "08-00-09",
        "organization": "Hewlett Packard",
        "address_1": "ENTERPRISE SYSTEMS TECH.CENTER",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "90CDB6": {
        "oui_hex": "90-CD-B6",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "40490F": {
        "oui_hex": "40-49-0F",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "00265C": {
        "oui_hex": "00-26-5C",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "002269": {
        "oui_hex": "00-22-69",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "D87988": {
        "oui_hex": "D8-79-88",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "74A78E": {
        "oui_hex": "74-A7-8E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "00092D": {
        "oui_hex": "00-09-2D",
        "organization": "HTC Corporation",
        "address_1": "No.23 Xinghua Road,",
        "address_2": "Taoyuan County     330",
        "country": "TW"
    },
    "443192": {
        "oui_hex": "44-31-92",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "A0D3C1": {
        "oui_hex": "A0-D3-C1",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "38EAA7": {
        "oui_hex": "38-EA-A7",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "AC162D": {
        "oui_hex": "AC-16-2D",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "80C16E": {
        "oui_hex": "80-C1-6E",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "B4B52F": {
        "oui_hex": "B4-B5-2F",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D07E28": {
        "oui_hex": "D0-7E-28",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "D0BF9C": {
        "oui_hex": "D0-BF-9C",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "7C6193": {
        "oui_hex": "7C-61-93",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd.,",
        "address_2": "Taoyuan County    330",
        "country": "TW"
    },
    "90E7C4": {
        "oui_hex": "90-E7-C4",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd.",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "BCEAFA": {
        "oui_hex": "BC-EA-FA",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "7446A0": {
        "oui_hex": "74-46-A0",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "2C44FD": {
        "oui_hex": "2C-44-FD",
        "organization": "Hewlett Packard",
        "address_1": "11445 Compaq Center Drive",
        "address_2": "Houston    77070",
        "country": "US"
    },
    "0453D5": {
        "oui_hex": "04-53-D5",
        "organization": "Sysorex Global Holdings",
        "address_1": "Suite 195 2479 E. Bayshore Road",
        "address_2": "Palo Alto  CA  94303",
        "country": "US"
    },
    "EC52DC": {
        "oui_hex": "EC-52-DC",
        "organization": "WORLD MEDIA AND TECHNOLOGY Corp.",
        "address_1": "600 Brickell World Plaza, suite 1775",
        "address_2": "Miami    33132",
        "country": "US"
    },
    "94B2CC": {
        "oui_hex": "94-B2-CC",
        "organization": "PIONEER CORPORATION",
        "address_1": "1-1 Shin-ogura",
        "address_2": "Kawasaki-shi  Kanagawa Prefecture  2120031",
        "country": "JP"
    },
    "0452F3": {
        "oui_hex": "04-52-F3",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88C255": {
        "oui_hex": "88-C2-55",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "CC78AB": {
        "oui_hex": "CC-78-AB",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "1C7839": {
        "oui_hex": "1C-78-39",
        "organization": "Shenzhen Tencent Computer System Co., Ltd.",
        "address_1": "36/F, Tencent Building, Kejizhongyi Avenue, Hi-Tech Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "FCD733": {
        "oui_hex": "FC-D7-33",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "5C899A": {
        "oui_hex": "5C-89-9A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "A81B5A": {
        "oui_hex": "A8-1B-5A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN,DONGGUAN,GUANGDONG,CHINA",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "2C5BB8": {
        "oui_hex": "2C-5B-B8",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,WUSHA,CHANG'AN,DONGGUAN,GUANGDONG,CHINA",
        "address_2": "DONGGUAN  GUANGDONG  523860",
        "country": "CN"
    },
    "08EB74": {
        "oui_hex": "08-EB-74",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 11-4, Sunae-dong, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-825",
        "country": "KR"
    },
    "E005C5": {
        "oui_hex": "E0-05-C5",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 7, Second Part, Honghualing Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "388345": {
        "oui_hex": "38-83-45",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park,Shennan Rd, Nanshan,",
        "address_2": "Shenzhen,  Guangdong Province  518057",
        "country": "CN"
    },
    "EC888F": {
        "oui_hex": "EC-88-8F",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "6466B3": {
        "oui_hex": "64-66-B3",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)  Central Science and Technology Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "2832C5": {
        "oui_hex": "28-32-C5",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village,216,Hwangsaeul-ro,Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "F0F336": {
        "oui_hex": "F0-F3-36",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "BC4699": {
        "oui_hex": "BC-46-99",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "F483CD": {
        "oui_hex": "F4-83-CD",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24 (floors 1,3,4,5) and 28 (floors1-4)",
        "address_2": "Shennan Rd, Nanshan  Shenzhen,Guangdong Province  518057",
        "country": "CN"
    },
    "002127": {
        "oui_hex": "00-21-27",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "South Building, No.5 Keyuan Road, Central Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "5C63BF": {
        "oui_hex": "5C-63-BF",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "1-6F, Building 2, Pingshandayuan Industrial, South Zone,",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "142D27": {
        "oui_hex": "14-2D-27",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "88E3AB": {
        "oui_hex": "88-E3-AB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "C40528": {
        "oui_hex": "C4-05-28",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "3CDFBD": {
        "oui_hex": "3C-DF-BD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "509F27": {
        "oui_hex": "50-9F-27",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "80717A": {
        "oui_hex": "80-71-7A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0021E8": {
        "oui_hex": "00-21-E8",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "000E6D": {
        "oui_hex": "00-0E-6D",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "2288, Oaza-Ohshinohara, Yasu-cho,",
        "address_2": "Yasu-gun  Shiga  520-2393",
        "country": "JP"
    },
    "902106": {
        "oui_hex": "90-21-06",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "D02788": {
        "oui_hex": "D0-27-88",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "904CE5": {
        "oui_hex": "90-4C-E5",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "001FE2": {
        "oui_hex": "00-1F-E2",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "0016CF": {
        "oui_hex": "00-16-CF",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "2002AF": {
        "oui_hex": "20-02-AF",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1 Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "98F537": {
        "oui_hex": "98-F5-37",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building,kejinan Road,",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5C4CA9": {
        "oui_hex": "5C-4C-A9",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "F4C714": {
        "oui_hex": "F4-C7-14",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District,",
        "address_2": "Shenzhen  Guangdong  518108",
        "country": "CN"
    },
    "286ED4": {
        "oui_hex": "28-6E-D4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "HUAWEI Industrial Base Bantian,Longgang",
        "address_2": "Shenzhen  guangdong  518129",
        "country": "CN"
    },
    "001E10": {
        "oui_hex": "00-1E-10",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "HUAWEI INDUSTRIAL PK BANTIAN, LONGGANG DIST SHENZHEN",
        "address_2": "SHENZHEN  GUANGDONG  518077",
        "country": "CN"
    },
    "D47856": {
        "oui_hex": "D4-78-56",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "D842AC": {
        "oui_hex": "D8-42-AC",
        "organization": "Shanghai Feixun Communication Co.,Ltd.",
        "address_1": "Building 90, No. 4855, Guangfulin Road, Songjiang District",
        "address_2": "Shanghai    201616",
        "country": "CN"
    },
    "5439DF": {
        "oui_hex": "54-39-DF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "283CE4": {
        "oui_hex": "28-3C-E4",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate,Shiyan Baoan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "2CF4C5": {
        "oui_hex": "2C-F4-C5",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "3C3A73": {
        "oui_hex": "3C-3A-73",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "FC8399": {
        "oui_hex": "FC-83-99",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "587F66": {
        "oui_hex": "58-7F-66",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "64A651": {
        "oui_hex": "64-A6-51",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "086361": {
        "oui_hex": "08-63-61",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "Building 17,Nangang Industrial Park, Tangtou 3nd Industrial Estate",
        "address_2": "Shenzhen  GuangDong  518057",
        "country": "CN"
    },
    "A01290": {
        "oui_hex": "A0-12-90",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "38BB3C": {
        "oui_hex": "38-BB-3C",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "F873A2": {
        "oui_hex": "F8-73-A2",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "CCF954": {
        "oui_hex": "CC-F9-54",
        "organization": "Avaya Inc",
        "address_1": "360 Mt Kemble Ave",
        "address_2": "Morristown  NJ  07960",
        "country": "US"
    },
    "8C34FD": {
        "oui_hex": "8C-34-FD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ACF7F3": {
        "oui_hex": "AC-F7-F3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "D4970B": {
        "oui_hex": "D4-97-0B",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "8CBEBE": {
        "oui_hex": "8C-BE-BE",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "14F65A": {
        "oui_hex": "14-F6-5A",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "009EC8": {
        "oui_hex": "00-9E-C8",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "0C1DAF": {
        "oui_hex": "0C-1D-AF",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "0819A6": {
        "oui_hex": "08-19-A6",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "3CF808": {
        "oui_hex": "3C-F8-08",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "486276": {
        "oui_hex": "48-62-76",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "B41513": {
        "oui_hex": "B4-15-13",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "AC4E91": {
        "oui_hex": "AC-4E-91",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "283152": {
        "oui_hex": "28-31-52",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base,Bantian,Longgang,Shenzhen",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "3480B3": {
        "oui_hex": "34-80-B3",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "F48B32": {
        "oui_hex": "F4-8B-32",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "009021": {
        "oui_hex": "00-90-21",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0090B1": {
        "oui_hex": "00-90-B1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001AB6": {
        "oui_hex": "00-1A-B6",
        "organization": "Texas Instruments",
        "address_1": "108 Wild Basin Ste 350",
        "address_2": "Austin  TX  78746",
        "country": "US"
    },
    "0012D1": {
        "oui_hex": "00-12-D1",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard,",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "001237": {
        "oui_hex": "00-12-37",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Boulevard,",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "A0E6F8": {
        "oui_hex": "A0-E6-F8",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "70FF76": {
        "oui_hex": "70-FF-76",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D03972": {
        "oui_hex": "D0-39-72",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "5C313E": {
        "oui_hex": "5C-31-3E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "F4B85E": {
        "oui_hex": "F4-B8-5E",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "68C90B": {
        "oui_hex": "68-C9-0B",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "74882A": {
        "oui_hex": "74-88-2A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "4CB16C": {
        "oui_hex": "4C-B1-6C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1-4,Huawei Industrial Base,Bantian,Longgang",
        "address_2": "ShenZhen  GuangDong  518129",
        "country": "CN"
    },
    "04BD70": {
        "oui_hex": "04-BD-70",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "D1,Huawei Industrial Base",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "D4F513": {
        "oui_hex": "D4-F5-13",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "507224": {
        "oui_hex": "50-72-24",
        "organization": "Texas Instruments",
        "address_1": "12500 TI BLVD",
        "address_2": "Dallas    75243",
        "country": "US"
    },
    "0090D9": {
        "oui_hex": "00-90-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "009092": {
        "oui_hex": "00-90-92",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00102F": {
        "oui_hex": "00-10-2F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00100D": {
        "oui_hex": "00-10-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001007": {
        "oui_hex": "00-10-07",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "001014": {
        "oui_hex": "00-10-14",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "0090BF": {
        "oui_hex": "00-90-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0050D1": {
        "oui_hex": "00-50-D1",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 W. TASMAN DR.",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "1CE6C7": {
        "oui_hex": "1C-E6-C7",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CCD539": {
        "oui_hex": "CC-D5-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "4C0082": {
        "oui_hex": "4C-00-82",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "7C95F3": {
        "oui_hex": "7C-95-F3",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "34DBFD": {
        "oui_hex": "34-DB-FD",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "885A92": {
        "oui_hex": "88-5A-92",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00400B": {
        "oui_hex": "00-40-0B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "006070": {
        "oui_hex": "00-60-70",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "500604": {
        "oui_hex": "50-06-04",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "00E01E": {
        "oui_hex": "00-E0-1E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "00112F": {
        "oui_hex": "00-11-2F",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "No.150, Li-Te Rd., Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "001BFC": {
        "oui_hex": "00-1B-FC",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "A0554F": {
        "oui_hex": "A0-55-4F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "204C9E": {
        "oui_hex": "20-4C-9E",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "84B802": {
        "oui_hex": "84-B8-02",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "B0AA77": {
        "oui_hex": "B0-AA-77",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "BCC493": {
        "oui_hex": "BC-C4-93",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "A46C2A": {
        "oui_hex": "A4-6C-2A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "D0A5A6": {
        "oui_hex": "D0-A5-A6",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "3C5EC3": {
        "oui_hex": "3C-5E-C3",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "64F69D": {
        "oui_hex": "64-F6-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000389": {
        "oui_hex": "00-03-89",
        "organization": "PLANTRONICS, INC.",
        "address_1": "345 ENCINAL STREET",
        "address_2": "SANTA CRUZ  CA  95060",
        "country": "US"
    },
    "D072DC": {
        "oui_hex": "D0-72-DC",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "28C7CE": {
        "oui_hex": "28-C7-CE",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F40F1B": {
        "oui_hex": "F4-0F-1B",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F8C288": {
        "oui_hex": "F8-C2-88",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "1C6A7A": {
        "oui_hex": "1C-6A-7A",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001EE5": {
        "oui_hex": "00-1E-E5",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine    92612",
        "country": "US"
    },
    "484487": {
        "oui_hex": "48-44-87",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "38C85C": {
        "oui_hex": "38-C8-5C",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "485B39": {
        "oui_hex": "48-5B-39",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,Taipei 112 ,Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "BCAEC5": {
        "oui_hex": "BC-AE-C5",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "10BF48": {
        "oui_hex": "10-BF-48",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd.,Peitou,",
        "address_2": "Taipei    112",
        "country": "TW"
    },
    "5067AE": {
        "oui_hex": "50-67-AE",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "F09E63": {
        "oui_hex": "F0-9E-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "6C9989": {
        "oui_hex": "6C-99-89",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "18E728": {
        "oui_hex": "18-E7-28",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001217": {
        "oui_hex": "00-12-17",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "001310": {
        "oui_hex": "00-13-10",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Dr.",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "046C9D": {
        "oui_hex": "04-6C-9D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "84B261": {
        "oui_hex": "84-B2-61",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "E448C7": {
        "oui_hex": "E4-48-C7",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Pkwy",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "00101F": {
        "oui_hex": "00-10-1F",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 WEST TASMAN DRIVE",
        "address_2": "SAN JOSE  CA  95134-1706",
        "country": "US"
    },
    "54A274": {
        "oui_hex": "54-A2-74",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "60FB42": {
        "oui_hex": "60-FB-42",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "64B9E8": {
        "oui_hex": "64-B9-E8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "001D4F": {
        "oui_hex": "00-1D-4F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "002312": {
        "oui_hex": "00-23-12",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "80E01D": {
        "oui_hex": "80-E0-1D",
        "organization": "Cisco Systems, Inc",
        "address_1": "170 West Tasman Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "D8A25E": {
        "oui_hex": "D8-A2-5E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "000A27": {
        "oui_hex": "00-0A-27",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "183451": {
        "oui_hex": "18-34-51",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "0C771A": {
        "oui_hex": "0C-77-1A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "286ABA": {
        "oui_hex": "28-6A-BA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4CB199": {
        "oui_hex": "4C-B1-99",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "C09F42": {
        "oui_hex": "C0-9F-42",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D023DB": {
        "oui_hex": "D0-23-DB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "70DEE2": {
        "oui_hex": "70-DE-E2",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0CBA1": {
        "oui_hex": "F0-CB-A1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "182032": {
        "oui_hex": "18-20-32",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "403CFC": {
        "oui_hex": "40-3C-FC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "4860BC": {
        "oui_hex": "48-60-BC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3451C9": {
        "oui_hex": "34-51-C9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "406C8F": {
        "oui_hex": "40-6C-8F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "5855CA": {
        "oui_hex": "58-55-CA",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC2B61": {
        "oui_hex": "DC-2B-61",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "40A6D9": {
        "oui_hex": "40-A6-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "60FACD": {
        "oui_hex": "60-FA-CD",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "003EE1": {
        "oui_hex": "00-3E-E1",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FC253F": {
        "oui_hex": "FC-25-3F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04F7E4": {
        "oui_hex": "04-F7-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "34C059": {
        "oui_hex": "34-C0-59",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F0D1A9": {
        "oui_hex": "F0-D1-A9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "705681": {
        "oui_hex": "70-56-81",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "14109F": {
        "oui_hex": "14-10-9F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "040CCE": {
        "oui_hex": "04-0C-CE",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "54EAA8": {
        "oui_hex": "54-EA-A8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28E14C": {
        "oui_hex": "28-E1-4C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E4C63D": {
        "oui_hex": "E4-C6-3D",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "54E43A": {
        "oui_hex": "54-E4-3A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04DB56": {
        "oui_hex": "04-DB-56",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC3C0B": {
        "oui_hex": "AC-3C-0B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "701124": {
        "oui_hex": "70-11-24",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "042665": {
        "oui_hex": "04-26-65",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "EC3586": {
        "oui_hex": "EC-35-86",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "78FD94": {
        "oui_hex": "78-FD-94",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2CBE08": {
        "oui_hex": "2C-BE-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E8802E": {
        "oui_hex": "E8-80-2E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "006171": {
        "oui_hex": "00-61-71",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "8C7C92": {
        "oui_hex": "8C-7C-92",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B03495": {
        "oui_hex": "B0-34-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F437B7": {
        "oui_hex": "F4-37-B7",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "AC7F3E": {
        "oui_hex": "AC-7F-3E",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "280B5C": {
        "oui_hex": "28-0B-5C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "ACFDEC": {
        "oui_hex": "AC-FD-EC",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC9B9C": {
        "oui_hex": "DC-9B-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "54724F": {
        "oui_hex": "54-72-4F",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D8CF9C": {
        "oui_hex": "D8-CF-9C",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7C6DF8": {
        "oui_hex": "7C-6D-F8",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "04E536": {
        "oui_hex": "04-E5-36",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "A8BBCF": {
        "oui_hex": "A8-BB-CF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C4008": {
        "oui_hex": "6C-40-08",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "FCA386": {
        "oui_hex": "FC-A3-86",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "40331A": {
        "oui_hex": "40-33-1A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "CCC760": {
        "oui_hex": "CC-C7-60",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "BC4CC4": {
        "oui_hex": "BC-4C-C4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "DC3714": {
        "oui_hex": "DC-37-14",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "20A2E4": {
        "oui_hex": "20-A2-E4",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28F076": {
        "oui_hex": "28-F0-76",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "141357": {
        "oui_hex": "14-13-57",
        "organization": "ATP Electronics, Inc.",
        "address_1": "2590 North First Street Suite 150",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "B8B2EB": {
        "oui_hex": "B8-B2-EB",
        "organization": "Googol Technology (HK) Limited",
        "address_1": "Unit 1008-09, 10/F C-Bons International Center",
        "address_2": "Kwun Tong  Kowloon  nil",
        "country": "HK"
    },
    "FCCF43": {
        "oui_hex": "FC-CF-43",
        "organization": "HUIZHOU CITY HUIYANG DISTRICT MEISIQI INDUSTRY DEVELOPMENT CO,.LTD",
        "address_1": "Meisiqi lndustrialPark,Yuechang,",
        "address_2": "Huizhou  Guangdong  516000",
        "country": "CN"
    },
    "D848EE": {
        "oui_hex": "D8-48-EE",
        "organization": "Hangzhou Xueji Technology Co., Ltd.",
        "address_1": "Room 1902, Tower D, West Intime City",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "B4EF04": {
        "oui_hex": "B4-EF-04",
        "organization": "DAIHAN Scientific Co., Ltd.",
        "address_1": "326, Sinpyoungsukhwaro",
        "address_2": "Wonju-si,  Gangwon-do  26358",
        "country": "KR"
    },
    "A4DEC9": {
        "oui_hex": "A4-DE-C9",
        "organization": "QLove Mobile Intelligence Information Technology (W.H.) Co. Ltd.",
        "address_1": "Sun Jia Tuan Township, Huan Cui District, Weihai, P.R.China",
        "address_2": " Weihai  Shan Dong  264201",
        "country": "CN"
    },
    "CCE0C3": {
        "oui_hex": "CC-E0-C3",
        "organization": "EXTEN Technologies, Inc.",
        "address_1": "4201 W Parmer Lane Bldg A, Ste 200",
        "address_2": "Austin  TX  78727",
        "country": "US"
    },
    "646A74": {
        "oui_hex": "64-6A-74",
        "organization": "AUTH-SERVERS, LLC",
        "address_1": "43479 Stukely Dr",
        "address_2": "Sterling  VA  20166",
        "country": "US"
    },
    "4C8ECC": {
        "oui_hex": "4C-8E-CC",
        "organization": "SILKAN SA",
        "address_1": "Immeuble le Sirius",
        "address_2": "Meudon La Foret  Ile de France  92360",
        "country": "FR"
    },
    "E435C8": {
        "oui_hex": "E4-35-C8",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "0C54B9": {
        "oui_hex": "0C-54-B9",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "84100D": {
        "oui_hex": "84-10-0D",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "D00F6D": {
        "oui_hex": "D0-0F-6D",
        "organization": "T&W Electronics Company",
        "address_1": "89# Jiang Nan RD, Lu Du",
        "address_2": "Taicang  Jiangsu  21500",
        "country": "CN"
    },
    "908D78": {
        "oui_hex": "90-8D-78",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "7C7176": {
        "oui_hex": "7C-71-76",
        "organization": "Wuxi iData Technology Company Ltd.",
        "address_1": "Floor 11, Building B1, Wuxi(Binhu) National Sensing Information Center, No. 999 Gaolang East Road, Wuxi City, Jiangsu Province, P.R.C.",
        "address_2": "Wuxi  Jiangsu  214131",
        "country": "CN"
    },
    "7C0191": {
        "oui_hex": "7C-01-91",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "2C1BC8": {
        "oui_hex": "2C-1B-C8",
        "organization": "Hunan Topview Network System CO.,LTD",
        "address_1": "RM 3002,3009,3010 Yuelu High-Tech Zone, Hanpu Couty, Yuelu District",
        "address_2": "Changsha  Hunan  410208",
        "country": "CN"
    },
    "A8474A": {
        "oui_hex": "A8-47-4A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "C40049": {
        "oui_hex": "C4-00-49",
        "organization": "Kamama",
        "address_1": "100 Enterprise Way",
        "address_2": "Scotts Valley  CA  95066",
        "country": "US"
    },
    "80D605": {
        "oui_hex": "80-D6-05",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "98E848": {
        "oui_hex": "98-E8-48",
        "organization": "Axiim",
        "address_1": "12126 NE 106th Pl",
        "address_2": "Kirkland  WA  98033",
        "country": "US"
    },
    "4040A7": {
        "oui_hex": "40-40-A7",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "C04A09": {
        "oui_hex": "C0-4A-09",
        "organization": "Zhejiang Everbright Communication Equip. Co,. Ltd",
        "address_1": "291# Wei 19th Rd.",
        "address_2": "Wenzhou  Zhejiang  325600",
        "country": "CN"
    },
    "A01E0B": {
        "oui_hex": "A0-1E-0B",
        "organization": "MINIX Technology Limited",
        "address_1": "Unit 1501, Chevalier Commercial Center",
        "address_2": "Kowloon Bay  Kowloon  000000",
        "country": "HK"
    },
    "68E8EB": {
        "oui_hex": "68-E8-EB",
        "organization": "Linktel Technologies Co.,Ltd",
        "address_1": "No.20 University Science Park Road,",
        "address_2": "Wuhan  Hubei  430223",
        "country": "CN"
    },
    "A845CD": {
        "oui_hex": "A8-45-CD",
        "organization": "Siselectron Technology LTD.",
        "address_1": "5F., No.232, Sec. 2, Sioulang Rd., Yonghe Dist.,",
        "address_2": "New Taipei City  Taiwan  23453",
        "country": "TW"
    },
    "D0C193": {
        "oui_hex": "D0-C1-93",
        "organization": "SKYBELL, INC",
        "address_1": "1 JENNER, SUITE 100",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "AC6462": {
        "oui_hex": "AC-64-62",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C025A2": {
        "oui_hex": "C0-25-A2",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "2-3 Kandatsukasamachi",
        "address_2": "Chiyodaku  Tokyo  101-8532",
        "country": "JP"
    },
    "48137E": {
        "oui_hex": "48-13-7E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "30F772": {
        "oui_hex": "30-F7-72",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "DC3CF6": {
        "oui_hex": "DC-3C-F6",
        "organization": "Atomic Rules LLC",
        "address_1": "287 Chester Rd",
        "address_2": "Auburn  NH  03032",
        "country": "US"
    },
    "089B4B": {
        "oui_hex": "08-9B-4B",
        "organization": "iKuai Networks",
        "address_1": "So Boss Tech Center 2 # 716",
        "address_2": "Fengtai District  Beijing  100068",
        "country": "CN"
    },
    "4473D6": {
        "oui_hex": "44-73-D6",
        "organization": "Logitech",
        "address_1": "7700 Gateway Blvd",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "10CC1B": {
        "oui_hex": "10-CC-1B",
        "organization": "Liverock technologies,INC",
        "address_1": "Shinjuku 5-13-10,Joshu-Bldg. 4F",
        "address_2": "Tokyo  Shinjuku-ku  160-0022",
        "country": "JP"
    },
    "E80734": {
        "oui_hex": "E8-07-34",
        "organization": "Champion Optical Network Engineering, LLC",
        "address_1": "23645 Mercantile Rd.",
        "address_2": "Beachwood  OH  44122",
        "country": "US"
    },
    "A43831": {
        "oui_hex": "A4-38-31",
        "organization": "RF elements s.r.o.",
        "address_1": "Jasenovská 2528",
        "address_2": "Humenne  SK  06603",
        "country": "SK"
    },
    "380546": {
        "oui_hex": "38-05-46",
        "organization": "Foctek Photonics, Inc.",
        "address_1": "No. 8, the 7th Road Phase II of Minhou Tieling Industrial District",
        "address_2": "Fuzhou  Fujian  350100",
        "country": "CN"
    },
    "D48304": {
        "oui_hex": "D4-83-04",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "DC2B2A": {
        "oui_hex": "DC-2B-2A",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "9C8DD3": {
        "oui_hex": "9C-8D-D3",
        "organization": "Leonton Technologies",
        "address_1": "3F, No.501-16, Zhongzheng Rd., Xindian Dist.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "E41A2C": {
        "oui_hex": "E4-1A-2C",
        "organization": "ZPE Systems, Inc.",
        "address_1": "39420 Liberty Street,  #253",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "E8BDD1": {
        "oui_hex": "E8-BD-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "F41535": {
        "oui_hex": "F4-15-35",
        "organization": "SPON Communication Technology Co.,Ltd",
        "address_1": "B Building, Lugu International Industrial Zone, NO.229, Tongzipo Road, Changsha, China",
        "address_2": "changsha  hunan  410000",
        "country": "CN"
    },
    "380AAB": {
        "oui_hex": "38-0A-AB",
        "organization": "Formlabs",
        "address_1": "35 Medford St",
        "address_2": "Somerville  MA  02143",
        "country": "US"
    },
    "382DE8": {
        "oui_hex": "38-2D-E8",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C08997": {
        "oui_hex": "C0-89-97",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "A815D6": {
        "oui_hex": "A8-15-D6",
        "organization": "Shenzhen Meione Technology CO., LTD",
        "address_1": "12th FloorFutian Sports Park Cultural Industries Headquarters Building No. 3030 Fuqiang Road, Futian District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "C07CD1": {
        "oui_hex": "C0-7C-D1",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "90D8F3": {
        "oui_hex": "90-D8-F3",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "D445E8": {
        "oui_hex": "D4-45-E8",
        "organization": "Jiangxi Hongpai Technology Co., Ltd.",
        "address_1": "5th Floor,C Region, Zhejiang University Science Park,No. 698,",
        "address_2": "Nanchang  Jiangxi  330096",
        "country": "CN"
    },
    "342606": {
        "oui_hex": "34-26-06",
        "organization": "CarePredict, Inc.",
        "address_1": "PO Box 551686",
        "address_2": "Fort Lauderdale  Florida  33355",
        "country": "US"
    },
    "38B725": {
        "oui_hex": "38-B7-25",
        "organization": "Wistron Infocomm (Zhongshan) Corporation",
        "address_1": "No.38,East Keji Road,Zhongshan Torch Development Zone,Zhongshan City,Guangdong,China",
        "address_2": "Zhongshan  Guangdong  528437",
        "country": "CN"
    },
    "ACEC80": {
        "oui_hex": "AC-EC-80",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "507B9D": {
        "oui_hex": "50-7B-9D",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "6C7220": {
        "oui_hex": "6C-72-20",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "30A243": {
        "oui_hex": "30-A2-43",
        "organization": "Shenzhen Prifox Innovation Technology Co., Ltd.",
        "address_1": "Room B905, Bldg 4, Software Industry Park,",
        "address_2": "Shenzhen  Guangdong Province  518057",
        "country": ""
    },
    "380195": {
        "oui_hex": "38-01-95",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "246E96": {
        "oui_hex": "24-6E-96",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "44975A": {
        "oui_hex": "44-97-5A",
        "organization": "SHENZHEN FAST TECHNOLOGIES CO.,LTD",
        "address_1": "Room 202,Building No.5,Section 30,No.2 of Kefa Road,Nanshan District,Shenzhen,P.R.China",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "5045F7": {
        "oui_hex": "50-45-F7",
        "organization": "Liuhe Intelligence Technology Ltd.",
        "address_1": "7th Floor,Information Building,",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "AC676F": {
        "oui_hex": "AC-67-6F",
        "organization": "Electrocompaniet A.S.",
        "address_1": "Breivikveien 7",
        "address_2": "Tau  Rogaland  4120",
        "country": "NO"
    },
    "640DE6": {
        "oui_hex": "64-0D-E6",
        "organization": "Petra Systems",
        "address_1": "One Cragwood Road",
        "address_2": "South Plainfield  NJ  07080",
        "country": "US"
    },
    "E0553D": {
        "oui_hex": "E0-55-3D",
        "organization": "Cisco Meraki",
        "address_1": "500 Terry A. Francois Blvd",
        "address_2": "San Francisco  California  94158",
        "country": "US"
    },
    "FC335F": {
        "oui_hex": "FC-33-5F",
        "organization": "Polyera",
        "address_1": "8045 Lamon Avenue",
        "address_2": "Skokie  IL  60077",
        "country": "US"
    },
    "84D4C8": {
        "oui_hex": "84-D4-C8",
        "organization": "Widex A/S",
        "address_1": "Nymoellevej 6",
        "address_2": "Lynge  Alleroed  DK3540",
        "country": "DK"
    },
    "EC21E5": {
        "oui_hex": "EC-21-E5",
        "organization": "Toshiba",
        "address_1": "2-9,Suehiro-Cho",
        "address_2": "Ome  Tokyo  1988710",
        "country": "JP"
    },
    "04C23E": {
        "oui_hex": "04-C2-3E",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "E01AEA": {
        "oui_hex": "E0-1A-EA",
        "organization": "Allied Telesis, Inc.",
        "address_1": "3041 Orchard Parkway",
        "address_2": "San Jose  CALIFORNIA  95134",
        "country": "US"
    },
    "28B9D9": {
        "oui_hex": "28-B9-D9",
        "organization": "Radisys Corporation",
        "address_1": "5435 NE Dawson Creek Drive",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "F4C613": {
        "oui_hex": "F4-C6-13",
        "organization": "Alcatel-Lucent Shanghai Bell Co., Ltd",
        "address_1": "No. 389, Ningqiao Road, Pudong Jinqiao",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "445F8C": {
        "oui_hex": "44-5F-8C",
        "organization": "Intercel Group Limited",
        "address_1": "Unit 6, 17/F, Vanta industrial Centre,",
        "address_2": "New Territories, Hong Kong",
        "country": "CN"
    },
    "B88981": {
        "oui_hex": "B8-89-81",
        "organization": "Chengdu InnoThings Technology Co., Ltd.",
        "address_1": "West Port Technology Enterprise Incubator Park",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "F02624": {
        "oui_hex": "F0-26-24",
        "organization": "WAFA TECHNOLOGIES CO., LTD.",
        "address_1": "Room302, Longtaili Building",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F8F464": {
        "oui_hex": "F8-F4-64",
        "organization": "Rawe Electonic GmbH",
        "address_1": "Bregenzer Str. 67-69",
        "address_2": "Weiler im Allgäu  Bavaria  88171",
        "country": "DE"
    },
    "5C5188": {
        "oui_hex": "5C-51-88",
        "organization": "Motorola Mobility LLC, a Lenovo Company",
        "address_1": "222 West Merchandise Mart Plaza",
        "address_2": "Chicago  IL  60654",
        "country": "US"
    },
    "EC0133": {
        "oui_hex": "EC-01-33",
        "organization": "TRINUS SYSTEMS INC.",
        "address_1": "UNITECH VENTURE TOWN SUITE 801",
        "address_2": "GOYANG-SI  GYEONGGI-DO  410-722",
        "country": "KR"
    },
    "2CC548": {
        "oui_hex": "2C-C5-48",
        "organization": "IAdea Corporation",
        "address_1": "3F, No.33, Lane 77, Xing-ai Road",
        "address_2": "Taipei  Taiwan  114",
        "country": "TW"
    },
    "14DDA9": {
        "oui_hex": "14-DD-A9",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "184F32": {
        "oui_hex": "18-4F-32",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "DCA3AC": {
        "oui_hex": "DC-A3-AC",
        "organization": "RBcloudtech",
        "address_1": "5th Floor, Jiangnan Street NO.3900, Binjiang District, Hangzhou City.",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "0CE725": {
        "oui_hex": "0C-E7-25",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "58F102": {
        "oui_hex": "58-F1-02",
        "organization": "BLU Products Inc.",
        "address_1": "Tower 4, Excellence Century Center",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "B4AE2B": {
        "oui_hex": "B4-AE-2B",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "949F3E": {
        "oui_hex": "94-9F-3E",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "3089D3": {
        "oui_hex": "30-89-D3",
        "organization": "HONGKONG UCLOUDLINK NETWORK TECHNOLOGY LIMITED",
        "address_1": "FLAT A-8 9/F DELYA INDUSTRIAL CENTRE 7 SHEK PAI TAU ROAD",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "5CB395": {
        "oui_hex": "5C-B3-95",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "906CAC": {
        "oui_hex": "90-6C-AC",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale  California  94086",
        "country": "US"
    },
    "3CDA2A": {
        "oui_hex": "3C-DA-2A",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "842E27": {
        "oui_hex": "84-2E-27",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1CADD1": {
        "oui_hex": "1C-AD-D1",
        "organization": "Bosung Electronics Co., Ltd.",
        "address_1": "74-12, Saemaeul-ro.",
        "address_2": "Gumi-si  Gyeongsangbuk-do  730-930",
        "country": "KR"
    },
    "082CB0": {
        "oui_hex": "08-2C-B0",
        "organization": "Network Instruments",
        "address_1": "10701 Red Circle Dr",
        "address_2": "Minnetonka  Minnesota  55343",
        "country": "US"
    },
    "A013CB": {
        "oui_hex": "A0-13-CB",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "D00492": {
        "oui_hex": "D0-04-92",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "1432D1": {
        "oui_hex": "14-32-D1",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1816C9": {
        "oui_hex": "18-16-C9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "00FC8D": {
        "oui_hex": "00-FC-8D",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "84DF19": {
        "oui_hex": "84-DF-19",
        "organization": "Chuango Security Technology Corporation",
        "address_1": "6-17, Overseas Students Pioneer Park,",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "DC15DB": {
        "oui_hex": "DC-15-DB",
        "organization": "Ge Ruili Intelligent Technology ( Beijing ) Co., Ltd.",
        "address_1": "Room 821, block E, No.6 Taiping Street, Xicheng District",
        "address_2": "Beijing    100005",
        "country": "CN"
    },
    "E0DB10": {
        "oui_hex": "E0-DB-10",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "546172": {
        "oui_hex": "54-61-72",
        "organization": "ZODIAC AEROSPACE SAS",
        "address_1": "61 rue Pierre Curie",
        "address_2": "PLAISIR    78370",
        "country": "FR"
    },
    "EC60E0": {
        "oui_hex": "EC-60-E0",
        "organization": "AVI-ON LABS",
        "address_1": "2585 LARKSPUR DR",
        "address_2": "PARK CITY  UT  84060",
        "country": "US"
    },
    "B46D35": {
        "oui_hex": "B4-6D-35",
        "organization": "Dalian Seasky Automation Co;Ltd",
        "address_1": "Room 408, DUT Science & Technology Park Building B, No.80 Software Park Road,          High-Tech Industrial Zone, Dalian, Liaoning, China",
        "address_2": "Dalian  Liao Ning  116023",
        "country": "CN"
    },
    "3CA31A": {
        "oui_hex": "3C-A3-1A",
        "organization": "Oilfind International LLC",
        "address_1": "12651 Briar Forest Dr, Suite 151",
        "address_2": "Houston  Texas  77077",
        "country": "US"
    },
    "30F335": {
        "oui_hex": "30-F3-35",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "E8F2E3": {
        "oui_hex": "E8-F2-E3",
        "organization": "Starcor Beijing Co.,Limited",
        "address_1": "NO.210 Block B, Building 2",
        "address_2": "Beijing  Berijing  100089",
        "country": "CN"
    },
    "6459F8": {
        "oui_hex": "64-59-F8",
        "organization": "Vodafone Omnitel B.V.",
        "address_1": "VIA JERVIS, 13 10015 IVREA (TO)",
        "address_2": "",
        "country": "IT"
    },
    "6C4418": {
        "oui_hex": "6C-44-18",
        "organization": "Zappware",
        "address_1": "Ilgatlaan 19",
        "address_2": "Hasselt  Limburg  3500",
        "country": "BE"
    },
    "A8D409": {
        "oui_hex": "A8-D4-09",
        "organization": "USA 111 Inc",
        "address_1": "5885 Green Pointe Dr. Suite B Groveport, OH 43125",
        "address_2": "Groveport  Ohio  43125",
        "country": "US"
    },
    "6C4598": {
        "oui_hex": "6C-45-98",
        "organization": "Antex Electronic Corp.",
        "address_1": "170 He Ping St.,",
        "address_2": "Tainan City    73443",
        "country": "TW"
    },
    "68A378": {
        "oui_hex": "68-A3-78",
        "organization": "FREEBOX SAS",
        "address_1": "16 rue de la Ville l'Eveque",
        "address_2": "PARIS  IdF  75008",
        "country": "FR"
    },
    "340A22": {
        "oui_hex": "34-0A-22",
        "organization": "TOP-ACCESS ELECTRONICS CO LTD",
        "address_1": "No. 2 Building",
        "address_2": "MingZhi Street  BaoAn District,ShenzheN  518131",
        "country": "CN"
    },
    "E866C4": {
        "oui_hex": "E8-66-C4",
        "organization": "Diamanti",
        "address_1": "111 N. Market Street",
        "address_2": "San Jose  CA  95113",
        "country": "US"
    },
    "D4D7A9": {
        "oui_hex": "D4-D7-A9",
        "organization": "Shanghai Kaixiang Info Tech LTD",
        "address_1": "A401, NO.509 Caobao Road, Shanghai, PRC",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "343D98": {
        "oui_hex": "34-3D-98",
        "organization": "JinQianMao Technology Co.,Ltd.",
        "address_1": "58#,Jiangbin Road,Taijiang District",
        "address_2": "Fuzhou  Fujian  350009",
        "country": "CN"
    },
    "F44713": {
        "oui_hex": "F4-47-13",
        "organization": "Leading Public Performance Co., Ltd.",
        "address_1": "137/77-78 Moo 1 Nanthanagarden Soi 12 Pathum-Rangsit Road Banklang Muang Pathumthani 12000 Thailand",
        "address_2": "Pathumthani  Pathumthani  12000",
        "country": "TH"
    },
    "5CA178": {
        "oui_hex": "5C-A1-78",
        "organization": "TableTop Media (dba Ziosk)",
        "address_1": "12404 Park Central Drive",
        "address_2": "Dallas  TX  75251",
        "country": "US"
    },
    "9CBEE0": {
        "oui_hex": "9C-BE-E0",
        "organization": "Biosoundlab Co., Ltd.",
        "address_1": "(Sangdaewon-dong, Sunil Technopia 907-908ho)",
        "address_2": "Jungwon-gu  Seongnam-si Gyeonggi-do,  462726",
        "country": "KR"
    },
    "0C413E": {
        "oui_hex": "0C-41-3E",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "D06F4A": {
        "oui_hex": "D0-6F-4A",
        "organization": "TOPWELL INTERNATIONAL HOLDINGS LIMITED",
        "address_1": "Unit 2506, 25/F, Prosperity Place,",
        "address_2": "Hong Kong  N/A  N/A",
        "country": "CN"
    },
    "0492EE": {
        "oui_hex": "04-92-EE",
        "organization": "iway AG",
        "address_1": "Badenerstrasse 569",
        "address_2": "Zurich  ZH  8048",
        "country": "CH"
    },
    "807459": {
        "oui_hex": "80-74-59",
        "organization": "K's Co.,Ltd.",
        "address_1": "2864-16 Ryomitsuyanagi",
        "address_2": "Yonago  Tottori  683-0853",
        "country": "JP"
    },
    "601970": {
        "oui_hex": "60-19-70",
        "organization": "HUIZHOU QIAOXING ELECTRONICS TECHNOLOGY CO., LTD.",
        "address_1": "Room -611, TianAn High-Tech Plaza II , Futian District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "A408EA": {
        "oui_hex": "A4-08-EA",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "B87879": {
        "oui_hex": "B8-78-79",
        "organization": "Roche Diagnostics GmbH",
        "address_1": "Sandhofer Strasse 116",
        "address_2": "Mannheim  Baden-Wuerttemberg  68305",
        "country": "DE"
    },
    "D083D4": {
        "oui_hex": "D0-83-D4",
        "organization": "Xtel Wireless ApS",
        "address_1": "Alfred Nobels vej 21E",
        "address_2": "Aalborg Oest  Nordjylland  9220",
        "country": "DK"
    },
    "08D34B": {
        "oui_hex": "08-D3-4B",
        "organization": "Techman Electronics (Changshu) Co., Ltd.",
        "address_1": "No.66, Dalian Road, High-Tech Industrial Park",
        "address_2": "Changshu  Jiangsu Province  215500",
        "country": "CN"
    },
    "78A351": {
        "oui_hex": "78-A3-51",
        "organization": "SHENZHEN ZHIBOTONG ELECTRONICS CO.,LTD",
        "address_1": "2F,Bldg. A,Kangmai Industrial Park,Renmin Rd",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "E4695A": {
        "oui_hex": "E4-69-5A",
        "organization": "Dictum Health, Inc.",
        "address_1": "255 3rd Street, Suite 102",
        "address_2": "Oakland  CA  94607",
        "country": "US"
    },
    "7C7A53": {
        "oui_hex": "7C-7A-53",
        "organization": "Phytrex Technology Corp.",
        "address_1": "8F-16, No.81, Shuili Rd.,",
        "address_2": "Hsinchu  Taiwan  30059",
        "country": "TW"
    },
    "107873": {
        "oui_hex": "10-78-73",
        "organization": "Shenzhen Jinkeyi Communication Co., Ltd.",
        "address_1": "No. 10 Shun King Road, Zhen Ping Xi Cun,",
        "address_2": "Shenzhen  Guangdong  518117",
        "country": "CN"
    },
    "48EE0C": {
        "oui_hex": "48-EE-0C",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "EC3C88": {
        "oui_hex": "EC-3C-88",
        "organization": "MCNEX Co.,Ltd.",
        "address_1": "Hanshin IT Tower2 11F, Digital lo 9 gil",
        "address_2": "Geumcheon-Gu  Seoul  153-712",
        "country": "KR"
    },
    "70AD54": {
        "oui_hex": "70-AD-54",
        "organization": "Malvern Instruments Ltd",
        "address_1": "Grovewood Rd",
        "address_2": "Malvern  Worcestershire  WR14 1XZ",
        "country": "GB"
    },
    "9000DB": {
        "oui_hex": "90-00-DB",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B4EF39": {
        "oui_hex": "B4-EF-39",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "F02A23": {
        "oui_hex": "F0-2A-23",
        "organization": "Creative Next Design",
        "address_1": "6-6-15, Kaminopporo 3-jo,",
        "address_2": "Sapporo-shi  Hokkaido  004-0033",
        "country": "JP"
    },
    "584704": {
        "oui_hex": "58-47-04",
        "organization": " Shenzhen Webridge Technology Co.,Ltd",
        "address_1": "B2-22/F Chinese Technology Development Institute, High South Road, Nanshan District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "74A063": {
        "oui_hex": "74-A0-63",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "ECE2FD": {
        "oui_hex": "EC-E2-FD",
        "organization": "SKG Electric Group(Thailand) Co., Ltd.",
        "address_1": "3F,The Second Building,Sanhe village , Longhua Rd, Baoan Dist., Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518301",
        "country": "CN"
    },
    "148F21": {
        "oui_hex": "14-8F-21",
        "organization": "Garmin International",
        "address_1": "1200 E. 151st St",
        "address_2": "Olathe  KS  66062",
        "country": "US"
    },
    "9C685B": {
        "oui_hex": "9C-68-5B",
        "organization": "Octonion SA",
        "address_1": "EPFL Innovation Park, Bâtiment C",
        "address_2": "Lausanne  Vaud  1015",
        "country": "CH"
    },
    "7C534A": {
        "oui_hex": "7C-53-4A",
        "organization": "Metamako",
        "address_1": "Suite 207",
        "address_2": "Sydney  Other  2000",
        "country": "AU"
    },
    "BC6E64": {
        "oui_hex": "BC-6E-64",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "BCB308": {
        "oui_hex": "BC-B3-08",
        "organization": "HONGKONG RAGENTEK COMMUNICATION TECHNOLOGY CO.,LIMITED",
        "address_1": "Building D10-D11",
        "address_2": "PuDong District  Shanghai  201315",
        "country": "CN"
    },
    "6C2E72": {
        "oui_hex": "6C-2E-72",
        "organization": "B&B EXPORTING LIMITED",
        "address_1": "Bldg.#D,Xinhe Industrial Park",
        "address_2": "Guangzhou  Guangdong  510880",
        "country": "CN"
    },
    "5CCCFF": {
        "oui_hex": "5C-CC-FF",
        "organization": "Techroutes Network Pvt Ltd",
        "address_1": "WW1-SF, Malibu Towne",
        "address_2": "Gurgaon  Haryana  122002",
        "country": "IN"
    },
    "90C35F": {
        "oui_hex": "90-C3-5F",
        "organization": "Nanjing Jiahao Technology Co., Ltd.",
        "address_1": "Moling Industrial Park, Development Zone, Jiangning, Nanjing",
        "address_2": "Nanjing  Jiangsu  211111",
        "country": "CN"
    },
    "C808E9": {
        "oui_hex": "C8-08-E9",
        "organization": "LG Electronics",
        "address_1": "222 LG-ro, JINWI-MYEON",
        "address_2": "Pyeongtaek-si  Gyeonggi-do  451-713",
        "country": "KR"
    },
    "183A2D": {
        "oui_hex": "18-3A-2D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "EC74BA": {
        "oui_hex": "EC-74-BA",
        "organization": "Hirschmann Automation and Control GmbH",
        "address_1": "Stuttgarter Strasse 45-51",
        "address_2": "Neckartenzlingen  Baden-Württemberg  72654",
        "country": "DE"
    },
    "FC3288": {
        "oui_hex": "FC-32-88",
        "organization": "CELOT Wireless Co., Ltd",
        "address_1": "4Fl.,NongHyup Bldg.,#1588-10 Gwanyang-Dong",
        "address_2": "Anyang City,  Gyeonggi-Do  431-727",
        "country": "KR"
    },
    "D87495": {
        "oui_hex": "D8-74-95",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "5C3B35": {
        "oui_hex": "5C-3B-35",
        "organization": "Gehirn Inc.",
        "address_1": "1-3-6 Kudan-kita",
        "address_2": "Chiyoda  Tokyo  102-0073",
        "country": "JP"
    },
    "E4FED9": {
        "oui_hex": "E4-FE-D9",
        "organization": "EDMI Europe Ltd",
        "address_1": "The Grainger Suite, Dobson House, Regent  Centre",
        "address_2": "Newcastle upon Tyne  Newcastle upon Tyne  NE3 3PF",
        "country": "GB"
    },
    "5CF7C3": {
        "oui_hex": "5C-F7-C3",
        "organization": "SYNTECH (HK) TECHNOLOGY LIMITED",
        "address_1": "Unit No. 1, 12/F., Perfect Industrial Building ,",
        "address_2": "Kowloon, Hong Kong    999077",
        "country": "HK"
    },
    "9CE230": {
        "oui_hex": "9C-E2-30",
        "organization": "JULONG CO,.LTD.",
        "address_1": "308，QianShanZhong Road,TieDong District,AnShan",
        "address_2": "AnShan City  LiaoNing Province  114051",
        "country": "CN"
    },
    "5C41E7": {
        "oui_hex": "5C-41-E7",
        "organization": "Wiatec International Ltd.",
        "address_1": "Unit 601-605,TaoJinDi Electronic Commercial",
        "address_2": "Shenzhen  GuangDong  518131",
        "country": "CN"
    },
    "344CA4": {
        "oui_hex": "34-4C-A4",
        "organization": "amazipoint technology Ltd.",
        "address_1": "1F,No. 14, Aly. 32, Ln. 133, Zhongyang Rd.,",
        "address_2": " New Taipei City,    231",
        "country": "TW"
    },
    "A8F038": {
        "oui_hex": "A8-F0-38",
        "organization": "SHEN ZHEN SHI JIN HUA TAI ELECTRONICS CO.,LTD",
        "address_1": "Room A,Forth Floor,Building B,Hengmingzhu Industrial Park,Xixiang Forist and Fruit Bureau,Qianjin Road, Baoan District,Shenzhen city,Guangdong provice",
        "address_2": "    518126",
        "country": "CN"
    },
    "ACC73F": {
        "oui_hex": "AC-C7-3F",
        "organization": "VITSMO CO., LTD.",
        "address_1": "RM1418-1419, HansinIntervalley 24 Bldg.",
        "address_2": "  SEOUL  135-918",
        "country": "KR"
    },
    "44356F": {
        "oui_hex": "44-35-6F",
        "organization": "Neterix",
        "address_1": "The Printworks",
        "address_2": "Chester  Cheshire  CH1 4RN",
        "country": "GB"
    },
    "74E277": {
        "oui_hex": "74-E2-77",
        "organization": "Vizmonet Pte Ltd",
        "address_1": "32,Canberra drive,#05-28",
        "address_2": "    76431",
        "country": "SG"
    },
    "14893E": {
        "oui_hex": "14-89-3E",
        "organization": "VIXTEL TECHNOLOGIES LIMTED",
        "address_1": "ROOM 1409, 14/F, BLOCK B, KAILEY CENTER",
        "address_2": "CHAI WAN",
        "country": "HK"
    },
    "BC54F9": {
        "oui_hex": "BC-54-F9",
        "organization": "Drogoo Technology Co., Ltd.",
        "address_1": "Shenzhen Dayun software town 17 2 floor",
        "address_2": "Shenzhen  Guangdong  518172",
        "country": "CN"
    },
    "78FC14": {
        "oui_hex": "78-FC-14",
        "organization": "Family Zone Cyber Safety Ltd",
        "address_1": "175 Heytesbury Rd",
        "address_2": "Subiaco  WA  6008",
        "country": "AU"
    },
    "3809A4": {
        "oui_hex": "38-09-A4",
        "organization": "Firefly Integrations",
        "address_1": "1013 Elroy Dr",
        "address_2": "Middlebury  IN  46540",
        "country": "US"
    },
    "BCE767": {
        "oui_hex": "BC-E7-67",
        "organization": "Quanzhou  TDX Electronics Co., Ltd",
        "address_1": "Hi-tech Park economic and tech development zone",
        "address_2": "Quanzhou  Fujian province  362005",
        "country": "CN"
    },
    "FCAFAC": {
        "oui_hex": "FC-AF-AC",
        "organization": "Socionext Inc.",
        "address_1": "19 Nishikujo-Kasuga-cho",
        "address_2": "Minaki-ku  Kyoto  601-8413",
        "country": "JP"
    },
    "BC4DFB": {
        "oui_hex": "BC-4D-FB",
        "organization": "Hitron Technologies. Inc",
        "address_1": "No. 1-8, Lising 1st Rd. Hsinchu Science Park, Hsinchu, 300, Taiwan, R.O.C",
        "address_2": "Hsin-chu  Taiwan  300",
        "country": "TW"
    },
    "2C337A": {
        "oui_hex": "2C-33-7A",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "84DDB7": {
        "oui_hex": "84-DD-B7",
        "organization": "Cilag GmbH International",
        "address_1": "Gubelstrasse 34",
        "address_2": "Zug  _  CH-6300",
        "country": "CH"
    },
    "08EFAB": {
        "oui_hex": "08-EF-AB",
        "organization": "SAYME WIRELESS SENSOR NETWORK",
        "address_1": "Calle Albert Einstein 18, 4a",
        "address_2": "Santander  Cantabria  39011",
        "country": "ES"
    },
    "7076FF": {
        "oui_hex": "70-76-FF",
        "organization": "KERLINK",
        "address_1": "1 rue Jacqueline AURIOL",
        "address_2": "THORIGNE FOUILLARD    35235",
        "country": "FR"
    },
    "1436C6": {
        "oui_hex": "14-36-C6",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information & Optoelectronics Park,",
        "address_2": "Xiamen  Fujian  361006",
        "country": ""
    },
    "68F728": {
        "oui_hex": "68-F7-28",
        "organization": "LCFC(HeFei) Electronics Technology co., ltd",
        "address_1": "YunGu Road 3188-1",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "382C4A": {
        "oui_hex": "38-2C-4A",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "307350": {
        "oui_hex": "30-73-50",
        "organization": "Inpeco SA",
        "address_1": "Via San Gottardo 10",
        "address_2": "Lugano  Ticino  6900",
        "country": "CH"
    },
    "DCEC06": {
        "oui_hex": "DC-EC-06",
        "organization": "Heimi Network Technology Co., Ltd.",
        "address_1": "Room 12B12, Block A2, Long-Term World Building,",
        "address_2": "Beijing  Beijing  100080",
        "country": "CN"
    },
    "CCBDD3": {
        "oui_hex": "CC-BD-D3",
        "organization": "Ultimaker B.V.",
        "address_1": "Burgemeester Rozeveld van de Venlaan 11",
        "address_2": "Geldermalsen  Gelderland  4191 PL",
        "country": "NL"
    },
    "8CE78C": {
        "oui_hex": "8C-E7-8C",
        "organization": "DK Networks",
        "address_1": "20F-3, No.689, Zhong-Zheng Road, Zhong-He Dist.",
        "address_2": "New Taipei City  Taiwan  235",
        "country": "TW"
    },
    "545146": {
        "oui_hex": "54-51-46",
        "organization": "AMG Systems Ltd.",
        "address_1": "3 The Omega Centre",
        "address_2": "Biggleswade  Bedfordshire  SG18 8QB",
        "country": "GB"
    },
    "8463D6": {
        "oui_hex": "84-63-D6",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "EC13B2": {
        "oui_hex": "EC-13-B2",
        "organization": "Netonix",
        "address_1": "6 East Main St",
        "address_2": "Leola  PA  17540",
        "country": "US"
    },
    "104E07": {
        "oui_hex": "10-4E-07",
        "organization": "Shanghai Genvision Industries Co.,Ltd",
        "address_1": "2/F Building E,NO.55,Luo Jin Road,MinHang District,Shanghai",
        "address_2": "Shanghai  Shanghai  200237",
        "country": "CN"
    },
    "049B9C": {
        "oui_hex": "04-9B-9C",
        "organization": "Eadingcore  Intelligent Technology Co., Ltd.",
        "address_1": "No. 169 Lijia city C District comprehensive 3 layer C3-10 mall，Five-One road",
        "address_2": "Fuzhou  Fujian  350000",
        "country": "CN"
    },
    "842690": {
        "oui_hex": "84-26-90",
        "organization": "BEIJING THOUGHT SCIENCE CO.,LTD.",
        "address_1": "1-1102,Intermational Business Park,No.1 ShangDi Xinxi Rd,Haidian District,Beijing",
        "address_2": "beijing  beijing  100085",
        "country": "CN"
    },
    "801967": {
        "oui_hex": "80-19-67",
        "organization": "Shanghai Reallytek Information Technology  Co.,Ltd",
        "address_1": "906 Room,No.1 Building,No.3000 Longdong Avenue",
        "address_2": "  Shanghai  201203",
        "country": "CN"
    },
    "2CF7F1": {
        "oui_hex": "2C-F7-F1",
        "organization": "Seeed Technology Inc.",
        "address_1": " 5th Floor, 8th Building, Shiling industrial Park, XiLi Town, NanShan dist. Shenzhen",
        "address_2": "ShenZhen  GuangDong  518055",
        "country": "CN"
    },
    "3C1E13": {
        "oui_hex": "3C-1E-13",
        "organization": "HANGZHOU SUNRISE TECHNOLOGY CO., LTD",
        "address_1": "No.9, LongTan Road, CangQian Town, YuHang District, Hangzhou, China",
        "address_2": "HangZhou  ZheJiang  311121",
        "country": "CN"
    },
    "08115E": {
        "oui_hex": "08-11-5E",
        "organization": "Bitel Co., Ltd.",
        "address_1": "9F Yohyun B/D, 242-29, Nonhyun-dong",
        "address_2": "Seoul  Gangnam-gu  135830",
        "country": "KR"
    },
    "0881BC": {
        "oui_hex": "08-81-BC",
        "organization": "HongKong Ipro Technology Co., Limited",
        "address_1": "Flat/Rm A3 9/F Silvercorp Int Tower",
        "address_2": "  HONGKONG  999077",
        "country": "HK"
    },
    "C09879": {
        "oui_hex": "C0-98-79",
        "organization": "Acer Inc.",
        "address_1": "8F, 88, Sec.1, Xintai 5th Rd.",
        "address_2": "New Taipei City  N/A  221",
        "country": "TW"
    },
    "B84FD5": {
        "oui_hex": "B8-4F-D5",
        "organization": "Microsoft Corporation",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "FI"
    },
    "D84A87": {
        "oui_hex": "D8-4A-87",
        "organization": "OI ELECTRIC CO.,LTD",
        "address_1": "7-3-16 KIKUNA",
        "address_2": "YOKOHAMA  KANAGAWA-KEN  222-0011",
        "country": "JP"
    },
    "F03D29": {
        "oui_hex": "F0-3D-29",
        "organization": "Actility",
        "address_1": "110 rue des Poissonniers",
        "address_2": "Paris  Paris  75018",
        "country": "FR"
    },
    "88708C": {
        "oui_hex": "88-70-8C",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information & Optoelectronics Park,",
        "address_2": "Xiamen  Fujian  361006",
        "country": ""
    },
    "5014B5": {
        "oui_hex": "50-14-B5",
        "organization": "Richfit Information Technology Co., Ltd",
        "address_1": "Room 1501, Gehua Tower, Suite N0.1, Qinglong lane, Dongcheng District",
        "address_2": "Beijing  Beijing  100007",
        "country": "CN"
    },
    "CC3F1D": {
        "oui_hex": "CC-3F-1D",
        "organization": "Intesis Software SL",
        "address_1": "Mila i Fontanals 1bis 1",
        "address_2": "Igualada  Barcelona  08700",
        "country": "ES"
    },
    "DCDA4F": {
        "oui_hex": "DC-DA-4F",
        "organization": "GETCK TECHNOLOGY,  INC",
        "address_1": "Room 508, NO .48 ZhengYi road",
        "address_2": "  SHANGHAI  200082",
        "country": "CN"
    },
    "101218": {
        "oui_hex": "10-12-18",
        "organization": "Korins Inc.",
        "address_1": "Rm. 608, Suntechcity Bldg.",
        "address_2": "Seongnam  Gyeonggi  462-725",
        "country": "KR"
    },
    "3428F0": {
        "oui_hex": "34-28-F0",
        "organization": "ATN International Limited",
        "address_1": "4210, Office Tower, Convention Plaza",
        "address_2": "Hong Kong  Hong Kong  00000",
        "country": "HK"
    },
    "CC10A3": {
        "oui_hex": "CC-10-A3",
        "organization": "Beijing Nan Bao Technology Co., Ltd.",
        "address_1": "Room 8476，Floor 8,Building 3",
        "address_2": "Shijingshan District  Beijing  100041",
        "country": "CN"
    },
    "5CAAFD": {
        "oui_hex": "5C-AA-FD",
        "organization": "Sonos, Inc.",
        "address_1": "614 Chapala St",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "14EDE4": {
        "oui_hex": "14-ED-E4",
        "organization": "Kaiam Corporation",
        "address_1": "39677 Eureka Drive",
        "address_2": "Newark  California  94560",
        "country": "US"
    },
    "D01242": {
        "oui_hex": "D0-12-42",
        "organization": "BIOS Corporation",
        "address_1": "2-43-15 Tomigaya",
        "address_2": "Shibuya-ku  TOKYO  151-0063",
        "country": "JP"
    },
    "603696": {
        "oui_hex": "60-36-96",
        "organization": "The Sapling Company",
        "address_1": "1633 Republic Rd",
        "address_2": "Huntingdon Valley  PA  19006",
        "country": "US"
    },
    "54FFCF": {
        "oui_hex": "54-FF-CF",
        "organization": "Mopria Alliance",
        "address_1": "2400 Camino Ramon, Ste #375",
        "address_2": "San Ramon  CA  94583",
        "country": "US"
    },
    "F4F26D": {
        "oui_hex": "F4-F2-6D",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "404EEB": {
        "oui_hex": "40-4E-EB",
        "organization": "Higher Way Electronic Co., Ltd.",
        "address_1": "No.15 Jingke E. Rd., Nantun District",
        "address_2": "  Taichung  408",
        "country": "TW"
    },
    "C456FE": {
        "oui_hex": "C4-56-FE",
        "organization": "Lava International Ltd.",
        "address_1": "Room 705, Block A, HengYue Building",
        "address_2": "  Shanghai  518054",
        "country": "CN"
    },
    "ACB74F": {
        "oui_hex": "AC-B7-4F",
        "organization": "METEL s.r.o.",
        "address_1": "Zizkuv Kopec 617",
        "address_2": "Ceska Skalice  NA  55203",
        "country": "CZ"
    },
    "C0EEFB": {
        "oui_hex": "C0-EE-FB",
        "organization": "OnePlus Tech (Shenzhen) Ltd",
        "address_1": "18F Tairan Building C, Tairan 8th Road  Chegongmiao, Futian",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "304225": {
        "oui_hex": "30-42-25",
        "organization": "BURG-WÄCHTER KG",
        "address_1": "Altenhofer Weg 15",
        "address_2": "Wetter  NRW  58300",
        "country": "DE"
    },
    "FCDBB3": {
        "oui_hex": "FC-DB-B3",
        "organization": "Murata Manufacturing Co., Ltd.",
        "address_1": "1-10-1, Higashikotari",
        "address_2": "Nagaokakyo-shi  Kyoto  617-8555",
        "country": "JP"
    },
    "CCF538": {
        "oui_hex": "CC-F5-38",
        "organization": "3isysnetworks",
        "address_1": "11F-2 No1247 , Jung Jeng RD ,",
        "address_2": "Taipei  Taiwan  0000",
        "country": "TW"
    },
    "B8BD79": {
        "oui_hex": "B8-BD-79",
        "organization": "TrendPoint Systems",
        "address_1": "1595 East 6th Street",
        "address_2": "Corona  CA  92879",
        "country": "US"
    },
    "74F413": {
        "oui_hex": "74-F4-13",
        "organization": "Maxwell Forest",
        "address_1": "Level 2, 51 Murray Street",
        "address_2": "Pyrmont  NSW  2009",
        "country": "AU"
    },
    "A00627": {
        "oui_hex": "A0-06-27",
        "organization": "NEXPA System",
        "address_1": "#105, YBS bldg,227-1 Yongdap-Dong",
        "address_2": "  Seoul  ASI/KR/KS013/SEOUL",
        "country": "KR"
    },
    "303335": {
        "oui_hex": "30-33-35",
        "organization": "Boosty",
        "address_1": "40 Princes Street",
        "address_2": "Ipswich  Suffolk  IP11RJ",
        "country": "GB"
    },
    "44746C": {
        "oui_hex": "44-74-6C",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "4C9EFF": {
        "oui_hex": "4C-9E-FF",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "BC9CC5": {
        "oui_hex": "BC-9C-C5",
        "organization": "Beijing Huafei Technology Co., Ltd.",
        "address_1": "2 floor, Research building, Guanghua Pioneer Park, No.18, Anningzhuang East Rd, Haidian District, Beijing, China.",
        "address_2": "Beijing  Beijing  100085",
        "country": "CN"
    },
    "5CB8CB": {
        "oui_hex": "5C-B8-CB",
        "organization": "Allis Communications",
        "address_1": "10F.-3,No.31-1, Lane 169 Kangning St.,",
        "address_2": "New Taipei City  New Taipei City  221",
        "country": "TW"
    },
    "34F0CA": {
        "oui_hex": "34-F0-CA",
        "organization": "Shenzhen Linghangyuan Digital Technology Co.,Ltd.",
        "address_1": "Building R, Linghangyuan Industrial Park, No. 163 Banxuegang Road, Longgang Distrial, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518129",
        "country": "CN"
    },
    "70720D": {
        "oui_hex": "70-72-0D",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999, Qishan North 2nd Road, Information & Optoelectronics Park, Torch Hi-tech Industry Development Zone, Xiamen, P.R.China",
        "address_2": "Xiamen  Fujian  361000",
        "country": "CN"
    },
    "3CCD5A": {
        "oui_hex": "3C-CD-5A",
        "organization": "Technische Alternative GmbH",
        "address_1": "Langestr. 124",
        "address_2": "Amaliendorf  Lower Austria  A-3872",
        "country": "AT"
    },
    "FCAA14": {
        "oui_hex": "FC-AA-14",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "Pin-Jen City, Taoyuan, Taiwan, R.O.C.",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "94D60E": {
        "oui_hex": "94-D6-0E",
        "organization": "shenzhen yunmao information technologies co., ltd",
        "address_1": "H4-3A, Twelve Oaks Manor, bulong road",
        "address_2": "shenzhen  guanggong  518127",
        "country": "CN"
    },
    "748F4D": {
        "oui_hex": "74-8F-4D",
        "organization": "MEN Mikro Elektronik GmbH",
        "address_1": "Neuwieder Str. 3 - 7",
        "address_2": "Nuernberg  Bavaria  90411",
        "country": "DE"
    },
    "506787": {
        "oui_hex": "50-67-87",
        "organization": "Planet Networks",
        "address_1": "1 Ivy Crest Ln",
        "address_2": "Rockaway  NJ  07866",
        "country": "US"
    },
    "8CBF9D": {
        "oui_hex": "8C-BF-9D",
        "organization": "Shanghai Xinyou Information Technology Ltd. Co.",
        "address_1": "905，418 Guiqing Road, Xuhui District,",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "9CAD97": {
        "oui_hex": "9C-AD-97",
        "organization": "Hon Hai Precision Ind. Co.,Ltd.",
        "address_1": "Building D21,No.1, East Zone 1st Road",
        "address_2": "Chongqing  Chongqing  401332",
        "country": "CN"
    },
    "882950": {
        "oui_hex": "88-29-50",
        "organization": "Netmoon Technology Co., Ltd",
        "address_1": "2nd Floor, Building No.1, NO.319, Qingpi Avenue",
        "address_2": "Wenjiang District  Chengdu  611130",
        "country": "CN"
    },
    "7CE524": {
        "oui_hex": "7C-E5-24",
        "organization": "Quirky, Inc.",
        "address_1": "606 W 28th Street",
        "address_2": "New York  NY  10001",
        "country": "US"
    },
    "F4D261": {
        "oui_hex": "F4-D2-61",
        "organization": "SEMOCON Co., Ltd",
        "address_1": "B-19F, Gunpo IT Valley, Dangjeong-dong, 17, Gosan-ro 148beon-gil,",
        "address_2": "Gunpo-si  Gyeonggi-do  435-833",
        "country": "KR"
    },
    "48D855": {
        "oui_hex": "48-D8-55",
        "organization": "Telvent",
        "address_1": "P.I. Alcobendas c/ Valgrande. 6",
        "address_2": "Alcobendas  Madrid  28108",
        "country": "ES"
    },
    "08F728": {
        "oui_hex": "08-F7-28",
        "organization": "GLOBO Multimedia Sp. z o.o. Sp.k.",
        "address_1": "Gryfinska 104",
        "address_2": "Szczecin  Zachodniopomorskie  70-772",
        "country": "PL"
    },
    "206E9C": {
        "oui_hex": "20-6E-9C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "6C2F2C": {
        "oui_hex": "6C-2F-2C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "B009D3": {
        "oui_hex": "B0-09-D3",
        "organization": "Avizia",
        "address_1": "12018 Sunrise Valley Drive",
        "address_2": "Reston  VA  20191",
        "country": "US"
    },
    "60C1CB": {
        "oui_hex": "60-C1-CB",
        "organization": "Fujian Great Power PLC Equipment Co.,Ltd",
        "address_1": "6/F.Bld.34.Zone C.Software Park",
        "address_2": "Fuzhou  Fujian,China  350003",
        "country": "CN"
    },
    "BC25F0": {
        "oui_hex": "BC-25-F0",
        "organization": "3D Display Technologies Co., Ltd.",
        "address_1": "4F., No.542-17, Zhongzheng Rd",
        "address_2": "New Taipei City    242",
        "country": "TW"
    },
    "C03D46": {
        "oui_hex": "C0-3D-46",
        "organization": "Shanghai Sango Network Technology Co.,Ltd",
        "address_1": "No 666 Zhangheng Road",
        "address_2": "Pudong  Shanghai  210203",
        "country": "CN"
    },
    "64EAC5": {
        "oui_hex": "64-EA-C5",
        "organization": "SiboTech Automation Co., Ltd.",
        "address_1": "5th Floor, Bld 3",
        "address_2": "Shanghai  Shanghai  201612",
        "country": "CN"
    },
    "30F7D7": {
        "oui_hex": "30-F7-D7",
        "organization": "Thread Technology Co., Ltd",
        "address_1": "4F, A Block, CYG, No.2,Mid GaoXin",
        "address_2": "Shenzhen  GuangDong  518055",
        "country": "CN"
    },
    "18227E": {
        "oui_hex": "18-22-7E",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "30C7AE": {
        "oui_hex": "30-C7-AE",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44D4E0": {
        "oui_hex": "44-D4-E0",
        "organization": "Sony Mobile Communications Inc",
        "address_1": "4-12-3 Higashi – Shinagawa",
        "address_2": "Shinagawa-ku  Tokyo  140-0002",
        "country": "JP"
    },
    "FCD5D9": {
        "oui_hex": "FC-D5-D9",
        "organization": "Shenzhen SDMC Technology Co., Ltd.",
        "address_1": "7/F,Block A,Huahan Bldg.,",
        "address_2": "Shenzhen  GuangDong  518000",
        "country": "CN"
    },
    "74DA38": {
        "oui_hex": "74-DA-38",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "E4F4C6": {
        "oui_hex": "E4-F4-C6",
        "organization": "NETGEAR",
        "address_1": "350 East Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "CCA0E5": {
        "oui_hex": "CC-A0-E5",
        "organization": "DZG Metering GmbH",
        "address_1": "Heidelberger Str. 32",
        "address_2": "Oranienburg  Brandenburg  16515",
        "country": "DE"
    },
    "60812B": {
        "oui_hex": "60-81-2B",
        "organization": "Custom Control Concepts",
        "address_1": "6020 S 190th ST",
        "address_2": "Kent  Washington  98032",
        "country": "US"
    },
    "1C1CFD": {
        "oui_hex": "1C-1C-FD",
        "organization": "Dalian Hi-Think Computer Technology, Corp",
        "address_1": "Hi-Think Software Building,No.6 Hi-Tech Street, Qixianling Industrial Base, Hi-Tech Zone, Dalian, China",
        "address_2": "Dalian  LiaoNing  116023",
        "country": "CN"
    },
    "90AE1B": {
        "oui_hex": "90-AE-1B",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "60E327": {
        "oui_hex": "60-E3-27",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "48D18E": {
        "oui_hex": "48-D1-8E",
        "organization": "Metis Communication Co.,Ltd",
        "address_1": "#102-805 Digital Empire2",
        "address_2": "Suwon-Si  GyeongGi-Do  443-734",
        "country": "KR"
    },
    "F86601": {
        "oui_hex": "F8-66-01",
        "organization": "Suzhou Chi-tek information technology Co., Ltd",
        "address_1": "Rm204C、204D, Building A7,",
        "address_2": " SuZhou  Jiangsu  215123",
        "country": "CN"
    },
    "145645": {
        "oui_hex": "14-56-45",
        "organization": "Savitech Corp.",
        "address_1": "3F, No.309, Guangming 1st Rd.,",
        "address_2": "Zhubei  Hsinchu  30259",
        "country": "TW"
    },
    "7062B8": {
        "oui_hex": "70-62-B8",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "ACA919": {
        "oui_hex": "AC-A9-19",
        "organization": "TrekStor GmbH",
        "address_1": "Kastanienallee 8-10",
        "address_2": "Lorsch  Hessen  64653",
        "country": "DE"
    },
    "B025AA": {
        "oui_hex": "B0-25-AA",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "D4B43E": {
        "oui_hex": "D4-B4-3E",
        "organization": "Messcomp Datentechnik GmbH",
        "address_1": "Neudecker Str. 11",
        "address_2": "Wasserburg  Bayern  83512",
        "country": "DE"
    },
    "94C014": {
        "oui_hex": "94-C0-14",
        "organization": "Sorter Sp. j. Konrad Grzeszczyk MichaA, Ziomek",
        "address_1": "ul. Gdynska 32",
        "address_2": "PL9482565081  Mazowieckie  26-600",
        "country": "PL"
    },
    "9CFBF1": {
        "oui_hex": "9C-FB-F1",
        "organization": "MESOMATIC GmbH & Co.KG",
        "address_1": "Siemensstr. 36",
        "address_2": "Kernen i.R.    71394",
        "country": "DE"
    },
    "1027BE": {
        "oui_hex": "10-27-BE",
        "organization": "TVIP",
        "address_1": "190000 ul. Decabristov, h.6 А, of.10-Н",
        "address_2": "  Saint-Petersburg  197227",
        "country": "RU"
    },
    "2087AC": {
        "oui_hex": "20-87-AC",
        "organization": "AES motomation",
        "address_1": "48501 Warm Springs Blvd.",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "709383": {
        "oui_hex": "70-93-83",
        "organization": "Intelligent Optical Network High Tech CO.,LTD.",
        "address_1": "Room 205,Building 11,Jia",
        "address_2": "Changping District  Beijing  102200",
        "country": "CN"
    },
    "80D433": {
        "oui_hex": "80-D4-33",
        "organization": "LzLabs GmbH",
        "address_1": "Alte Winterthurerstrasse 14B",
        "address_2": "Wallisellen  Zurich  8304",
        "country": "CH"
    },
    "B0DA00": {
        "oui_hex": "B0-DA-00",
        "organization": "CERA ELECTRONIQUE",
        "address_1": "PARC D&#39;ACTIVITES",
        "address_2": "VAL DE REUIL  HAUTE NORMANDIE  27100",
        "country": "FR"
    },
    "1CAB01": {
        "oui_hex": "1C-AB-01",
        "organization": "Innovolt",
        "address_1": "14 Piedmont Center",
        "address_2": "Atlanta  GA  30305",
        "country": "US"
    },
    "D8B6D6": {
        "oui_hex": "D8-B6-D6",
        "organization": "Blu Tether Limited",
        "address_1": "7600 Leesburg Pike",
        "address_2": "Falls Church  VA  22043",
        "country": "US"
    },
    "6C2C06": {
        "oui_hex": "6C-2C-06",
        "organization": "OOO NPP Systemotechnika-NN",
        "address_1": "Nartova lane, 2v",
        "address_2": "Nizhny Novgorod  Nizhegorodskaya oblast  603057",
        "country": "RU"
    },
    "C4913A": {
        "oui_hex": "C4-91-3A",
        "organization": "Shenzhen Sanland Electronic Co., ltd.",
        "address_1": "3 floor,Block D, Glory Technology Industrial Park,",
        "address_2": "ShenZhen  Guangdong  518116",
        "country": "CN"
    },
    "68856A": {
        "oui_hex": "68-85-6A",
        "organization": "OuterLink Corporation",
        "address_1": "187 Ballardvale St., Ste. A260",
        "address_2": "Wilmington  MA  01887",
        "country": "US"
    },
    "9451BF": {
        "oui_hex": "94-51-BF",
        "organization": "Hyundai ESG",
        "address_1": "Gangnam-gu",
        "address_2": "Seoul  KOREA, REPUBLIC OF  135-845",
        "country": "KR"
    },
    "F015A0": {
        "oui_hex": "F0-15-A0",
        "organization": "KyungDong One Co., Ltd.",
        "address_1": "205-38, Gasan digital 1-ro,",
        "address_2": "  Seoul  153-803",
        "country": "KR"
    },
    "C44E1F": {
        "oui_hex": "C4-4E-1F",
        "organization": "BlueN",
        "address_1": "121-122 3F",
        "address_2": "Daegu  Korea  700-809",
        "country": "KR"
    },
    "B0869E": {
        "oui_hex": "B0-86-9E",
        "organization": "Chloride S.r.L",
        "address_1": "Via Fornace ,30",
        "address_2": "CastelGuelfo (Bologna)  Italy  40023",
        "country": "IT"
    },
    "D057A1": {
        "oui_hex": "D0-57-A1",
        "organization": "Werma Signaltechnik GmbH & Co. KG",
        "address_1": "Duerbheimer Strasse",
        "address_2": "Rietheim-Weilheim    78604",
        "country": "DE"
    },
    "B4B542": {
        "oui_hex": "B4-B5-42",
        "organization": "Hubbell Power Systems, Inc.",
        "address_1": "8100 Churchill Ave",
        "address_2": "Leeds  AL  35094",
        "country": "US"
    },
    "54CDEE": {
        "oui_hex": "54-CD-EE",
        "organization": "ShenZhen Apexis Electronic Co.,Ltd",
        "address_1": "12th floor,Keji BuildiHigng",
        "address_2": " ShenZhen   GuangDong   518057",
        "country": "CN"
    },
    "88E8F8": {
        "oui_hex": "88-E8-F8",
        "organization": "YONG TAI ELECTRONIC (DONGGUAN) LTD.",
        "address_1": "Yuan Shan Bei Managed Region",
        "address_2": "Dong Guan  Guang Dong  523583",
        "country": "CN"
    },
    "909864": {
        "oui_hex": "90-98-64",
        "organization": "Impex-Sat GmbH&amp;Co KG",
        "address_1": "Beim Giesshaus 7",
        "address_2": "Glueckstadt    25348",
        "country": "DE"
    },
    "DCE578": {
        "oui_hex": "DC-E5-78",
        "organization": "Experimental Factory of Scientific Engineering and Special Design Department",
        "address_1": "9, Academician Semenov prospect",
        "address_2": "Chernogolovka  Moscow region  142432",
        "country": "RU"
    },
    "D86595": {
        "oui_hex": "D8-65-95",
        "organization": "Toy's Myth Inc.",
        "address_1": "304, Yongsan-gu Changup-Jiwon center",
        "address_2": "  Seoul  140-240",
        "country": "KR"
    },
    "F4B52F": {
        "oui_hex": "F4-B5-2F",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C0F79D": {
        "oui_hex": "C0-F7-9D",
        "organization": "Powercode",
        "address_1": "300 Industrial Dr",
        "address_2": "Random Lake  Wisconsin  53075",
        "country": "US"
    },
    "C4C919": {
        "oui_hex": "C4-C9-19",
        "organization": "Energy Imports Ltd",
        "address_1": "306a Broadway Ave",
        "address_2": "Palmerston North  Manawatu  4414",
        "country": "NZ"
    },
    "38F098": {
        "oui_hex": "38-F0-98",
        "organization": "Vapor Stone Rail Systems",
        "address_1": "10000 Cavendish",
        "address_2": "Saint-Laurent  Quebec  H4M2V1",
        "country": "CA"
    },
    "64E892": {
        "oui_hex": "64-E8-92",
        "organization": "Morio Denki Co., Ltd.",
        "address_1": "2, Nadooka",
        "address_2": "Ryugasaki  Ibaraki  301-0845",
        "country": "JP"
    },
    "D8DD5F": {
        "oui_hex": "D8-DD-5F",
        "organization": "BALMUDA Inc.",
        "address_1": "5-1-21 Kyonancho",
        "address_2": "Musashino  Tokyo  180-0023",
        "country": "JP"
    },
    "D86194": {
        "oui_hex": "D8-61-94",
        "organization": "Objetivos y Sevicios de Valor Añadido",
        "address_1": "Calle Monte Esquinza 28, 1ºD",
        "address_2": "Madrid    28010",
        "country": "ES"
    },
    "E8FC60": {
        "oui_hex": "E8-FC-60",
        "organization": "ELCOM Innovations Private Limited",
        "address_1": "9TH FLOOR, MERIDIEN COMMERCIAL TOWER",
        "address_2": "New Delhi    110001",
        "country": "US"
    },
    "589CFC": {
        "oui_hex": "58-9C-FC",
        "organization": "FreeBSD Foundation",
        "address_1": "P.O. Box 20247",
        "address_2": "Boulder  CO   80308-3247",
        "country": "US"
    },
    "702C1F": {
        "oui_hex": "70-2C-1F",
        "organization": "Wisol",
        "address_1": "377-3, Gajang-dong, Osan-si",
        "address_2": "    447-210",
        "country": "KR"
    },
    "C8D429": {
        "oui_hex": "C8-D4-29",
        "organization": "Muehlbauer AG",
        "address_1": "Josef-Mühlbauer-Platz 1",
        "address_2": "Roding  Bavaria  93426",
        "country": "DE"
    },
    "F85C45": {
        "oui_hex": "F8-5C-45",
        "organization": "IC Nexus Co. Ltd.",
        "address_1": "6F-1, No.3-2 Park Street",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "ACE069": {
        "oui_hex": "AC-E0-69",
        "organization": "ISAAC Instruments",
        "address_1": "240 Frechette",
        "address_2": "Chambly  Quebec  J3L2Z5",
        "country": "CA"
    },
    "30B5C2": {
        "oui_hex": "30-B5-C2",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "E07F53": {
        "oui_hex": "E0-7F-53",
        "organization": "TECHBOARD SRL",
        "address_1": "Via Della Scienza, 50",
        "address_2": "Modena    41122",
        "country": "IT"
    },
    "48FEEA": {
        "oui_hex": "48-FE-EA",
        "organization": "HOMA B.V.",
        "address_1": "P.O. Box 545",
        "address_2": "Enschede    7500 AM",
        "country": "NL"
    },
    "E8EA6A": {
        "oui_hex": "E8-EA-6A",
        "organization": "StarTech.com",
        "address_1": "45 Artisans Cres",
        "address_2": "London  Ontario  N5V5E9",
        "country": "CA"
    },
    "04DB8A": {
        "oui_hex": "04-DB-8A",
        "organization": "Suntech International Ltd.",
        "address_1": "Room 605, IT Mirae Tower",
        "address_2": "  Seoul  153-760",
        "country": "KR"
    },
    "90DFB7": {
        "oui_hex": "90-DF-B7",
        "organization": "s.m.s smart microwave sensors GmbH",
        "address_1": "In den Waashainen 1",
        "address_2": "Braunschweig  NI  38108",
        "country": "DE"
    },
    "085700": {
        "oui_hex": "08-57-00",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "FC27A2": {
        "oui_hex": "FC-27-A2",
        "organization": "TRANS ELECTRIC CO., LTD.",
        "address_1": "771,Sec.2 Chungsan Rd,Huatang",
        "address_2": "Changhua  Taiwan  503",
        "country": "TW"
    },
    "FCBBA1": {
        "oui_hex": "FC-BB-A1",
        "organization": "Shenzhen Minicreate Technology Co.,Ltd",
        "address_1": "5/F.,5th,Building,Animation Park,Yuehai Road",
        "address_2": "Shenzhen  Guangdong  518066",
        "country": "CN"
    },
    "F08A28": {
        "oui_hex": "F0-8A-28",
        "organization": "JIANGSU HENGSION ELECTRONIC S and T CO.,LTD",
        "address_1": "4F,Building 3",
        "address_2": "ChangZhou  Jiangsu  213125",
        "country": "CN"
    },
    "28BB59": {
        "oui_hex": "28-BB-59",
        "organization": "RNET Technologies, Inc.",
        "address_1": "240. W. Elmwood Dr.",
        "address_2": "Dayton  OHIO  45459-4248",
        "country": "US"
    },
    "242642": {
        "oui_hex": "24-26-42",
        "organization": "SHARP Corporation.",
        "address_1": "22-22,Abeno-ku",
        "address_2": "Osaka-City  Osaka-Prefecture  545-8522",
        "country": "JP"
    },
    "34DE34": {
        "oui_hex": "34-DE-34",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "FC1607": {
        "oui_hex": "FC-16-07",
        "organization": "Taian Technology(Wuxi) Co.,Ltd.",
        "address_1": "Gaolang East Road No.29",
        "address_2": "Wuxi  Jiangsu  214000",
        "country": "CN"
    },
    "AC02CA": {
        "oui_hex": "AC-02-CA",
        "organization": "HI Solutions, Inc.",
        "address_1": "4105 Royal Drive",
        "address_2": "Kennesaw  GA  30144",
        "country": "US"
    },
    "746F3D": {
        "oui_hex": "74-6F-3D",
        "organization": "Contec GmbH",
        "address_1": "Oberahrer Straße 9",
        "address_2": "Sainerholz  RP  56244",
        "country": "DE"
    },
    "4C0DEE": {
        "oui_hex": "4C-0D-EE",
        "organization": "JABIL CIRCUIT (SHANGHAI) LTD.",
        "address_1": "FL5-UNIT A2 NO 1528 GUMEI ROAD",
        "address_2": "  SHANGHAI  200233",
        "country": "CN"
    },
    "D0634D": {
        "oui_hex": "D0-63-4D",
        "organization": "Meiko Maschinenbau GmbH &amp; Co. KG",
        "address_1": "Englerstraße 3",
        "address_2": "Offenburg    77652",
        "country": "DE"
    },
    "008B43": {
        "oui_hex": "00-8B-43",
        "organization": "RFTECH",
        "address_1": "Cheoin-gu",
        "address_2": "Yongin  Gyeonggi  449-871",
        "country": "KR"
    },
    "8C41F2": {
        "oui_hex": "8C-41-F2",
        "organization": "RDA Technologies Ltd.",
        "address_1": "Suite 2203, CC Wu Building,",
        "address_2": "WanChai  Hong Kong  00000",
        "country": "HK"
    },
    "E036E3": {
        "oui_hex": "E0-36-E3",
        "organization": "Stage One International Co., Ltd.",
        "address_1": "Fl. 5., No. 10., Lane 321, Yangguang St.,",
        "address_2": "Taipei City    11491",
        "country": "TW"
    },
    "DC052F": {
        "oui_hex": "DC-05-2F",
        "organization": "National Products Inc.",
        "address_1": "8410 Dallas Ave S.",
        "address_2": "Seattle  WA  98108",
        "country": "US"
    },
    "D0BD01": {
        "oui_hex": "D0-BD-01",
        "organization": "DS International",
        "address_1": "806ho, ACE HITECH21 B/D",
        "address_2": "Busan  Busan  612-020",
        "country": "KR"
    },
    "8CDE99": {
        "oui_hex": "8C-DE-99",
        "organization": "Comlab Inc.",
        "address_1": "2300 Leon-Harmel, suite 220",
        "address_2": "Quebec  Quebec  G1N 4L2",
        "country": "CA"
    },
    "4CE1BB": {
        "oui_hex": "4C-E1-BB",
        "organization": "Zhuhai HiFocus Technology Co., Ltd.",
        "address_1": "The second floor of the friend industrial park,",
        "address_2": "zhuhai  guangdong  519080",
        "country": "US"
    },
    "24A87D": {
        "oui_hex": "24-A8-7D",
        "organization": "Panasonic Automotive Systems Asia Pacific(Thailand)Co.,Ltd.",
        "address_1": "101 Moo 2 Teparak Road ,",
        "address_2": "Bangsaothong  Samutprakarn  10540",
        "country": "TH"
    },
    "EC71DB": {
        "oui_hex": "EC-71-DB",
        "organization": "Shenzhen Baichuan Digital Technology Co., Ltd.",
        "address_1": "Room 602, Complex Building, Tsinghua High-Tech Park",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "A409CB": {
        "oui_hex": "A4-09-CB",
        "organization": "Alfred Kaercher GmbH &amp; Co KG",
        "address_1": "Alfred Kaercher Gmbh &amp; Co KG",
        "address_2": "Winnenden  Baden-Wuerttemberg  71364",
        "country": "DE"
    },
    "8C569D": {
        "oui_hex": "8C-56-9D",
        "organization": "Imaging Solutions Group",
        "address_1": "1387 Fairport Rd",
        "address_2": "Fairport  NY  14450",
        "country": "US"
    },
    "40B6B1": {
        "oui_hex": "40-B6-B1",
        "organization": "SUNGSAM CO,.Ltd",
        "address_1": "SUNGSAM Bldg, 7-1, BAnga-ro 23beon-gil, Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-829",
        "country": "KR"
    },
    "84FE9E": {
        "oui_hex": "84-FE-9E",
        "organization": "RTC Industries, Inc.",
        "address_1": "2800 Golf Road",
        "address_2": "Rolling Meadows  IL  60008",
        "country": "US"
    },
    "FC4B1C": {
        "oui_hex": "FC-4B-1C",
        "organization": "INTERSENSOR S.R.L.",
        "address_1": "101 Bd. Iuliu Maniu str., Bl. A2, Sc. 2, #47",
        "address_2": "  Bucharest  061094",
        "country": "RO"
    },
    "403067": {
        "oui_hex": "40-30-67",
        "organization": "Conlog (Pty) Ltd",
        "address_1": "270 Felix Dlamini Road",
        "address_2": "Durban  Kwa-zulu Natal  4000",
        "country": "ZA"
    },
    "E86183": {
        "oui_hex": "E8-61-83",
        "organization": "Black Diamond Advanced Technology, LLC",
        "address_1": "7450 S. Priest Drive",
        "address_2": "Tempe  AZ  85283",
        "country": "US"
    },
    "38C9A9": {
        "oui_hex": "38-C9-A9",
        "organization": "SMART High Reliability Solutions, Inc.",
        "address_1": "1325 N Fiesta Blvd., #101",
        "address_2": "Gilbert  AZ  85233",
        "country": "US"
    },
    "501AC5": {
        "oui_hex": "50-1A-C5",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "B0989F": {
        "oui_hex": "B0-98-9F",
        "organization": "LG CNS",
        "address_1": "53-94 Jinwisandan-ro, Jinwuy-Myun",
        "address_2": "Pyungtaek-City  Kyunggi-Do  451-862",
        "country": "KR"
    },
    "C0F1C4": {
        "oui_hex": "C0-F1-C4",
        "organization": "Pacidal Corporation Ltd.",
        "address_1": "3F., No. 11, Aly 3, Ln. 123, Sec. 3 Ren'ai Rd.",
        "address_2": "Taipei City    106",
        "country": "TW"
    },
    "600347": {
        "oui_hex": "60-03-47",
        "organization": "Billion Electric Co. Ltd.",
        "address_1": "8F., No.192, Sec. 2, Zhongxing Rd.,",
        "address_2": "New Taipei City,    231",
        "country": "TW"
    },
    "F0D3A7": {
        "oui_hex": "F0-D3-A7",
        "organization": "CobaltRay Co., Ltd",
        "address_1": "Room 409,Humanteco Building,#281-16",
        "address_2": "Seoul    133120",
        "country": "KR"
    },
    "38A53C": {
        "oui_hex": "38-A5-3C",
        "organization": "COMECER Netherlands",
        "address_1": "Madame Curieweg 1",
        "address_2": "Joure  Friesland  8500 AC",
        "country": "NL"
    },
    "5CFFFF": {
        "oui_hex": "5C-FF-FF",
        "organization": "Shenzhen Kezhonglong Optoelectronic Technology Co., Ltd",
        "address_1": "3/F, B5 Building, Xinfu Industrial Park, Heping Village",
        "address_2": "Shenzhen, Guangdong 518101",
        "country": "US"
    },
    "085240": {
        "oui_hex": "08-52-40",
        "organization": "EbV Elektronikbau- und Vertriebs GmbH",
        "address_1": "Heisterner Weg 8 - 12",
        "address_2": "Burbach  Nordrhein-Westfalen  57299",
        "country": "DE"
    },
    "B8C1A2": {
        "oui_hex": "B8-C1-A2",
        "organization": "Dragon Path Technologies Co., Limited",
        "address_1": "12/F., San Toi Building,",
        "address_2": "Central  Hong Kong",
        "country": "HK"
    },
    "80F25E": {
        "oui_hex": "80-F2-5E",
        "organization": "Kyynel",
        "address_1": "Pirttikuja 3",
        "address_2": "  Oulu  90450",
        "country": "FI"
    },
    "68692E": {
        "oui_hex": "68-69-2E",
        "organization": "Zycoo Co.,Ltd",
        "address_1": "F7,B7,Tianfu Software park",
        "address_2": "Chengdu  Sichuan  610000",
        "country": "CN"
    },
    "D46867": {
        "oui_hex": "D4-68-67",
        "organization": "Neoventus Design Group",
        "address_1": "2350 Commonwealth Dr, Suite E",
        "address_2": "Charlottesville  VA  22901",
        "country": "US"
    },
    "2C18AE": {
        "oui_hex": "2C-18-AE",
        "organization": "Trend Electronics Co., Ltd.",
        "address_1": "4F-3, No 17, Lane 77, Sec. 2",
        "address_2": "Taipei  Taiwan  10446",
        "country": "TW"
    },
    "F81CE5": {
        "oui_hex": "F8-1C-E5",
        "organization": "Telefonbau Behnke GmbH",
        "address_1": "Robert-Jungk-Str. 3",
        "address_2": "Kirkel  Saarland  66459",
        "country": "DE"
    },
    "889166": {
        "oui_hex": "88-91-66",
        "organization": "Viewcooper Corp.",
        "address_1": "Room 1061, A,Seven Block, No.128 Huayuan Rd",
        "address_2": "SHANGHAI    200083",
        "country": "CN"
    },
    "103378": {
        "oui_hex": "10-33-78",
        "organization": "FLECTRON Co., LTD",
        "address_1": "A-625, Sigma2, Tancheonsang-ro 164",
        "address_2": "Seongnam-si  Gyeonggi-do  463-741",
        "country": "KR"
    },
    "14EDA5": {
        "oui_hex": "14-ED-A5",
        "organization": "Wächter GmbH Sicherheitssysteme",
        "address_1": "Alte Ricklinger Str. 3",
        "address_2": "Hannover  Garbsen  30823",
        "country": "DE"
    },
    "50C006": {
        "oui_hex": "50-C0-06",
        "organization": "Carmanah Signs",
        "address_1": "#5 6025 12 Street SE",
        "address_2": "Calgary  Alberta  T2H2K1",
        "country": "CA"
    },
    "04CB1D": {
        "oui_hex": "04-CB-1D",
        "organization": "Traka plc",
        "address_1": "30 Stilebrook Road",
        "address_2": "Bucks  Buckinghamshire  MK46 5EA",
        "country": "GB"
    },
    "A4E9A3": {
        "oui_hex": "A4-E9-A3",
        "organization": "Honest Technology Co., Ltd",
        "address_1": "5F, KyungDong Bldg. 906-5,",
        "address_2": "  Daejeon  305-330",
        "country": "KR"
    },
    "A0E5E9": {
        "oui_hex": "A0-E5-E9",
        "organization": "enimai Inc",
        "address_1": "701 Villa St",
        "address_2": "Mountain View  California  94041",
        "country": "US"
    },
    "9C216A": {
        "oui_hex": "9C-21-6A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "F862AA": {
        "oui_hex": "F8-62-AA",
        "organization": "xn systems",
        "address_1": "#917, Worldmerdian 2nd",
        "address_2": "  Seoul  153759",
        "country": "KR"
    },
    "107BEF": {
        "oui_hex": "10-7B-EF",
        "organization": "Zyxel Communications Corporation",
        "address_1": "No. 6 Innovation Road II, Science Park",
        "address_2": "Hsichu  Taiwan  300",
        "country": "TW"
    },
    "B462AD": {
        "oui_hex": "B4-62-AD",
        "organization": "Elysia Germany GmbH",
        "address_1": "Benzstr.4",
        "address_2": "Straubenhardt  Baden-Wuerttemberg  75334",
        "country": "DE"
    },
    "345C40": {
        "oui_hex": "34-5C-40",
        "organization": "Cargt Holdings LLC",
        "address_1": "8820 Hillside Dr",
        "address_2": "Lenexa  KANSAS (KS)  66227",
        "country": "US"
    },
    "68193F": {
        "oui_hex": "68-19-3F",
        "organization": "Digital Airways",
        "address_1": "5, Place Jean SIARD",
        "address_2": "ARGENTAN  NORMANDY  61200",
        "country": "FR"
    },
    "B4750E": {
        "oui_hex": "B4-75-0E",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  Ca.   90094",
        "country": "US"
    },
    "94103E": {
        "oui_hex": "94-10-3E",
        "organization": "Belkin International Inc.",
        "address_1": "12045 East Waterfront Drive",
        "address_2": "Playa Vista  Ca.   90094",
        "country": "US"
    },
    "7CB733": {
        "oui_hex": "7C-B7-33",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "3051F8": {
        "oui_hex": "30-51-F8",
        "organization": "BYK-Gardner GmbH",
        "address_1": "Lausitzer Strasse 8",
        "address_2": "Geretsried  Bavarian  82538",
        "country": "DE"
    },
    "E8F226": {
        "oui_hex": "E8-F2-26",
        "organization": "MILLSON CUSTOM SOLUTIONS INC.",
        "address_1": "2036 COLUMBIA STREET",
        "address_2": "VANCOUVER  BRITISH COLUMBIA  V5Y 3E1",
        "country": "CA"
    },
    "44EE30": {
        "oui_hex": "44-EE-30",
        "organization": "Budelmann Elektronik GmbH",
        "address_1": "Von-Renesse-Weg 60",
        "address_2": "Muenster  North Rhine-Westphalia  48163",
        "country": "DE"
    },
    "FC1E16": {
        "oui_hex": "FC-1E-16",
        "organization": "IPEVO corp",
        "address_1": "3F,No.53,Bo-ai Road,Taipei 100,Taiwan",
        "address_2": "Taipei    10044",
        "country": "TW"
    },
    "3C6E63": {
        "oui_hex": "3C-6E-63",
        "organization": "Mitron OY",
        "address_1": "Yrittäjankaari 19",
        "address_2": "FORSSA  Kanta-Hame  30420",
        "country": "FI"
    },
    "A4059E": {
        "oui_hex": "A4-05-9E",
        "organization": "STA Infinity LLP",
        "address_1": "WINNINGTON HOUSE",
        "address_2": "London    N12 0DR",
        "country": "GB"
    },
    "A0BF50": {
        "oui_hex": "A0-BF-50",
        "organization": "S.C. ADD-PRODUCTION S.R.L.",
        "address_1": "36, Dragomirna str.",
        "address_2": "Chisinau    MD-2008",
        "country": "MD"
    },
    "E8D4E0": {
        "oui_hex": "E8-D4-E0",
        "organization": "Beijing BenyWave Technology Co., Ltd.",
        "address_1": "No.55, Jiachuang Road, Taihu Town",
        "address_2": "  Beijing  101111",
        "country": "CN"
    },
    "FC019E": {
        "oui_hex": "FC-01-9E",
        "organization": "VIEVU",
        "address_1": "105 W. John St",
        "address_2": "Seattle  WA  98119",
        "country": "US"
    },
    "642184": {
        "oui_hex": "64-21-84",
        "organization": "Nippon Denki Kagaku Co.,LTD",
        "address_1": "Nishino Gotochou 18",
        "address_2": "Kyoto City  Kyoto Pref  607-8356",
        "country": "JP"
    },
    "2464EF": {
        "oui_hex": "24-64-EF",
        "organization": "CYG SUNRI CO.,LTD.",
        "address_1": "No. 3, Langshan 1st Road, North Area of Hi-Tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "D8270C": {
        "oui_hex": "D8-27-0C",
        "organization": "MaxTronic International Co., Ltd.",
        "address_1": "4F., No.529, Zhongzheng Rd., Xindian Dist.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "B4CCE9": {
        "oui_hex": "B4-CC-E9",
        "organization": "PROSYST",
        "address_1": "2C Rue de l' EPINOY",
        "address_2": "TEMPLEMARS    59175",
        "country": "FR"
    },
    "C4D655": {
        "oui_hex": "C4-D6-55",
        "organization": "Tercel technology co.,ltd",
        "address_1": "Huafa South Road, Futian District,",
        "address_2": "SHENZHEN  GUANGDONG  518000",
        "country": "CN"
    },
    "58BDF9": {
        "oui_hex": "58-BD-F9",
        "organization": "Sigrand",
        "address_1": "UNIT 602 6/F, Causeway Bay Comm Bldg,",
        "address_2": "  Hong Kong  999077",
        "country": "HK"
    },
    "C0C687": {
        "oui_hex": "C0-C6-87",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "C49380": {
        "oui_hex": "C4-93-80",
        "organization": "Speedytel technology",
        "address_1": "ROOM 1103,HANG SENG MONGKOK BUILDING,677 NATHAN ROAD,MONGKOK,KOWLOON",
        "address_2": "HONG KONG  HONG KONG",
        "country": "HK"
    },
    "007DFA": {
        "oui_hex": "00-7D-FA",
        "organization": "Volkswagen Group of America",
        "address_1": "3800 Hamlin Rd",
        "address_2": "Auburn Hills  MI  48326",
        "country": "US"
    },
    "2C7155": {
        "oui_hex": "2C-71-55",
        "organization": "HiveMotion",
        "address_1": "1806, STX-V Tower",
        "address_2": "Seoul    153-803",
        "country": "KR"
    },
    "20180E": {
        "oui_hex": "20-18-0E",
        "organization": "Shenzhen Sunchip Technology Co., Ltd",
        "address_1": "Room 818-831, Building B1, Mingyou Purchasing Center, Bao'an District, Shenzhen, China",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "80B219": {
        "oui_hex": "80-B2-19",
        "organization": "ELEKTRON TECHNOLOGY UK LIMITED",
        "address_1": "BROERS BUILDING,",
        "address_2": "CAMBRIDGE  CAMBS  CB3 0FA",
        "country": "US"
    },
    "E0AEB2": {
        "oui_hex": "E0-AE-B2",
        "organization": "Bender GmbH &amp; Co.KG",
        "address_1": "Londorfer Straße 65",
        "address_2": "Grünberg  Hessen  35305",
        "country": "DE"
    },
    "F84A7F": {
        "oui_hex": "F8-4A-7F",
        "organization": "Innometriks Inc",
        "address_1": "3654 Ocean Ranch Blvd",
        "address_2": "Oceanside  Ca  92056",
        "country": "US"
    },
    "74A4B5": {
        "oui_hex": "74-A4-B5",
        "organization": "Powerleader Science and Technology Co. Ltd.",
        "address_1": "Powerleader Technology Park, #3 Guanyi Rd.",
        "address_2": "Shenzhen  Guangdong  518110",
        "country": "CN"
    },
    "909F43": {
        "oui_hex": "90-9F-43",
        "organization": "Accutron Instruments Inc.",
        "address_1": "11 Mary Street",
        "address_2": "Sudbury  Ontario  P3C1B4",
        "country": "CA"
    },
    "2894AF": {
        "oui_hex": "28-94-AF",
        "organization": "Samhwa Telecom",
        "address_1": "293-7, Doksan-dong",
        "address_2": "Seoul  Seoul  153-813",
        "country": "KR"
    },
    "AC5036": {
        "oui_hex": "AC-50-36",
        "organization": "Pi-Coral Inc",
        "address_1": "2130 Gold St",
        "address_2": "San Jose  CA  95002-1177",
        "country": "US"
    },
    "0C9B13": {
        "oui_hex": "0C-9B-13",
        "organization": "Shanghai Magic Mobile Telecommunication Co.Ltd.",
        "address_1": " B7 parts, second floor",
        "address_2": "Waigaoqiao Free Trade Zone  Shanghai  200131",
        "country": "CN"
    },
    "94BF1E": {
        "oui_hex": "94-BF-1E",
        "organization": "eflow Inc. / Smart Device Planning and Development Division",
        "address_1": "Ryoka-Yoyogi building 3F",
        "address_2": "Shibuya-Ku  TOKYO  151-0051",
        "country": "JP"
    },
    "E8516E": {
        "oui_hex": "E8-51-6E",
        "organization": "TSMART Inc.",
        "address_1": "The-O-valley 306,",
        "address_2": "Anyang-si  Gyeonggi-do  431-080",
        "country": "KR"
    },
    "AC220B": {
        "oui_hex": "AC-22-0B",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "B887A8": {
        "oui_hex": "B8-87-A8",
        "organization": "Step Ahead Innovations Inc.",
        "address_1": "20 Wintersport Ln.",
        "address_2": "Williston  VT  05495",
        "country": "US"
    },
    "E0A198": {
        "oui_hex": "E0-A1-98",
        "organization": "NOJA Power Switchgear Pty Ltd",
        "address_1": "16 Archimedes Place",
        "address_2": "Murarrie  QLD  4172",
        "country": "AU"
    },
    "88354C": {
        "oui_hex": "88-35-4C",
        "organization": "Transics",
        "address_1": "p/a Ter Waarde 91",
        "address_2": "Ieper    8900",
        "country": "BE"
    },
    "3C6104": {
        "oui_hex": "3C-61-04",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "CC4AE1": {
        "oui_hex": "CC-4A-E1",
        "organization": "fourtec -Fourier Technologies",
        "address_1": "16 Hamelacha St. POB 11681",
        "address_2": "Rosh Ha’ayin    48091",
        "country": "IL"
    },
    "8C4B59": {
        "oui_hex": "8C-4B-59",
        "organization": "3D Imaging & Simulations Corp",
        "address_1": "815, Timnip-Dong, Yuseong-Gu",
        "address_2": "  Daejeon  305510",
        "country": "KR"
    },
    "5C3327": {
        "oui_hex": "5C-33-27",
        "organization": "Spazio Italia srl",
        "address_1": "Via G.Galilei, 50",
        "address_2": "Padenghe sul Garda  BS  25080",
        "country": "IT"
    },
    "507691": {
        "oui_hex": "50-76-91",
        "organization": "Tekpea, Inc.",
        "address_1": "2225 East Bayshore Road",
        "address_2": "Palo Alto  California  94303",
        "country": "US"
    },
    "28F532": {
        "oui_hex": "28-F5-32",
        "organization": "ADD-Engineering BV",
        "address_1": "P.O. BOX 5893",
        "address_2": "ROTTERDAM  ZH  3008 AW",
        "country": "NL"
    },
    "9440A2": {
        "oui_hex": "94-40-A2",
        "organization": "Anywave Communication Technologies, Inc.",
        "address_1": "300 Knightsbridge Parkway, Suite 150",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "1C86AD": {
        "oui_hex": "1C-86-AD",
        "organization": "MCT CO., LTD.",
        "address_1": "C-815/816, Garden5 Works, 52 Chungmin-ro",
        "address_2": "Songpa-gu  Seoul  138-961",
        "country": "KR"
    },
    "28D93E": {
        "oui_hex": "28-D9-3E",
        "organization": "Telecor Inc.",
        "address_1": "6205 Kestrel Road",
        "address_2": "Mississauga  Ontario  L5T 2A1",
        "country": "CA"
    },
    "640B4A": {
        "oui_hex": "64-0B-4A",
        "organization": "Digital Telecom Technology Limited",
        "address_1": "1708 Nan Fung Tower,",
        "address_2": "    00852",
        "country": "US"
    },
    "384233": {
        "oui_hex": "38-42-33",
        "organization": "Wildeboer Bauteile GmbH",
        "address_1": "Marker Weg 11",
        "address_2": "Weener  Niedersachsen  26826",
        "country": "US"
    },
    "3C8AB0": {
        "oui_hex": "3C-8A-B0",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C034B4": {
        "oui_hex": "C0-34-B4",
        "organization": "Gigastone Corporation",
        "address_1": "12F.NO 480. Rueiguang Rd.",
        "address_2": "Taipei    11492",
        "country": "TW"
    },
    "CCE8AC": {
        "oui_hex": "CC-E8-AC",
        "organization": "SOYEA Technology Co.,Ltd.",
        "address_1": "STB department,Floor 4,Building 11 south",
        "address_2": "hangzhou  zhejiang  310007",
        "country": "CN"
    },
    "70F176": {
        "oui_hex": "70-F1-76",
        "organization": "Data Modul AG",
        "address_1": "Landsberger Str. 322",
        "address_2": "Munich  Bavaria  80687",
        "country": "DE"
    },
    "B847C6": {
        "oui_hex": "B8-47-C6",
        "organization": "SanJet Technology Corp.",
        "address_1": "4F,No2,Li-Hsin Rd., 6,",
        "address_2": "Hsinchu    30078",
        "country": "TW"
    },
    "B8CD93": {
        "oui_hex": "B8-CD-93",
        "organization": "Penetek, Inc",
        "address_1": "6F, No.18, Wuqun 7th Rd, Wugu Dist",
        "address_2": "New Taipei City    248",
        "country": "TW"
    },
    "28DB81": {
        "oui_hex": "28-DB-81",
        "organization": "Shanghai Guao Electronic Technology Co., Ltd",
        "address_1": "No.6, Alley 1225 TongPu Road,",
        "address_2": "  Shanghai  200333",
        "country": "CN"
    },
    "3806B4": {
        "oui_hex": "38-06-B4",
        "organization": "A.D.C. GmbH",
        "address_1": "Peter-Dornier-Str. 10",
        "address_2": "Lindau    88131",
        "country": "DE"
    },
    "B8241A": {
        "oui_hex": "B8-24-1A",
        "organization": "SWEDA INFORMATICA LTDA",
        "address_1": "RUA DONA BRIGIDA, 713",
        "address_2": "SAO PAULO  SP  04111-081",
        "country": "BR"
    },
    "A0B100": {
        "oui_hex": "A0-B1-00",
        "organization": "ShenZhen Cando Electronics Co.,Ltd",
        "address_1": "Building A, Dagang Industrial Zone, Changzhen Community",
        "address_2": "Shenzhen City  Guangdong  518132",
        "country": "CN"
    },
    "201D03": {
        "oui_hex": "20-1D-03",
        "organization": "Elatec GmbH",
        "address_1": "Lilienthalstr. 3",
        "address_2": "Puchheim  Bayern  82178",
        "country": "DE"
    },
    "E067B3": {
        "oui_hex": "E0-67-B3",
        "organization": "Shenzhen C-Data Technology Co., Ltd",
        "address_1": "#601, Fl6, Bldg F, No.1008  Yangguang Community",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "1C4AF7": {
        "oui_hex": "1C-4A-F7",
        "organization": "AMON INC",
        "address_1": "HANJUN BLDG 4/F, SHINGILDONG 110-4",
        "address_2": "  SEOUL  150839",
        "country": "KR"
    },
    "E4776B": {
        "oui_hex": "E4-77-6B",
        "organization": "AARTESYS AG",
        "address_1": "Bahnhofplatz 7",
        "address_2": "Biel  Bern  CH-2501",
        "country": "CH"
    },
    "30F31D": {
        "oui_hex": "30-F3-1D",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A0EC80": {
        "oui_hex": "A0-EC-80",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0CC81F": {
        "oui_hex": "0C-C8-1F",
        "organization": "Summer Infant, Inc.",
        "address_1": "1275 Park East Drive",
        "address_2": "Woonsocket  Rhode Island  02895",
        "country": "US"
    },
    "A8FB70": {
        "oui_hex": "A8-FB-70",
        "organization": "WiseSec L.t.d",
        "address_1": "145 yaffo ST.",
        "address_2": "Haifa  Israel  37503",
        "country": "IL"
    },
    "E481B3": {
        "oui_hex": "E4-81-B3",
        "organization": "Shenzhen ACT Industrial Co.,Ltd.",
        "address_1": "NO.5 B/D,BEISHAN INDUSTRIAL PARK,BEISHAN R/D,",
        "address_2": "Shenzhen  Guangdong  518083",
        "country": "CN"
    },
    "C06C6D": {
        "oui_hex": "C0-6C-6D",
        "organization": "MagneMotion, Inc.",
        "address_1": "139 Barnum Road",
        "address_2": "Devens  Massachusetts  01434",
        "country": "US"
    },
    "E880D8": {
        "oui_hex": "E8-80-D8",
        "organization": "GNTEK Electronics Co.,Ltd.",
        "address_1": "Suzhou Industrial Park",
        "address_2": "Suzhou  Jiangsu  215021",
        "country": "CN"
    },
    "303EAD": {
        "oui_hex": "30-3E-AD",
        "organization": "Sonavox Canada Inc",
        "address_1": "81 Zenway Blvd #25",
        "address_2": "Woodbridge  Ontario  L4S0S5",
        "country": "CA"
    },
    "F835DD": {
        "oui_hex": "F8-35-DD",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road Hsinchu Industrial Park Hukou, Hsinchu 30352 TAIWAN, REPUBLIC OF CHINA",
        "address_2": "Hsinchu  TAIWAN  30352",
        "country": "TW"
    },
    "D8B04C": {
        "oui_hex": "D8-B0-4C",
        "organization": "Jinan USR IOT Technology Co., Ltd.",
        "address_1": "#1-523, Huizhan Guoji Cheng, Gaoxin Qu",
        "address_2": "JINAN  SHANDONG  250101",
        "country": "CN"
    },
    "CC04B4": {
        "oui_hex": "CC-04-B4",
        "organization": "Select Comfort",
        "address_1": "9800 59th Ave N",
        "address_2": "Minneapolis  MN  55442",
        "country": "US"
    },
    "5C15E1": {
        "oui_hex": "5C-15-E1",
        "organization": "AIDC TECHNOLOGY (S) PTE LTD",
        "address_1": "NO.1 GOLDHILL PLAZA #03-21",
        "address_2": "SINGAPORE    308899",
        "country": "SG"
    },
    "E8519D": {
        "oui_hex": "E8-51-9D",
        "organization": "Yeonhab Precision Co.,LTD",
        "address_1": "219-27, Haksusosa-Gil, Mokcheon-Eup",
        "address_2": "Cheonan  Chungcheongnamdo  330-844",
        "country": "KR"
    },
    "DC5726": {
        "oui_hex": "DC-57-26",
        "organization": "Power-One",
        "address_1": "Via San Girgio 642",
        "address_2": "Terranuova  Arezzo  52028",
        "country": "IT"
    },
    "F8DADF": {
        "oui_hex": "F8-DA-DF",
        "organization": "EcoTech, Inc.",
        "address_1": "999 Postal Road",
        "address_2": "Allentown  PA  18109",
        "country": "US"
    },
    "30AE7B": {
        "oui_hex": "30-AE-7B",
        "organization": "Deqing Dusun Electron CO., LTD",
        "address_1": "No. 640 FengQing Street, Deqing",
        "address_2": "Huzhou  Zhejiang  313200",
        "country": "CN"
    },
    "68EC62": {
        "oui_hex": "68-EC-62",
        "organization": "YODO Technology Corp. Ltd.",
        "address_1": "8F., No.168-1, Liancheng Rd",
        "address_2": "Taipei City    235",
        "country": "TW"
    },
    "188857": {
        "oui_hex": "18-88-57",
        "organization": "Beijing Jinhong Xi-Dian Information Technology Corp.",
        "address_1": "4th -5th Floor, 1# Building NO.1 Zhonghe Road",
        "address_2": "  Beijing  100070",
        "country": "CN"
    },
    "B8C855": {
        "oui_hex": "B8-C8-55",
        "organization": "Shanghai GBCOM Communication Technology Co.,Ltd.",
        "address_1": "Room 602, Building 6, No.",
        "address_2": "  Shanghai  200241",
        "country": "CN"
    },
    "78303B": {
        "oui_hex": "78-30-3B",
        "organization": "Stephen Technologies Co.,Limited",
        "address_1": "5/F, Building NO.1, TongXin Industry Zone",
        "address_2": "Shenzhen  Guangdong  518115",
        "country": "CN"
    },
    "CC1AFA": {
        "oui_hex": "CC-1A-FA",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "6C8B2F": {
        "oui_hex": "6C-8B-2F",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "8C5AF0": {
        "oui_hex": "8C-5A-F0",
        "organization": "Exeltech Solar Products",
        "address_1": "3001 Northern Cross Blvd #361",
        "address_2": "Fort Worth  TX  76137",
        "country": "US"
    },
    "B0808C": {
        "oui_hex": "B0-80-8C",
        "organization": "Laser Light Engines",
        "address_1": "8C Industrial Way",
        "address_2": "Salem  New Hamshire  03079",
        "country": "US"
    },
    "D8DCE9": {
        "oui_hex": "D8-DC-E9",
        "organization": "Kunshan Erlab ductless filtration system Co.,Ltd",
        "address_1": "NO.100 Liu Shi Jin Road",
        "address_2": "Kunshan  Jiangsu  215300",
        "country": "CN"
    },
    "DCD52A": {
        "oui_hex": "DC-D5-2A",
        "organization": "Sunny Heart Limited",
        "address_1": "Rm. 1516, 15/F, Hewlett Center",
        "address_2": "Kwun Tong Kowloon    852",
        "country": "HK"
    },
    "D866C6": {
        "oui_hex": "D8-66-C6",
        "organization": "Shenzhen Daystar Technology Co.,ltd",
        "address_1": "The 5th Floor,#4 Building, Minxing Industria Zone",
        "address_2": "Shenzhen  Guangdong  518131",
        "country": "CN"
    },
    "D00EA4": {
        "oui_hex": "D0-0E-A4",
        "organization": "Porsche Cars North America",
        "address_1": "980 Hammond Drive",
        "address_2": "Atlanta  GA  30328",
        "country": "US"
    },
    "784B08": {
        "oui_hex": "78-4B-08",
        "organization": "f.robotics acquisitions ltd",
        "address_1": "Yevulim, Industrial Zone",
        "address_2": "Pardesia  Hasharon  42815",
        "country": "IL"
    },
    "84E4D9": {
        "oui_hex": "84-E4-D9",
        "organization": "Shenzhen NEED technology Ltd.",
        "address_1": "Room 581 ,Jinda technology center,No.8, Kefeng road,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "40BC73": {
        "oui_hex": "40-BC-73",
        "organization": "Cronoplast  S.L.",
        "address_1": "Pol.Ind.S.Ermengol II -",
        "address_2": "ABRERA  BARCELONA  08630",
        "country": "ES"
    },
    "4007C0": {
        "oui_hex": "40-07-C0",
        "organization": "Railtec Systems GmbH",
        "address_1": "Sonnenbergstr. 19",
        "address_2": "Hergiswil  Nidwalden  6052",
        "country": "CH"
    },
    "A4D3B5": {
        "oui_hex": "A4-D3-B5",
        "organization": "GLITEL Stropkov, s.r.o.",
        "address_1": "Cintorinska 557/73",
        "address_2": "Stropkov    09101",
        "country": "SK"
    },
    "D43A65": {
        "oui_hex": "D4-3A-65",
        "organization": "IGRS Engineering Lab Ltd.",
        "address_1": "8F,Taipeng Mansion",
        "address_2": "Haidian District  Beijing  10000",
        "country": "CN"
    },
    "F499AC": {
        "oui_hex": "F4-99-AC",
        "organization": "WEBER Schraubautomaten GmbH",
        "address_1": "Hans-Urmiller-Ring 56",
        "address_2": "Wolfratshausen  Bayern  82515",
        "country": "DE"
    },
    "D05099": {
        "oui_hex": "D0-50-99",
        "organization": "ASRock Incorporation",
        "address_1": "2F., No.37, Sec. 2, Jhongyang S. Rd.",
        "address_2": "Taipei    112",
        "country": "US"
    },
    "A49EDB": {
        "oui_hex": "A4-9E-DB",
        "organization": "AutoCrib, Inc.",
        "address_1": "3011 S. Croddy Way",
        "address_2": "Santa Ana  CA  92704",
        "country": "US"
    },
    "1C76CA": {
        "oui_hex": "1C-76-CA",
        "organization": "Terasic Technologies Inc.",
        "address_1": "9F., No.176, Sec.2, Gongdao 5th Rd",
        "address_2": "Hsinchu City    30070",
        "country": "TW"
    },
    "888964": {
        "oui_hex": "88-89-64",
        "organization": "GSI Electronics Inc.",
        "address_1": "5200 Armand-Frappier",
        "address_2": "St-Hubert  Quebec  J3Z 1G5",
        "country": "CA"
    },
    "7CD844": {
        "oui_hex": "7C-D8-44",
        "organization": "Enmotus Inc",
        "address_1": "65 Enterprise",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "44619C": {
        "oui_hex": "44-61-9C",
        "organization": "FONsystem co. ltd.",
        "address_1": "3F annex of Venture support center",
        "address_2": "  GwangJu  500-706",
        "country": "KR"
    },
    "70820E": {
        "oui_hex": "70-82-0E",
        "organization": "as electronics GmbH",
        "address_1": "Kantstraße 10",
        "address_2": "Großbettlingen  Baden -Württemberg  72663",
        "country": "DE"
    },
    "0C1105": {
        "oui_hex": "0C-11-05",
        "organization": "AKUVOX (XIAMEN) NETWORKS CO., LTD",
        "address_1": "Suite 201-15, 31 WangHai Rd",
        "address_2": "Xiamen  Fujian  361008",
        "country": "CN"
    },
    "5C22C4": {
        "oui_hex": "5C-22-C4",
        "organization": "DAE EUN ELETRONICS CO., LTD",
        "address_1": "1029 Hokye-Dong, Dongan-Goo",
        "address_2": "Anyang-Shi  Kyongki-Do  431-080",
        "country": "KR"
    },
    "F8FEA8": {
        "oui_hex": "F8-FE-A8",
        "organization": "Technico Japan Corporation",
        "address_1": "AM Building 9F, 2-5-3,",
        "address_2": "Tokyo    160-0022",
        "country": "JP"
    },
    "1800DB": {
        "oui_hex": "18-00-DB",
        "organization": "Fitbit Inc.",
        "address_1": "150 Spear St Ste 200",
        "address_2": "San Francisco  CA  94105",
        "country": "US"
    },
    "78A106": {
        "oui_hex": "78-A1-06",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "6C6126": {
        "oui_hex": "6C-61-26",
        "organization": "Rinicom Holdings",
        "address_1": "Riverway House",
        "address_2": "Lancaster  Lancashire  LA1 2RX",
        "country": "GB"
    },
    "88685C": {
        "oui_hex": "88-68-5C",
        "organization": "Shenzhen ChuangDao & Perpetual Eternal Technology Co.,Ltd",
        "address_1": "Area c,2/F,Building 1, BaoAn foreign trade industrial zone",
        "address_2": "BaoAn District, Shenzhen  Guangdong province  518100",
        "country": "CN"
    },
    "102831": {
        "oui_hex": "10-28-31",
        "organization": "Morion Inc.",
        "address_1": "Shosse Kosmonavtov, 111",
        "address_2": "Perm  Permsky Krai  614990",
        "country": "US"
    },
    "EC2C49": {
        "oui_hex": "EC-2C-49",
        "organization": "University of Tokyo",
        "address_1": "4-6-1 Komaba",
        "address_2": "Meguro-ku  Tokyo  153-8904",
        "country": "US"
    },
    "D82916": {
        "oui_hex": "D8-29-16",
        "organization": "Ascent Communication Technology",
        "address_1": "13/F., Shum Tower",
        "address_2": " Hong Kong    9999",
        "country": "HK"
    },
    "2CF203": {
        "oui_hex": "2C-F2-03",
        "organization": "EMKO ELEKTRONIK SAN VE TIC AS",
        "address_1": "DOSAB, KARANFIL SOK, NO:6",
        "address_2": "  BURSA  16369",
        "country": "TR"
    },
    "B4FE8C": {
        "oui_hex": "B4-FE-8C",
        "organization": "Centro Sicurezza Italia SpA",
        "address_1": "Via Venaria 28-30",
        "address_2": "Alpignano  Torino  10091",
        "country": "IT"
    },
    "40E730": {
        "oui_hex": "40-E7-30",
        "organization": "DEY Storage Systems, Inc.",
        "address_1": "215 South B Street",
        "address_2": "San Mateo  CA  94401",
        "country": "US"
    },
    "68B094": {
        "oui_hex": "68-B0-94",
        "organization": "INESA ELECTRON CO.,LTD",
        "address_1": "5F, NO.168, Tianlin Road",
        "address_2": "  Shanghai  200233",
        "country": "CN"
    },
    "A073FC": {
        "oui_hex": "A0-73-FC",
        "organization": "Rancore Technologies Private Limited",
        "address_1": "5th Floor, Court House",
        "address_2": "Dhobi Talao  Maharashtra  400 002",
        "country": "IN"
    },
    "44F849": {
        "oui_hex": "44-F8-49",
        "organization": "Union Pacific Railroad",
        "address_1": "1400 Douglas St. STOP 0610",
        "address_2": "Omaha  NE  68179",
        "country": "US"
    },
    "CC0DEC": {
        "oui_hex": "CC-0D-EC",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "1C37BF": {
        "oui_hex": "1C-37-BF",
        "organization": "Cloudium Systems Ltd.",
        "address_1": "Hartnett Centre",
        "address_2": "Limerick    00",
        "country": "IE"
    },
    "50ABBF": {
        "oui_hex": "50-AB-BF",
        "organization": "Hoseo Telecom",
        "address_1": "701 ACE Techno Tower 684-1",
        "address_2": "Seoul    157-721",
        "country": "KR"
    },
    "0C722C": {
        "oui_hex": "0C-72-2C",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "9CE635": {
        "oui_hex": "9C-E6-35",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "60A44C": {
        "oui_hex": "60-A4-4C",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "185AE8": {
        "oui_hex": "18-5A-E8",
        "organization": "Zenotech.Co.,Ltd",
        "address_1": "E-503, BundangTechno Park, Yatap-dong",
        "address_2": "Seongnam    463-760",
        "country": "KR"
    },
    "C47DCC": {
        "oui_hex": "C4-7D-CC",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "E0AEED": {
        "oui_hex": "E0-AE-ED",
        "organization": "LOENK",
        "address_1": "F9, Cheongdam Venture Plaza",
        "address_2": "  SEOUL  135-951",
        "country": "KR"
    },
    "E492E7": {
        "oui_hex": "E4-92-E7",
        "organization": "Gridlink Tech. Co.,Ltd.",
        "address_1": "Room No. 619, No. 108 Jiang Bin Dong Road",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "CC047C": {
        "oui_hex": "CC-04-7C",
        "organization": "G-WAY Microwave",
        "address_1": "38 Leuning Street",
        "address_2": "South Hackensack  New Jersey  07078",
        "country": "US"
    },
    "64535D": {
        "oui_hex": "64-53-5D",
        "organization": "Frauscher Sensortechnik",
        "address_1": "Gewerbestraße 1",
        "address_2": "St. Marienkirchen  Upper Austria  4774",
        "country": "US"
    },
    "3C6FF7": {
        "oui_hex": "3C-6F-F7",
        "organization": "EnTek Systems, Inc.",
        "address_1": "562 Starlight Dr.",
        "address_2": "Sautee Nacoochee  GA  30571",
        "country": "US"
    },
    "2C7B5A": {
        "oui_hex": "2C-7B-5A",
        "organization": "Milper Ltd",
        "address_1": "32 Shaham St.",
        "address_2": "Petach Tikva    49250",
        "country": "IL"
    },
    "D4BF2D": {
        "oui_hex": "D4-BF-2D",
        "organization": "SE Controls Asia Pacific Ltd",
        "address_1": "Unit 301, 3/F, Hung To Centre,",
        "address_2": "Kwun Tong  Kowloon",
        "country": "HK"
    },
    "E0D9A2": {
        "oui_hex": "E0-D9-A2",
        "organization": "Hippih aps",
        "address_1": "Sceince Park Scion",
        "address_2": "Lyngby    2800",
        "country": "DK"
    },
    "FC0647": {
        "oui_hex": "FC-06-47",
        "organization": "Cortland Research, LLC",
        "address_1": "12 S Main St., Ste 207",
        "address_2": "Homer  NY  13077",
        "country": "US"
    },
    "6CD146": {
        "oui_hex": "6C-D1-46",
        "organization": "FRAMOS GmbH",
        "address_1": "Mehlbeerenstr. 2",
        "address_2": "Taufkirchen    82024",
        "country": "DE"
    },
    "54E032": {
        "oui_hex": "54-E0-32",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "5461EA": {
        "oui_hex": "54-61-EA",
        "organization": "Zaplox AB",
        "address_1": "Scheelev",
        "address_2": "Lund  Sk  22370",
        "country": "SE"
    },
    "D08B7E": {
        "oui_hex": "D0-8B-7E",
        "organization": "Passif Semiconductor",
        "address_1": "400 S. El Camino Real Suite 250",
        "address_2": "San Mateo  California  94402",
        "country": "US"
    },
    "04586F": {
        "oui_hex": "04-58-6F",
        "organization": "Sichuan Whayer information industry Co.,LTD",
        "address_1": "Layer 16,Building 10, C Area",
        "address_2": "Chengdu City    610041",
        "country": "CN"
    },
    "FC9FAE": {
        "oui_hex": "FC-9F-AE",
        "organization": "Fidus Systems Inc",
        "address_1": "35 Fitzgerald Road",
        "address_2": "Ottawa  Ontario  K2H 1E6",
        "country": "CA"
    },
    "681E8B": {
        "oui_hex": "68-1E-8B",
        "organization": "InfoSight Corporation",
        "address_1": "20700 US Hwy 23",
        "address_2": "Chillicothe  Ohio  45601",
        "country": "US"
    },
    "D052A8": {
        "oui_hex": "D0-52-A8",
        "organization": "Physical Graph Corporation",
        "address_1": "11654 Plaza America Drive",
        "address_2": "Reston  VA  20190",
        "country": "US"
    },
    "CC3A61": {
        "oui_hex": "CC-3A-61",
        "organization": "SAMSUNG ELECTRO MECHANICS CO., LTD.",
        "address_1": "314, Maetan3-Dong, Yeongtong-Gu",
        "address_2": "Suwon  Gyunggi-Do  443-743",
        "country": "US"
    },
    "F8D7BF": {
        "oui_hex": "F8-D7-BF",
        "organization": "REV Ritter GmbH",
        "address_1": "Frankenstra",
        "address_2": "M  Bavaria  63776",
        "country": "DE"
    },
    "48BE2D": {
        "oui_hex": "48-BE-2D",
        "organization": "Symanitron",
        "address_1": "Ap.103, 17 Rudnevka str.,111674",
        "address_2": "  Moscow",
        "country": "RU"
    },
    "F02329": {
        "oui_hex": "F0-23-29",
        "organization": "SHOWA DENKI CO.,LTD.",
        "address_1": "1-25",
        "address_2": "Daito-city  Osaka  574-0052",
        "country": "JP"
    },
    "F073AE": {
        "oui_hex": "F0-73-AE",
        "organization": "PEAK-System Technik",
        "address_1": "Otto-Roehm-Str 69",
        "address_2": "Darmstadt  Hessen  64293",
        "country": "DE"
    },
    "48B8DE": {
        "oui_hex": "48-B8-DE",
        "organization": "HOMEWINS TECHNOLOGY CO.,LTD.",
        "address_1": "10F-1, NO. 122, QIAOHE RD.,",
        "address_2": "NEW TAIPEI CITY,    235",
        "country": "TW"
    },
    "10EA59": {
        "oui_hex": "10-EA-59",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "0C191F": {
        "oui_hex": "0C-19-1F",
        "organization": "Inform Electronik",
        "address_1": "Emek mah.Ordu cad.No-49-51-53",
        "address_2": "Sarigazi-Sancaktepe  Istanbul  34785",
        "country": "US"
    },
    "495153": {
        "oui_hex": "49-51-53",
        "organization": "Emek mah.Ordu cad.No-49-51-53",
        "address_1": "US",
        "address_2": "",
        "country": ""
    },
    "1065CF": {
        "oui_hex": "10-65-CF",
        "organization": "IQSIM",
        "address_1": "2000 Route des Lucioles",
        "address_2": "BIOT    06410",
        "country": "FR"
    },
    "684CA8": {
        "oui_hex": "68-4C-A8",
        "organization": "Shenzhen Herotel Tech. Co., Ltd.",
        "address_1": "Room W1402, West Tower, No.10128, Shennan Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "98208E": {
        "oui_hex": "98-20-8E",
        "organization": "Definium Technologies",
        "address_1": "34 Fairthorne Road",
        "address_2": "Launceston  Tasmania  7250",
        "country": "AU"
    },
    "704AE4": {
        "oui_hex": "70-4A-E4",
        "organization": "Rinstrum Pty Ltd",
        "address_1": "41 Success St",
        "address_2": "Acacia Ridge  QLD  4110",
        "country": "AU"
    },
    "083AB8": {
        "oui_hex": "08-3A-B8",
        "organization": "Shinoda Plasma Co., Ltd.",
        "address_1": "4-6-7, Minatojima Minamimachi, Chuo-ku",
        "address_2": "Kobe  Hyogo  6500047",
        "country": "JP"
    },
    "A0DD97": {
        "oui_hex": "A0-DD-97",
        "organization": "PolarLink Technologies, Ltd",
        "address_1": "6FL 352, Zhonghua 1st Rd. Kaohsiung 804 Taiwan",
        "address_2": "Kaohsiung  Taiwan  804",
        "country": "TW"
    },
    "EC89F5": {
        "oui_hex": "EC-89-F5",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,Torch Hi-tech Industry Development Zone,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "US"
    },
    "B49842": {
        "oui_hex": "B4-98-42",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "7054D2": {
        "oui_hex": "70-54-D2",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "645A04": {
        "oui_hex": "64-5A-04",
        "organization": "Chicony Electronics Co., Ltd.",
        "address_1": "No.25, Wugong 6th Rd., Wugu Dist.,",
        "address_2": "New Taipei City 248,  TAIWAN, REPUBLIC OF CHINA  248",
        "country": "TW"
    },
    "AC1702": {
        "oui_hex": "AC-17-02",
        "organization": "Fibar Group sp. z o.o.",
        "address_1": "ul. Lotnicza 1",
        "address_2": "Poznan    60-421",
        "country": "PL"
    },
    "984CD3": {
        "oui_hex": "98-4C-D3",
        "organization": "Mantis Deposition",
        "address_1": "2 Goodson Industrial Mews",
        "address_2": "Thame  Oxfordshire  OX9 3BX",
        "country": "GB"
    },
    "08606E": {
        "oui_hex": "08-60-6E",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "3C57D5": {
        "oui_hex": "3C-57-D5",
        "organization": "FiveCo",
        "address_1": "Ch. de la Rueyre 116",
        "address_2": "Renens  VD  1020",
        "country": "US"
    },
    "F84897": {
        "oui_hex": "F8-48-97",
        "organization": "Hitachi, Ltd.",
        "address_1": "27-18, Minami Oi 6-chome, Shinagawa-ku",
        "address_2": "Tokyo    140-8572",
        "country": "JP"
    },
    "F80BD0": {
        "oui_hex": "F8-0B-D0",
        "organization": "Datang Telecom communication terminal (Tianjin) Co., Ltd.",
        "address_1": "Garden East Roadon the 15th,",
        "address_2": "Haidian District  Beijing  100191",
        "country": "CN"
    },
    "E89AFF": {
        "oui_hex": "E8-9A-FF",
        "organization": "Fujian LANDI Commercial Equipment Co.,Ltd",
        "address_1": "Building 17,the 1st Section ,Fuzhou Software Park",
        "address_2": "No.89 Software Road   Fuzhou ,Fujian  350003",
        "country": "CN"
    },
    "0C8CDC": {
        "oui_hex": "0C-8C-DC",
        "organization": "Suunto Oy",
        "address_1": "Valimotie 7",
        "address_2": "Vantaa  Uusimaa  02710",
        "country": "FI"
    },
    "60C5A8": {
        "oui_hex": "60-C5-A8",
        "organization": "Beijing LT Honway Technology Co.,Ltd",
        "address_1": "Room 1703,A1 Tower, Changyuan Tiandi, No.18,Suzhou Street",
        "address_2": "beijing  beijing  100086",
        "country": "CN"
    },
    "28D244": {
        "oui_hex": "28-D2-44",
        "organization": "LCFC(HeFei) Electronics Technology Co., Ltd.",
        "address_1": "6 Cui Wei Road",
        "address_2": "Hefei  Anhui  230000",
        "country": "CN"
    },
    "B4DF3B": {
        "oui_hex": "B4-DF-3B",
        "organization": "Chromlech",
        "address_1": "19 av. Gabriel Faure",
        "address_2": "THORIGNE FOUILLARD    35235",
        "country": "FR"
    },
    "7C9A9B": {
        "oui_hex": "7C-9A-9B",
        "organization": "VSE valencia smart energy",
        "address_1": "Sir Alexander Fleming n",
        "address_2": "Paterna  Valencia  46980",
        "country": "ES"
    },
    "84E714": {
        "oui_hex": "84-E7-14",
        "organization": "Liang Herng Enterprise,Co.Ltd.",
        "address_1": "1FL,No.27,KweiYang Street,Sanchung District,New Taipei City,Taiwan,R.O.C.",
        "address_2": "New Taipei City    241",
        "country": "TW"
    },
    "B829F7": {
        "oui_hex": "B8-29-F7",
        "organization": "Blaster Tech",
        "address_1": "13337 South Street",
        "address_2": "Cerritos  CA  90703",
        "country": "US"
    },
    "E4A7FD": {
        "oui_hex": "E4-A7-FD",
        "organization": "Cellco Partnership",
        "address_1": "One Verizon Way",
        "address_2": "Baskin Ridge  New Jersey  07920",
        "country": "US"
    },
    "2CE2A8": {
        "oui_hex": "2C-E2-A8",
        "organization": "DeviceDesign",
        "address_1": "Yeongtong-dong, Yeongtong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  443-813",
        "country": "KR"
    },
    "00B56D": {
        "oui_hex": "00-B5-6D",
        "organization": "David Electronics Co., LTD.",
        "address_1": "9F, -2, No. 188, Sec. 3, Ta-Tung Rd.,",
        "address_2": "New Taipei City,     22103",
        "country": "TW"
    },
    "2C3557": {
        "oui_hex": "2C-35-57",
        "organization": "ELLIY Power CO..Ltd",
        "address_1": "1-6-4, Osaki",
        "address_2": "Shinagawa-ku  TOKYO  141-0032",
        "country": "US"
    },
    "B80415": {
        "oui_hex": "B8-04-15",
        "organization": "Bayan Audio",
        "address_1": "5 The Pavilions",
        "address_2": "Pease Pottage  West Sussex  RH11 9BJ",
        "country": "GB"
    },
    "D4136F": {
        "oui_hex": "D4-13-6F",
        "organization": "Asia Pacific Brands",
        "address_1": "PO Box 113001",
        "address_2": "Auckland  Newmarket  1149",
        "country": "NZ"
    },
    "C8E1A7": {
        "oui_hex": "C8-E1-A7",
        "organization": "Vertu Corporation Limited",
        "address_1": "Beacon Hill Road",
        "address_2": "Church Crookham  Hampshire  GU52 8DY",
        "country": "GB"
    },
    "4CAB33": {
        "oui_hex": "4C-AB-33",
        "organization": "KST technology",
        "address_1": "Bangi-dong, songpa-gu",
        "address_2": "  Seoul  138-050",
        "country": "KR"
    },
    "F4472A": {
        "oui_hex": "F4-47-2A",
        "organization": "Nanjing Rousing Sci. and Tech. Industrial Co., Ltd",
        "address_1": "A630,F6,NO.58 Nanhu Road,Jianye District",
        "address_2": "Nanjing  Jiangsu  210017",
        "country": "CN"
    },
    "DC028E": {
        "oui_hex": "DC-02-8E",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A845E9": {
        "oui_hex": "A8-45-E9",
        "organization": "Firich Enterprises CO., LTD.",
        "address_1": "10F., No. 75, Sec. 1, Xintai 5th Rd., Xizhi Dist.",
        "address_2": "New Taipei City  Taiwan (R.O.C.)  886",
        "country": "TW"
    },
    "485261": {
        "oui_hex": "48-52-61",
        "organization": "SOREEL",
        "address_1": "18 Rue de la Gâtine",
        "address_2": "CHOLET  FRANCE  49304",
        "country": "FR"
    },
    "646223": {
        "oui_hex": "64-62-23",
        "organization": "Cellient Co., Ltd.",
        "address_1": "6F Glass Tower, 366-4 Yatap-dong Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-827",
        "country": "KR"
    },
    "98473C": {
        "oui_hex": "98-47-3C",
        "organization": "SHANGHAI SUNMON COMMUNICATION TECHNOGY CO.,LTD",
        "address_1": "Suite 604-605,Xing Yuan Technology Plaza 418 Gui Ping Road  ShangHAI",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "5481AD": {
        "oui_hex": "54-81-AD",
        "organization": "Eagle Research Corporation",
        "address_1": "4237 State Route 34",
        "address_2": "Hurricane  West Virginia  25526",
        "country": "US"
    },
    "54A04F": {
        "oui_hex": "54-A0-4F",
        "organization": "t-mac Technologies Ltd",
        "address_1": "Stand Park",
        "address_2": "Chesterfield  Derbyshire  S41 8JT",
        "country": "GB"
    },
    "14DB85": {
        "oui_hex": "14-DB-85",
        "organization": "S NET MEDIA",
        "address_1": "4F, SEHYUN BLDG, 1581-7",
        "address_2": "SEOUL    137-875",
        "country": "KR"
    },
    "B8DAF1": {
        "oui_hex": "B8-DA-F1",
        "organization": "Strahlenschutz- Entwicklungs- und Ausruestungsgesellschaft mbH",
        "address_1": "Ostdamm 139",
        "address_2": "Duelmen  NRW  48249",
        "country": "DE"
    },
    "D45C70": {
        "oui_hex": "D4-5C-70",
        "organization": "Wi-Fi Alliance",
        "address_1": "10900-B Stonelake Boulevard",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "EC473C": {
        "oui_hex": "EC-47-3C",
        "organization": "Redwire, LLC",
        "address_1": "8 Thorndike St",
        "address_2": "Everett  MA  02149",
        "country": "US"
    },
    "3CC12C": {
        "oui_hex": "3C-C1-2C",
        "organization": "AES Corporation",
        "address_1": "285 Newbury St",
        "address_2": "Peabody  MA  01960",
        "country": "US"
    },
    "949BFD": {
        "oui_hex": "94-9B-FD",
        "organization": "Trans New Technology, Inc.",
        "address_1": "KY Bldg. 8F, 5-14-4 Nishinippori",
        "address_2": "Arakawa  Tokyo  116-0013",
        "country": "JP"
    },
    "A00ABF": {
        "oui_hex": "A0-0A-BF",
        "organization": "Wieson Technologies Co., Ltd.",
        "address_1": "7F, No. 276, Sec. 1, Datong Rd",
        "address_2": "New Taipei City    221",
        "country": "TW"
    },
    "8CCDE8": {
        "oui_hex": "8C-CD-E8",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "7CB232": {
        "oui_hex": "7C-B2-32",
        "organization": "Hui Zhou Gaoshengda Technology Co.,LTD",
        "address_1": "No.75,Zhongkai High-Tech Development District,Huizhou",
        "address_2": "Hui Zhou  Guangdong  516006",
        "country": "CN"
    },
    "00E666": {
        "oui_hex": "00-E6-66",
        "organization": "ARIMA Communications Corp.",
        "address_1": "6F.,No.866,Zhongzheng Rd.,Zhonghe Dist.,",
        "address_2": "New Taipei City  Taiwan  23586",
        "country": "TW"
    },
    "34BDFA": {
        "oui_hex": "34-BD-FA",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "F41E26": {
        "oui_hex": "F4-1E-26",
        "organization": "Simon-Kaloi Engineering",
        "address_1": "31192 La Baya Drive Unit G",
        "address_2": "Westlake Village  CA  91362",
        "country": "US"
    },
    "702526": {
        "oui_hex": "70-25-26",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "18D949": {
        "oui_hex": "18-D9-49",
        "organization": "Qvis Labs, LLC",
        "address_1": "3204 Rustic River Cove",
        "address_2": "Austin  TX  78746-2001",
        "country": "US"
    },
    "D808F5": {
        "oui_hex": "D8-08-F5",
        "organization": "Arcadia Networks Co. Ltd.",
        "address_1": "Cheung Sha Wan 5-B FL",
        "address_2": "Kowloon    0633",
        "country": "HK"
    },
    "0CC47E": {
        "oui_hex": "0C-C4-7E",
        "organization": "EUCAST Co., Ltd.",
        "address_1": "Room 303, 1018-2 Unjung-dong, Bundang-Gu",
        "address_2": "Seongnam-si  Kyunggi-do  463-440",
        "country": "KR"
    },
    "50724D": {
        "oui_hex": "50-72-4D",
        "organization": "BEG Brueck Electronic GmbH",
        "address_1": "Schlosserstraße 30",
        "address_2": "Lindlar  Nordrhein-Westfalen  51789",
        "country": "DE"
    },
    "783CE3": {
        "oui_hex": "78-3C-E3",
        "organization": "Kai-EE",
        "address_1": "3F.-12, No.79, Sec. 1, Xintai 5th Rd.,",
        "address_2": " New Taipei City    22101",
        "country": "TW"
    },
    "B898B0": {
        "oui_hex": "B8-98-B0",
        "organization": "Atlona Inc.",
        "address_1": "70 Daggett Dr.",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "24694A": {
        "oui_hex": "24-69-4A",
        "organization": "Jasmine Systems Inc.",
        "address_1": "50 Charles Lindbergh Blvd. Suite 411",
        "address_2": "Uniondale  NY  11553",
        "country": "US"
    },
    "080C0B": {
        "oui_hex": "08-0C-0B",
        "organization": "SysMik GmbH Dresden",
        "address_1": "Bertolt-Brecht-Allee 24",
        "address_2": "Dresden    01309",
        "country": "DE"
    },
    "DCBF90": {
        "oui_hex": "DC-BF-90",
        "organization": "HUIZHOU QIAOXING TELECOMMUNICATION INDUSTRY CO.,LTD.",
        "address_1": "Qiaoxing Science Technological&Industrial Zone Tangquan",
        "address_2": "Huizhou  Guangdong  516023",
        "country": "CN"
    },
    "049F06": {
        "oui_hex": "04-9F-06",
        "organization": "Smobile Co., Ltd.",
        "address_1": "T-1009, Poongrim i-won Plus, 255-1",
        "address_2": "Seohyeon-dong, Bundang-gu  Seongnam-si, Gyeonggi-do  463-862",
        "country": "KR"
    },
    "289A4B": {
        "oui_hex": "28-9A-4B",
        "organization": "SteelSeries ApS",
        "address_1": "656 West Randolph, Suite 2E",
        "address_2": "Chicago  IL  60661",
        "country": "US"
    },
    "A08C15": {
        "oui_hex": "A0-8C-15",
        "organization": "Gerhard D. Wempe KG",
        "address_1": "Steinstrasse 23",
        "address_2": "  Hamburg  20095",
        "country": "DE"
    },
    "90CF6F": {
        "oui_hex": "90-CF-6F",
        "organization": "Dlogixs Co Ltd",
        "address_1": "DLogixs Bldg, #351-1, Anyang-Dong",
        "address_2": "Anyang-si  Gyeonggi-do  430-010",
        "country": "KR"
    },
    "C8FB26": {
        "oui_hex": "C8-FB-26",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "B85810": {
        "oui_hex": "B8-58-10",
        "organization": "NUMERA, INC.",
        "address_1": "1511 3RD AVE",
        "address_2": "SEATTLE  WA  98101",
        "country": "US"
    },
    "ECD950": {
        "oui_hex": "EC-D9-50",
        "organization": "IRT SA",
        "address_1": "Puits-Godet 16",
        "address_2": "NEUCHATEL  NE  2000",
        "country": "CH"
    },
    "7C02BC": {
        "oui_hex": "7C-02-BC",
        "organization": "Hansung Electronics Co. LTD",
        "address_1": "319, Bong san-ri, San dong-myun",
        "address_2": "Gumi    730-853",
        "country": "KR"
    },
    "B82410": {
        "oui_hex": "B8-24-10",
        "organization": "Magneti Marelli Slovakia s.r.o.",
        "address_1": "Industrial Park Kechnec",
        "address_2": "Kechnec    04458",
        "country": "SK"
    },
    "105F49": {
        "oui_hex": "10-5F-49",
        "organization": "Cisco SPVTG",
        "address_1": "5030 Sugarloaf Parkway",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "1C5C60": {
        "oui_hex": "1C-5C-60",
        "organization": "Shenzhen Belzon Technology Co.,LTD.",
        "address_1": "5F Block 1,Zhongxin Building,Chuangye Rd",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "B8B94E": {
        "oui_hex": "B8-B9-4E",
        "organization": "Shenzhen iBaby Labs, Inc.",
        "address_1": "Room 218, Building 17,Shangsha Innovation Science and Technology Park,Futian District",
        "address_2": "Shenzhen  Guangdong  518047",
        "country": "CN"
    },
    "ACC698": {
        "oui_hex": "AC-C6-98",
        "organization": "Kohzu Precision Co., Ltd.",
        "address_1": "2-6-15, Kurigi, Asao-ku",
        "address_2": "Kawasaki-shi  Kanagawa  215-8521",
        "country": "JP"
    },
    "7C386C": {
        "oui_hex": "7C-38-6C",
        "organization": "Real Time Logic",
        "address_1": "12515 Academy Ridge View",
        "address_2": "Colorado Springs  Colorado  80921",
        "country": "US"
    },
    "2067B1": {
        "oui_hex": "20-67-B1",
        "organization": "Pluto inc.",
        "address_1": "Hongo5-21-1-303",
        "address_2": "Bunkyo-ku  Tokyo  113-0033",
        "country": "JP"
    },
    "189A67": {
        "oui_hex": "18-9A-67",
        "organization": "CSE-Servelec Limited",
        "address_1": "Rotherside Road",
        "address_2": "Sheffield    S21 4HL",
        "country": "GB"
    },
    "087D21": {
        "oui_hex": "08-7D-21",
        "organization": "Altasec technology corporation",
        "address_1": "9F-1, No.75, Sec.1, Xintai 5th Rd.,",
        "address_2": "New Taipei City  Taiwan  221",
        "country": "TW"
    },
    "F8051C": {
        "oui_hex": "F8-05-1C",
        "organization": "DRS Imaging and Targeting Solutions",
        "address_1": "100 N Babcock St",
        "address_2": "Melbourne  FL  32935",
        "country": "US"
    },
    "78D34F": {
        "oui_hex": "78-D3-4F",
        "organization": "Pace-O-Matic, Inc.",
        "address_1": "4150 Blue Ridge Industrial Parkway",
        "address_2": "Norcross  GA  30071",
        "country": "US"
    },
    "A4466B": {
        "oui_hex": "A4-46-6B",
        "organization": "EOC Technology",
        "address_1": "#1601 Acro Palace, 1594 Gwanyang-dong, Dongan-gu",
        "address_2": "Anyang-si  Gyeonggi-do  431-060",
        "country": "KR"
    },
    "901EDD": {
        "oui_hex": "90-1E-DD",
        "organization": "GREAT COMPUTER CORPORATION",
        "address_1": "4F., No.236, Fude 2nd Rd., Xizhi Dist.,",
        "address_2": "New Taipei City    22151",
        "country": "TW"
    },
    "34D7B4": {
        "oui_hex": "34-D7-B4",
        "organization": "Tributary Systems, Inc.",
        "address_1": "3717 Commerce Place",
        "address_2": "Bedford  Texas  76021",
        "country": "US"
    },
    "F40F9B": {
        "oui_hex": "F4-0F-9B",
        "organization": "WAVELINK",
        "address_1": "#701, Dongyoung Venture'stel 3rd, 202-4,",
        "address_2": "Anyang-si  Kyungki-do  430-817",
        "country": "KR"
    },
    "645FFF": {
        "oui_hex": "64-5F-FF",
        "organization": "Nicolet Neuro",
        "address_1": "1850 Deming Way",
        "address_2": "Middleton  WI  53562",
        "country": "US"
    },
    "AC7A42": {
        "oui_hex": "AC-7A-42",
        "organization": "iConnectivity",
        "address_1": "#21, 1725 30th Ave NE",
        "address_2": "Calgary  Alberta  T2E 7P6",
        "country": "CA"
    },
    "700BC0": {
        "oui_hex": "70-0B-C0",
        "organization": "Dewav Technology Company",
        "address_1": "Room 1408, Real Estate Mansion",
        "address_2": "  Shangahi  200120",
        "country": "CN"
    },
    "CC14A6": {
        "oui_hex": "CC-14-A6",
        "organization": "Yichun MyEnergy Domain, Inc",
        "address_1": "349W. Yuanshan Rd, Yichun",
        "address_2": "Yichun  Jiangxi  336000",
        "country": "CN"
    },
    "109FA9": {
        "oui_hex": "10-9F-A9",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "C0A364": {
        "oui_hex": "C0-A3-64",
        "organization": "3D Systems Massachusetts",
        "address_1": "19 Connector Road",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "1C5FFF": {
        "oui_hex": "1C-5F-FF",
        "organization": "Beijing Ereneben Information Technology Co.,Ltd Shenzhen Branch",
        "address_1": "Room 14A, Building A, Honglong Central Plaza, No.3001,Heping Road, Luohu District, Shenzhen City",
        "address_2": "Shenzhen  Guangdong  518001",
        "country": "CN"
    },
    "6045BD": {
        "oui_hex": "60-45-BD",
        "organization": "Microsoft",
        "address_1": "1 Microsoft Way",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "241064": {
        "oui_hex": "24-10-64",
        "organization": "Shenzhen Ecsino Tecnical Co. Ltd",
        "address_1": "7F Guoxin build ChangXin Road. Nan'shan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "7CEBEA": {
        "oui_hex": "7C-EB-EA",
        "organization": "ASCT",
        "address_1": "4F., No.49, Wu-Gong 6th Rd. Wu-Gu Industrial Park,",
        "address_2": "New Taipei City    248",
        "country": "TW"
    },
    "9C0DAC": {
        "oui_hex": "9C-0D-AC",
        "organization": "Tymphany HK Limited",
        "address_1": "RM 1307-8",
        "address_2": "43-59, Queen's Road East  Wanchai",
        "country": "HK"
    },
    "70B599": {
        "oui_hex": "70-B5-99",
        "organization": "Embedded Technologies s.r.o.",
        "address_1": "Doubravice 134",
        "address_2": "Turnov    51101",
        "country": "CZ"
    },
    "EC4C4D": {
        "oui_hex": "EC-4C-4D",
        "organization": "ZAO NPK RoTeK",
        "address_1": "Bild. 119-1, Prospekt Mira",
        "address_2": "Moscow  Moscow  129223",
        "country": "RU"
    },
    "A4D18F": {
        "oui_hex": "A4-D1-8F",
        "organization": "Shenzhen Skyee Optical Fiber Communication Technology Ltd.",
        "address_1": "No.5 Bldg. Yimin Industrial Park, No.31, Makan South Road, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "58343B": {
        "oui_hex": "58-34-3B",
        "organization": "Glovast Technology Ltd.",
        "address_1": "6F., No.23, JianKang Rd., SongShan Dist.,",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "889676": {
        "oui_hex": "88-96-76",
        "organization": "TTC MARCONI s.r.o.",
        "address_1": "Trebohosticka s.r.o.",
        "address_2": "Praha    10000",
        "country": "CZ"
    },
    "5C1737": {
        "oui_hex": "5C-17-37",
        "organization": "I-View Now, LLC.",
        "address_1": "1421 E. Sunset",
        "address_2": "Las Vegas  NV  89119",
        "country": "US"
    },
    "AC0A61": {
        "oui_hex": "AC-0A-61",
        "organization": "Labor S.r.L.",
        "address_1": "Via della Scrofa 117",
        "address_2": "  Rome  00186",
        "country": "IT"
    },
    "1C43EC": {
        "oui_hex": "1C-43-EC",
        "organization": "JAPAN CIRCUIT CO.,LTD",
        "address_1": "NKF-Kawasaki-Building 7F",
        "address_2": "Kawasaki  Kanagawa  2100005",
        "country": "JP"
    },
    "54D1B0": {
        "oui_hex": "54-D1-B0",
        "organization": "Universal Laser Systems, Inc",
        "address_1": "16008 N 81st street",
        "address_2": "scottsdale  az  85260",
        "country": "US"
    },
    "785262": {
        "oui_hex": "78-52-62",
        "organization": "Shenzhen Hojy Software Co., Ltd.",
        "address_1": "3F,East of Building25,Keyuanxi,Number 5,Kezhixi Road, Science & Industry Park ,Nan Shan District ,Shenzhen",
        "address_2": "ShenZhen  GuangDong  508057",
        "country": "CN"
    },
    "746A89": {
        "oui_hex": "74-6A-89",
        "organization": "Rezolt Corporation",
        "address_1": "2855 Bowers Avenue",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "702F4B": {
        "oui_hex": "70-2F-4B",
        "organization": "PolyVision Inc.",
        "address_1": "3970 Johns Creek Ct.",
        "address_2": "Suwanee  Georgia  30024",
        "country": "US"
    },
    "741489": {
        "oui_hex": "74-14-89",
        "organization": "SRT Wireless",
        "address_1": "4101 SW 47th Avenue #102",
        "address_2": "Davie  Florida  33314",
        "country": "US"
    },
    "241B13": {
        "oui_hex": "24-1B-13",
        "organization": "Shanghai Nutshell Electronic Co., Ltd.",
        "address_1": "365 Guoshoujing RD.,Zhangjiang Hi-Tech Park, Pudong District",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "20014F": {
        "oui_hex": "20-01-4F",
        "organization": "Linea Research Ltd",
        "address_1": "1 Marquis Business Centre",
        "address_2": "Baldock  Hertfordshire  SG7 6XL",
        "country": "GB"
    },
    "EC0ED6": {
        "oui_hex": "EC-0E-D6",
        "organization": "ITECH INSTRUMENTS SAS",
        "address_1": "3 Avenue de la Maranne",
        "address_2": "Châteauneuf-Les-Martigues    13220",
        "country": "FR"
    },
    "240917": {
        "oui_hex": "24-09-17",
        "organization": "Devlin Electronics Limited",
        "address_1": "Unit D1",
        "address_2": "Basingstoke  Hampshire  RG226HZ",
        "country": "GB"
    },
    "9C54CA": {
        "oui_hex": "9C-54-CA",
        "organization": "Zhengzhou VCOM Science and Technology Co.,Ltd",
        "address_1": "National 863 Software Park£¬No.6 Cuizhu Street, Hi-tech Indusry Developing Park",
        "address_2": "ZhengZhou City  Henan Province  450001",
        "country": "CN"
    },
    "B43564": {
        "oui_hex": "B4-35-64",
        "organization": "Fujian Tian Cheng Electron Science & Technical Development Co.,Ltd.",
        "address_1": "1801 unit,Tian an Cyber Times Tower A,Futian District",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "00BF15": {
        "oui_hex": "00-BF-15",
        "organization": "Genetec Inc.",
        "address_1": "2280 boul. Alfred-Nobel",
        "address_2": "St,. Laurent  Quebec  H4S 2A4",
        "country": "CA"
    },
    "38EE9D": {
        "oui_hex": "38-EE-9D",
        "organization": "Anedo Ltd.",
        "address_1": "Huelsmeyerstraße 35",
        "address_2": "Eydelstedt    49406",
        "country": "DE"
    },
    "78BEBD": {
        "oui_hex": "78-BE-BD",
        "organization": "STULZ GmbH",
        "address_1": "Holsteiner Chausse 283",
        "address_2": "  Hamburg  22457",
        "country": "DE"
    },
    "D4DF57": {
        "oui_hex": "D4-DF-57",
        "organization": "Alpinion Medical Systems",
        "address_1": "1F Verdi Tower 222-22",
        "address_2": "Seoul    181-848",
        "country": "KR"
    },
    "5048EB": {
        "oui_hex": "50-48-EB",
        "organization": "BEIJING HAIHEJINSHENG NETWORK TECHNOLOGY CO. LTD.",
        "address_1": "RM 701 Unit 2 Huirong Bldg. No.106 Lianhuachi East RD. Xuanwu Dist. Beijing",
        "address_2": "BEIJING  CHINA  100055",
        "country": "CN"
    },
    "B40E96": {
        "oui_hex": "B4-0E-96",
        "organization": "HERAN",
        "address_1": "No.88, Keji 3rd Rd., Guishan Township",
        "address_2": "Taoyuan  R.O.C  333",
        "country": "TW"
    },
    "508C77": {
        "oui_hex": "50-8C-77",
        "organization": "DIRMEIER Schanktechnik GmbH &Co KG",
        "address_1": "Alfons-Goppel-Straße 5",
        "address_2": "92526 Oberviechtach",
        "country": "DE"
    },
    "40704A": {
        "oui_hex": "40-70-4A",
        "organization": "Power Idea Technology Limited",
        "address_1": "1401A, Mintai Building, WenXin 5 Road, ShenZhen, PRC",
        "address_2": "Guang Dong  Shen Zhen  518054",
        "country": "CN"
    },
    "545EBD": {
        "oui_hex": "54-5E-BD",
        "organization": "NL Technologies",
        "address_1": "33 Laird Drive",
        "address_2": "Toronto  ON  M4G3S8",
        "country": "CA"
    },
    "F47F35": {
        "oui_hex": "F4-7F-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "BCC168": {
        "oui_hex": "BC-C1-68",
        "organization": "DinBox Sverige AB",
        "address_1": "Surbrunnsgatan 14",
        "address_2": "Stockholm    11427",
        "country": "SE"
    },
    "DC309C": {
        "oui_hex": "DC-30-9C",
        "organization": "Heyrex Limited",
        "address_1": "Level 1, 236-256 Karori Road",
        "address_2": "Wellington    6147",
        "country": "NZ"
    },
    "2C00F7": {
        "oui_hex": "2C-00-F7",
        "organization": "XOS",
        "address_1": "15 Tech Valley Drive",
        "address_2": "East Greenbush  NY  12061",
        "country": "US"
    },
    "28F606": {
        "oui_hex": "28-F6-06",
        "organization": "Syes srl",
        "address_1": "Via Zanella 21",
        "address_2": "Lissone (MB)  Monza Brianza  20851",
        "country": "IT"
    },
    "0CAF5A": {
        "oui_hex": "0C-AF-5A",
        "organization": "GENUS POWER INFRASTRUCTURES LIMITED",
        "address_1": "SPL-3 RIICO INDUSTRIAL AREA",
        "address_2": "JAIPUR  RAJASTHAN  302022",
        "country": "IN"
    },
    "7CEF8A": {
        "oui_hex": "7C-EF-8A",
        "organization": "Inhon International Ltd.",
        "address_1": "2F, No.552, Ruiguang Rd, Neihu Dist",
        "address_2": "Taipei  Taiwan  114",
        "country": "TW"
    },
    "241125": {
        "oui_hex": "24-11-25",
        "organization": "Hutek Co., Ltd.",
        "address_1": "E-402 Bundang Technopark",
        "address_2": "Seongnam-city  Gyeonggi-do  463-760",
        "country": "KR"
    },
    "B431B8": {
        "oui_hex": "B4-31-B8",
        "organization": "Aviwest",
        "address_1": "6 rue du Patis Tatelin",
        "address_2": "Rennes    35700",
        "country": "FR"
    },
    "CC187B": {
        "oui_hex": "CC-18-7B",
        "organization": "Manzanita Systems, Inc.",
        "address_1": "14269 Danielson Street",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "08BE09": {
        "oui_hex": "08-BE-09",
        "organization": "Astrol Electronic AG",
        "address_1": "Vorderi Böde 3",
        "address_2": "Oberrohrdorf  AG  5452",
        "country": "CH"
    },
    "B41DEF": {
        "oui_hex": "B4-1D-EF",
        "organization": "Internet Laboratories, Inc.",
        "address_1": "P.O. Box 7697",
        "address_2": "Atlanta  GA  30357",
        "country": "US"
    },
    "809393": {
        "oui_hex": "80-93-93",
        "organization": "Xapt GmbH",
        "address_1": "Neidenburger Str. 10",
        "address_2": "Gelsenkirchen  NRW  45897",
        "country": "DE"
    },
    "A007B6": {
        "oui_hex": "A0-07-B6",
        "organization": "Advanced Technical Support, Inc.",
        "address_1": "10 Grassmere Ave",
        "address_2": "West Hartford  CT  06110",
        "country": "US"
    },
    "0CD2B5": {
        "oui_hex": "0C-D2-B5",
        "organization": "Binatone Telecommunication Pvt. Ltd",
        "address_1": "A36, G/F, Sector 4",
        "address_2": "  Uttar Pradesh  201301",
        "country": "IN"
    },
    "4846F1": {
        "oui_hex": "48-46-F1",
        "organization": "Uros Oy",
        "address_1": "Tutkijantie 4",
        "address_2": "OULU    90590",
        "country": "FI"
    },
    "B827EB": {
        "oui_hex": "B8-27-EB",
        "organization": "Raspberry Pi Foundation",
        "address_1": "Mitchell Wood House",
        "address_2": "Caldecote  Cambridgeshire  CB23 7NU",
        "country": "US"
    },
    "84AF1F": {
        "oui_hex": "84-AF-1F",
        "organization": "Beat System Service Co,. Ltd.",
        "address_1": "1-11-1-2F, Nodaya-cho",
        "address_2": "Okayama-city  Okayama  700-0815",
        "country": "JP"
    },
    "B058C4": {
        "oui_hex": "B0-58-C4",
        "organization": "Broadcast Microwave Services, Inc",
        "address_1": "12367 Crosthwaite Circle",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "745798": {
        "oui_hex": "74-57-98",
        "organization": "TRUMPF Laser GmbH + Co. KG",
        "address_1": "Aichhalder Str. 39",
        "address_2": "Schramberg  BW  78713",
        "country": "DE"
    },
    "2817CE": {
        "oui_hex": "28-17-CE",
        "organization": "Omnisense Ltd",
        "address_1": "3rd Floor St Andrew's House",
        "address_2": "Cambridge  Cambridgeshire  CB2 3BZ",
        "country": "GB"
    },
    "3CCE73": {
        "oui_hex": "3C-CE-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B0BD6D": {
        "oui_hex": "B0-BD-6D",
        "organization": "Echostreams Innovative Solutions",
        "address_1": "1130 Coiner Ct.",
        "address_2": "City of Industry  CA  91748",
        "country": "US"
    },
    "6044F5": {
        "oui_hex": "60-44-F5",
        "organization": "Easy Digital Ltd.",
        "address_1": "Victoria Buildings, 1 Haddington Road",
        "address_2": "Dublin    4",
        "country": "IE"
    },
    "90AC3F": {
        "oui_hex": "90-AC-3F",
        "organization": "BrightSign LLC",
        "address_1": "16795 Lark Ave.",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "AC51EE": {
        "oui_hex": "AC-51-EE",
        "organization": "Cambridge Communication Systems Ltd",
        "address_1": "Sheraton House",
        "address_2": "Cambridge  Cambridgeshire  CB3 0AX",
        "country": "GB"
    },
    "78A183": {
        "oui_hex": "78-A1-83",
        "organization": "Advidia",
        "address_1": "3 Riverway",
        "address_2": "Houston  TX  77056",
        "country": "US"
    },
    "A8D0E5": {
        "oui_hex": "A8-D0-E5",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "F89955": {
        "oui_hex": "F8-99-55",
        "organization": "Fortress Technology Inc",
        "address_1": "51 Grand Marshall Drive",
        "address_2": "Scarborough  Ontario  M1B 5N6",
        "country": "CA"
    },
    "4CC94F": {
        "oui_hex": "4C-C9-4F",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "0CE5D3": {
        "oui_hex": "0C-E5-D3",
        "organization": "DH electronics GmbH",
        "address_1": "Am Anger 8",
        "address_2": "Bergen    83346",
        "country": "DE"
    },
    "E425E9": {
        "oui_hex": "E4-25-E9",
        "organization": "Color-Chip",
        "address_1": "Tavor Building 1",
        "address_2": "New Industrial Park  Yokneam  20692",
        "country": "IL"
    },
    "14B1C8": {
        "oui_hex": "14-B1-C8",
        "organization": "InfiniWing, Inc.",
        "address_1": "19925 Stevens Creek Blvd",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "E840F2": {
        "oui_hex": "E8-40-F2",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "50053D": {
        "oui_hex": "50-05-3D",
        "organization": "CyWee Group Ltd",
        "address_1": "3F, No.28, Lane128",
        "address_2": "Taipei    10462",
        "country": "TW"
    },
    "F88C1C": {
        "oui_hex": "F8-8C-1C",
        "organization": "KAISHUN ELECTRONIC TECHNOLOGY CO., LTD. BEIJING",
        "address_1": "NO.1 FARM, HENGQIAO VILLAGE WEST, MACHIKOU TOWN,",
        "address_2": "BEIJING    102200",
        "country": "CN"
    },
    "1C0B52": {
        "oui_hex": "1C-0B-52",
        "organization": "EPICOM S.A",
        "address_1": "Autovia Andalucia Km 12.700",
        "address_2": "Getafe  Madrid  28905",
        "country": "ES"
    },
    "747E2D": {
        "oui_hex": "74-7E-2D",
        "organization": "Beijing Thomson CITIC Digital Technology Co. LTD.",
        "address_1": "8301, No.8 Workshop, 3 Yongchangbei Road",
        "address_2": "Beijing    100176",
        "country": "CN"
    },
    "885C47": {
        "oui_hex": "88-5C-47",
        "organization": "Alcatel Lucent",
        "address_1": "Via Energy Park, 14",
        "address_2": "Vimercate  MB  20871",
        "country": "IT"
    },
    "3CC1F6": {
        "oui_hex": "3C-C1-F6",
        "organization": "Melange Systems Pvt. Ltd.",
        "address_1": "4/1, 7th Cross, Kumarapark West",
        "address_2": "Bangalore  Karnataka  560020",
        "country": "IN"
    },
    "94FAE8": {
        "oui_hex": "94-FA-E8",
        "organization": "Shenzhen Eycom Technology Co., Ltd",
        "address_1": "EYANG Building, No. 3 of Qimin Rd, Langshan 2nd Street, North Area of Hi-Tech Industrial Zone, Nanshan District",
        "address_2": "Shenzhen  Guang Dong  518057",
        "country": "CN"
    },
    "B48255": {
        "oui_hex": "B4-82-55",
        "organization": "Research Products Corporation",
        "address_1": "1015 E. Washington Ave",
        "address_2": "Madison  WI  53703",
        "country": "US"
    },
    "8016B7": {
        "oui_hex": "80-16-B7",
        "organization": "Brunel University",
        "address_1": "School of IS, Computing & Maths",
        "address_2": "Uxbridge  Middlesex  UB8 3PH",
        "country": "GB"
    },
    "008DDA": {
        "oui_hex": "00-8D-DA",
        "organization": "Link One Co., Ltd.",
        "address_1": "601F   Chungjuk tower 546-9",
        "address_2": "Buchion  Gyeonggi-do   420-864",
        "country": "KR"
    },
    "C49805": {
        "oui_hex": "C4-98-05",
        "organization": "Minieum Networks, Inc",
        "address_1": "6404 International Parkway",
        "address_2": "Plano  Texas  75093",
        "country": "US"
    },
    "90F4C1": {
        "oui_hex": "90-F4-C1",
        "organization": "Rand McNally",
        "address_1": "9855 Woods Drive",
        "address_2": "Skokie  IL  60077",
        "country": "US"
    },
    "18193F": {
        "oui_hex": "18-19-3F",
        "organization": "Tamtron Oy",
        "address_1": "P.O.Box 15 (Vestonkatu 11)",
        "address_2": "Tampere    33561",
        "country": "FI"
    },
    "944444": {
        "oui_hex": "94-44-44",
        "organization": "LG Innotek",
        "address_1": "Jangduk-dong, Gwangsan-gu",
        "address_2": "Gwang-ju    506-731",
        "country": "KR"
    },
    "4C64D9": {
        "oui_hex": "4C-64-D9",
        "organization": "Guangdong Leawin Group Co., Ltd",
        "address_1": "10/F, Domain Bldg,No.8 Keji Road(E),HiTech Development District,",
        "address_2": "Shantou  Guangdong  515041",
        "country": "CN"
    },
    "940149": {
        "oui_hex": "94-01-49",
        "organization": "AutoHotBox",
        "address_1": "14090 SW Frwy, Ste. 300",
        "address_2": "Sugar Land  TX  77478",
        "country": "US"
    },
    "1CB094": {
        "oui_hex": "1C-B0-94",
        "organization": "HTC Corporation",
        "address_1": "No. 23, Xinghua Rd., Taoyuan City",
        "address_2": "Taoyuan County  Taiwan  330",
        "country": "TW"
    },
    "9C0111": {
        "oui_hex": "9C-01-11",
        "organization": "Shenzhen Newabel Electronic Co., Ltd.",
        "address_1": "5Flr, South Tower of Sichuan Bld.,",
        "address_2": "Shenzhen  Guangdong  518028",
        "country": "CN"
    },
    "400E67": {
        "oui_hex": "40-0E-67",
        "organization": "Tremol Ltd.",
        "address_1": "6 Toledo str.",
        "address_2": "Veliko Turnovo    5000",
        "country": "BG"
    },
    "C0DF77": {
        "oui_hex": "C0-DF-77",
        "organization": "Conrad Electronic SE",
        "address_1": "Klaus Conrad Str. 1",
        "address_2": "Hirschau  Bavaria  92240",
        "country": "DE"
    },
    "3055ED": {
        "oui_hex": "30-55-ED",
        "organization": "Trex Network LLC",
        "address_1": "Room 505, Tower B Nongke Building,",
        "address_2": "Beijing    100097",
        "country": "CN"
    },
    "F0F755": {
        "oui_hex": "F0-F7-55",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "1CB243": {
        "oui_hex": "1C-B2-43",
        "organization": "TDC A/S",
        "address_1": "Telehøjen 1",
        "address_2": "Odense SØ    5220",
        "country": "DK"
    },
    "38BF33": {
        "oui_hex": "38-BF-33",
        "organization": "NEC CASIO Mobile Communications",
        "address_1": "1753,Shimonumabe",
        "address_2": "Kawasaki-shi  Kanagawa  211-8666",
        "country": "JP"
    },
    "B467E9": {
        "oui_hex": "B4-67-E9",
        "organization": "Qingdao GoerTek Technology Co., Ltd.",
        "address_1": "5F, No.3 Building, Fortune Center",
        "address_2": "Qingdao  Shandong  266061",
        "country": "CN"
    },
    "186751": {
        "oui_hex": "18-67-51",
        "organization": "KOMEG Industrielle Messtechnik GmbH",
        "address_1": "Zum Wasserwerk 3",
        "address_2": "Völklingen    66333",
        "country": "DE"
    },
    "645EBE": {
        "oui_hex": "64-5E-BE",
        "organization": "Yahoo! JAPAN",
        "address_1": "Midtown Tower",
        "address_2": "Minato-ku  Tokyo  107-6211",
        "country": "JP"
    },
    "CCC50A": {
        "oui_hex": "CC-C5-0A",
        "organization": "SHENZHEN DAJIAHAO TECHNOLOGY CO.,LTD",
        "address_1": "3F Buliding 1, 2th Park TaoHuaYuan Tech- Innovation,",
        "address_2": "Shenzhen  Guangdong  518102",
        "country": "CN"
    },
    "1CB17F": {
        "oui_hex": "1C-B1-7F",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "E42C56": {
        "oui_hex": "E4-2C-56",
        "organization": "Lilee Systems, Ltd.",
        "address_1": "2905 Stender Way, Suite 78",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "48ED80": {
        "oui_hex": "48-ED-80",
        "organization": "daesung eltec",
        "address_1": "#509 SJ Technoville, 60-19, Gasan-dong",
        "address_2": "Seoul    153-769",
        "country": "KR"
    },
    "C80718": {
        "oui_hex": "C8-07-18",
        "organization": "TDSi",
        "address_1": "Unit 10 Concept Park",
        "address_2": "Poole  Dorset  BH12 4QT",
        "country": "GB"
    },
    "581D91": {
        "oui_hex": "58-1D-91",
        "organization": "Advanced Mobile Telecom co.,ltd.",
        "address_1": "#608, Yatap Leaders Bldg. 342-1",
        "address_2": "Seongnam-si  Gyeonggi-do  463-828",
        "country": "KR"
    },
    "D8BF4C": {
        "oui_hex": "D8-BF-4C",
        "organization": "Victory Concept Electronics Limited",
        "address_1": "4/F., CAC Tower,",
        "address_2": "Kwun Tong  Kowloon  KLN",
        "country": "HK"
    },
    "3CB9A6": {
        "oui_hex": "3C-B9-A6",
        "organization": "Belden Deutschland GmbH",
        "address_1": "Stuttgarter Straße 45-51",
        "address_2": "Neckartenzlingen    72654",
        "country": "DE"
    },
    "8C0CA3": {
        "oui_hex": "8C-0C-A3",
        "organization": "Amper",
        "address_1": "Marconi 3, PTM",
        "address_2": "Tres Cantos  Madrid  28760",
        "country": "US"
    },
    "94DF58": {
        "oui_hex": "94-DF-58",
        "organization": "IJ Electron CO.,Ltd.",
        "address_1": "401 ACE HIGHEND8, 345-4 GASAN-DONG",
        "address_2": "SEOUL    153-802",
        "country": "KR"
    },
    "48D54C": {
        "oui_hex": "48-D5-4C",
        "organization": "Jeda Networks",
        "address_1": "2618 San Miguel Drive",
        "address_2": "Newport Beach  Ca.  92660",
        "country": "US"
    },
    "8CDE52": {
        "oui_hex": "8C-DE-52",
        "organization": "ISSC Technologies Corp.",
        "address_1": "4F, No.8, Dusing Rd.,",
        "address_2": "Hsinchu City     30078",
        "country": "TW"
    },
    "082522": {
        "oui_hex": "08-25-22",
        "organization": "ADVANSEE",
        "address_1": "9 Rue Alfred Kastler",
        "address_2": "NANTES    44307",
        "country": "FR"
    },
    "4C2F9D": {
        "oui_hex": "4C-2F-9D",
        "organization": "ICM Controls",
        "address_1": "7313 William Barry Blvd",
        "address_2": "North Syracuse  NY  13212",
        "country": "US"
    },
    "E467BA": {
        "oui_hex": "E4-67-BA",
        "organization": "Danish Interpretation Systems A/S",
        "address_1": "Vestre Teglgade 12",
        "address_2": "Copenhagen  SV  2450",
        "country": "DK"
    },
    "BCB852": {
        "oui_hex": "BC-B8-52",
        "organization": "Cybera, Inc.",
        "address_1": "9009 Carothers Parkway",
        "address_2": "Franklin  TN  37067",
        "country": "US"
    },
    "C49300": {
        "oui_hex": "C4-93-00",
        "organization": "8Devices",
        "address_1": "Gedimino st. 47",
        "address_2": "Kaunas  LT  44242",
        "country": "LT"
    },
    "6CA682": {
        "oui_hex": "6C-A6-82",
        "organization": "EDAM information & communications",
        "address_1": "601, Hanlim Veture town, 689-6",
        "address_2": "Gunpo  Gyenggi-Do  435-862",
        "country": "KR"
    },
    "28D576": {
        "oui_hex": "28-D5-76",
        "organization": "Premier Wireless, Inc.",
        "address_1": "4222 E. La Palma Ave.",
        "address_2": "Anaheim  CA  92807",
        "country": "US"
    },
    "70D6B6": {
        "oui_hex": "70-D6-B6",
        "organization": "Metrum Technologies",
        "address_1": "315 South University Parks Drive",
        "address_2": "Waco  Texas  76701",
        "country": "US"
    },
    "C0A0DE": {
        "oui_hex": "C0-A0-DE",
        "organization": "Multi Touch Oy",
        "address_1": "Henry Fordin katu 6",
        "address_2": "Helsinki    00150",
        "country": "FI"
    },
    "40BC8B": {
        "oui_hex": "40-BC-8B",
        "organization": "itelio GmbH",
        "address_1": "Franz-Larcher-Straße 4",
        "address_2": "Kiefersfelden  Bavaria  83088",
        "country": "DE"
    },
    "9CA134": {
        "oui_hex": "9C-A1-34",
        "organization": "Nike, Inc.",
        "address_1": "1 Bowerman Drive",
        "address_2": "Beaverton  OR  97005",
        "country": "US"
    },
    "50FC30": {
        "oui_hex": "50-FC-30",
        "organization": "Treehouse Labs",
        "address_1": "601 Great Oaks Dr.",
        "address_2": "Round Rock  TX  78681",
        "country": "US"
    },
    "B89674": {
        "oui_hex": "B8-96-74",
        "organization": "AllDSP GmbH & Co. KG",
        "address_1": "Spenglerstrasse 6",
        "address_2": "Hamm  NRW  59067",
        "country": "DE"
    },
    "48E1AF": {
        "oui_hex": "48-E1-AF",
        "organization": "Vity",
        "address_1": "180 rue Pierre Landais",
        "address_2": "Caudan  56  56850",
        "country": "FR"
    },
    "1CBBA8": {
        "oui_hex": "1C-BB-A8",
        "organization": "OJSC Ufimskiy Zavod Promsvyaz",
        "address_1": "39, 50 let SSSR",
        "address_2": "Ufa  Bashkortostan  450071",
        "country": "RU"
    },
    "006BA0": {
        "oui_hex": "00-6B-A0",
        "organization": "SHENZHEN UNIVERSAL INTELLISYS PTE LTD",
        "address_1": "ROOM 1607-1608,XINGJI MANSION",
        "address_2": "SHENZHEN  GUANGDONG  518104",
        "country": "CN"
    },
    "A898C6": {
        "oui_hex": "A8-98-C6",
        "organization": "Shinbo Co., Ltd.",
        "address_1": "203-14, Anyang 7-Dong, Manan-Gu",
        "address_2": "Anyang-Si  Kyungki-Do  430-817",
        "country": "KR"
    },
    "B4211D": {
        "oui_hex": "B4-21-1D",
        "organization": "Beijing GuangXin Technology Co., Ltd",
        "address_1": "Room 313,B Bld,Horizon International Tower,Zhichun Road,6,Haidian District,Beijing City,P.R.China",
        "address_2": "Beijing    100086",
        "country": "CN"
    },
    "903CAE": {
        "oui_hex": "90-3C-AE",
        "organization": "Yunnan KSEC Digital Technology Co.,Ltd.",
        "address_1": "3F,NO.176 Keyi ROAD,High and New Technological Industrial Development Zone",
        "address_2": "Kunming  Yunnan  650106",
        "country": "CN"
    },
    "70704C": {
        "oui_hex": "70-70-4C",
        "organization": "Purple Communications, Inc",
        "address_1": "595 Menlo",
        "address_2": "Rocklin  CA  95765",
        "country": "US"
    },
    "D89760": {
        "oui_hex": "D8-97-60",
        "organization": "C2 Development, Inc.",
        "address_1": "127 S Bell Ave",
        "address_2": "Ames  IA  50010",
        "country": "US"
    },
    "F47ACC": {
        "oui_hex": "F4-7A-CC",
        "organization": "SolidFire, Inc.",
        "address_1": "1620 Pearl Street",
        "address_2": "Boulder  Colorado  80302",
        "country": "US"
    },
    "905682": {
        "oui_hex": "90-56-82",
        "organization": "Lenbrook Industries Limited",
        "address_1": "633 Granite Court",
        "address_2": "Pickering  Ontario  L1W 3K1",
        "country": "CA"
    },
    "F0DA7C": {
        "oui_hex": "F0-DA-7C",
        "organization": "RLH INDUSTRIES,INC.",
        "address_1": "936 N. MAIN ST.",
        "address_2": "ORANGE  CA  92867",
        "country": "US"
    },
    "AC319D": {
        "oui_hex": "AC-31-9D",
        "organization": "Shenzhen TG-NET Botone Technology Co.,Ltd.",
        "address_1": "2nd floor,Building No.6,Pengtengda industrial zone,Huarong road,Dalang Street Office,",
        "address_2": "Shenzhen  Guangdong  518109",
        "country": "CN"
    },
    "20107A": {
        "oui_hex": "20-10-7A",
        "organization": "Gemtek Technology Co., Ltd.",
        "address_1": "No. 1 Jen Ai Road Hsinchu Industrial Park Hukou, Hsinchu 30352 TAIWAN, REPUBLIC OF CHINA",
        "address_2": "Hsinchu  TAIWAN  30352",
        "country": "TW"
    },
    "78DDD6": {
        "oui_hex": "78-DD-D6",
        "organization": "c-scape",
        "address_1": "westerkade 22",
        "address_2": "Gouda    2802 SL",
        "country": "NL"
    },
    "C09132": {
        "oui_hex": "C0-91-32",
        "organization": "Patriot Memory",
        "address_1": "47027 Benicia",
        "address_2": "Fremont  CA  94555",
        "country": "US"
    },
    "90185E": {
        "oui_hex": "90-18-5E",
        "organization": "Apex Tool Group GmbH & Co OHG",
        "address_1": "Industriestraße 1",
        "address_2": "Westhausen    73463",
        "country": "DE"
    },
    "F8FE5C": {
        "oui_hex": "F8-FE-5C",
        "organization": "Reciprocal Labs Corp",
        "address_1": "3 S. Pinckney St.",
        "address_2": "Madison  WI  53703",
        "country": "US"
    },
    "6C9CED": {
        "oui_hex": "6C-9C-ED",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "2486F4": {
        "oui_hex": "24-86-F4",
        "organization": "Ctek, Inc.",
        "address_1": "34 Miraleste Plaza",
        "address_2": "Rancho Palos Verdes  California  90275",
        "country": "US"
    },
    "C4237A": {
        "oui_hex": "C4-23-7A",
        "organization": "WhizNets Inc.",
        "address_1": "830 Stewart Drive",
        "address_2": "Sunnyvale  California  94085",
        "country": "US"
    },
    "F4E6D7": {
        "oui_hex": "F4-E6-D7",
        "organization": "Solar Power Technologies, Inc.",
        "address_1": "3006 Bee Caves Rd.",
        "address_2": "Austin  Texas  78746",
        "country": "US"
    },
    "B87424": {
        "oui_hex": "B8-74-24",
        "organization": "Viessmann Elektronik GmbH",
        "address_1": "Beetwiese 2",
        "address_2": "Allendorf (Eder)    35108",
        "country": "DE"
    },
    "B451F9": {
        "oui_hex": "B4-51-F9",
        "organization": "NB Software",
        "address_1": "Eichhalde 3",
        "address_2": "Weissach i. T.  Baden-Württemberg  71554",
        "country": "DE"
    },
    "30168D": {
        "oui_hex": "30-16-8D",
        "organization": "ProLon",
        "address_1": "17510 rue Charles, Suite 100",
        "address_2": "Mirabel  Quebec   J7J 1X9",
        "country": "CA"
    },
    "E4AFA1": {
        "oui_hex": "E4-AF-A1",
        "organization": "HES-SO",
        "address_1": "Case postale 2134",
        "address_2": "Sion    1950",
        "country": "CH"
    },
    "A887ED": {
        "oui_hex": "A8-87-ED",
        "organization": "ARC Wireless LLC",
        "address_1": "6330 N. Washington St.",
        "address_2": "Denver  CO  80216",
        "country": "US"
    },
    "D4D249": {
        "oui_hex": "D4-D2-49",
        "organization": "Power Ethernet",
        "address_1": "4th Floor, Holborn Gate",
        "address_2": "London    WC2A 1AH",
        "country": "GB"
    },
    "80427C": {
        "oui_hex": "80-42-7C",
        "organization": "Adolf Tedsen GmbH & Co. KG",
        "address_1": "Otto-Hahn-Str. 13-15",
        "address_2": "Trittau  Schleswig-Holstein  D-22946",
        "country": "DE"
    },
    "E0DADC": {
        "oui_hex": "E0-DA-DC",
        "organization": "JVC KENWOOD Corporation",
        "address_1": "3-12, Moriyacho, Kanagawa-ku",
        "address_2": "Yokohama-shi  Kanagawa  221-0022",
        "country": "JP"
    },
    "E843B6": {
        "oui_hex": "E8-43-B6",
        "organization": "QNAP Systems, Inc.",
        "address_1": "2F., No.22, Zhongxing Rd., Xizhi Dist.",
        "address_2": "New Taipei City    221",
        "country": "TW"
    },
    "B89BC9": {
        "oui_hex": "B8-9B-C9",
        "organization": "SMC Networks Inc",
        "address_1": "20 Mason",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "409FC7": {
        "oui_hex": "40-9F-C7",
        "organization": "BAEKCHUN I&C Co., Ltd.",
        "address_1": "67-5, Gyesu-dong",
        "address_2": "Bucheon-si  Gyeonggi-do  422-070",
        "country": "KR"
    },
    "00FC58": {
        "oui_hex": "00-FC-58",
        "organization": "WebSilicon Ltd.",
        "address_1": "25, Habarzel St.,",
        "address_2": "Tel-Aviv    69710",
        "country": "IL"
    },
    "983571": {
        "oui_hex": "98-35-71",
        "organization": "Sub10 Systems Ltd",
        "address_1": "Ash House",
        "address_2": "Kingsteignton  Devon  TQ12 3RZ",
        "country": "GB"
    },
    "5404A6": {
        "oui_hex": "54-04-A6",
        "organization": "ASUSTek COMPUTER INC.",
        "address_1": "15,Li-Te Rd., Peitou, Taipei 112, Taiwan",
        "address_2": "Taipei  Taiwan  112",
        "country": "TW"
    },
    "186D99": {
        "oui_hex": "18-6D-99",
        "organization": "Adanis Inc.",
        "address_1": "#2015-2016 Geumkang Penterium",
        "address_2": "Hakuro, Dongan-Gu, Anyang-Si  Kyunggi-Do  431-060",
        "country": "KR"
    },
    "A0E201": {
        "oui_hex": "A0-E2-01",
        "organization": "AVTrace Ltd.(China)",
        "address_1": "RM704, District B1, Originality Building, No.162 KeXue Avenue Science Town,GUANGZHOU,CHINA",
        "address_2": "GUANGZHOU  GUANGDONG  510611",
        "country": "US"
    },
    "F0DEB9": {
        "oui_hex": "F0-DE-B9",
        "organization": "ShangHai Y&Y Electronics Co., Ltd",
        "address_1": "No.3, 588 Tianxiong Road, Shanghai International Medical Zone(SIMZ),",
        "address_2": "Shanghai    201318",
        "country": "CN"
    },
    "7CA61D": {
        "oui_hex": "7C-A6-1D",
        "organization": "MHL, LLC",
        "address_1": "1140 East Arques Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "9CF67D": {
        "oui_hex": "9C-F6-7D",
        "organization": "Ricardo Prague, s.r.o.",
        "address_1": "Thamova 13",
        "address_2": "Praha 8    186 00",
        "country": "CZ"
    },
    "F82F5B": {
        "oui_hex": "F8-2F-5B",
        "organization": "eGauge Systems LLC",
        "address_1": "1510 28th St, Suite 205",
        "address_2": "Boulder  CO  80303",
        "country": "US"
    },
    "98C845": {
        "oui_hex": "98-C8-45",
        "organization": "PacketAccess",
        "address_1": "611 North Main Street",
        "address_2": "Goldfield  IA  50543",
        "country": "US"
    },
    "989080": {
        "oui_hex": "98-90-80",
        "organization": "Linkpower Network System Inc Ltd.",
        "address_1": "Room 202, Build 18, Shahe Industrial Zone",
        "address_2": "Shenzhen  Guangdong  518053",
        "country": "CN"
    },
    "F83376": {
        "oui_hex": "F8-33-76",
        "organization": "Good Mind Innovation Co., Ltd.",
        "address_1": "20, Lane 200, Cheng Hu Rd.",
        "address_2": "Kaohsiung    833",
        "country": "TW"
    },
    "50F61A": {
        "oui_hex": "50-F6-1A",
        "organization": "Kunshan JADE Technologies co., Ltd.",
        "address_1": "12th Floor, Southern Building, Pudong Software Park,828 Xueyuan Road, Bacheng Town",
        "address_2": "Kunshan  Jiangsu  215311",
        "country": "CN"
    },
    "542018": {
        "oui_hex": "54-20-18",
        "organization": "Tely Labs",
        "address_1": "545 Middlefield Road",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "581FEF": {
        "oui_hex": "58-1F-EF",
        "organization": "Tuttnaer LTD",
        "address_1": "Har-Tuv B",
        "address_2": "Beith Shemesh    99000",
        "country": "IL"
    },
    "58BDA3": {
        "oui_hex": "58-BD-A3",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "F8F25A": {
        "oui_hex": "F8-F2-5A",
        "organization": "G-Lab GmbH",
        "address_1": "Schiffbaustrasse 10",
        "address_2": "Zurich  CH  8005",
        "country": "CH"
    },
    "307ECB": {
        "oui_hex": "30-7E-CB",
        "organization": "SFR",
        "address_1": "40/42 Quai du point du jour",
        "address_2": "Boulongne Billancourt  Hauts de Seine  92659",
        "country": "FR"
    },
    "68F125": {
        "oui_hex": "68-F1-25",
        "organization": "Data Controls Inc.",
        "address_1": "Fukashiro Bldg, 8F",
        "address_2": "Taito-ku  Tokyo  111-0052",
        "country": "JP"
    },
    "BC764E": {
        "oui_hex": "BC-76-4E",
        "organization": "Rackspace US, Inc.",
        "address_1": "5000 Walzem Rd.",
        "address_2": "San Antonio  TX  78218",
        "country": "US"
    },
    "CCC8D7": {
        "oui_hex": "CC-C8-D7",
        "organization": "CIAS Elettronica srl",
        "address_1": "Via Giovanni Durando 38",
        "address_2": "Milan    20158",
        "country": "IT"
    },
    "84D32A": {
        "oui_hex": "84-D3-2A",
        "organization": "IEEE 1905.1",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway   NJ  08855-1331",
        "country": "US"
    },
    "4C0289": {
        "oui_hex": "4C-02-89",
        "organization": "LEX COMPUTECH CO., LTD",
        "address_1": "3F, No.77, LI DE St. Chung Ho Dist.,",
        "address_2": "New Taipei City    23556",
        "country": "TW"
    },
    "C0E54E": {
        "oui_hex": "C0-E5-4E",
        "organization": "ARIES Embedded GmbH",
        "address_1": "Schöngeisinger Str. 84",
        "address_2": " Fürstenfeldbruck    D-82256",
        "country": "DE"
    },
    "F8C001": {
        "oui_hex": "F8-C0-01",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "187C81": {
        "oui_hex": "18-7C-81",
        "organization": "Valeo Vision Systems",
        "address_1": "Dunmore Road",
        "address_2": "County Galway",
        "country": "IE"
    },
    "ACCC8E": {
        "oui_hex": "AC-CC-8E",
        "organization": "Axis Communications AB",
        "address_1": "Emdalavägen 14",
        "address_2": "LUND    22369",
        "country": "SE"
    },
    "8C94CF": {
        "oui_hex": "8C-94-CF",
        "organization": "Encell Technology, Inc.",
        "address_1": "1412 Sachem Place, Suite 204",
        "address_2": "Charlottesville  VA  22901",
        "country": "US"
    },
    "6CA780": {
        "oui_hex": "6C-A7-80",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "3057AC": {
        "oui_hex": "30-57-AC",
        "organization": "IRLAB LTD.",
        "address_1": "3rd Floor, 2A Biulding, Huihao Industrial Park",
        "address_2": "Shenzhen  Guang Dong  518106",
        "country": "CN"
    },
    "842B50": {
        "oui_hex": "84-2B-50",
        "organization": "Huria Co.,Ltd.",
        "address_1": "#190-28 Chungchun-2Dong",
        "address_2": "Incheon    403-032",
        "country": "KR"
    },
    "48F7F1": {
        "oui_hex": "48-F7-F1",
        "organization": "Nokia",
        "address_1": "600 March Road",
        "address_2": "Kanata  Ontario  K2K 2E6",
        "country": "CA"
    },
    "8C8E76": {
        "oui_hex": "8C-8E-76",
        "organization": "taskit GmbH",
        "address_1": "Groß-Berliner Damm 37",
        "address_2": "Berlin    12487",
        "country": "DE"
    },
    "A0133B": {
        "oui_hex": "A0-13-3B",
        "organization": "HiTi Digital, Inc.",
        "address_1": "9F., No.225, Sec. 3, Beixin Rd., Xindian Dist.,",
        "address_2": "Xindian Dist.  New Taipei City  231",
        "country": "TW"
    },
    "9C5711": {
        "oui_hex": "9C-57-11",
        "organization": "Feitian Xunda(Beijing) Aeronautical Information Technology Co., Ltd.",
        "address_1": "Building B,Horizon International Tower,No.6 Zhichun Rd,Haidian District,",
        "address_2": "Beijing    100088",
        "country": "CN"
    },
    "88F488": {
        "oui_hex": "88-F4-88",
        "organization": "cellon communications technology(shenzhen)Co.,Ltd.",
        "address_1": "13/F C Building,Gaoxin S.Ave.,Hi-Tech Industrial Park,Nanshan,shenzhen518057,PRC",
        "address_2": "shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "448E12": {
        "oui_hex": "44-8E-12",
        "organization": "DT Research, Inc.",
        "address_1": "2000 Concourse Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "B8BB6D": {
        "oui_hex": "B8-BB-6D",
        "organization": "ENERES Co.,Ltd.",
        "address_1": "1907 Tokyo Art Center",
        "address_2": "Adahci-ku  Tokyo  120-0034",
        "country": "JP"
    },
    "14373B": {
        "oui_hex": "14-37-3B",
        "organization": "PROCOM Systems",
        "address_1": "#1001, Kranz Techno, 5442-1",
        "address_2": "Seongnam-si  Gyunggi-do  462-729",
        "country": "KR"
    },
    "1897FF": {
        "oui_hex": "18-97-FF",
        "organization": "TechFaith Wireless Technology Limited",
        "address_1": "Building C, Jia No.5, Rongchang East Street, BDA District,",
        "address_2": "Beijing    100176",
        "country": "CN"
    },
    "4C5585": {
        "oui_hex": "4C-55-85",
        "organization": "Hamilton Systems",
        "address_1": "3143 Production Drive",
        "address_2": "Fairfield  OH  45014",
        "country": "US"
    },
    "ECEA03": {
        "oui_hex": "EC-EA-03",
        "organization": "DARFON LIGHTING CORP",
        "address_1": "167, Shanying Road",
        "address_2": "Gueishan  Taoyuan  33341",
        "country": "TW"
    },
    "30F9ED": {
        "oui_hex": "30-F9-ED",
        "organization": "Sony Corporation",
        "address_1": "Gotenyama Tec 5-1-2",
        "address_2": "Tokyo  Shinagawa-ku  141-0001",
        "country": "JP"
    },
    "582EFE": {
        "oui_hex": "58-2E-FE",
        "organization": "Lighting Science Group",
        "address_1": "1227 South Patrick Drive",
        "address_2": "Satellite Beach  FL  32937",
        "country": "US"
    },
    "CC60BB": {
        "oui_hex": "CC-60-BB",
        "organization": "Empower RF Systems",
        "address_1": "316 W. Florence Ave",
        "address_2": "Inglewood  CA  90301",
        "country": "US"
    },
    "7CDD20": {
        "oui_hex": "7C-DD-20",
        "organization": "IOXOS Technologies S.A.",
        "address_1": "4 Chemin de Fontenailles",
        "address_2": "GLAND  VAUD  CH-1196",
        "country": "CH"
    },
    "ECF236": {
        "oui_hex": "EC-F2-36",
        "organization": "NEOMONTANA ELECTRONICS",
        "address_1": "Mladost-4, bl. 483, mag. 13",
        "address_2": "Sofia    1715",
        "country": "BG"
    },
    "0418B6": {
        "oui_hex": "04-18-B6",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "E4A5EF": {
        "oui_hex": "E4-A5-EF",
        "organization": "TRON LINK ELECTRONICS CO., LTD.",
        "address_1": "FLAT A, 20/F., BLOCK 4,ON NING GARDEN,",
        "address_2": "KOWLOON    999077",
        "country": "HK"
    },
    "3071B2": {
        "oui_hex": "30-71-B2",
        "organization": "Hangzhou Prevail Optoelectronic Equipment Co.,LTD.",
        "address_1": "Industrial Development Area, Guali Town,",
        "address_2": "Hangzhou City  Zhe Jiang  311241",
        "country": "CN"
    },
    "DCCE41": {
        "oui_hex": "DC-CE-41",
        "organization": "FE GLOBAL HONG KONG LIMITED",
        "address_1": "FLAT 204-205 2/F LAFORD CENTRE838 LAI CHI KOK RD CHEUNG SHA WAN KL",
        "address_2": "SHENZHEN    518057",
        "country": "CN"
    },
    "FC6C31": {
        "oui_hex": "FC-6C-31",
        "organization": "LXinstruments GmbH",
        "address_1": "Herrenberger Str. 130",
        "address_2": "Boeblingen    71034",
        "country": "DE"
    },
    "705CAD": {
        "oui_hex": "70-5C-AD",
        "organization": "Konami Gaming Inc",
        "address_1": "585 Trade Center Drive",
        "address_2": "Las Vegas  Nevada  89119",
        "country": "US"
    },
    "3C6F45": {
        "oui_hex": "3C-6F-45",
        "organization": "Fiberpro Inc.",
        "address_1": "59-4 Jang-dong, Yusong-gu",
        "address_2": "  Deajeon  305-343",
        "country": "KR"
    },
    "703187": {
        "oui_hex": "70-31-87",
        "organization": "ACX GmbH",
        "address_1": "Äußere Zwickauer Straße 8",
        "address_2": "Zwickau    08064",
        "country": "DE"
    },
    "30E4DB": {
        "oui_hex": "30-E4-DB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "88E0F3": {
        "oui_hex": "88-E0-F3",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "80971B": {
        "oui_hex": "80-97-1B",
        "organization": "Altenergy Power System,Inc.",
        "address_1": "No.1 Yatai Road,",
        "address_2": "Jiaxing City,    Zhejiang Province,  314050",
        "country": "CN"
    },
    "587675": {
        "oui_hex": "58-76-75",
        "organization": "Beijing ECHO Technologies Co.,Ltd",
        "address_1": "NO1 Street 4 Shangdi",
        "address_2": "BeiJing    100085",
        "country": "CN"
    },
    "0C51F7": {
        "oui_hex": "0C-51-F7",
        "organization": "CHAUVIN ARNOUX",
        "address_1": "LA QUEUE DEVEE",
        "address_2": "REUX  PONT L EVEQUE  14130",
        "country": "FR"
    },
    "0CFC83": {
        "oui_hex": "0C-FC-83",
        "organization": "Airoha Technology Corp.,",
        "address_1": "5F, No.6-5, Dushing Road , Hsinchu Science Park",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "007F28": {
        "oui_hex": "00-7F-28",
        "organization": "Actiontec Electronics, Inc",
        "address_1": "3301 Olcott St.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "804731": {
        "oui_hex": "80-47-31",
        "organization": "Packet Design, Inc.",
        "address_1": "2455 Augustine Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "B09BD4": {
        "oui_hex": "B0-9B-D4",
        "organization": "GNH Software India Private Limited",
        "address_1": "9/14 Sengani Amman Koil Street",
        "address_2": "Chennai  Tamilnadu  600032",
        "country": "IN"
    },
    "F08BFE": {
        "oui_hex": "F0-8B-FE",
        "organization": "COSTEL.,CO.LTD",
        "address_1": "223-39, Sangdaewon-Dong, Jungwon-Gu",
        "address_2": "Seongnam-si  Kyunggi-Do  462-807",
        "country": "KR"
    },
    "3C26D5": {
        "oui_hex": "3C-26-D5",
        "organization": "Sotera Wireless",
        "address_1": "9444 Waples Street",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "E84E06": {
        "oui_hex": "E8-4E-06",
        "organization": "EDUP INTERNATIONAL (HK) CO., LTD",
        "address_1": "20D Room, Block B, Modern Windows Buidling, FuTian District,",
        "address_2": "Shenzhen  Guangdong  518028",
        "country": "CN"
    },
    "00077D": {
        "oui_hex": "00-07-7D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "CCD9E9": {
        "oui_hex": "CC-D9-E9",
        "organization": "SCR Engineers Ltd.",
        "address_1": "6 Haomanut St.",
        "address_2": "Netanya    42504",
        "country": "IL"
    },
    "34A709": {
        "oui_hex": "34-A7-09",
        "organization": "Trevil srl",
        "address_1": "Via Copernico 1",
        "address_2": "Pozzo d'Adda  MI  20060",
        "country": "IT"
    },
    "E0C922": {
        "oui_hex": "E0-C9-22",
        "organization": "Jireh Energy Tech., Ltd.",
        "address_1": "#606 Seoul Forest Hallasigmavalley, 325-2",
        "address_2": "Seoul  Seongdong-Gu  133-120",
        "country": "KR"
    },
    "905F8D": {
        "oui_hex": "90-5F-8D",
        "organization": "modas GmbH",
        "address_1": "Belziger Str. 69-71",
        "address_2": "Berlin    10823",
        "country": "DE"
    },
    "98293F": {
        "oui_hex": "98-29-3F",
        "organization": "Fujian Start Computer Equipment Co.,Ltd",
        "address_1": "No.68 Hongshangyuan Road,",
        "address_2": "Fuzhou City,   Fujian Province,  350002",
        "country": "CN"
    },
    "B45CA4": {
        "oui_hex": "B4-5C-A4",
        "organization": "Thing-talk Wireless Communication Technologies Corporation Limited",
        "address_1": "498 Guo Shou Jing Road, Suite 10402",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "908D1D": {
        "oui_hex": "90-8D-1D",
        "organization": "GH Technologies",
        "address_1": "5022 Binhe Road, Block B, United Plaza",
        "address_2": "Shenzhen    518026",
        "country": "CN"
    },
    "444F5E": {
        "oui_hex": "44-4F-5E",
        "organization": "Pan Studios Co.,Ltd.",
        "address_1": "1F., NO.402, SEC. 2, JHONGYANG N. RD., BEITOU DISTRICT,",
        "address_2": "TAIPEI CITY     11258",
        "country": "TW"
    },
    "D0AFB6": {
        "oui_hex": "D0-AF-B6",
        "organization": "Linktop Technology Co., LTD",
        "address_1": "2F Guangye Buliding, Torch Hi-Tech,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "98EC65": {
        "oui_hex": "98-EC-65",
        "organization": "Cosesy ApS",
        "address_1": "Tyttebaervej 2",
        "address_2": "Ans  Jylland  DK-8643",
        "country": "DK"
    },
    "ACC935": {
        "oui_hex": "AC-C9-35",
        "organization": "Ness Corporation",
        "address_1": "4/167 Prospect Highway",
        "address_2": "Sydney  NSW  2147",
        "country": "AU"
    },
    "008D4E": {
        "oui_hex": "00-8D-4E",
        "organization": "CJSC NII STT",
        "address_1": "N.Leningradskaya str, 10",
        "address_2": "Smolensk    214012",
        "country": "RU"
    },
    "98F8DB": {
        "oui_hex": "98-F8-DB",
        "organization": "Marini Impianti Industriali s.r.l.",
        "address_1": "Via delle Province, 6A",
        "address_2": "Cisterna di Latina    04012",
        "country": "IT"
    },
    "E41289": {
        "oui_hex": "E4-12-89",
        "organization": "topsystem Systemhaus GmbH",
        "address_1": "Monnetstraße 24",
        "address_2": "Würselen  NRW  52146",
        "country": "DE"
    },
    "58E808": {
        "oui_hex": "58-E8-08",
        "organization": "AUTONICS CORPORATION",
        "address_1": "41-5 YONGDANG-DONG",
        "address_2": "YANGSAN-SI  KYEONGNAM  626-847",
        "country": "KR"
    },
    "DC05ED": {
        "oui_hex": "DC-05-ED",
        "organization": "Nabtesco  Corporation",
        "address_1": "9-18, Kaigan 1-chome",
        "address_2": "Minato-ku  Tokyo  105-0022",
        "country": "JP"
    },
    "4C98EF": {
        "oui_hex": "4C-98-EF",
        "organization": "Zeo",
        "address_1": "320 Nevada St",
        "address_2": "Newton   MA  02460",
        "country": "US"
    },
    "00A1DE": {
        "oui_hex": "00-A1-DE",
        "organization": "ShenZhen ShiHua Technology CO.,LTD",
        "address_1": "Room505,5/F TsingYi Building,LangShan 2ed Road,High-Tech Industrial Park,",
        "address_2": "ShenZhen  GuangDong  518052",
        "country": "CN"
    },
    "806CBC": {
        "oui_hex": "80-6C-BC",
        "organization": "NET New Electronic Technology GmbH",
        "address_1": "Lerchenberg 7",
        "address_2": "Finning  Bavarian  86923",
        "country": "DE"
    },
    "909060": {
        "oui_hex": "90-90-60",
        "organization": "RSI VIDEO TECHNOLOGIES",
        "address_1": "56, Rue Jean-Giraudoux - BAT 60",
        "address_2": "STRASBOURG  Bas-Rhin  67200",
        "country": "FR"
    },
    "BC8199": {
        "oui_hex": "BC-81-99",
        "organization": "BASIC Co.,Ltd.",
        "address_1": "Keiefu-Building 9F",
        "address_2": "Minato-ku  Tokyo  108-0014",
        "country": "JP"
    },
    "DCA7D9": {
        "oui_hex": "DC-A7-D9",
        "organization": "Compressor Controls Corp",
        "address_1": "4725 121st Street",
        "address_2": "Des Moines  Iowa  50323",
        "country": "US"
    },
    "38FEC5": {
        "oui_hex": "38-FE-C5",
        "organization": "Ellips B.V.",
        "address_1": "Esp 300",
        "address_2": "Eindhoven  Noord-Brabant  5633 AE",
        "country": "NL"
    },
    "C455A6": {
        "oui_hex": "C4-55-A6",
        "organization": "Cadac Holdings Ltd",
        "address_1": "1 New Street",
        "address_2": "Luton  Bedfordshire  LU1 5DX",
        "country": "GB"
    },
    "5C7757": {
        "oui_hex": "5C-77-57",
        "organization": "Haivision Network Video",
        "address_1": "4445 Garand",
        "address_2": "Montreal  QC  H4R 2H9",
        "country": "CA"
    },
    "D4D898": {
        "oui_hex": "D4-D8-98",
        "organization": "Korea CNO Tech Co., Ltd",
        "address_1": "#240-1,Uigok-Ri",
        "address_2": "Mungyeong-Si  Gyeongsangbuk-do  745-853",
        "country": "KR"
    },
    "B4AA4D": {
        "oui_hex": "B4-AA-4D",
        "organization": "Ensequence, Inc.",
        "address_1": "111 SW 5th Ave Suite 1400",
        "address_2": "Portland  OR  97204",
        "country": "US"
    },
    "B83D4E": {
        "oui_hex": "B8-3D-4E",
        "organization": "Shenzhen Cultraview Digital Technology Co.,Ltd Shanghai Branch",
        "address_1": "2/F,Building#5,1690Cailun Road,Zhangjiang Hi-tech Park,",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "5087B8": {
        "oui_hex": "50-87-B8",
        "organization": "Nuvyyo Inc",
        "address_1": "1 Smythe Rd",
        "address_2": "Carleton Place  Ontario  K7C4J4",
        "country": "CA"
    },
    "C0EAE4": {
        "oui_hex": "C0-EA-E4",
        "organization": "Sonicwall",
        "address_1": "2001 Logic Drive",
        "address_2": "San Jose  CA  95124-3452",
        "country": "US"
    },
    "0838A5": {
        "oui_hex": "08-38-A5",
        "organization": "Funkwerk plettac electronic GmbH",
        "address_1": "Wuerzburger Str. 150",
        "address_2": "Fuerth  Bavaria  90766",
        "country": "DE"
    },
    "CC1EFF": {
        "oui_hex": "CC-1E-FF",
        "organization": "Metrological Group BV",
        "address_1": "Mariniersweg 151",
        "address_2": "Rotterdam  Zuid-Holland  3011NK",
        "country": "NL"
    },
    "184E94": {
        "oui_hex": "18-4E-94",
        "organization": "MESSOA TECHNOLOGIES INC.",
        "address_1": "13611 12th St., Unit B",
        "address_2": "Chino  CA  91710",
        "country": "US"
    },
    "6C391D": {
        "oui_hex": "6C-39-1D",
        "organization": "Beijing ZhongHuaHun Network Information center",
        "address_1": "6F BeiAo Mansion,HuiXin East Street A2,",
        "address_2": "Beijing    100029",
        "country": "CN"
    },
    "80B32A": {
        "oui_hex": "80-B3-2A",
        "organization": "UK Grid Solutions Ltd",
        "address_1": "Harry Kerr Drive",
        "address_2": "Stafford   Staffordshire  ST17 4LX",
        "country": "GB"
    },
    "405539": {
        "oui_hex": "40-55-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "E0F211": {
        "oui_hex": "E0-F2-11",
        "organization": "Digitalwatt",
        "address_1": "Via Dante, 18",
        "address_2": "Renate Brianza  MB  20055",
        "country": "IT"
    },
    "F86971": {
        "oui_hex": "F8-69-71",
        "organization": "Seibu Electric Co.,",
        "address_1": "1458-7",
        "address_2": "Hachioji  Tokyo  193-0941",
        "country": "JP"
    },
    "44AA27": {
        "oui_hex": "44-AA-27",
        "organization": "udworks Co., Ltd.",
        "address_1": "#810, Byuksan3cha Digital Valley, 212-13, Guro-dong, Guro-gu",
        "address_2": "Seoul    152-775",
        "country": "KR"
    },
    "E8F928": {
        "oui_hex": "E8-F9-28",
        "organization": "RFTECH SRL",
        "address_1": "VIA VENETO, 22",
        "address_2": "SCHIO  VICENZA  36015",
        "country": "IT"
    },
    "1C955D": {
        "oui_hex": "1C-95-5D",
        "organization": "I-LAX ELECTRONICS INC.",
        "address_1": "2283 ARGENTIA RD.- UNIT # 10",
        "address_2": "MISSISSAUGA  ON.  L5N 5Z2",
        "country": "CA"
    },
    "60F59C": {
        "oui_hex": "60-F5-9C",
        "organization": "CRU-Dataport",
        "address_1": "1000 SE Tech Center Drive",
        "address_2": "Vancouver  WA  98683",
        "country": "US"
    },
    "B0A72A": {
        "oui_hex": "B0-A7-2A",
        "organization": "Ensemble Designs, Inc.",
        "address_1": "870 Gold Flat Road",
        "address_2": "Nevada City  CA  95959",
        "country": "US"
    },
    "6400F1": {
        "oui_hex": "64-00-F1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "B8F4D0": {
        "oui_hex": "B8-F4-D0",
        "organization": "Herrmann Ultraschalltechnik GmbH & Co. Kg",
        "address_1": "Descostraße 3-9",
        "address_2": "Karlsbad  Baden-Württemberg  76307",
        "country": "DE"
    },
    "08ACA5": {
        "oui_hex": "08-AC-A5",
        "organization": "Benu Video, Inc.",
        "address_1": "300 Concord Rd., Suite #110",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "586D8F": {
        "oui_hex": "58-6D-8F",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "10E3C7": {
        "oui_hex": "10-E3-C7",
        "organization": "Seohwa Telecom",
        "address_1": "678 Seohwa Bldg",
        "address_2": "Gasan-Dong, Gumcheon-Gu  Seoul  153-803",
        "country": "KR"
    },
    "7465D1": {
        "oui_hex": "74-65-D1",
        "organization": "Atlinks",
        "address_1": "30 Avenue Geroge V",
        "address_2": "Paris    75008",
        "country": "FR"
    },
    "040A83": {
        "oui_hex": "04-0A-83",
        "organization": "Alcatel-Lucent",
        "address_1": "Via Trento, 30",
        "address_2": "Vimenrcate  MB  2059",
        "country": "IT"
    },
    "C45600": {
        "oui_hex": "C4-56-00",
        "organization": "Galleon Embedded Computing",
        "address_1": "Grenseveien 97c",
        "address_2": "Oslo  Oslo  N-0602",
        "country": "NO"
    },
    "BC3E13": {
        "oui_hex": "BC-3E-13",
        "organization": "Accordance Systems Inc.",
        "address_1": "2F, No. 31, Sec. 6, Hsin Yi Road",
        "address_2": "Taipei    11085",
        "country": "TW"
    },
    "A81B18": {
        "oui_hex": "A8-1B-18",
        "organization": "XTS CORP",
        "address_1": "10125 NW 116TH WAY, SUITE 5",
        "address_2": "MEDLEY  FLORIDA  33178",
        "country": "US"
    },
    "D0A311": {
        "oui_hex": "D0-A3-11",
        "organization": "Neuberger Gebäudeautomation GmbH",
        "address_1": "Oberer Kaiserweg 6",
        "address_2": "Rothenburg o.d.T.  Bayern  91541",
        "country": "DE"
    },
    "041D10": {
        "oui_hex": "04-1D-10",
        "organization": "Dream Ware Inc.",
        "address_1": "5-23-7 Masugata, Tama-ku,",
        "address_2": "Kawasaki  Kanagawa  214-0032",
        "country": "JP"
    },
    "801440": {
        "oui_hex": "80-14-40",
        "organization": "Sunlit System Technology Corp",
        "address_1": "8F, No.19,Lane 120, Sec1, Neihu Rd.",
        "address_2": "Tapiei    114",
        "country": "TW"
    },
    "180B52": {
        "oui_hex": "18-0B-52",
        "organization": "Nanotron Technologies GmbH",
        "address_1": "Alt-Moabit 60",
        "address_2": "Berlin    10555",
        "country": "DE"
    },
    "DC07C1": {
        "oui_hex": "DC-07-C1",
        "organization": "HangZhou QiYang Technology Co.,Ltd.",
        "address_1": "Floor 5, Building 2, Road XiYuanYi, WestLake Technology Park,",
        "address_2": "HangZhou  ZheJiang  310028",
        "country": "CN"
    },
    "C0A26D": {
        "oui_hex": "C0-A2-6D",
        "organization": "Abbott Point of Care",
        "address_1": "400 College Road East",
        "address_2": "Princeton  NJ  08540",
        "country": "US"
    },
    "00BB8E": {
        "oui_hex": "00-BB-8E",
        "organization": "HME Co., Ltd.",
        "address_1": "No.200 , Liao Bei Str.,San Min Dist.,",
        "address_2": "Kaohsiung    807",
        "country": "TW"
    },
    "D82A7E": {
        "oui_hex": "D8-2A-7E",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "801F02": {
        "oui_hex": "80-1F-02",
        "organization": "Edimax Technology Co. Ltd.",
        "address_1": "No. 278, Xinhu 1st Road",
        "address_2": "Taipei City  Neihu Dist  248",
        "country": "TW"
    },
    "58EECE": {
        "oui_hex": "58-EE-CE",
        "organization": "Icon Time Systems",
        "address_1": "15201 NW Greenbrier Parkway",
        "address_2": "Beaverton  OR  97006",
        "country": "US"
    },
    "647FDA": {
        "oui_hex": "64-7F-DA",
        "organization": "TEKTELIC Communications Inc.",
        "address_1": "7657 10th Street NE",
        "address_2": "Calgary  Alberta  T2E 8X2",
        "country": "CA"
    },
    "AC0613": {
        "oui_hex": "AC-06-13",
        "organization": "Senselogix Ltd",
        "address_1": "56 Carlton Court, Ford William Morgan",
        "address_2": "St. Asaph  Debighshire  LL17 0JG",
        "country": "GB"
    },
    "747818": {
        "oui_hex": "74-78-18",
        "organization": "Jurumani Solutions",
        "address_1": "321 14th Road",
        "address_2": "Midrand    1685",
        "country": "ZA"
    },
    "E01F0A": {
        "oui_hex": "E0-1F-0A",
        "organization": "Xslent Energy Technologies. LLC",
        "address_1": "7428 Redwood Blvd",
        "address_2": "Novato  CA  94945",
        "country": "US"
    },
    "443719": {
        "oui_hex": "44-37-19",
        "organization": "2 Save Energy Ltd",
        "address_1": "The Annexe, Field House Barn",
        "address_2": "Sherborne St John  Hampshire  RG24 9LR",
        "country": "GB"
    },
    "84EA99": {
        "oui_hex": "84-EA-99",
        "organization": "Vieworks",
        "address_1": "6F Suntechcity 2,307-2 Sangdaewon-dong, Jungwon-gu",
        "address_2": "Seongnam   Gyeonggi  462-806",
        "country": "KR"
    },
    "E00C7F": {
        "oui_hex": "E0-0C-7F",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "E48AD5": {
        "oui_hex": "E4-8A-D5",
        "organization": "RF WINDOW CO., LTD.",
        "address_1": "14F, Daerung Posttower3",
        "address_2": "Seoul    152-746",
        "country": "KR"
    },
    "FCF1CD": {
        "oui_hex": "FC-F1-CD",
        "organization": "OPTEX-FA CO.,LTD.",
        "address_1": "91 Awata-cho",
        "address_2": "Kyoto    600-8815",
        "country": "JP"
    },
    "4425BB": {
        "oui_hex": "44-25-BB",
        "organization": "Bamboo Entertainment Corporation",
        "address_1": "179 South Street",
        "address_2": "Boston  MA  02111",
        "country": "US"
    },
    "7CDA84": {
        "oui_hex": "7C-DA-84",
        "organization": "Dongnian Networks Inc.",
        "address_1": "90 Wensan Road, Building 8-A303",
        "address_2": "Hangzhou  Zhejiang  310012",
        "country": "CN"
    },
    "BCC61A": {
        "oui_hex": "BC-C6-1A",
        "organization": "SPECTRA EMBEDDED SYSTEMS",
        "address_1": "Khasra No. 24, Village Ghumman,1st Floor, Chawla Mansion,",
        "address_2": "Parwanoo  Himachal Pradesh  173 220",
        "country": "IN"
    },
    "0470BC": {
        "oui_hex": "04-70-BC",
        "organization": "Globalstar Inc.",
        "address_1": "461 S Milpitas Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "88DD79": {
        "oui_hex": "88-DD-79",
        "organization": "Voltaire",
        "address_1": "13, Zarchin St",
        "address_2": "Raanana    43662",
        "country": "IL"
    },
    "64F987": {
        "oui_hex": "64-F9-87",
        "organization": "Avvasi Inc.",
        "address_1": "103 Randall Dr.",
        "address_2": "Waterloo  ON  N2V 1C5",
        "country": "CA"
    },
    "D85D84": {
        "oui_hex": "D8-5D-84",
        "organization": "CAx soft GmbH",
        "address_1": "Noettinger Strasse 3",
        "address_2": "Karlsbad  BW  76307",
        "country": "DE"
    },
    "D4E32C": {
        "oui_hex": "D4-E3-2C",
        "organization": "S. Siedle & Sohne",
        "address_1": "Bregstrasse 1",
        "address_2": "Furtwangen    D-78120",
        "country": "DE"
    },
    "7C6ADB": {
        "oui_hex": "7C-6A-DB",
        "organization": "SafeTone Technology Co.,Ltd",
        "address_1": "Room 323,ZhuouJi Plaza,No.16 AnDe Road,East District,",
        "address_2": "Beijing    100011",
        "country": "CN"
    },
    "902E87": {
        "oui_hex": "90-2E-87",
        "organization": "LabJack",
        "address_1": "3232 S Vance St STE 100",
        "address_2": "Lakewood  CO  80227",
        "country": "US"
    },
    "A424B3": {
        "oui_hex": "A4-24-B3",
        "organization": "FlatFrog Laboratories AB",
        "address_1": "Magistratsvägen 10",
        "address_2": "Lund  Skåne  22643",
        "country": "SE"
    },
    "94CDAC": {
        "oui_hex": "94-CD-AC",
        "organization": "Creowave Oy",
        "address_1": "Lentokatu 2",
        "address_2": "Oulunsalo    FIN-90460",
        "country": "FI"
    },
    "144C1A": {
        "oui_hex": "14-4C-1A",
        "organization": "Max Communication GmbH",
        "address_1": "Siemensstrasse 47",
        "address_2": "Rellingen    25462",
        "country": "DE"
    },
    "340804": {
        "oui_hex": "34-08-04",
        "organization": "D-Link Corporation",
        "address_1": "No.289, Sinhu 3rd Rd., Neihu District,",
        "address_2": "Taipei City     114",
        "country": "TW"
    },
    "F05D89": {
        "oui_hex": "F0-5D-89",
        "organization": "Dycon Limited",
        "address_1": "Unit D",
        "address_2": "Mountain Ash  Rhondda Cynon Taff  CF45 4ER",
        "country": "GB"
    },
    "AC80D6": {
        "oui_hex": "AC-80-D6",
        "organization": "Hexatronic AB",
        "address_1": "Exportgatan 47B",
        "address_2": "Gothenburg    42246",
        "country": "SE"
    },
    "9CF938": {
        "oui_hex": "9C-F9-38",
        "organization": "AREVA NP GmbH",
        "address_1": "Seligenstaedter Str. 100",
        "address_2": "Karlstein  Germany  63791",
        "country": "DE"
    },
    "8CDB25": {
        "oui_hex": "8C-DB-25",
        "organization": "ESG Solutions",
        "address_1": "20 Hyperion Court",
        "address_2": "Kingston  Ontario  K7K 7K2",
        "country": "CA"
    },
    "FC3598": {
        "oui_hex": "FC-35-98",
        "organization": "Favite Inc.",
        "address_1": "No.19, Lane 78, Yanhe St.,",
        "address_2": "Jhubei City  Hsinchu County  302",
        "country": "TW"
    },
    "90D92C": {
        "oui_hex": "90-D9-2C",
        "organization": "HUG-WITSCHI AG",
        "address_1": "Auriedstrasse 10",
        "address_2": "Boesingen  Fribourg  3178",
        "country": "CH"
    },
    "988E34": {
        "oui_hex": "98-8E-34",
        "organization": "ZHEJIANG BOXSAM ELECTRONIC CO.,LTD",
        "address_1": "No.288,LONGTAN ROAD,",
        "address_2": "JINHUA CITY  ZHEJIANG PROVINCE,  321017",
        "country": "CN"
    },
    "C471FE": {
        "oui_hex": "C4-71-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4022ED": {
        "oui_hex": "40-22-ED",
        "organization": "Digital Projection Ltd",
        "address_1": "Greenside Way",
        "address_2": "Manchester  Lancs  M24 1XX",
        "country": "GB"
    },
    "989449": {
        "oui_hex": "98-94-49",
        "organization": "Skyworth Wireless Technology Ltd.",
        "address_1": "Unit A Rm.3A01, Skyworth Bldg., Gaoxin Ave. 1.S.,",
        "address_2": "Nanshan District  Shenzhen  518057",
        "country": "CN"
    },
    "2CA157": {
        "oui_hex": "2C-A1-57",
        "organization": "acromate, Inc.",
        "address_1": "#1101, JnK Digital Tower, 111",
        "address_2": "Seoul    152-848",
        "country": "KR"
    },
    "942053": {
        "oui_hex": "94-20-53",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "28852D": {
        "oui_hex": "28-85-2D",
        "organization": "Touch Networks",
        "address_1": "2515 152nd Ave NE",
        "address_2": "Redmond  Washington  98052",
        "country": "US"
    },
    "B8BA68": {
        "oui_hex": "B8-BA-68",
        "organization": "Xi'an Jizhong Digital Communication Co.,Ltd",
        "address_1": "10 Block NO.1 Enterprise Newly-typed Industrial Zone High-Tech Zone XiÂ¡Â¯an,China",
        "address_2": "Xi'an  ShaanXi  710119",
        "country": "CN"
    },
    "B0B32B": {
        "oui_hex": "B0-B3-2B",
        "organization": "Slican Sp. z o.o.",
        "address_1": "M. Konopnickiej 18",
        "address_2": "Bydgoszcz  Kujawsko-Pomorskie  85-124",
        "country": "PL"
    },
    "5842E4": {
        "oui_hex": "58-42-E4",
        "organization": "Baxter International Inc",
        "address_1": "One Baxter Parkway",
        "address_2": "Deerfield  IL  60015",
        "country": "US"
    },
    "B8797E": {
        "oui_hex": "B8-79-7E",
        "organization": "Secure Meters (UK) Limited",
        "address_1": "Secure House",
        "address_2": "Winchester  Hampshire  SO23 7RX",
        "country": "GB"
    },
    "CC9E00": {
        "oui_hex": "CC-9E-00",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "58A76F": {
        "oui_hex": "58-A7-6F",
        "organization": "iD corporation",
        "address_1": "goryokaku bld. 2F",
        "address_2": "hakodate  hokkaido  040-0011",
        "country": "JP"
    },
    "0006F6": {
        "oui_hex": "00-06-F6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "747DB6": {
        "oui_hex": "74-7D-B6",
        "organization": "Aliwei Communications, Inc",
        "address_1": "Keji 6 Road , Hi-tech Industrial Park",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B06563": {
        "oui_hex": "B0-65-63",
        "organization": "Shanghai Railway Communication Factory",
        "address_1": "No.179 West Jiangchang road",
        "address_2": "Shanghai    200436",
        "country": "CN"
    },
    "4018D7": {
        "oui_hex": "40-18-D7",
        "organization": "Smartronix, Inc.",
        "address_1": "44150 Smartronix Way",
        "address_2": "Hollywood  MD  20636",
        "country": "US"
    },
    "4C2C80": {
        "oui_hex": "4C-2C-80",
        "organization": "Beijing Skyway Technologies Co.,Ltd",
        "address_1": "No.5 Jiangtai Road,",
        "address_2": "Beijing    100015",
        "country": "CN"
    },
    "D49E6D": {
        "oui_hex": "D4-9E-6D",
        "organization": "Wuhan Zhongyuan Huadian Science & Technology Co.,",
        "address_1": "NO.6, 6 Road, Sci. & Tech. region of HUST, East Lake Development Zone,",
        "address_2": "Wuhan   Hubei  430223",
        "country": "CN"
    },
    "6C2E33": {
        "oui_hex": "6C-2E-33",
        "organization": "Accelink Technologies Co.,Ltd.",
        "address_1": "88 Youkeyuan Road,",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "40987B": {
        "oui_hex": "40-98-7B",
        "organization": "Aisino Corporation",
        "address_1": "No.18 A,Xingshikou Road,Haidian District,",
        "address_2": "Beijing    100195",
        "country": "CN"
    },
    "BC38D2": {
        "oui_hex": "BC-38-D2",
        "organization": "Pandachip Limited",
        "address_1": "Unit 210, 2/F (Lakeside 1), Building 15, No. 8 Science Park West Avenue",
        "address_2": "Shatin, N.T.",
        "country": "HK"
    },
    "2005E8": {
        "oui_hex": "20-05-E8",
        "organization": "OOO InProMedia",
        "address_1": "pr.4806, d.6",
        "address_2": "Zelenograd  Moscow  124466",
        "country": "RU"
    },
    "F00248": {
        "oui_hex": "F0-02-48",
        "organization": "SmarteBuilding",
        "address_1": "3267 Bee Cave Road",
        "address_2": "Austin  TX  78746",
        "country": "US"
    },
    "AC6F4F": {
        "oui_hex": "AC-6F-4F",
        "organization": "Enspert Inc",
        "address_1": "2F., Daehwa B/D,",
        "address_2": "Seoul    135090",
        "country": "KR"
    },
    "E82877": {
        "oui_hex": "E8-28-77",
        "organization": "TMY Co., Ltd.",
        "address_1": "Attic Bldg. 3F, 1-2-10 Ise-cho,",
        "address_2": "Ashikaga-shi  Tochigi  326-0053",
        "country": "JP"
    },
    "F0C88C": {
        "oui_hex": "F0-C8-8C",
        "organization": "LeddarTech Inc.",
        "address_1": "2740 Einstein Street",
        "address_2": "Quebec City    G1P 4S4",
        "country": "CA"
    },
    "4037AD": {
        "oui_hex": "40-37-AD",
        "organization": "Macro Image Technology, Inc.",
        "address_1": "East Bldg., 6th Floor, IT Venture Tower,",
        "address_2": "Seoul    138-950",
        "country": "KR"
    },
    "28ED58": {
        "oui_hex": "28-ED-58",
        "organization": "JAG Jakob AG",
        "address_1": "Industriestrasse 20",
        "address_2": "BRUEGG  BE  2555",
        "country": "CH"
    },
    "486B91": {
        "oui_hex": "48-6B-91",
        "organization": "Fleetwood Group Inc.",
        "address_1": "11832 James St",
        "address_2": "Holland  Michigan  49424",
        "country": "US"
    },
    "643409": {
        "oui_hex": "64-34-09",
        "organization": "BITwave Pte Ltd",
        "address_1": "2 Serangoon North Ave 5",
        "address_2": "    554911",
        "country": "SG"
    },
    "40C245": {
        "oui_hex": "40-C2-45",
        "organization": "Shenzhen Hexicom Technology Co., Ltd.",
        "address_1": "1510 West Building,Nanshan Software Park, Nanshan Dist.",
        "address_2": "Shenzhen  Guangdong  518053",
        "country": "CN"
    },
    "CC55AD": {
        "oui_hex": "CC-55-AD",
        "organization": "RIM",
        "address_1": "Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "E8757F": {
        "oui_hex": "E8-75-7F",
        "organization": "FIRS Technologies(Shenzhen) Co., Ltd",
        "address_1": "Rm 12A, Area A, Hongsong Business Building, Tairan 9th Rd, Chegongmiao,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "F0F7B3": {
        "oui_hex": "F0-F7-B3",
        "organization": "Phorm",
        "address_1": "222 Regent Street",
        "address_2": "London    W1B 5TR",
        "country": "GB"
    },
    "00D38D": {
        "oui_hex": "00-D3-8D",
        "organization": "Hotel Technology Next Generation",
        "address_1": "650 E. Algonquin Road",
        "address_2": "Schaumburg  IL  60173",
        "country": "US"
    },
    "C83EA7": {
        "oui_hex": "C8-3E-A7",
        "organization": "KUNBUS GmbH",
        "address_1": "Heerweg 15C",
        "address_2": "Denkendorf  BW  D-73770",
        "country": "DE"
    },
    "60893C": {
        "oui_hex": "60-89-3C",
        "organization": "Thermo Fisher Scientific P.O.A.",
        "address_1": "46 Jonspin Rd.",
        "address_2": "Wilmington  MA  01887",
        "country": "US"
    },
    "D86BF7": {
        "oui_hex": "D8-6B-F7",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "74CD0C": {
        "oui_hex": "74-CD-0C",
        "organization": "Smith Myers Communications Ltd.",
        "address_1": "The Omega Centre",
        "address_2": "Biggleswade  BEDS  SG18 8QB",
        "country": "GB"
    },
    "CCCE40": {
        "oui_hex": "CC-CE-40",
        "organization": "Janteq Corp",
        "address_1": "9272 Jeronimo Road",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "B8EE79": {
        "oui_hex": "B8-EE-79",
        "organization": "YWire Technologies, Inc.",
        "address_1": "1372 Overdale",
        "address_2": "Montreal  QC  H3G 1V3",
        "country": "CA"
    },
    "74D675": {
        "oui_hex": "74-D6-75",
        "organization": "WYMA Tecnologia",
        "address_1": "Rua Clímaco Barbosa, 171-179",
        "address_2": "São Paulo    01523-000",
        "country": "BR"
    },
    "B40EDC": {
        "oui_hex": "B4-0E-DC",
        "organization": "LG-Ericsson Co.,Ltd.",
        "address_1": "533,Hogye-1dong,Dongan-gu",
        "address_2": "Anyang-shi  Kyungki-do  431-749",
        "country": "KR"
    },
    "E0EE1B": {
        "oui_hex": "E0-EE-1B",
        "organization": "Panasonic Automotive Systems Company of America",
        "address_1": "776 Highway 74 South",
        "address_2": "Peachtree City  Georgia  30269",
        "country": "US"
    },
    "74BE08": {
        "oui_hex": "74-BE-08",
        "organization": "ATEK Products, LLC",
        "address_1": "210 NE 10th Avenue",
        "address_2": "Brainerd  MN  56401",
        "country": "US"
    },
    "6063FD": {
        "oui_hex": "60-63-FD",
        "organization": "Transcend Communication Beijing Co.,Ltd.",
        "address_1": "A-6,Keshi plaza,28#,Information Road",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "D8B6C1": {
        "oui_hex": "D8-B6-C1",
        "organization": "NetworkAccountant, Inc.",
        "address_1": "12101 Tukwila International Blvd.",
        "address_2": "Seattle  Washington  98168",
        "country": "US"
    },
    "74A4A7": {
        "oui_hex": "74-A4-A7",
        "organization": "QRS Music Technologies, Inc.",
        "address_1": "269 Quaker Drive",
        "address_2": "Seneca  PA  16346",
        "country": "US"
    },
    "700258": {
        "oui_hex": "70-02-58",
        "organization": "01DB-METRAVIB",
        "address_1": "200 CHEMIN DES ORMEAUX",
        "address_2": "LIMONEST CEDEX  RHONE  69578",
        "country": "FR"
    },
    "F455E0": {
        "oui_hex": "F4-55-E0",
        "organization": "Niceway CNC Technology Co.,Ltd.Hunan Province",
        "address_1": "5/F,Innovation-Undertaking Center,HuanBao Industrial Park,199#,ZhenHua Road,",
        "address_2": "Changsha  Hunan  410116",
        "country": "CN"
    },
    "20FDF1": {
        "oui_hex": "20-FD-F1",
        "organization": "3COM EUROPE LTD",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  HERTS.  HP2 4NW",
        "country": "GB"
    },
    "8497B8": {
        "oui_hex": "84-97-B8",
        "organization": "Memjet Inc.",
        "address_1": "15920 Bernardo Center Drive",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "A0DDE5": {
        "oui_hex": "A0-DD-E5",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "206AFF": {
        "oui_hex": "20-6A-FF",
        "organization": "Atlas Elektronik UK Limited",
        "address_1": "A22 Buliding, Dorset Green Tech. Park",
        "address_2": "Dorchester  Dorset  DT2 8ZB",
        "country": "GB"
    },
    "AC34CB": {
        "oui_hex": "AC-34-CB",
        "organization": "Shanhai GBCOM Communication Technology Co. Ltd",
        "address_1": "Room 602, Building 6, No.555 Dongchuan Road",
        "address_2": "Shanghai     200241",
        "country": "CN"
    },
    "9088A2": {
        "oui_hex": "90-88-A2",
        "organization": "IONICS TECHNOLOGY ME LTDA",
        "address_1": "RUA DEP. ANTONIO EDU VIEIRA",
        "address_2": "FLORIAN POLIS  SANTA CATARINA  88040000",
        "country": "BR"
    },
    "40CD3A": {
        "oui_hex": "40-CD-3A",
        "organization": "Z3 Technology",
        "address_1": "2720 Harrison St",
        "address_2": "Evanston  IL  60201",
        "country": "US"
    },
    "482CEA": {
        "oui_hex": "48-2C-EA",
        "organization": "Motorola Inc Business Light Radios",
        "address_1": "8000 W Sunrise Boulevard",
        "address_2": "Plantation  Florida  33324",
        "country": "US"
    },
    "00336C": {
        "oui_hex": "00-33-6C",
        "organization": "SynapSense Corporation",
        "address_1": "2365 Iron Point Road, Suite 100",
        "address_2": "Folsom  CA  95630",
        "country": "US"
    },
    "2CD1DA": {
        "oui_hex": "2C-D1-DA",
        "organization": "Sanjole, Inc.",
        "address_1": "2800 Woodlawn Drive, #271",
        "address_2": "Honolulu  Hawaii  96822",
        "country": "US"
    },
    "F866F2": {
        "oui_hex": "F8-66-F2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "AC6123": {
        "oui_hex": "AC-61-23",
        "organization": "Drivven, Inc.",
        "address_1": "12001 Network Boulevard",
        "address_2": "San Antonio  TX  78249",
        "country": "US"
    },
    "100C24": {
        "oui_hex": "10-0C-24",
        "organization": "pomdevices, LLC",
        "address_1": "178 Colvard Park Dr",
        "address_2": "Durham  NC  27713",
        "country": "US"
    },
    "58F6BF": {
        "oui_hex": "58-F6-BF",
        "organization": "Kyoto University",
        "address_1": "Yoshida-Hommachi",
        "address_2": "Kyoto    6068501",
        "country": "JP"
    },
    "78EC22": {
        "oui_hex": "78-EC-22",
        "organization": "Shanghai Qihui Telecom Technology Co., LTD",
        "address_1": "Room 501, No 2 BoYun Rd, PuDong New Area,",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "0C15C5": {
        "oui_hex": "0C-15-C5",
        "organization": "SDTEC Co., Ltd.",
        "address_1": "167, Churye-2Dong, Sasang-Gu,",
        "address_2": "Busan     617-716",
        "country": "KR"
    },
    "FC75E6": {
        "oui_hex": "FC-75-E6",
        "organization": "Handreamnet",
        "address_1": "#1209 MarioTower, 222-12, Guro-Dong, Guro-Gu",
        "address_2": "Seoul  Guro-Gu  152-848",
        "country": "KR"
    },
    "A0A763": {
        "oui_hex": "A0-A7-63",
        "organization": "Polytron Vertrieb GmbH",
        "address_1": "Langwiesenweg 64-71",
        "address_2": "Bad Wildbad  Baden-Württemberg  75323",
        "country": "DE"
    },
    "EC2368": {
        "oui_hex": "EC-23-68",
        "organization": "IntelliVoice Co.,Ltd.",
        "address_1": "3-6 Kioicho",
        "address_2": "Chiyoda  Tokyo  102-0094",
        "country": "JP"
    },
    "749050": {
        "oui_hex": "74-90-50",
        "organization": "Renesas Electronics Corporation",
        "address_1": "1753, Shimonumabe, Nakahara-Ku",
        "address_2": "Kawasaki  Kanagawa  211-8668",
        "country": "JP"
    },
    "389592": {
        "oui_hex": "38-95-92",
        "organization": "Beijing Tendyron Corporation",
        "address_1": "1810,Tower B,Jin-ma,Building,17 East Qing Hua Road",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "A4218A": {
        "oui_hex": "A4-21-8A",
        "organization": "Nortel Networks",
        "address_1": "CARRETERA BASE AEREA # 5850",
        "address_2": "Zapopan  Jalisco  44130",
        "country": "MX"
    },
    "F8FB2F": {
        "oui_hex": "F8-FB-2F",
        "organization": "Santur Corporation",
        "address_1": "40931 Encyclopedia Circle",
        "address_2": "Fremont  California  94538",
        "country": "US"
    },
    "2CCD43": {
        "oui_hex": "2C-CD-43",
        "organization": "Summit Technology Group",
        "address_1": "145 Belmont Drive",
        "address_2": "Somerset  NJ  08873",
        "country": "US"
    },
    "64995D": {
        "oui_hex": "64-99-5D",
        "organization": "LGE",
        "address_1": "60-39 , Kasan -dong , Gumcheon-gu.",
        "address_2": "Seoul     153-801",
        "country": "KR"
    },
    "7CEF18": {
        "oui_hex": "7C-EF-18",
        "organization": "Creative Product Design Pty. Ltd.",
        "address_1": "82 Victoria Street",
        "address_2": "Sandringham  Victoria  3191",
        "country": "AU"
    },
    "FC7CE7": {
        "oui_hex": "FC-7C-E7",
        "organization": "FCI USA LLC",
        "address_1": "825 Old Trail Road",
        "address_2": "Etters  PA  17319",
        "country": "US"
    },
    "145412": {
        "oui_hex": "14-54-12",
        "organization": "Entis Co., Ltd.",
        "address_1": "2-20-6, Hanaoka Bldg, 6F",
        "address_2": "Tokyo    1030007",
        "country": "JP"
    },
    "7C3E9D": {
        "oui_hex": "7C-3E-9D",
        "organization": "PATECH",
        "address_1": "#23-17. WonhyoRo-2Ga",
        "address_2": "YongSan-Gu  Seoul  140112",
        "country": "KR"
    },
    "244597": {
        "oui_hex": "24-45-97",
        "organization": "GEMUE Gebr. Mueller Apparatebau",
        "address_1": "Fritz-Mueller-Strasse 6-8",
        "address_2": "Ingelfingen Criesbach    74653",
        "country": "DE"
    },
    "78818F": {
        "oui_hex": "78-81-8F",
        "organization": "Server Racks Australia Pty Ltd",
        "address_1": "4 - 6 Endurance Ave",
        "address_2": "Queanbeyan  NSW  2620",
        "country": "AU"
    },
    "284846": {
        "oui_hex": "28-48-46",
        "organization": "GridCentric Inc.",
        "address_1": "350 Bloor St. E",
        "address_2": "Toronto  Ontario  M4W 0A1",
        "country": "CA"
    },
    "30694B": {
        "oui_hex": "30-69-4B",
        "organization": "RIM",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "6C626D": {
        "oui_hex": "6C-62-6D",
        "organization": "Micro-Star INT'L CO., LTD",
        "address_1": "No.69, Lide St., Jhonghe City",
        "address_2": "Taipei Conuty    235",
        "country": "TW"
    },
    "28068D": {
        "oui_hex": "28-06-8D",
        "organization": "ITL, LLC",
        "address_1": "P.O. Box 41875",
        "address_2": "Nashville  TN  37204",
        "country": "US"
    },
    "C00D7E": {
        "oui_hex": "C0-0D-7E",
        "organization": "Additech, Inc.",
        "address_1": "10925 Kinghurst",
        "address_2": "Houston  TX  77099",
        "country": "US"
    },
    "84C7A9": {
        "oui_hex": "84-C7-A9",
        "organization": "C3PO S.A.",
        "address_1": "Alejandro Goicoechea 6 Local 9",
        "address_2": "Sant Just Desvern  Barcelona  ES08960",
        "country": "ES"
    },
    "D87157": {
        "oui_hex": "D8-71-57",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "No.999,Qishan North 2nd Road,Information&Optoelectronics Park,Torch Hi-tech Industry Development Zone,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "609AA4": {
        "oui_hex": "60-9A-A4",
        "organization": "GVI SECURITY INC.",
        "address_1": "2801 TRADE CENTER DR STE.120",
        "address_2": "CARROLLTON  TX  75007",
        "country": "US"
    },
    "641084": {
        "oui_hex": "64-10-84",
        "organization": "HEXIUM Technical Development Co., Ltd.",
        "address_1": "Vaci ut 51b",
        "address_2": "BUDAPEST    H-1134",
        "country": "HU"
    },
    "342109": {
        "oui_hex": "34-21-09",
        "organization": "Jensen Scandinavia AS",
        "address_1": "Balder Allé 3",
        "address_2": "Jessheim    2050",
        "country": "NO"
    },
    "3C106F": {
        "oui_hex": "3C-10-6F",
        "organization": "ALBAHITH TECHNOLOGIES",
        "address_1": "165, King Abdullah Second Street",
        "address_2": "Amman    11953",
        "country": "JO"
    },
    "0CDDEF": {
        "oui_hex": "0C-DD-EF",
        "organization": "Nokia Corporation",
        "address_1": "Elektroniikkatie 10",
        "address_2": "Oulu    90570",
        "country": "FI"
    },
    "ECFE7E": {
        "oui_hex": "EC-FE-7E",
        "organization": "BlueRadios, Inc.",
        "address_1": "7173 S. Havana Street, Suite 600",
        "address_2": "Englewood  Colorado  80112",
        "country": "US"
    },
    "E4AD7D": {
        "oui_hex": "E4-AD-7D",
        "organization": "SCL Elements",
        "address_1": "5800 St-Denis, #222",
        "address_2": "Montreal  Quebec  H2S3l5",
        "country": "CA"
    },
    "F09CBB": {
        "oui_hex": "F0-9C-BB",
        "organization": "RaonThink Inc.",
        "address_1": "916, Byucksan Digital Valley 2-Cha, 481-10, Kasan-Dong, Kumcheon-Gu,",
        "address_2": "Seoul    153-783",
        "country": "KR"
    },
    "10CCDB": {
        "oui_hex": "10-CC-DB",
        "organization": "AXIMUM PRODUITS ELECTRONIQUES",
        "address_1": "ZI DELTA INDUSTRIE",
        "address_2": "MARSEILLE CEDEX 11    13368",
        "country": "FR"
    },
    "38C7BA": {
        "oui_hex": "38-C7-BA",
        "organization": "CS Services Co.,Ltd.",
        "address_1": "Imon BLDG 95 Edomachi",
        "address_2": "Kobe  Hyogo  6500033",
        "country": "JP"
    },
    "EC5C69": {
        "oui_hex": "EC-5C-69",
        "organization": "MITSUBISHI HEAVY INDUSTRIES MECHATRONICS SYSTEMS,LTD.",
        "address_1": "1-16,5-CHOME,KOMATSU-DORI,",
        "address_2": "KOBE  HYOGO  652-0865",
        "country": "JP"
    },
    "6C92BF": {
        "oui_hex": "6C-92-BF",
        "organization": "Inspur Electronic Information Industry Co.,Ltd.",
        "address_1": "No 224 Shanda Road",
        "address_2": "Jinan  Shandong  250013",
        "country": "CN"
    },
    "44A8C2": {
        "oui_hex": "44-A8-C2",
        "organization": "SEWOO TECH CO., LTD",
        "address_1": "689-20 GEUMJUNG-DONG",
        "address_2": "GUNPO-SI  KYUNGGI-DO  435-862",
        "country": "KR"
    },
    "80EE73": {
        "oui_hex": "80-EE-73",
        "organization": "Shuttle Inc.",
        "address_1": "No. 30 Lane 76, Rei Kuang Rd",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "FCE23F": {
        "oui_hex": "FC-E2-3F",
        "organization": "CLAY PAKY SPA",
        "address_1": "Via Pastrengo 3/b",
        "address_2": "Seriate  Bergamo  24068",
        "country": "IT"
    },
    "58570D": {
        "oui_hex": "58-57-0D",
        "organization": "Danfoss Solar Inverters",
        "address_1": "Jyllandsgade 28",
        "address_2": "Sønderborg    DK-6400",
        "country": "DK"
    },
    "C4823F": {
        "oui_hex": "C4-82-3F",
        "organization": "Fujian Newland Auto-ID Tech. Co,.Ltd.",
        "address_1": "Newland Science & Technology Park, No.1 Rujiang West Rd., Mawei",
        "address_2": "Fuzhou  Fujian  350015",
        "country": "CN"
    },
    "E85B5B": {
        "oui_hex": "E8-5B-5B",
        "organization": "LG ELECTRONICS INC",
        "address_1": "19-1, CHEONGHO-RI, JINWI-MYEON",
        "address_2": "PYEONGTAEK  GYEONGGI-DO  451-713",
        "country": "KR"
    },
    "BCA9D6": {
        "oui_hex": "BC-A9-D6",
        "organization": "Cyber-Rain, Inc.",
        "address_1": "5272 Evanwood Avenue",
        "address_2": "Oak Park  California  91377-4809",
        "country": "US"
    },
    "6C3E9C": {
        "oui_hex": "6C-3E-9C",
        "organization": "KE Knestel Elektronik GmbH",
        "address_1": "Osterwalder Str. 12",
        "address_2": "Hopferbach  Bavaria  87496",
        "country": "DE"
    },
    "8CD628": {
        "oui_hex": "8C-D6-28",
        "organization": "Ikor Metering",
        "address_1": "Francisco Grandmontagne 4",
        "address_2": "San Sebastian  Guipuzcoa  20008",
        "country": "ES"
    },
    "243C20": {
        "oui_hex": "24-3C-20",
        "organization": "Dynamode Group",
        "address_1": "Head Office, 132a St Albans Road",
        "address_2": "Watford  Herts  WD24 4AE",
        "country": "GB"
    },
    "3C39C3": {
        "oui_hex": "3C-39-C3",
        "organization": "JW Electronics Co., Ltd.",
        "address_1": "3A17, No. 5 Hsin-yi Rd., Sec. 5",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "3C05AB": {
        "oui_hex": "3C-05-AB",
        "organization": "Product Creation Studio",
        "address_1": "425 Westlake Ave N",
        "address_2": "Seattle  WA  98109",
        "country": "US"
    },
    "F04335": {
        "oui_hex": "F0-43-35",
        "organization": "DVN(Shanghai)Ltd.",
        "address_1": "11F,Hechuan Building,2016 Yishan Rd,",
        "address_2": "Shanghai    201103",
        "country": "CN"
    },
    "A479E4": {
        "oui_hex": "A4-79-E4",
        "organization": "KLINFO Corp",
        "address_1": "301 923 wolpyung-dong",
        "address_2": "Daejeon    302-852",
        "country": "KR"
    },
    "481BD2": {
        "oui_hex": "48-1B-D2",
        "organization": "Intron Scientific co., ltd.",
        "address_1": "6F., NO. 136,Sec 2,Keelung Rd., Da-an district",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "D0F0DB": {
        "oui_hex": "D0-F0-DB",
        "organization": "Ericsson",
        "address_1": "250 Holger Way",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "7C1476": {
        "oui_hex": "7C-14-76",
        "organization": "Damall Technologies SAS",
        "address_1": "Corso della Repubblica 65",
        "address_2": "Fabriano  Ancona  60044",
        "country": "IT"
    },
    "8C541D": {
        "oui_hex": "8C-54-1D",
        "organization": "LGE",
        "address_1": "60-39 , Kasan -dong , Gumcheon-gu.",
        "address_2": "Seoul     153-801",
        "country": "KR"
    },
    "00A2DA": {
        "oui_hex": "00-A2-DA",
        "organization": "INAT GmbH",
        "address_1": "Ostendstraße 50A",
        "address_2": "Nuremberg  Bavaria  90482",
        "country": "DE"
    },
    "003CC5": {
        "oui_hex": "00-3C-C5",
        "organization": "WONWOO Engineering Co., Ltd",
        "address_1": "7F 201, Techno-Park SsangYong III,",
        "address_2": "Bucheon City  Gyeonggi-Do  421-808",
        "country": "KR"
    },
    "F077D0": {
        "oui_hex": "F0-77-D0",
        "organization": "Xcellen",
        "address_1": "15F KINS Tower 25-1,Jeongja-dong,Bungdang-gu,",
        "address_2": "Seongnam  Gyeonggi  463811",
        "country": "KR"
    },
    "4CC602": {
        "oui_hex": "4C-C6-02",
        "organization": "Radios, Inc.",
        "address_1": "31355 State Road 46",
        "address_2": "Sorrenot  Floriad  32776",
        "country": "US"
    },
    "80711F": {
        "oui_hex": "80-71-1F",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "88FD15": {
        "oui_hex": "88-FD-15",
        "organization": "LINEEYE CO., LTD",
        "address_1": "5F Marufuku Bldg. 39-1 Karahashi",
        "address_2": "Kyoto    601-8468",
        "country": "JP"
    },
    "884B39": {
        "oui_hex": "88-4B-39",
        "organization": "Siemens AG, Healthcare Sector",
        "address_1": "Henkestrasse 127",
        "address_2": "Erlangen  Bavaria  91052",
        "country": "DE"
    },
    "D828C9": {
        "oui_hex": "D8-28-C9",
        "organization": "General Electric Consumer and Industrial",
        "address_1": "AP35-1405",
        "address_2": "Louisville  KY  40225",
        "country": "US"
    },
    "44C233": {
        "oui_hex": "44-C2-33",
        "organization": "Guangzhou Comet Technology Development Co.Ltd",
        "address_1": "Rm 304,FL 3,Block G,Science and  Technology Innovation Base,",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "30EFD1": {
        "oui_hex": "30-EF-D1",
        "organization": "Alstom Strongwish (Shenzhen) Co., Ltd.",
        "address_1": "5F,Building No.6, Keji Middle 2 Road High-Tech Industrial Park,",
        "address_2": "Shen Zhen  Guangdong  518057",
        "country": "CN"
    },
    "7C2CF3": {
        "oui_hex": "7C-2C-F3",
        "organization": "Secure Electrans Ltd",
        "address_1": "Pioneer House, Pioneer Business Park",
        "address_2": "Ellesmere Port    CH65 1AD",
        "country": "GB"
    },
    "081651": {
        "oui_hex": "08-16-51",
        "organization": "SHENZHEN SEA STAR TECHNOLOGY CO.,LTD",
        "address_1": "Seastar industrial Park, BaoLong  6th Ave",
        "address_2": "ShenZhen  GuangDong  518116",
        "country": "CN"
    },
    "A863DF": {
        "oui_hex": "A8-63-DF",
        "organization": "DISPLAIRE CORPORATION",
        "address_1": "1300 Valley House Dr, Ste 100",
        "address_2": "Rohnert Park  CA  94928",
        "country": "US"
    },
    "183BD2": {
        "oui_hex": "18-3B-D2",
        "organization": "BYD Precision Manufacture Company Ltd.",
        "address_1": "No3000 LongDong Avenue, Pudong District",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "E43593": {
        "oui_hex": "E4-35-93",
        "organization": "Hangzhou GoTo technology Co.Ltd",
        "address_1": "Room 1303,Boee buliding,3760 Nanhuan Road, Binjiang,",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "2C3A28": {
        "oui_hex": "2C-3A-28",
        "organization": "Fagor Electrónica",
        "address_1": "B. San Andres, s/n",
        "address_2": "Mondragón  Guipuzcoa  20500",
        "country": "ES"
    },
    "B45861": {
        "oui_hex": "B4-58-61",
        "organization": "CRemote, LLC",
        "address_1": "1195 Noel Drive",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "B0973A": {
        "oui_hex": "B0-97-3A",
        "organization": "E-Fuel Corporation",
        "address_1": "15466 Los Gatos Blvd. #37",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "204E6B": {
        "oui_hex": "20-4E-6B",
        "organization": "Axxana(israel) ltd",
        "address_1": "Habarzel 38",
        "address_2": "Tel aviv    69710",
        "country": "IL"
    },
    "80F593": {
        "oui_hex": "80-F5-93",
        "organization": "IRCO Sistemas de Telecomunicación S.A.",
        "address_1": "Via Sergia 98",
        "address_2": "Mataró  Barcelona  08302",
        "country": "ES"
    },
    "E497F0": {
        "oui_hex": "E4-97-F0",
        "organization": "Shanghai VLC Technologies Ltd. Co.",
        "address_1": "Room 901, B-Zone, East Beijing Road",
        "address_2": "Shanghai    200001",
        "country": "CN"
    },
    "B40832": {
        "oui_hex": "B4-08-32",
        "organization": "TC Communications",
        "address_1": "17575 Cartwright Road",
        "address_2": "Irvine  CA  92614",
        "country": "US"
    },
    "ECDE3D": {
        "oui_hex": "EC-DE-3D",
        "organization": "Lamprey Networks, Inc.",
        "address_1": "58 Dover Road",
        "address_2": "Durham  NH  03824",
        "country": "US"
    },
    "6CFFBE": {
        "oui_hex": "6C-FF-BE",
        "organization": "MPB Communications Inc.",
        "address_1": "147 Hymus Blvd",
        "address_2": "Pointe-Claire  Quebec  H9R 1E9",
        "country": "CA"
    },
    "304174": {
        "oui_hex": "30-41-74",
        "organization": "ALTEC LANSING LLC",
        "address_1": "535 ROUTES 6 & 209",
        "address_2": "MILFORD  PA  18337",
        "country": "US"
    },
    "80B289": {
        "oui_hex": "80-B2-89",
        "organization": "Forworld Electronics Ltd.",
        "address_1": "No.16 Keyuan 2nd Rd., Situn District",
        "address_2": "Taichung City    886",
        "country": "TW"
    },
    "E83A97": {
        "oui_hex": "E8-3A-97",
        "organization": "Toshiba Corporation",
        "address_1": "1-1-1, Shibaura, Minato-ku",
        "address_2": "Tokyo    00000",
        "country": "JP"
    },
    "1056CA": {
        "oui_hex": "10-56-CA",
        "organization": "Peplink International Ltd.",
        "address_1": "17/F, Park Building,",
        "address_2": "Cheung Sha Wan",
        "country": "HK"
    },
    "486FD2": {
        "oui_hex": "48-6F-D2",
        "organization": "StorSimple Inc",
        "address_1": "2350 Mission College Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "A03A75": {
        "oui_hex": "A0-3A-75",
        "organization": "PSS Belgium N.V.",
        "address_1": "Hoogveld 50",
        "address_2": "Dendermonde    9200",
        "country": "BE"
    },
    "24DBAD": {
        "oui_hex": "24-DB-AD",
        "organization": "ShopperTrak RCT Corporation",
        "address_1": "200 W. Monroe Street",
        "address_2": "Chicago  IL  60606",
        "country": "US"
    },
    "9CEBE8": {
        "oui_hex": "9C-EB-E8",
        "organization": "BizLink (Kunshan) Co.,Ltd",
        "address_1": "No.168,Nanhe Road,Economic & Technological Development Zone,",
        "address_2": "Kunshan City  Jiangsu Province  215300",
        "country": "CN"
    },
    "040EC2": {
        "oui_hex": "04-0E-C2",
        "organization": "ViewSonic Mobile China Limited",
        "address_1": "Room 601, The Gate Tower B, No.19, Zhongguancun Street, Haidian District",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "C8D1D1": {
        "oui_hex": "C8-D1-D1",
        "organization": "AGAiT Technology Corporation",
        "address_1": "5F,No.27-8, Sec. 2, Zhongzheng E. Rd., Danshui Township",
        "address_2": "Taipei County     25170",
        "country": "TW"
    },
    "00DB45": {
        "oui_hex": "00-DB-45",
        "organization": "THAMWAY CO.,LTD.",
        "address_1": "3-9-2",
        "address_2": "Fuji  Shizuoka  417-0001",
        "country": "JP"
    },
    "D49C28": {
        "oui_hex": "D4-9C-28",
        "organization": "JayBird LLC",
        "address_1": "3676 California Ave",
        "address_2": "Salt Lake City  UT  84104",
        "country": "US"
    },
    "74F726": {
        "oui_hex": "74-F7-26",
        "organization": "Neuron Robotics",
        "address_1": "91 Pearson Ave",
        "address_2": "Somerville  MA  02144",
        "country": "US"
    },
    "2872C5": {
        "oui_hex": "28-72-C5",
        "organization": "Smartmatic Corp",
        "address_1": "1001 Broken Sound Pkwy NW Suite D",
        "address_2": "Boca Raton  Florida  33487",
        "country": "US"
    },
    "E08FEC": {
        "oui_hex": "E0-8F-EC",
        "organization": "REPOTEC CO., LTD.",
        "address_1": "3F, 258.",
        "address_2": "CHUNG HO CITY, TAIPEI COUNTY    235",
        "country": "TW"
    },
    "ACE9AA": {
        "oui_hex": "AC-E9-AA",
        "organization": "Hay Systems Ltd",
        "address_1": "Watermark",
        "address_2": "Livingston  West Lothian  EH54 7EG",
        "country": "GB"
    },
    "082AD0": {
        "oui_hex": "08-2A-D0",
        "organization": "SRD Innovations Inc.",
        "address_1": "11525 Valley Ridge Dr. NW",
        "address_2": "Calgary  AB  T3B 5T4",
        "country": "CA"
    },
    "889821": {
        "oui_hex": "88-98-21",
        "organization": "TERAON",
        "address_1": "2F Seohan Bldg., 1552-10, Seocho-Dong, Seocho-Gu,",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "E0E751": {
        "oui_hex": "E0-E7-51",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "003AAF": {
        "oui_hex": "00-3A-AF",
        "organization": "BlueBit Ltd.",
        "address_1": "Unit B, 21/F., 78 Hung To Road,",
        "address_2": "Kowloon,",
        "country": "HK"
    },
    "64168D": {
        "oui_hex": "64-16-8D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003A9C": {
        "oui_hex": "00-3A-9C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "7C6C8F": {
        "oui_hex": "7C-6C-8F",
        "organization": "AMS NEVE LTD",
        "address_1": "BILLINGTON ROAD",
        "address_2": "BURNLEY  LANCASHIRE  BB11 5UB",
        "country": "GB"
    },
    "9CB206": {
        "oui_hex": "9C-B2-06",
        "organization": "PROCENTEC",
        "address_1": "Klopperman 16",
        "address_2": "Wateringen  Zuid Holland  2292JD",
        "country": "NL"
    },
    "88ED1C": {
        "oui_hex": "88-ED-1C",
        "organization": "Cudo Communication Co., Ltd.",
        "address_1": "10F ArirangTV 1467-80, Seocho-3dong, Seocho-gu",
        "address_2": "Seoul    137-868",
        "country": "KR"
    },
    "9CCD82": {
        "oui_hex": "9C-CD-82",
        "organization": "CHENG UEI PRECISION INDUSTRY CO.,LTD",
        "address_1": "No.18, Chung Shan Rd., Tu-Cheng Industry Park",
        "address_2": "Tu Cheng City  Taipei Hsien  23680",
        "country": "TW"
    },
    "F06281": {
        "oui_hex": "F0-62-81",
        "organization": "ProCurve Networking by HP",
        "address_1": "60 Alexandra Terrace",
        "address_2": "    118502",
        "country": "SG"
    },
    "C09C92": {
        "oui_hex": "C0-9C-92",
        "organization": "COBY",
        "address_1": "COBY Electronics ShenZhen R&D Center",
        "address_2": "SHENZHEN  GUANGDONG  518109",
        "country": "CN"
    },
    "C038F9": {
        "oui_hex": "C0-38-F9",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "F46349": {
        "oui_hex": "F4-63-49",
        "organization": "Diffon Corporation",
        "address_1": "Digital Tower Aston 1505",
        "address_2": "Seoul    153803",
        "country": "KR"
    },
    "74F07D": {
        "oui_hex": "74-F0-7D",
        "organization": "BnCOM Co.,Ltd",
        "address_1": "Room1007, Daehyun Techno World, 174",
        "address_2": "Uiwang-si  Gyeonggi-do  437-753",
        "country": "KR"
    },
    "F852DF": {
        "oui_hex": "F8-52-DF",
        "organization": "VNL Europe AB",
        "address_1": "Finlandsgatan 10",
        "address_2": "Kista    164 74",
        "country": "SE"
    },
    "A8CB95": {
        "oui_hex": "A8-CB-95",
        "organization": "EAST BEST CO., LTD.",
        "address_1": "4F,NO.98,SHING TEH ROAD",
        "address_2": "SAN CHUNG CITY   TAIPEI  241",
        "country": "TW"
    },
    "F45FF7": {
        "oui_hex": "F4-5F-F7",
        "organization": "DQ Technology Inc.",
        "address_1": "5111 Johnson Drive",
        "address_2": "Pleasanton  CA  94588",
        "country": "US"
    },
    "7C3BD5": {
        "oui_hex": "7C-3B-D5",
        "organization": "Imago Group",
        "address_1": "Ramon Marti Alsina 2-4-6",
        "address_2": "Badalona  Barcelona  08911",
        "country": "ES"
    },
    "5CE223": {
        "oui_hex": "5C-E2-23",
        "organization": "Delphin Technology AG",
        "address_1": "Lustheide 81",
        "address_2": "Bergisch-Gladbach    51427",
        "country": "DE"
    },
    "F871FE": {
        "oui_hex": "F8-71-FE",
        "organization": "The Goldman Sachs Group, Inc.",
        "address_1": "Christchurch Court | 10-15 Newgate Street",
        "address_2": "London  London  EC1A 7HD",
        "country": "GB"
    },
    "2C1984": {
        "oui_hex": "2C-19-84",
        "organization": "IDN Telecom, Inc.",
        "address_1": "2669 Great Arbor Way",
        "address_2": "Union City  CA  94587",
        "country": "US"
    },
    "D8C3FB": {
        "oui_hex": "D8-C3-FB",
        "organization": "DETRACOM",
        "address_1": "41 AVENUE DE L'EUROPE",
        "address_2": "CASTELNAU D'ESTRETEFONDS    31620",
        "country": "FR"
    },
    "58F67B": {
        "oui_hex": "58-F6-7B",
        "organization": "Xia Men UnionCore Technology LTD.",
        "address_1": "(224)2F Chuangye Building,Xiamen Pioneering Park for Overseas Chinese Scholars",
        "address_2": "Xia Men  Fu Jian  361009",
        "country": "CN"
    },
    "6CF049": {
        "oui_hex": "6C-F0-49",
        "organization": "GIGA-BYTE TECHNOLOGY CO.,LTD.",
        "address_1": "",
        "address_2": "Pin-Jen  Taoyuan  324",
        "country": "TW"
    },
    "644F74": {
        "oui_hex": "64-4F-74",
        "organization": "LENUS Co., Ltd.",
        "address_1": "18-5 Gwacheon-Dong",
        "address_2": "Gwacheon  Gyeonggi-Do  427-060",
        "country": "KR"
    },
    "787F62": {
        "oui_hex": "78-7F-62",
        "organization": "GiK mbH",
        "address_1": "Goethestraße 5",
        "address_2": "Aachen    52064",
        "country": "DE"
    },
    "401597": {
        "oui_hex": "40-15-97",
        "organization": "Protect America, Inc.",
        "address_1": "5100 N IH-35",
        "address_2": "Round Rock  TX  78681",
        "country": "US"
    },
    "C4FCE4": {
        "oui_hex": "C4-FC-E4",
        "organization": "DishTV NZ Ltd",
        "address_1": "10 Penney Ave",
        "address_2": "Auckland    1041",
        "country": "NZ"
    },
    "E80B13": {
        "oui_hex": "E8-0B-13",
        "organization": "Akib Systems Taiwan, INC",
        "address_1": "No.582-1, RuiGuang Rd",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "EC6C9F": {
        "oui_hex": "EC-6C-9F",
        "organization": "Chengdu Volans Technology CO.,LTD",
        "address_1": "2nd Floor Building 4B Hi-Tech Incubation Park,Nanyan Xian,Tianfu Ave",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "40EF4C": {
        "oui_hex": "40-EF-4C",
        "organization": "Fihonest communication co.,Ltd",
        "address_1": "Room902,Park road,Zhixing business-building",
        "address_2": "Dongguan  Guangdong  523560",
        "country": "CN"
    },
    "00271E": {
        "oui_hex": "00-27-1E",
        "organization": "Xagyl Communications",
        "address_1": "1667 Marronier Crt",
        "address_2": "Cumberland  Ontario  K4C 1C2",
        "country": "CA"
    },
    "00271D": {
        "oui_hex": "00-27-1D",
        "organization": "Comba Telecom Systems (China) Ltd.",
        "address_1": "10 Shenzhou Road",
        "address_2": "Guangzhou  Guangdong  510663",
        "country": "CN"
    },
    "002720": {
        "oui_hex": "00-27-20",
        "organization": "NEW-SOL COM",
        "address_1": "Bucheon Tecnopark 403-602",
        "address_2": "Bucheon city  Kyoungki-do  420-734",
        "country": "KR"
    },
    "0026F0": {
        "oui_hex": "00-26-F0",
        "organization": "cTrixs International GmbH.",
        "address_1": "Lieferinger Hauptstr. 140",
        "address_2": "Salzburg  Salzburg  5020",
        "country": "AT"
    },
    "0026EA": {
        "oui_hex": "00-26-EA",
        "organization": "Cheerchip Electronic Technology (ShangHai) Co., Ltd.",
        "address_1": "ROOM 1202, NO. 51, 7 Area, NO. 1467 CAOBAO ROAD;",
        "address_2": "SHANGHAI    201101",
        "country": "CN"
    },
    "002708": {
        "oui_hex": "00-27-08",
        "organization": "Nordiag ASA",
        "address_1": "Frysjaveien 40",
        "address_2": "Oslo    0884",
        "country": "NO"
    },
    "002702": {
        "oui_hex": "00-27-02",
        "organization": "SolarEdge Technologies",
        "address_1": "1 Abba Eban St.",
        "address_2": "Herzelia    46725",
        "country": "IL"
    },
    "002704": {
        "oui_hex": "00-27-04",
        "organization": "Accelerated Concepts, Inc",
        "address_1": "1208 E Kennedy Blvd",
        "address_2": "Tampa  FL  33602",
        "country": "US"
    },
    "0026FA": {
        "oui_hex": "00-26-FA",
        "organization": "BandRich Inc.",
        "address_1": "7F., No.188, Baociao Road",
        "address_2": "Sindian City  Taipei  23145",
        "country": "TW"
    },
    "0026F9": {
        "oui_hex": "00-26-F9",
        "organization": "S.E.M. srl",
        "address_1": "via Lecco, 61",
        "address_2": "Vimercate  Monza Brianza  20059",
        "country": "IT"
    },
    "0026FD": {
        "oui_hex": "00-26-FD",
        "organization": "Interactive Intelligence",
        "address_1": "7601 Interactive Way",
        "address_2": "  IN  46278",
        "country": "US"
    },
    "0026F7": {
        "oui_hex": "00-26-F7",
        "organization": "Nivetti Systems Pvt. Ltd.",
        "address_1": "#727,8th Main, JP Nagar 3rd Phase",
        "address_2": "Bangalore    560078",
        "country": "IN"
    },
    "0026F6": {
        "oui_hex": "00-26-F6",
        "organization": "Military Communication Institute",
        "address_1": "ul. Warszawska 22A",
        "address_2": "Zegrze    05-130",
        "country": "PL"
    },
    "0026DD": {
        "oui_hex": "00-26-DD",
        "organization": "Fival Science & Technology Co.,Ltd.",
        "address_1": "1/F, Building 57, No.461",
        "address_2": "Shanghai  Shanghai  200233",
        "country": "CN"
    },
    "0026DE": {
        "oui_hex": "00-26-DE",
        "organization": "FDI MATELEC",
        "address_1": "Route de saint symphorien",
        "address_2": "Les landes Génusson    85130",
        "country": "FR"
    },
    "0026DA": {
        "oui_hex": "00-26-DA",
        "organization": "Universal Media Corporation /Slovakia/ s.r.o.",
        "address_1": "Mickiewiczova 7104/14",
        "address_2": "Bratislava    811 07",
        "country": "SK"
    },
    "0026DB": {
        "oui_hex": "00-26-DB",
        "organization": "Ionics EMS Inc.",
        "address_1": "Carmelray Industrial Park 2, Brgy. Tulo",
        "address_2": "Calamba  Laguna  4027",
        "country": "PH"
    },
    "0026D5": {
        "oui_hex": "00-26-D5",
        "organization": "Ory Solucoes em Comercio de Informatica Ltda.",
        "address_1": "Av. Unisinos, 615",
        "address_2": "Sao Leopoldo  RS  93022000",
        "country": "BR"
    },
    "0026CE": {
        "oui_hex": "00-26-CE",
        "organization": "Kozumi USA Corp.",
        "address_1": "3005 Hartridge Terrace",
        "address_2": "Wellington  FL  33414",
        "country": "US"
    },
    "002711": {
        "oui_hex": "00-27-11",
        "organization": "LanPro Inc",
        "address_1": "1880 NW 93Av",
        "address_2": "Miami  Florida  33172",
        "country": "US"
    },
    "002686": {
        "oui_hex": "00-26-86",
        "organization": "Quantenna Communcations, Inc.",
        "address_1": "3450 W. Warren Ave.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "002684": {
        "oui_hex": "00-26-84",
        "organization": "KISAN SYSTEM",
        "address_1": "GWANGMYEONG TECHNOPARK B-403",
        "address_2": "GWANGMYEONG  GYEONGGI  423-050",
        "country": "KR"
    },
    "002680": {
        "oui_hex": "00-26-80",
        "organization": "SIL3 Pty.Ltd",
        "address_1": "Factory 10",
        "address_2": "DANDENONG  VICTORIA  3175",
        "country": "AU"
    },
    "0026BF": {
        "oui_hex": "00-26-BF",
        "organization": "ShenZhen Temobi Science&Tech Development Co.,Ltd",
        "address_1": "4FloorG, Jinrun Tower, 6019 Shennan Road",
        "address_2": "ShenZhen    518000",
        "country": "CN"
    },
    "0026B4": {
        "oui_hex": "00-26-B4",
        "organization": "Ford Motor Company",
        "address_1": "20300 Rotunda Drive",
        "address_2": "Dearborn  MI  48124",
        "country": "US"
    },
    "0026CA": {
        "oui_hex": "00-26-CA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0026C9": {
        "oui_hex": "00-26-C9",
        "organization": "Proventix Systems, Inc.",
        "address_1": "4518 Valleydale Road",
        "address_2": "Birmingham  AL  35242",
        "country": "US"
    },
    "002690": {
        "oui_hex": "00-26-90",
        "organization": "I DO IT",
        "address_1": "1308, WoolimLions2nd Doksan Station",
        "address_2": "Seoul    153-787",
        "country": "KR"
    },
    "00268F": {
        "oui_hex": "00-26-8F",
        "organization": "MTA SpA",
        "address_1": "Viale dell Industria 12",
        "address_2": "Codogno  LODI  26845",
        "country": "IT"
    },
    "002679": {
        "oui_hex": "00-26-79",
        "organization": "Euphonic Technologies, Inc.",
        "address_1": "2-5-10 Shin-yokohama, Kouhoku-ku",
        "address_2": "Yokohama    222-0033",
        "country": "JP"
    },
    "0026AC": {
        "oui_hex": "00-26-AC",
        "organization": "Shanghai LUSTER Teraband photonic Co., Ltd.",
        "address_1": "F4, No.39 ChengZhong Rd.",
        "address_2": "Shanghai    201800",
        "country": "CN"
    },
    "0026A6": {
        "oui_hex": "00-26-A6",
        "organization": "TRIXELL",
        "address_1": "460, Rue du pommarin",
        "address_2": "MOIRANS    38210",
        "country": "FR"
    },
    "00269C": {
        "oui_hex": "00-26-9C",
        "organization": "ITUS JAPAN CO. LTD",
        "address_1": "7F Shinkawa B/D",
        "address_2": "Chuoku  Tokyo  1040033",
        "country": "JP"
    },
    "002694": {
        "oui_hex": "00-26-94",
        "organization": "Senscient Ltd",
        "address_1": "Unit 2, Block A, Arena Business Centre",
        "address_2": "Poole  Dorset  BH17 7FJ",
        "country": "GB"
    },
    "002676": {
        "oui_hex": "00-26-76",
        "organization": "COMMidt AS",
        "address_1": "Kikregata 57-59",
        "address_2": "Levanger  Nord-Troendelag  7600",
        "country": "NO"
    },
    "00261D": {
        "oui_hex": "00-26-1D",
        "organization": "COP SECURITY SYSTEM CORP.",
        "address_1": "4~7F, No.5, Lane 130, Min-Chung Rd.,",
        "address_2": "Taipei    23141",
        "country": "TW"
    },
    "002617": {
        "oui_hex": "00-26-17",
        "organization": "OEM Worldwide",
        "address_1": "2920 Kelly Ave",
        "address_2": "Watertown  SD  57201",
        "country": "US"
    },
    "002613": {
        "oui_hex": "00-26-13",
        "organization": "Engel Axil S.L.",
        "address_1": "Puig dels Tudons, 6",
        "address_2": "Barbera del Valles  Barcelona  08210",
        "country": "ES"
    },
    "002638": {
        "oui_hex": "00-26-38",
        "organization": "Xia Men Joyatech Co., Ltd.",
        "address_1": "Room 304, 28th Building, Guanri Road, Xiamen Software Park",
        "address_2": "Xiamen  Fujian Province  361008",
        "country": "CN"
    },
    "00263A": {
        "oui_hex": "00-26-3A",
        "organization": "Digitec Systems",
        "address_1": "7,1st Street, Kasturibai Nagar",
        "address_2": "Chennai  Tamil Nadu  600054",
        "country": "IN"
    },
    "00260F": {
        "oui_hex": "00-26-0F",
        "organization": "Linn Products Ltd",
        "address_1": "Glasgow Road",
        "address_2": "Glasgow  Scotland  G76 0EQ",
        "country": "GB"
    },
    "00260C": {
        "oui_hex": "00-26-0C",
        "organization": "Dataram",
        "address_1": "186 Princeton Rd.",
        "address_2": "West Windsor  NJ  08550",
        "country": "US"
    },
    "00262B": {
        "oui_hex": "00-26-2B",
        "organization": "Wongs Electronics Co. Ltd.",
        "address_1": "Wanfeng Ind. Esata, Shajing, Baoan,",
        "address_2": "Shenzhen  Guang Dong  518104",
        "country": "CN"
    },
    "002620": {
        "oui_hex": "00-26-20",
        "organization": "ISGUS GmbH",
        "address_1": "Oberdorfstraße 18 - 22",
        "address_2": "VS - Schwenningen  BW  78054",
        "country": "DE"
    },
    "002601": {
        "oui_hex": "00-26-01",
        "organization": "Cutera Inc",
        "address_1": "3240 Bayshore Blvd",
        "address_2": "Brisbane  CA  94405",
        "country": "US"
    },
    "002635": {
        "oui_hex": "00-26-35",
        "organization": "Bluetechnix GmbH",
        "address_1": "Waidhausenstr. 3/19",
        "address_2": "Vienna    1140",
        "country": "AT"
    },
    "002657": {
        "oui_hex": "00-26-57",
        "organization": "OOO NPP EKRA",
        "address_1": "I.Yakovleva St., 3",
        "address_2": "Cheboksary  Chuvash Republic  428003",
        "country": "RU"
    },
    "002652": {
        "oui_hex": "00-26-52",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002666": {
        "oui_hex": "00-26-66",
        "organization": "EFM Networks",
        "address_1": "6F, Benposra II 1197-1 Bojeong Giheung Gu",
        "address_2": "Yong In  Kyunggi do  446913",
        "country": "KR"
    },
    "0025F5": {
        "oui_hex": "00-25-F5",
        "organization": "DVS Korea, Co., Ltd",
        "address_1": "497-3, SangHa-Dong, Giheung-gu",
        "address_2": "Yong-In city  Gyeonggi-do  446-914",
        "country": "KR"
    },
    "0025EB": {
        "oui_hex": "00-25-EB",
        "organization": "Reutech Radar Systems (PTY) Ltd",
        "address_1": "35 Elektron Avenue",
        "address_2": "Stellenbosch  Western Cape  7600",
        "country": "ZA"
    },
    "0025EE": {
        "oui_hex": "00-25-EE",
        "organization": "Avtex Ltd",
        "address_1": "Unit G5 Capital Business Park",
        "address_2": "Cardiff    CF3 2PX",
        "country": "GB"
    },
    "0025AE": {
        "oui_hex": "00-25-AE",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "0025AF": {
        "oui_hex": "00-25-AF",
        "organization": "COMFILE Technology",
        "address_1": "Guro 5 dong, Guro-gu",
        "address_2": "Seoul    152-842",
        "country": "KR"
    },
    "0025A8": {
        "oui_hex": "00-25-A8",
        "organization": "Kontron (BeiJing) Technology Co.,Ltd",
        "address_1": "17 Building, Block #1,ABP.  188 Western South 4th Ring Road",
        "address_2": "BeiJing    100070",
        "country": "CN"
    },
    "0025D9": {
        "oui_hex": "00-25-D9",
        "organization": "DataFab Systems Inc.",
        "address_1": "385-3 Hongzun Road",
        "address_2": "Pingzhen City  Taoyuan County  32466",
        "country": "TW"
    },
    "0025D6": {
        "oui_hex": "00-25-D6",
        "organization": "The Kroger Co.",
        "address_1": "11450 Grooms Road",
        "address_2": "Blue Ash  OH  45242",
        "country": "US"
    },
    "0025D1": {
        "oui_hex": "00-25-D1",
        "organization": "Eastern Asia Technology Limited",
        "address_1": "8F-1, No. 188, Baoqiao Rd., Xindian Dist.",
        "address_2": "New Taipei City    23145",
        "country": "TW"
    },
    "0025CD": {
        "oui_hex": "00-25-CD",
        "organization": "Skylane Optics",
        "address_1": "Rue d'Arlon, 6",
        "address_2": "Windhof    8399",
        "country": "LU"
    },
    "0025BF": {
        "oui_hex": "00-25-BF",
        "organization": "Wireless Cables Inc.",
        "address_1": "1414 Soquel Ave, Ste 212",
        "address_2": "Santa Cruz  CA  95062",
        "country": "US"
    },
    "0025B9": {
        "oui_hex": "00-25-B9",
        "organization": "Cypress Solutions Inc",
        "address_1": "3066 Beta Ave",
        "address_2": "  BC  V5G 4K4",
        "country": "CA"
    },
    "0025B6": {
        "oui_hex": "00-25-B6",
        "organization": "Telecom FM",
        "address_1": "895 Plymouth Road",
        "address_2": "Slough  Berkshire  SL1 4LP",
        "country": "GB"
    },
    "0025A5": {
        "oui_hex": "00-25-A5",
        "organization": "Walnut Media Network",
        "address_1": "440 N Wolfe Rd",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "0025A4": {
        "oui_hex": "00-25-A4",
        "organization": "EuroDesign embedded technologies GmbH",
        "address_1": "Waldstratraße 4A",
        "address_2": "Kirchdorf a.d. Amper  Bayern  85414",
        "country": "DE"
    },
    "0025C1": {
        "oui_hex": "00-25-C1",
        "organization": "Nawoo Korea Corp.",
        "address_1": "4Fl., Hanwon Bldg., 6-1, Sunae-dong, Bundang-gu,",
        "address_2": "Seongnam-si  Gyeonggi-do  463-825",
        "country": "KR"
    },
    "0025F6": {
        "oui_hex": "00-25-F6",
        "organization": "netTALK.com, Inc.",
        "address_1": "1100 NW 163RD DRIVE",
        "address_2": "NORTH MIAMI BEACH  FL  33169",
        "country": "US"
    },
    "00257A": {
        "oui_hex": "00-25-7A",
        "organization": "CAMCO Produktions- und Vertriebs-GmbH für  Beschallungs- und Beleuchtungsanlagen",
        "address_1": "Fischpicke 5",
        "address_2": "Wenden  NRW  57482",
        "country": "DE"
    },
    "002576": {
        "oui_hex": "00-25-76",
        "organization": "NELI TECHNOLOGIES",
        "address_1": "Route Nationale",
        "address_2": "LE RHEU    35650",
        "country": "FR"
    },
    "002574": {
        "oui_hex": "00-25-74",
        "organization": "KUNIMI MEDIA DEVICE Co., Ltd.",
        "address_1": "3 KITAMACHIDA YAMAZAKI",
        "address_2": "KUNIMI, DATE  FUKUSHIMA  969-1771",
        "country": "JP"
    },
    "002559": {
        "oui_hex": "00-25-59",
        "organization": "Syphan Technologies Ltd",
        "address_1": "The Watermill",
        "address_2": "Skipton  North Yorkshire  BD23 3AG",
        "country": "GB"
    },
    "002554": {
        "oui_hex": "00-25-54",
        "organization": "Pixel8 Networks",
        "address_1": "22 Great Oaks Blvd, Suite 150",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "002540": {
        "oui_hex": "00-25-40",
        "organization": "Quasar Technologies, Inc.",
        "address_1": "1701 Barrett Lakes Boulevard",
        "address_2": "Kennesaw  GA  30144",
        "country": "US"
    },
    "002533": {
        "oui_hex": "00-25-33",
        "organization": "WITTENSTEIN AG",
        "address_1": "Walter-Wittenstein-Straße 1",
        "address_2": "Igersheim    97999",
        "country": "DE"
    },
    "002530": {
        "oui_hex": "00-25-30",
        "organization": "Aetas Systems Inc.",
        "address_1": "3A3, No. 1, LiHsin Road I",
        "address_2": "HsinChu  Taiwan  30078",
        "country": "TW"
    },
    "00252C": {
        "oui_hex": "00-25-2C",
        "organization": "Entourage Systems, Inc.",
        "address_1": "7901 Jones Branch Drive",
        "address_2": "McLean  Virginia  22102",
        "country": "US"
    },
    "00258C": {
        "oui_hex": "00-25-8C",
        "organization": "ESUS ELEKTRONIK SAN. VE DIS. TIC. LTD. STI.",
        "address_1": "ESENSEHIR MAHALLESI KURKCULER CADDESI",
        "address_2": "ISTANBUL    34776",
        "country": "TR"
    },
    "00255A": {
        "oui_hex": "00-25-5A",
        "organization": "Tantalus Systems Corp.",
        "address_1": "301-3480 Gilmore Way",
        "address_2": "Burnaby  BC  V5G 4Y1",
        "country": "CA"
    },
    "002587": {
        "oui_hex": "00-25-87",
        "organization": "Vitality, Inc.",
        "address_1": "One Broadway",
        "address_2": "Cambridge  MA  02142",
        "country": "US"
    },
    "002573": {
        "oui_hex": "00-25-73",
        "organization": "ST Electronics (Info-Security) Pte Ltd",
        "address_1": "100, Jurong East Street 21, ST Electronics Jurong East Bldg",
        "address_2": "    609602",
        "country": "SG"
    },
    "00256F": {
        "oui_hex": "00-25-6F",
        "organization": "Dantherm Power",
        "address_1": "Marienlystvej 65",
        "address_2": "Skive    7800",
        "country": "DK"
    },
    "00252F": {
        "oui_hex": "00-25-2F",
        "organization": "Energy, Inc.",
        "address_1": "3297 Pacific Street",
        "address_2": "Charleston  SC  29418",
        "country": "US"
    },
    "00250A": {
        "oui_hex": "00-25-0A",
        "organization": "Security Expert Co. Ltd",
        "address_1": "8F-3, No.2, Jian 8th Rd.,",
        "address_2": "Jhonghe  Taipei  235",
        "country": "TW"
    },
    "002505": {
        "oui_hex": "00-25-05",
        "organization": "eks Engel GmbH & Co. KG",
        "address_1": "Schuetzenstrasse 2",
        "address_2": "Wenden-Hillmicke  NRW  57482",
        "country": "DE"
    },
    "002509": {
        "oui_hex": "00-25-09",
        "organization": "SHARETRONIC Group LTD",
        "address_1": "ShaJing,Bao'an Zone,",
        "address_2": "ShenZhen  Guangdong  518104",
        "country": "CN"
    },
    "0024DA": {
        "oui_hex": "00-24-DA",
        "organization": "Innovar Systems Limited",
        "address_1": "12155 Commissioner Drive",
        "address_2": "North Jackson  Ohio  44451",
        "country": "US"
    },
    "0024D8": {
        "oui_hex": "00-24-D8",
        "organization": "IlSung Precision",
        "address_1": "182-2, Jegi-ri, Jeongnam-myeon",
        "address_2": "Hwanseong-si  Gyeonggi-do  445-964",
        "country": "KR"
    },
    "0024CD": {
        "oui_hex": "00-24-CD",
        "organization": "Willow Garage, Inc.",
        "address_1": "68 Willow Rd.",
        "address_2": "Menlo Park  CA  94025",
        "country": "US"
    },
    "0024D3": {
        "oui_hex": "00-24-D3",
        "organization": "QUALICA Inc.",
        "address_1": "5-29-15,Toyo,",
        "address_2": "Tokyo    135-0016",
        "country": "JP"
    },
    "0024CE": {
        "oui_hex": "00-24-CE",
        "organization": "Exeltech Inc",
        "address_1": "7317 Jack Newell Blvd North",
        "address_2": "Fort Worth  TX  76118",
        "country": "US"
    },
    "0024CF": {
        "oui_hex": "00-24-CF",
        "organization": "Inscape Data Corporation",
        "address_1": "1611 South Main Street",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0024C6": {
        "oui_hex": "00-24-C6",
        "organization": "Hager Electro SAS",
        "address_1": "132, boulevard d'Europe",
        "address_2": "Obernai  Bas-Rhin  67215",
        "country": "FR"
    },
    "0024FD": {
        "oui_hex": "00-24-FD",
        "organization": "Accedian Networks Inc",
        "address_1": "2351 Alfred Nobel Blvd",
        "address_2": "Saint Laurent  QC  h4s 2A9",
        "country": "CA"
    },
    "002523": {
        "oui_hex": "00-25-23",
        "organization": "OCP Inc.",
        "address_1": "18495 S Dixie Hwy    PMB 107",
        "address_2": "Miami  Florida  33157",
        "country": "US"
    },
    "00251D": {
        "oui_hex": "00-25-1D",
        "organization": "DSA Encore, LLC",
        "address_1": "50 Pocono Rd",
        "address_2": "Brookfield  CT  06804",
        "country": "US"
    },
    "00250F": {
        "oui_hex": "00-25-0F",
        "organization": "On-Ramp Wireless, Inc.",
        "address_1": "16885 West Bernardo Drive",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "0024F5": {
        "oui_hex": "00-24-F5",
        "organization": "NDS Surgical Imaging",
        "address_1": "5750 Hellyer Ave.",
        "address_2": "San Jose  CA.  95138",
        "country": "US"
    },
    "002467": {
        "oui_hex": "00-24-67",
        "organization": "AOC International (Europe) GmbH",
        "address_1": "Lahnstrasse 86A",
        "address_2": "Berlin    12055",
        "country": "DE"
    },
    "00246D": {
        "oui_hex": "00-24-6D",
        "organization": "Weinzierl Engineering GmbH",
        "address_1": "Bahnhofstrasse 6",
        "address_2": "Tyrlaching  Bayern  84558",
        "country": "DE"
    },
    "002470": {
        "oui_hex": "00-24-70",
        "organization": "AUROTECH ultrasound AS.",
        "address_1": "Svingen 1",
        "address_2": "Tydal  Sr-Tr  N-7590",
        "country": "NO"
    },
    "00246A": {
        "oui_hex": "00-24-6A",
        "organization": "Solid Year Co., Ltd.",
        "address_1": "2F-1, No. 94, Bao-chung Road,",
        "address_2": "Hsin-tien City  Taipei Hsien  23147",
        "country": "TW"
    },
    "002492": {
        "oui_hex": "00-24-92",
        "organization": "Motorola, Broadband Solutions Group",
        "address_1": "1101 Marina Village Parkway",
        "address_2": "Alameda  CA  94501",
        "country": "US"
    },
    "00248B": {
        "oui_hex": "00-24-8B",
        "organization": "HYBUS CO., LTD.",
        "address_1": "Rm# 701, Daerung Post Tower 1st",
        "address_2": "SEOUL    152-790",
        "country": "KR"
    },
    "002484": {
        "oui_hex": "00-24-84",
        "organization": "Bang and Olufsen Medicom a/s",
        "address_1": "Gimsinglundvej 20",
        "address_2": "Struer  DK  DK7600",
        "country": "DK"
    },
    "002480": {
        "oui_hex": "00-24-80",
        "organization": "Meteocontrol GmbH",
        "address_1": "Spichererstrasse 48",
        "address_2": "Augsburg  Bavaria  86152",
        "country": "DE"
    },
    "00247A": {
        "oui_hex": "00-24-7A",
        "organization": "FU YI CHENG Technology Co., Ltd.",
        "address_1": "13F, No. 105-1, Jilin Rd., Luju Shiang,",
        "address_2": "Taoyuan    338",
        "country": "TW"
    },
    "002476": {
        "oui_hex": "00-24-76",
        "organization": "TAP.tv",
        "address_1": "16w361 South Frontage Road",
        "address_2": "Burr Ridge  IL  60527",
        "country": "US"
    },
    "0024B4": {
        "oui_hex": "00-24-B4",
        "organization": "ESCATRONIC GmbH",
        "address_1": "Wuerzburger Str. 8",
        "address_2": "Laatzen  Lower Saxony  30880",
        "country": "DE"
    },
    "0024B1": {
        "oui_hex": "00-24-B1",
        "organization": "Coulomb Technologies",
        "address_1": "1692 Dell Ave",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "00249C": {
        "oui_hex": "00-24-9C",
        "organization": "Bimeng Comunication System Co. Ltd",
        "address_1": "Level 16/f, Tower B,Sinotrans Plaza,No.43, Xi Zhi Men Northern Road,Hai dian District",
        "address_2": "Beijing    100044",
        "country": "CN"
    },
    "002498": {
        "oui_hex": "00-24-98",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002452": {
        "oui_hex": "00-24-52",
        "organization": "Silicon Software GmbH",
        "address_1": "Steubenstrasse 46",
        "address_2": "Mannheim  Baden-Wuerttemberg  68163",
        "country": "DE"
    },
    "002453": {
        "oui_hex": "00-24-53",
        "organization": "Initra d.o.o.",
        "address_1": "Slomskova 33",
        "address_2": "Ljubljana    1000",
        "country": "SI"
    },
    "00244C": {
        "oui_hex": "00-24-4C",
        "organization": "Solartron Metrology Ltd",
        "address_1": "Steyning Way",
        "address_2": "Bognor Regis  West Sussex  PO20 9ST",
        "country": "GB"
    },
    "002448": {
        "oui_hex": "00-24-48",
        "organization": "SpiderCloud Wireless, Inc",
        "address_1": "475 Sycamore Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00244B": {
        "oui_hex": "00-24-4B",
        "organization": "PERCEPTRON INC",
        "address_1": "47827 HALYARD DR",
        "address_2": "PLYMOUTH  MI  48170",
        "country": "US"
    },
    "002428": {
        "oui_hex": "00-24-28",
        "organization": "EnergyICT",
        "address_1": "Theodoor Sevenslaan 104a",
        "address_2": "Kortrijk    8500",
        "country": "BE"
    },
    "002417": {
        "oui_hex": "00-24-17",
        "organization": "Thomson Telecom Belgium",
        "address_1": "Prins Boudewijnlaan 47",
        "address_2": "Edegem  Antwerp  B-2650",
        "country": "BE"
    },
    "002416": {
        "oui_hex": "00-24-16",
        "organization": "Any Use",
        "address_1": "LG APT 211-1805,",
        "address_2": "Yongin City  Gyeong-Gi Province  448-150",
        "country": "KR"
    },
    "00242A": {
        "oui_hex": "00-24-2A",
        "organization": "Hittite Microwave Corporation",
        "address_1": "20 Alpha Rd",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "002422": {
        "oui_hex": "00-24-22",
        "organization": "Knapp Logistik Automation GmbH",
        "address_1": "Günter Knapp-Straße 5-7",
        "address_2": "Hart bei Graz  Styria  8075",
        "country": "AT"
    },
    "00241B": {
        "oui_hex": "00-24-1B",
        "organization": "iWOW Communications Pte Ltd",
        "address_1": "1 Lorong 2 Toa Payoh #04-01",
        "address_2": "    319637",
        "country": "SG"
    },
    "00245E": {
        "oui_hex": "00-24-5E",
        "organization": "Hivision Co.,ltd",
        "address_1": "2201-2202, COFCO Property Tower,",
        "address_2": "Shenzhen  Guangdong  518101",
        "country": "CN"
    },
    "00244D": {
        "oui_hex": "00-24-4D",
        "organization": "Hokkaido Electronics Corporation",
        "address_1": "1-1 East 10 North 10",
        "address_2": "Sapporo  Hokkaido  065-0010",
        "country": "JP"
    },
    "002442": {
        "oui_hex": "00-24-42",
        "organization": "Axona Limited",
        "address_1": "Unit 4U St. Albans Enterprise Centre",
        "address_2": "St. Albans  Herts  AL3 6EN",
        "country": "GB"
    },
    "002400": {
        "oui_hex": "00-24-00",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0023FB": {
        "oui_hex": "00-23-FB",
        "organization": "IP Datatel, LLC.",
        "address_1": "13110 Southwest Freeway",
        "address_2": "Sugar Land  Texas  77478",
        "country": "US"
    },
    "002409": {
        "oui_hex": "00-24-09",
        "organization": "The Toro Company",
        "address_1": "5825 Jasmine Street",
        "address_2": "Riverside  CA  92504",
        "country": "US"
    },
    "002406": {
        "oui_hex": "00-24-06",
        "organization": "Pointmobile",
        "address_1": "301,World Meridian Verture Center-1 60-24",
        "address_2": "Seoul  Geumcheon-gu  153781",
        "country": "KR"
    },
    "00243C": {
        "oui_hex": "00-24-3C",
        "organization": "S.A.A.A.",
        "address_1": "Z.A. Croix Saint Mathieu",
        "address_2": "GALLARDON  Eure et Loir  28320",
        "country": "FR"
    },
    "0023D3": {
        "oui_hex": "00-23-D3",
        "organization": "AirLink WiFi Networking Corp.",
        "address_1": "19F-1 Room A , No.97, Sec 4, Chung Hsin Rd.,",
        "address_2": "San Chung City,  Taipei Hsien  241",
        "country": "TW"
    },
    "0023CA": {
        "oui_hex": "00-23-CA",
        "organization": "Behind The Set, LLC",
        "address_1": "2185 Knollwood Dr.",
        "address_2": "Boulder  CO  80302",
        "country": "US"
    },
    "0023CB": {
        "oui_hex": "00-23-CB",
        "organization": "Shenzhen Full-join Technology Co.,Ltd",
        "address_1": "9/F,No.1,Xinrui Road,Hourui ,Xixiang Town, Bao'an District",
        "address_2": "ShenZhen  GuangDong  518000",
        "country": "CN"
    },
    "0023AD": {
        "oui_hex": "00-23-AD",
        "organization": "Xmark Corporation",
        "address_1": "309 Legget  Drive",
        "address_2": "Ottawa  Ontario  K2K 3A3",
        "country": "CA"
    },
    "0023AB": {
        "oui_hex": "00-23-AB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0023A4": {
        "oui_hex": "00-23-A4",
        "organization": "New Concepts Development Corp.",
        "address_1": "2650 Bridge Lane",
        "address_2": "Woodstock  IL  60098",
        "country": "US"
    },
    "0023DC": {
        "oui_hex": "00-23-DC",
        "organization": "Benein, Inc",
        "address_1": "Hyojachonjesangga228 B9, 297,",
        "address_2": "Sengnam-si  Kyunggi-do  463-818",
        "country": "KR"
    },
    "0023D1": {
        "oui_hex": "00-23-D1",
        "organization": "TRG",
        "address_1": "Wisma Kosgoro 13th Floor",
        "address_2": "Jakarta Pusat    10350",
        "country": "ID"
    },
    "0023FE": {
        "oui_hex": "00-23-FE",
        "organization": "Biodevices, SA",
        "address_1": "Rua 5 de Outubro, 309",
        "address_2": "Porto    4100-175",
        "country": "PT"
    },
    "0023F4": {
        "oui_hex": "00-23-F4",
        "organization": "Masternaut",
        "address_1": "4, rue Charles Cros",
        "address_2": "Louviers    27407",
        "country": "FR"
    },
    "0023D0": {
        "oui_hex": "00-23-D0",
        "organization": "Uniloc USA Inc.",
        "address_1": "3333 Michelson Drive",
        "address_2": "Irvine  CA  92612",
        "country": "US"
    },
    "0023C7": {
        "oui_hex": "00-23-C7",
        "organization": "AVSystem",
        "address_1": "ul. Friedleina 4",
        "address_2": "Kraków  małopolskie  30-009",
        "country": "PL"
    },
    "0023C3": {
        "oui_hex": "00-23-C3",
        "organization": "LogMeIn, Inc.",
        "address_1": "500 Unicorn Park Drive",
        "address_2": "Woburn  Massachusetts  01801",
        "country": "US"
    },
    "0023B0": {
        "oui_hex": "00-23-B0",
        "organization": "COMXION Technology Inc.",
        "address_1": "11F, No. 111, Sec 2, Keelung Rd., Sinyi Distric",
        "address_2": "Taipei  Taiwan  110",
        "country": "TW"
    },
    "0023E1": {
        "oui_hex": "00-23-E1",
        "organization": "Cavena Image Products AB",
        "address_1": "Nytorpsvägen 26",
        "address_2": "Täby  Stockholm  se-183 53",
        "country": "SE"
    },
    "00237E": {
        "oui_hex": "00-23-7E",
        "organization": "ELSTER GMBH",
        "address_1": "KUHLMANNSTRASSE 10",
        "address_2": "HAMELN    31785",
        "country": "DE"
    },
    "00237C": {
        "oui_hex": "00-23-7C",
        "organization": "NEOTION",
        "address_1": "ZI les Paluds",
        "address_2": "AUBAGNE    F-13400",
        "country": "FR"
    },
    "00237A": {
        "oui_hex": "00-23-7A",
        "organization": "RIM",
        "address_1": "295 Phillip Street",
        "address_2": "Waterloo  Ontario  N2L 3W8",
        "country": "CA"
    },
    "00236D": {
        "oui_hex": "00-23-6D",
        "organization": "ResMed Ltd",
        "address_1": "1, Elizabeth Macarthur Drive",
        "address_2": "Bella Vista  NSW  2153",
        "country": "AU"
    },
    "00236B": {
        "oui_hex": "00-23-6B",
        "organization": "Xembedded, Inc.",
        "address_1": "1050 Highland Dr",
        "address_2": "Ann Arbor  MI  48108",
        "country": "US"
    },
    "002361": {
        "oui_hex": "00-23-61",
        "organization": "Unigen Corporation",
        "address_1": "45388 Warm Springs Blvd",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "00232C": {
        "oui_hex": "00-23-2C",
        "organization": "Senticare",
        "address_1": "161 Worcester Rd",
        "address_2": "Framingham  MA  01701",
        "country": "US"
    },
    "00232B": {
        "oui_hex": "00-23-2B",
        "organization": "IRD A/S",
        "address_1": "Kullinggade 31",
        "address_2": "Svendborg  Fyn  5700",
        "country": "DK"
    },
    "002336": {
        "oui_hex": "00-23-36",
        "organization": "METEL s.r.o.",
        "address_1": "Zizkuv Kopec 617",
        "address_2": "Ceska Skalice  Nachod  55203",
        "country": "CZ"
    },
    "002338": {
        "oui_hex": "00-23-38",
        "organization": "OJ-Electronics A/S",
        "address_1": "Stenager 13B",
        "address_2": "Sønderborg    6400",
        "country": "DK"
    },
    "00233B": {
        "oui_hex": "00-23-3B",
        "organization": "C-Matic Systems Ltd",
        "address_1": "Warren Court",
        "address_2": "Crowborough  East Sussex  TN6 2QX",
        "country": "GB"
    },
    "00232A": {
        "oui_hex": "00-23-2A",
        "organization": "eonas IT-Beratung und -Entwicklung GmbH",
        "address_1": "Greifenhagener Str. 54",
        "address_2": "Berlin    10437",
        "country": "DE"
    },
    "002327": {
        "oui_hex": "00-23-27",
        "organization": "Shouyo Electronics CO., LTD",
        "address_1": "4F., No.8, Lane 345, Yang Kung St.",
        "address_2": "Taipei    11491",
        "country": "TW"
    },
    "002328": {
        "oui_hex": "00-23-28",
        "organization": "ALCON TELECOMMUNICATIONS CO., LTD.",
        "address_1": "2nd FL, NO 480-5, SEC. 6, YEN-PING N. RD.,",
        "address_2": "TAIPEI  TAIWAN  111",
        "country": "TW"
    },
    "002372": {
        "oui_hex": "00-23-72",
        "organization": "MORE STAR INDUSTRIAL GROUP LIMITED",
        "address_1": "Rm1221-1225, F12 Sangda Science and Technology Building ,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "00234C": {
        "oui_hex": "00-23-4C",
        "organization": "KTC AB",
        "address_1": "F O Petersons gata 6",
        "address_2": "Vastra Frolunda  Gothenburg  SE-42131",
        "country": "SE"
    },
    "002343": {
        "oui_hex": "00-23-43",
        "organization": "TEM AG",
        "address_1": "Triststrasse 8",
        "address_2": "Chur    7007",
        "country": "CH"
    },
    "00235F": {
        "oui_hex": "00-23-5F",
        "organization": "Silicon Micro Sensors GmbH",
        "address_1": "Grenzstrasse 28 / Gebäude 32",
        "address_2": "Dresden  Saxony  01109",
        "country": "DE"
    },
    "002385": {
        "oui_hex": "00-23-85",
        "organization": "ANTIPODE",
        "address_1": "5 RUE DE DOUAI",
        "address_2": "PARIS  ILE DE FRANCE  75009",
        "country": "FR"
    },
    "0022D8": {
        "oui_hex": "00-22-D8",
        "organization": "Shenzhen GST Security and Safety Technology Limited",
        "address_1": "Room 502,Building 6 of Kupai Infomation Harbour,",
        "address_2": "Shenzhen  Guangdong  518040",
        "country": "CN"
    },
    "0022DC": {
        "oui_hex": "00-22-DC",
        "organization": "Vigil Health Solutions Inc.",
        "address_1": "2102-4464 Markham St",
        "address_2": "Victoria  BC  V8Z 7X8",
        "country": "CA"
    },
    "0022D9": {
        "oui_hex": "00-22-D9",
        "organization": "Fortex Industrial Ltd.",
        "address_1": "Flat 16, 12 /F.,Pacific Trade Centre",
        "address_2": "Kowloon  Hong Kong  852",
        "country": "CN"
    },
    "0022D3": {
        "oui_hex": "00-22-D3",
        "organization": "Hub-Tech",
        "address_1": "77, Imae-dong",
        "address_2": "Seongnam-si  Gyeonggi-do  463-829",
        "country": "KR"
    },
    "0022D4": {
        "oui_hex": "00-22-D4",
        "organization": "ComWorth Co., Ltd.",
        "address_1": "2-35-7 Nishimagome",
        "address_2": "Ohta-ku  Tokyo  143-0026",
        "country": "JP"
    },
    "0022FE": {
        "oui_hex": "00-22-FE",
        "organization": "Advanced Illumination",
        "address_1": "440 State Garage Road",
        "address_2": "Rochester  Vermont  05767",
        "country": "US"
    },
    "002300": {
        "oui_hex": "00-23-00",
        "organization": "Cayee Computer Ltd.",
        "address_1": "Units 1002-1003, 10/F, Join-In Hang Sing Centre",
        "address_2": "Kwai Chung  N.T",
        "country": "HK"
    },
    "0022F3": {
        "oui_hex": "00-22-F3",
        "organization": "SHARP Corporation",
        "address_1": "22-22,Nagaike-cho",
        "address_2": "Osaka city  Osaka prefecture  545-8522",
        "country": "JP"
    },
    "0022F6": {
        "oui_hex": "00-22-F6",
        "organization": "Syracuse Research Corporation",
        "address_1": "6225 Running Ridge Road",
        "address_2": "North Syracuse  NY  13212",
        "country": "US"
    },
    "00230D": {
        "oui_hex": "00-23-0D",
        "organization": "Nortel Networks",
        "address_1": "2221 Lakeside Blvd",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "002303": {
        "oui_hex": "00-23-03",
        "organization": "LITE-ON IT Corporation",
        "address_1": "14F, No. 392, Ruey Kuang Road, Neihu",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "0022ED": {
        "oui_hex": "00-22-ED",
        "organization": "TSI Power Corporation",
        "address_1": "1103 West Pierce Avenue",
        "address_2": "Antigo  WI  54409",
        "country": "US"
    },
    "0022E1": {
        "oui_hex": "00-22-E1",
        "organization": "ZORT Labs, LLC.",
        "address_1": "44H Dover Point Road",
        "address_2": "Dover  NH  03820",
        "country": "US"
    },
    "0022E0": {
        "oui_hex": "00-22-E0",
        "organization": "Atlantic Software Technologies S.r.L.",
        "address_1": "Via Martino Bassi, 9",
        "address_2": "Milano    20148",
        "country": "IT"
    },
    "0022DF": {
        "oui_hex": "00-22-DF",
        "organization": "TAMUZ Monitors",
        "address_1": "Tiedenkamp 16",
        "address_2": "Henstedt-Ulzburg  SH  24558",
        "country": "DE"
    },
    "00231A": {
        "oui_hex": "00-23-1A",
        "organization": "ITF Co., Ltd.",
        "address_1": "2-2-11 Nishiki-cho",
        "address_2": "Tachikawa-shi  Tokyo  190-0022",
        "country": "JP"
    },
    "0022BC": {
        "oui_hex": "00-22-BC",
        "organization": "JDSU France SAS",
        "address_1": "34 rue Necker",
        "address_2": "SAINT ETIENNE  LOIRE  42000",
        "country": "FR"
    },
    "0022AA": {
        "oui_hex": "00-22-AA",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0022C9": {
        "oui_hex": "00-22-C9",
        "organization": "Lenord, Bauer & Co GmbH",
        "address_1": "Dohlenstr 32",
        "address_2": "Oberhausen  NRW  46145",
        "country": "DE"
    },
    "00228C": {
        "oui_hex": "00-22-8C",
        "organization": "Photon Europe GmbH",
        "address_1": "Jülicher Straße 376",
        "address_2": "Aachen  Nordrhein-Westfalen  52070",
        "country": "DE"
    },
    "00228B": {
        "oui_hex": "00-22-8B",
        "organization": "Kensington Computer Products Group",
        "address_1": "333 Twin Dolphin Dr.",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "00228D": {
        "oui_hex": "00-22-8D",
        "organization": "GBS Laboratories LLC",
        "address_1": "2325 Dulles Corner Blvd",
        "address_2": "Herndon  VA  20171",
        "country": "US"
    },
    "00224C": {
        "oui_hex": "00-22-4C",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "00224A": {
        "oui_hex": "00-22-4A",
        "organization": "RAYLASE AG",
        "address_1": "Argelsrieder Feld 2-4",
        "address_2": "Wessling  Bavaria  82234",
        "country": "DE"
    },
    "00224B": {
        "oui_hex": "00-22-4B",
        "organization": "AIRTECH TECHNOLOGIES, INC.",
        "address_1": "19fl-4, no.77, Hsin Tai Wu Rd., sec.1, Hsin-Chih",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "002256": {
        "oui_hex": "00-22-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002252": {
        "oui_hex": "00-22-52",
        "organization": "ZOLL Lifecor Corporation",
        "address_1": "121 Freeport Road",
        "address_2": "Pittsburgh  PA  15238",
        "country": "US"
    },
    "00224D": {
        "oui_hex": "00-22-4D",
        "organization": "MITAC INTERNATIONAL CORP.",
        "address_1": "6TH FL., NO187, TIDING BLVD., SEC. 2",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00229F": {
        "oui_hex": "00-22-9F",
        "organization": "Sensys Traffic AB",
        "address_1": "Slottsgatan 14",
        "address_2": "Jonkoping  Smaland  55322",
        "country": "SE"
    },
    "002299": {
        "oui_hex": "00-22-99",
        "organization": "SeaMicro Inc.",
        "address_1": "4677 Old Ironsides Dr.,",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00226D": {
        "oui_hex": "00-22-6D",
        "organization": "Shenzhen GIEC Electronics Co., Ltd.",
        "address_1": "24/F, XiNian Center, ShenNan Road 6021#, Futian District",
        "address_2": "Shenzhen  Guangdong Province  518040",
        "country": "CN"
    },
    "00226E": {
        "oui_hex": "00-22-6E",
        "organization": "Gowell Electronic Limited",
        "address_1": "Room 3601 ,36 Floor,Golden Central Tower,Jintian Road,Futian Central District,",
        "address_2": "Shenzhen  GuangDong  518048",
        "country": "CN"
    },
    "00225D": {
        "oui_hex": "00-22-5D",
        "organization": "Digicable Network India Pvt. Ltd.",
        "address_1": "7B, Shah Industrial Estate",
        "address_2": "Andheri - West, Mumbai.  Maharashtra  400 053",
        "country": "IN"
    },
    "00227B": {
        "oui_hex": "00-22-7B",
        "organization": "Apogee Labs, Inc.",
        "address_1": "210 S. 3rd St.",
        "address_2": "North Wales  PA  19454",
        "country": "US"
    },
    "002289": {
        "oui_hex": "00-22-89",
        "organization": "Vandelrande APC inc.",
        "address_1": "1280 Lebourgneuf Blvd.",
        "address_2": "Quebec    G2K 0H1",
        "country": "CA"
    },
    "00227D": {
        "oui_hex": "00-22-7D",
        "organization": "YE DATA INC.",
        "address_1": "182 Shinko",
        "address_2": "Iruma  Saitama  358-0055",
        "country": "JP"
    },
    "0022A8": {
        "oui_hex": "00-22-A8",
        "organization": "Ouman Oy",
        "address_1": "Voimatie 6",
        "address_2": "Kempele    FIN-90440",
        "country": "FI"
    },
    "002223": {
        "oui_hex": "00-22-23",
        "organization": "TimeKeeping Systems, Inc.",
        "address_1": "30700 Bainbridge Road",
        "address_2": "Solon  OH  44139",
        "country": "US"
    },
    "00221A": {
        "oui_hex": "00-22-1A",
        "organization": "Audio Precision",
        "address_1": "5750 SW Arctic Drive",
        "address_2": "Beaverton  OR  97005",
        "country": "US"
    },
    "002218": {
        "oui_hex": "00-22-18",
        "organization": "AKAMAI TECHNOLOGIES INC",
        "address_1": "150 BROADWAY",
        "address_2": "CAMBRIDGE  MA  02142",
        "country": "US"
    },
    "00223C": {
        "oui_hex": "00-22-3C",
        "organization": "RATIO Entwicklungen GmbH",
        "address_1": "Ludwig-Erhard-Strasse 22",
        "address_2": "Hamburg    20459",
        "country": "DE"
    },
    "0021E7": {
        "oui_hex": "00-21-E7",
        "organization": "Informatics Services Corporation",
        "address_1": "140, Negin Bldg.,",
        "address_2": "Tehran    1549534511",
        "country": "IR"
    },
    "0021DC": {
        "oui_hex": "00-21-DC",
        "organization": "TECNOALARM S.r.l.",
        "address_1": "Via Cirie'",
        "address_2": "San Mauro Torinese  Torino  10099",
        "country": "IT"
    },
    "0021F1": {
        "oui_hex": "00-21-F1",
        "organization": "Tutus Data AB",
        "address_1": "Svardvagen 11",
        "address_2": "Danderyd  Stockholm  18233",
        "country": "SE"
    },
    "0021E3": {
        "oui_hex": "00-21-E3",
        "organization": "SerialTek LLC",
        "address_1": "1570 Oakland Road",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "00221C": {
        "oui_hex": "00-22-1C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "002222": {
        "oui_hex": "00-22-22",
        "organization": "Schaffner Deutschland GmbH",
        "address_1": "Nürtingen Branch",
        "address_2": "Nürtingen  BW  D-72622",
        "country": "DE"
    },
    "0021F8": {
        "oui_hex": "00-21-F8",
        "organization": "Enseo, Inc.",
        "address_1": "401 International Parkway",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0021F3": {
        "oui_hex": "00-21-F3",
        "organization": "Si14 SpA",
        "address_1": "Via Tommaseo 77",
        "address_2": "Padova  PD  35131",
        "country": "IT"
    },
    "002231": {
        "oui_hex": "00-22-31",
        "organization": "SMT&C Co., Ltd.",
        "address_1": "2Fr. Haksan Bldg. 110, Gwangjang-dong, Gwangjin-gu",
        "address_2": "Seoul    143-802",
        "country": "KR"
    },
    "002213": {
        "oui_hex": "00-22-13",
        "organization": "PCI CORPORATION",
        "address_1": "No.25, Lane 66, Hebei 1st St.,  Beitun District",
        "address_2": "Taichung    406",
        "country": "TW"
    },
    "002201": {
        "oui_hex": "00-22-01",
        "organization": "Aksys Networks Inc",
        "address_1": "428, 3553 - 31 Street NW",
        "address_2": "Calgary    T2L 2K7",
        "country": "CA"
    },
    "00217B": {
        "oui_hex": "00-21-7B",
        "organization": "Bastec AB",
        "address_1": "Hästvägen 4A",
        "address_2": "Malmö  SE  212 35",
        "country": "SE"
    },
    "002176": {
        "oui_hex": "00-21-76",
        "organization": "YMax Telecom Ltd.",
        "address_1": "11 Moshe Levi str.",
        "address_2": "Rishon Le Zion    75658",
        "country": "IL"
    },
    "002171": {
        "oui_hex": "00-21-71",
        "organization": "Wesung TNC Co., Ltd.",
        "address_1": "102-1409, Bucheon Chunui Technopark 1st,",
        "address_2": "Bucheon-City,  Gyeongggi-Do  420-857",
        "country": "KR"
    },
    "002193": {
        "oui_hex": "00-21-93",
        "organization": "Videofon MV",
        "address_1": "6 Blackoak Mews",
        "address_2": "Newtown  PA  18940",
        "country": "US"
    },
    "002192": {
        "oui_hex": "00-21-92",
        "organization": "Baoding Galaxy Electronic Technology  Co.,Ltd",
        "address_1": "NO.91 Fengfan Rd.,GaoKai District,Baoding City,Hebei Prov.China 071051",
        "address_2": "Baoding City  Hebei Prov.  071051",
        "country": "CN"
    },
    "0021A7": {
        "oui_hex": "00-21-A7",
        "organization": "Hantle System Co., Ltd.",
        "address_1": "481-10 Byucksan Digital Vally II, RM 1511",
        "address_2": "Seoul City  Seoul  153-783",
        "country": "KR"
    },
    "00219C": {
        "oui_hex": "00-21-9C",
        "organization": "Honeywld Technology Corp.",
        "address_1": "No.40,Hsueh-Fu Rd.",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "00219A": {
        "oui_hex": "00-21-9A",
        "organization": "Cambridge Visual Networks Ltd",
        "address_1": "61 Selwyn Road",
        "address_2": "Cambridge  Cambridgeshire  CB3 9EA",
        "country": "GB"
    },
    "0021D8": {
        "oui_hex": "00-21-D8",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0021D7": {
        "oui_hex": "00-21-D7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0021D9": {
        "oui_hex": "00-21-D9",
        "organization": "SEKONIC CORPORATION",
        "address_1": "7-24-14",
        "address_2": "NERIMA-KU  TOKYO  178-8686",
        "country": "JP"
    },
    "0021DA": {
        "oui_hex": "00-21-DA",
        "organization": "Automation Products Group Inc.",
        "address_1": "1025 West 1700 North",
        "address_2": "Logan  Utah  84321",
        "country": "US"
    },
    "0021B5": {
        "oui_hex": "00-21-B5",
        "organization": "Galvanic Ltd",
        "address_1": "38 Nothumberland Road",
        "address_2": "Dublin    2",
        "country": "IE"
    },
    "0021BD": {
        "oui_hex": "00-21-BD",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "0021C4": {
        "oui_hex": "00-21-C4",
        "organization": "Consilium AB",
        "address_1": "Västra Finnbodavägen 2-4",
        "address_2": "Nacka  Stockholm  13131",
        "country": "SE"
    },
    "002189": {
        "oui_hex": "00-21-89",
        "organization": "AppTech, Inc.",
        "address_1": "363 E Greyhound Pass",
        "address_2": "Carmel  Indiana  46032",
        "country": "US"
    },
    "002122": {
        "oui_hex": "00-21-22",
        "organization": "Chip-pro Ltd.",
        "address_1": "5F.-4, No.63, Siwei Rd., North District,",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "002125": {
        "oui_hex": "00-21-25",
        "organization": "KUK JE TONG SHIN Co.,LTD",
        "address_1": "476-3",
        "address_2": "Incheon  Kwangyouk-Si  407-060",
        "country": "KR"
    },
    "002126": {
        "oui_hex": "00-21-26",
        "organization": "Shenzhen Torch Equipment Co., Ltd.",
        "address_1": "Floor 5, Block 3, Liming Industrial District, Zhongshanyuan Road, Nanshan,",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "002113": {
        "oui_hex": "00-21-13",
        "organization": "Padtec S/A",
        "address_1": "Road Campinas Mogi-Mirim km 118,5",
        "address_2": "Campinas  São Paulo  13086-902",
        "country": "BR"
    },
    "002112": {
        "oui_hex": "00-21-12",
        "organization": "WISCOM SYSTEM CO.,LTD",
        "address_1": "100 Jiangjun Road,Jiangning,",
        "address_2": "Nanjing    211100",
        "country": "CN"
    },
    "00210E": {
        "oui_hex": "00-21-0E",
        "organization": "Orpak Systems L.T.D.",
        "address_1": "31 Lechi St",
        "address_2": "Bnei - Brak    51114",
        "country": "IL"
    },
    "002161": {
        "oui_hex": "00-21-61",
        "organization": "Yournet Inc.",
        "address_1": "KT R&D Center",
        "address_2": "Seoul    137-792",
        "country": "KR"
    },
    "00215F": {
        "oui_hex": "00-21-5F",
        "organization": "IHSE GmbH",
        "address_1": "Maybachstraße 11",
        "address_2": "Oberteuringen  Baden-Württemberg  88094",
        "country": "DE"
    },
    "002135": {
        "oui_hex": "00-21-35",
        "organization": "ALCATEL-LUCENT",
        "address_1": "Ramirez de Prado 5",
        "address_2": "Madrid    28045",
        "country": "ES"
    },
    "002138": {
        "oui_hex": "00-21-38",
        "organization": "Cepheid",
        "address_1": "904 Caribbean Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "002147": {
        "oui_hex": "00-21-47",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "002149": {
        "oui_hex": "00-21-49",
        "organization": "China Daheng Group ,Inc.",
        "address_1": "12F Daheng Science & Technology Tower ,NO.3 Suzhou Str.",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "002156": {
        "oui_hex": "00-21-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002151": {
        "oui_hex": "00-21-51",
        "organization": "Millinet Co., Ltd.",
        "address_1": "2F, West Building, IT Venture Tower, 78, Garakbon-Dong",
        "address_2": "Songpa-gu  Seoul  138-803",
        "country": "US"
    },
    "00216C": {
        "oui_hex": "00-21-6C",
        "organization": "ODVA",
        "address_1": "4220 Varsity Drive",
        "address_2": "Ann Arbor  MI  48108-5006",
        "country": "US"
    },
    "00211C": {
        "oui_hex": "00-21-1C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "002118": {
        "oui_hex": "00-21-18",
        "organization": "Athena Tech, Inc.",
        "address_1": "3721 Macintosh Dr",
        "address_2": "Warrenton  VA  20187",
        "country": "US"
    },
    "001FBD": {
        "oui_hex": "00-1F-BD",
        "organization": "Kyocera Wireless Corp.",
        "address_1": "10300 Campus Point Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001FB9": {
        "oui_hex": "00-1F-B9",
        "organization": "Paltronics",
        "address_1": "1145 Paltronics Ct",
        "address_2": "Crystal Lake  IL  60014",
        "country": "US"
    },
    "001FB7": {
        "oui_hex": "00-1F-B7",
        "organization": "WiMate Technologies Corp.",
        "address_1": "14A Building 2, Guimiao Garden, Nanguanglu, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518054",
        "country": "CN"
    },
    "001FB4": {
        "oui_hex": "00-1F-B4",
        "organization": "SmartShare Systems",
        "address_1": "Tonsbakken 16-18",
        "address_2": "Skovlunde    DK-2740",
        "country": "DK"
    },
    "001FB6": {
        "oui_hex": "00-1F-B6",
        "organization": "Chi Lin Technology Co., Ltd.",
        "address_1": "No.18, Sheng Li 1st St., Jen Te Hsiang,",
        "address_2": "Tainan  Taiwan  71758",
        "country": "CN"
    },
    "001FC8": {
        "oui_hex": "00-1F-C8",
        "organization": "Up-Today Industrial Co., Ltd.",
        "address_1": "7/F., Unify Commercial & Industrial Building",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "001FC5": {
        "oui_hex": "00-1F-C5",
        "organization": "Nintendo Co., Ltd.",
        "address_1": "  11-1 HOKOTATE-CHO KAMITOBA, MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "001FC0": {
        "oui_hex": "00-1F-C0",
        "organization": "Control Express Finland Oy",
        "address_1": "Laitaatsillantie 3",
        "address_2": "Savonlinna    57170",
        "country": "FI"
    },
    "001FBC": {
        "oui_hex": "00-1F-BC",
        "organization": "EVGA Corporation",
        "address_1": "2900 Saturn St.",
        "address_2": "Brea  CA  92821",
        "country": "US"
    },
    "001FF9": {
        "oui_hex": "00-1F-F9",
        "organization": "Advanced Knowledge Associates",
        "address_1": "3350 Scott Blvd, Suite 40",
        "address_2": "Santa Clara  CA  95054-3119",
        "country": "US"
    },
    "001FED": {
        "oui_hex": "00-1F-ED",
        "organization": "Tecan Systems Inc.",
        "address_1": "2450 Zanker Road",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "001FE5": {
        "oui_hex": "00-1F-E5",
        "organization": "In-Circuit GmbH",
        "address_1": "Königsbrücker Strasse 69",
        "address_2": "Dresden    01099",
        "country": "DE"
    },
    "001FF4": {
        "oui_hex": "00-1F-F4",
        "organization": "Power Monitors, Inc.",
        "address_1": "800 North Main Street",
        "address_2": "Mt. Crawford  Virginia  22841",
        "country": "US"
    },
    "001F5F": {
        "oui_hex": "00-1F-5F",
        "organization": "Blatand GmbH",
        "address_1": "Lichtenbergstrße 8",
        "address_2": "Garching  Bavaria  85748",
        "country": "DE"
    },
    "001F57": {
        "oui_hex": "00-1F-57",
        "organization": "Phonik Innovation Co.,LTD",
        "address_1": "29/167 Moo2, 345 Rd, Lampo,",
        "address_2": "Nonthaburi    11110",
        "country": "TH"
    },
    "001F59": {
        "oui_hex": "00-1F-59",
        "organization": "Kronback Tracers",
        "address_1": "c/o DTU, R254",
        "address_2": "Ballerup  Copenhagen  2750",
        "country": "DK"
    },
    "001F4E": {
        "oui_hex": "00-1F-4E",
        "organization": "ConMed Linvatec",
        "address_1": "11311 Concept Blvd.",
        "address_2": "Largo  FL  33773",
        "country": "US"
    },
    "001FAA": {
        "oui_hex": "00-1F-AA",
        "organization": "Taseon, Inc.",
        "address_1": " 3099 N. First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001F7B": {
        "oui_hex": "00-1F-7B",
        "organization": "TechNexion Ltd.",
        "address_1": "17F-1, No. 16, Jian Ba Road,",
        "address_2": "Chung Ho   Taipei  235",
        "country": "TW"
    },
    "001F7D": {
        "oui_hex": "00-1F-7D",
        "organization": "Embedded Wireless GmbH",
        "address_1": "Soeflinger Strasse 200",
        "address_2": "Ulm  BW  89077",
        "country": "DE"
    },
    "001F8D": {
        "oui_hex": "00-1F-8D",
        "organization": "Ingenieurbuero Stark GmbH und Ko. KG",
        "address_1": "Rudolf-Diesel-Strasse 44",
        "address_2": "Laichingen  BW  89150",
        "country": "DE"
    },
    "001FAF": {
        "oui_hex": "00-1F-AF",
        "organization": "NextIO, Inc.",
        "address_1": "8303 N MoPac Expressway",
        "address_2": "Austin  TX  78759",
        "country": "US"
    },
    "001F74": {
        "oui_hex": "00-1F-74",
        "organization": "Eigen Development",
        "address_1": "1807 W10th Ave",
        "address_2": "Vancouver  BC  V6J 2A9",
        "country": "CA"
    },
    "001F75": {
        "oui_hex": "00-1F-75",
        "organization": "GiBahn Media",
        "address_1": "1816 Rosedale Suseo-dong",
        "address_2": "Seoul    135-885",
        "country": "KR"
    },
    "001F8F": {
        "oui_hex": "00-1F-8F",
        "organization": "Shanghai Bellmann Digital Source Co.,Ltd.",
        "address_1": "404-408 Main Bd, FDUSP, No.11 Guotai Rd.",
        "address_2": "Shanghai    200433",
        "country": "CN"
    },
    "001F84": {
        "oui_hex": "00-1F-84",
        "organization": "Gigle Semiconductor",
        "address_1": "Barcelona Activa - Vivero Glorias",
        "address_2": "Barcelona    08018",
        "country": "ES"
    },
    "001F6E": {
        "oui_hex": "00-1F-6E",
        "organization": "Vtech Engineering Corporation",
        "address_1": "20 New England Business Center",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "001F66": {
        "oui_hex": "00-1F-66",
        "organization": "PLANAR LLC",
        "address_1": "32, Elkina str",
        "address_2": "Chelyabinsk  SU  454091",
        "country": "RU"
    },
    "001FA0": {
        "oui_hex": "00-1F-A0",
        "organization": "A10 Networks",
        "address_1": "3 West Plumeria Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001F9E": {
        "oui_hex": "00-1F-9E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001EE6": {
        "oui_hex": "00-1E-E6",
        "organization": "Shenzhen Advanced Video Info-Tech Co., Ltd.",
        "address_1": "Tianxiang 11A,  Tian'an Cyber Park , Futian",
        "address_2": "Shenzhen  Guangdong  518048",
        "country": "CN"
    },
    "001EF7": {
        "oui_hex": "00-1E-F7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001F0B": {
        "oui_hex": "00-1F-0B",
        "organization": "Federal State Unitary Enterprise Industrial UnionElectropribor",
        "address_1": "",
        "address_2": "Penza    440011",
        "country": "RU"
    },
    "001F0C": {
        "oui_hex": "00-1F-0C",
        "organization": "Intelligent Digital Services GmbH",
        "address_1": "Grevesmuehlener Strasse 8",
        "address_2": "Mallentin  Mecklenburg-Vorpommern  23639",
        "country": "DE"
    },
    "001F08": {
        "oui_hex": "00-1F-08",
        "organization": "RISCO LTD",
        "address_1": "32 Hacharoshet St",
        "address_2": "Kiriat Malachi    83101",
        "country": "IL"
    },
    "001F43": {
        "oui_hex": "00-1F-43",
        "organization": "ENTES ELEKTRONIK",
        "address_1": "Y. Dudullu Org. San. Bol. And Sanayi Sit. No.6",
        "address_2": "Istanbul  Dudullu  34775",
        "country": "TR"
    },
    "001F14": {
        "oui_hex": "00-1F-14",
        "organization": "NexG",
        "address_1": "5F Seoul Academy Bldg, Daechi-Dong, Gangnam-Gu,",
        "address_2": "Seoul    135-280",
        "country": "KR"
    },
    "001EF1": {
        "oui_hex": "00-1E-F1",
        "organization": "Servimat",
        "address_1": "ZAET Les Haies",
        "address_2": "St Maximin  Oise  60740",
        "country": "FR"
    },
    "001EF4": {
        "oui_hex": "00-1E-F4",
        "organization": "L-3 Communications Display Systems",
        "address_1": "1355 Bluegrass Lakes Parkway",
        "address_2": "Alpharetta  GA  30004-8458",
        "country": "US"
    },
    "001EF5": {
        "oui_hex": "00-1E-F5",
        "organization": "Hitek Automated Inc.",
        "address_1": "Room C3-901, No.383, Huamen Shijia",
        "address_2": "Hangzhou    310012",
        "country": "CN"
    },
    "001F0E": {
        "oui_hex": "00-1F-0E",
        "organization": "Japan Kyastem Co., Ltd",
        "address_1": "1-4-4",
        "address_2": "Tachikawa  Tokyo  190-0022",
        "country": "JP"
    },
    "001F28": {
        "oui_hex": "00-1F-28",
        "organization": "HPN Supply Chain",
        "address_1": "8000 Foothills Blvd",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "001F1E": {
        "oui_hex": "00-1F-1E",
        "organization": "Astec Technology Co., Ltd",
        "address_1": "12F, No.2, Jian Ba Rd.",
        "address_2": "Chung Ho  Taipei Hsien  235",
        "country": "TW"
    },
    "001F4A": {
        "oui_hex": "00-1F-4A",
        "organization": "Albentia Systems S.A.",
        "address_1": "Albala 13",
        "address_2": "Madrid    28037",
        "country": "ES"
    },
    "001EAA": {
        "oui_hex": "00-1E-AA",
        "organization": "E-Senza Technologies GmbH",
        "address_1": "Blarerstrasse 56",
        "address_2": "Konstanz  BW  78462",
        "country": "DE"
    },
    "001E9C": {
        "oui_hex": "00-1E-9C",
        "organization": "Fidustron INC",
        "address_1": "NO.770-6, Jhongiheng Rd.",
        "address_2": "Jhonghe City  Taipei County  235",
        "country": "TW"
    },
    "001E97": {
        "oui_hex": "00-1E-97",
        "organization": "Medium Link System Technology CO., LTD,",
        "address_1": "11F.-2, No.7, Alley 92, Lane 77, Sec. 4, Sinhai Rd.,",
        "address_2": "Wunshan District,  Taipei  11693",
        "country": "TW"
    },
    "001E8B": {
        "oui_hex": "00-1E-8B",
        "organization": "Infra Access Korea Co., Ltd.",
        "address_1": "#902, Sambo Saving Bank B/D,",
        "address_2": "Kwanak-gu,  Seoul  151-830",
        "country": "KR"
    },
    "001EBB": {
        "oui_hex": "00-1E-BB",
        "organization": "BLUELIGHT TECHNOLOGY INC.",
        "address_1": "6472 CAMDEN AVE., SUITE 102B",
        "address_2": "SAN JOSE  CA  95120",
        "country": "US"
    },
    "001EB5": {
        "oui_hex": "00-1E-B5",
        "organization": "Ever Sparkle Technologies Ltd",
        "address_1": "Unit 403, Nan Fung Commercial Centre",
        "address_2": "Kowloon Bay  Kowloon",
        "country": "HK"
    },
    "001EB3": {
        "oui_hex": "00-1E-B3",
        "organization": "Primex Wireless",
        "address_1": "965 Wells Street",
        "address_2": "Lake Geneva  WI  53147",
        "country": "US"
    },
    "001E85": {
        "oui_hex": "00-1E-85",
        "organization": "Lagotek Corporation",
        "address_1": "11661 SE 1st St. #208",
        "address_2": "Bellevue  WA  98005",
        "country": "US"
    },
    "001ED8": {
        "oui_hex": "00-1E-D8",
        "organization": "Digital United Inc.",
        "address_1": "9F, No.220, Gangcian Rd.",
        "address_2": "Taipei    11444",
        "country": "TW"
    },
    "001ED6": {
        "oui_hex": "00-1E-D6",
        "organization": "Alentec & Orion AB",
        "address_1": "Grustagsvägen 4",
        "address_2": "138 40  ÄLTA",
        "country": "SE"
    },
    "001EC6": {
        "oui_hex": "00-1E-C6",
        "organization": "Obvius Holdings LLC",
        "address_1": "20811 NW Cornell Road",
        "address_2": "Hillsboro  OR  97124",
        "country": "US"
    },
    "001EC4": {
        "oui_hex": "00-1E-C4",
        "organization": "Celio Corp",
        "address_1": "265 E 100 S  # 280",
        "address_2": "Salt Lake City  UT  84111",
        "country": "US"
    },
    "001EC1": {
        "oui_hex": "00-1E-C1",
        "organization": "3COM EUROPE LTD",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  HERTS.  HP2 4NW",
        "country": "GB"
    },
    "001EB6": {
        "oui_hex": "00-1E-B6",
        "organization": "TAG Heuer SA",
        "address_1": "Rue Louis-Joseph Chevrolet 6A",
        "address_2": "la Chaux-de-Fonds  NE  2300",
        "country": "CH"
    },
    "001EAC": {
        "oui_hex": "00-1E-AC",
        "organization": "Armadeus Systems",
        "address_1": "Business Campus",
        "address_2": "MULHOUSE cedex  Haut-Rhin  68058",
        "country": "FR"
    },
    "001E77": {
        "oui_hex": "00-1E-77",
        "organization": "Air2App",
        "address_1": "50 Old Forge Rd",
        "address_2": "Hanover  MA  02339",
        "country": "US"
    },
    "001E7B": {
        "oui_hex": "00-1E-7B",
        "organization": "R.I.CO. S.r.l.",
        "address_1": "via Adriatica, 17",
        "address_2": "Castelfidardo  AN  60022",
        "country": "IT"
    },
    "001E6E": {
        "oui_hex": "00-1E-6E",
        "organization": "Shenzhen First Mile Communications Ltd",
        "address_1": "5th Floor, Block R3-A",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001E6D": {
        "oui_hex": "00-1E-6D",
        "organization": "IT R&D Center",
        "address_1": "461-25, Jeonmin-dong,Yuseong-Gu",
        "address_2": "Daejeon    305-811",
        "country": "KR"
    },
    "001E34": {
        "oui_hex": "00-1E-34",
        "organization": "CryptoMetrics",
        "address_1": "160 Michael Cowpland Dr",
        "address_2": "Ottawa  Ontario  K2M 1P6",
        "country": "CA"
    },
    "001E2D": {
        "oui_hex": "00-1E-2D",
        "organization": "STIM",
        "address_1": "ZAC les COUSTELLIERS",
        "address_2": "CASTRIES  HERAULT  34160",
        "country": "FR"
    },
    "001E41": {
        "oui_hex": "00-1E-41",
        "organization": "Microwave Communication & Component, Inc.",
        "address_1": "#204, WOOLIM LION`S VALLEY 2, 680",
        "address_2": "Seoul    150-787",
        "country": "KR"
    },
    "001DFC": {
        "oui_hex": "00-1D-FC",
        "organization": "KSIC",
        "address_1": "#6F, Korea Federation of Teacher's Associations, 114-1, TaeBong-Ro,",
        "address_2": "Seoul  Seocho-Ku  137-715",
        "country": "KR"
    },
    "001E55": {
        "oui_hex": "00-1E-55",
        "organization": "COWON SYSTEMS,Inc.",
        "address_1": "6th Fl. COWON TOWER,689-3,",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "001E56": {
        "oui_hex": "00-1E-56",
        "organization": "Bally Wulff Entertainment GmbH",
        "address_1": "Maybachufer 48-51",
        "address_2": "Berlin    12045",
        "country": "DE"
    },
    "001E3F": {
        "oui_hex": "00-1E-3F",
        "organization": "TrellisWare Technologies, Inc.",
        "address_1": "16516 Via Esprillo, Suite 300",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "001E57": {
        "oui_hex": "00-1E-57",
        "organization": "ALCOMA, spol. s r.o.",
        "address_1": "Klukovice 313, Praha - 5",
        "address_2": "Praha    152 00",
        "country": "CZ"
    },
    "001E50": {
        "oui_hex": "00-1E-50",
        "organization": "BATTISTONI RESEARCH",
        "address_1": "PARCO DONICA 56",
        "address_2": "FISCIANO  SALERNO  84084",
        "country": "IT"
    },
    "001E11": {
        "oui_hex": "00-1E-11",
        "organization": "ELELUX INTERNATIONAL LTD",
        "address_1": "3F., NO.103 CHOW TZE STREET",
        "address_2": "TAIPEI    114",
        "country": "TW"
    },
    "001DF2": {
        "oui_hex": "00-1D-F2",
        "organization": "Netflix, Inc.",
        "address_1": "100 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "001DEF": {
        "oui_hex": "00-1D-EF",
        "organization": "TRIMM, INC.",
        "address_1": "407 RAILROAD STREET",
        "address_2": "BUTNER  NC  27509",
        "country": "US"
    },
    "001DF1": {
        "oui_hex": "00-1D-F1",
        "organization": "Intego Systems, Inc.",
        "address_1": "5343 Bowden Road",
        "address_2": "Jacksonville  FL  32216",
        "country": "US"
    },
    "001DED": {
        "oui_hex": "00-1D-ED",
        "organization": "Grid Net, Inc.",
        "address_1": "340 Brannan Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "001DC3": {
        "oui_hex": "00-1D-C3",
        "organization": "RIKOR TV, Ltd",
        "address_1": "Kostomarovsky per.,3",
        "address_2": "Moscow    105120",
        "country": "RU"
    },
    "001DC1": {
        "oui_hex": "00-1D-C1",
        "organization": "Audinate Pty L",
        "address_1": "Level 1, 458 Wattle St",
        "address_2": "Ultimo  NSW  2007",
        "country": "AU"
    },
    "001DB2": {
        "oui_hex": "00-1D-B2",
        "organization": "HOKKAIDO ELECTRIC ENGINEERING CO.,LTD.",
        "address_1": "Nishinopporo 120-8",
        "address_2": "Ebetu-City  Hokkaido  069-0832",
        "country": "JP"
    },
    "001DAD": {
        "oui_hex": "00-1D-AD",
        "organization": "Sinotech Engineering Consultants, Inc.  Geotechnical Enginee",
        "address_1": "Basement No.7 Lane 26, Yat-Sen Rd.",
        "address_2": "Taipei    110",
        "country": "TW"
    },
    "001DAB": {
        "oui_hex": "00-1D-AB",
        "organization": "SwissQual License AG",
        "address_1": "Baarerstrasse 78",
        "address_2": "Zug  Postfach  117",
        "country": "CH"
    },
    "001D9C": {
        "oui_hex": "00-1D-9C",
        "organization": "Rockwell Automation",
        "address_1": "1 Allen-Bradley Dr.",
        "address_2": "Mayfield Heights  OH  44124-6118",
        "country": "US"
    },
    "001DA0": {
        "oui_hex": "00-1D-A0",
        "organization": "Heng Yu Electronic Manufacturing Company Limited",
        "address_1": "Room 1503-5, Nan Fung Com'l Centre,",
        "address_2": "Kowloon",
        "country": "HK"
    },
    "001DD8": {
        "oui_hex": "00-1D-D8",
        "organization": "Microsoft Corporation",
        "address_1": "One Microsoft Way",
        "address_2": "Redmond  Washington  98052-6399",
        "country": "US"
    },
    "001DC8": {
        "oui_hex": "00-1D-C8",
        "organization": "Navionics Research Inc., dba SCADAmetrics",
        "address_1": "1133 Pond Road",
        "address_2": "Wildwood  Missouri  63038",
        "country": "US"
    },
    "001DCC": {
        "oui_hex": "00-1D-CC",
        "organization": "Ayon Cyber Security, Inc",
        "address_1": "2350 Commerce Park Dr.",
        "address_2": "Palm Bay  FL  32905",
        "country": "US"
    },
    "001D92": {
        "oui_hex": "00-1D-92",
        "organization": "MICRO-STAR INT'L CO.,LTD.",
        "address_1": "No.69,Li-De St,Jung-Ho City",
        "address_2": "Taipei  Hsien  235",
        "country": "TW"
    },
    "001D8A": {
        "oui_hex": "00-1D-8A",
        "organization": "TechTrex Inc",
        "address_1": "6221 Highway 7, Unit 12",
        "address_2": "Woodbridge  Ontalio  L4H 0K8",
        "country": "CA"
    },
    "001D80": {
        "oui_hex": "00-1D-80",
        "organization": "Beijing Huahuan Eletronics Co.,Ltd",
        "address_1": "No.26,Shangdi 6th St.Haidian District,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001D83": {
        "oui_hex": "00-1D-83",
        "organization": "Emitech Corporation",
        "address_1": "2F,No.7-1,Industry E,Rd.9",
        "address_2": "Hsinchu    308",
        "country": "TW"
    },
    "001D74": {
        "oui_hex": "00-1D-74",
        "organization": "Tianjin China-Silicon Microelectronics Co., Ltd.",
        "address_1": "301,3F Building 211,No.214 Hongqi Road, Nankai District, Tianjin China",
        "address_2": "Tianjin    300190",
        "country": "CN"
    },
    "001D4B": {
        "oui_hex": "00-1D-4B",
        "organization": "Grid Connect Inc.",
        "address_1": "1630 W. Diehl Rd",
        "address_2": "Naperville  IL  60563",
        "country": "US"
    },
    "001D4D": {
        "oui_hex": "00-1D-4D",
        "organization": "Adaptive Recognition Hungary, Inc",
        "address_1": "Kiralyhago ter 8-9",
        "address_2": "Budapest  Europe  1126",
        "country": "HU"
    },
    "001D1E": {
        "oui_hex": "00-1D-1E",
        "organization": "KYUSHU TEN CO.,LTD",
        "address_1": "2360 YUNOKIMOTOMACHI",
        "address_2": "SASEBO-City  NAGASAKI Prefecture  857-0115",
        "country": "JP"
    },
    "001D1D": {
        "oui_hex": "00-1D-1D",
        "organization": "Inter-M Corporation",
        "address_1": "653-5 Banghak-Dong, Dobong-Ku",
        "address_2": "Seoul    132-846",
        "country": "KR"
    },
    "001D0E": {
        "oui_hex": "00-1D-0E",
        "organization": "Agapha Technology co., Ltd.",
        "address_1": "9F No.121, Shingde Rd.,",
        "address_2": "Sanchung City  Taipei County  241",
        "country": "TW"
    },
    "001D0A": {
        "oui_hex": "00-1D-0A",
        "organization": "Davis Instruments, Inc.",
        "address_1": "3465 Diablo Ave.",
        "address_2": "Hayward  CA  94545",
        "country": "US"
    },
    "001D67": {
        "oui_hex": "00-1D-67",
        "organization": "AMEC",
        "address_1": "9F,No.360,Ruel Guang Rd,Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001D7C": {
        "oui_hex": "00-1D-7C",
        "organization": "ABE Elettronica S.p.A.",
        "address_1": "Via Leonardo da Vinci, 92",
        "address_2": "CARAVAGGIO  BG  24043",
        "country": "IT"
    },
    "001D6D": {
        "oui_hex": "00-1D-6D",
        "organization": "Confidant International LLC",
        "address_1": "2530 Meridian Pkwy",
        "address_2": "Durham  North Carolina  27713",
        "country": "US"
    },
    "001D75": {
        "oui_hex": "00-1D-75",
        "organization": "Radioscape PLC",
        "address_1": "1 Albany Terrace",
        "address_2": "Regent's Park  London  NW1 4DS",
        "country": "GB"
    },
    "001D53": {
        "oui_hex": "00-1D-53",
        "organization": "S&O Electronics (Malaysia) Sdn. Bhd.",
        "address_1": "Lot 202, Bakar Arang",
        "address_2": "08000 Sungai Petani  Kedah",
        "country": "MY"
    },
    "001D54": {
        "oui_hex": "00-1D-54",
        "organization": "Sunnic Technology & Merchandise INC.",
        "address_1": "6F, NO.74,ZHOU-Z ST.,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001D5F": {
        "oui_hex": "00-1D-5F",
        "organization": "OverSpeed SARL",
        "address_1": "15, allee du Bois Cailley",
        "address_2": "Le Thuit-Signol  Normandie  27370",
        "country": "FR"
    },
    "001D58": {
        "oui_hex": "00-1D-58",
        "organization": "CQ Inc",
        "address_1": "5F, No. 43, Lane 76, Rui Guang Road",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001D87": {
        "oui_hex": "00-1D-87",
        "organization": "VigTech Labs Sdn Bhd",
        "address_1": "45-11 The Boulevard Mid Valley City",
        "address_2": "Kuala Lumpur  Selangor  59200",
        "country": "MY"
    },
    "001D2F": {
        "oui_hex": "00-1D-2F",
        "organization": "QuantumVision Corporation",
        "address_1": "335 Plantation Way",
        "address_2": "Roswell  Ga  30075",
        "country": "US"
    },
    "001CE5": {
        "oui_hex": "00-1C-E5",
        "organization": "MBS Electronic Systems GmbH",
        "address_1": "Ringstrasse 3",
        "address_2": "82319 Starnberg  Bavaria  82319",
        "country": "DE"
    },
    "001CDD": {
        "oui_hex": "00-1C-DD",
        "organization": "COWBELL ENGINEERING CO., LTD.",
        "address_1": "1739-1 Nagatoro",
        "address_2": "SAKU  Nagano  385-0021",
        "country": "JP"
    },
    "001CC2": {
        "oui_hex": "00-1C-C2",
        "organization": "Part II Research, Inc.",
        "address_1": "4601 E. Airport Dr.",
        "address_2": "Ontario  CA  91761",
        "country": "US"
    },
    "001CBD": {
        "oui_hex": "00-1C-BD",
        "organization": "Ezze Mobile Tech., Inc.",
        "address_1": "3F, Bubmusa Bldg., 151-31",
        "address_2": "  Seoul  135-824",
        "country": "KR"
    },
    "001CB8": {
        "oui_hex": "00-1C-B8",
        "organization": "CBC Co., Ltd",
        "address_1": "2-15-13, Tsukishima, Chuo-ku",
        "address_2": "Tokyo    104-0052",
        "country": "JP"
    },
    "001CAC": {
        "oui_hex": "00-1C-AC",
        "organization": "Qniq Technology Corp.",
        "address_1": "5F, No.133, Sec.4, Minsheng E. Rd.,",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "001CA5": {
        "oui_hex": "00-1C-A5",
        "organization": "Zygo Corporation",
        "address_1": "21 Laurel Brook Rd.",
        "address_2": "Middlefield  CT  06455",
        "country": "US"
    },
    "001C9D": {
        "oui_hex": "00-1C-9D",
        "organization": "Liecthi AG",
        "address_1": "10 Unterholz Street",
        "address_2": "Kriegstetten  Solothurn  4566",
        "country": "CH"
    },
    "001CFF": {
        "oui_hex": "00-1C-FF",
        "organization": "Napera Networks Inc",
        "address_1": "7683 SE 27th",
        "address_2": "Mercer Island  WA  98040",
        "country": "US"
    },
    "001CDC": {
        "oui_hex": "00-1C-DC",
        "organization": "Custom Computer Services, Inc.",
        "address_1": "1020 Spring City Drive",
        "address_2": "Waukesha  WI  53186",
        "country": "US"
    },
    "001CD1": {
        "oui_hex": "00-1C-D1",
        "organization": "Waves Audio LTD",
        "address_1": "Azrilei Center 3, Triangle tower",
        "address_2": "Tel Aviv  Central  67023",
        "country": "IL"
    },
    "001CED": {
        "oui_hex": "00-1C-ED",
        "organization": "ENVIRONNEMENT SA",
        "address_1": "111 bd. Robespierre",
        "address_2": "POISSY  Yvelines  78300",
        "country": "FR"
    },
    "001CBA": {
        "oui_hex": "00-1C-BA",
        "organization": "VerScient, Inc.",
        "address_1": "7700 Equitable Drive",
        "address_2": "Eden Prairie  MN  55344",
        "country": "US"
    },
    "001CB0": {
        "oui_hex": "00-1C-B0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C4C": {
        "oui_hex": "00-1C-4C",
        "organization": "Petrotest Instruments",
        "address_1": "Ludwig-Erhard-Ring 13",
        "address_2": "Dahlewitz  BBG  15827",
        "country": "DE"
    },
    "001C45": {
        "oui_hex": "00-1C-45",
        "organization": "Chenbro Micom Co., Ltd.",
        "address_1": "15Fl., No. 150, Jian Yi Road",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "001C3C": {
        "oui_hex": "00-1C-3C",
        "organization": "Seon Design Inc.",
        "address_1": "111-3B Burbidge Street",
        "address_2": "Coquitlam  BC  V3K 7B2",
        "country": "CA"
    },
    "001C57": {
        "oui_hex": "00-1C-57",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001C5D": {
        "oui_hex": "00-1C-5D",
        "organization": "Leica Microsystems",
        "address_1": "Lothbury House Cambridge Technopark",
        "address_2": "Cambridge    CB5 8PB",
        "country": "GB"
    },
    "001C5E": {
        "oui_hex": "00-1C-5E",
        "organization": "ASTON France",
        "address_1": "151 Avenue Gallieni",
        "address_2": "BAGNOLET  ile de france  93177",
        "country": "FR"
    },
    "001C55": {
        "oui_hex": "00-1C-55",
        "organization": "Shenzhen Kaifa Technology Co.",
        "address_1": "7006 Caitian Road, Futian District,",
        "address_2": "Shenzhen  Guangdong  518035",
        "country": "CN"
    },
    "001C5B": {
        "oui_hex": "00-1C-5B",
        "organization": "Chubb Electronic Security Systems Ltd",
        "address_1": "Shadsworth Road",
        "address_2": "Blackburn  Lancashire  BB1 2PR",
        "country": "GB"
    },
    "001C44": {
        "oui_hex": "00-1C-44",
        "organization": "Bosch Security Systems BV",
        "address_1": "Kapittelweg 10",
        "address_2": "4827 HG  Breda  Brabant  4827",
        "country": "NL"
    },
    "001C82": {
        "oui_hex": "00-1C-82",
        "organization": "Genew Technologies",
        "address_1": "3A3 Building B1, Cyber-tech Zone,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "001C84": {
        "oui_hex": "00-1C-84",
        "organization": "STL Solution Co.,Ltd.",
        "address_1": "#710, World Meridian Venture Center I",
        "address_2": "Seoul    152781",
        "country": "KR"
    },
    "001C79": {
        "oui_hex": "00-1C-79",
        "organization": "Cohesive Financial Technologies LLC",
        "address_1": "200 South Wacker Dr.",
        "address_2": "Chicago  IL  60606",
        "country": "US"
    },
    "001C64": {
        "oui_hex": "00-1C-64",
        "organization": "Landis+Gyr",
        "address_1": "30000 Mill Creek Ave. Suite 100",
        "address_2": "Alpharetta  GA  30022",
        "country": "US"
    },
    "001C31": {
        "oui_hex": "00-1C-31",
        "organization": "Mobile XP Technology Co., LTD",
        "address_1": "Room No.2506,Tri-tower C building,No.66 Zhongguancun East Road,Haidian District",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "001C8B": {
        "oui_hex": "00-1C-8B",
        "organization": "MJ Innovations Ltd.",
        "address_1": "333 Wyecroft Road",
        "address_2": "Oakville  Ontario  L6K 2H2",
        "country": "CA"
    },
    "001C6D": {
        "oui_hex": "00-1C-6D",
        "organization": "KYOHRITSU ELECTRONIC INDUSTRY CO., LTD.",
        "address_1": "2-5-1, NIPPONBASHI-NISHI,",
        "address_2": "OSAKA    556-0004",
        "country": "JP"
    },
    "001C96": {
        "oui_hex": "00-1C-96",
        "organization": "Linkwise Technology Pte Ltd",
        "address_1": "Blk 3, Ang Mo Kio Industrial Park 2A",
        "address_2": "    568050",
        "country": "SG"
    },
    "001C29": {
        "oui_hex": "00-1C-29",
        "organization": "CORE DIGITAL ELECTRONICS CO., LTD",
        "address_1": "1006# 102 CHUNUITECHNOPARK 200-1",
        "address_2": "BUCHEON-CITY  GYUNGGI-DO  420-857",
        "country": "KR"
    },
    "001C24": {
        "oui_hex": "00-1C-24",
        "organization": "Formosa Wireless Systems Corp.",
        "address_1": "No. 408, Guandong Rd.,",
        "address_2": "HsinChu City    300",
        "country": "TW"
    },
    "001C20": {
        "oui_hex": "00-1C-20",
        "organization": "CLB Benelux",
        "address_1": "Ramgatseweg 17",
        "address_2": "Raamsdonksveer  NBR  4941 VN",
        "country": "NL"
    },
    "001C1C": {
        "oui_hex": "00-1C-1C",
        "organization": "Center Communication Systems GmbH",
        "address_1": "Ignaz-Koeck-Strasse 19",
        "address_2": "Vienna    A-1210",
        "country": "AT"
    },
    "001BDA": {
        "oui_hex": "00-1B-DA",
        "organization": "UTStarcom Inc",
        "address_1": "1275 Harbor Bay PKWY",
        "address_2": "Alameda  CA  94502",
        "country": "US"
    },
    "001BD1": {
        "oui_hex": "00-1B-D1",
        "organization": "SOGESTMATIC",
        "address_1": "409 Route de la Gare",
        "address_2": "CHATEAUNEUF DE GADAGNE  PACA  84470",
        "country": "FR"
    },
    "001C00": {
        "oui_hex": "00-1C-00",
        "organization": "Entry Point, LLC",
        "address_1": "735 Robins",
        "address_2": "Idaho Falls  Idaho  83401",
        "country": "US"
    },
    "001BFD": {
        "oui_hex": "00-1B-FD",
        "organization": "Dignsys Inc.",
        "address_1": "14F, Digital Empire Bldg., B-1408",
        "address_2": "Suwon  Gyeonggi-do  443-813",
        "country": "KR"
    },
    "001BD6": {
        "oui_hex": "00-1B-D6",
        "organization": "Kelvin Hughes Ltd",
        "address_1": "New North Road",
        "address_2": "Ilford  Essex  IG6 2UR",
        "country": "GB"
    },
    "001BCF": {
        "oui_hex": "00-1B-CF",
        "organization": "Dataupia Corporation",
        "address_1": "One Alewife Center",
        "address_2": "Cambridge  MA  02140",
        "country": "US"
    },
    "001BCB": {
        "oui_hex": "00-1B-CB",
        "organization": "PEMPEK SYSTEMS PTY LTD",
        "address_1": "UNIT 3 / 13 HOYLE AVENUE",
        "address_2": "CASTLE HILL  NSW  2154",
        "country": "AU"
    },
    "001BF5": {
        "oui_hex": "00-1B-F5",
        "organization": "Tellink Sistemas de Telecomunicación S.L.",
        "address_1": "C/ María Tubau Nº 5 Bajo B",
        "address_2": "Madrid    28050",
        "country": "ES"
    },
    "001BE6": {
        "oui_hex": "00-1B-E6",
        "organization": "VR AG",
        "address_1": "Rütistrasse 18",
        "address_2": "Schlieren    CH-8952",
        "country": "CH"
    },
    "001BE2": {
        "oui_hex": "00-1B-E2",
        "organization": "AhnLab,Inc.",
        "address_1": "6th Fl, CCMM Bldg, 12 Yeouido-dong",
        "address_2": "Seoul    150869",
        "country": "KR"
    },
    "001BE0": {
        "oui_hex": "00-1B-E0",
        "organization": "TELENOT ELECTRONIC GmbH",
        "address_1": "Wiesentalstraße 42",
        "address_2": "Aalen  Baden-Württemberg  73434",
        "country": "DE"
    },
    "001C34": {
        "oui_hex": "00-1C-34",
        "organization": "HUEY CHIAO INTERNATIONAL CO., LTD.",
        "address_1": "5F, NO. 649-1,",
        "address_2": "HSIN CHUANG CITY  TAIPEI  242",
        "country": "TW"
    },
    "001C36": {
        "oui_hex": "00-1C-36",
        "organization": "iNEWiT NV",
        "address_1": "Schaliënhoevedreef 20D",
        "address_2": "Mechelen  Antwerp  2800",
        "country": "BE"
    },
    "001C15": {
        "oui_hex": "00-1C-15",
        "organization": "iPhotonix LLC",
        "address_1": "2600 N Central Expressway",
        "address_2": "Richardson  Texas  75080",
        "country": "US"
    },
    "001C07": {
        "oui_hex": "00-1C-07",
        "organization": "Cwlinux Limited",
        "address_1": "Unit 138, 13/F, Weswick Commercial Building,",
        "address_2": "Wan Chai",
        "country": "HK"
    },
    "001BA3": {
        "oui_hex": "00-1B-A3",
        "organization": "Flexit Group GmbH",
        "address_1": "Bräuhausstraße 14",
        "address_2": "Salzburg  Salzburg  5020",
        "country": "AT"
    },
    "001B9F": {
        "oui_hex": "00-1B-9F",
        "organization": "Calyptech Pty Ltd",
        "address_1": "5/486 Lower Heidelberg Road",
        "address_2": "Heidelberg  Victoria  3084",
        "country": "AU"
    },
    "001B9A": {
        "oui_hex": "00-1B-9A",
        "organization": "Apollo Fire Detectors Ltd",
        "address_1": "36 Brookside Road",
        "address_2": "Havant  Hampshire  P09 1JR",
        "country": "GB"
    },
    "001BBD": {
        "oui_hex": "00-1B-BD",
        "organization": "FMC Kongsberg Subsea AS",
        "address_1": "Kirkegaardsveien 45",
        "address_2": "Kongsberg  Buskerud  3601",
        "country": "NO"
    },
    "001BBE": {
        "oui_hex": "00-1B-BE",
        "organization": "ICOP Digital",
        "address_1": "16801 W. 116th St.",
        "address_2": "Lenexa  KS  66219",
        "country": "US"
    },
    "001BB3": {
        "oui_hex": "00-1B-B3",
        "organization": "Condalo GmbH",
        "address_1": "Kohlstatt 3",
        "address_2": "Lichtenau  Bavaria  86706",
        "country": "DE"
    },
    "001BB7": {
        "oui_hex": "00-1B-B7",
        "organization": "Alta Heights Technology Corp.",
        "address_1": "108 Alta Heights Court",
        "address_2": "Los Gatos  California  95030",
        "country": "US"
    },
    "001B99": {
        "oui_hex": "00-1B-99",
        "organization": "KS System GmbH",
        "address_1": "Alexanderstraße 37",
        "address_2": "Muelheim  NRW  45472",
        "country": "DE"
    },
    "001B8F": {
        "oui_hex": "00-1B-8F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B8C": {
        "oui_hex": "00-1B-8C",
        "organization": "JMicron Technology Corp.",
        "address_1": "1F, No.13, Innovation Road 1",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "001B91": {
        "oui_hex": "00-1B-91",
        "organization": "EFKON AG",
        "address_1": "Dietrich-Keller-Strasse 20",
        "address_2": "8074 Raaba",
        "country": "AT"
    },
    "001B82": {
        "oui_hex": "00-1B-82",
        "organization": "Taiwan Semiconductor Co., Ltd.",
        "address_1": "11F, No. 205, Sec. 3, Beishin Rd,",
        "address_2": "Shindian  Taipei  231",
        "country": "TW"
    },
    "001B89": {
        "oui_hex": "00-1B-89",
        "organization": "EMZA Visual Sense Ltd.",
        "address_1": "20 Ha'ta'as St., Beith Hapamon",
        "address_2": "Kfar Saba    44425",
        "country": "IL"
    },
    "001B8B": {
        "oui_hex": "00-1B-8B",
        "organization": "NEC Platforms, Ltd.",
        "address_1": "800 Shimomata",
        "address_2": "Kakegawa  Shizuoka  436-8501",
        "country": "JP"
    },
    "001BAC": {
        "oui_hex": "00-1B-AC",
        "organization": "Curtiss Wright Controls Embedded Computing",
        "address_1": "10201 Wateridge Circle",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "001B6A": {
        "oui_hex": "00-1B-6A",
        "organization": "Powerwave Technologies Sweden AB",
        "address_1": "164 26",
        "address_2": "Knarrarnäsgatan 7, Kista",
        "country": "SE"
    },
    "001B67": {
        "oui_hex": "00-1B-67",
        "organization": "Cisco Systems Inc",
        "address_1": "The Stella Building",
        "address_2": "Swindon  Wiltshire  SN5 6NX",
        "country": "GB"
    },
    "001B7B": {
        "oui_hex": "00-1B-7B",
        "organization": "The Tintometer Ltd",
        "address_1": "Solar Way",
        "address_2": "Amesbury  Wiltshire  SP4 7SZ",
        "country": "GB"
    },
    "001B75": {
        "oui_hex": "00-1B-75",
        "organization": "Hypermedia Systems",
        "address_1": "2B Bergman St.",
        "address_2": "Rehovot    76705",
        "country": "IL"
    },
    "001B27": {
        "oui_hex": "00-1B-27",
        "organization": "Merlin CSI",
        "address_1": "12625 Danielson Court",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "001B1B": {
        "oui_hex": "00-1B-1B",
        "organization": "Siemens AG,",
        "address_1": "I IA SC MF-K PE 3",
        "address_2": "76187 Karlsruhe   Baden Wuerttemberg",
        "country": "DE"
    },
    "001B1F": {
        "oui_hex": "00-1B-1F",
        "organization": "DELTA - Danish Electronics, Light & Acoustics",
        "address_1": "Venlighedsvej 4",
        "address_2": "Hørsholm    DK-2970",
        "country": "DK"
    },
    "001B57": {
        "oui_hex": "00-1B-57",
        "organization": "SEMINDIA SYSTEMS PRIVATE LIMITED",
        "address_1": "#1106/9,A.M.Industrial Estate,Garvebhai palya,",
        "address_2": "BANGALORE  KARNATAKA  560068",
        "country": "IN"
    },
    "001B55": {
        "oui_hex": "00-1B-55",
        "organization": "Hurco Automation Ltd.",
        "address_1": "6F, No. 31, Shintai Rd.",
        "address_2": "Jubei City,  Hsinchu Hsien  30244",
        "country": "TW"
    },
    "001B53": {
        "oui_hex": "00-1B-53",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B49": {
        "oui_hex": "00-1B-49",
        "organization": "Roberts Radio limited",
        "address_1": "Swinton Works",
        "address_2": "Mexborough  South Yorkshire  S64 8AJ",
        "country": "GB"
    },
    "001B0E": {
        "oui_hex": "00-1B-0E",
        "organization": "InoTec GmbH Organisationssysteme",
        "address_1": "Biedrichstrasse 11",
        "address_2": "Woelfersheim  Hessen  D-61200",
        "country": "DE"
    },
    "001B04": {
        "oui_hex": "00-1B-04",
        "organization": "Affinity International S.p.a",
        "address_1": "C.so Savona 51",
        "address_2": "Villastellone    I10029",
        "country": "IT"
    },
    "001B06": {
        "oui_hex": "00-1B-06",
        "organization": "Ateliers R. LAUMONIER",
        "address_1": "Ateliers R. LAUMONIER",
        "address_2": "Nesles-la-Vallée  Val d'Oise  95690",
        "country": "FR"
    },
    "001B31": {
        "oui_hex": "00-1B-31",
        "organization": "Neural Image. Co. Ltd.",
        "address_1": "A307, CASI, Osaka Univ.",
        "address_2": "Suita city  Osaka  565-0871",
        "country": "JP"
    },
    "001B29": {
        "oui_hex": "00-1B-29",
        "organization": "Avantis.Co.,Ltd",
        "address_1": "502 SEOIL BLDG.",
        "address_2": "SEOUL    132-872",
        "country": "KR"
    },
    "001B2B": {
        "oui_hex": "00-1B-2B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001B28": {
        "oui_hex": "00-1B-28",
        "organization": "POLYGON, JSC",
        "address_1": "37/1, Karl Marx str., floor 5",
        "address_2": "Ufa  Bashkortostan  450077",
        "country": "RU"
    },
    "001B43": {
        "oui_hex": "00-1B-43",
        "organization": "Beijing DG Telecommunications equipment Co.,Ltd",
        "address_1": "No.5 Jiangtai Road, Chaoyang District",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "001B3C": {
        "oui_hex": "00-1B-3C",
        "organization": "Software Technologies Group,Inc.",
        "address_1": "10330 W. Roosevelt Road",
        "address_2": "Weschester  IL  60154",
        "country": "US"
    },
    "001B3D": {
        "oui_hex": "00-1B-3D",
        "organization": "EuroTel Spa",
        "address_1": "viale Martiri della Liberta,4",
        "address_2": "Lissone  Milan  20035",
        "country": "IT"
    },
    "001B66": {
        "oui_hex": "00-1B-66",
        "organization": "Sennheiser electronic GmbH & Co. KG",
        "address_1": "Am Labor 1",
        "address_2": "Wedemark  Niedersachsen  30900",
        "country": "DE"
    },
    "001B60": {
        "oui_hex": "00-1B-60",
        "organization": "NAVIGON AG",
        "address_1": "Berliner Platz 11",
        "address_2": "Wuerzburg  Bavaria  97080",
        "country": "DE"
    },
    "001B05": {
        "oui_hex": "00-1B-05",
        "organization": "YMC AG",
        "address_1": "Sonnenstrasse 4",
        "address_2": "Kreuzlingen  Thurgau  8280",
        "country": "CH"
    },
    "001AFF": {
        "oui_hex": "00-1A-FF",
        "organization": "Wizyoung Tech.",
        "address_1": "9F, No. 25, Sec. 1, Nanjing E. Rd.",
        "address_2": "Taipei    104",
        "country": "TW"
    },
    "001B00": {
        "oui_hex": "00-1B-00",
        "organization": "Neopost Technologies",
        "address_1": "113 rue Jean-Marin Naudin",
        "address_2": "Bagneux    92220",
        "country": "FR"
    },
    "001B4E": {
        "oui_hex": "00-1B-4E",
        "organization": "Navman New Zealand",
        "address_1": "7-21 Kawana Street",
        "address_2": "Auckland    0627",
        "country": "NZ"
    },
    "001B16": {
        "oui_hex": "00-1B-16",
        "organization": "Celtro Ltd.",
        "address_1": "Azorim Business Park",
        "address_2": "Petach Tikva    49527",
        "country": "IL"
    },
    "001AE6": {
        "oui_hex": "00-1A-E6",
        "organization": "Atlanta Advanced Communications Holdings Limited",
        "address_1": "1900 West Oak Circle, Marietta",
        "address_2": "Atlanta  Georgia  30062",
        "country": "US"
    },
    "001AD9": {
        "oui_hex": "00-1A-D9",
        "organization": "International Broadband Electric Communications, Inc.",
        "address_1": "285 Dunlop Blvd. SW",
        "address_2": "Huntsville  AL  35824",
        "country": "US"
    },
    "001AC8": {
        "oui_hex": "00-1A-C8",
        "organization": "ISL (Instrumentation Scientifique de Laboratoire)",
        "address_1": "Impasse des 4 vents",
        "address_2": "VERSON  CALVADOS  14790",
        "country": "FR"
    },
    "001AAB": {
        "oui_hex": "00-1A-AB",
        "organization": "eWings s.r.l.",
        "address_1": "via S. Quasimodo 46",
        "address_2": "Castel Maggiore  Bologna  40013",
        "country": "IT"
    },
    "001AAC": {
        "oui_hex": "00-1A-AC",
        "organization": "Corelatus AB",
        "address_1": "Tegnergatan 37",
        "address_2": "Stockholm    11161",
        "country": "SE"
    },
    "001AAF": {
        "oui_hex": "00-1A-AF",
        "organization": "BLUSENS TECHNOLOGY",
        "address_1": "EDIFICIO CNL,- AV.",
        "address_2": "15707 - SANTIAGO DE COMPOSTELA  A Coruña",
        "country": "ES"
    },
    "001AB0": {
        "oui_hex": "00-1A-B0",
        "organization": "Signal Networks Pvt. Ltd.,",
        "address_1": "No.12, Kalpataru Apartments,",
        "address_2": "Bangalore  Karnataka  560001",
        "country": "IN"
    },
    "001AA1": {
        "oui_hex": "00-1A-A1",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001AC6": {
        "oui_hex": "00-1A-C6",
        "organization": "Micro Control Designs",
        "address_1": "17490 Caribou Dr",
        "address_2": "Monument  Co.  80132",
        "country": "US"
    },
    "001AF2": {
        "oui_hex": "00-1A-F2",
        "organization": "Dynavisions Schweiz AG",
        "address_1": "Freisinger Landstraße 21",
        "address_2": "D-80939  Muenchen",
        "country": "DE"
    },
    "001A82": {
        "oui_hex": "00-1A-82",
        "organization": "PROBA Building Automation Co.,LTD",
        "address_1": "Penghuan Building 501, Shangdi East Road #1, Haidian District,",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001A7C": {
        "oui_hex": "00-1A-7C",
        "organization": "Hirschmann Multimedia B.V.",
        "address_1": "Pampuslaan 170",
        "address_2": "Weesp  Noord-Holland  1382 JS",
        "country": "NL"
    },
    "001A7A": {
        "oui_hex": "00-1A-7A",
        "organization": "Lismore Instruments Limited",
        "address_1": "Unit 2 Tristar Centre, Star Road",
        "address_2": "Horsham  West Sussex  RH13 8RA",
        "country": "GB"
    },
    "001A78": {
        "oui_hex": "00-1A-78",
        "organization": "ubtos",
        "address_1": "Rn.213, Woolim Lions Valley, #680",
        "address_2": "seoul  Gasan-dong  153-803",
        "country": "KR"
    },
    "001A76": {
        "oui_hex": "00-1A-76",
        "organization": "SDT information Technology Co.,LTD.",
        "address_1": "Samil B/B 2F, 5-63 Hyochang-dong",
        "address_2": "Seoul    140-896",
        "country": "KR"
    },
    "001A70": {
        "oui_hex": "00-1A-70",
        "organization": "Cisco-Linksys, LLC",
        "address_1": "121 Theory Drive",
        "address_2": "Irvine  California  92612",
        "country": "US"
    },
    "001A61": {
        "oui_hex": "00-1A-61",
        "organization": "PacStar Corp.",
        "address_1": "15055 SW Sequoia Pkwy, Suite 100",
        "address_2": "Portland  OR  97006",
        "country": "US"
    },
    "001A62": {
        "oui_hex": "00-1A-62",
        "organization": "Data Robotics, Incorporated",
        "address_1": "1881 Landings Dr",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "001A65": {
        "oui_hex": "00-1A-65",
        "organization": "Seluxit",
        "address_1": "Nyhavnsgade 9, 2.sal",
        "address_2": "Aalborg  Nord Jylland  9000",
        "country": "DK"
    },
    "001A54": {
        "oui_hex": "00-1A-54",
        "organization": "Hip Shing Electronics Ltd.",
        "address_1": "Unit 1/2/3, 20/F, New Treasure Center",
        "address_2": "",
        "country": "HK"
    },
    "001A42": {
        "oui_hex": "00-1A-42",
        "organization": "Techcity Technology co., Ltd.",
        "address_1": "4F, No. 4, Alley 1, Szu Wei Lane, Chung Cheng Rd.,",
        "address_2": "Hsin Tein City  Taipei Hsien  231",
        "country": "TW"
    },
    "001A50": {
        "oui_hex": "00-1A-50",
        "organization": "PheeNet Technology Corp.",
        "address_1": "Rm. 3, 20F, No. 79, Sec. 1 Hsin Tai Wu Rd.",
        "address_2": "Hsi-Chih  New-Taipei City  221",
        "country": "TW"
    },
    "001A53": {
        "oui_hex": "00-1A-53",
        "organization": "Zylaya",
        "address_1": "444 N. Frederick Ave.",
        "address_2": "Gaithersburg  MD  20877",
        "country": "US"
    },
    "001A4C": {
        "oui_hex": "00-1A-4C",
        "organization": "Crossbow Technology, Inc",
        "address_1": "4145 N. First Street",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "001A1A": {
        "oui_hex": "00-1A-1A",
        "organization": "Gentex Corporation/Electro-Acoustic Products",
        "address_1": "2456 Brown Avenue",
        "address_2": "Manchester  NH  03103",
        "country": "US"
    },
    "001A12": {
        "oui_hex": "00-1A-12",
        "organization": "Essilor",
        "address_1": "64 Bis Avenue Aubert",
        "address_2": "94300  Vincennes",
        "country": "FR"
    },
    "001A7D": {
        "oui_hex": "00-1A-7D",
        "organization": "cyber-blue(HK)Ltd",
        "address_1": "Room 1408 block C stars Plaza HongLiRoad,FuTian District",
        "address_2": "Shenzhen  GuangDong  518028",
        "country": "CN"
    },
    "001A60": {
        "oui_hex": "00-1A-60",
        "organization": "Wave Electronics Co.,Ltd.",
        "address_1": "3th Fl.,DaeSan Plaza B/D,Guun-Dong, 12-1,Gwonseon-Gu",
        "address_2": "Suwon-si  Kyeonggi-Do  441-814",
        "country": "KR"
    },
    "001A56": {
        "oui_hex": "00-1A-56",
        "organization": "ViewTel Co,. Ltd.",
        "address_1": "#B-502,Bundang Techno Park 148",
        "address_2": "BunDang-Ku, SeongNam-Si  GyeongGi-Do  463-760",
        "country": "KR"
    },
    "0019F3": {
        "oui_hex": "00-19-F3",
        "organization": "Cetis, Inc",
        "address_1": "5025 Galley Rd",
        "address_2": "Colorado Springs  CO  80915",
        "country": "US"
    },
    "0019EF": {
        "oui_hex": "00-19-EF",
        "organization": "SHENZHEN LINNKING ELECTRONICS CO.,LTD",
        "address_1": "Room 901,B Block,Qinghua Information Center Hi-tec park North District,Nanshan District,Shenzhen",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "0019F7": {
        "oui_hex": "00-19-F7",
        "organization": "Onset Computer Corporation",
        "address_1": "P.O. Box 3450",
        "address_2": "Pocasset  MA  02559",
        "country": "US"
    },
    "0019EE": {
        "oui_hex": "00-19-EE",
        "organization": "CARLO GAVAZZI CONTROLS SPA-Controls Division",
        "address_1": "Via Safforze 8",
        "address_2": "BELLUNO  BL  I-32100",
        "country": "IT"
    },
    "0019BF": {
        "oui_hex": "00-19-BF",
        "organization": "Citiway technology Co.,ltd",
        "address_1": "No.2 Building,Jia 32,Beiheyan Avenue,East City",
        "address_2": "Peijing    100006",
        "country": "CN"
    },
    "0019B6": {
        "oui_hex": "00-19-B6",
        "organization": "Euro Emme s.r.l.",
        "address_1": "Via Belvedere, 24",
        "address_2": "Galliate Lombardo  Varese  21020",
        "country": "IT"
    },
    "0019EB": {
        "oui_hex": "00-19-EB",
        "organization": "Pyronix Ltd",
        "address_1": "Braithwell Way",
        "address_2": "Rotherham  South Yorkshire  S66 8QY",
        "country": "GB"
    },
    "0019E7": {
        "oui_hex": "00-19-E7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0019E9": {
        "oui_hex": "00-19-E9",
        "organization": "S-Information Technolgy, Co., Ltd.",
        "address_1": "Sungwoo Bldg, 717-3 Suseo-dong,",
        "address_2": "Seoul    135-884",
        "country": "KR"
    },
    "0019DA": {
        "oui_hex": "00-19-DA",
        "organization": "Welltrans O&E Technology Co. , Ltd.",
        "address_1": "the 3rd Floor, building C-D, Hi-tech Digital Harbor, Guandong Industrial Park",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "001A14": {
        "oui_hex": "00-1A-14",
        "organization": "Xin Hua Control Engineering Co.,Ltd.",
        "address_1": "160 Wenjing Rd., Minhang",
        "address_2": "Shanghai    2000245",
        "country": "CN"
    },
    "001A10": {
        "oui_hex": "00-1A-10",
        "organization": "LUCENT TRANS ELECTRONICS CO.,LTD",
        "address_1": "9F-1,No.16,Chien Pah Rd.",
        "address_2": "Chung Ho  Taipei  235",
        "country": "TW"
    },
    "001A0C": {
        "oui_hex": "00-1A-0C",
        "organization": "Swe-Dish Satellite Systems AB",
        "address_1": "Torggatan 15",
        "address_2": "Solna  Stockholm  SE-171 06",
        "country": "SE"
    },
    "0019DC": {
        "oui_hex": "00-19-DC",
        "organization": "ENENSYS Technologies",
        "address_1": "Le Germanium",
        "address_2": "RENNES  Brittany  35700",
        "country": "FR"
    },
    "0019D0": {
        "oui_hex": "00-19-D0",
        "organization": "Cathexis",
        "address_1": "PO Box 1091",
        "address_2": "Durban  KwaZulu Natal  4320",
        "country": "ZA"
    },
    "0019D6": {
        "oui_hex": "00-19-D6",
        "organization": "LS Cable and System Ltd.",
        "address_1": "12F LS Tower, 1026-6, Hogey-dong",
        "address_2": "Anyang-si  Gyeonggi-do  431-080",
        "country": "KR"
    },
    "0019D7": {
        "oui_hex": "00-19-D7",
        "organization": "FORTUNETEK CO., LTD",
        "address_1": "12F, No. 75, Sec 1, Chongqing S. Rd.,",
        "address_2": "Taipei    100",
        "country": "TW"
    },
    "001A02": {
        "oui_hex": "00-1A-02",
        "organization": "SECURE CARE PRODUCTS, INC",
        "address_1": "39 CHENELL DRIVE",
        "address_2": "CONCORD  NH  03301",
        "country": "US"
    },
    "0019F8": {
        "oui_hex": "00-19-F8",
        "organization": "Embedded Systems Design, Inc.",
        "address_1": "6810 Deerpath Road",
        "address_2": "Elkridge  MD  21075",
        "country": "US"
    },
    "001A07": {
        "oui_hex": "00-1A-07",
        "organization": "Arecont Vision",
        "address_1": "2400 N. Lincoln Ave",
        "address_2": "Altadena  CA  91001",
        "country": "US"
    },
    "001A08": {
        "oui_hex": "00-1A-08",
        "organization": "Simoco Ltd.",
        "address_1": "Field House",
        "address_2": "Derby    DE1 1NH",
        "country": "GB"
    },
    "001A04": {
        "oui_hex": "00-1A-04",
        "organization": "Interay Solutions BV",
        "address_1": "Mr. W.M. Oppedijk van Veenweg 8",
        "address_2": "BURGUM  Friesland  9251 GA",
        "country": "NL"
    },
    "0019C9": {
        "oui_hex": "00-19-C9",
        "organization": "S&C ELECTRIC COMPANY",
        "address_1": "1135 ATLANTIC AVE",
        "address_2": "ALAMEDA  CA  94501",
        "country": "US"
    },
    "0019B5": {
        "oui_hex": "00-19-B5",
        "organization": "Famar Fueguina S.A.",
        "address_1": "Rodney 70",
        "address_2": "Buenos Aires    1427",
        "country": "AR"
    },
    "0019B8": {
        "oui_hex": "00-19-B8",
        "organization": "Boundary Devices",
        "address_1": "7200 W. Oakland",
        "address_2": "Chandler  AZ  85226",
        "country": "US"
    },
    "00195D": {
        "oui_hex": "00-19-5D",
        "organization": "ShenZhen XinHuaTong Opto Electronics Co.,Ltd",
        "address_1": "5F,BaodaZhou,Shancheng Industrial Zone,BaoAn District",
        "address_2": "ShenZhen  GuangDong  518108",
        "country": "CN"
    },
    "001953": {
        "oui_hex": "00-19-53",
        "organization": "Chainleader Communications Corp.",
        "address_1": "5F, No. 400, Sec. 2 Bade Rd.,",
        "address_2": "Taipei    105",
        "country": "TW"
    },
    "001955": {
        "oui_hex": "00-19-55",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001959": {
        "oui_hex": "00-19-59",
        "organization": "Staccato Communications Inc.",
        "address_1": "6195 Lusk Blvd.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00194D": {
        "oui_hex": "00-19-4D",
        "organization": "Avago Technologies Sdn Bhd",
        "address_1": "Bayan Lepas Free Industrial Zone",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "00194E": {
        "oui_hex": "00-19-4E",
        "organization": "Ultra Electronics - TCS (Tactical Communication Systems)",
        "address_1": "5990 Cote De Liesse",
        "address_2": "TMR  Quebec  H4T 1V7",
        "country": "CA"
    },
    "0019AC": {
        "oui_hex": "00-19-AC",
        "organization": "GSP SYSTEMS Inc.",
        "address_1": "13FL, 101 Dong, Chunui Techno Park 1,",
        "address_2": "Bucheon-City  Gyeonggi-Do  420-857",
        "country": "KR"
    },
    "0019B0": {
        "oui_hex": "00-19-B0",
        "organization": "HanYang System",
        "address_1": "701Ho, Kofomo Techno Center II, 1289-5",
        "address_2": "Shihung-Shi  Kyunggi-Do  429-850",
        "country": "KR"
    },
    "001995": {
        "oui_hex": "00-19-95",
        "organization": "Jurong Hi-Tech (Suzhou)Co.ltd",
        "address_1": "275,Xing Long Street, Suzhou Indudtrial Park",
        "address_2": "Suzhou  Jiang Su  215021",
        "country": "CN"
    },
    "00199A": {
        "oui_hex": "00-19-9A",
        "organization": "EDO-EVI",
        "address_1": "7065 Columbia Gateway Dr.",
        "address_2": "Columbia  MD  21046",
        "country": "US"
    },
    "001994": {
        "oui_hex": "00-19-94",
        "organization": "Jorjin Technologies Inc.",
        "address_1": "5F, No.28, Lane141, Sing-ai Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00197C": {
        "oui_hex": "00-19-7C",
        "organization": "Riedel Communications GmbH",
        "address_1": "Uellendahler Str. 353",
        "address_2": "Wuppertal  NRW  42109",
        "country": "DE"
    },
    "0019A0": {
        "oui_hex": "00-19-A0",
        "organization": "NIHON DATA SYSTENS, INC.",
        "address_1": "6-9, Koyo-cho naka",
        "address_2": "Kobe-shi  Hyogo  658-0032",
        "country": "JP"
    },
    "001991": {
        "oui_hex": "00-19-91",
        "organization": "avinfo",
        "address_1": "Jiahuiyuan 703,Huaao Center,31# Zizhuyuan Road,",
        "address_2": "Beijing    100089",
        "country": "CN"
    },
    "00198C": {
        "oui_hex": "00-19-8C",
        "organization": "iXSea",
        "address_1": "55 av auguste Renoir",
        "address_2": "Marly le Roi    78160",
        "country": "FR"
    },
    "001962": {
        "oui_hex": "00-19-62",
        "organization": "Commerciant, LP",
        "address_1": "2901 Wilcrest",
        "address_2": "Houston  Texas  77042",
        "country": "US"
    },
    "00196F": {
        "oui_hex": "00-19-6F",
        "organization": "SensoPart GmbH",
        "address_1": "Am Wiedenbach 1",
        "address_2": "Wieden  Baden-Württemberg  D-79695",
        "country": "DE"
    },
    "0018DD": {
        "oui_hex": "00-18-DD",
        "organization": "Silicondust Engineering Ltd",
        "address_1": "38 Lillington Road",
        "address_2": "Auckland",
        "country": "NZ"
    },
    "0018DF": {
        "oui_hex": "00-18-DF",
        "organization": "The Morey Corporation",
        "address_1": "100 Morey Drive",
        "address_2": "Woodridge  IL  60517",
        "country": "US"
    },
    "0018E1": {
        "oui_hex": "00-18-E1",
        "organization": "Verkerk Service Systemen",
        "address_1": "Molenvliet 1",
        "address_2": "Zwijndrecht  Zuid-Holland  NL-3335LH",
        "country": "NL"
    },
    "0018DA": {
        "oui_hex": "00-18-DA",
        "organization": "Würth Elektronik eiSos GmbH & Co. KG",
        "address_1": "Max-Eyth-Straße 1",
        "address_2": "Waldenburg    74638",
        "country": "DE"
    },
    "0018D5": {
        "oui_hex": "00-18-D5",
        "organization": "REIGNCOM",
        "address_1": "14F Kamco Yanjae Tower, 949-3",
        "address_2": "Seoul    135-739",
        "country": "KR"
    },
    "0018E7": {
        "oui_hex": "00-18-E7",
        "organization": "Cameo Communications, INC.",
        "address_1": "NO.42, Sec. 6, Mincyuan E. Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0018E4": {
        "oui_hex": "00-18-E4",
        "organization": "YIGUANG",
        "address_1": "3/FL.Industry zone,Fuxinlin,Hangcheng,Xixiang,Baoan",
        "address_2": "Shenzhen  Guangdong  518126",
        "country": "CN"
    },
    "0018E5": {
        "oui_hex": "00-18-E5",
        "organization": "Adhoco AG",
        "address_1": "Technopark",
        "address_2": "Winterthur  ZH  CH-8406",
        "country": "CH"
    },
    "00190A": {
        "oui_hex": "00-19-0A",
        "organization": "HASWARE INC.",
        "address_1": "4-12-3 HIGASHI",
        "address_2": "KUNITACHI  TOKYO  186-0002",
        "country": "JP"
    },
    "001923": {
        "oui_hex": "00-19-23",
        "organization": "Phonex Korea Co., LTD.",
        "address_1": "33-3, Geoyeo-Dong",
        "address_2": "Seoul  Songpa-Gu  138-814",
        "country": "KR"
    },
    "00191C": {
        "oui_hex": "00-19-1C",
        "organization": "Sensicast Systems",
        "address_1": "200 Reservoir St",
        "address_2": "Needham  MA  02494",
        "country": "US"
    },
    "001928": {
        "oui_hex": "00-19-28",
        "organization": "Siemens AG, Transportation Systems",
        "address_1": "Ackerstraße 22",
        "address_2": "Braunschweig    38126",
        "country": "DE"
    },
    "001915": {
        "oui_hex": "00-19-15",
        "organization": "TECOM Co., Ltd.",
        "address_1": "23 R&D Road 2 Science Based Industrial Park",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "00191B": {
        "oui_hex": "00-19-1B",
        "organization": "Sputnik Engineering AG",
        "address_1": "Höheweg 85",
        "address_2": "Biel-Bienne BE    2502",
        "country": "CH"
    },
    "001909": {
        "oui_hex": "00-19-09",
        "organization": "DEVI - Danfoss A/S",
        "address_1": "Ulvehavevej 61",
        "address_2": "Vejle    7100",
        "country": "DK"
    },
    "001933": {
        "oui_hex": "00-19-33",
        "organization": "Strix Systems, Inc.",
        "address_1": "26610 Agoura Road",
        "address_2": "Calabasas  CA  91302",
        "country": "US"
    },
    "001904": {
        "oui_hex": "00-19-04",
        "organization": "WB Electronics Sp. z o.o.",
        "address_1": "ul. Poznanska 129/133",
        "address_2": "Ozarow Mazowiecki  Mazowieckie  05-850",
        "country": "PL"
    },
    "001934": {
        "oui_hex": "00-19-34",
        "organization": "TRENDON TOUCH TECHNOLOGY CORP.",
        "address_1": "2F No.5, Alley 22, Lane 513, Rueiguang Rd., Neihu",
        "address_2": "Taipei City    114",
        "country": "TW"
    },
    "00190D": {
        "oui_hex": "00-19-0D",
        "organization": "IEEE 1394c",
        "address_1": "c/o 1394 Trade Association",
        "address_2": "Southlake  TX  76092",
        "country": "US"
    },
    "001881": {
        "oui_hex": "00-18-81",
        "organization": "Buyang Electronics Industrial Co., Ltd",
        "address_1": "434-140, Oryu-Dong",
        "address_2": "Incheon    404-300",
        "country": "KR"
    },
    "001876": {
        "oui_hex": "00-18-76",
        "organization": "WowWee Ltd.",
        "address_1": "92 Granville Rd. Suite 301A-C",
        "address_2": "T.S.T. East  Kowloon",
        "country": "HK"
    },
    "00187A": {
        "oui_hex": "00-18-7A",
        "organization": "Wiremold",
        "address_1": "60 Woodlawn St.",
        "address_2": "West Hartford  CT  06110",
        "country": "US"
    },
    "00186C": {
        "oui_hex": "00-18-6C",
        "organization": "Neonode AB",
        "address_1": "Biblioteksgatan 11, 1st floor",
        "address_2": "Stockholm    S-111 46",
        "country": "SE"
    },
    "001873": {
        "oui_hex": "00-18-73",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00185F": {
        "oui_hex": "00-18-5F",
        "organization": "TAC Inc.",
        "address_1": "66 Nishiishigatsubocho Nishinanajyo Shimogyoku",
        "address_2": "Kyoto    600-8896",
        "country": "JP"
    },
    "0018D4": {
        "oui_hex": "00-18-D4",
        "organization": "Unified Display Interface SIG",
        "address_1": "15201 SW Greenbrier Road",
        "address_2": "Beaverton  Oregon  97006",
        "country": "US"
    },
    "0018A7": {
        "oui_hex": "00-18-A7",
        "organization": "Yoggie Security Systems LTD.",
        "address_1": "P.P.Box 156",
        "address_2": "Beth Halevy    42870",
        "country": "IL"
    },
    "0018A2": {
        "oui_hex": "00-18-A2",
        "organization": "XIP Technology AB",
        "address_1": "PO Box 437",
        "address_2": "Jönköping  Sweden  SE- 551 16",
        "country": "SE"
    },
    "00189C": {
        "oui_hex": "00-18-9C",
        "organization": "Weldex Corporation",
        "address_1": "6751 Katella Avenue",
        "address_2": "Cypress  CA  90630",
        "country": "US"
    },
    "00189A": {
        "oui_hex": "00-18-9A",
        "organization": "HANA Micron Inc.",
        "address_1": "#95-1 Wonnam-Li, Umbong-Myeon",
        "address_2": "Asan-City  Chung-Nam  336-864",
        "country": "KR"
    },
    "001864": {
        "oui_hex": "00-18-64",
        "organization": "Eaton Corporation",
        "address_1": "730, rue Commerciale",
        "address_2": "St-Jean-Chrysostome  QC  G6Z 2C5",
        "country": "CA"
    },
    "001866": {
        "oui_hex": "00-18-66",
        "organization": "Leutron Vision",
        "address_1": "Industriestrasse 57",
        "address_2": "Glattbrugg  ZH  8152",
        "country": "CH"
    },
    "001860": {
        "oui_hex": "00-18-60",
        "organization": "SIM Technology Group Shanghai Simcom Ltd.,",
        "address_1": "SIM Technology building,",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "001897": {
        "oui_hex": "00-18-97",
        "organization": "JESS-LINK PRODUCTS Co., LTD",
        "address_1": "9F, No. 176, Jian-Yi Rd., Chung Ho City",
        "address_2": "Taipei County    235",
        "country": "TW"
    },
    "00189E": {
        "oui_hex": "00-18-9E",
        "organization": "OMNIKEY GmbH.",
        "address_1": "Ferihumerstrasse 13",
        "address_2": "Linz  Upperaustria  4040",
        "country": "AT"
    },
    "0018A9": {
        "oui_hex": "00-18-A9",
        "organization": "Ethernet Direct Corporation",
        "address_1": "19F,No.345 Chung Ho Road, Yung Ho City",
        "address_2": "Taipei    234",
        "country": "TW"
    },
    "0018A8": {
        "oui_hex": "00-18-A8",
        "organization": "AnNeal Technology Inc.",
        "address_1": "Room 106, No. 47, Science Park Rd. II",
        "address_2": "Hsinchu    300",
        "country": "TW"
    },
    "0018C2": {
        "oui_hex": "00-18-C2",
        "organization": "Firetide, Inc",
        "address_1": "16795 Lark Av, Suite 200",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "00183E": {
        "oui_hex": "00-18-3E",
        "organization": "Digilent, Inc",
        "address_1": "215 E. Main St.",
        "address_2": "Pullman  WA  99163",
        "country": "US"
    },
    "001842": {
        "oui_hex": "00-18-42",
        "organization": "Nokia Danmark A/S",
        "address_1": "Frederikskaj",
        "address_2": "Copenhagen V    DK-1790",
        "country": "DK"
    },
    "001840": {
        "oui_hex": "00-18-40",
        "organization": "3 Phoenix, Inc.",
        "address_1": "14585 Avion Pkway",
        "address_2": "Chantilly  Virginia  20151",
        "country": "US"
    },
    "001844": {
        "oui_hex": "00-18-44",
        "organization": "Heads Up Technologies, Inc.",
        "address_1": "2033 Chennault Drive, Suite 100",
        "address_2": "Carrollton  Texas  75006-5119",
        "country": "US"
    },
    "001821": {
        "oui_hex": "00-18-21",
        "organization": "SINDORICOH",
        "address_1": "277-22, 2ga, Sungsu-dong, Sungdong-gu,",
        "address_2": "Seoul    133-120",
        "country": "KR"
    },
    "001823": {
        "oui_hex": "00-18-23",
        "organization": "Delta Electronics, Inc.",
        "address_1": "186 Ruey Kuang Road, Neihu,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001815": {
        "oui_hex": "00-18-15",
        "organization": "GZ Technologies, Inc.",
        "address_1": "Room 1, 5F., No.94, Baojhong Rd.",
        "address_2": "Taipei    231",
        "country": "TW"
    },
    "001857": {
        "oui_hex": "00-18-57",
        "organization": "Unilever R&D",
        "address_1": "Bldg. 50",
        "address_2": "Bedford  Bedfordshire  MK44 1LQ",
        "country": "GB"
    },
    "001853": {
        "oui_hex": "00-18-53",
        "organization": "Atera Networks LTD.",
        "address_1": "31, Habarzel St.",
        "address_2": "Tel-Aviv    69710",
        "country": "IL"
    },
    "001859": {
        "oui_hex": "00-18-59",
        "organization": "Strawberry Linux Co.,Ltd.",
        "address_1": "1-28-8-204 Higashiayase",
        "address_2": "Adachiku  Tokyo  120-0004",
        "country": "JP"
    },
    "00184F": {
        "oui_hex": "00-18-4F",
        "organization": "8 Ways Technology Corp.",
        "address_1": "2F-1, No. 216, Sec. 3, Roosevelt Rd.",
        "address_2": "  Taipei  231",
        "country": "TW"
    },
    "001806": {
        "oui_hex": "00-18-06",
        "organization": "Hokkei Industries Co., Ltd.",
        "address_1": "Imahira 432",
        "address_2": "Hakusan  Ishikawa  924-0827",
        "country": "JP"
    },
    "001818": {
        "oui_hex": "00-18-18",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00181A": {
        "oui_hex": "00-18-1A",
        "organization": "AVerMedia Information Inc.",
        "address_1": "5F., No. 135, Jian 1st Rd.,",
        "address_2": "  New Taipei City  235",
        "country": "TW"
    },
    "001816": {
        "oui_hex": "00-18-16",
        "organization": "Ubixon Co., Ltd.",
        "address_1": "Cheongdong Building 2F",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "00182B": {
        "oui_hex": "00-18-2B",
        "organization": "Softier",
        "address_1": "Tidhar 3",
        "address_2": "Ra'anana  none  43665",
        "country": "IL"
    },
    "001829": {
        "oui_hex": "00-18-29",
        "organization": "Gatsometer",
        "address_1": "Claes Tillyweg 2",
        "address_2": "Haarlem  Noord-Holland  2031 CW",
        "country": "NL"
    },
    "001838": {
        "oui_hex": "00-18-38",
        "organization": "PanAccess Communications,Inc.",
        "address_1": "Floor 8,Tower B,Global Trade Center,36 Beisanhuandonglu,Dongcheng District",
        "address_2": "  Beijing  100013",
        "country": "CN"
    },
    "0017F0": {
        "oui_hex": "00-17-F0",
        "organization": "SZCOM Broadband Network Technology Co.,Ltd",
        "address_1": "Room 602 No.8 Building ,Shenzhen Software Park,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "0017F1": {
        "oui_hex": "00-17-F1",
        "organization": "Renu Electronics Pvt Ltd",
        "address_1": "Sr No 2/6, Baner Road,",
        "address_2": "Pune  Maharashtra  411045",
        "country": "IN"
    },
    "0017FF": {
        "oui_hex": "00-17-FF",
        "organization": "PLAYLINE Co.,Ltd.",
        "address_1": "1-4-21 MOTOAKASAKA",
        "address_2": "TOKYO    107-0051",
        "country": "JP"
    },
    "0017F6": {
        "oui_hex": "00-17-F6",
        "organization": "Pyramid Meriden Inc.",
        "address_1": "45 Gracey Ave.",
        "address_2": "Meriden  CT  06451",
        "country": "US"
    },
    "0017C5": {
        "oui_hex": "00-17-C5",
        "organization": "SonicWALL",
        "address_1": "1143 Borregas Ave",
        "address_2": "Sunnyvale  CA  95126",
        "country": "US"
    },
    "0017BE": {
        "oui_hex": "00-17-BE",
        "organization": "Tratec Telecom B.V.",
        "address_1": "De Smalle Zijde 12",
        "address_2": "Veenendaal    NL0-3903 LP",
        "country": "NL"
    },
    "0017C0": {
        "oui_hex": "00-17-C0",
        "organization": "PureTech Systems, Inc.",
        "address_1": "1950 W Rose Garden Lane",
        "address_2": "Phoenix  AZ  85027",
        "country": "US"
    },
    "0017BA": {
        "oui_hex": "00-17-BA",
        "organization": "SEDO CO., LTD.",
        "address_1": "302, KT Bldg, 1ANNEX, 35-1",
        "address_2": "Seoul    150-038",
        "country": "KR"
    },
    "0017D4": {
        "oui_hex": "00-17-D4",
        "organization": "Monsoon Multimedia, Inc",
        "address_1": "1730 South Amphlett blvd. Suite 101",
        "address_2": "San Mateo  CA  94402",
        "country": "US"
    },
    "001780": {
        "oui_hex": "00-17-80",
        "organization": "Applied Biosystems B.V.",
        "address_1": "Blk 33, Marsiling Industrial Estate Road 3,",
        "address_2": "    739256",
        "country": "SG"
    },
    "0017A5": {
        "oui_hex": "00-17-A5",
        "organization": "Ralink Technology Corp",
        "address_1": "Suite 215, Bldg 53. 195-61 Sec.4, Chung Hsing Rd,",
        "address_2": "Chutung  Hsinchu  310",
        "country": "TW"
    },
    "0017A8": {
        "oui_hex": "00-17-A8",
        "organization": "EDM Corporation",
        "address_1": "3-5-2 Itabashi",
        "address_2": "Itabashi-ku  Tokyo  173-0004",
        "country": "JP"
    },
    "0017A9": {
        "oui_hex": "00-17-A9",
        "organization": "Sentivision",
        "address_1": "Marynarska 19a",
        "address_2": "Warsaw  Mazowieckie  02-674",
        "country": "PL"
    },
    "0017AF": {
        "oui_hex": "00-17-AF",
        "organization": "Enermet",
        "address_1": "Salvesenintie",
        "address_2": "Jyskä    FIN-40420",
        "country": "FI"
    },
    "0017AA": {
        "oui_hex": "00-17-AA",
        "organization": "elab-experience inc.",
        "address_1": "104 Anotsupia",
        "address_2": "Tsu-shi  mie prefecture  514-0131",
        "country": "JP"
    },
    "0017AE": {
        "oui_hex": "00-17-AE",
        "organization": "GAI-Tronics",
        "address_1": "Brunel Drive",
        "address_2": "Burton Upon Trent  Staffordshire  DE13 0BZ",
        "country": "GB"
    },
    "0017B5": {
        "oui_hex": "00-17-B5",
        "organization": "Peerless Systems Corporation",
        "address_1": "2381 Rosecrans Avenue, Suite 400",
        "address_2": "El Segundo  CA  90245",
        "country": "US"
    },
    "00176C": {
        "oui_hex": "00-17-6C",
        "organization": "Pivot3, Inc.",
        "address_1": "6605 Cypresswood Drive, Ste 350",
        "address_2": "Spring  TX  77379-7741",
        "country": "US"
    },
    "001770": {
        "oui_hex": "00-17-70",
        "organization": "Arti Industrial Electronics Ltd.",
        "address_1": "Ger-San Sitesi, 657. Sokak",
        "address_2": "Ankara    06370",
        "country": "TR"
    },
    "00178B": {
        "oui_hex": "00-17-8B",
        "organization": "Teledyne Technologies Incorporated",
        "address_1": "12333 West Olympic Blvd",
        "address_2": "Los Angeles  CA  90064",
        "country": "US"
    },
    "0017DF": {
        "oui_hex": "00-17-DF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001746": {
        "oui_hex": "00-17-46",
        "organization": "Freedom9 Inc.",
        "address_1": "4140B SLADEVIEW CRE.,",
        "address_2": "MISSISSAUGA,  Ontario  L5L6A1",
        "country": "CA"
    },
    "00174D": {
        "oui_hex": "00-17-4D",
        "organization": "DYNAMIC NETWORK FACTORY, INC.",
        "address_1": "26250 EDEN LANDING RD.",
        "address_2": "HAYWARD  CA  94545",
        "country": "US"
    },
    "001744": {
        "oui_hex": "00-17-44",
        "organization": "Araneo Ltd.",
        "address_1": "103 Medinat Hayehudim",
        "address_2": "Herzliya    46733",
        "country": "IL"
    },
    "001749": {
        "oui_hex": "00-17-49",
        "organization": "HYUNDAE YONG-O-SA CO.,LTD",
        "address_1": "448-10, Hyuckjae B/D Seongnae, Kangdong-gu",
        "address_2": "Seoul    134-847",
        "country": "KR"
    },
    "001743": {
        "oui_hex": "00-17-43",
        "organization": "Deck Srl",
        "address_1": "Via Fabio Filzi 2",
        "address_2": "Milan    20124",
        "country": "IT"
    },
    "001728": {
        "oui_hex": "00-17-28",
        "organization": "Selex Communications",
        "address_1": "Via Pieragostini 80",
        "address_2": "Genova    16151",
        "country": "IT"
    },
    "001722": {
        "oui_hex": "00-17-22",
        "organization": "Hanazeder Electronic GmbH",
        "address_1": "J.M. Dimmelstr 10",
        "address_2": "Ried i. I.  Oberösterreich  4910",
        "country": "AT"
    },
    "00173D": {
        "oui_hex": "00-17-3D",
        "organization": "Neology",
        "address_1": "13000 Gregg Street Suite A",
        "address_2": "Poway  CA  92064",
        "country": "US"
    },
    "001740": {
        "oui_hex": "00-17-40",
        "organization": "Bluberi Gaming Technologies Inc",
        "address_1": "2125, rue Letendre Suite 420",
        "address_2": "Drummondville  Quebec  J2C 7G1",
        "country": "CA"
    },
    "001732": {
        "oui_hex": "00-17-32",
        "organization": "Science-Technical Center RISSA",
        "address_1": "st. Abramtsevskaja, h.9",
        "address_2": "Moscow    128572",
        "country": "RU"
    },
    "00176D": {
        "oui_hex": "00-17-6D",
        "organization": "CORE CORPORATION",
        "address_1": "1-22-3, Sangenjaya,",
        "address_2": "Setagaya-ku  Tokyo-to  154-8552",
        "country": "JP"
    },
    "001773": {
        "oui_hex": "00-17-73",
        "organization": "Laketune Technologies Co. Ltd",
        "address_1": "No. 38 Zijinghua Rd. Westlake District",
        "address_2": "Hangzhou  Zhejiang  310013",
        "country": "CN"
    },
    "00173A": {
        "oui_hex": "00-17-3A",
        "organization": "Cloudastructure Inc",
        "address_1": "585 Broadway",
        "address_2": "Redwood City  CA  94063",
        "country": "US"
    },
    "00172F": {
        "oui_hex": "00-17-2F",
        "organization": "NeuLion Incorporated",
        "address_1": "1600 Old Country Road",
        "address_2": "Plainview  NY  11803",
        "country": "US"
    },
    "001723": {
        "oui_hex": "00-17-23",
        "organization": "Summit Data Communications",
        "address_1": "526 South Main Street",
        "address_2": "Akron  Ohio  44311",
        "country": "US"
    },
    "00171F": {
        "oui_hex": "00-17-1F",
        "organization": "IMV Corporation",
        "address_1": "2-6-10 Takejima",
        "address_2": "Osaka    555-0011",
        "country": "JP"
    },
    "001753": {
        "oui_hex": "00-17-53",
        "organization": "nFore Technology Inc.",
        "address_1": "5F, NO 31, Ln 258, Rulguang Rd",
        "address_2": "Taipei  Neihu District  11491",
        "country": "TW"
    },
    "001757": {
        "oui_hex": "00-17-57",
        "organization": "RIX TECHNOLOGY LIMITED",
        "address_1": "17 DAI WANG STREET",
        "address_2": "TAI PO  NEW TERRITORIES",
        "country": "HK"
    },
    "0016BB": {
        "oui_hex": "00-16-BB",
        "organization": "Law-Chain Computer Technology Co Ltd",
        "address_1": "7F-2, 286-4, hsin ya road, chien chen district",
        "address_2": "Kaohsiung    80673",
        "country": "TW"
    },
    "0016B4": {
        "oui_hex": "00-16-B4",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0016A7": {
        "oui_hex": "00-16-A7",
        "organization": "AWETA G&P",
        "address_1": "Burg. Winkellaan 3",
        "address_2": "Nootdorp    2631 HG",
        "country": "NL"
    },
    "001710": {
        "oui_hex": "00-17-10",
        "organization": "Casa Systems Inc.",
        "address_1": "10, New England Business Center Dr.",
        "address_2": "Andover  MA  01810",
        "country": "US"
    },
    "0016BF": {
        "oui_hex": "00-16-BF",
        "organization": "PaloDEx Group Oy",
        "address_1": "P.O. Box 64",
        "address_2": "Tuusula    04301",
        "country": "FI"
    },
    "0016B7": {
        "oui_hex": "00-16-B7",
        "organization": "Seoul Commtech",
        "address_1": "448-11, Seongnae 3dong. Gangdong gu,",
        "address_2": "Seoul    134033",
        "country": "KR"
    },
    "0016E1": {
        "oui_hex": "00-16-E1",
        "organization": "SiliconStor, Inc.",
        "address_1": "48430 Lakeview Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0016E2": {
        "oui_hex": "00-16-E2",
        "organization": "American Fibertek, Inc.",
        "address_1": "120 Belmont Drive",
        "address_2": "Somerset  New Jersey  08873-1204",
        "country": "US"
    },
    "001713": {
        "oui_hex": "00-17-13",
        "organization": "Tiger NetCom",
        "address_1": "J-15 Mudan Cun, Yijing Huayuan,",
        "address_2": "Shenzhen  Guangdong  518003",
        "country": "CN"
    },
    "0016CD": {
        "oui_hex": "00-16-CD",
        "organization": "HIJI HIGH-TECH CO., LTD.",
        "address_1": "Ohga 8133",
        "address_2": "Hayami  Oita  879-1504",
        "country": "JP"
    },
    "0016EF": {
        "oui_hex": "00-16-EF",
        "organization": "Koko Fitness, Inc.",
        "address_1": "136 Longwater Drive",
        "address_2": "Norwell  MA  02061",
        "country": "US"
    },
    "0016FD": {
        "oui_hex": "00-16-FD",
        "organization": "Jaty Electronics",
        "address_1": "Jaty Bldg 10F, 1659-5 Bongchun11-Dong",
        "address_2": "Seoul    151-832",
        "country": "KR"
    },
    "001678": {
        "oui_hex": "00-16-78",
        "organization": "SHENZHEN BAOAN GAOKE ELECTRONICS CO., LTD",
        "address_1": "GAOKE INDUSTRIAL PARK, NO.8 TANGKENG ROAD, SHIYAN TOWN",
        "address_2": "SHENZHEN  GUANGDONG  518108",
        "country": "CN"
    },
    "001674": {
        "oui_hex": "00-16-74",
        "organization": "EuroCB (Phils.), Inc.",
        "address_1": "SFB No.2",
        "address_2": "Lapulapu City  Cebu  6015",
        "country": "PH"
    },
    "001670": {
        "oui_hex": "00-16-70",
        "organization": "SKNET Corporation",
        "address_1": "Fontana Shinyokohama",
        "address_2": "Yokohama  Kanagawa  222-0033",
        "country": "JP"
    },
    "001689": {
        "oui_hex": "00-16-89",
        "organization": "Pilkor Electronics Co., Ltd",
        "address_1": "381,Wonchun-Dong,Yeoungtong-Gu",
        "address_2": "Suwon  Kyung Ki-Do  442-380",
        "country": "KR"
    },
    "00168A": {
        "oui_hex": "00-16-8A",
        "organization": "id-Confirm Inc",
        "address_1": "1800 Boulder St",
        "address_2": "Denver  CO  80211",
        "country": "US"
    },
    "001686": {
        "oui_hex": "00-16-86",
        "organization": "Karl Storz Imaging",
        "address_1": "175 Cremona Dr.",
        "address_2": "Goleta  CA  93117",
        "country": "US"
    },
    "00168D": {
        "oui_hex": "00-16-8D",
        "organization": "KORWIN CO., Ltd.",
        "address_1": "3rd Floor, Hana Bldg, 123-7 Nonhyun-dong",
        "address_2": "Seoul    135-010",
        "country": "KR"
    },
    "00168E": {
        "oui_hex": "00-16-8E",
        "organization": "Vimicro corporation",
        "address_1": "15/F,Shining Tower,No.35,xueyuan",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "00164F": {
        "oui_hex": "00-16-4F",
        "organization": "World Ethnic Broadcastin Inc.",
        "address_1": "50 California Street, Suite 1500",
        "address_2": "San Francisco  California  94111",
        "country": "US"
    },
    "00167E": {
        "oui_hex": "00-16-7E",
        "organization": "DIBOSS.CO.,LTD",
        "address_1": "126-1, Gongdan-dong",
        "address_2": "Gumi  Gyeongbuk  730-902",
        "country": "KR"
    },
    "00167B": {
        "oui_hex": "00-16-7B",
        "organization": "Haver&Boecker",
        "address_1": "Carl-Haver-Platz 3",
        "address_2": "Oelde  NRW  59302",
        "country": "DE"
    },
    "001679": {
        "oui_hex": "00-16-79",
        "organization": "eOn Communications",
        "address_1": "4105 Royal Drive, Suite 100",
        "address_2": "Kennesaw  Georgia  30144",
        "country": "US"
    },
    "0016A3": {
        "oui_hex": "00-16-A3",
        "organization": "Ingeteam Transmission&Distribution, S.A.",
        "address_1": "C/ Usausuaga, 7",
        "address_2": "Basauri  Bizkaia  48970",
        "country": "ES"
    },
    "0016A0": {
        "oui_hex": "00-16-A0",
        "organization": "Auto-Maskin",
        "address_1": "Sophie Radichs Vei 7",
        "address_2": "LILLESTROM  Akershus  2003",
        "country": "NO"
    },
    "00165D": {
        "oui_hex": "00-16-5D",
        "organization": "AirDefense, Inc.",
        "address_1": "4800 North Point Pkwy",
        "address_2": "Alpharetta  GA  30022",
        "country": "US"
    },
    "00165B": {
        "oui_hex": "00-16-5B",
        "organization": "Grip Audio",
        "address_1": "6345 W. Louise Drive",
        "address_2": "Glendale  Arizona  85310-4243",
        "country": "US"
    },
    "001667": {
        "oui_hex": "00-16-67",
        "organization": "A-TEC Subsystem INC.",
        "address_1": "4F, No. 86, Chung-Hsing Road, Shijr City,",
        "address_2": "    221",
        "country": "TW"
    },
    "00164A": {
        "oui_hex": "00-16-4A",
        "organization": "Vibration Technology Limited",
        "address_1": "Vibtech House, Central Boulevard",
        "address_2": "Larbert  Scotland  FK5 4RU",
        "country": "GB"
    },
    "001645": {
        "oui_hex": "00-16-45",
        "organization": "Power Distribution, Inc.",
        "address_1": "4200 Oakleys Ct.",
        "address_2": "Richmond  VA  23223",
        "country": "US"
    },
    "00163F": {
        "oui_hex": "00-16-3F",
        "organization": "CReTE SYSTEMS Inc.",
        "address_1": "7F,No.250,Sec.3,Pei Shen Rd.,Shen Keng Hsiang",
        "address_2": "Taipei County    22204",
        "country": "TW"
    },
    "00163D": {
        "oui_hex": "00-16-3D",
        "organization": "Tsinghua Tongfang Legend Silicon Tech. Co., Ltd.",
        "address_1": "26F TSINGHUA TONGFANG HI-TECH PLAZA",
        "address_2": "BEIJING    100083",
        "country": "CN"
    },
    "00162D": {
        "oui_hex": "00-16-2D",
        "organization": "STNet Co., Ltd.",
        "address_1": "Shin-wha Building 4F, 954-25",
        "address_2": "Anyang-si  Kyungki-do   431-060",
        "country": "KR"
    },
    "001627": {
        "oui_hex": "00-16-27",
        "organization": "embedded-logic DESIGN AND MORE GmbH",
        "address_1": "Hansestrasse 24",
        "address_2": "Muenster  NRW  48153",
        "country": "DE"
    },
    "00163A": {
        "oui_hex": "00-16-3A",
        "organization": "YVES TECHNOLOGY CO., LTD.",
        "address_1": "No.74, Fusing 2nd Rd.",
        "address_2": "Gueishan  Taoyuan  33377",
        "country": "TW"
    },
    "001638": {
        "oui_hex": "00-16-38",
        "organization": "TECOM Co., Ltd.",
        "address_1": "23 R&D Road 2 Science Based Industrial Park",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "001633": {
        "oui_hex": "00-16-33",
        "organization": "Oxford Diagnostics Ltd.",
        "address_1": "Sandybrae",
        "address_2": "Oxford  Oxon.  OX1 5HJ",
        "country": "GB"
    },
    "0015EC": {
        "oui_hex": "00-15-EC",
        "organization": "Boca Devices LLC",
        "address_1": "7647 Sierra Ter",
        "address_2": "Boca Raton  Florida  33433",
        "country": "US"
    },
    "0015EF": {
        "oui_hex": "00-15-EF",
        "organization": "NEC TOKIN Corporation",
        "address_1": " 1-1,Asahi-Cho 7-chome,Shiroishi,",
        "address_2": "Miyagi    989-0223",
        "country": "JP"
    },
    "0015E4": {
        "oui_hex": "00-15-E4",
        "organization": "Zimmer Elektromedizin",
        "address_1": "Junkersstrasse 9",
        "address_2": "Neu-Ulm  Bayern  89231",
        "country": "DE"
    },
    "001622": {
        "oui_hex": "00-16-22",
        "organization": "BBH SYSTEMS GMBH",
        "address_1": "Böttgerstraße 40",
        "address_2": "Weiden i.d.OPf.  Bayern  92637",
        "country": "DE"
    },
    "001613": {
        "oui_hex": "00-16-13",
        "organization": "LibreStream Technologies Inc.",
        "address_1": "895 Waverley Street",
        "address_2": "Winnipeg  Manitoba  R3T 5P4",
        "country": "CA"
    },
    "00160F": {
        "oui_hex": "00-16-0F",
        "organization": "BADGER METER INC",
        "address_1": "4545 W BROWN DEER RD",
        "address_2": "MILWAUKEE  WI  53223",
        "country": "US"
    },
    "001604": {
        "oui_hex": "00-16-04",
        "organization": "Sigpro",
        "address_1": "655 W Evelyn ST",
        "address_2": "Mountain View  CA  94041",
        "country": "US"
    },
    "0015FB": {
        "oui_hex": "00-15-FB",
        "organization": "setex schermuly textile computer gmbh",
        "address_1": "Hauptstraße 25",
        "address_2": "Mengerskirchen  Hessen  35794",
        "country": "DE"
    },
    "0015FE": {
        "oui_hex": "00-15-FE",
        "organization": "SCHILLING ROBOTICS LLC",
        "address_1": "260 COUSTEAU PL",
        "address_2": "DAVIS  CA  95618",
        "country": "US"
    },
    "00160D": {
        "oui_hex": "00-16-0D",
        "organization": "Be Here Corporation",
        "address_1": "39300 Civic Center Dr., Suite 180",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0015C9": {
        "oui_hex": "00-15-C9",
        "organization": "Gumstix, Inc",
        "address_1": "3130 Alpine Road",
        "address_2": "Portola Valley  CA  94028",
        "country": "US"
    },
    "0015BA": {
        "oui_hex": "00-15-BA",
        "organization": "iba AG",
        "address_1": "Koenigswarterstrasse 44",
        "address_2": "Fuerth  Bavaria  90762",
        "country": "DE"
    },
    "0015BB": {
        "oui_hex": "00-15-BB",
        "organization": "SMA Solar Technology AG",
        "address_1": "Sonnenallee 1",
        "address_2": "Niestetal  Hessen  34266",
        "country": "DE"
    },
    "0015BF": {
        "oui_hex": "00-15-BF",
        "organization": "technicob",
        "address_1": "4 Rue Camille Saint-Saens",
        "address_2": "LANESTER  Morbihan  56602",
        "country": "US"
    },
    "001582": {
        "oui_hex": "00-15-82",
        "organization": "Pulse Eight Limited",
        "address_1": "13 The Metro Centre",
        "address_2": "Peterbourugh  PE2 7UH",
        "country": "GB"
    },
    "00157B": {
        "oui_hex": "00-15-7B",
        "organization": "Leuze electronic GmbH + Co. KG",
        "address_1": "In der Braike 1",
        "address_2": "Owen  Baden-Württemberg  73277",
        "country": "DE"
    },
    "001578": {
        "oui_hex": "00-15-78",
        "organization": "Audio / Video Innovations",
        "address_1": "A3-3375 North Service Road",
        "address_2": "Burlington  ON  L7N 3G2",
        "country": "CA"
    },
    "0015AE": {
        "oui_hex": "00-15-AE",
        "organization": "kyung il",
        "address_1": "woar rong-myn yougate-ri 101-2",
        "address_2": "paju-city  gyeong gi  413-813",
        "country": "KR"
    },
    "0015BC": {
        "oui_hex": "00-15-BC",
        "organization": "Develco",
        "address_1": "Olof Palmes Allé 40",
        "address_2": "Aarhus N    8200",
        "country": "DK"
    },
    "0015BD": {
        "oui_hex": "00-15-BD",
        "organization": "Group 4 Technology Ltd",
        "address_1": "Challenge House",
        "address_2": "Tewkesbury  Gloucestershire  GL20 8UQ",
        "country": "GB"
    },
    "0015B5": {
        "oui_hex": "00-15-B5",
        "organization": "CI Network Corp.",
        "address_1": "2F Daini Inoue Bldg",
        "address_2": "Tokyo    107-0052",
        "country": "JP"
    },
    "0015CD": {
        "oui_hex": "00-15-CD",
        "organization": "Exartech International Corp.",
        "address_1": "3/F, No.62, Lane 188, Ruei Guang Rd., Neihu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "0015D9": {
        "oui_hex": "00-15-D9",
        "organization": "PKC Electronics Oy",
        "address_1": "Pajuniityntie 43",
        "address_2": "RAAHE    92120",
        "country": "FI"
    },
    "0015DD": {
        "oui_hex": "00-15-DD",
        "organization": "IP Control Systems Ltd.",
        "address_1": "Unit 15, Hi-Tech Village,",
        "address_2": "Boldon  Tyne & Wear  NE35 9PE",
        "country": "GB"
    },
    "00159C": {
        "oui_hex": "00-15-9C",
        "organization": "B-KYUNG SYSTEM Co.,Ltd.",
        "address_1": "#812,WOOLIM E-BIZ CENTER,170-5",
        "address_2": "GURO-DONG  GURO-GU  152-847",
        "country": "KR"
    },
    "001595": {
        "oui_hex": "00-15-95",
        "organization": "Quester Tangent Corporation",
        "address_1": "201 - 9865 West Saanich Road",
        "address_2": "Sidney  BC  V8L 5Y8",
        "country": "CA"
    },
    "001587": {
        "oui_hex": "00-15-87",
        "organization": "Takenaka Seisakusho Co.,Ltd",
        "address_1": "178 HISHIE",
        "address_2": "HIGASHI-OSAKA CITY  OSAKA  578-0984",
        "country": "JP"
    },
    "00151A": {
        "oui_hex": "00-15-1A",
        "organization": "Hunter Engineering Company",
        "address_1": "11250 Hunter Drive",
        "address_2": "Bridgeton  Missouri  63044",
        "country": "US"
    },
    "001514": {
        "oui_hex": "00-15-14",
        "organization": "Hu Zhou NAVA Networks&Electronics Ltd.",
        "address_1": "3/F,No.328-4,Guang Yuan Rd.",
        "address_2": "Hu Zhou  Zhe Jiang  313000",
        "country": "CN"
    },
    "001516": {
        "oui_hex": "00-15-16",
        "organization": "URIEL SYSTEMS INC.",
        "address_1": "#204 Byucksan Digitalvalley 1st, 212-16, Guro-dong, Guro-gu",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "001545": {
        "oui_hex": "00-15-45",
        "organization": "SEECODE Co., Ltd.",
        "address_1": "4th Floor, Amin Bldg., 110-1, Yangjaedong, Seochogu",
        "address_2": "Seoul    137-891",
        "country": "KR"
    },
    "001543": {
        "oui_hex": "00-15-43",
        "organization": "Aberdeen Test Center",
        "address_1": "400 Colleran Road",
        "address_2": "Aberdeen Proving Grounds  MD  21005-5059",
        "country": "US"
    },
    "001541": {
        "oui_hex": "00-15-41",
        "organization": "StrataLight Communications, Inc.",
        "address_1": "2105 S. Bascom Avenue",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "001569": {
        "oui_hex": "00-15-69",
        "organization": "PECO II, Inc.",
        "address_1": "7060 Huntley Road",
        "address_2": "Columbus  OH  43229",
        "country": "US"
    },
    "001564": {
        "oui_hex": "00-15-64",
        "organization": "BEHRINGER Spezielle Studiotechnik GmbH",
        "address_1": "Hanns-Martin-Schleyer-Str. 36-38",
        "address_2": "Willich",
        "country": "DE"
    },
    "001563": {
        "oui_hex": "00-15-63",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001561": {
        "oui_hex": "00-15-61",
        "organization": "JJPlus Corporation",
        "address_1": "678 Massachusetts Ave",
        "address_2": "Cambridge  MA  02139",
        "country": "US"
    },
    "001571": {
        "oui_hex": "00-15-71",
        "organization": "Nolan Systems",
        "address_1": "1595 Cleo Springs Dr.",
        "address_2": "San Jose  Ca.  95131",
        "country": "US"
    },
    "001565": {
        "oui_hex": "00-15-65",
        "organization": "XIAMEN YEALINK NETWORK TECHNOLOGY CO.,LTD",
        "address_1": "7F Hualian Electronic BLDG.580 Jiahe Road,Xiamen China",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "001538": {
        "oui_hex": "00-15-38",
        "organization": "RFID, Inc.",
        "address_1": "14100 East Jewell Ave.",
        "address_2": "Aurora  CO  80012",
        "country": "US"
    },
    "00152E": {
        "oui_hex": "00-15-2E",
        "organization": "PacketHop, Inc.",
        "address_1": "1301 Shoreway Road",
        "address_2": "Belmont  California  94002",
        "country": "US"
    },
    "001558": {
        "oui_hex": "00-15-58",
        "organization": "FOXCONN",
        "address_1": "No.2,2nd DongHuan Road,10th YouSong",
        "address_2": "ShenZhen  GuangDong  518109",
        "country": "US"
    },
    "00151F": {
        "oui_hex": "00-15-1F",
        "organization": "Multivision Intelligent Surveillance (Hong Kong) Ltd",
        "address_1": "26/F, Aitken Vanson Centre,",
        "address_2": "",
        "country": "HK"
    },
    "001522": {
        "oui_hex": "00-15-22",
        "organization": "Dea Security",
        "address_1": "Via Togliatti",
        "address_2": "Santo Stefano Magra  SP  19037",
        "country": "IT"
    },
    "00154F": {
        "oui_hex": "00-15-4F",
        "organization": "one RF Technology",
        "address_1": "1360 Route des Dolines",
        "address_2": "Valbonne Sophia-Antipolis  PACA  06560",
        "country": "FR"
    },
    "001501": {
        "oui_hex": "00-15-01",
        "organization": "LexBox",
        "address_1": "3, avenue Didier Daurat",
        "address_2": "TOULOUSE    31400",
        "country": "FR"
    },
    "0014A3": {
        "oui_hex": "00-14-A3",
        "organization": "Vitelec BV",
        "address_1": "kapittelweg 18",
        "address_2": "Breda  NB  NL 4827 HG",
        "country": "NL"
    },
    "001497": {
        "oui_hex": "00-14-97",
        "organization": "ZHIYUAN Eletronics co.,ltd.",
        "address_1": "2 Floor, NO.3 Building, Huangzhou Industrial Estate, Chebei Road,",
        "address_2": "Guangzhou  Guangdong  510660",
        "country": "CN"
    },
    "001499": {
        "oui_hex": "00-14-99",
        "organization": "Helicomm Inc",
        "address_1": "1947 Camino Vida Roble",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "001492": {
        "oui_hex": "00-14-92",
        "organization": "Liteon, Mobile Media Solution SBU",
        "address_1": "4F, 3, Lane 768, Sec. 4,",
        "address_2": "Taipei    115",
        "country": "TW"
    },
    "001494": {
        "oui_hex": "00-14-94",
        "organization": "ESU AG",
        "address_1": "Lukasstrasse 29",
        "address_2": "St. Gallen    9008",
        "country": "CH"
    },
    "0014EF": {
        "oui_hex": "00-14-EF",
        "organization": "TZero Technologies, Inc.",
        "address_1": "455 W. Maude Avenue",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "0014BC": {
        "oui_hex": "00-14-BC",
        "organization": "SYNECTIC TELECOM EXPORTS PVT. LTD.",
        "address_1": "196, 1st Main, 3rd Stage, 4th Block",
        "address_2": "BANGALORE    560079",
        "country": "IN"
    },
    "0014B9": {
        "oui_hex": "00-14-B9",
        "organization": "MSTAR SEMICONDUCTOR",
        "address_1": "11-13 rue René Jacques",
        "address_2": "Issy les Moulineaux    92130",
        "country": "FR"
    },
    "0014BD": {
        "oui_hex": "00-14-BD",
        "organization": "incNETWORKS, Inc",
        "address_1": "198 Brighton Ave",
        "address_2": "Long Branch  NJ  07740",
        "country": "US"
    },
    "0014B7": {
        "oui_hex": "00-14-B7",
        "organization": "AR Infotek Inc.",
        "address_1": "9F, No.185, GangQian Road",
        "address_2": "Taipei    11494",
        "country": "TW"
    },
    "0014CA": {
        "oui_hex": "00-14-CA",
        "organization": "Key Radio Systems Limited",
        "address_1": "Venus House",
        "address_2": "Aldermaston  Berkshire  RG7 8DA",
        "country": "GB"
    },
    "0014C8": {
        "oui_hex": "00-14-C8",
        "organization": "Contemporary Research Corp",
        "address_1": "4355 Excel Pkwy",
        "address_2": "Addison  TX  75001",
        "country": "US"
    },
    "0014C5": {
        "oui_hex": "00-14-C5",
        "organization": "Alive Technologies Pty Ltd",
        "address_1": "11 Technology Drive",
        "address_2": "Arundel  Queensland  4214",
        "country": "AU"
    },
    "0014DA": {
        "oui_hex": "00-14-DA",
        "organization": "Huntleigh Healthcare",
        "address_1": "Huntleigh Healthcare - Diagnostic Products Division",
        "address_2": "Cardiff    CF24 5HN",
        "country": "GB"
    },
    "0014D5": {
        "oui_hex": "00-14-D5",
        "organization": "Datang Telecom Technology CO. , LCD,Optical Communication Br",
        "address_1": "3rd Floor,Building 8,Hi-Tech Incubation Park,",
        "address_2": "ChengDu  SiChuan  610041",
        "country": "CN"
    },
    "0014D3": {
        "oui_hex": "00-14-D3",
        "organization": "SEPSA",
        "address_1": "calle Albatros, 7 y 9",
        "address_2": "PINTO  Madrid  28320",
        "country": "ES"
    },
    "0014D8": {
        "oui_hex": "00-14-D8",
        "organization": "bio-logic SA",
        "address_1": "1, rue de l'Europe",
        "address_2": "CLAIX    38640",
        "country": "FR"
    },
    "0014EE": {
        "oui_hex": "00-14-EE",
        "organization": "Western Digital Technologies, Inc.",
        "address_1": "20511 Lake Forest Dr.",
        "address_2": "Lake Forest  Ca  92630",
        "country": "US"
    },
    "0014B5": {
        "oui_hex": "00-14-B5",
        "organization": "PHYSIOMETRIX,INC",
        "address_1": "101 BILLERICA AVE #5",
        "address_2": "N. BILLERICA  MA  01862",
        "country": "US"
    },
    "00149C": {
        "oui_hex": "00-14-9C",
        "organization": "HF Company",
        "address_1": "Node Park Touraine",
        "address_2": "BP1 Tauxigny    37310",
        "country": "FR"
    },
    "00145C": {
        "oui_hex": "00-14-5C",
        "organization": "Intronics B.V.",
        "address_1": "Koolhovenstraat 1E",
        "address_2": "Barneveld  Gelderland  3772 MT",
        "country": "NL"
    },
    "00145A": {
        "oui_hex": "00-14-5A",
        "organization": "Neratec Solutions AG",
        "address_1": "Rosswiesstrasse 29",
        "address_2": "CH-8608  Bubikon  ZH",
        "country": "CH"
    },
    "00145B": {
        "oui_hex": "00-14-5B",
        "organization": "SeekerNet Inc.",
        "address_1": "300 Satellite Blvd.",
        "address_2": "Suwanee  Georgia  30024",
        "country": "US"
    },
    "001449": {
        "oui_hex": "00-14-49",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "001446": {
        "oui_hex": "00-14-46",
        "organization": "SuperVision Solutions LLC",
        "address_1": "762 Industrial Dr.",
        "address_2": "Elmhurst  IL  60126",
        "country": "US"
    },
    "001440": {
        "oui_hex": "00-14-40",
        "organization": "ATOMIC Corporation",
        "address_1": "MAMPO BLDG",
        "address_2": "TAITO-KU  TOKYO  111-0053",
        "country": "JP"
    },
    "00142E": {
        "oui_hex": "00-14-2E",
        "organization": "77 Elektronika Kft.",
        "address_1": "Fehervari ut 98.",
        "address_2": "  Budapest  H-1163",
        "country": "HU"
    },
    "001430": {
        "oui_hex": "00-14-30",
        "organization": "ViPowER, Inc",
        "address_1": "9F., No.205-3, Sec. 3, Beisin Rd",
        "address_2": "Sindian  Taipei County  231",
        "country": "TW"
    },
    "001432": {
        "oui_hex": "00-14-32",
        "organization": "Tarallax Wireless, Inc.",
        "address_1": "10 West 100 South,",
        "address_2": "Salt Lake City  UT  84101",
        "country": "US"
    },
    "001485": {
        "oui_hex": "00-14-85",
        "organization": "Giga-Byte",
        "address_1": "No.215,Nan-Ping Road,",
        "address_2": "Pin-Jen  Taoyuan  326",
        "country": "TW"
    },
    "001483": {
        "oui_hex": "00-14-83",
        "organization": "eXS Inc.",
        "address_1": "1900 Alameda de las Pulgas",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "001471": {
        "oui_hex": "00-14-71",
        "organization": "Eastern Asia Technology Limited",
        "address_1": "8F-1, No. 188, Baoqiao Rd., Xindian Dist.",
        "address_2": "New Taipei City    23145",
        "country": "TW"
    },
    "00146A": {
        "oui_hex": "00-14-6A",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00144C": {
        "oui_hex": "00-14-4C",
        "organization": "General Meters Corp.",
        "address_1": "1935 Dominion Way",
        "address_2": "Colorado Springs  Colorado  80918",
        "country": "US"
    },
    "001443": {
        "oui_hex": "00-14-43",
        "organization": "Consultronics Europe Ltd",
        "address_1": "Electron Way",
        "address_2": "Chandlers Ford  Hants  SO53 4SE",
        "country": "GB"
    },
    "001460": {
        "oui_hex": "00-14-60",
        "organization": "Kyocera Wireless Corp.",
        "address_1": "10300 Campus Point Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0013F5": {
        "oui_hex": "00-13-F5",
        "organization": "Akimbi Systems",
        "address_1": "1400 Fashion Island Blvd",
        "address_2": "San Mateo  CA  94404",
        "country": "US"
    },
    "0013F1": {
        "oui_hex": "00-13-F1",
        "organization": "AMOD Technology Co., Ltd.",
        "address_1": "2F., No. 16, Prosperity Road II",
        "address_2": "Hsinchu,    30078",
        "country": "TW"
    },
    "0013E7": {
        "oui_hex": "00-13-E7",
        "organization": "Halcro",
        "address_1": "Suite 1, Level 1",
        "address_2": "Wayville  South Australia  5034",
        "country": "AU"
    },
    "0013EA": {
        "oui_hex": "00-13-EA",
        "organization": "Kamstrup A/S",
        "address_1": "Industrivej 28",
        "address_2": "Stilling    8660",
        "country": "DK"
    },
    "0013E1": {
        "oui_hex": "00-13-E1",
        "organization": "Iprobe AB",
        "address_1": "Finlandsgatan 12",
        "address_2": "  Kista  SE-16474",
        "country": "SE"
    },
    "0013E3": {
        "oui_hex": "00-13-E3",
        "organization": "CoVi Technologies, Inc.",
        "address_1": "6300 Bridgepoint Parkway",
        "address_2": "Austin  Texas  78730",
        "country": "US"
    },
    "0013E4": {
        "oui_hex": "00-13-E4",
        "organization": "YANGJAE SYSTEMS CORP.",
        "address_1": "1202. HANSHIN IT TOWER Guro-3Dong,",
        "address_2": "  Seoul  152-848",
        "country": "KR"
    },
    "0013C1": {
        "oui_hex": "00-13-C1",
        "organization": "Asoka USA Corporation",
        "address_1": "558 Pilgrim Drive",
        "address_2": "Foster City  CA  94404",
        "country": "US"
    },
    "0013C0": {
        "oui_hex": "00-13-C0",
        "organization": "Trix Tecnologia Ltda.",
        "address_1": "Rua da Paz, 1957 - Chácara Santo Antônio",
        "address_2": "São Paulo    04713-002",
        "country": "BR"
    },
    "00141F": {
        "oui_hex": "00-14-1F",
        "organization": "SunKwang Electronics Co., Ltd",
        "address_1": "#365(Techno-park, 301 dong, 901 ho,) Samjung-dong, Ohjung-ku,",
        "address_2": "Bucheon-shi  Kyunggi-do  421-809",
        "country": "KR"
    },
    "00141D": {
        "oui_hex": "00-14-1D",
        "organization": "LTI-Motion GmbH",
        "address_1": "Gewerbestrasse 5-9",
        "address_2": "Lahnau  Hessen  35633",
        "country": "DE"
    },
    "001412": {
        "oui_hex": "00-14-12",
        "organization": "S-TEC electronics AG",
        "address_1": "Industriestrasse 49",
        "address_2": "  Zug  6300",
        "country": "CH"
    },
    "001411": {
        "oui_hex": "00-14-11",
        "organization": "Deutschmann Automation GmbH & Co. KG",
        "address_1": "Carl-Zeiss-Str. 8",
        "address_2": "Bad Camberg    D - 65520",
        "country": "DE"
    },
    "001405": {
        "oui_hex": "00-14-05",
        "organization": "OpenIB, Inc.",
        "address_1": "OpenFabrics, Inc., c/o QLogic Corporation",
        "address_2": "Mountain View  CA  94043-4655",
        "country": "US"
    },
    "004501": {
        "oui_hex": "00-45-01",
        "organization": "Midmark RTLS",
        "address_1": "2600 Miller Creek Road",
        "address_2": "Traverse City  MI  49684",
        "country": "US"
    },
    "001403": {
        "oui_hex": "00-14-03",
        "organization": "Renasis, LLC",
        "address_1": "1530 N. State St.",
        "address_2": "Lehi  UT  84043",
        "country": "US"
    },
    "001401": {
        "oui_hex": "00-14-01",
        "organization": "Rivertree Networks Corp.",
        "address_1": "R#304, K-Center, 1591-9",
        "address_2": "Anyang-si  Kyunggi-do  431-815",
        "country": "KR"
    },
    "0013D9": {
        "oui_hex": "00-13-D9",
        "organization": "Matrix Product Development, Inc.",
        "address_1": "13 North Bird Street",
        "address_2": "Sun Prairie  WI  53590",
        "country": "US"
    },
    "0013CC": {
        "oui_hex": "00-13-CC",
        "organization": "Tall Maple Systems",
        "address_1": "85 Saratoga Ave Suite 139",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "001394": {
        "oui_hex": "00-13-94",
        "organization": "Infohand Co.,Ltd",
        "address_1": "Kranz-Techno #1207, 5442-1, Sangdaewon-dong, Jungwon-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  462-819",
        "country": "KR"
    },
    "001389": {
        "oui_hex": "00-13-89",
        "organization": "Redes de Telefonía Móvil S.A.",
        "address_1": "C/Puerto de la Morcuera 14 B4",
        "address_2": "Leganés  Madrid  28918",
        "country": "ES"
    },
    "00138C": {
        "oui_hex": "00-13-8C",
        "organization": "Kumyoung.Co.Ltd",
        "address_1": "Seoul KY building, 40-17 Hangang Ro, 3Ga, Youngsan-Gu",
        "address_2": "Seoul    140-880",
        "country": "KR"
    },
    "0013A1": {
        "oui_hex": "00-13-A1",
        "organization": "Crow Electronic Engeneering",
        "address_1": "12 Kinneret st.",
        "address_2": "Airport City",
        "country": "IL"
    },
    "00139C": {
        "oui_hex": "00-13-9C",
        "organization": "Exavera Technologies, Inc.",
        "address_1": "195 New Hampshire Avenue",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "001355": {
        "oui_hex": "00-13-55",
        "organization": "TOMEN Cyber-business Solutions, Inc.",
        "address_1": "2-11-19 Kohnan",
        "address_2": "TOKYO    108-0075",
        "country": "JP"
    },
    "001357": {
        "oui_hex": "00-13-57",
        "organization": "Soyal Technology Co., Ltd.",
        "address_1": "10F, No. 27, Lane 169, Kangning St., Shijr City,",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "001360": {
        "oui_hex": "00-13-60",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00138E": {
        "oui_hex": "00-13-8E",
        "organization": "FOAB Elektronik AB",
        "address_1": "Sankt Jorgens Vag 8",
        "address_2": "Gothenburg    422 49",
        "country": "SE"
    },
    "001376": {
        "oui_hex": "00-13-76",
        "organization": "Tabor Electronics Ltd.",
        "address_1": "9 Hatatsia St.",
        "address_2": "Tel Hanan    20302",
        "country": "IL"
    },
    "00135D": {
        "oui_hex": "00-13-5D",
        "organization": "NTTPC Communications, Inc.",
        "address_1": "3-25 Kanda Jinbo-cho",
        "address_2": "Chiyoda-ku  Tokyo  101-0051",
        "country": "JP"
    },
    "001352": {
        "oui_hex": "00-13-52",
        "organization": "Naztec, Inc.",
        "address_1": "820 Park Two Dr.",
        "address_2": "Sugar Land  TX  77478",
        "country": "US"
    },
    "00136C": {
        "oui_hex": "00-13-6C",
        "organization": "TomTom",
        "address_1": "Oosterdoksstraat 114",
        "address_2": "1011 DK  Amsterdam",
        "country": "NL"
    },
    "001364": {
        "oui_hex": "00-13-64",
        "organization": "Paradigm Technology Inc..",
        "address_1": "3F, No. 285, Sec.2, Ti-Ding Blvd Nei-Hu,",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "00136B": {
        "oui_hex": "00-13-6B",
        "organization": "E-TEC",
        "address_1": "2-17-14-503 Hakataekimae",
        "address_2": "Fukuoka  Fukuokaken  812-0011",
        "country": "JP"
    },
    "171450": {
        "oui_hex": "17-14-50",
        "organization": "2-17-14-503 Hakataekimae",
        "address_1": "JP",
        "address_2": "",
        "country": ""
    },
    "001380": {
        "oui_hex": "00-13-80",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001385": {
        "oui_hex": "00-13-85",
        "organization": "Add-On Technology Co., LTD.",
        "address_1": "1F, No.11, Lane 206, Da-An Road Sec. 1,",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "0013B3": {
        "oui_hex": "00-13-B3",
        "organization": "Ecom Communications Technology Co., Ltd.",
        "address_1": "Floor 7, Machinery Industry Building, No.22,",
        "address_2": "Beijing",
        "country": "CN"
    },
    "0013B7": {
        "oui_hex": "00-13-B7",
        "organization": "Scantech ID",
        "address_1": "Vanadiumweg 22",
        "address_2": "Amersfoort  Utrecht  3812 PZ",
        "country": "NL"
    },
    "001308": {
        "oui_hex": "00-13-08",
        "organization": "Nuvera Fuel Cells",
        "address_1": "129 Concord Road, #1",
        "address_2": "Billerica  MA  01821",
        "country": "US"
    },
    "001307": {
        "oui_hex": "00-13-07",
        "organization": "Paravirtual Corporation",
        "address_1": "2953 Bunker Hill Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0012FC": {
        "oui_hex": "00-12-FC",
        "organization": "PLANET System Co.,LTD",
        "address_1": "4th Floor, Daehan B/D, 873-29,",
        "address_2": "Seoul    137-064",
        "country": "KR"
    },
    "0012FE": {
        "oui_hex": "00-12-FE",
        "organization": "Lenovo Mobile Communication Technology Ltd.",
        "address_1": "Xiamen Overseas Chinese Electronic Science Park,Huoju High Technology Development Zone",
        "address_2": "XIA MEN  FU JIAN  361009",
        "country": "CN"
    },
    "0012EC": {
        "oui_hex": "00-12-EC",
        "organization": "Movacolor b.v.",
        "address_1": "Koperslagersstraat 31",
        "address_2": "Sneek  Friesland  8601 WL",
        "country": "NL"
    },
    "0012EB": {
        "oui_hex": "00-12-EB",
        "organization": "PDH Solutions, LLC",
        "address_1": "34154 Bennett Rd",
        "address_2": "Warren  OR  97053",
        "country": "US"
    },
    "001343": {
        "oui_hex": "00-13-43",
        "organization": "Matsushita Electronic Components (Europe) GmbH",
        "address_1": "Zeppelinstraße 19",
        "address_2": "Lueneburg  Niedersachsen  21337",
        "country": "DE"
    },
    "00133E": {
        "oui_hex": "00-13-3E",
        "organization": "MetaSwitch",
        "address_1": "1411 Harbor Bay Parkway",
        "address_2": "Alameda  CA  94502",
        "country": "US"
    },
    "001345": {
        "oui_hex": "00-13-45",
        "organization": "Eaton Corporation",
        "address_1": "4201 North 27th Street",
        "address_2": "Milwaukee  Wisconsin  53216",
        "country": "US"
    },
    "001347": {
        "oui_hex": "00-13-47",
        "organization": "Red Lion Controls, LP",
        "address_1": "20 Willow Springs Circle",
        "address_2": "York  NY  17402",
        "country": "US"
    },
    "00132E": {
        "oui_hex": "00-13-2E",
        "organization": "ITian Coporation",
        "address_1": "4F Youngho Bd.1605-1 Seocho-dong",
        "address_2": "Seoul    137-070",
        "country": "KR"
    },
    "001339": {
        "oui_hex": "00-13-39",
        "organization": "CCV Deutschland GmbH",
        "address_1": "Gewerbering 1",
        "address_2": "Au i. d. Hallertau  Bayern  84072",
        "country": "DE"
    },
    "001329": {
        "oui_hex": "00-13-29",
        "organization": "VSST Co., LTD",
        "address_1": "suit 3202, Korea World Trade Center 159-1",
        "address_2": "Seoul    135-729",
        "country": "KR"
    },
    "00132B": {
        "oui_hex": "00-13-2B",
        "organization": "Phoenix Digital",
        "address_1": "7650 East Evans Rd. Bldg. A",
        "address_2": "Scottsdale  Az  85260",
        "country": "US"
    },
    "00130B": {
        "oui_hex": "00-13-0B",
        "organization": "Mextal B.V.",
        "address_1": "De Tienden 48",
        "address_2": "Nuenen  Noord Brabant  5674TB",
        "country": "NL"
    },
    "00130D": {
        "oui_hex": "00-13-0D",
        "organization": "GALILEO AVIONICA",
        "address_1": "VIALE EUROPA",
        "address_2": " NERVIANO  MILANO  20014",
        "country": "IT"
    },
    "0012F7": {
        "oui_hex": "00-12-F7",
        "organization": "Xiamen Xinglian Electronics Co., Ltd.",
        "address_1": "Xinglian Electronics (Xingtel) Building,Chuangxin Road,",
        "address_2": "Xiamen  Fujian  361006",
        "country": "CN"
    },
    "00131B": {
        "oui_hex": "00-13-1B",
        "organization": "BeCell Innovations Corp.",
        "address_1": "12F-9, No. 79, Shin-Tai 5th Rd Sec 1,",
        "address_2": "Shih-chih,  Taipei  221",
        "country": "TW"
    },
    "0012E2": {
        "oui_hex": "00-12-E2",
        "organization": "ALAXALA Networks Corporation",
        "address_1": "890 Kashimada, Saiwai-ku",
        "address_2": "Kawasaki-shi  Kanagawa-ken  212-0058",
        "country": "JP"
    },
    "0012DF": {
        "oui_hex": "00-12-DF",
        "organization": "Novomatic AG",
        "address_1": "Wiener Strasse 158",
        "address_2": "Gumpoldskirchen  Niederösterreich  A-2352",
        "country": "AT"
    },
    "0012D4": {
        "oui_hex": "00-12-D4",
        "organization": "Princeton Technology, Ltd",
        "address_1": "K.A.I. Bldg. 3F",
        "address_2": "Chiyodaku  Tokyo  101-0032",
        "country": "JP"
    },
    "0012D9": {
        "oui_hex": "00-12-D9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0012C2": {
        "oui_hex": "00-12-C2",
        "organization": "Apex Electronics Factory",
        "address_1": "No.3 Industrial Zone, No.4 Block,",
        "address_2": "Shen Zhen  Guang Dong  518103",
        "country": "CN"
    },
    "0012BE": {
        "oui_hex": "00-12-BE",
        "organization": "Astek Corporation",
        "address_1": "5055 Corporate Plaza Drive",
        "address_2": "Colorado Springs  Colorado  80919",
        "country": "US"
    },
    "0012E1": {
        "oui_hex": "00-12-E1",
        "organization": "Alliant Networks, Inc",
        "address_1": "1259 Birchwood Dr.",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "0012C5": {
        "oui_hex": "00-12-C5",
        "organization": "V-Show  Technology (China) Co.,Ltd",
        "address_1": "7F, Tengda Plaza, No.168",
        "address_2": "HaiDian District,  Beijing  100089",
        "country": "CN"
    },
    "0012AD": {
        "oui_hex": "00-12-AD",
        "organization": "IDS GmbH",
        "address_1": "Nobelstraße, 18",
        "address_2": "Ettlingen  Baden-Württemberg  76275",
        "country": "DE"
    },
    "0012A0": {
        "oui_hex": "00-12-A0",
        "organization": "NeoMeridian Sdn Bhd",
        "address_1": "3A-1, Perdana The Place",
        "address_2": "Bandar Damansara Perdana  Selangor  47820",
        "country": "MY"
    },
    "001286": {
        "oui_hex": "00-12-86",
        "organization": "ENDEVCO CORP",
        "address_1": "30700 RANCHO VIEJO ROAD",
        "address_2": "SAN JUAN CAPISTRANO  CA  92675",
        "country": "US"
    },
    "001263": {
        "oui_hex": "00-12-63",
        "organization": "Data Voice Technologies GmbH",
        "address_1": "Stockholmer Allee 32b",
        "address_2": "Dortmund  NRW  D-44269",
        "country": "DE"
    },
    "001270": {
        "oui_hex": "00-12-70",
        "organization": "NGES Denro Systems",
        "address_1": "7055 Troy Hill Dr",
        "address_2": "Elkridge  MD  21075",
        "country": "US"
    },
    "00126E": {
        "oui_hex": "00-12-6E",
        "organization": "Seidel Elektronik GmbH Nfg.KG",
        "address_1": "Frauentalerstrasse 100",
        "address_2": "Deutschlandsberg  Steiermark  8530",
        "country": "AT"
    },
    "00126F": {
        "oui_hex": "00-12-6F",
        "organization": "Rayson Technology Co., Ltd.",
        "address_1": "1F No.9 R&D Rd.II, Science-Based Industrial Park",
        "address_2": "Hsin-Chu    300",
        "country": "TW"
    },
    "00125C": {
        "oui_hex": "00-12-5C",
        "organization": "Green Hills Software, Inc.",
        "address_1": "30 West Sola Street",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "00125F": {
        "oui_hex": "00-12-5F",
        "organization": "AWIND Inc.",
        "address_1": "17F., No. 886-5, Jungjeng Rd",
        "address_2": "Taipei County    235",
        "country": "TW"
    },
    "00122D": {
        "oui_hex": "00-12-2D",
        "organization": "SiNett Corporation",
        "address_1": "640 W. California Avenue",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "001274": {
        "oui_hex": "00-12-74",
        "organization": "NIT lab",
        "address_1": "Skoriny str., 65-3",
        "address_2": "Minsk  Minskaya obl.  220013",
        "country": "BY"
    },
    "001253": {
        "oui_hex": "00-12-53",
        "organization": "AudioDev AB",
        "address_1": "Kabingatan 9",
        "address_2": "Malmö    SE-212 39",
        "country": "SE"
    },
    "00124C": {
        "oui_hex": "00-12-4C",
        "organization": "BBWM Corporation",
        "address_1": "6F, No. 578, Rui Guang Road, Nei Hu",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "001255": {
        "oui_hex": "00-12-55",
        "organization": "NetEffect Incorporated",
        "address_1": "9211 Waterford Centre Blvd",
        "address_2": "Austin  Texas  78758",
        "country": "US"
    },
    "001244": {
        "oui_hex": "00-12-44",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00122C": {
        "oui_hex": "00-12-2C",
        "organization": "Soenen Controls N.V.",
        "address_1": "Wijnedalestraat 190",
        "address_2": "Roeselare  W-VL  8800",
        "country": "BE"
    },
    "00122B": {
        "oui_hex": "00-12-2B",
        "organization": "Virbiage Pty Ltd",
        "address_1": "Level 4",
        "address_2": "Melbourne  Victoria  3000",
        "country": "AU"
    },
    "001232": {
        "oui_hex": "00-12-32",
        "organization": "LeWiz Communications Inc.",
        "address_1": "1376 N. 4th St. #300",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "001227": {
        "oui_hex": "00-12-27",
        "organization": "Franklin Electric Co., Inc.",
        "address_1": "400 E. Spring Street",
        "address_2": "Bluffton  Indiana  46714",
        "country": "US"
    },
    "00121A": {
        "oui_hex": "00-12-1A",
        "organization": "Techno Soft Systemnics Inc.",
        "address_1": "2-5-17, Ebisu-nishi, Naniwa-ku,",
        "address_2": "Osaka    556-0003",
        "country": "JP"
    },
    "00121B": {
        "oui_hex": "00-12-1B",
        "organization": "Sound Devices, LLC",
        "address_1": "300 Wengel Drive",
        "address_2": "Reedsburg  WI  53959",
        "country": "US"
    },
    "0011DF": {
        "oui_hex": "00-11-DF",
        "organization": "Current Energy",
        "address_1": "5440 Harvest Hill, Ste 100",
        "address_2": "Dallas  TX  75230",
        "country": "US"
    },
    "0011D7": {
        "oui_hex": "00-11-D7",
        "organization": "eWerks Inc",
        "address_1": "420-2166 Mountain Grove Ave",
        "address_2": "Burlington  Ontario  L7P4X4",
        "country": "CA"
    },
    "001204": {
        "oui_hex": "00-12-04",
        "organization": "u10 Networks, Inc.",
        "address_1": "2-2-14 Kakinokizaka",
        "address_2": "Meguro  Tokyo  152-0022",
        "country": "JP"
    },
    "00120A": {
        "oui_hex": "00-12-0A",
        "organization": "Emerson Climate Technologies GmbH",
        "address_1": "Heerstrasse 111",
        "address_2": "Waiblingen  BW  71332",
        "country": "DE"
    },
    "001208": {
        "oui_hex": "00-12-08",
        "organization": "Gantner Instruments GmbH",
        "address_1": "Montafonerstrasse 8",
        "address_2": "Schruns  Vorarlberg  6780",
        "country": "AT"
    },
    "001201": {
        "oui_hex": "00-12-01",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0011EE": {
        "oui_hex": "00-11-EE",
        "organization": "Estari, Inc.",
        "address_1": "1800 Paxton St",
        "address_2": "Harrisburg  PA  17104",
        "country": "US"
    },
    "001200": {
        "oui_hex": "00-12-00",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0011E5": {
        "oui_hex": "00-11-E5",
        "organization": "KCodes Corporation",
        "address_1": "Floor 2, Number 501, Section 2",
        "address_2": "Neihu District  Taipei City  114",
        "country": "TW"
    },
    "0011DE": {
        "oui_hex": "00-11-DE",
        "organization": "EURILOGIC",
        "address_1": "Centrale Parc Bât 7",
        "address_2": "Chatenay Malabry    92298",
        "country": "FR"
    },
    "0011C8": {
        "oui_hex": "00-11-C8",
        "organization": "Powercom Co., Ltd.",
        "address_1": "8F, No. 246, Lien Chen Rd.",
        "address_2": "Chung Ho  Taipei  235",
        "country": "TW"
    },
    "0011B8": {
        "oui_hex": "00-11-B8",
        "organization": "Liebherr - Elektronik GmbH",
        "address_1": "Peter - Dornier - Strasse 11",
        "address_2": "Lindau (Bodensee)  Bavaria  88131",
        "country": "DE"
    },
    "0011B4": {
        "oui_hex": "00-11-B4",
        "organization": "Westermo Network Technologies AB",
        "address_1": "Stora Sundby",
        "address_2": "Sweden    SE-640 40",
        "country": "SE"
    },
    "001178": {
        "oui_hex": "00-11-78",
        "organization": "Chiron Technology Ltd",
        "address_1": "Wyvols Court",
        "address_2": "Reading  Berkshire  RG7 1WY",
        "country": "GB"
    },
    "00116A": {
        "oui_hex": "00-11-6A",
        "organization": "Domo Ltd",
        "address_1": "Wessex House",
        "address_2": "Eastleigh  Hampshire  SO50 9FD",
        "country": "GB"
    },
    "001193": {
        "oui_hex": "00-11-93",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00118C": {
        "oui_hex": "00-11-8C",
        "organization": "Missouri Department of Transportation",
        "address_1": "P.O. Box 270",
        "address_2": "Jefferson City  Missouri  65102",
        "country": "US"
    },
    "00118E": {
        "oui_hex": "00-11-8E",
        "organization": "Halytech Mace",
        "address_1": "Unit 11, 22 Lexington Drive",
        "address_2": "Baulkham Hills  NSW  2153",
        "country": "AU"
    },
    "001186": {
        "oui_hex": "00-11-86",
        "organization": "Prime Systems, Inc.",
        "address_1": "16267-333",
        "address_2": "Suwa-gun Hara-mura  Nagano  391-0100",
        "country": "JP"
    },
    "001183": {
        "oui_hex": "00-11-83",
        "organization": "Datalogic ADC, Inc.",
        "address_1": "959 Terry St",
        "address_2": "Eugene  OR  97402",
        "country": "US"
    },
    "00117D": {
        "oui_hex": "00-11-7D",
        "organization": "ZMD America, Inc.",
        "address_1": "15373 Innovation Drive",
        "address_2": "San Dieo  CA  92128",
        "country": "US"
    },
    "00117F": {
        "oui_hex": "00-11-7F",
        "organization": "Neotune Information Technology Corporation,.LTD",
        "address_1": "1703#  No.737  North of Caoxi Rd.",
        "address_2": "Shanghai    200030",
        "country": "CN"
    },
    "00119D": {
        "oui_hex": "00-11-9D",
        "organization": "Diginfo Technology Corporation",
        "address_1": "10Fl., No.82, Fu Hsing North Road",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "00119C": {
        "oui_hex": "00-11-9C",
        "organization": "EP&T Energy",
        "address_1": "358 Eastern Valley Way",
        "address_2": "Sydney  NSW  2067",
        "country": "AU"
    },
    "00119A": {
        "oui_hex": "00-11-9A",
        "organization": "Alkeria srl",
        "address_1": "25 Via Giuntini",
        "address_2": "Navacchio (PI)    I-56023",
        "country": "IT"
    },
    "0011C1": {
        "oui_hex": "00-11-C1",
        "organization": "4P MOBILE DATA PROCESSING",
        "address_1": "VIALE REGIONE VENETO 26",
        "address_2": "PADOVA  PD  35127",
        "country": "IT"
    },
    "0011B2": {
        "oui_hex": "00-11-B2",
        "organization": "2001 Technology Inc.",
        "address_1": "7F-10, 79 Hsin Tai 5th. Rd. Sec.1",
        "address_2": "Hsi Chih  Taipei County  221",
        "country": "TW"
    },
    "0011AF": {
        "oui_hex": "00-11-AF",
        "organization": "Medialink-i,Inc",
        "address_1": "1-9-10 Hamamatsu-Cho",
        "address_2": "Minato-Ku  Tokyo  105-0013",
        "country": "JP"
    },
    "00115E": {
        "oui_hex": "00-11-5E",
        "organization": "ProMinent Dosiertechnik GmbH",
        "address_1": "Im Schumachergewann 5-11",
        "address_2": "Heidelberg  BW  69123",
        "country": "DE"
    },
    "00117C": {
        "oui_hex": "00-11-7C",
        "organization": "e-zy.net",
        "address_1": "Smirnis 14",
        "address_2": "Veria  Imathia  59100",
        "country": "GR"
    },
    "001139": {
        "oui_hex": "00-11-39",
        "organization": "STOEBER ANTRIEBSTECHNIK GmbH + Co. KG.",
        "address_1": "Kieselbronner Str. 12",
        "address_2": "Pforzheim    75177",
        "country": "DE"
    },
    "00113E": {
        "oui_hex": "00-11-3E",
        "organization": "JL Corporation",
        "address_1": "4-4-17 SUGE",
        "address_2": "KAWASAKI-CITY  KANAGAWA-KEN  214-0001",
        "country": "JP"
    },
    "001138": {
        "oui_hex": "00-11-38",
        "organization": "TAISHIN CO., LTD.",
        "address_1": "200-7 Nakano",
        "address_2": "Nakano  Nagano  383-0013",
        "country": "JP"
    },
    "001136": {
        "oui_hex": "00-11-36",
        "organization": "Goodrich Sensor Systems",
        "address_1": "14300 Judicial Road",
        "address_2": "Burnsville  Minnesota  55306-4898",
        "country": "US"
    },
    "001132": {
        "oui_hex": "00-11-32",
        "organization": "Synology Incorporated",
        "address_1": "6F-2, No.106, Chang An W. Rd.,",
        "address_2": "Taipei    103",
        "country": "TW"
    },
    "00114B": {
        "oui_hex": "00-11-4B",
        "organization": "Francotyp-Postalia GmbH",
        "address_1": "Triftweg 21-26",
        "address_2": "Birkenwerder  Brandenburg  16547",
        "country": "DE"
    },
    "001147": {
        "oui_hex": "00-11-47",
        "organization": "Secom-Industry co.LTD.",
        "address_1": "Fukuoka Kuramoto Ichihonki 3-3",
        "address_2": "Shiroishi  Miyagi  989-0295",
        "country": "JP"
    },
    "00114A": {
        "oui_hex": "00-11-4A",
        "organization": "KAYABA INDUSTRY Co,.Ltd.",
        "address_1": "World Trade Center Bldg., 4-1",
        "address_2": "Minato-ku,  Tokyo Meto.  105-6111",
        "country": "JP"
    },
    "001142": {
        "oui_hex": "00-11-42",
        "organization": "e-SMARTCOM  INC.",
        "address_1": "3F, 216, Imok-Dong",
        "address_2": "Suwon  Kyoungki-Do  440-310",
        "country": "KR"
    },
    "001120": {
        "oui_hex": "00-11-20",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001118": {
        "oui_hex": "00-11-18",
        "organization": "BLX IC Design Corp., Ltd.",
        "address_1": "Rm 1006, Quantum Plaza",
        "address_2": "Beijing    100083",
        "country": "CN"
    },
    "001107": {
        "oui_hex": "00-11-07",
        "organization": "RGB Networks Inc.",
        "address_1": "2929 Campus Drive",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "001108": {
        "oui_hex": "00-11-08",
        "organization": "Orbital Data Corporation",
        "address_1": "1900 S. Norfolk St. Ste 320",
        "address_2": "San Mateo  CA  94403",
        "country": "US"
    },
    "00110C": {
        "oui_hex": "00-11-0C",
        "organization": "Atmark Techno, Inc.",
        "address_1": "2F SD BLDG, 2-2-3-14 Atsubetsu-nishi, Atsubetsu-ku",
        "address_2": "Sapporo  Hokkaido  004-0062",
        "country": "JP"
    },
    "00114D": {
        "oui_hex": "00-11-4D",
        "organization": "Atsumi Electric Co.,LTD.",
        "address_1": "4-2-2 Shin-Miyakoda, Kita-ku",
        "address_2": "Hamamatsu  Shizuoka  431-2103",
        "country": "JP"
    },
    "001130": {
        "oui_hex": "00-11-30",
        "organization": "Allied Telesis (Hong Kong) Ltd.",
        "address_1": "Room F, 3/F, Yeung Yiu Chong (no. 8) Industrial building,",
        "address_2": "",
        "country": "HK"
    },
    "001129": {
        "oui_hex": "00-11-29",
        "organization": "Paradise Datacom Ltd.",
        "address_1": "1 Wheaton Road",
        "address_2": "Witham  Essex UK  CM8 1UJ",
        "country": "GB"
    },
    "001157": {
        "oui_hex": "00-11-57",
        "organization": "Oki Electric Industry Co., Ltd.",
        "address_1": "1-7-12 Toranomon",
        "address_2": "Tokyo 105-8460",
        "country": "JP"
    },
    "000FD9": {
        "oui_hex": "00-0F-D9",
        "organization": "FlexDSL Telecommunications AG",
        "address_1": "Haus zum Engel",
        "address_2": "Altendorf  Schwyz  8852",
        "country": "CH"
    },
    "000FD0": {
        "oui_hex": "00-0F-D0",
        "organization": "ASTRI",
        "address_1": "18/F Tower 6, Gateway, 9 Canton Rd",
        "address_2": "",
        "country": "HK"
    },
    "000FCA": {
        "oui_hex": "00-0F-CA",
        "organization": "A-JIN TECHLINE CO, LTD",
        "address_1": "327-35",
        "address_2": "Kumchun-Ku  Seoul  153-802",
        "country": "KR"
    },
    "000FEC": {
        "oui_hex": "00-0F-EC",
        "organization": "ARKUS Inc.",
        "address_1": "3-8 Chuo-cho",
        "address_2": "3-8 Noda, Kitaa-Ku    700-0971",
        "country": "JP"
    },
    "000FED": {
        "oui_hex": "00-0F-ED",
        "organization": "Anam Electronics Co., Ltd",
        "address_1": "645 Sungkok-dong",
        "address_2": "Ansan-city  Kyungki-do  425-834",
        "country": "KR"
    },
    "000FE5": {
        "oui_hex": "00-0F-E5",
        "organization": "MERCURY SECURITY CORPORATION",
        "address_1": "2355 MIRA MAR AVE.",
        "address_2": "LONG BEACH  CA  90815",
        "country": "US"
    },
    "000FAE": {
        "oui_hex": "00-0F-AE",
        "organization": "E2O Communications",
        "address_1": "52 Serangoon North Ave 4",
        "address_2": "    555853",
        "country": "SG"
    },
    "000FB1": {
        "oui_hex": "00-0F-B1",
        "organization": "Cognio Inc.",
        "address_1": "101 Orchard Ridge Drive",
        "address_2": "Gaithersburg  MD  20878",
        "country": "US"
    },
    "000FA7": {
        "oui_hex": "00-0F-A7",
        "organization": "Raptor Networks Technology",
        "address_1": "65 Enterprise Road",
        "address_2": "Aliso Viejo  CA  92656",
        "country": "US"
    },
    "000FF0": {
        "oui_hex": "00-0F-F0",
        "organization": "Sunray Co. Ltd.",
        "address_1": "Osawa2-5-5 Mitaka",
        "address_2": "  Tokyo  181-0015",
        "country": "JP"
    },
    "001103": {
        "oui_hex": "00-11-03",
        "organization": "kawamura electric inc.",
        "address_1": "3-86 akatsuki-cho",
        "address_2": "seto  aichi  489-0071",
        "country": "JP"
    },
    "000FDD": {
        "oui_hex": "00-0F-DD",
        "organization": "SORDIN AB",
        "address_1": "Rorlaggarvagen 8",
        "address_2": "Varnamo  Smaland  S-331 34",
        "country": "SE"
    },
    "000FC3": {
        "oui_hex": "00-0F-C3",
        "organization": "PalmPalm Technology, Inc.",
        "address_1": "Samsung-dong 156-3, Gangnam-gu",
        "address_2": "Seoul    135-091",
        "country": "KR"
    },
    "000F88": {
        "oui_hex": "00-0F-88",
        "organization": "AMETEK, Inc.",
        "address_1": "150 Freeport Road",
        "address_2": "Pittsburgh  PA  15238",
        "country": "US"
    },
    "000F7E": {
        "oui_hex": "00-0F-7E",
        "organization": "Ablerex Electronics Co., LTD",
        "address_1": "1F, No.3 Lane 7, Paokao Rd.",
        "address_2": "Hsintien  Taipei Hsien  23114",
        "country": "TW"
    },
    "000F83": {
        "oui_hex": "00-0F-83",
        "organization": "Brainium Technologies Inc.",
        "address_1": "#201 - 11491 Kingston Street",
        "address_2": "Maple Ridge  BC  V2X 0Y6",
        "country": "CA"
    },
    "000F84": {
        "oui_hex": "00-0F-84",
        "organization": "Astute Networks, Inc.",
        "address_1": "15015 Ave of Science",
        "address_2": "San Diego  CA  92128",
        "country": "US"
    },
    "000F5C": {
        "oui_hex": "00-0F-5C",
        "organization": "Day One Digital Media Limited",
        "address_1": "197 Archers Rd",
        "address_2": "Auckland  North Island  1310",
        "country": "NZ"
    },
    "000F52": {
        "oui_hex": "00-0F-52",
        "organization": "YORK Refrigeration, Marine & Controls",
        "address_1": "Jens Juulsvej 28",
        "address_2": "Viby J  DK  8362",
        "country": "DK"
    },
    "000F4C": {
        "oui_hex": "00-0F-4C",
        "organization": "Elextech INC",
        "address_1": "554-2, Gasan-Dong, Gumcheon-Gu",
        "address_2": "Seoul    153-023",
        "country": "KR"
    },
    "000F93": {
        "oui_hex": "00-0F-93",
        "organization": "Landis+Gyr Ltd.",
        "address_1": "Feldstrasse 1",
        "address_2": "Zug    CH-6301",
        "country": "CH"
    },
    "000F94": {
        "oui_hex": "00-0F-94",
        "organization": "Genexis BV",
        "address_1": "Lodewijktraat 1A",
        "address_2": "5652 AC  Eindhoven",
        "country": "SE"
    },
    "000F6C": {
        "oui_hex": "00-0F-6C",
        "organization": "ADDI-DATA GmbH",
        "address_1": "Airport Boulevard B210",
        "address_2": "RHEINMUENSTER  BW  77836",
        "country": "DE"
    },
    "000F8F": {
        "oui_hex": "00-0F-8F",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000F7D": {
        "oui_hex": "00-0F-7D",
        "organization": "Xirrus",
        "address_1": "310 North Westlake Blvd.",
        "address_2": "Westlake Village  CA  91362",
        "country": "US"
    },
    "000F76": {
        "oui_hex": "00-0F-76",
        "organization": "Digital Keystone, Inc.",
        "address_1": "1975 El Camino Real",
        "address_2": "Mountain View  CA  94040",
        "country": "US"
    },
    "000F9E": {
        "oui_hex": "00-0F-9E",
        "organization": "Murrelektronik GmbH",
        "address_1": "Falkenstraße 3",
        "address_2": "Oppenweiler  Baden-Württemberg  71570",
        "country": "DE"
    },
    "000F79": {
        "oui_hex": "00-0F-79",
        "organization": "Bluetooth Interest Group Inc.",
        "address_1": "4F, No. 9, Alley 2, Lane 35, Ji-Hu Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000F17": {
        "oui_hex": "00-0F-17",
        "organization": "Insta Elektro GmbH",
        "address_1": "Hohe Steinert 10",
        "address_2": "Luedenscheid  NRW  58509",
        "country": "DE"
    },
    "000F1E": {
        "oui_hex": "00-0F-1E",
        "organization": "Chengdu KT Electric Co.of High & New Technology",
        "address_1": "No.2 Gaopeng Dong Road,High & New Development Zone",
        "address_2": "Chengdu  Sichuan  610041",
        "country": "CN"
    },
    "000F15": {
        "oui_hex": "00-0F-15",
        "organization": "Icotera A/S",
        "address_1": "Vibeholms Allé 16",
        "address_2": "Brøndby    2605",
        "country": "DK"
    },
    "000F39": {
        "oui_hex": "00-0F-39",
        "organization": "IRIS SENSORS",
        "address_1": "ZA les Ufernets",
        "address_2": "TOULAUD  Ardeche  F07130",
        "country": "FR"
    },
    "000F3E": {
        "oui_hex": "00-0F-3E",
        "organization": "CardioNet, Inc",
        "address_1": "1010 Second Avenue",
        "address_2": "San Diego  CA  92101",
        "country": "US"
    },
    "000F3F": {
        "oui_hex": "00-0F-3F",
        "organization": "Big Bear Networks",
        "address_1": "345 Potrero Ave",
        "address_2": "Sunny Vale  California  94085",
        "country": "US"
    },
    "000F35": {
        "oui_hex": "00-0F-35",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000F36": {
        "oui_hex": "00-0F-36",
        "organization": "Accurate Techhnologies, Inc.",
        "address_1": "47199 Cartier Dr.",
        "address_2": "Wixom  Michigan  48393",
        "country": "US"
    },
    "000F28": {
        "oui_hex": "00-0F-28",
        "organization": "Itronix Corporation",
        "address_1": "South 801 Stevens Street",
        "address_2": "Spokane  WA  99204",
        "country": "US"
    },
    "000F23": {
        "oui_hex": "00-0F-23",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000F22": {
        "oui_hex": "00-0F-22",
        "organization": "Helius, Inc.",
        "address_1": "333 South 520 West",
        "address_2": "Lindon  UT  84042",
        "country": "US"
    },
    "000F24": {
        "oui_hex": "00-0F-24",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000EFC": {
        "oui_hex": "00-0E-FC",
        "organization": "JTAG Technologies B.V.",
        "address_1": "Boschdijk 50",
        "address_2": "Eindhoven  NB  5612 AN",
        "country": "NL"
    },
    "000EFE": {
        "oui_hex": "00-0E-FE",
        "organization": "EndRun Technologies LLC",
        "address_1": "2270 Northpoint Parkway",
        "address_2": "Santa Rosa  CA  95407",
        "country": "US"
    },
    "000F2C": {
        "oui_hex": "00-0F-2C",
        "organization": "Uplogix, Inc.",
        "address_1": "Bldg 1, Suite 235",
        "address_2": "Austin  TX  78730",
        "country": "US"
    },
    "000F2B": {
        "oui_hex": "00-0F-2B",
        "organization": "GREENBELL SYSTEMS",
        "address_1": "2TH Floor, Doonam Bldg, 236-11 Nonhyun-Dong, Kangnam-Ku",
        "address_2": "Seoul    135-010",
        "country": "KR"
    },
    "000EF2": {
        "oui_hex": "00-0E-F2",
        "organization": "Infinico Corporation",
        "address_1": "4F, F-1 Bldg., 1-2-12,",
        "address_2": "Tokyo    105-0013",
        "country": "JP"
    },
    "000F0D": {
        "oui_hex": "00-0F-0D",
        "organization": "Hunt Electronic Co., Ltd.",
        "address_1": "6FI, NO. 57-59, Jiun H Sien Rd., Chi Tu District",
        "address_2": "Keelung  Taiwan  206",
        "country": "TW"
    },
    "000F08": {
        "oui_hex": "00-0F-08",
        "organization": "Indagon Oy",
        "address_1": "Nuijamiestentie 5 A",
        "address_2": "Helsinki  -  00400",
        "country": "FI"
    },
    "000F04": {
        "oui_hex": "00-0F-04",
        "organization": "cim-usa inc",
        "address_1": "10813 nw 30th street",
        "address_2": "miami  florida  33172",
        "country": "US"
    },
    "000F42": {
        "oui_hex": "00-0F-42",
        "organization": "Xalyo Systems",
        "address_1": "Grenier 9",
        "address_2": "Commugny  VD  1291",
        "country": "CH"
    },
    "000EA5": {
        "oui_hex": "00-0E-A5",
        "organization": "BLIP Systems",
        "address_1": "Haekken 2",
        "address_2": "Vodskov  Vester Hassing  9310",
        "country": "DK"
    },
    "000EA0": {
        "oui_hex": "00-0E-A0",
        "organization": "NetKlass Technology Inc.",
        "address_1": "2F-1, No.30,Tai Yuen Street,",
        "address_2": "Chupei City,  Hsinchu,  302",
        "country": "TW"
    },
    "000EE4": {
        "oui_hex": "00-0E-E4",
        "organization": "BOE TECHNOLOGY GROUP CO.,LTD",
        "address_1": "No.10 Jiuxianqiao Road,Chaoyang District,Beijing,PRC",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "000EDE": {
        "oui_hex": "00-0E-DE",
        "organization": "REMEC, Inc.",
        "address_1": "2144 Franklin Drive NE",
        "address_2": "Palm Bay  Florida  32905-4021",
        "country": "US"
    },
    "000E9C": {
        "oui_hex": "00-0E-9C",
        "organization": "Benchmark Electronics",
        "address_1": "3535 Technology Drive",
        "address_2": "Rochester  MN  55901",
        "country": "US"
    },
    "000E9A": {
        "oui_hex": "00-0E-9A",
        "organization": "BOE TECHNOLOGY GROUP CO.,LTD",
        "address_1": "No.10 Jiuxianqiao Road,Chaoyang District,Beijing,PRC",
        "address_2": "Beijing    100016",
        "country": "CN"
    },
    "000E90": {
        "oui_hex": "00-0E-90",
        "organization": "PONICO CORP.",
        "address_1": "602, Ace Twin Tower 1, 212-1 Guro-dong",
        "address_2": "Gurogu  Seoul  152-766",
        "country": "KR"
    },
    "000E8A": {
        "oui_hex": "00-0E-8A",
        "organization": "Avara Technologies Pty. Ltd.",
        "address_1": "9 Business Park Drive",
        "address_2": "Notting Hill  Victoria  3168",
        "country": "AU"
    },
    "000EB8": {
        "oui_hex": "00-0E-B8",
        "organization": "Iiga co.,Ltd",
        "address_1": "3F TKBldg. 3-5-2 Sotokanda",
        "address_2": "Chiyoda-Ku  Tokyo  101-0021",
        "country": "JP"
    },
    "000EBE": {
        "oui_hex": "00-0E-BE",
        "organization": "B&B Electronics Manufacturing Co.",
        "address_1": "707 Dayton Road",
        "address_2": "Ottawa  Ilinois  61350",
        "country": "US"
    },
    "000EBB": {
        "oui_hex": "00-0E-BB",
        "organization": "Everbee Networks",
        "address_1": "41, Boulevard des Capucines",
        "address_2": "Paris    75002",
        "country": "FR"
    },
    "000ECE": {
        "oui_hex": "00-0E-CE",
        "organization": "S.I.T.T.I. S.p.A.",
        "address_1": "Via Cadorna 69",
        "address_2": "Vimodrone  Milan  I-20090",
        "country": "IT"
    },
    "000ED4": {
        "oui_hex": "00-0E-D4",
        "organization": "CRESITT INDUSTRIE",
        "address_1": "12 rue de Blois",
        "address_2": "Orleans  BP 6744  45067  cedex",
        "country": "FR"
    },
    "000ED6": {
        "oui_hex": "00-0E-D6",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000ED8": {
        "oui_hex": "00-0E-D8",
        "organization": "Positron Access Solutions Corp",
        "address_1": "5101 Buchan Street",
        "address_2": "  Montreal, Quebec  H4P 2R9",
        "country": "CA"
    },
    "000ED1": {
        "oui_hex": "00-0E-D1",
        "organization": "Osaka Micro Computer.",
        "address_1": "Isonokamicyo 3-11-7",
        "address_2": "Kishiwada  Osaka  5960001",
        "country": "JP"
    },
    "000EB0": {
        "oui_hex": "00-0E-B0",
        "organization": "Solutions Radio BV",
        "address_1": "Prinsegracht 82",
        "address_2": "The Hague  ZH  2512 GC",
        "country": "NL"
    },
    "000E83": {
        "oui_hex": "00-0E-83",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E81": {
        "oui_hex": "00-0E-81",
        "organization": "Devicescape Software, Inc.",
        "address_1": "1000 Marina Blvd",
        "address_2": "Brisbane  CA  94005",
        "country": "US"
    },
    "000E88": {
        "oui_hex": "00-0E-88",
        "organization": "VIDEOTRON CORP.",
        "address_1": "17-16,2-CHOME",
        "address_2": "HACHIOJI  TOKYO  193-0835",
        "country": "JP"
    },
    "000E86": {
        "oui_hex": "00-0E-86",
        "organization": "Alcatel North America",
        "address_1": "2301 Sugar Bush Road",
        "address_2": "Raleigh  NC  27612",
        "country": "US"
    },
    "000E69": {
        "oui_hex": "00-0E-69",
        "organization": "China Electric Power Research Institute",
        "address_1": "No.15 Xiaoying East Road,Qinghe,Beijing,China",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "000E61": {
        "oui_hex": "00-0E-61",
        "organization": "MICROTROL LIMITED",
        "address_1": "16 ELGAR BUSINESS CENTRE",
        "address_2": "HALLOW  WORCESTER  WR2 6NJ",
        "country": "GB"
    },
    "000E64": {
        "oui_hex": "00-0E-64",
        "organization": "Elphel, Inc",
        "address_1": "3200 S. Elpmer St.",
        "address_2": "Magna  UT  84044",
        "country": "US"
    },
    "000E49": {
        "oui_hex": "00-0E-49",
        "organization": "Forsway Scandinavia AB",
        "address_1": "Kanikegränd 3B",
        "address_2": "541 34  Skövde",
        "country": "SE"
    },
    "000E42": {
        "oui_hex": "00-0E-42",
        "organization": "Motic Incoporation Ltd.",
        "address_1": "Room 2907-8, Windsor  House",
        "address_2": "Hong Kong",
        "country": "CN"
    },
    "000E3D": {
        "oui_hex": "00-0E-3D",
        "organization": "Televic N.V.",
        "address_1": "Leo Bekaertlaan 1",
        "address_2": "Izegem    8870",
        "country": "BE"
    },
    "000E39": {
        "oui_hex": "00-0E-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000E34": {
        "oui_hex": "00-0E-34",
        "organization": "NexGen City, LP",
        "address_1": "1680 Glenville",
        "address_2": "Richardson  Texas  75081",
        "country": "US"
    },
    "000E6A": {
        "oui_hex": "00-0E-6A",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "000E5A": {
        "oui_hex": "00-0E-5A",
        "organization": "TELEFIELD inc.",
        "address_1": "3F, Kumbo Bldg, 2-9, Seokchon-Dong",
        "address_2": "Seoul    138-190",
        "country": "KR"
    },
    "000E5D": {
        "oui_hex": "00-0E-5D",
        "organization": "Triple Play Technologies A/S",
        "address_1": "Herstedvang 8",
        "address_2": "Albertslund    DK-2620",
        "country": "DK"
    },
    "000E52": {
        "oui_hex": "00-0E-52",
        "organization": "Optium Corporation",
        "address_1": "500 Horizon Dr",
        "address_2": "Chalfont  PA  18914",
        "country": "US"
    },
    "000E7E": {
        "oui_hex": "00-0E-7E",
        "organization": "ionSign Oy",
        "address_1": "P.O.BOX  246",
        "address_2": "Rauma",
        "country": "FI"
    },
    "000E77": {
        "oui_hex": "00-0E-77",
        "organization": "Decru, Inc.",
        "address_1": "275 Shoreline Dr",
        "address_2": "Redwood City  CA  94065",
        "country": "US"
    },
    "000E4D": {
        "oui_hex": "00-0E-4D",
        "organization": "Numesa Inc.",
        "address_1": "4444 Westgrove Suite 300",
        "address_2": "Addison  TX  75001",
        "country": "US"
    },
    "000E4C": {
        "oui_hex": "00-0E-4C",
        "organization": "Bermai Inc.",
        "address_1": "410 Cambridge Ave",
        "address_2": "Palo Alto  CA  94306",
        "country": "US"
    },
    "000E2D": {
        "oui_hex": "00-0E-2D",
        "organization": "Hyundai Digital Technology Co.,Ltd.",
        "address_1": "223-22, Sangdaewon-1dong, Jungwon-gu",
        "address_2": "Seongnam-si  Kyoungki-do  462-807",
        "country": "KR"
    },
    "000E30": {
        "oui_hex": "00-0E-30",
        "organization": "AERAS Networks, Inc.",
        "address_1": "P.O. Box 7330",
        "address_2": "Laguna Niguel  CA  92607-7330",
        "country": "US"
    },
    "000E29": {
        "oui_hex": "00-0E-29",
        "organization": "Shester Communications Inc",
        "address_1": "159 S. Lincoln",
        "address_2": "Spokane  WA  99201",
        "country": "US"
    },
    "000DE1": {
        "oui_hex": "00-0D-E1",
        "organization": "Control Products, Inc.",
        "address_1": "1724 Lake Drive West",
        "address_2": "Chanhassen  MN  55317",
        "country": "US"
    },
    "000DD0": {
        "oui_hex": "00-0D-D0",
        "organization": "TetraTec Instruments GmbH",
        "address_1": "Gewerbestrasse 8",
        "address_2": "Steinenbronn  BW  71144",
        "country": "DE"
    },
    "000DD3": {
        "oui_hex": "00-0D-D3",
        "organization": "SAMWOO Telecommunication Co.,Ltd.",
        "address_1": "",
        "address_2": "Gunpo  Kyoung-Gi  435-831",
        "country": "KR"
    },
    "000DD8": {
        "oui_hex": "00-0D-D8",
        "organization": "BBN",
        "address_1": "7F-3,NO.186, Jian Yi Rd ., Chung Ho City",
        "address_2": "Taipei    235",
        "country": "TW"
    },
    "000DB3": {
        "oui_hex": "00-0D-B3",
        "organization": "SDO Communication Corperation",
        "address_1": "6F, No.112, Shin Min Street",
        "address_2": "Chung Ho City  Taipei Hsien  235",
        "country": "TW"
    },
    "000DAE": {
        "oui_hex": "00-0D-AE",
        "organization": "SAMSUNG HEAVY INDUSTRIES CO., LTD.",
        "address_1": "493, Banweol-Ri, Taean-Eup",
        "address_2": "Hwaseong-City  Kyeonggi-Do  445-973",
        "country": "KR"
    },
    "000DB2": {
        "oui_hex": "00-0D-B2",
        "organization": "Ammasso, Inc.",
        "address_1": "345 Summer Street",
        "address_2": "Boston  MA  02210",
        "country": "US"
    },
    "000E0D": {
        "oui_hex": "00-0E-0D",
        "organization": "Hesch Schröder GmbH",
        "address_1": "Boschstraße 8",
        "address_2": "Neustadt  Niedersachsen  31535",
        "country": "DE"
    },
    "000DF6": {
        "oui_hex": "00-0D-F6",
        "organization": "Technology Thesaurus Corp.",
        "address_1": "NO. 6, East 4th St. KEPZ",
        "address_2": "KAOHSIUNG    806",
        "country": "TW"
    },
    "000DFF": {
        "oui_hex": "00-0D-FF",
        "organization": "CHENMING MOLD INDUSTRY CORP.",
        "address_1": "2F No. 26, Lane 513, Rei Kuang Rd.",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000DC7": {
        "oui_hex": "00-0D-C7",
        "organization": "COSMIC ENGINEERING INC.",
        "address_1": "1-3-5, Nishihirayama",
        "address_2": "Hino-shi  TOKYO  191-0055",
        "country": "JP"
    },
    "000DC2": {
        "oui_hex": "00-0D-C2",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000DBF": {
        "oui_hex": "00-0D-BF",
        "organization": "TekTone Sound & Signal Mfg., Inc.",
        "address_1": "277 Industrial Park Rd.",
        "address_2": "Franklin  NC  28734",
        "country": "US"
    },
    "000E19": {
        "oui_hex": "00-0E-19",
        "organization": "LogicaCMG Pty Ltd",
        "address_1": "17-19 Orion Road",
        "address_2": "Lane Cove  NSW  2066",
        "country": "AU"
    },
    "000E1A": {
        "oui_hex": "00-0E-1A",
        "organization": "JPS Communications",
        "address_1": "5800 Departure Drive",
        "address_2": "Raleigh  NC  27616",
        "country": "US"
    },
    "000E06": {
        "oui_hex": "00-0E-06",
        "organization": "Team Simoco Ltd",
        "address_1": "Field House",
        "address_2": "Derby  Derbyshire  DE1 1NH",
        "country": "GB"
    },
    "000D5C": {
        "oui_hex": "00-0D-5C",
        "organization": "Robert Bosch GmbH, VT-ATMO",
        "address_1": "Wernerstrasse 51",
        "address_2": "Stuttgart  BW  70469",
        "country": "DE"
    },
    "000D60": {
        "oui_hex": "00-0D-60",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "000D67": {
        "oui_hex": "00-0D-67",
        "organization": "Ericsson",
        "address_1": "349 Terry Fox Drive",
        "address_2": "Kanata  Ottawa  K2K 2V6",
        "country": "CA"
    },
    "000D5F": {
        "oui_hex": "00-0D-5F",
        "organization": "Minds Inc",
        "address_1": "1919 boul lionel bertrand",
        "address_2": "Boisbriand  Quebec  J7H 1N8",
        "country": "CA"
    },
    "000D9C": {
        "oui_hex": "00-0D-9C",
        "organization": "Elan GmbH & Co KG",
        "address_1": "Im Ostpark 2",
        "address_2": "Wettenberg  Hessen  35435",
        "country": "DE"
    },
    "000D98": {
        "oui_hex": "00-0D-98",
        "organization": "S.W.A.C. Schmitt-Walter Automation Consult GmbH",
        "address_1": "Oedenpullach 1",
        "address_2": "Oberhaching  Bavaria  82041",
        "country": "DE"
    },
    "000D8C": {
        "oui_hex": "00-0D-8C",
        "organization": "Shanghai Wedone Digital Ltd. CO.",
        "address_1": "893-899 Huashan Road,",
        "address_2": "Shanghai    200031",
        "country": "CN"
    },
    "000D94": {
        "oui_hex": "00-0D-94",
        "organization": "AFAR Communications,Inc",
        "address_1": "81 David Love Place",
        "address_2": "Santa Barbara  CA  93117",
        "country": "US"
    },
    "000DAA": {
        "oui_hex": "00-0D-AA",
        "organization": "S.A.Tehnology co.,Ltd.",
        "address_1": "80-12 Yangjae 1 Dong",
        "address_2": "Seoul  South Korea  137-890",
        "country": "KR"
    },
    "000DA6": {
        "oui_hex": "00-0D-A6",
        "organization": "Universal Switching Corporation",
        "address_1": "7671 San Fernando Rd",
        "address_2": "Burbank  CA  91505-1073",
        "country": "US"
    },
    "000D8D": {
        "oui_hex": "00-0D-8D",
        "organization": "Prosoft Technology, Inc",
        "address_1": "5201 Truxtun Ave",
        "address_2": "Bakersfield  CA  93300",
        "country": "US"
    },
    "000D84": {
        "oui_hex": "00-0D-84",
        "organization": "Makus Inc.",
        "address_1": "4F Daedo Bldg., 748-14 Yeoksam-dong",
        "address_2": "Kangnam-gu  Seoul  135-080",
        "country": "KR"
    },
    "000D73": {
        "oui_hex": "00-0D-73",
        "organization": "Technical Support, Inc.",
        "address_1": "11253 John Galt Blvd",
        "address_2": "Omaha  Nebraska  68137",
        "country": "US"
    },
    "000D69": {
        "oui_hex": "00-0D-69",
        "organization": "TMT&D Corporation",
        "address_1": "2-24-1",
        "address_2": "Fuchu-si  Tokyo  183-0057",
        "country": "JP"
    },
    "000DA2": {
        "oui_hex": "00-0D-A2",
        "organization": "Infrant Technologies, Inc.",
        "address_1": "48820 Kato Road",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000D68": {
        "oui_hex": "00-0D-68",
        "organization": "Vinci Systems, Inc.",
        "address_1": "8330 Boone Boulevard",
        "address_2": "Vienna  VA  22182",
        "country": "US"
    },
    "000D64": {
        "oui_hex": "00-0D-64",
        "organization": "COMAG Handels AG",
        "address_1": "Zillenhardtstraße 41",
        "address_2": "Goeppingen  Baden-Württemberg  73037",
        "country": "DE"
    },
    "000D74": {
        "oui_hex": "00-0D-74",
        "organization": "Sand Network Systems, Inc.",
        "address_1": "434 Payran Street, Suite B",
        "address_2": "Petaluma  CA  94952",
        "country": "US"
    },
    "000D7D": {
        "oui_hex": "00-0D-7D",
        "organization": "Afco Systems",
        "address_1": "200 Finn Court",
        "address_2": "Farmingdale  NY  11735",
        "country": "US"
    },
    "000D54": {
        "oui_hex": "00-0D-54",
        "organization": "3Com Ltd",
        "address_1": "Peoplebuilding 2",
        "address_2": "Hemel Hempstead  Herts  HP2 4NW",
        "country": "GB"
    },
    "000D4C": {
        "oui_hex": "00-0D-4C",
        "organization": "Outline Electronics Ltd.",
        "address_1": "7/F Benson Tower",
        "address_2": "Kwun Tong  Kowloon",
        "country": "HK"
    },
    "000D0F": {
        "oui_hex": "00-0D-0F",
        "organization": "Finlux Ltd",
        "address_1": "Radiomiehenkatu 3",
        "address_2": "Turku    FIN-20321",
        "country": "FI"
    },
    "000D12": {
        "oui_hex": "00-0D-12",
        "organization": "AXELL Corporation",
        "address_1": "Akihabara UDX South Wing 10F",
        "address_2": "Chiyoda-ku  Tokyo  101-8973",
        "country": "JP"
    },
    "000D34": {
        "oui_hex": "00-0D-34",
        "organization": "Shell International Exploration and Production, Inc.",
        "address_1": "BTC-Gasmer",
        "address_2": "Houston  TX  77001",
        "country": "US"
    },
    "000D32": {
        "oui_hex": "00-0D-32",
        "organization": "DispenseSource, Inc.",
        "address_1": "29801 Santa Margarita Parkway",
        "address_2": "Rancho Santa Margarita  CA  92688",
        "country": "US"
    },
    "000CF6": {
        "oui_hex": "00-0C-F6",
        "organization": "Sitecom Europe BV",
        "address_1": "Sevillaweg 122",
        "address_2": "Rotterdam  ZH  3047 AL",
        "country": "NL"
    },
    "000CF2": {
        "oui_hex": "00-0C-F2",
        "organization": "GAMESA Eólica",
        "address_1": "Polígono Agustinos. C/ A s/n.",
        "address_2": "Pamplona  NAVARRA  31013",
        "country": "ES"
    },
    "000D2E": {
        "oui_hex": "00-0D-2E",
        "organization": "Matsushita Avionics Systems Corporation",
        "address_1": "26200 Enterprise Way",
        "address_2": "Lake Forest  CA  92630",
        "country": "US"
    },
    "000D28": {
        "oui_hex": "00-0D-28",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000D4D": {
        "oui_hex": "00-0D-4D",
        "organization": "Ninelanes",
        "address_1": "#405 4F Diplomatic Center",
        "address_2": "Seoul    1376-1",
        "country": "KR"
    },
    "000D53": {
        "oui_hex": "00-0D-53",
        "organization": "Beijing 5w Communication Corp.",
        "address_1": "NO.4,Zhong-Guan-Cun South 4 street,",
        "address_2": "Beijing    100080",
        "country": "CN"
    },
    "000CFC": {
        "oui_hex": "00-0C-FC",
        "organization": "S2io Technologies Corp",
        "address_1": "505 March Rd",
        "address_2": "Ottawa  Ontario  K2K 2M5",
        "country": "CA"
    },
    "000D38": {
        "oui_hex": "00-0D-38",
        "organization": "NISSIN INC.",
        "address_1": "10-7 KAMEI-CHO",
        "address_2": "TAKARAZUKA  HYOGO  665-0047",
        "country": "JP"
    },
    "000D15": {
        "oui_hex": "00-0D-15",
        "organization": "Voipac s.r.o.",
        "address_1": "Ul. Janka Krala 3",
        "address_2": "Trencin    911 01",
        "country": "SK"
    },
    "000CA1": {
        "oui_hex": "00-0C-A1",
        "organization": "SIGMACOM Co., LTD.",
        "address_1": "DacomBldg 7F 200-12 Anyang-dong",
        "address_2": "    430-817",
        "country": "KR"
    },
    "000CA6": {
        "oui_hex": "00-0C-A6",
        "organization": "Mintera Corporation",
        "address_1": "847 Rogers Street",
        "address_2": "Lowell  MA  01852",
        "country": "US"
    },
    "000CC1": {
        "oui_hex": "00-0C-C1",
        "organization": "Eaton Corporation",
        "address_1": "2300 Badger Drive",
        "address_2": "Waukesha  WI  53188",
        "country": "US"
    },
    "000C8B": {
        "oui_hex": "00-0C-8B",
        "organization": "Connect Tech Inc",
        "address_1": "42 Arrow Road",
        "address_2": "Guelph  Ontario  N1K 1S6",
        "country": "CA"
    },
    "000C90": {
        "oui_hex": "00-0C-90",
        "organization": "Octasic Inc.",
        "address_1": "4101 Molson St.",
        "address_2": "Montreal  Quebec  H1Y 3L1",
        "country": "CA"
    },
    "000C8C": {
        "oui_hex": "00-0C-8C",
        "organization": "KODICOM CO.,LTD.",
        "address_1": "A-Dong 5FI.,SK Twin Tower 345-9,",
        "address_2": "Seoul    153-023",
        "country": "KR"
    },
    "000CC2": {
        "oui_hex": "00-0C-C2",
        "organization": "ControlNet (India) Private Limited",
        "address_1": "L-44, Unit - I",
        "address_2": "Verna, Salcete  Goa  403 722",
        "country": "IN"
    },
    "000C94": {
        "oui_hex": "00-0C-94",
        "organization": "United Electronic Industries, Inc. (EUI)",
        "address_1": "27 Renmar Ave",
        "address_2": "Walpole  MA  02081",
        "country": "US"
    },
    "000C9B": {
        "oui_hex": "00-0C-9B",
        "organization": "EE Solutions, Inc",
        "address_1": "8F, No. 9, Park II Ave., Science-Based I",
        "address_2": "Hsin Chu    300",
        "country": "TW"
    },
    "000CE1": {
        "oui_hex": "00-0C-E1",
        "organization": "The Open Group",
        "address_1": "Apex Plaza",
        "address_2": "Reading  Berks  RG1 1AX",
        "country": "GB"
    },
    "000CDC": {
        "oui_hex": "00-0C-DC",
        "organization": "BECS Technology, Inc",
        "address_1": "9487 Dielman Rock Island Industrial Driv",
        "address_2": "St. Louis  MO  63132",
        "country": "US"
    },
    "000CC5": {
        "oui_hex": "00-0C-C5",
        "organization": "Nextlink Co., Ltd.",
        "address_1": "C 605, Technopark #145 Yatop-dong,",
        "address_2": "Seongnam-si  Bundang-gu, Gyeonggi  463-760",
        "country": "KR"
    },
    "000CDE": {
        "oui_hex": "00-0C-DE",
        "organization": "ABB STOTZ-KONTAKT GmbH",
        "address_1": "Eppelheimer Straße 82",
        "address_2": "Heidelberg  Baden-Württemberg  69123",
        "country": "DE"
    },
    "000CBF": {
        "oui_hex": "00-0C-BF",
        "organization": "Holy Stone Ent. Co., Ltd.",
        "address_1": "1F, No.62, Sec.2, Huang Shan Rd.,",
        "address_2": "Taipei    114",
        "country": "US"
    },
    "000C4D": {
        "oui_hex": "00-0C-4D",
        "organization": "Curtiss-Wright Controls Avionics & Electronics",
        "address_1": "Landscape House,",
        "address_2": "Churchtown,  Dublin  14",
        "country": "IE"
    },
    "000C44": {
        "oui_hex": "00-0C-44",
        "organization": "Automated Interfaces, Inc.",
        "address_1": "120 Confederate Lane",
        "address_2": "Greer  South Carolina  29651",
        "country": "US"
    },
    "000C3B": {
        "oui_hex": "00-0C-3B",
        "organization": "Orion Electric Co., Ltd.",
        "address_1": "41-1, Iehisa-cho",
        "address_2": "Takefu-shi  Fukui  915-8555",
        "country": "JP"
    },
    "000C71": {
        "oui_hex": "00-0C-71",
        "organization": "Wybron, Inc",
        "address_1": "4830 LIst Dr",
        "address_2": "Colorado Springs  Colorado  80919",
        "country": "US"
    },
    "000C72": {
        "oui_hex": "00-0C-72",
        "organization": "Tempearl Industrial Co., Ltd.",
        "address_1": "3-1-42 Ohzu",
        "address_2": "Hiroshima-shi  Hiroshima  732-0802",
        "country": "JP"
    },
    "000C78": {
        "oui_hex": "00-0C-78",
        "organization": "In-Tech Electronics Limited",
        "address_1": "Unit A, 13th Floor., Wing Tai Centre",
        "address_2": "Kwun Tong  Kowloon",
        "country": "HK"
    },
    "000C59": {
        "oui_hex": "00-0C-59",
        "organization": "Indyme Electronics, Inc.",
        "address_1": "9085 Aero Dr.",
        "address_2": "San Diego  CA  92123",
        "country": "US"
    },
    "000C5C": {
        "oui_hex": "00-0C-5C",
        "organization": "GTN Systems B.V.",
        "address_1": "Postbus 12236",
        "address_2": "Amsterdam",
        "country": "NL"
    },
    "000C55": {
        "oui_hex": "00-0C-55",
        "organization": "Microlink Communications Inc.",
        "address_1": "8F, 31, Hsintai Road",
        "address_2": "Hsinchu    302",
        "country": "TW"
    },
    "000C52": {
        "oui_hex": "00-0C-52",
        "organization": "Roll Systems Inc.",
        "address_1": "53 Third Avenue",
        "address_2": "Burlington  MA  01803",
        "country": "US"
    },
    "000C74": {
        "oui_hex": "00-0C-74",
        "organization": "RIVERTEC CORPORATION",
        "address_1": "882-5 MIYAGASAKI",
        "address_2": "IMABARI  EHIME  799-1537",
        "country": "JP"
    },
    "000C67": {
        "oui_hex": "00-0C-67",
        "organization": "OYO ELECTRIC CO.,LTD",
        "address_1": "63-1 Nakamichi Omote",
        "address_2": "Joyo  Kyoto  610-0101",
        "country": "JP"
    },
    "000C2E": {
        "oui_hex": "00-0C-2E",
        "organization": "Openet information technology(shenzhen) Co., Ltd.",
        "address_1": "2/F,A tower,international tech-innovatio",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "000C2C": {
        "oui_hex": "00-0C-2C",
        "organization": "Enwiser Inc.",
        "address_1": "4F, Cheongseok B/D",
        "address_2": "Seoul  Seoul  135-010",
        "country": "KR"
    },
    "000C28": {
        "oui_hex": "00-0C-28",
        "organization": "RIFATRON",
        "address_1": "9th FL, SHINTAEYANG BLDG",
        "address_2": "SEOUL  SEOCHO-GU  137-041",
        "country": "KR"
    },
    "000C3D": {
        "oui_hex": "00-0C-3D",
        "organization": "Glsystech Co., Ltd.",
        "address_1": "Song Bo B/D 3F",
        "address_2": "Seoul",
        "country": "KR"
    },
    "000C2F": {
        "oui_hex": "00-0C-2F",
        "organization": "SeorimTechnology Co.,Ltd.",
        "address_1": "2F DIPLOMATIC CENTER B/D 1376-1 SEOCHO2-",
        "address_2": "SEOUL    137-072",
        "country": "US"
    },
    "000C31": {
        "oui_hex": "00-0C-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000C53": {
        "oui_hex": "00-0C-53",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "000C48": {
        "oui_hex": "00-0C-48",
        "organization": "QoStek Corporation",
        "address_1": "7F, 22, Taiyuen Street",
        "address_2": "Chupei  Hsinchu Hsien  302",
        "country": "TW"
    },
    "000C63": {
        "oui_hex": "00-0C-63",
        "organization": "Zenith Electronics Corporation",
        "address_1": "2000 Millbrook Drive",
        "address_2": "Lincolnshire  Illinois  60069",
        "country": "US"
    },
    "000BBB": {
        "oui_hex": "00-0B-BB",
        "organization": "Etin Systems Co., Ltd",
        "address_1": "12F, IT Venture Tower,",
        "address_2": "Seoul    138-803",
        "country": "KR"
    },
    "000BBC": {
        "oui_hex": "00-0B-BC",
        "organization": "En Garde Systems, Inc.",
        "address_1": "2101 White Cloud St. NE",
        "address_2": "Albuquerque  NM  87112",
        "country": "US"
    },
    "000BB1": {
        "oui_hex": "00-0B-B1",
        "organization": "Super Star Technology Co., Ltd.",
        "address_1": "No. 7 Lane 306,Sec. 2,Tai-Lin Rd.",
        "address_2": "Taipei Hsien    243",
        "country": "US"
    },
    "000BBF": {
        "oui_hex": "00-0B-BF",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000BAD": {
        "oui_hex": "00-0B-AD",
        "organization": "PC-PoS Inc.",
        "address_1": "309 Commissioners Road West",
        "address_2": "London  Ontario  N6J 1Y4",
        "country": "CA"
    },
    "000BA0": {
        "oui_hex": "00-0B-A0",
        "organization": "T&L Information Inc.",
        "address_1": "898-44 Hokye-Dong, Dongan-Gu",
        "address_2": "Anyang  Kyungki-Do  431-836",
        "country": "KR"
    },
    "000C17": {
        "oui_hex": "00-0C-17",
        "organization": "AJA Video Systems Inc",
        "address_1": "180 Litton Drive",
        "address_2": "Grass Valley  CA  95945",
        "country": "US"
    },
    "000C11": {
        "oui_hex": "00-0C-11",
        "organization": "NIPPON DEMPA CO.,LTD.",
        "address_1": "1-4-8",
        "address_2": "kakegawa city  shizuoka pref.  436-0028",
        "country": "JP"
    },
    "000C14": {
        "oui_hex": "00-0C-14",
        "organization": "Diagnostic Instruments, Inc.",
        "address_1": "6540 Burroughs",
        "address_2": "Sterling Heights  MI  48314",
        "country": "US"
    },
    "000BB5": {
        "oui_hex": "00-0B-B5",
        "organization": "nStor Technologies, Inc.",
        "address_1": "100 Technology Park",
        "address_2": "Lake Mary  FL  32746",
        "country": "US"
    },
    "000BB9": {
        "oui_hex": "00-0B-B9",
        "organization": "Imsys AB",
        "address_1": "Johanneslundsvagen 3",
        "address_2": "Upplands Vasby    SE-19461",
        "country": "SE"
    },
    "000C21": {
        "oui_hex": "00-0C-21",
        "organization": "Faculty of Science and Technology, Keio University",
        "address_1": "3-14-1 Hiyoshi, Kohoku-ku",
        "address_2": "Yokohama  Kanagawa  223-8522",
        "country": "JP"
    },
    "000C1B": {
        "oui_hex": "00-0C-1B",
        "organization": "ORACOM Co, Ltd.",
        "address_1": "3rd Fl, A-Sung Bldg, 999-3",
        "address_2": "Seoul    135-280",
        "country": "KR"
    },
    "000BC9": {
        "oui_hex": "00-0B-C9",
        "organization": "Electroline Equipment",
        "address_1": "8265 boul. St-Michel",
        "address_2": "Montreal  Quebec  H1Z 3E4",
        "country": "CA"
    },
    "000BC2": {
        "oui_hex": "00-0B-C2",
        "organization": "Corinex Communication Corp.",
        "address_1": "#308 1168 Hamilton Street",
        "address_2": "Vancouver  B.C.  V6B 2S2",
        "country": "US"
    },
    "000BF7": {
        "oui_hex": "00-0B-F7",
        "organization": "NIDEK CO.,LTD",
        "address_1": "34-14 Maehama",
        "address_2": "Gamagori  Aich  443-0038",
        "country": "JP"
    },
    "000C00": {
        "oui_hex": "00-0C-00",
        "organization": "BEB Industrie-Elektronik AG",
        "address_1": "Progressastrasse 31",
        "address_2": "Oberburg  BE  3414",
        "country": "CH"
    },
    "000BF3": {
        "oui_hex": "00-0B-F3",
        "organization": "BAE SYSTEMS",
        "address_1": "6500 Tracor Lane",
        "address_2": "Austin  Texas  78725",
        "country": "US"
    },
    "000BED": {
        "oui_hex": "00-0B-ED",
        "organization": "ELM Inc.",
        "address_1": "2398 Kasedamiyahara",
        "address_2": "Minamisatsuma  Kagoshima  897-1124",
        "country": "JP"
    },
    "000B91": {
        "oui_hex": "00-0B-91",
        "organization": "Aglaia Gesellschaft für Bildverarbeitung und Kommunikation mbH",
        "address_1": "Tiniusstraße 12-15",
        "address_2": "Berlin    D-13089",
        "country": "DE"
    },
    "000B97": {
        "oui_hex": "00-0B-97",
        "organization": "Matsushita Electric Industrial Co.,Ltd.",
        "address_1": "3-1-1 Yagumo-Naka-Machi",
        "address_2": "Moriguchi City  Osaka  570-8501",
        "country": "JP"
    },
    "000B92": {
        "oui_hex": "00-0B-92",
        "organization": "Ascom Danmark A/S",
        "address_1": "Fabriksparken 42",
        "address_2": "Glostrup  Denmark  2600",
        "country": "DK"
    },
    "000B9A": {
        "oui_hex": "00-0B-9A",
        "organization": "Shanghai Ulink Telecom Equipment Co. Ltd.",
        "address_1": "6 Floor, Building 3",
        "address_2": "Shanghai    200083",
        "country": "CN"
    },
    "000B9D": {
        "oui_hex": "00-0B-9D",
        "organization": "TwinMOS Technologies Inc.",
        "address_1": "303 No.3, Tzu Chiang Rd., Hu Kou Xiang,",
        "address_2": "Hsin Chu    303",
        "country": "TW"
    },
    "000B96": {
        "oui_hex": "00-0B-96",
        "organization": "Innotrac Diagnostics Oy",
        "address_1": "Kalevantie 25",
        "address_2": "Turku  Åbo  20520",
        "country": "FI"
    },
    "000B56": {
        "oui_hex": "00-0B-56",
        "organization": "Cybernetics",
        "address_1": "111 Cybernetics Way STE 300",
        "address_2": "Yorktown  VA  23693",
        "country": "US"
    },
    "000B50": {
        "oui_hex": "00-0B-50",
        "organization": "Oxygnet",
        "address_1": "402 E. Carrillo St.",
        "address_2": "Santa Barbara  CA  93101",
        "country": "US"
    },
    "000B52": {
        "oui_hex": "00-0B-52",
        "organization": "JOYMAX ELECTRONICS CO. LTD.",
        "address_1": "No.5 Dong-Yuan Road 2, Jhong-Li Industrial Park,",
        "address_2": "Tao-Yuan    32063",
        "country": "TW"
    },
    "000B69": {
        "oui_hex": "00-0B-69",
        "organization": "Franke Finland Oy",
        "address_1": "Vartiokuja 1",
        "address_2": "NAARAJARVI    FIN-76850",
        "country": "FI"
    },
    "000BA5": {
        "oui_hex": "00-0B-A5",
        "organization": "Quasar Cipta Mandiri, PT",
        "address_1": "Jl. Palasari 9A",
        "address_2": "Bandung  West Java  40262",
        "country": "ID"
    },
    "000B49": {
        "oui_hex": "00-0B-49",
        "organization": "RF-Link System Inc.",
        "address_1": "No.6, Nan-Ke 5th Rd., Hsin-Shi,",
        "address_2": "Tainan County    744",
        "country": "TW"
    },
    "000B46": {
        "oui_hex": "00-0B-46",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000B7A": {
        "oui_hex": "00-0B-7A",
        "organization": "L-3 Linkabit",
        "address_1": "9890 Town Center Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000B84": {
        "oui_hex": "00-0B-84",
        "organization": "BODET",
        "address_1": "Route de la Tourlandry",
        "address_2": "TREMENTINES  FRANCE  49340",
        "country": "FR"
    },
    "000B77": {
        "oui_hex": "00-0B-77",
        "organization": "Cogent Systems, Inc.",
        "address_1": "209 Fair Oaks Ave.",
        "address_2": "South Pasadena  CA  91030",
        "country": "US"
    },
    "000B66": {
        "oui_hex": "00-0B-66",
        "organization": "Teralink Communications",
        "address_1": "Capital Tower 15F,",
        "address_2": "Daejeon    302120",
        "country": "KR"
    },
    "000B2C": {
        "oui_hex": "00-0B-2C",
        "organization": "Eiki Industrial Co. Ltd.",
        "address_1": "4-12 Manzai-cho, Kita-ku",
        "address_2": "Osaka    530",
        "country": "JP"
    },
    "000B26": {
        "oui_hex": "00-0B-26",
        "organization": "Wetek Corporation",
        "address_1": "4F, NO.17, Kuanfu N. Road",
        "address_2": "Hsin Chu Industrial Park    303",
        "country": "TW"
    },
    "000B28": {
        "oui_hex": "00-0B-28",
        "organization": "Quatech Inc.",
        "address_1": "662 Wolf Ledges Pkwy.",
        "address_2": "Akron  OH  44311",
        "country": "US"
    },
    "000B2A": {
        "oui_hex": "00-0B-2A",
        "organization": "HOWTEL Co., Ltd.",
        "address_1": "J-COM Bd. 4F, 124-4 OJEON-DONG",
        "address_2": "UIWANG-SHI  KYOUNGGI-DO  437-070",
        "country": "KR"
    },
    "000B30": {
        "oui_hex": "00-0B-30",
        "organization": "Beijing Gongye Science & Technology Co.,Ltd",
        "address_1": "Unit D.17/E,Shenlanhuating mid Road No.6",
        "address_2": "Beijing    100029",
        "country": "CN"
    },
    "000AF2": {
        "oui_hex": "00-0A-F2",
        "organization": "NeoAxiom Corp.",
        "address_1": "1520 Montague Expressway",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000AF5": {
        "oui_hex": "00-0A-F5",
        "organization": "Airgo Networks, Inc.",
        "address_1": "900 Arastradero Rd",
        "address_2": "Palo Alto  CA  94304",
        "country": "US"
    },
    "000AF0": {
        "oui_hex": "00-0A-F0",
        "organization": "SHIN-OH ELECTRONICS CO., LTD. R&D",
        "address_1": "#729-5, Bonoh-Dong, Ansan-City, Kyunggi-",
        "address_2": "Ansan-City  Kyunggi-Do  425-180",
        "country": "KR"
    },
    "000AF4": {
        "oui_hex": "00-0A-F4",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000AEE": {
        "oui_hex": "00-0A-EE",
        "organization": "GCD Hard- & Software GmbH",
        "address_1": "Henkestraße 79",
        "address_2": "Erlangen  Bayern  91052",
        "country": "DE"
    },
    "000AD8": {
        "oui_hex": "00-0A-D8",
        "organization": "IPCserv Technology Corp.",
        "address_1": "6f,No.107,Pan-Hsin Rd",
        "address_2": "Pan-Chiao  Taipei  22046",
        "country": "TW"
    },
    "000AD7": {
        "oui_hex": "00-0A-D7",
        "organization": "Origin ELECTRIC CO.,LTD.",
        "address_1": "1-18-1",
        "address_2": "TOSHIMA WARD  TOKYO MET.  171-8555",
        "country": "JP"
    },
    "000B38": {
        "oui_hex": "00-0B-38",
        "organization": "Knürr GmbH",
        "address_1": "Mariakirchener Straße 38",
        "address_2": "Arnstorf  Bavaria  94424",
        "country": "DE"
    },
    "000B32": {
        "oui_hex": "00-0B-32",
        "organization": "VORMETRIC, INC.",
        "address_1": "2060 CORPORATE CT",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "000B07": {
        "oui_hex": "00-0B-07",
        "organization": "Voxpath Networks",
        "address_1": "7600B Capital of Texas Highway  - North",
        "address_2": "Austin  Texas  78731",
        "country": "US"
    },
    "000B04": {
        "oui_hex": "00-0B-04",
        "organization": "Volktek Corporation",
        "address_1": "4F., No.192, Lian-Chang Road, Chang-Ho",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000AF9": {
        "oui_hex": "00-0A-F9",
        "organization": "HiConnect, Inc.",
        "address_1": "Rm #906, Haksan Cosmostel, 110",
        "address_2": "Kwangjin-Gu  Seoul  143-802",
        "country": "KR"
    },
    "000B1F": {
        "oui_hex": "00-0B-1F",
        "organization": "I CON Computer Co.",
        "address_1": "3F, No. 142 , Hsin Ming Road",
        "address_2": "Neihu  Taipei  114",
        "country": "TW"
    },
    "000B13": {
        "oui_hex": "00-0B-13",
        "organization": "ZETRON INC",
        "address_1": "PO Box 97004",
        "address_2": "REDMOND  WA  98073",
        "country": "US"
    },
    "000B10": {
        "oui_hex": "00-0B-10",
        "organization": "11wave Technonlogy Co.,Ltd",
        "address_1": "10F,no.285 sec.2 ,Ti-Ding Ave,NaiHu.Taip",
        "address_2": "Taipei    114",
        "country": "TW"
    },
    "000AE9": {
        "oui_hex": "00-0A-E9",
        "organization": "AirVast Technology Inc.",
        "address_1": "3F.-5, No.6, Lane 609, Sec. 5, Chongsin Rd.",
        "address_2": "Sanchong City  Taipei  241",
        "country": "TW"
    },
    "000B2B": {
        "oui_hex": "00-0B-2B",
        "organization": "HOSTNET CORPORATION",
        "address_1": "10F-12,No. 12 Lane 609, Sec.5,Chunghsin",
        "address_2": "Sanchung  Taipei Hsien  241",
        "country": "TW"
    },
    "000B02": {
        "oui_hex": "00-0B-02",
        "organization": "Dallmeier electronic",
        "address_1": "Würzburgerstraße 5",
        "address_2": "Regensburg  Bavaria  93059",
        "country": "DE"
    },
    "000ACD": {
        "oui_hex": "00-0A-CD",
        "organization": "Sunrich Technology Limited",
        "address_1": "Unit 1301, Eastern Centre, 1065 King's R",
        "address_2": "Quarry Bay",
        "country": "HK"
    },
    "000ACC": {
        "oui_hex": "00-0A-CC",
        "organization": "Winnow Networks, Inc.",
        "address_1": "701 Emerson Road",
        "address_2": "St. Louis  MO  63141",
        "country": "US"
    },
    "000ACF": {
        "oui_hex": "00-0A-CF",
        "organization": "PROVIDEO Multimedia Co. Ltd.",
        "address_1": "5F, NO.8, ALLEY 2, TZU-WEI LANE,",
        "address_2": "HSIN TIEN CITY  TAIPEI HSIEN,  231",
        "country": "TW"
    },
    "000AD1": {
        "oui_hex": "00-0A-D1",
        "organization": "MWS",
        "address_1": "12, quai Papacino",
        "address_2": "NICE    06300",
        "country": "FR"
    },
    "000A7D": {
        "oui_hex": "00-0A-7D",
        "organization": "Valo, Inc.",
        "address_1": "1351 Redwood Way",
        "address_2": "Petaluma  CA  94954",
        "country": "US"
    },
    "000A7F": {
        "oui_hex": "00-0A-7F",
        "organization": "Teradon Industries, Inc",
        "address_1": "7500 2nd ST NW",
        "address_2": "Albuquerque  NM  87120",
        "country": "US"
    },
    "000A81": {
        "oui_hex": "00-0A-81",
        "organization": "TEIMA Audiotex S.L.",
        "address_1": "C/ Tirvia, 6, local B",
        "address_2": "Madrid    28040",
        "country": "ES"
    },
    "000A87": {
        "oui_hex": "00-0A-87",
        "organization": "Integrated Micromachines Inc.",
        "address_1": "1400 S. Shamrock Ave.",
        "address_2": "Monrovia  CA  91016",
        "country": "US"
    },
    "000A77": {
        "oui_hex": "00-0A-77",
        "organization": "Bluewire Technologies LLC",
        "address_1": "420 N. O St.",
        "address_2": "Tulare  Ca  93274",
        "country": "US"
    },
    "000A8C": {
        "oui_hex": "00-0A-8C",
        "organization": "Guardware Systems Ltd.",
        "address_1": "Ulloi ut 102.",
        "address_2": "Budapest    H-1089",
        "country": "HU"
    },
    "000A96": {
        "oui_hex": "00-0A-96",
        "organization": "MEWTEL TECHNOLOGY INC.",
        "address_1": "E15FL. IT VENTURE TOWER",
        "address_2": "SEOUL    138-803",
        "country": "KR"
    },
    "000A82": {
        "oui_hex": "00-0A-82",
        "organization": "TATSUTA SYSTEM ELECTRONICS CO.,LTD.",
        "address_1": "IWATATYOU2-3-1",
        "address_2": "HIGASHIOOSAKA-SHI  OOSAKA-FU  578-8585",
        "country": "JP"
    },
    "000AD3": {
        "oui_hex": "00-0A-D3",
        "organization": "INITECH Co., Ltd",
        "address_1": "3F, INITECH Bldg, 559-5,",
        "address_2": "Seoul  Songpa  138-816",
        "country": "KR"
    },
    "000AC8": {
        "oui_hex": "00-0A-C8",
        "organization": "ZPSYS CO.,LTD. (Planning&Management)",
        "address_1": "106 Ace Techno Tower1",
        "address_2": "Seoul    152-050",
        "country": "KR"
    },
    "000AC6": {
        "oui_hex": "00-0A-C6",
        "organization": "Overture Networks.",
        "address_1": "637 Davis Drive",
        "address_2": "Morrisville  NC  27560",
        "country": "US"
    },
    "000AAB": {
        "oui_hex": "00-0A-AB",
        "organization": "Toyota Technical Development Corporation",
        "address_1": "1-9, Imae, Hanamoto-cho",
        "address_2": "Toyota  Aichi  470-0334",
        "country": "JP"
    },
    "000AB4": {
        "oui_hex": "00-0A-B4",
        "organization": "ETIC Telecommunications",
        "address_1": "13, chemin du vieux-chene ZIRST",
        "address_2": "MEYLAN  Isere  38240",
        "country": "FR"
    },
    "000A7A": {
        "oui_hex": "00-0A-7A",
        "organization": "Kyoritsu Electric Co., Ltd.",
        "address_1": "2-3-17",
        "address_2": "Komae-shi  Tokyo  201-0005",
        "country": "JP"
    },
    "000A9C": {
        "oui_hex": "00-0A-9C",
        "organization": "Server Technology, Inc.",
        "address_1": "1040 Sandhill Drive",
        "address_2": "Reno  Nevada  89521",
        "country": "US"
    },
    "000A75": {
        "oui_hex": "00-0A-75",
        "organization": "Caterpillar, Inc",
        "address_1": "Mailstop Location AC6130",
        "address_2": "Mossville  IL  61552-0610",
        "country": "US"
    },
    "000A12": {
        "oui_hex": "00-0A-12",
        "organization": "Azylex Technology, Inc",
        "address_1": "7-2Fl., No. 738 Chung Cheng Road,",
        "address_2": "Chung Ho City  Taipei  235",
        "country": "TW"
    },
    "000A13": {
        "oui_hex": "00-0A-13",
        "organization": "Honeywell Video Systems",
        "address_1": "6554 176 Street",
        "address_2": "Surrey  BC  V3S 4G5",
        "country": "CA"
    },
    "000A09": {
        "oui_hex": "00-0A-09",
        "organization": "TaraCom Integrated Products, Inc.",
        "address_1": "830 Stewart Dr.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "000A41": {
        "oui_hex": "00-0A-41",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000A36": {
        "oui_hex": "00-0A-36",
        "organization": "Synelec Telecom Multimedia",
        "address_1": "Zone Industrielle",
        "address_2": "Saint Sernin sur Rance  Aveyron  F-12380",
        "country": "FR"
    },
    "000A48": {
        "oui_hex": "00-0A-48",
        "organization": "Albatron Technology",
        "address_1": "6F, No 716, Chung Cheng,",
        "address_2": "Chung-Ho City  Taipei Hsien",
        "country": "TW"
    },
    "000A3E": {
        "oui_hex": "00-0A-3E",
        "organization": "EADS Telecom",
        "address_1": "Landshuter Strasse 26",
        "address_2": "Munich  Bavaria  85716",
        "country": "DE"
    },
    "000A59": {
        "oui_hex": "00-0A-59",
        "organization": "HW server",
        "address_1": "Italska 15",
        "address_2": "Prague 2  Czech Republic  120 00",
        "country": "KM"
    },
    "000A54": {
        "oui_hex": "00-0A-54",
        "organization": "Laguna Hills, Inc.",
        "address_1": "3-5-2",
        "address_2": "Chiyoda-ku  Tokyo  102-0083",
        "country": "JP"
    },
    "000A4F": {
        "oui_hex": "00-0A-4F",
        "organization": "Brain Boxes Limited",
        "address_1": "Unit 3c, Wavertree Boulevard South",
        "address_2": "Liverpool  Merseyside  L7 9PF",
        "country": "GB"
    },
    "000A52": {
        "oui_hex": "00-0A-52",
        "organization": "AsiaRF Ltd.",
        "address_1": "3F, No.176, Yongzhen Road",
        "address_2": "New Taipei City  Taipei  234",
        "country": "TW"
    },
    "000A02": {
        "oui_hex": "00-0A-02",
        "organization": "ANNSO CO., LTD.",
        "address_1": "5F, No. 100, Min-Chuan Road, Shing-Tien",
        "address_2": "Shing-Tien City Taipei Hsien  Taiwan  221",
        "country": "TW"
    },
    "000A65": {
        "oui_hex": "00-0A-65",
        "organization": "GentechMedia.co.,ltd.",
        "address_1": "solvit bldg 2f, 402-8, yangjae-don,",
        "address_2": "seocho-gu,  seoul  137-899",
        "country": "KR"
    },
    "000A22": {
        "oui_hex": "00-0A-22",
        "organization": "Amperion Inc",
        "address_1": "250 Apollo Drive",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "000A1C": {
        "oui_hex": "00-0A-1C",
        "organization": "Bridge Information Co., Ltd.",
        "address_1": "No.3, Lane 106, Wu-Kung 2 Rd.,",
        "address_2": "Taipei    248",
        "country": "TW"
    },
    "000A32": {
        "oui_hex": "00-0A-32",
        "organization": "Xsido Corporation",
        "address_1": "3F,2-8-13,Shiba-Daimon,",
        "address_2": "Tokyo    105-0012",
        "country": "JP"
    },
    "000A2B": {
        "oui_hex": "00-0A-2B",
        "organization": "Etherstuff",
        "address_1": "208 W. Mimosa Circle",
        "address_2": "San Marcos  TX  78666",
        "country": "US"
    },
    "000A42": {
        "oui_hex": "00-0A-42",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000A38": {
        "oui_hex": "00-0A-38",
        "organization": "Apani Networks",
        "address_1": "1800 E. Imperial Hwy",
        "address_2": "Brea  CA  92821",
        "country": "US"
    },
    "0009A8": {
        "oui_hex": "00-09-A8",
        "organization": "Eastmode Pte Ltd",
        "address_1": "30 Loyang Way #07-06",
        "address_2": "    508769",
        "country": "SG"
    },
    "0009AA": {
        "oui_hex": "00-09-AA",
        "organization": "Data Comm for Business, Inc.",
        "address_1": "2949 County Road 1000 East",
        "address_2": "Dewey  IL  61853",
        "country": "US"
    },
    "0009A4": {
        "oui_hex": "00-09-A4",
        "organization": "HARTEC Corporation",
        "address_1": "KOUHOKUKU SHIN-YOKOHAMA",
        "address_2": "YOKOHAMA-SHI  KANAGAWA-KEN  222-0033",
        "country": "JP"
    },
    "0009A6": {
        "oui_hex": "00-09-A6",
        "organization": "Ignis Optics, Inc.",
        "address_1": "482 W. San Carlos",
        "address_2": "San Jose  California  95110",
        "country": "US"
    },
    "0009A7": {
        "oui_hex": "00-09-A7",
        "organization": "Bang & Olufsen A/S",
        "address_1": "Peter Bangs Vej 15",
        "address_2": "Struer    7600",
        "country": "DK"
    },
    "0009C8": {
        "oui_hex": "00-09-C8",
        "organization": "SINAGAWA TSUSHIN KEISOU SERVICE",
        "address_1": "13-5 Fuke , Sumiyoshi , Onahama",
        "address_2": "Iwaki City  Fukushima Prefecture  971-8124",
        "country": "JP"
    },
    "0009B7": {
        "oui_hex": "00-09-B7",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0009B2": {
        "oui_hex": "00-09-B2",
        "organization": "L&F Inc.",
        "address_1": "4-2-9",
        "address_2": "ITABASHI-KU  Tokyo  175-0083",
        "country": "JP"
    },
    "0009F3": {
        "oui_hex": "00-09-F3",
        "organization": "WELL Communication Corp.",
        "address_1": "11F, No.778, Chung Cheng Rd., Chung Ho C",
        "address_2": "Chung Ho    235",
        "country": "TW"
    },
    "0009EF": {
        "oui_hex": "00-09-EF",
        "organization": "Vocera Communications",
        "address_1": "525 Race St.",
        "address_2": "San Jose  California  95126",
        "country": "US"
    },
    "0009C4": {
        "oui_hex": "00-09-C4",
        "organization": "Medicore Co., Ltd",
        "address_1": "72-3 5th Fl., Luna Bldg, Chungdam-dong",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "0009D9": {
        "oui_hex": "00-09-D9",
        "organization": "Neoscale Systems, Inc",
        "address_1": "1500 Mc Candless Drive",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0009D0": {
        "oui_hex": "00-09-D0",
        "organization": "Solacom Technologies Inc.",
        "address_1": "80 Jean-Proulx",
        "address_2": "Gatineau  Quebec  J8Z 1W1",
        "country": "CA"
    },
    "0009CC": {
        "oui_hex": "00-09-CC",
        "organization": "Moog GmbH",
        "address_1": "Hanns-Klemm-Str. 28",
        "address_2": "Boeblingen    D-71034",
        "country": "DE"
    },
    "000A00": {
        "oui_hex": "00-0A-00",
        "organization": "Mediatek Corp.",
        "address_1": "8F, No 69-5, Sec.2, Chung Cheng East Rd.",
        "address_2": "Taipei    251",
        "country": "TW"
    },
    "0009F0": {
        "oui_hex": "00-09-F0",
        "organization": "Shimizu Technology Inc.",
        "address_1": "15-6, No.107, Chung Shan Rd., Sec.1",
        "address_2": "Hsin Chuan,  Taipei  242",
        "country": "US"
    },
    "0009E4": {
        "oui_hex": "00-09-E4",
        "organization": "K Tech Infosystem Inc.",
        "address_1": "B-405, Bundang Techno-Park 148, Yatap-do",
        "address_2": "Seongnam  Kyonggi-Do  464-070",
        "country": "KR"
    },
    "000972": {
        "oui_hex": "00-09-72",
        "organization": "Securebase,Inc",
        "address_1": "2nd Fl,Seungseung-Bldg,Dokok 2-Dong,Kang",
        "address_2": "Seoul    135-854",
        "country": "KR"
    },
    "000978": {
        "oui_hex": "00-09-78",
        "organization": "AIJI System Co., Ltd.",
        "address_1": "#208 Samho-Park-Tower Bldg. 1122-10, Ing",
        "address_2": "Suwon  Gyeonggi-do  442-835",
        "country": "KR"
    },
    "000973": {
        "oui_hex": "00-09-73",
        "organization": "Lenten Technology Co., Ltd.",
        "address_1": "16F, No.51, Sec.2, Gungyi Road,",
        "address_2": "Taichung City    408",
        "country": "TW"
    },
    "000975": {
        "oui_hex": "00-09-75",
        "organization": "fSONA Communications Corporation",
        "address_1": "#140-11120 Horseshoe Way",
        "address_2": "Richmond  BC  V7A 5H7",
        "country": "CA"
    },
    "000977": {
        "oui_hex": "00-09-77",
        "organization": "Brunner Elektronik AG",
        "address_1": "Müllerwis 1",
        "address_2": "Hittnau  Zurich  8335",
        "country": "CH"
    },
    "000969": {
        "oui_hex": "00-09-69",
        "organization": "Meret Optical Communications",
        "address_1": "10070 Mesa Rim Road",
        "address_2": "San Diego  California  92121",
        "country": "US"
    },
    "000942": {
        "oui_hex": "00-09-42",
        "organization": "Wireless Technologies, Inc",
        "address_1": "Ohmori Mitsubishi Bldg., 7F, Sannoh 2-chome",
        "address_2": "Tokyo    143-0023",
        "country": "JP"
    },
    "000945": {
        "oui_hex": "00-09-45",
        "organization": "Palmmicro Communications Inc",
        "address_1": "630 Alder Dr",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "00093E": {
        "oui_hex": "00-09-3E",
        "organization": "C&I Technologies",
        "address_1": "#303 Kwanbo Plaza B/D, 1467-2",
        "address_2": "Anyang-Shi  Kyunggi-Do  431-808",
        "country": "KR"
    },
    "000940": {
        "oui_hex": "00-09-40",
        "organization": "AGFEO GmbH & Co. KG",
        "address_1": "Postfach 140107",
        "address_2": "Bielefeld  Rhine Westfalia  33621",
        "country": "DE"
    },
    "00097F": {
        "oui_hex": "00-09-7F",
        "organization": "Vsecure 2000 LTD.",
        "address_1": "11 Moshe Levi St.",
        "address_2": "Rishon LeZion    75658",
        "country": "IL"
    },
    "000980": {
        "oui_hex": "00-09-80",
        "organization": "Power Zenith Inc.",
        "address_1": "Tsujido Nishikaigan 1-10-7",
        "address_2": "Fujisawa  Kanagawa  251-0046",
        "country": "JP"
    },
    "0009A0": {
        "oui_hex": "00-09-A0",
        "organization": "Microtechno Corporation",
        "address_1": "2-33-36 Shimoodanaka",
        "address_2": "Kawasaki  Kanagawa  211-0041",
        "country": "JP"
    },
    "00099B": {
        "oui_hex": "00-09-9B",
        "organization": "Western Telematic Inc.",
        "address_1": "5 Sterling",
        "address_2": "Irvine  CA  92618",
        "country": "US"
    },
    "000990": {
        "oui_hex": "00-09-90",
        "organization": "ACKSYS Communications & systems",
        "address_1": "ZA du Val Joyeux",
        "address_2": "VILLEPREUX    F-78450",
        "country": "FR"
    },
    "000953": {
        "oui_hex": "00-09-53",
        "organization": "Linkage System Integration Co.Ltd.",
        "address_1": "40 Gongjianfang",
        "address_2": "Nanjing  Jiangsu  210006",
        "country": "CN"
    },
    "00094C": {
        "oui_hex": "00-09-4C",
        "organization": "Communication Weaver Co.,Ltd.",
        "address_1": "1~3 COWEAVER B/D 446-19,",
        "address_2": "SEOUL    121-841",
        "country": "KR"
    },
    "00096E": {
        "oui_hex": "00-09-6E",
        "organization": "GIANT ELECTRONICS LTD.",
        "address_1": "7/F., ELITE INDUSTRIAL BUILDING,",
        "address_2": "KWUN TONG  KOWLOON",
        "country": "HK"
    },
    "00096C": {
        "oui_hex": "00-09-6C",
        "organization": "Imedia Semiconductor Corp.",
        "address_1": "4988 Great America Pkwy.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "00095F": {
        "oui_hex": "00-09-5F",
        "organization": "Telebyte, Inc.",
        "address_1": "270 Pulaski Road",
        "address_2": "Greenlawn  NY  11740-1616",
        "country": "US"
    },
    "00098A": {
        "oui_hex": "00-09-8A",
        "organization": "EqualLogic Inc",
        "address_1": "9 Townsend West",
        "address_2": "Nashua  NH  03062",
        "country": "US"
    },
    "0008F9": {
        "oui_hex": "00-08-F9",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way Suite 190",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "0008F4": {
        "oui_hex": "00-08-F4",
        "organization": "Bluetake Technology Co., Ltd.",
        "address_1": "6F, No. 33, Lane 155, Sec. 3, Pei Shen R",
        "address_2": "Taipei  Taiwan  222",
        "country": "TW"
    },
    "0008F7": {
        "oui_hex": "00-08-F7",
        "organization": "Hitachi Ltd, Semiconductor & Integrated Circuits Gr",
        "address_1": "20-1 Josuihon-chou 5chome",
        "address_2": "Kodaira-shi  Tokyo  187-8588",
        "country": "JP"
    },
    "000920": {
        "oui_hex": "00-09-20",
        "organization": "EpoX COMPUTER CO.,LTD.",
        "address_1": "10th Floor, No.346,Chung San Rd.,Sec.2,",
        "address_2": "Chung Ho City,Taipei Hsien    235",
        "country": "TW"
    },
    "000922": {
        "oui_hex": "00-09-22",
        "organization": "TST Biometrics GmbH",
        "address_1": "Moehlstraße 39",
        "address_2": "81675  Munich",
        "country": "DE"
    },
    "000916": {
        "oui_hex": "00-09-16",
        "organization": "Listman Home Technologies, Inc.",
        "address_1": "1100 Northmeadow Parkway",
        "address_2": "Roswell  Georgia  30076",
        "country": "US"
    },
    "000911": {
        "oui_hex": "00-09-11",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000912": {
        "oui_hex": "00-09-12",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000908": {
        "oui_hex": "00-09-08",
        "organization": "VTech Technology Corp.",
        "address_1": "2F-2, No. 124, Chung Cheng Rd., Shihlin",
        "address_2": "Taipei    11141",
        "country": "TW"
    },
    "00090B": {
        "oui_hex": "00-09-0B",
        "organization": "MTL  Instruments PLC",
        "address_1": "Power Court",
        "address_2": "Luton  Bedfordshire  LU1 3JJ",
        "country": "GB"
    },
    "00093B": {
        "oui_hex": "00-09-3B",
        "organization": "HYUNDAI NETWORKS INC.",
        "address_1": "SAN 136-1  AMI-RI  BUBAL_EUP",
        "address_2": "ICHON  KYUNGKI-DO  467-701",
        "country": "KR"
    },
    "000934": {
        "oui_hex": "00-09-34",
        "organization": "Dream-Multimedia-Tv GmbH",
        "address_1": "Brückstraße 29",
        "address_2": "Menden  Sauerland  58706",
        "country": "DE"
    },
    "000931": {
        "oui_hex": "00-09-31",
        "organization": "Future Internet, Inc.",
        "address_1": "11'th Floor Samhomoolsan Bldg, B/Bldg, 2",
        "address_2": "Seoul  Kyung-Ki  137-130",
        "country": "KP"
    },
    "0008F5": {
        "oui_hex": "00-08-F5",
        "organization": "YESTECHNOLOGY Co.,Ltd.",
        "address_1": "4th FL Kyung-Am B/D 157-27 Samsung-Dong,",
        "address_2": "  Seoul  135-090",
        "country": "KR"
    },
    "0008EC": {
        "oui_hex": "00-08-EC",
        "organization": "Optical Zonu Corporation",
        "address_1": "15028 Delano Street",
        "address_2": "Van Nuys  CA  91411-2016",
        "country": "US"
    },
    "0008E6": {
        "oui_hex": "00-08-E6",
        "organization": "Littlefeet",
        "address_1": "13000 Gregg Street",
        "address_2": "Poway  California  92064",
        "country": "US"
    },
    "000930": {
        "oui_hex": "00-09-30",
        "organization": "AeroConcierge Inc.",
        "address_1": "10256 Yonge St.",
        "address_2": "Richmond Hill  Ont.  L4C 3B7",
        "country": "CA"
    },
    "00091E": {
        "oui_hex": "00-09-1E",
        "organization": "Firstech Technology Corp.",
        "address_1": "8fl.,No.267,section 4,Hsin-Yi Rd. ,Da-An",
        "address_2": "Taipei    106",
        "country": "TW"
    },
    "0008E2": {
        "oui_hex": "00-08-E2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000905": {
        "oui_hex": "00-09-05",
        "organization": "iTEC Technologies Ltd.",
        "address_1": "160-1, Karak-Dong, Songpa-Gu",
        "address_2": "Seoul    138-809",
        "country": "KR"
    },
    "0008A5": {
        "oui_hex": "00-08-A5",
        "organization": "Peninsula Systems Inc.",
        "address_1": "6902 Verde Ridge Rd.",
        "address_2": "Rancho Palos Verdes  CA  90275",
        "country": "US"
    },
    "0008A2": {
        "oui_hex": "00-08-A2",
        "organization": "ADI Engineering, Inc.",
        "address_1": "1769A Worth Park",
        "address_2": "Charlottesville  VA  22911",
        "country": "US"
    },
    "000898": {
        "oui_hex": "00-08-98",
        "organization": "Gigabit Optics Corporation",
        "address_1": "1156 Aster Ave.",
        "address_2": "Sunnyvale  CA  94086-6810",
        "country": "US"
    },
    "00089B": {
        "oui_hex": "00-08-9B",
        "organization": "ICP Electronics Inc.",
        "address_1": "4F, No. 22, Chung-Hsing Rd. Shi-Chi City",
        "address_2": "Taipei    221",
        "country": "TW"
    },
    "00089C": {
        "oui_hex": "00-08-9C",
        "organization": "Elecs Industry Co., Ltd.",
        "address_1": "1-22-23,Shinsaku,Takatsu-Ku",
        "address_2": "Kawasaki  Kanagawa  213-0014",
        "country": "JP"
    },
    "00089D": {
        "oui_hex": "00-08-9D",
        "organization": "UHD-Elektronik",
        "address_1": "Zuercherstrasse 12",
        "address_2": "Baden  AG  5400",
        "country": "CH"
    },
    "0008CF": {
        "oui_hex": "00-08-CF",
        "organization": "Nippon Koei Power Systems Co., Ltd.",
        "address_1": "2940 Shinyoshida-cho",
        "address_2": "Kohoku-ku  Yokohama  223-8506",
        "country": "JP"
    },
    "0008CB": {
        "oui_hex": "00-08-CB",
        "organization": "Zeta Broadband Inc.",
        "address_1": "660 Vista Way, Suite B",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0008D3": {
        "oui_hex": "00-08-D3",
        "organization": "Hercules Technologies S.A.S.",
        "address_1": "6,place des colombes",
        "address_2": "Rennes  Bretagne  35000",
        "country": "FR"
    },
    "0008D0": {
        "oui_hex": "00-08-D0",
        "organization": "Musashi Engineering Co., LTD.",
        "address_1": "3-11-7, Nishi-shimbashi",
        "address_2": "Minato-ku  Tokyo  105-0003",
        "country": "JP"
    },
    "0008BA": {
        "oui_hex": "00-08-BA",
        "organization": "Erskine Systems Ltd",
        "address_1": "Salter Road",
        "address_2": "Scarborough  North Yorkshire  YO11 3DU",
        "country": "GB"
    },
    "0008B5": {
        "oui_hex": "00-08-B5",
        "organization": "TAI GUEN ENTERPRISE CO., LTD",
        "address_1": "N0.400, 10F-7 HUANPEI RD.,",
        "address_2": "CHUNG LI    320-61",
        "country": "TW"
    },
    "0008B7": {
        "oui_hex": "00-08-B7",
        "organization": "HIT Incorporated",
        "address_1": "4F, 8, Lane 235, Pao-Chiao Road,",
        "address_2": "Shin Tien  Taipei  231",
        "country": "TW"
    },
    "0008A9": {
        "oui_hex": "00-08-A9",
        "organization": "SangSang Technology, Inc.",
        "address_1": "64-8, Nogok-ri, Docheok-myun,",
        "address_2": "Gwangju  Kyonggi-do  464-882",
        "country": "KR"
    },
    "0008C8": {
        "oui_hex": "00-08-C8",
        "organization": "Soneticom, Inc.",
        "address_1": "4325 Woodland Park Drive, Suite 102",
        "address_2": "West Melbourne  Florida  32904",
        "country": "US"
    },
    "0008C4": {
        "oui_hex": "00-08-C4",
        "organization": "Hikari Co.,Ltd.",
        "address_1": "418-4 Minaminoda Chigenobu-cho",
        "address_2": "Onsen-gun  Ehime  791-0297",
        "country": "JP"
    },
    "00088F": {
        "oui_hex": "00-08-8F",
        "organization": "ADVANCED DIGITAL TECHNOLOGY",
        "address_1": "ADT BLDG.,3-3, YANGJAE-DONG,",
        "address_2": "SEOUL",
        "country": "KR"
    },
    "00088B": {
        "oui_hex": "00-08-8B",
        "organization": "Tropic Networks Inc.",
        "address_1": "135 Micheal Cowpland Drive",
        "address_2": "Ottawa  Ontario  K2M2E9",
        "country": "CA"
    },
    "00086B": {
        "oui_hex": "00-08-6B",
        "organization": "MIPSYS",
        "address_1": "19C, Avenue des Indes",
        "address_2": "LES ULIS Cedex    FR-91969",
        "country": "FR"
    },
    "00087F": {
        "oui_hex": "00-08-7F",
        "organization": "SPAUN electronic GmbH & Co. KG",
        "address_1": "Byk-Gulden - Str. 22",
        "address_2": "",
        "country": "DE"
    },
    "000886": {
        "oui_hex": "00-08-86",
        "organization": "Hansung Teliann, Inc.",
        "address_1": "195-1, Neungpyung-ri, Opo-eub",
        "address_2": "",
        "country": "KR"
    },
    "000858": {
        "oui_hex": "00-08-58",
        "organization": "Novatechnology Inc.",
        "address_1": "Nova Bldg. 4F 641 03",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "000850": {
        "oui_hex": "00-08-50",
        "organization": "Arizona Instrument Corp.",
        "address_1": "1912 W. 4th Street",
        "address_2": "Tempe  AZ  85281",
        "country": "US"
    },
    "00085B": {
        "oui_hex": "00-08-5B",
        "organization": "Hanbit Electronics Co., Ltd.",
        "address_1": "414-5, Woncheon-Dong, Paldal-Gu",
        "address_2": "",
        "country": "KR"
    },
    "00082B": {
        "oui_hex": "00-08-2B",
        "organization": "Wooksung Electronics, Inc.",
        "address_1": "Jaho-Bldg. 6F, Tanbang-Dong,",
        "address_2": "",
        "country": "KR"
    },
    "00082E": {
        "oui_hex": "00-08-2E",
        "organization": "Multitone Electronics PLC",
        "address_1": "Multitone House, Beggarwood Lane",
        "address_2": "",
        "country": "GB"
    },
    "0007ED": {
        "oui_hex": "00-07-ED",
        "organization": "Altera Corporation",
        "address_1": "101 Innovation Drive",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0007F1": {
        "oui_hex": "00-07-F1",
        "organization": "TeraBurst Networks Inc.",
        "address_1": "985 Stewart Drive",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "0007F2": {
        "oui_hex": "00-07-F2",
        "organization": "IOA Corporation",
        "address_1": "350 Potrero Ave.",
        "address_2": "Sunnyvale  CA  94085",
        "country": "US"
    },
    "0007EA": {
        "oui_hex": "00-07-EA",
        "organization": "Massana, Inc.",
        "address_1": "2901 Tasman Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0007F0": {
        "oui_hex": "00-07-F0",
        "organization": "LogiSync LLC",
        "address_1": "1313 Lear Industrial Parkway",
        "address_2": "Avon  OH  44011",
        "country": "US"
    },
    "0007E7": {
        "oui_hex": "00-07-E7",
        "organization": "FreeWave Technologies",
        "address_1": "1880 S. Flaitron Ct.",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "0007D6": {
        "oui_hex": "00-07-D6",
        "organization": "Commil Ltd.",
        "address_1": "P.O. Box 10050",
        "address_2": "",
        "country": "IL"
    },
    "0007D7": {
        "oui_hex": "00-07-D7",
        "organization": "Caporis Networks AG",
        "address_1": "Süggelstraße 31",
        "address_2": "",
        "country": "DE"
    },
    "0007D4": {
        "oui_hex": "00-07-D4",
        "organization": "Zhejiang Yutong Network Communication Co Ltd.",
        "address_1": "805 HuaXing Technical Building",
        "address_2": "Zhejiang",
        "country": "CN"
    },
    "0007CE": {
        "oui_hex": "00-07-CE",
        "organization": "Cabletime Limited",
        "address_1": "64 Greenham Road",
        "address_2": "Newbury  Berkshire  RG14 7HX",
        "country": "GB"
    },
    "0007D3": {
        "oui_hex": "00-07-D3",
        "organization": "SPGPrints B.V.",
        "address_1": "Raamstraat 1-3, 5831 AT Boxmeer",
        "address_2": "Boxmeer",
        "country": "NL"
    },
    "000813": {
        "oui_hex": "00-08-13",
        "organization": "Diskbank, Inc.",
        "address_1": "3F Focus Building, 725-25",
        "address_2": "Seoul    135-080",
        "country": "KR"
    },
    "00080F": {
        "oui_hex": "00-08-0F",
        "organization": "Proximion Fiber Optics AB",
        "address_1": "Isafjordsgatan 9",
        "address_2": "",
        "country": "SE"
    },
    "000812": {
        "oui_hex": "00-08-12",
        "organization": "GM-2 Corporation",
        "address_1": "Shiba-Matushira-Bldg.",
        "address_2": "Tokyo  Minato-ku  105-0014",
        "country": "JP"
    },
    "00080B": {
        "oui_hex": "00-08-0B",
        "organization": "Birka BPA Informationssystem AB",
        "address_1": "Box 20100",
        "address_2": "",
        "country": "SE"
    },
    "00080A": {
        "oui_hex": "00-08-0A",
        "organization": "Espera-Werke GmbH",
        "address_1": "Moltkestrasse 17- 33",
        "address_2": "",
        "country": "DE"
    },
    "0007E3": {
        "oui_hex": "00-07-E3",
        "organization": "Navcom Technology, Inc.",
        "address_1": "123 West Torrance Blvd.,",
        "address_2": "Redondo Beach  CA  90277",
        "country": "US"
    },
    "0007E1": {
        "oui_hex": "00-07-E1",
        "organization": "WIS Communications Co. Ltd.",
        "address_1": "4/F Building 533",
        "address_2": "Shenzhen Guangdong Providence",
        "country": "CN"
    },
    "0007E0": {
        "oui_hex": "00-07-E0",
        "organization": "Palm Inc.",
        "address_1": "950 West Maude Ave",
        "address_2": "Sunnyvale  CA  94085-2801",
        "country": "US"
    },
    "0007FA": {
        "oui_hex": "00-07-FA",
        "organization": "ITT Co., Ltd.",
        "address_1": "1-14-7, Mukohjyuku,",
        "address_2": "",
        "country": "JP"
    },
    "0007F6": {
        "oui_hex": "00-07-F6",
        "organization": "Qqest Software Systems",
        "address_1": "860 East 4500 South #200",
        "address_2": "Murray  UT  84107",
        "country": "US"
    },
    "0007FB": {
        "oui_hex": "00-07-FB",
        "organization": "Giga Stream UMTS Technologies GmbH",
        "address_1": "Konrad-Zuse-Strabe 7",
        "address_2": "",
        "country": "DE"
    },
    "00085D": {
        "oui_hex": "00-08-5D",
        "organization": "Mitel Corporation",
        "address_1": "350 Legget Drive",
        "address_2": "-    K2K 2W7",
        "country": "CA"
    },
    "000855": {
        "oui_hex": "00-08-55",
        "organization": "NASA-Goddard Space Flight Center",
        "address_1": "Code 561",
        "address_2": "Greenbelt  MD  20771",
        "country": "US"
    },
    "00085A": {
        "oui_hex": "00-08-5A",
        "organization": "IntiGate Inc.",
        "address_1": "309E IT Venture Tower",
        "address_2": "Seoul    138-803",
        "country": "KR"
    },
    "000817": {
        "oui_hex": "00-08-17",
        "organization": "EmergeCore Networks LLC",
        "address_1": "10542 S. Jordan Gateway",
        "address_2": "South Jordan  UT  84095",
        "country": "US"
    },
    "000815": {
        "oui_hex": "00-08-15",
        "organization": "CATS Co., Ltd.",
        "address_1": "751-2 Kachida-cho,",
        "address_2": "    224-0034",
        "country": "JP"
    },
    "000818": {
        "oui_hex": "00-08-18",
        "organization": "Pixelworks, Inc.",
        "address_1": "7700 SW Mohawk Street",
        "address_2": "Tualatin  OR  97062",
        "country": "US"
    },
    "00082A": {
        "oui_hex": "00-08-2A",
        "organization": "Powerwallz Network Security",
        "address_1": "120-13160 Vanier Place,",
        "address_2": "    V6V 2J2",
        "country": "CA"
    },
    "0007AC": {
        "oui_hex": "00-07-AC",
        "organization": "Eolring",
        "address_1": "10 Rue Alfred Kastler",
        "address_2": "",
        "country": "FR"
    },
    "0007AA": {
        "oui_hex": "00-07-AA",
        "organization": "Quantum Data Inc.",
        "address_1": "2111 Big Timber Rd.",
        "address_2": "Elgin  IL  60123-1100",
        "country": "US"
    },
    "0007A4": {
        "oui_hex": "00-07-A4",
        "organization": "GN Netcom Ltd.",
        "address_1": "12-13 Sedling Road, Wear Est., District",
        "address_2": "  England  NE38 9BZ",
        "country": "GB"
    },
    "00079D": {
        "oui_hex": "00-07-9D",
        "organization": "Musashi Co., Ltd.",
        "address_1": "3-21-1, Shimo-ochiai,",
        "address_2": "Tokyo    161-0033",
        "country": "JP"
    },
    "00079F": {
        "oui_hex": "00-07-9F",
        "organization": "Action Digital Inc.",
        "address_1": "10650 Main St.",
        "address_2": "Fairfax  VA  22030",
        "country": "US"
    },
    "00047C": {
        "oui_hex": "00-04-7C",
        "organization": "Skidata AG",
        "address_1": "T-697553 Untersbergstr. 40",
        "address_2": "",
        "country": "AT"
    },
    "0007BE": {
        "oui_hex": "00-07-BE",
        "organization": "DataLogic SpA",
        "address_1": "Via Candini, 2",
        "address_2": "Bologna",
        "country": "IT"
    },
    "0007AF": {
        "oui_hex": "00-07-AF",
        "organization": "Red Lion Controls, LP",
        "address_1": "20 Willow Springs Circle",
        "address_2": "York  NY  17402",
        "country": "US"
    },
    "000767": {
        "oui_hex": "00-07-67",
        "organization": "Yuxing Electronics Company Limited",
        "address_1": "Unit 1808, 18/F Tower 3,",
        "address_2": "Kowloon Bay,  Kowloon",
        "country": "HK"
    },
    "00075B": {
        "oui_hex": "00-07-5B",
        "organization": "Gibson Guitars",
        "address_1": "309 Park Plus Blvd.",
        "address_2": "Nashville  TN  37217",
        "country": "US"
    },
    "000762": {
        "oui_hex": "00-07-62",
        "organization": "Group Sense Limited",
        "address_1": "27/F, Wu Chung House,",
        "address_2": "Wanchai",
        "country": "HK"
    },
    "000784": {
        "oui_hex": "00-07-84",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000776": {
        "oui_hex": "00-07-76",
        "organization": "Federal APD",
        "address_1": "42775 Nine Mile Rd.",
        "address_2": "Novi  MI  48375",
        "country": "US"
    },
    "00077A": {
        "oui_hex": "00-07-7A",
        "organization": "Infoware System Co., Ltd.",
        "address_1": "Mizorogi Daiichi Bldg 4 F",
        "address_2": "Tokyo",
        "country": "JP"
    },
    "000790": {
        "oui_hex": "00-07-90",
        "organization": "Tri-M Technologies (s) Limited",
        "address_1": "Blk 25, Kallang Avenue #07-01/04",
        "address_2": "    339416",
        "country": "SG"
    },
    "00078D": {
        "oui_hex": "00-07-8D",
        "organization": "NetEngines Ltd.",
        "address_1": "146 Walnut Tree Close",
        "address_2": "    GUI 4UB",
        "country": "GB"
    },
    "00078A": {
        "oui_hex": "00-07-8A",
        "organization": "Mentor Data System Inc.",
        "address_1": "No. 24-1, Industry East 4 Rd.,",
        "address_2": "Hsin-Chu,",
        "country": "TW"
    },
    "000792": {
        "oui_hex": "00-07-92",
        "organization": "Sütron Electronic GmbH",
        "address_1": "Kurze Straße 29",
        "address_2": "",
        "country": "DE"
    },
    "0007B2": {
        "oui_hex": "00-07-B2",
        "organization": "Transaccess S.A.",
        "address_1": "R. Galeno De Castro, 1445",
        "address_2": "São Paulo SP",
        "country": "BR"
    },
    "0007AD": {
        "oui_hex": "00-07-AD",
        "organization": "Pentacon GmbH Foto-und Feinwerktechnik",
        "address_1": "Enderstrabe 94",
        "address_2": "",
        "country": "DE"
    },
    "0007D0": {
        "oui_hex": "00-07-D0",
        "organization": "Automat Engenharia de Automação Ltda.",
        "address_1": "Rua Santo Antonio, 917 - Reboucas",
        "address_2": "    80230-120",
        "country": "BR"
    },
    "00076A": {
        "oui_hex": "00-07-6A",
        "organization": "NEXTEYE Co., Ltd.",
        "address_1": "Shinsegi Plaza 4F, 900-9,",
        "address_2": "Kyunggi    431-070",
        "country": "KR"
    },
    "0006E6": {
        "oui_hex": "00-06-E6",
        "organization": "DongYang Telecom Co., Ltd.",
        "address_1": "642-7 Deung Chon-Dong, KangSeo-Gu",
        "address_2": "  Seoul  157-841",
        "country": "KR"
    },
    "0006DC": {
        "oui_hex": "00-06-DC",
        "organization": "Syabas Technology (Amquest)",
        "address_1": "4727 Paseo Padre Parkway",
        "address_2": "Fremont  CA  94555",
        "country": "US"
    },
    "00070C": {
        "oui_hex": "00-07-0C",
        "organization": "SVA-Intrusion.com Co. Ltd.",
        "address_1": "The 4th Floor, No. 28 Building",
        "address_2": "Shanghai    20233",
        "country": "CN"
    },
    "00070F": {
        "oui_hex": "00-07-0F",
        "organization": "Fujant, Inc.",
        "address_1": "6305 Carpinteria Avenue",
        "address_2": "Carpinteria  CA  93013-2901",
        "country": "US"
    },
    "000714": {
        "oui_hex": "00-07-14",
        "organization": "Brightcom",
        "address_1": "6 Hanechoshet St.,",
        "address_2": "",
        "country": "IL"
    },
    "0006F3": {
        "oui_hex": "00-06-F3",
        "organization": "AcceLight Networks",
        "address_1": "70 Abele Road, Building 1200",
        "address_2": "Pittsburgh  PA  15017",
        "country": "US"
    },
    "0006D2": {
        "oui_hex": "00-06-D2",
        "organization": "Tundra Semiconductor Corp.",
        "address_1": "603 March Road",
        "address_2": "    K2K-2M5",
        "country": "CA"
    },
    "0006D8": {
        "oui_hex": "00-06-D8",
        "organization": "Maple Optical Systems",
        "address_1": "3200 North First St.",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "0006CF": {
        "oui_hex": "00-06-CF",
        "organization": "Thales Avionics In-Flight Systems, LLC",
        "address_1": "17481 Red Hill Avenue",
        "address_2": "Irvine  CA  92614-5630",
        "country": "US"
    },
    "0006FE": {
        "oui_hex": "00-06-FE",
        "organization": "Ambrado, Inc",
        "address_1": "11301 W. President George Bush Fwy.",
        "address_2": "Richardson  TX  75080",
        "country": "US"
    },
    "0006E7": {
        "oui_hex": "00-06-E7",
        "organization": "Bit Blitz Communications Inc.",
        "address_1": "830 Hillview Ct., #290",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "0006ED": {
        "oui_hex": "00-06-ED",
        "organization": "Inara Networks",
        "address_1": "3031 Tisch Way,",
        "address_2": "San Jose  CA  95128",
        "country": "US"
    },
    "0006DB": {
        "oui_hex": "00-06-DB",
        "organization": "ICHIPS Co., Ltd.",
        "address_1": "3F, Samjeon Bldg., 236-3",
        "address_2": "Seoul-City    135-01",
        "country": "KR"
    },
    "000727": {
        "oui_hex": "00-07-27",
        "organization": "Zi Corporation (HK) Ltd.",
        "address_1": "30/F, China Resources Building",
        "address_2": "",
        "country": "HK"
    },
    "00072E": {
        "oui_hex": "00-07-2E",
        "organization": "North Node AB",
        "address_1": "Skeppsloron 42",
        "address_2": "",
        "country": "SE"
    },
    "000699": {
        "oui_hex": "00-06-99",
        "organization": "Vida Design Co.",
        "address_1": "10F, No. 278 Ho Ping E. Rd.,",
        "address_2": "",
        "country": "TW"
    },
    "00068D": {
        "oui_hex": "00-06-8D",
        "organization": "SEPATON, Inc.",
        "address_1": "400 Nickerson Rd.",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "0006A3": {
        "oui_hex": "00-06-A3",
        "organization": "Bitran Corporation",
        "address_1": "2213 Mochida",
        "address_2": "",
        "country": "JP"
    },
    "00069F": {
        "oui_hex": "00-06-9F",
        "organization": "Kuokoa Networks",
        "address_1": "2901 Tasman Dr.",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "0006A2": {
        "oui_hex": "00-06-A2",
        "organization": "Microtune, Inc.",
        "address_1": "6440 Lusk Blvd., Suite D205",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0006A6": {
        "oui_hex": "00-06-A6",
        "organization": "Artistic Licence Engineering Ltd",
        "address_1": "24 Forward Drive",
        "address_2": "Harrow  Middlesex  HA3 8NT",
        "country": "GB"
    },
    "0006B8": {
        "oui_hex": "00-06-B8",
        "organization": "Bandspeed Pty Ltd",
        "address_1": "Level 9, 5000 Collins Street",
        "address_2": "",
        "country": "AU"
    },
    "0006BB": {
        "oui_hex": "00-06-BB",
        "organization": "ATI Technologies Inc.",
        "address_1": "75 Tiverton Court",
        "address_2": "",
        "country": "CA"
    },
    "0006BD": {
        "oui_hex": "00-06-BD",
        "organization": "BNTECHNOLOGY Co., Ltd.",
        "address_1": "602 Youngshin Bldg. 238-8",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0006C3": {
        "oui_hex": "00-06-C3",
        "organization": "Schindler Elevator Ltd.",
        "address_1": "R&D-CO",
        "address_2": "  Ebikon  CH-6030",
        "country": "CH"
    },
    "0006AA": {
        "oui_hex": "00-06-AA",
        "organization": "VT Miltope",
        "address_1": "4900 Pearl East Circle",
        "address_2": "Boulder  CO  80301",
        "country": "US"
    },
    "000657": {
        "oui_hex": "00-06-57",
        "organization": "Market Central, Inc.",
        "address_1": "500 Business Center Drive",
        "address_2": "Pittsburgh  PA  15205-1333",
        "country": "US"
    },
    "000697": {
        "oui_hex": "00-06-97",
        "organization": "R & D Center",
        "address_1": "5F, Seungwon B/D, 810-9",
        "address_2": "Seoul",
        "country": "KR"
    },
    "00069A": {
        "oui_hex": "00-06-9A",
        "organization": "e & Tel",
        "address_1": "100 Sejong-no Chongno-gu,",
        "address_2": "",
        "country": "KR"
    },
    "00067D": {
        "oui_hex": "00-06-7D",
        "organization": "Takasago Ltd.",
        "address_1": "1-24-16 Mizonokuchi Takatsu-ku",
        "address_2": "",
        "country": "JP"
    },
    "000671": {
        "oui_hex": "00-06-71",
        "organization": "Softing AG",
        "address_1": "Richard-Reitzner-Allee 6",
        "address_2": "",
        "country": "DE"
    },
    "000672": {
        "oui_hex": "00-06-72",
        "organization": "Netezza",
        "address_1": "1671 Worcester Road",
        "address_2": "Framingham  MA  01701",
        "country": "US"
    },
    "00066A": {
        "oui_hex": "00-06-6A",
        "organization": "InfiniCon Systems, Inc.",
        "address_1": "700 American Ave.",
        "address_2": "King of Prussia  PA  19406",
        "country": "US"
    },
    "000661": {
        "oui_hex": "00-06-61",
        "organization": "NIA Home Technologies Corp.",
        "address_1": "Innovation Incubator, NTHU,",
        "address_2": "Hsinchu  30013,",
        "country": "TW"
    },
    "0006B2": {
        "oui_hex": "00-06-B2",
        "organization": "Linxtek Co.",
        "address_1": "2F Kum-a B/D 31-3 Karak-dong,",
        "address_2": "    138-160",
        "country": "KR"
    },
    "0006B6": {
        "oui_hex": "00-06-B6",
        "organization": "Nir-Or Israel Ltd.",
        "address_1": "11 Amal St.",
        "address_2": "",
        "country": "IL"
    },
    "000684": {
        "oui_hex": "00-06-84",
        "organization": "Biacore AB",
        "address_1": "Software, Electronics and Optics",
        "address_2": "",
        "country": "SE"
    },
    "000682": {
        "oui_hex": "00-06-82",
        "organization": "Convedia",
        "address_1": "4190 Still Creek Dr.",
        "address_2": "    V5C 6C6",
        "country": "CA"
    },
    "0005E3": {
        "oui_hex": "00-05-E3",
        "organization": "LightSand Communications, Inc.",
        "address_1": "375 Los Coches St.",
        "address_2": "Milpitas  CA  94539",
        "country": "US"
    },
    "0005ED": {
        "oui_hex": "00-05-ED",
        "organization": "Technikum Joanneum GmbH",
        "address_1": "Alte Poststrasse 149",
        "address_2": "",
        "country": "AT"
    },
    "0005EF": {
        "oui_hex": "00-05-EF",
        "organization": "ADOIR Digital Technology",
        "address_1": "28 Fl, ZhaoFeng World Trade Bldg.",
        "address_2": "Shanghai  200050,",
        "country": "CN"
    },
    "000600": {
        "oui_hex": "00-06-00",
        "organization": "Toshiba Teli Corporation",
        "address_1": " 4-7-1 Asahigaoka, Hino-Shi,",
        "address_2": "  Tokyo  191-0065",
        "country": "JP"
    },
    "00066B": {
        "oui_hex": "00-06-6B",
        "organization": "Sysmex Corporation",
        "address_1": "4-4-4 Takatsukadai,",
        "address_2": "    651-2271",
        "country": "JP"
    },
    "00055A": {
        "oui_hex": "00-05-5A",
        "organization": "Power Dsine Ltd.",
        "address_1": "1 Hanagar St., P.O. Box 7220",
        "address_2": "",
        "country": "IL"
    },
    "000653": {
        "oui_hex": "00-06-53",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00064F": {
        "oui_hex": "00-06-4F",
        "organization": "PRO-NETS Technology Corporation",
        "address_1": "Pao-Chung Road,",
        "address_2": "Hsin Tien  Taipei,",
        "country": "TW"
    },
    "000612": {
        "oui_hex": "00-06-12",
        "organization": "Accusys, Inc.",
        "address_1": "5F, No. 38, Taiyuan St",
        "address_2": "Hsinchu County    30265",
        "country": "TW"
    },
    "000609": {
        "oui_hex": "00-06-09",
        "organization": "Crossport Systems",
        "address_1": "10940 NE 33rd Place",
        "address_2": "Bellevue  WA  98005",
        "country": "US"
    },
    "000616": {
        "oui_hex": "00-06-16",
        "organization": "Tel Net Co., Ltd.",
        "address_1": "3F BOF Bldg 730-15 Goje Song",
        "address_2": "",
        "country": "KR"
    },
    "00060D": {
        "oui_hex": "00-06-0D",
        "organization": "Wave7 Optics",
        "address_1": "1075 Windward Ridge Pkwy.",
        "address_2": "Alpharetta  GA  30005",
        "country": "US"
    },
    "00064A": {
        "oui_hex": "00-06-4A",
        "organization": "Honeywell Co., Ltd. (KOREA)",
        "address_1": "56, Chaam-dong, Chonan-city",
        "address_2": "",
        "country": "KR"
    },
    "00063F": {
        "oui_hex": "00-06-3F",
        "organization": "Everex Communications Inc.",
        "address_1": "5020A Brandin Ct.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "00063D": {
        "oui_hex": "00-06-3D",
        "organization": "Microwave Data Systems Inc.",
        "address_1": "175 Science Parkway",
        "address_2": "Rochester  NY  14620",
        "country": "US"
    },
    "000639": {
        "oui_hex": "00-06-39",
        "organization": "Newtec",
        "address_1": "Laarstraat 5",
        "address_2": "",
        "country": "BE"
    },
    "00062F": {
        "oui_hex": "00-06-2F",
        "organization": "Pivotech Systems Inc.",
        "address_1": "200 Centennial Ave.,",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "000636": {
        "oui_hex": "00-06-36",
        "organization": "Jedai Broadband Networks",
        "address_1": "331 Newman Springs Rd.",
        "address_2": "Red Bank  NJ  07701",
        "country": "US"
    },
    "000651": {
        "oui_hex": "00-06-51",
        "organization": "Aspen Networks Inc.",
        "address_1": "3777 Stevens Creek Blvd",
        "address_2": "Santa Clara  CA  95051",
        "country": "US"
    },
    "00065C": {
        "oui_hex": "00-06-5C",
        "organization": "Malachite Technologies, Inc.",
        "address_1": "195 New Hampshire Avenue",
        "address_2": "Portsmouth  NH  03801",
        "country": "US"
    },
    "000642": {
        "oui_hex": "00-06-42",
        "organization": "Genetel Systems Inc.",
        "address_1": "Mockwoo B/D, 912 Walpyoung-Dong",
        "address_2": "    302-852",
        "country": "KR"
    },
    "0005E9": {
        "oui_hex": "00-05-E9",
        "organization": "Unicess Network, Inc.",
        "address_1": "870 Dorothy Dr. #708",
        "address_2": "Richardson  TX  75081",
        "country": "US"
    },
    "0005E6": {
        "oui_hex": "00-05-E6",
        "organization": "Egenera, Inc.",
        "address_1": "165 Forest St.",
        "address_2": "Marlboro  MA  01752",
        "country": "US"
    },
    "00061E": {
        "oui_hex": "00-06-1E",
        "organization": "Maxan Systems",
        "address_1": "1-84, Woulam-dong",
        "address_2": "",
        "country": "KR"
    },
    "000622": {
        "oui_hex": "00-06-22",
        "organization": "Chung Fu Chen Yeh Enterprise Corp.",
        "address_1": "2F No. 666 Jing Ping Road,",
        "address_2": "Taipei Hsien",
        "country": "TW"
    },
    "000588": {
        "oui_hex": "00-05-88",
        "organization": "Sensoria Corp.",
        "address_1": "15950 Bernardo Ctr. Dr.",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "00058D": {
        "oui_hex": "00-05-8D",
        "organization": "Lynx Photonic Networks, Inc.",
        "address_1": "13 Hamelaha St.",
        "address_2": "",
        "country": "IL"
    },
    "00058A": {
        "oui_hex": "00-05-8A",
        "organization": "Netcom Co., Ltd.",
        "address_1": "1F, No. 7, Lane 242,",
        "address_2": "Taipei",
        "country": "TW"
    },
    "000591": {
        "oui_hex": "00-05-91",
        "organization": "Active Silicon Ltd",
        "address_1": "Pinewood Mews",
        "address_2": "Iver    SL0 0NA",
        "country": "GB"
    },
    "000593": {
        "oui_hex": "00-05-93",
        "organization": "Grammar Engine Inc.",
        "address_1": "921 Eastwind Drive",
        "address_2": "Westerville  OH  43081",
        "country": "US"
    },
    "0005C7": {
        "oui_hex": "00-05-C7",
        "organization": "I/F-COM A/S",
        "address_1": "Ellegaardvej 36",
        "address_2": "",
        "country": "DK"
    },
    "0005CC": {
        "oui_hex": "00-05-CC",
        "organization": "Sumtel Communications, Inc.",
        "address_1": "1F, No. 173, Gung Yuan Road,",
        "address_2": "Hsinchu City    30054",
        "country": "TW"
    },
    "0005CF": {
        "oui_hex": "00-05-CF",
        "organization": "Thunder River Technologies, Inc.",
        "address_1": "23 Corporate Plaza Ste. 250",
        "address_2": "Newport Beach  CA  92660",
        "country": "US"
    },
    "0005C6": {
        "oui_hex": "00-05-C6",
        "organization": "Triz Communications",
        "address_1": "Anwon Bldg. 7th Fl.",
        "address_2": "Seoul    150-010",
        "country": "KR"
    },
    "0005D6": {
        "oui_hex": "00-05-D6",
        "organization": "L-3 Linkabit",
        "address_1": "9890 Town Center Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0005DA": {
        "oui_hex": "00-05-DA",
        "organization": "Apex Automationstechnik",
        "address_1": "Vossenkamp 4",
        "address_2": "",
        "country": "DE"
    },
    "0005A1": {
        "oui_hex": "00-05-A1",
        "organization": "Zenocom",
        "address_1": "No.402, 4th floor, Wongok Bldg.",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0005A9": {
        "oui_hex": "00-05-A9",
        "organization": "Princeton Networks, Inc.",
        "address_1": "100 Century Center Ct. #100",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "0005AF": {
        "oui_hex": "00-05-AF",
        "organization": "InnoScan Computing A/S",
        "address_1": "Soren Frichsvej 42R",
        "address_2": "",
        "country": "DK"
    },
    "0005A6": {
        "oui_hex": "00-05-A6",
        "organization": "Extron Electronics",
        "address_1": "1230 S. Lewis",
        "address_2": "Anahiem  CA  92805",
        "country": "US"
    },
    "0005A0": {
        "oui_hex": "00-05-A0",
        "organization": "MOBILINE Kft.",
        "address_1": "Lehel Utca 14",
        "address_2": "    H-1134",
        "country": "HU"
    },
    "000584": {
        "oui_hex": "00-05-84",
        "organization": "AbsoluteValue Systems, Inc.",
        "address_1": "715-D North Dr.",
        "address_2": "Melbourne  FL  32934",
        "country": "US"
    },
    "00058F": {
        "oui_hex": "00-05-8F",
        "organization": "CLCsoft co.",
        "address_1": "Dept. of Electrical Engineering",
        "address_2": "",
        "country": "KR"
    },
    "0005BB": {
        "oui_hex": "00-05-BB",
        "organization": "Myspace AB",
        "address_1": "Sveavagen 33",
        "address_2": "",
        "country": "SE"
    },
    "000517": {
        "oui_hex": "00-05-17",
        "organization": "Shellcomm, Inc.",
        "address_1": "Rm #6122 ETRI TBI Center, 1,",
        "address_2": "",
        "country": "KR"
    },
    "00051C": {
        "oui_hex": "00-05-1C",
        "organization": "Xnet Technology Corp.",
        "address_1": "9F-16, No. 12, Lane 609,",
        "address_2": "",
        "country": "TW"
    },
    "0004F9": {
        "oui_hex": "00-04-F9",
        "organization": "Xtera Communications, Inc.",
        "address_1": "500 W Bethany Drive",
        "address_2": "Allen  TX  75013",
        "country": "US"
    },
    "0004FA": {
        "oui_hex": "00-04-FA",
        "organization": "NBS Technologies Inc.",
        "address_1": "703 Evans Avenue, Suite 400",
        "address_2": "Ontario    M9C 5E9",
        "country": "CA"
    },
    "000541": {
        "oui_hex": "00-05-41",
        "organization": "Advanced Systems Co., Ltd.",
        "address_1": "2-9-7 Nishikicho,",
        "address_2": "    190-0022",
        "country": "JP"
    },
    "000545": {
        "oui_hex": "00-05-45",
        "organization": "Internet Photonics",
        "address_1": "1030 Broad St., 2nd Floor",
        "address_2": "Shrewsbury  NJ  07702",
        "country": "US"
    },
    "00053A": {
        "oui_hex": "00-05-3A",
        "organization": "Willowglen Services Pte Ltd",
        "address_1": "151 Lorong Chuan,",
        "address_2": "    556741",
        "country": "SG"
    },
    "000531": {
        "oui_hex": "00-05-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000539": {
        "oui_hex": "00-05-39",
        "organization": "A Brand New World in Sweden AB",
        "address_1": "Box 1223",
        "address_2": "",
        "country": "SE"
    },
    "00052A": {
        "oui_hex": "00-05-2A",
        "organization": "Ikegami Tsushinki Co., Ltd.",
        "address_1": "5-6-16 Ikegami Ohta-ku,",
        "address_2": "    146-8567",
        "country": "JP"
    },
    "00052D": {
        "oui_hex": "00-05-2D",
        "organization": "Zoltrix International Limited",
        "address_1": "Room 701 Po Hing Centre,",
        "address_2": "",
        "country": "HK"
    },
    "000525": {
        "oui_hex": "00-05-25",
        "organization": "Puretek Industrial Co., Ltd.",
        "address_1": "No. 14, 4 Flr. Lane 235",
        "address_2": "",
        "country": "TW"
    },
    "000558": {
        "oui_hex": "00-05-58",
        "organization": "Synchronous, Inc.",
        "address_1": "77 Las Colinas Lane",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "000550": {
        "oui_hex": "00-05-50",
        "organization": "Vcomms Connect Limited",
        "address_1": "75 The Esplanade, Level 3",
        "address_2": "Wellington Mail Centre 5045  Wellington",
        "country": "NZ"
    },
    "000512": {
        "oui_hex": "00-05-12",
        "organization": "Zebra Technologies Inc",
        "address_1": "475 Half Day Road",
        "address_2": "Lincolnshire  IL  60069",
        "country": "US"
    },
    "000503": {
        "oui_hex": "00-05-03",
        "organization": "ICONAG",
        "address_1": "AM Bahnhof 2",
        "address_2": "",
        "country": "DE"
    },
    "00057A": {
        "oui_hex": "00-05-7A",
        "organization": "Overture Networks",
        "address_1": "637 Davis Drive",
        "address_2": "Morrisville  NC  27560",
        "country": "US"
    },
    "000564": {
        "oui_hex": "00-05-64",
        "organization": "Tsinghua Bitway Co., Ltd.",
        "address_1": "12 Floor, Tower C, Corporate",
        "address_2": "",
        "country": "CN"
    },
    "0004F8": {
        "oui_hex": "00-04-F8",
        "organization": "QUALICABLE TV Industria E Com., Ltda",
        "address_1": "Av. Joao Paulo Ablas, 308",
        "address_2": "",
        "country": "BR"
    },
    "0004F5": {
        "oui_hex": "00-04-F5",
        "organization": "SnowShore Networks, Inc.",
        "address_1": "285 Billerica Road",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "0004F2": {
        "oui_hex": "00-04-F2",
        "organization": "Polycom",
        "address_1": "1000 West 14th Street",
        "address_2": "  Canada  V7P3P3",
        "country": "CA"
    },
    "0004F3": {
        "oui_hex": "00-04-F3",
        "organization": "FS FORTH-SYSTEME GmbH",
        "address_1": "Küferstraße 8",
        "address_2": "",
        "country": "DE"
    },
    "0004ED": {
        "oui_hex": "00-04-ED",
        "organization": "Billion Electric Co., Ltd.",
        "address_1": "8F, No.192, Sec.2, Chung Hsing Rd.,",
        "address_2": "Taiwan  Taiwan  ROC",
        "country": "TW"
    },
    "0004E7": {
        "oui_hex": "00-04-E7",
        "organization": "Lightpointe Communications, Inc",
        "address_1": "10140 Barnes Canyon Road",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "0004E6": {
        "oui_hex": "00-04-E6",
        "organization": "Banyan Network Private Limited",
        "address_1": "443, 8th Floor, Guna Complex",
        "address_2": "",
        "country": "IN"
    },
    "0004DE": {
        "oui_hex": "00-04-DE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0004A2": {
        "oui_hex": "00-04-A2",
        "organization": "L.S.I. Japan Co., Ltd.",
        "address_1": "1-8-14 Sendagaya Shibuya-Ku",
        "address_2": "Tokyo  151-0051",
        "country": "JP"
    },
    "00049B": {
        "oui_hex": "00-04-9B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000499": {
        "oui_hex": "00-04-99",
        "organization": "Chino Corporation",
        "address_1": "1 Mori, Fujioka City,",
        "address_2": "  Zip:  375-8505",
        "country": "JP"
    },
    "00048E": {
        "oui_hex": "00-04-8E",
        "organization": "Ohm Tech Labs, Inc.",
        "address_1": "141 Lanza Ave., B-12",
        "address_2": "Garfield  NJ  07026",
        "country": "US"
    },
    "0004A6": {
        "oui_hex": "00-04-A6",
        "organization": "SAF Tehnika Ltd.",
        "address_1": "91 Dzirnavu Str.,",
        "address_2": "",
        "country": "LV"
    },
    "0004A8": {
        "oui_hex": "00-04-A8",
        "organization": "Broadmax Technologies, Inc.",
        "address_1": "180, Wai Yip Street,",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "0004A1": {
        "oui_hex": "00-04-A1",
        "organization": "Pathway Connectivity",
        "address_1": "1439-17 Avenue SE",
        "address_2": "Calgary  Alberta  T2G 1J9",
        "country": "CA"
    },
    "0004CE": {
        "oui_hex": "00-04-CE",
        "organization": "Patria Ailon",
        "address_1": "Naulakatu 3",
        "address_2": "",
        "country": "FI"
    },
    "0004C7": {
        "oui_hex": "00-04-C7",
        "organization": "NetMount",
        "address_1": "P.O.B. 2325",
        "address_2": "",
        "country": "IL"
    },
    "00048D": {
        "oui_hex": "00-04-8D",
        "organization": " Teo Technologies, Inc",
        "address_1": "11609 49th Place West",
        "address_2": "Mukilteo  WA  98275",
        "country": "US"
    },
    "000490": {
        "oui_hex": "00-04-90",
        "organization": "Optical Access",
        "address_1": "P.O. Box 114",
        "address_2": "",
        "country": "IL"
    },
    "0004E1": {
        "oui_hex": "00-04-E1",
        "organization": "Infinior Microsystems",
        "address_1": "2F, Accufar Bldg, 234-10,",
        "address_2": "Seoul  KOREA  138-220",
        "country": "KR"
    },
    "0004C2": {
        "oui_hex": "00-04-C2",
        "organization": "Magnipix, Inc.",
        "address_1": "3539 St-Charles Blvd., Suite 212",
        "address_2": "  CANADA  H9H3C4",
        "country": "CA"
    },
    "000486": {
        "oui_hex": "00-04-86",
        "organization": "ITTC, University of Kansas",
        "address_1": "2335 Irving Hill Rd.",
        "address_2": "Lawrence  KS  66045",
        "country": "US"
    },
    "00048B": {
        "oui_hex": "00-04-8B",
        "organization": "Poscon Corporation",
        "address_1": "#606 Ho-Dong, Nam Gu,",
        "address_2": "  SOUTH  KOREA",
        "country": "KR"
    },
    "000484": {
        "oui_hex": "00-04-84",
        "organization": "Amann GmbH",
        "address_1": "Unteranger 6",
        "address_2": "",
        "country": "DE"
    },
    "000478": {
        "oui_hex": "00-04-78",
        "organization": "G. Star Technology Corporation",
        "address_1": "4th Floor, No. 118, Sector 2",
        "address_2": "Taipei City  Taipei City  TAIWAN",
        "country": "TW"
    },
    "00047A": {
        "oui_hex": "00-04-7A",
        "organization": "AXXESSIT ASA",
        "address_1": "AXXESSIT ASA HALDEN",
        "address_2": "",
        "country": "NO"
    },
    "00046A": {
        "oui_hex": "00-04-6A",
        "organization": "Navini Networks",
        "address_1": "3605 E. Plano Pkwy,",
        "address_2": "Plano  TX  75074",
        "country": "US"
    },
    "00046B": {
        "oui_hex": "00-04-6B",
        "organization": "Palm Wireless, Inc.",
        "address_1": "48933 Warm Springs Blvd.",
        "address_2": "Fremont  CA  94539",
        "country": "US"
    },
    "000472": {
        "oui_hex": "00-04-72",
        "organization": "Telelynx, Inc.",
        "address_1": "3F-1, 66 Nankan Rd.,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "000464": {
        "oui_hex": "00-04-64",
        "organization": "Pulse-Link Inc",
        "address_1": "1934 Kellogg Avenue",
        "address_2": "Carlsbad  CA  92008",
        "country": "US"
    },
    "000465": {
        "oui_hex": "00-04-65",
        "organization": "i.s.t isdn-support technik GmbH",
        "address_1": "Rhein Strasse 7E",
        "address_2": "",
        "country": "DE"
    },
    "00045E": {
        "oui_hex": "00-04-5E",
        "organization": "PolyTrax Information Technology AG",
        "address_1": "Martin-Kollar - Str. 5",
        "address_2": "",
        "country": "DE"
    },
    "000411": {
        "oui_hex": "00-04-11",
        "organization": "Inkra Networks, Inc.",
        "address_1": "40971 Encyclopedia Circle",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000410": {
        "oui_hex": "00-04-10",
        "organization": "Spinnaker Networks, Inc.",
        "address_1": "107 Gamma Drive",
        "address_2": "Pittsburgh  PA  15238",
        "country": "US"
    },
    "000412": {
        "oui_hex": "00-04-12",
        "organization": "WaveSmith Networks, Inc.",
        "address_1": "40 Nagog Park",
        "address_2": "Acton  MA  01720-3425",
        "country": "US"
    },
    "000442": {
        "oui_hex": "00-04-42",
        "organization": "NACT",
        "address_1": "191 W. 5200 N.",
        "address_2": "Provo  UT  84604",
        "country": "US"
    },
    "000445": {
        "oui_hex": "00-04-45",
        "organization": "LMS Skalar Instruments GmbH",
        "address_1": "Willi-Eichler-Str 11",
        "address_2": "",
        "country": "DE"
    },
    "00044E": {
        "oui_hex": "00-04-4E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000452": {
        "oui_hex": "00-04-52",
        "organization": "RocketLogix, Inc.",
        "address_1": "6504 International Parkway",
        "address_2": "Plano  TX  75093",
        "country": "US"
    },
    "000427": {
        "oui_hex": "00-04-27",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000420": {
        "oui_hex": "00-04-20",
        "organization": "Slim Devices, Inc.",
        "address_1": "12 South First St.",
        "address_2": "San Jose  CA  95113",
        "country": "US"
    },
    "00043D": {
        "oui_hex": "00-04-3D",
        "organization": "INDEL AG",
        "address_1": "Tufiwis 26",
        "address_2": "",
        "country": "CH"
    },
    "00043B": {
        "oui_hex": "00-04-3B",
        "organization": "Lava Computer Mfg., Inc.",
        "address_1": "2 Vulcan St.",
        "address_2": "  CANADA  M9W-1L2",
        "country": "CA"
    },
    "000431": {
        "oui_hex": "00-04-31",
        "organization": "GlobalStreams, Inc.",
        "address_1": "2882 Prospect Park Drive",
        "address_2": "Rancho Cordova  CA  95670",
        "country": "US"
    },
    "0003C4": {
        "oui_hex": "00-03-C4",
        "organization": "Tomra Systems ASA",
        "address_1": "Drengsrudhagen 2",
        "address_2": "",
        "country": "NO"
    },
    "0003C5": {
        "oui_hex": "00-03-C5",
        "organization": "Mobotix AG",
        "address_1": "Wingertsweilerhof 6",
        "address_2": "",
        "country": "DE"
    },
    "0003BF": {
        "oui_hex": "00-03-BF",
        "organization": "Centerpoint Broadband Technologies, Inc.",
        "address_1": "1741 Technology Drive,",
        "address_2": "San Jose  CA  95110-1310",
        "country": "US"
    },
    "0003B9": {
        "oui_hex": "00-03-B9",
        "organization": "Hualong Telecom Co., Ltd.",
        "address_1": "9 Guanghua St.",
        "address_2": "  P.R.",
        "country": "CN"
    },
    "0003F9": {
        "oui_hex": "00-03-F9",
        "organization": "Pleiades Communications, Inc.",
        "address_1": "2830 Market Loop #104",
        "address_2": "South Lake  TX  76092",
        "country": "US"
    },
    "0003FE": {
        "oui_hex": "00-03-FE",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0003F5": {
        "oui_hex": "00-03-F5",
        "organization": "Chip2Chip",
        "address_1": "2249 Zanker Rd.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000391": {
        "oui_hex": "00-03-91",
        "organization": "Advanced Digital Broadcast, Ltd.",
        "address_1": "8F, 145 Chung Shan N. Rd. Sec. 2,",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "0003AC": {
        "oui_hex": "00-03-AC",
        "organization": "Fronius Schweissmaschinen",
        "address_1": "Günter Fronius-Straße 1",
        "address_2": "",
        "country": "AT"
    },
    "000399": {
        "oui_hex": "00-03-99",
        "organization": "Dongju Informations & Communications Co., Ltd.",
        "address_1": "#305, Eunsuk Bldg. Samsung-dong",
        "address_2": "Republic  of  KOREA",
        "country": "KR"
    },
    "0003FD": {
        "oui_hex": "00-03-FD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0003BA": {
        "oui_hex": "00-03-BA",
        "organization": "Oracle Corporation",
        "address_1": "17 Network Circle",
        "address_2": "Menlo Park  CA  95025",
        "country": "US"
    },
    "0003AF": {
        "oui_hex": "00-03-AF",
        "organization": "Paragea Communications",
        "address_1": "207 Perry Parkway",
        "address_2": "Gaithersburg  MD  20877",
        "country": "US"
    },
    "00030B": {
        "oui_hex": "00-03-0B",
        "organization": "Hunter Technology, Inc.",
        "address_1": "1408, Woolim e-biz Center,",
        "address_2": "Seoul    135-270",
        "country": "KR"
    },
    "0003C9": {
        "oui_hex": "00-03-C9",
        "organization": "TECOM Co., Ltd.",
        "address_1": "23, R&D Road 2",
        "address_2": "Hsin-Chu",
        "country": "TW"
    },
    "0003C1": {
        "oui_hex": "00-03-C1",
        "organization": "Packet Dynamics Ltd",
        "address_1": "2 Buckstane Park",
        "address_2": "UK  EH10  GPA",
        "country": "GB"
    },
    "0003DE": {
        "oui_hex": "00-03-DE",
        "organization": "OTC Wireless",
        "address_1": "602 Charlot Ave.",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000328": {
        "oui_hex": "00-03-28",
        "organization": "Mace Group, Inc.",
        "address_1": "5101 Commerce Dr.",
        "address_2": "Baldwin Park  CA  91706",
        "country": "US"
    },
    "00032B": {
        "oui_hex": "00-03-2B",
        "organization": "GAI Datenfunksysteme GmbH",
        "address_1": "Riedleparkstraße 28",
        "address_2": "Friedrichshafen    88045",
        "country": "DE"
    },
    "00032C": {
        "oui_hex": "00-03-2C",
        "organization": "ABB Switzerland Ltd",
        "address_1": "Dept. ATEP",
        "address_2": "Austrasse",
        "country": "CH"
    },
    "000323": {
        "oui_hex": "00-03-23",
        "organization": "Cornet Technology, Inc.",
        "address_1": "6800 Versar Center, Suite 216",
        "address_2": "Springfield  VA  22151-4147",
        "country": "US"
    },
    "000380": {
        "oui_hex": "00-03-80",
        "organization": "SSH Communications Security Corp.",
        "address_1": "Fredrikinkatu 42",
        "address_2": "",
        "country": "FI"
    },
    "000382": {
        "oui_hex": "00-03-82",
        "organization": "A-One Co., Ltd.",
        "address_1": "6-9-20, Shimoichiba-cho,",
        "address_2": "",
        "country": "JP"
    },
    "00037A": {
        "oui_hex": "00-03-7A",
        "organization": "Taiyo Yuden Co., Ltd.",
        "address_1": "8-1 Sakae-Cho",
        "address_2": "",
        "country": "JP"
    },
    "000375": {
        "oui_hex": "00-03-75",
        "organization": "NetMedia, Inc.",
        "address_1": "10940 N. Stallard Place",
        "address_2": "Tuscon  AZ  85737",
        "country": "US"
    },
    "00035A": {
        "oui_hex": "00-03-5A",
        "organization": "Photron Limited",
        "address_1": "1-1-8, Fujimi,",
        "address_2": "Chiyoda-ku    102-0071",
        "country": "JP"
    },
    "000353": {
        "oui_hex": "00-03-53",
        "organization": "Mitac, Inc.",
        "address_1": "No. 2, Chung-Hsiao Street",
        "address_2": "Chitu  Keelung,",
        "country": "TW"
    },
    "000356": {
        "oui_hex": "00-03-56",
        "organization": "Wincor Nixdorf International GmbH",
        "address_1": "Heinz-Nixdorf Ring 1",
        "address_2": "D-33106  Paderborn",
        "country": "DE"
    },
    "00034F": {
        "oui_hex": "00-03-4F",
        "organization": "Sur-Gard Security",
        "address_1": "401 Magnetic Drive",
        "address_2": "Ontario    M3J 3H9",
        "country": "CA"
    },
    "00037B": {
        "oui_hex": "00-03-7B",
        "organization": "IDEC IZUMI Corporation",
        "address_1": "7-31, Nishimiyahara",
        "address_2": "",
        "country": "JP"
    },
    "000367": {
        "oui_hex": "00-03-67",
        "organization": "Jasmine Networks, Inc.",
        "address_1": "1940 Zanker Road",
        "address_2": "San Jose  CA  95112",
        "country": "US"
    },
    "00036A": {
        "oui_hex": "00-03-6A",
        "organization": "Mainnet, Ltd.",
        "address_1": "P.O. Box 2324",
        "address_2": "",
        "country": "IL"
    },
    "00036B": {
        "oui_hex": "00-03-6B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00036C": {
        "oui_hex": "00-03-6C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00038F": {
        "oui_hex": "00-03-8F",
        "organization": "Weinschel Corporation",
        "address_1": "5305 Spectrum Drive",
        "address_2": "Frederick  MD  21703",
        "country": "US"
    },
    "000384": {
        "oui_hex": "00-03-84",
        "organization": "AETA",
        "address_1": "Kepler 6",
        "address_2": "Le Plessis Robinson    92350",
        "country": "FR"
    },
    "000387": {
        "oui_hex": "00-03-87",
        "organization": "Blaze Network Products",
        "address_1": "5180 Hacienda Drive",
        "address_2": "Dublin  CA  94568",
        "country": "US"
    },
    "000381": {
        "oui_hex": "00-03-81",
        "organization": "Ingenico International",
        "address_1": "1/9 Apollo Street",
        "address_2": "",
        "country": "AU"
    },
    "000340": {
        "oui_hex": "00-03-40",
        "organization": "Floware Wireless Systems, Ltd.",
        "address_1": "28 Hacharoshet Steet",
        "address_2": "    60250",
        "country": "IL"
    },
    "0001EC": {
        "oui_hex": "00-01-EC",
        "organization": "Ericsson Group",
        "address_1": "Telefonaktiebolaget",
        "address_2": "",
        "country": "SE"
    },
    "000333": {
        "oui_hex": "00-03-33",
        "organization": "Digitel Co., Ltd.",
        "address_1": "835-6, Yoksam-dong",
        "address_2": "",
        "country": "KR"
    },
    "000338": {
        "oui_hex": "00-03-38",
        "organization": "Oak Technology",
        "address_1": "139 Kifer Court",
        "address_2": "Sunnyvale  CA  94086-5160",
        "country": "US"
    },
    "000339": {
        "oui_hex": "00-03-39",
        "organization": "Eurologic Systems, Ltd.",
        "address_1": "Clonshaugh Industrial Estate",
        "address_2": "Clonshaugh  Dublin 17",
        "country": "IE"
    },
    "000331": {
        "oui_hex": "00-03-31",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000330": {
        "oui_hex": "00-03-30",
        "organization": "Imagenics, Co., Ltd.",
        "address_1": "1-31-5 Kokuryo-Cho",
        "address_2": "  182-0022",
        "country": "JP"
    },
    "00034A": {
        "oui_hex": "00-03-4A",
        "organization": "RIAS Corporation",
        "address_1": "46600 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "0002CF": {
        "oui_hex": "00-02-CF",
        "organization": "ZyGate Communications, Inc.",
        "address_1": "2F, No.48, Lung-Chin Road",
        "address_2": "",
        "country": "TW"
    },
    "0002D1": {
        "oui_hex": "00-02-D1",
        "organization": "Vivotek, Inc.",
        "address_1": "5F-1, 168-1, Lien-Chen Rd,",
        "address_2": "",
        "country": "TW"
    },
    "0002C2": {
        "oui_hex": "00-02-C2",
        "organization": "Net Vision Telecom",
        "address_1": "#206 Software Support Center",
        "address_2": "305-343  Rep.  of Korea",
        "country": "KR"
    },
    "0002B6": {
        "oui_hex": "00-02-B6",
        "organization": "Acrosser Technology Co., Ltd.",
        "address_1": "No. 116-2 Guang-Fu Rd.",
        "address_2": "Taipei  Taipei  R.O.C.",
        "country": "TW"
    },
    "0002B1": {
        "oui_hex": "00-02-B1",
        "organization": "Anritsu, Ltd.",
        "address_1": "Rutherford Close",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0002AD": {
        "oui_hex": "00-02-AD",
        "organization": "HOYA Corporation",
        "address_1": "2-7-5 Naka-Ochiai, Shinjuku-ku,",
        "address_2": "  Tokyo  161-8525",
        "country": "JP"
    },
    "0002AE": {
        "oui_hex": "00-02-AE",
        "organization": "Scannex Electronics Ltd.",
        "address_1": "Unit 8 English Business Park",
        "address_2": "Hove    BN3 7ET",
        "country": "GB"
    },
    "000304": {
        "oui_hex": "00-03-04",
        "organization": "Pacific Broadband Communications",
        "address_1": "3103 North First St.",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "000301": {
        "oui_hex": "00-03-01",
        "organization": "EXFO",
        "address_1": "400 Godin Avenue",
        "address_2": "Quebec   G1M 2K2",
        "country": "CA"
    },
    "0002FD": {
        "oui_hex": "00-02-FD",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "000300": {
        "oui_hex": "00-03-00",
        "organization": "Barracuda Networks, Inc.",
        "address_1": "3175 S. Winchester Blvd",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "0002BD": {
        "oui_hex": "00-02-BD",
        "organization": "Bionet Co., Ltd.",
        "address_1": "3F, Medison Venture Tower,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0002BE": {
        "oui_hex": "00-02-BE",
        "organization": "Totsu Engineering, Inc.",
        "address_1": " 5-16-20 Roppongi Minato-ku",
        "address_2": "Tokyo    106-8551",
        "country": "JP"
    },
    "0002B9": {
        "oui_hex": "00-02-B9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0002BA": {
        "oui_hex": "00-02-BA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0002F9": {
        "oui_hex": "00-02-F9",
        "organization": "MIMOS Berhad",
        "address_1": "Technology Park Malaysia",
        "address_2": "Kuala Lumpur    57000",
        "country": "MY"
    },
    "0002F3": {
        "oui_hex": "00-02-F3",
        "organization": "Media Serve Co., Ltd.",
        "address_1": "Dongsung Bldg. #17-8, Youido-dong,",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0002EA": {
        "oui_hex": "00-02-EA",
        "organization": "Focus Enhancements",
        "address_1": "1370 Dell Ave.",
        "address_2": "Campbell  CA  95008",
        "country": "US"
    },
    "000313": {
        "oui_hex": "00-03-13",
        "organization": "Access Media SPA",
        "address_1": "Via delle Industrie, 4/g",
        "address_2": "24035 LALLIO (BG)",
        "country": "IT"
    },
    "000310": {
        "oui_hex": "00-03-10",
        "organization": "E-Globaledge Corporation",
        "address_1": "7F Nakameguro GT Tower",
        "address_2": " Meduro-ku, Tokyo    153-0051",
        "country": "JP"
    },
    "00030A": {
        "oui_hex": "00-03-0A",
        "organization": "Argus Technologies",
        "address_1": "8F, No. 183, Kang Chien Rd.",
        "address_2": "    114",
        "country": "TW"
    },
    "00031E": {
        "oui_hex": "00-03-1E",
        "organization": "Optranet, Inc.",
        "address_1": "7041 Koll Center Pkwy",
        "address_2": "Pleasanton  CA  94566",
        "country": "US"
    },
    "000315": {
        "oui_hex": "00-03-15",
        "organization": "Cidco Incorporated",
        "address_1": "220 Cochrane Circle",
        "address_2": "Morgan Hill  CA  95037",
        "country": "US"
    },
    "000319": {
        "oui_hex": "00-03-19",
        "organization": "Infineon AG",
        "address_1": "P.O. Box 800949",
        "address_2": "",
        "country": "DE"
    },
    "0002E7": {
        "oui_hex": "00-02-E7",
        "organization": "CAB GmbH & Co KG",
        "address_1": "Wilhelm-Schickard-Str 14",
        "address_2": "",
        "country": "DE"
    },
    "0002DF": {
        "oui_hex": "00-02-DF",
        "organization": "Net Com Systems, Inc.",
        "address_1": "15-3, Yoido-Dong,",
        "address_2": "Seoul",
        "country": "KR"
    },
    "0002DB": {
        "oui_hex": "00-02-DB",
        "organization": "NETSEC",
        "address_1": "13505 Dulles Technology Dr., Ste. 1",
        "address_2": "Herdon  VA  20171",
        "country": "US"
    },
    "00024B": {
        "oui_hex": "00-02-4B",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00024D": {
        "oui_hex": "00-02-4D",
        "organization": "Mannesman Dematic Colby Pty. Ltd.",
        "address_1": "24 Narabang Way",
        "address_2": "",
        "country": "AU"
    },
    "000250": {
        "oui_hex": "00-02-50",
        "organization": "Geyser Networks, Inc.",
        "address_1": "535 Del Rey Avenue",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "000248": {
        "oui_hex": "00-02-48",
        "organization": "Pilz GmbH & Co.",
        "address_1": "Felix-Wankel-Straße 2",
        "address_2": "",
        "country": "DE"
    },
    "00024C": {
        "oui_hex": "00-02-4C",
        "organization": "SiByte, Inc.",
        "address_1": "2805 Bowers Avenue",
        "address_2": "Santa Clara  CA  95051-0917",
        "country": "US"
    },
    "00025A": {
        "oui_hex": "00-02-5A",
        "organization": "Catena Networks",
        "address_1": "307 Legget Drive",
        "address_2": "Canada  K2K  3C8",
        "country": "CA"
    },
    "00026E": {
        "oui_hex": "00-02-6E",
        "organization": "NeGeN Access, Inc.",
        "address_1": "33 Boston Post Rd. West",
        "address_2": "Marlborough  MA  01752",
        "country": "US"
    },
    "000270": {
        "oui_hex": "00-02-70",
        "organization": "Crewave Co., Ltd.",
        "address_1": "F7, Pureun Bldg., 28-1",
        "address_2": "Seoul  KOREA  137-030",
        "country": "KR"
    },
    "00023B": {
        "oui_hex": "00-02-3B",
        "organization": "Ericsson",
        "address_1": "250 Holger Way",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "000239": {
        "oui_hex": "00-02-39",
        "organization": "Visicom",
        "address_1": "10052 Mesa Ridge Ct.",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "000233": {
        "oui_hex": "00-02-33",
        "organization": "Mantra Communications, Inc.",
        "address_1": "12850 Middlebrook Road",
        "address_2": "Germantown  MD  20874",
        "country": "US"
    },
    "0002A2": {
        "oui_hex": "00-02-A2",
        "organization": "Hilscher GmbH",
        "address_1": "Rheinstraße 15",
        "address_2": "",
        "country": "DE"
    },
    "000254": {
        "oui_hex": "00-02-54",
        "organization": "WorldGate",
        "address_1": "3190 Tremont Avenue",
        "address_2": "Trevose  PA  19053",
        "country": "US"
    },
    "00029A": {
        "oui_hex": "00-02-9A",
        "organization": "Storage Apps",
        "address_1": "3 Princess Road",
        "address_2": "Lawrenceville  NJ  08648",
        "country": "US"
    },
    "00028F": {
        "oui_hex": "00-02-8F",
        "organization": "Globetek, Inc.",
        "address_1": "1607 Akron Peninsula Rd.",
        "address_2": "Akron  OH  44313-5190",
        "country": "US"
    },
    "000287": {
        "oui_hex": "00-02-87",
        "organization": "Adapcom",
        "address_1": "172-A Component Drive",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "000281": {
        "oui_hex": "00-02-81",
        "organization": "Madge Ltd.",
        "address_1": "Madge House",
        "address_2": "Maindenhead  Berkshire  SL6 2HP",
        "country": "GB"
    },
    "000263": {
        "oui_hex": "00-02-63",
        "organization": "UPS Manufacturing SRL",
        "address_1": "Via Giordano, 54",
        "address_2": "  Verona",
        "country": "IT"
    },
    "000240": {
        "oui_hex": "00-02-40",
        "organization": "Seedek Co., Ltd.",
        "address_1": "#709, 1638-32, Sammo",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001F3": {
        "oui_hex": "00-01-F3",
        "organization": "QPS, Inc.",
        "address_1": "8015 E. Crystal Drive",
        "address_2": "Anaheim  CA  92807",
        "country": "US"
    },
    "0001E4": {
        "oui_hex": "00-01-E4",
        "organization": "Sitera, Inc.",
        "address_1": "1820 Lefthand Circle",
        "address_2": "Longmont  CO  80501",
        "country": "US"
    },
    "0001E3": {
        "oui_hex": "00-01-E3",
        "organization": "Siemens AG",
        "address_1": "Schlavenhorst 88",
        "address_2": "",
        "country": "DE"
    },
    "0001EB": {
        "oui_hex": "00-01-EB",
        "organization": "C-COM Corporation",
        "address_1": "3F, No. 48, Park Ave. II SBIP",
        "address_2": "Hsinchu Taiwan  Hsinchu Taiwan  R.O.C.",
        "country": "TW"
    },
    "0001F2": {
        "oui_hex": "00-01-F2",
        "organization": "Mark of the Unicorn, Inc.",
        "address_1": "1280 Massachusetts Ave.",
        "address_2": "Cambridge  MA  02138",
        "country": "US"
    },
    "0001D9": {
        "oui_hex": "00-01-D9",
        "organization": "Sigma, Inc.",
        "address_1": "32-3 Seijyo 9 Chome",
        "address_2": "",
        "country": "JP"
    },
    "0001C5": {
        "oui_hex": "00-01-C5",
        "organization": "Simpler Networks",
        "address_1": "555 Dr Frederick Philips",
        "address_2": "  H4M  2X4",
        "country": "CA"
    },
    "0001C9": {
        "oui_hex": "00-01-C9",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00021B": {
        "oui_hex": "00-02-1B",
        "organization": "Kollmorgen-Servotronix",
        "address_1": "POB 3919, Petach Tikya",
        "address_2": "  49130",
        "country": "IL"
    },
    "00021E": {
        "oui_hex": "00-02-1E",
        "organization": "SIMTEL S.R.L.",
        "address_1": "Via Bonifacio Lupi, 25",
        "address_2": "",
        "country": "IT"
    },
    "000221": {
        "oui_hex": "00-02-21",
        "organization": "DSP Application, Ltd.",
        "address_1": "12F-12, No. 79, Sec. 1 Hsin Tai Wu Rd.",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "0001F7": {
        "oui_hex": "00-01-F7",
        "organization": "Image Display Systems, Inc.",
        "address_1": "46560 Fremont Blvd.",
        "address_2": "Fremont  CA  94538",
        "country": "US"
    },
    "000200": {
        "oui_hex": "00-02-00",
        "organization": "Net & Sys Co., Ltd.",
        "address_1": "Kuro Hitech Industrial Complex 304,",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001C4": {
        "oui_hex": "00-01-C4",
        "organization": "NeoWave, Inc.",
        "address_1": "10th KRIHS Bldg. 1591-6",
        "address_2": "  SOUTH  KOREA",
        "country": "KR"
    },
    "0001C1": {
        "oui_hex": "00-01-C1",
        "organization": "Vitesse Semiconductor Corporation",
        "address_1": "Hoerkaer 18",
        "address_2": "",
        "country": "DK"
    },
    "0001D8": {
        "oui_hex": "00-01-D8",
        "organization": "Teltronics, Inc.",
        "address_1": "4125 Keller Springs Road",
        "address_2": "Addison  TX  25001",
        "country": "US"
    },
    "000205": {
        "oui_hex": "00-02-05",
        "organization": "Hitachi Denshi, Ltd.",
        "address_1": "32 Miyaki-cho Kodaira-shi",
        "address_2": "  JAPAN  187-8511",
        "country": "JP"
    },
    "000215": {
        "oui_hex": "00-02-15",
        "organization": "Cotas Computer Technology A/B",
        "address_1": "Paludan-Mullers Vej 82",
        "address_2": "",
        "country": "DK"
    },
    "00022A": {
        "oui_hex": "00-02-2A",
        "organization": "Asound Electronic",
        "address_1": "Xianxi Industries Zone Changan Town",
        "address_2": "",
        "country": "CN"
    },
    "00018C": {
        "oui_hex": "00-01-8C",
        "organization": "Mega Vision",
        "address_1": "5765 Thornwood Drive",
        "address_2": "Goleta  CA  93117",
        "country": "US"
    },
    "00018F": {
        "oui_hex": "00-01-8F",
        "organization": "Kenetec, Inc.",
        "address_1": "115 Hurley Road",
        "address_2": "Oxford  CT  06748",
        "country": "US"
    },
    "00017B": {
        "oui_hex": "00-01-7B",
        "organization": "Heidelberger Druckmaschinen AG",
        "address_1": "Kurfürsten-Anlage  52-60",
        "address_2": "",
        "country": "DE"
    },
    "00019C": {
        "oui_hex": "00-01-9C",
        "organization": "JDS Uniphase Inc.",
        "address_1": "570 West Hunt Club Road",
        "address_2": "",
        "country": "CA"
    },
    "0001A3": {
        "oui_hex": "00-01-A3",
        "organization": "GENESYS LOGIC, INC.",
        "address_1": "10F, No. 11, Ln.3.,",
        "address_2": "",
        "country": "TW"
    },
    "000182": {
        "oui_hex": "00-01-82",
        "organization": "DICA TECHNOLOGIES AG",
        "address_1": "Rotherstr, 19",
        "address_2": "",
        "country": "DE"
    },
    "000189": {
        "oui_hex": "00-01-89",
        "organization": "Refraction Technology, Inc.",
        "address_1": "2626 Lombardy Lane - Ste. #105",
        "address_2": "Dallas  TX  75220",
        "country": "US"
    },
    "000193": {
        "oui_hex": "00-01-93",
        "organization": "Hanbyul Telecom Co., Ltd.",
        "address_1": "5th Fl. Oksan Bldg.",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0030F5": {
        "oui_hex": "00-30-F5",
        "organization": "Wild Lab. Ltd.",
        "address_1": "1-33-17-604 Harayama",
        "address_2": "Urawa City Saitama prif.  336-0931",
        "country": "JP"
    },
    "331760": {
        "oui_hex": "33-17-60",
        "organization": "1-33-17-604 Harayama",
        "address_1": "JP",
        "address_2": "",
        "country": ""
    },
    "00015D": {
        "oui_hex": "00-01-5D",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "000173": {
        "oui_hex": "00-01-73",
        "organization": "AMCC",
        "address_1": "6290 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "00016C": {
        "oui_hex": "00-01-6C",
        "organization": "FOXCONN",
        "address_1": "105 S Puente St.",
        "address_2": "Brea  CA  92821",
        "country": "US"
    },
    "000175": {
        "oui_hex": "00-01-75",
        "organization": "Radiant Communications Corp.",
        "address_1": "5001 Hadley Road",
        "address_2": "South Plainfield  NJ  07080",
        "country": "US"
    },
    "0001AF": {
        "oui_hex": "00-01-AF",
        "organization": "Artesyn Embedded Technologies",
        "address_1": "2900 S. Diablo Way",
        "address_2": "Tempe  AZ  85282",
        "country": "US"
    },
    "00018A": {
        "oui_hex": "00-01-8A",
        "organization": "ROI COMPUTER AG",
        "address_1": "Werner-von-Siemens-Str. 1",
        "address_2": "",
        "country": "DE"
    },
    "000192": {
        "oui_hex": "00-01-92",
        "organization": "Texas Digital Systems",
        "address_1": "400 Technology Parkway",
        "address_2": "College Station  TX  77845",
        "country": "US"
    },
    "00015C": {
        "oui_hex": "00-01-5C",
        "organization": "CADANT INC.",
        "address_1": "4343 Commerce Court - Ste. #207",
        "address_2": "Lisle  IL  60532",
        "country": "US"
    },
    "000169": {
        "oui_hex": "00-01-69",
        "organization": "Celestix Networks Pte Ltd.",
        "address_1": "18 Tannery Lane #05-03",
        "address_2": "  SINGAPORE  347780",
        "country": "SG"
    },
    "00016B": {
        "oui_hex": "00-01-6B",
        "organization": "LightChip, Inc.",
        "address_1": "5 Industrial Way",
        "address_2": "Salem  NH  03079",
        "country": "US"
    },
    "0001B6": {
        "oui_hex": "00-01-B6",
        "organization": "SAEJIN T&M Co., Ltd.",
        "address_1": "2nd Fl., Saejin Bldg., 689",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0001AB": {
        "oui_hex": "00-01-AB",
        "organization": "Main Street Networks",
        "address_1": "4030 Moorpark Ave.",
        "address_2": "San Jose  CA  95117-1849",
        "country": "US"
    },
    "000145": {
        "oui_hex": "00-01-45",
        "organization": "WINSYSTEMS, INC.",
        "address_1": "715 Stadium Drive",
        "address_2": "Arlington  TX  76011",
        "country": "US"
    },
    "000137": {
        "oui_hex": "00-01-37",
        "organization": "IT Farm Corporation",
        "address_1": "Asashiseimei Fuchu Bldg. 11F",
        "address_2": "  183-0055",
        "country": "JP"
    },
    "00013C": {
        "oui_hex": "00-01-3C",
        "organization": "TIW SYSTEMS",
        "address_1": "2211 Lawson Lane",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000133": {
        "oui_hex": "00-01-33",
        "organization": "KYOWA Electronic Instruments C",
        "address_1": "3-5-1, Cyofugaoka",
        "address_2": "Cyofu  Tokyo",
        "country": "JP"
    },
    "0001A5": {
        "oui_hex": "00-01-A5",
        "organization": "Nextcomm, Inc.",
        "address_1": "12413 Willows Road NE - Ste. #210",
        "address_2": "Kirkland  WA  98034",
        "country": "US"
    },
    "000190": {
        "oui_hex": "00-01-90",
        "organization": "SMK-M",
        "address_1": "1055 Tierra Del Rey",
        "address_2": "Chula Vista  CA  91910",
        "country": "US"
    },
    "00014C": {
        "oui_hex": "00-01-4C",
        "organization": "Berkeley Process Control",
        "address_1": "4124 Lakeside Dr",
        "address_2": "Richmond  CA  94806",
        "country": "US"
    },
    "000143": {
        "oui_hex": "00-01-43",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00014B": {
        "oui_hex": "00-01-4B",
        "organization": "Ennovate Networks, Inc.",
        "address_1": "60 Codman Hill Road",
        "address_2": "Boxborough  MA  01719",
        "country": "US"
    },
    "00013D": {
        "oui_hex": "00-01-3D",
        "organization": "RiscStation Ltd.",
        "address_1": "168 Elliott Street",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "000120": {
        "oui_hex": "00-01-20",
        "organization": "OSCILLOQUARTZ S.A.",
        "address_1": "Rue Des Brevards 16",
        "address_2": "2002 Neuchatel",
        "country": "CH"
    },
    "003046": {
        "oui_hex": "00-30-46",
        "organization": "Controlled Electronic Manageme",
        "address_1": "Unit 4 Ravenhill Business Park",
        "address_2": "Belfast",
        "country": "IE"
    },
    "003098": {
        "oui_hex": "00-30-98",
        "organization": "Global Converging Technologies",
        "address_1": "1800 Preston Park Blvd.",
        "address_2": "Plano  TX  75093",
        "country": "US"
    },
    "00300D": {
        "oui_hex": "00-30-0D",
        "organization": "MMC Technology, Inc.",
        "address_1": "#1502, Seoul Venture Town, Aju Bldg",
        "address_2": "Seoul 135-080",
        "country": "KR"
    },
    "003075": {
        "oui_hex": "00-30-75",
        "organization": "ADTECH",
        "address_1": "RUE DU VAL ST LAMBERT 191 / i",
        "address_2": " SERAING    4100",
        "country": "BE"
    },
    "00B069": {
        "oui_hex": "00-B0-69",
        "organization": "Honewell Oy",
        "address_1": "P.O. Box 168, FIN-78201",
        "address_2": "",
        "country": "FI"
    },
    "00B0C2": {
        "oui_hex": "00-B0-C2",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00B03B": {
        "oui_hex": "00-B0-3B",
        "organization": "HiQ Networks",
        "address_1": "2475 Augustine Drive",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "000127": {
        "oui_hex": "00-01-27",
        "organization": "OPEN Networks Pty Ltd",
        "address_1": "Level 5, 342 Flinders Street",
        "address_2": "Melbourne    VIC 3000",
        "country": "AU"
    },
    "00010E": {
        "oui_hex": "00-01-0E",
        "organization": "Bri-Link Technologies Co., Ltd",
        "address_1": "2F, No. 63, Chow-Tze Street",
        "address_2": "Taipei 114",
        "country": "TW"
    },
    "003037": {
        "oui_hex": "00-30-37",
        "organization": "Packard Bell Nec Services",
        "address_1": "299 avenue Patton, BP 645",
        "address_2": "49006 Angers Cedex 01",
        "country": "FR"
    },
    "003057": {
        "oui_hex": "00-30-57",
        "organization": "QTelNet, Inc.",
        "address_1": "400 - 3115 12th Street NE",
        "address_2": "Calgary  Alberta  T2E 7J2",
        "country": "CA"
    },
    "0030FC": {
        "oui_hex": "00-30-FC",
        "organization": "Terawave Communications, Inc.",
        "address_1": "30695 Huntwood Avenue",
        "address_2": "Hayward  CA  94544",
        "country": "US"
    },
    "00B086": {
        "oui_hex": "00-B0-86",
        "organization": "LocSoft Limited",
        "address_1": "7 Bright Street",
        "address_2": "Clitheroe  Lancashire  BB7 1NW",
        "country": "GB"
    },
    "0030A2": {
        "oui_hex": "00-30-A2",
        "organization": "Lightner Engineering",
        "address_1": "8551 La Jolla Shores Dr",
        "address_2": "La Jolla  CA  92037",
        "country": "US"
    },
    "003042": {
        "oui_hex": "00-30-42",
        "organization": "DeTeWe-Deutsche Telephonwerke",
        "address_1": "Zeughofstrasse 1",
        "address_2": "D-10997 Berlin",
        "country": "DE"
    },
    "00B0C7": {
        "oui_hex": "00-B0-C7",
        "organization": "Tellabs Operations, Inc.",
        "address_1": "One Tellabs Center",
        "address_2": "Naperville  IL  60563",
        "country": "US"
    },
    "00B02A": {
        "oui_hex": "00-B0-2A",
        "organization": "ORSYS GmbH",
        "address_1": "Am Stadtgraben 25",
        "address_2": "D-88677 Markdorf",
        "country": "DE"
    },
    "000104": {
        "oui_hex": "00-01-04",
        "organization": "DVICO Co., Ltd.",
        "address_1": "Kookmin Card B/D 6F 267-2",
        "address_2": "Sungnam-si Kyungki-do 463-050",
        "country": "KR"
    },
    "000106": {
        "oui_hex": "00-01-06",
        "organization": "Tews Datentechnik GmbH",
        "address_1": "Am Bahnhof 7",
        "address_2": "25469 Halstenbek",
        "country": "DE"
    },
    "000109": {
        "oui_hex": "00-01-09",
        "organization": "Nagano Japan Radio Co., Ltd.",
        "address_1": "Shimohigano 1163, Inasato-machi",
        "address_2": "Nagano 381-2288",
        "country": "JP"
    },
    "00029C": {
        "oui_hex": "00-02-9C",
        "organization": "3COM",
        "address_1": "405 SPRING HILL ROAD",
        "address_2": "SHARON  NH  03458",
        "country": "US"
    },
    "00B019": {
        "oui_hex": "00-B0-19",
        "organization": "UTC CCS",
        "address_1": "791 Commerce Blvd",
        "address_2": "Boca Raton  FL  33497",
        "country": "US"
    },
    "00306F": {
        "oui_hex": "00-30-6F",
        "organization": "SEYEON TECH. CO., LTD.",
        "address_1": "NAMCHEON BLDG. 6F,",
        "address_2": "  KOREA  135-280",
        "country": "KR"
    },
    "00303D": {
        "oui_hex": "00-30-3D",
        "organization": "IVA CORPORATION",
        "address_1": "142 NORTH RD STE R",
        "address_2": "SUDBURY  MA  01776",
        "country": "US"
    },
    "0030F4": {
        "oui_hex": "00-30-F4",
        "organization": "STARDOT TECHNOLOGIES",
        "address_1": "6820-H ORANGE THORPE AVE.",
        "address_2": "BUENA PARK  CA  90620",
        "country": "US"
    },
    "003052": {
        "oui_hex": "00-30-52",
        "organization": "ELASTIC NETWORKS",
        "address_1": "6120 WINDWARD PARKWAY -STE#100",
        "address_2": "ALPHARETTA  GA  30005",
        "country": "US"
    },
    "003019": {
        "oui_hex": "00-30-19",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "003076": {
        "oui_hex": "00-30-76",
        "organization": "Akamba Corporation",
        "address_1": "15595 Los Gatos Blvd.",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "0030EC": {
        "oui_hex": "00-30-EC",
        "organization": "BORGARDT",
        "address_1": "DIESELSTR. 15",
        "address_2": "",
        "country": "DE"
    },
    "0030F3": {
        "oui_hex": "00-30-F3",
        "organization": "At Work Computers",
        "address_1": "P.O. Box 947",
        "address_2": "Corvallis  OR  97339",
        "country": "US"
    },
    "0030CC": {
        "oui_hex": "00-30-CC",
        "organization": "Tenor Networks, Inc.",
        "address_1": "100 Nagog Park",
        "address_2": "Acton  MA  01720-3409",
        "country": "US"
    },
    "0030B0": {
        "oui_hex": "00-30-B0",
        "organization": "Convergenet Technologies",
        "address_1": "2222 Trade Zone Boulevard",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "0030EB": {
        "oui_hex": "00-30-EB",
        "organization": "TURBONET COMMUNICATIONS, INC.",
        "address_1": "19F-1, NO. 171, SUNG-TEH ROAD",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "0030A1": {
        "oui_hex": "00-30-A1",
        "organization": "WEBGATE Inc.",
        "address_1": "4F, Pika Bldg., 894-20, Hoyke 2-dong",
        "address_2": "Anyang-Si  Kyunggi-Do",
        "country": "KR"
    },
    "00306A": {
        "oui_hex": "00-30-6A",
        "organization": "PENTA MEDIA CO., LTD.",
        "address_1": "E-504 Bundang Technopark,151",
        "address_2": "Seongnam  Gyeonggi-do",
        "country": "KR"
    },
    "003086": {
        "oui_hex": "00-30-86",
        "organization": "Transistor Devices, Inc.",
        "address_1": "36A Newburgh Road",
        "address_2": "Hackettstown  NJ  07840",
        "country": "US"
    },
    "003044": {
        "oui_hex": "00-30-44",
        "organization": "CradlePoint, Inc",
        "address_1": "805 W. Franklin St.",
        "address_2": "Boise  ID  83702",
        "country": "US"
    },
    "0030C2": {
        "oui_hex": "00-30-C2",
        "organization": "COMONE",
        "address_1": "Parc De Marticot",
        "address_2": "33610 Cestas",
        "country": "FR"
    },
    "003053": {
        "oui_hex": "00-30-53",
        "organization": "Basler AG",
        "address_1": "An Der Strusbek 60-62",
        "address_2": "22926 Ahrensburg",
        "country": "DE"
    },
    "0030D2": {
        "oui_hex": "00-30-D2",
        "organization": "WIN TECHNOLOGIES, CO., LTD.",
        "address_1": "4F-6, No. 81, Sec. 1",
        "address_2": "Taipei",
        "country": "TW"
    },
    "003059": {
        "oui_hex": "00-30-59",
        "organization": "KONTRON COMPACT COMPUTERS AG",
        "address_1": "Nordstrasse 11/F",
        "address_2": " LUTERBACH    4542",
        "country": "CH"
    },
    "003097": {
        "oui_hex": "00-30-97",
        "organization": "AB Regin",
        "address_1": "Box 366",
        "address_2": "SE-26123  Landskrona",
        "country": "SE"
    },
    "00305F": {
        "oui_hex": "00-30-5F",
        "organization": "Hasselblad",
        "address_1": "Hejrevej 30",
        "address_2": "Copenhagen  NV  DK-2400",
        "country": "DK"
    },
    "0030DC": {
        "oui_hex": "00-30-DC",
        "organization": "RIGHTECH CORPORATION",
        "address_1": "4F, NO. 351, CHUNG-SHUN RD.",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "003025": {
        "oui_hex": "00-30-25",
        "organization": "CHECKOUT COMPUTER SYSTEMS, LTD",
        "address_1": "TOWNSEND FARM ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "003012": {
        "oui_hex": "00-30-12",
        "organization": "DIGITAL ENGINEERING LTD.",
        "address_1": "2 TRENCH ROAD, MALLUSK",
        "address_2": "  NORTHERN",
        "country": "IE"
    },
    "0030C6": {
        "oui_hex": "00-30-C6",
        "organization": "CONTROL SOLUTIONS, INC.",
        "address_1": "201 85TH AVENUE NW",
        "address_2": "MINNEAPOLIS  MN  55433",
        "country": "US"
    },
    "0030D6": {
        "oui_hex": "00-30-D6",
        "organization": "MSC VERTRIEBS GMBH",
        "address_1": "INDUSTRIESTR. 16",
        "address_2": "",
        "country": "DE"
    },
    "003041": {
        "oui_hex": "00-30-41",
        "organization": "SAEJIN T & M CO., LTD.",
        "address_1": "2ND FL., SAEJIN BLDG. 689",
        "address_2": "  135-230  KOREA",
        "country": "KR"
    },
    "00308C": {
        "oui_hex": "00-30-8C",
        "organization": "Quantum Corporation",
        "address_1": "10125 Federal Drive",
        "address_2": "Colorado Springs  CO  80908",
        "country": "US"
    },
    "0030E3": {
        "oui_hex": "00-30-E3",
        "organization": "SEDONA NETWORKS CORP.",
        "address_1": "10A HEARST WAY",
        "address_2": "CANADA  K2L  2P4",
        "country": "CA"
    },
    "0030BF": {
        "oui_hex": "00-30-BF",
        "organization": "MULTIDATA GMBH",
        "address_1": "Dieburger Str. 96a",
        "address_2": "",
        "country": "DE"
    },
    "00D00F": {
        "oui_hex": "00-D0-0F",
        "organization": "SPEECH DESIGN GMBH",
        "address_1": "INDUSTRIESTR. 1",
        "address_2": "",
        "country": "DE"
    },
    "003058": {
        "oui_hex": "00-30-58",
        "organization": "API MOTION",
        "address_1": "45 HAZELWOOD DRIVE",
        "address_2": "AMHERST  NY  14228",
        "country": "US"
    },
    "003034": {
        "oui_hex": "00-30-34",
        "organization": "SET ENGINEERING",
        "address_1": "15750 VINEYARD BLVD. STE. #100",
        "address_2": "MORGAN HILL  CA  95037",
        "country": "US"
    },
    "00304A": {
        "oui_hex": "00-30-4A",
        "organization": "Fraunhofer IPMS",
        "address_1": "Maria-Reiche-Strasse 2",
        "address_2": "Dresden    01109",
        "country": "DE"
    },
    "00308D": {
        "oui_hex": "00-30-8D",
        "organization": "Pinnacle Systems, Inc.",
        "address_1": "Frankfurter Str. 3c",
        "address_2": "D-38122  Braunschweig",
        "country": "DE"
    },
    "0030A6": {
        "oui_hex": "00-30-A6",
        "organization": "VIANET TECHNOLOGIES, LTD.",
        "address_1": "8 HACHARASH STREET",
        "address_2": "",
        "country": "IL"
    },
    "00D0BF": {
        "oui_hex": "00-D0-BF",
        "organization": "PIVOTAL TECHNOLOGIES",
        "address_1": "70 S. LAKE AVENUE - STE. #900",
        "address_2": "PASADENA  CA  91101",
        "country": "US"
    },
    "00303C": {
        "oui_hex": "00-30-3C",
        "organization": "ONNTO CORP.",
        "address_1": "12F-2,  NO. 161",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "003024": {
        "oui_hex": "00-30-24",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "0030F6": {
        "oui_hex": "00-30-F6",
        "organization": "SECURELOGIX CORPORATION",
        "address_1": "13750 SAN PEDRO",
        "address_2": "SAN ANTONIO  TX  78232",
        "country": "US"
    },
    "00D02F": {
        "oui_hex": "00-D0-2F",
        "organization": "VLSI TECHNOLOGY INC.",
        "address_1": "8375 S. RIVER PARKWAY",
        "address_2": "TEMPE  AZ  85284",
        "country": "US"
    },
    "0030D8": {
        "oui_hex": "00-30-D8",
        "organization": "SITEK",
        "address_1": "VIA MONTE FIORINO 9",
        "address_2": "",
        "country": "IT"
    },
    "003016": {
        "oui_hex": "00-30-16",
        "organization": "ISHIDA CO., LTD.",
        "address_1": "959-1 SHIMOMAGARI",
        "address_2": "",
        "country": "JP"
    },
    "00D0B1": {
        "oui_hex": "00-D0-B1",
        "organization": "OMEGA ELECTRONICS SA",
        "address_1": "ROUTE DE SOLEURE 68",
        "address_2": "",
        "country": "CH"
    },
    "00D016": {
        "oui_hex": "00-D0-16",
        "organization": "SCM MICROSYSTEMS, INC.",
        "address_1": "160 KNOWLES DRIVE",
        "address_2": "LOS GATOS  CA  95032",
        "country": "US"
    },
    "00D043": {
        "oui_hex": "00-D0-43",
        "organization": "ZONAL RETAIL DATA SYSTEMS",
        "address_1": "24 FORTH STREET",
        "address_2": "    SCOTLAND",
        "country": "GB"
    },
    "00D0C1": {
        "oui_hex": "00-D0-C1",
        "organization": "HARMONIC DATA SYSTEMS, LTD.",
        "address_1": "10 BEIT SHAMAI STREET",
        "address_2": "  ISRAEL  67018",
        "country": "IL"
    },
    "00D0AC": {
        "oui_hex": "00-D0-AC",
        "organization": "Commscope, Inc",
        "address_1": "140 Vista Centre Drive",
        "address_2": "Forest  VA  24551",
        "country": "US"
    },
    "00D07C": {
        "oui_hex": "00-D0-7C",
        "organization": "KOYO ELECTRONICS INC. CO.,LTD.",
        "address_1": "1-171 TENJIN-CHO KODAIRA",
        "address_2": "",
        "country": "JP"
    },
    "00D0BC": {
        "oui_hex": "00-D0-BC",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D0CB": {
        "oui_hex": "00-D0-CB",
        "organization": "DASAN CO., LTD.",
        "address_1": "DASAN Tower 7F, 49 Daewangpangyo-ro644beon-gil",
        "address_2": "Seonggnam-Si  Gyeoenggi-do  463-4000",
        "country": "KR"
    },
    "00D019": {
        "oui_hex": "00-D0-19",
        "organization": "DAINIPPON SCREEN CORPORATE",
        "address_1": "REPRESENTATIVES OF AMERICA,INC",
        "address_2": "IRVINE  CA  92614",
        "country": "US"
    },
    "00D035": {
        "oui_hex": "00-D0-35",
        "organization": "BEHAVIOR TECH. COMPUTER CORP.",
        "address_1": "20F-B, No.98, Sec. 1,",
        "address_2": "Sijhih City  Taipei County  22102",
        "country": "TW"
    },
    "00D0DB": {
        "oui_hex": "00-D0-DB",
        "organization": "MCQUAY INTERNATIONAL",
        "address_1": "13600 INDUSTRIAL PARK BLVD.",
        "address_2": "MINNEAPOLIS  MN  55441",
        "country": "US"
    },
    "00D070": {
        "oui_hex": "00-D0-70",
        "organization": "LONG WELL ELECTRONICS CORP.",
        "address_1": "4F, NO. 59-1, TSAO DI WEI",
        "address_2": "TAIWAN 222  TAIWAN 222  R.O.C.",
        "country": "TW"
    },
    "00D029": {
        "oui_hex": "00-D0-29",
        "organization": "WAKEFERN FOOD CORPORATION",
        "address_1": "230 RARITAN CENTER PARKWAY",
        "address_2": "EDISON  NJ  08837",
        "country": "US"
    },
    "00D0C3": {
        "oui_hex": "00-D0-C3",
        "organization": "VIVID TECHNOLOGY PTE, LTD.",
        "address_1": "1003 BUKIT MERAH CENTRAL",
        "address_2": "",
        "country": "SG"
    },
    "00D013": {
        "oui_hex": "00-D0-13",
        "organization": "PRIMEX AEROSPACE COMPANY",
        "address_1": "P.O. BOX 97009",
        "address_2": "REDMOND  WA  98073-9709",
        "country": "US"
    },
    "00D0A3": {
        "oui_hex": "00-D0-A3",
        "organization": "VOCAL DATA, INC.",
        "address_1": "1701 N GREENVILLE #304",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "00D07E": {
        "oui_hex": "00-D0-7E",
        "organization": "KEYCORP LTD.",
        "address_1": "P.O. BOX 199",
        "address_2": "",
        "country": "AU"
    },
    "00D020": {
        "oui_hex": "00-D0-20",
        "organization": "AIM SYSTEM, INC.",
        "address_1": "4TH FLOOR CHUNGWOO B/D 219-1",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00D0C8": {
        "oui_hex": "00-D0-C8",
        "organization": "Prevas A/S",
        "address_1": "Lyskær 3EF",
        "address_2": "DK-2730  Herlev",
        "country": "DK"
    },
    "005017": {
        "oui_hex": "00-50-17",
        "organization": "RSR S.R.L.",
        "address_1": "VIA SINIGAGLIA, 38",
        "address_2": "  22075",
        "country": "IT"
    },
    "005065": {
        "oui_hex": "00-50-65",
        "organization": "TDK-Lambda Corporation",
        "address_1": "36-1 Kasuminosato",
        "address_2": "Ami-Machi  Inashiki-Gun Ibaraki,  300-0396",
        "country": "JP"
    },
    "0050B9": {
        "oui_hex": "00-50-B9",
        "organization": "XITRON TECHNOLOGIES, INC.",
        "address_1": "6295-D FERRIS SQUARE",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00506B": {
        "oui_hex": "00-50-6B",
        "organization": "SPX-ATEG",
        "address_1": "802 S. MAIN STREET",
        "address_2": "WAYLAND  MI  49348",
        "country": "US"
    },
    "00D076": {
        "oui_hex": "00-D0-76",
        "organization": "Bank of America",
        "address_1": "1100 Merrill Drive",
        "address_2": "Pennington  NJ  08534",
        "country": "US"
    },
    "00D051": {
        "oui_hex": "00-D0-51",
        "organization": "O2 MICRO, INC.",
        "address_1": "2901 TASMAN DRIVE, STE.#205",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00D0BB": {
        "oui_hex": "00-D0-BB",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D06E": {
        "oui_hex": "00-D0-6E",
        "organization": "TRENDVIEW RECORDERS LTD.",
        "address_1": "4 AIRFIELD WAY",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00D05C": {
        "oui_hex": "00-D0-5C",
        "organization": "KATHREIN TechnoTrend GmbH",
        "address_1": "Ing.- Anton-Kathrein Str. 2",
        "address_2": "",
        "country": "DE"
    },
    "00D0EA": {
        "oui_hex": "00-D0-EA",
        "organization": "NEXTONE COMMUNICATIONS, INC.",
        "address_1": "9700 GREAT SENECA HGHWY",
        "address_2": "ROCKVILLE  MD  20850",
        "country": "US"
    },
    "00D064": {
        "oui_hex": "00-D0-64",
        "organization": "MULTITEL",
        "address_1": "2905 RUE DE CELLES",
        "address_2": "CANADA  CANADA  G2C-1W7",
        "country": "CA"
    },
    "00D05E": {
        "oui_hex": "00-D0-5E",
        "organization": "STRATABEAM TECHNOLOGY, INC.",
        "address_1": "1943 LANDINGS DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00D0AA": {
        "oui_hex": "00-D0-AA",
        "organization": "CHASE COMMUNICATIONS",
        "address_1": "ST. LEONARDS ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "00D05D": {
        "oui_hex": "00-D0-5D",
        "organization": "INTELLIWORXX, INC.",
        "address_1": "1819 MAIN STREET,  STE #1101",
        "address_2": "SARASOTA  FL  34236",
        "country": "US"
    },
    "00D0A1": {
        "oui_hex": "00-D0-A1",
        "organization": "OSKAR VIERLING GMBH + CO. KG",
        "address_1": "PRETZFELDER STR. 21",
        "address_2": "",
        "country": "DE"
    },
    "00D006": {
        "oui_hex": "00-D0-06",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D02A": {
        "oui_hex": "00-D0-2A",
        "organization": "Voxent Systems Ltd.",
        "address_1": "Unit 2, Rowan House",
        "address_2": "Chippenham  Wiltshire  SN14 0SQ",
        "country": "GB"
    },
    "00D08F": {
        "oui_hex": "00-D0-8F",
        "organization": "ARDENT TECHNOLOGIES, INC.",
        "address_1": "250 N. WOLFE ROAD",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00D0FA": {
        "oui_hex": "00-D0-FA",
        "organization": "Thales e-Security Ltd.",
        "address_1": "Meadow View House, Crendon Industrial Estate",
        "address_2": "Aylesbury  Buckinghamshire  HP18 9EQ",
        "country": "GB"
    },
    "00D0EB": {
        "oui_hex": "00-D0-EB",
        "organization": "LIGHTERA NETWORKS, INC.",
        "address_1": "10201 BUBB ROAD",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "0050A1": {
        "oui_hex": "00-50-A1",
        "organization": "CARLO GAVAZZI, INC.",
        "address_1": "222 PENNBRIGHT DR. - STE.#210",
        "address_2": "HOUSTON  TX  77090",
        "country": "US"
    },
    "00D0C0": {
        "oui_hex": "00-D0-C0",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "00D068": {
        "oui_hex": "00-D0-68",
        "organization": "IWILL CORPORATION",
        "address_1": "NO.10, WU-CHUAN 3 RD,",
        "address_2": "    TAIWAN",
        "country": "TW"
    },
    "005029": {
        "oui_hex": "00-50-29",
        "organization": "1394 PRINTER WORKING GROUP",
        "address_1": "P.O. BOX 23158",
        "address_2": "SAN JOSE  CA  95153",
        "country": "US"
    },
    "005081": {
        "oui_hex": "00-50-81",
        "organization": "MURATA MACHINERY, LTD.",
        "address_1": "136, TAKEDA-MUKAISHIRO-CHO",
        "address_2": "FUSHIMI-KU, KYOTO 612-8686",
        "country": "JP"
    },
    "0050AC": {
        "oui_hex": "00-50-AC",
        "organization": "MAPLE COMPUTER CORPORATION",
        "address_1": "2F, NO. 184, SEC. 2",
        "address_2": "Taipei",
        "country": "TJ"
    },
    "005049": {
        "oui_hex": "00-50-49",
        "organization": "Arbor Networks Inc",
        "address_1": "6 Omni Way",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "00500D": {
        "oui_hex": "00-50-0D",
        "organization": "SATORI ELECTORIC CO., LTD.",
        "address_1": "TIGUSADAI 38-8  MIDORI-KU",
        "address_2": "YOKOHAMA, KANAGAWA",
        "country": "JP"
    },
    "0050A3": {
        "oui_hex": "00-50-A3",
        "organization": "TransMedia Communications, Inc.",
        "address_1": "20 GREAT OAKS BLVD., #210",
        "address_2": "SAN JOSE  CA  95119",
        "country": "US"
    },
    "0050A4": {
        "oui_hex": "00-50-A4",
        "organization": "IO TECH, INC.",
        "address_1": "25971 CANNON ROAD",
        "address_2": "CLEVELAND  OH  44146",
        "country": "US"
    },
    "00505C": {
        "oui_hex": "00-50-5C",
        "organization": "TUNDO CORPORATION",
        "address_1": "7 GIBOREI ISRAEL STREET",
        "address_2": "",
        "country": "IL"
    },
    "0050B3": {
        "oui_hex": "00-50-B3",
        "organization": "VOICEBOARD CORPORATION",
        "address_1": "3151 WEST FIFTH STREET",
        "address_2": "OXNARD  CA  93030",
        "country": "US"
    },
    "00508C": {
        "oui_hex": "00-50-8C",
        "organization": "RSI SYSTEMS",
        "address_1": "5555 W. 78TH STREET, Suite F",
        "address_2": "EDINA  MN  55439",
        "country": "US"
    },
    "0050E1": {
        "oui_hex": "00-50-E1",
        "organization": "NS TECH ELECTRONICS SDN BHD",
        "address_1": "No. 37, Lorong 23, Geylang",
        "address_2": "Singapore 388371",
        "country": "SG"
    },
    "0050DE": {
        "oui_hex": "00-50-DE",
        "organization": "SIGNUM SYSTEMS CORP.",
        "address_1": "1211 Flynn Rd,",
        "address_2": "Camarillo  CA  93021",
        "country": "US"
    },
    "005075": {
        "oui_hex": "00-50-75",
        "organization": "KESTREL SOLUTIONS",
        "address_1": "2370 CHARLESTON ROAD",
        "address_2": "MT. VIEW  CA  94043",
        "country": "US"
    },
    "0050ED": {
        "oui_hex": "00-50-ED",
        "organization": "ANDA NETWORKS",
        "address_1": "2921 COPPER ROAD",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "005096": {
        "oui_hex": "00-50-96",
        "organization": "SALIX TECHNOLOGIES, INC.",
        "address_1": "904 WIND RIVER LANE- STE. #101",
        "address_2": "GAITHERSBURG  MD  20878",
        "country": "US"
    },
    "005012": {
        "oui_hex": "00-50-12",
        "organization": "CBL - GMBH",
        "address_1": "DARMSTAEDTER STR. 81",
        "address_2": "D-64839 MUENSTER",
        "country": "DE"
    },
    "0050F2": {
        "oui_hex": "00-50-F2",
        "organization": "MICROSOFT CORP.",
        "address_1": "ONE MICROSOFT WAY",
        "address_2": "REDMOND  WA  98052-6399",
        "country": "US"
    },
    "00504A": {
        "oui_hex": "00-50-4A",
        "organization": "ELTECO A.S.",
        "address_1": "ROSINSKA CESTA  P.O. BOX C-9",
        "address_2": "",
        "country": "SK"
    },
    "0050C1": {
        "oui_hex": "00-50-C1",
        "organization": "GEMFLEX NETWORKS, LTD.",
        "address_1": "230-6651 FRASERWOOD PL.",
        "address_2": "CANADA  V6W  1J3",
        "country": "CA"
    },
    "0050CF": {
        "oui_hex": "00-50-CF",
        "organization": "VANLINK COMMUNICATION TECHNOLOGY RESEARCH INSTITUTE",
        "address_1": "210 YADI OFFICE BUILDING",
        "address_2": "BEIJING 100088",
        "country": "CN"
    },
    "005024": {
        "oui_hex": "00-50-24",
        "organization": "NAVIC SYSTEMS, INC.",
        "address_1": "74 CRESCENT STREET",
        "address_2": "  NEEDHAM  MA",
        "country": "US"
    },
    "0090BD": {
        "oui_hex": "00-90-BD",
        "organization": "OMNIA COMMUNICATIONS, INC.",
        "address_1": "100 NICKERSON ROAD",
        "address_2": "MARLBOROUGH  MA  01752",
        "country": "US"
    },
    "0090B4": {
        "oui_hex": "00-90-B4",
        "organization": "WILLOWBROOK TECHNOLOGIES",
        "address_1": "7120 HAYVENHURST AVE.-STE.#401",
        "address_2": "VAN NUYS  CA  91406",
        "country": "US"
    },
    "009003": {
        "oui_hex": "00-90-03",
        "organization": "APLIO",
        "address_1": "18 Avenue Du 8 Mai 1945",
        "address_2": "",
        "country": "FR"
    },
    "009031": {
        "oui_hex": "00-90-31",
        "organization": "MYSTICOM, LTD.",
        "address_1": "P.O. 8364",
        "address_2": "NATANIA 42504",
        "country": "IL"
    },
    "00909D": {
        "oui_hex": "00-90-9D",
        "organization": "NovaTech Process Solutions, LLC",
        "address_1": "11500 Cronridge Drive",
        "address_2": "Owings Mills  MD  21117",
        "country": "US"
    },
    "0090DD": {
        "oui_hex": "00-90-DD",
        "organization": "MIHARU COMMUNICATIONS Inc",
        "address_1": "",
        "address_2": "KANAGAWA",
        "country": "JP"
    },
    "009028": {
        "oui_hex": "00-90-28",
        "organization": "NIPPON SIGNAL CO., LTD.",
        "address_1": "11 HIRAIDE-KOGIO-DANCHI",
        "address_2": "UISUNOMIYA TOCHIGI 321-8651",
        "country": "JP"
    },
    "00907D": {
        "oui_hex": "00-90-7D",
        "organization": "Lake Communications",
        "address_1": "1 Westbrook, Milton Road",
        "address_2": "",
        "country": "IE"
    },
    "0090C9": {
        "oui_hex": "00-90-C9",
        "organization": "DPAC Technologies",
        "address_1": "7321 Lincoln Way",
        "address_2": "Garden Grove  CA  92841",
        "country": "US"
    },
    "00507B": {
        "oui_hex": "00-50-7B",
        "organization": "MERLOT COMMUNICATIONS",
        "address_1": "BERKSHIRE CORPORATE PARK",
        "address_2": "BETHEL  CT  06801",
        "country": "US"
    },
    "0050CD": {
        "oui_hex": "00-50-CD",
        "organization": "DIGIANSWER A/S",
        "address_1": "SKALHUSE 5",
        "address_2": "",
        "country": "DK"
    },
    "00502D": {
        "oui_hex": "00-50-2D",
        "organization": "ACCEL, INC.",
        "address_1": "1F, NO. 7, R&D 1ST ROAD",
        "address_2": "HSINCHU",
        "country": "TW"
    },
    "00503A": {
        "oui_hex": "00-50-3A",
        "organization": "DATONG ELECTRONICS LTD.",
        "address_1": "CLAYTON WOOD CLOSE",
        "address_2": "Leeds LS16 6QE",
        "country": "GB"
    },
    "005087": {
        "oui_hex": "00-50-87",
        "organization": "TERASAKI ELECTRIC CO., LTD.",
        "address_1": "7-2-10 HANNAN-CHO ABENO-KU",
        "address_2": "OSAKA, 545-0021",
        "country": "JP"
    },
    "005026": {
        "oui_hex": "00-50-26",
        "organization": "COSYSTEMS, INC.",
        "address_1": "1263 OAKMEAD PARKWAY",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00902C": {
        "oui_hex": "00-90-2C",
        "organization": "DATA & CONTROL EQUIPMENT LTD.",
        "address_1": "COUNTY FARM, WENDOVER RD.",
        "address_2": "BUCKS. HP22 STA",
        "country": "GB"
    },
    "00901D": {
        "oui_hex": "00-90-1D",
        "organization": "PEC (NZ) LTD.",
        "address_1": "2 STATION ROAD",
        "address_2": "MARTON",
        "country": "NZ"
    },
    "009097": {
        "oui_hex": "00-90-97",
        "organization": "Sycamore Networks",
        "address_1": "220 Mill Rd",
        "address_2": "Chelmsford  MA  01824",
        "country": "US"
    },
    "009025": {
        "oui_hex": "00-90-25",
        "organization": "BAE Systems Australia (Electronic Systems) Pty Ltd",
        "address_1": "2 Second Ave",
        "address_2": "Mawson Lakes  South Australia  5095",
        "country": "AU"
    },
    "00904C": {
        "oui_hex": "00-90-4C",
        "organization": "Epigram, Inc.",
        "address_1": "870 West Maude Ave.",
        "address_2": "Sunnyvale  CA  94086",
        "country": "US"
    },
    "009084": {
        "oui_hex": "00-90-84",
        "organization": "ATECH SYSTEM",
        "address_1": "4F DAEBOONG BLDG. 1451-78",
        "address_2": " SEOUL  137-070",
        "country": "KR"
    },
    "00906A": {
        "oui_hex": "00-90-6A",
        "organization": "TURNSTONE SYSTEMS, INC.",
        "address_1": "274 Ferguson Drive",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "009087": {
        "oui_hex": "00-90-87",
        "organization": "ITIS",
        "address_1": "CENTRE ESPACE PERFORMANCE",
        "address_2": "35769 SAINT-GREGOIRE CEDEX",
        "country": "FR"
    },
    "009051": {
        "oui_hex": "00-90-51",
        "organization": "ULTIMATE TECHNOLOGY CORP.",
        "address_1": "100 RAWSON ROAD",
        "address_2": "VICTOR  NY  14564",
        "country": "US"
    },
    "009026": {
        "oui_hex": "00-90-26",
        "organization": "ADVANCED SWITCHING COMMUNICATIONS, INC.",
        "address_1": "8330 BOONE BOULEVARD--5TH FL.",
        "address_2": "VIENNA  VA  22182",
        "country": "US"
    },
    "0090D3": {
        "oui_hex": "00-90-D3",
        "organization": "GIESECKE & DEVRIENT GmbH",
        "address_1": "PRINZREGENTENSTRASSE 159",
        "address_2": "D-81677  MUNCHEN",
        "country": "DE"
    },
    "009067": {
        "oui_hex": "00-90-67",
        "organization": "WalkAbout Computers, Inc.",
        "address_1": "2655 N. OCEAN DRIVE--STE. #510",
        "address_2": "SINGER ISLAND  FL  33404",
        "country": "US"
    },
    "00902A": {
        "oui_hex": "00-90-2A",
        "organization": "COMMUNICATION DEVICES, INC.",
        "address_1": "85 Fulton Street",
        "address_2": "Boonton  NJ  07005-1912",
        "country": "US"
    },
    "00900D": {
        "oui_hex": "00-90-0D",
        "organization": "Overland Storage Inc.",
        "address_1": "9112 Spectrum Center Blvd",
        "address_2": "SAN DIEGO  CA  92123",
        "country": "US"
    },
    "0090CF": {
        "oui_hex": "00-90-CF",
        "organization": "NORTEL",
        "address_1": "250 SIDNEY STREET",
        "address_2": "Belleville  Ontario K8N 5B7",
        "country": "CA"
    },
    "009072": {
        "oui_hex": "00-90-72",
        "organization": "SIMRAD AS",
        "address_1": "P.O. BOX 111",
        "address_2": "  3191 HORTEN",
        "country": "NO"
    },
    "00902F": {
        "oui_hex": "00-90-2F",
        "organization": "NETCORE SYSTEMS, INC.",
        "address_1": "187 BALLARDVALE STREET",
        "address_2": "WILMINGTON  MA  01887",
        "country": "US"
    },
    "009098": {
        "oui_hex": "00-90-98",
        "organization": "SBC DESIGNS, INC.",
        "address_1": "3077-H LEEMAN FERRY ROAD",
        "address_2": "HUNTSVILLE  AL  35801",
        "country": "US"
    },
    "009045": {
        "oui_hex": "00-90-45",
        "organization": "Marconi Communications",
        "address_1": "1000 Fore Drive",
        "address_2": "Warrendale  PA  15086-7502",
        "country": "US"
    },
    "009036": {
        "oui_hex": "00-90-36",
        "organization": "ens, inc.",
        "address_1": "P.O. BOX 19207",
        "address_2": "RALEIGH  NC  27619",
        "country": "US"
    },
    "00908B": {
        "oui_hex": "00-90-8B",
        "organization": "Tattile SRL",
        "address_1": "2600 Fernbrook Lane",
        "address_2": "Plymouth  MN  55447",
        "country": "US"
    },
    "009044": {
        "oui_hex": "00-90-44",
        "organization": "ASSURED DIGITAL, INC.",
        "address_1": "9-11 GOLDSMITH ST.",
        "address_2": "LITTLETON  MA  01460",
        "country": "US"
    },
    "009091": {
        "oui_hex": "00-90-91",
        "organization": "DigitalScape, Inc.",
        "address_1": "6 MORGAN  - STE.#100",
        "address_2": "IRVINE  CA  92618",
        "country": "US"
    },
    "00907E": {
        "oui_hex": "00-90-7E",
        "organization": "VETRONIX CORP.",
        "address_1": "2030 ALAMEDE PADRE SERRA",
        "address_2": "SANTA BARBARA  CA  93103",
        "country": "US"
    },
    "009050": {
        "oui_hex": "00-90-50",
        "organization": "Teleste Corporation",
        "address_1": "Telestenkatu 1",
        "address_2": "LITTOINEN    FI-20660",
        "country": "FI"
    },
    "00904D": {
        "oui_hex": "00-90-4D",
        "organization": "SPEC S.A.",
        "address_1": "CASP 172 3-B",
        "address_2": "08013 BARCELONA",
        "country": "ES"
    },
    "0090FD": {
        "oui_hex": "00-90-FD",
        "organization": "CopperCom, Inc.",
        "address_1": "3255-1 SCOTT BLVD.,--STE.#103",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "009039": {
        "oui_hex": "00-90-39",
        "organization": "SHASTA NETWORKS",
        "address_1": "249 HUMBOLDT COURT",
        "address_2": "SUNNYVALE  CA  94089-1300",
        "country": "US"
    },
    "0090FC": {
        "oui_hex": "00-90-FC",
        "organization": "NETWORK COMPUTING DEVICES",
        "address_1": "301 RAVENDALE DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "009014": {
        "oui_hex": "00-90-14",
        "organization": "ROTORK INSTRUMENTS, LTD.",
        "address_1": "CHAUL END LANE",
        "address_2": "LU4 8EZ  England",
        "country": "GB"
    },
    "00908D": {
        "oui_hex": "00-90-8D",
        "organization": "VICKERS ELECTRONICS SYSTEMS",
        "address_1": "1151 W. MASON-MORROW RD.",
        "address_2": "LEBANON  OH  45036",
        "country": "US"
    },
    "009042": {
        "oui_hex": "00-90-42",
        "organization": "ECCS, Inc.",
        "address_1": "ONE SHEILA DRIVE",
        "address_2": "TINTON FALLS  NJ  07724",
        "country": "US"
    },
    "009033": {
        "oui_hex": "00-90-33",
        "organization": "INNOVAPHONE AG",
        "address_1": "Boeblinger Str. 76",
        "address_2": "SINDELFINGEN    D71065",
        "country": "DE"
    },
    "009002": {
        "oui_hex": "00-90-02",
        "organization": "ALLGON AB",
        "address_1": "GARDATORGET 1",
        "address_2": "412 50 GOTEBORG",
        "country": "SE"
    },
    "0010D4": {
        "oui_hex": "00-10-D4",
        "organization": "STORAGE COMPUTER CORPORATION",
        "address_1": "11 RIVERSIDE STREET",
        "address_2": "NASHUA  NH  03062",
        "country": "US"
    },
    "000629": {
        "oui_hex": "00-06-29",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "0010A9": {
        "oui_hex": "00-10-A9",
        "organization": "ADHOC TECHNOLOGIES",
        "address_1": "1150 FIRST STREET",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "00108A": {
        "oui_hex": "00-10-8A",
        "organization": "TeraLogic, Inc.",
        "address_1": "707 CALIFORNIA STREET",
        "address_2": "MOUNTAIN VIEW  CA  94041",
        "country": "US"
    },
    "001024": {
        "oui_hex": "00-10-24",
        "organization": "NAGOYA ELECTRIC WORKS CO., LTD",
        "address_1": "29-1 SHINODA, MIWA-CHO",
        "address_2": "AMA-GUN, AICHI 490-12",
        "country": "JP"
    },
    "0010D6": {
        "oui_hex": "00-10-D6",
        "organization": "Exelis",
        "address_1": "7310 Innovation Blvd., M/S 536",
        "address_2": "Ft Wayne  IN  46818",
        "country": "US"
    },
    "001048": {
        "oui_hex": "00-10-48",
        "organization": "HTRC AUTOMATION, INC.",
        "address_1": "285 LAVAL STREET",
        "address_2": "QUEBEC J0B 1H0",
        "country": "CA"
    },
    "001097": {
        "oui_hex": "00-10-97",
        "organization": "WinNet Metropolitan Communications Systems, Inc.",
        "address_1": "661 EAST ARQUES AVE.",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "001085": {
        "oui_hex": "00-10-85",
        "organization": "POLARIS COMMUNICATIONS, INC.",
        "address_1": "10200 SW ALLEN BLVD.",
        "address_2": "BEAVERTON  OR  97005",
        "country": "US"
    },
    "00100C": {
        "oui_hex": "00-10-0C",
        "organization": "ITO CO., LTD.",
        "address_1": "8-2 MIYANOSHITA-CHO",
        "address_2": "HIRAKATA-CITY, OSAKA",
        "country": "JP"
    },
    "001006": {
        "oui_hex": "00-10-06",
        "organization": "Thales Contact Solutions Ltd.",
        "address_1": "Tolbar Way",
        "address_2": "Southampton, SO30 2ZP",
        "country": "GB"
    },
    "009009": {
        "oui_hex": "00-90-09",
        "organization": "I Controls, Inc.",
        "address_1": "2nd Fl, I'Park 302, 11 Jeongja-Dong,",
        "address_2": "Seongnam  Gyeonggi-Do  463-859",
        "country": "KR"
    },
    "00908E": {
        "oui_hex": "00-90-8E",
        "organization": "Nortel Networks Broadband Access",
        "address_1": "39660 Eureka Drive",
        "address_2": "Newark  CA  94560",
        "country": "US"
    },
    "00907C": {
        "oui_hex": "00-90-7C",
        "organization": "DIGITALCAST, INC.",
        "address_1": "503, ILKWANG BLDG., 1656-2",
        "address_2": "SEOCHO-KU   SEOUL",
        "country": "KR"
    },
    "0090D2": {
        "oui_hex": "00-90-D2",
        "organization": "ARTEL VIDEO SYSTEMS",
        "address_1": "237 CEDAR HILL ST.",
        "address_2": "MARLBORO  MA  01752",
        "country": "US"
    },
    "0001FE": {
        "oui_hex": "00-01-FE",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "301 ROCKRIMMON BLVD, SOUTH",
        "address_2": "COLORADO SPRINGS  CO  80919",
        "country": "US"
    },
    "0090BE": {
        "oui_hex": "00-90-BE",
        "organization": "IBC/INTEGRATED BUSINESS COMPUTERS",
        "address_1": "2685 C PARK CENTER DRIVE",
        "address_2": "SIMI VALLEY  CA  93065",
        "country": "US"
    },
    "00103C": {
        "oui_hex": "00-10-3C",
        "organization": "IC ENSEMBLE, INC.",
        "address_1": "3255-2 SCOTT BLVD.--STE.#105",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "001019": {
        "oui_hex": "00-10-19",
        "organization": "SIRONA DENTAL SYSTEMS GmbH & Co. KG",
        "address_1": "FABRIKSTRASSE 31",
        "address_2": "64625 BENSHEIM",
        "country": "DE"
    },
    "0090DE": {
        "oui_hex": "00-90-DE",
        "organization": "CARDKEY SYSTEMS, INC.",
        "address_1": "1757 TAPO CANYON ROAD",
        "address_2": "SIMI VALLEY  CA  93063",
        "country": "US"
    },
    "00906B": {
        "oui_hex": "00-90-6B",
        "organization": "APPLIED RESOURCES, INC.",
        "address_1": "9821 WIDMER ROAD",
        "address_2": "LENEXA  KS  66215-1239",
        "country": "US"
    },
    "0010E2": {
        "oui_hex": "00-10-E2",
        "organization": "ArrayComm, Inc.",
        "address_1": "3141 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "0010D2": {
        "oui_hex": "00-10-D2",
        "organization": "NITTO TSUSHINKI CO., LTD",
        "address_1": "7-27-11, TODOROKI, SETAGAYA-KU",
        "address_2": "TOKYO 151",
        "country": "JP"
    },
    "0010D9": {
        "oui_hex": "00-10-D9",
        "organization": "IBM JAPAN, FUJISAWA MT+D",
        "address_1": "KIRIHARA-CHO 1, FUJISAWA CITY",
        "address_2": "KANAGAWA 252",
        "country": "JP"
    },
    "009066": {
        "oui_hex": "00-90-66",
        "organization": "Troika Networks, Inc.",
        "address_1": "2829 Townsgate Road,",
        "address_2": "Westlake Village  CA  91361",
        "country": "US"
    },
    "001094": {
        "oui_hex": "00-10-94",
        "organization": "Performance Analysis Broadband, Spirent plc",
        "address_1": "27349 Agoura Road",
        "address_2": "Calabasas Hills  CA  91301",
        "country": "US"
    },
    "001050": {
        "oui_hex": "00-10-50",
        "organization": "RION CO., LTD.",
        "address_1": "3-20-41 HIGASHIMOTOMACHI",
        "address_2": "KOKUBUNJI, TOKYO 185",
        "country": "JP"
    },
    "00109C": {
        "oui_hex": "00-10-9C",
        "organization": "M-SYSTEM CO., LTD.",
        "address_1": "1-1-25 SHIN URASHIMA CHOU",
        "address_2": " YOKOHAMA 221",
        "country": "JP"
    },
    "0010CE": {
        "oui_hex": "00-10-CE",
        "organization": "VOLAMP, LTD.",
        "address_1": "UNIT 3 RIVERSIDE BUSINESS PARK",
        "address_2": "FARNHAM, SURREY  ENGLAND",
        "country": "GB"
    },
    "0010B2": {
        "oui_hex": "00-10-B2",
        "organization": "COACTIVE AESTHETICS",
        "address_1": "4000 BRIDGEWAY - STE. #303",
        "address_2": "SAUSALITA  CA  94965",
        "country": "US"
    },
    "00105F": {
        "oui_hex": "00-10-5F",
        "organization": "ZODIAC DATA SYSTEMS",
        "address_1": "5 Av Des Andes",
        "address_2": "Les Ulis    91940",
        "country": "FR"
    },
    "00103E": {
        "oui_hex": "00-10-3E",
        "organization": "NETSCHOOLS CORPORATION",
        "address_1": "2003 LANDINGS DRIVE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "0010CB": {
        "oui_hex": "00-10-CB",
        "organization": "FACIT K.K.",
        "address_1": "HIMEI NIHOMBASHI BLDG. 3F",
        "address_2": "CHUO-KU, TOKYO 103",
        "country": "JP"
    },
    "0010E0": {
        "oui_hex": "00-10-E0",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "00107C": {
        "oui_hex": "00-10-7C",
        "organization": "P-COM, INC.",
        "address_1": "3175 S. WINCHESTER BLVD.",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "0010BD": {
        "oui_hex": "00-10-BD",
        "organization": "THE TELECOMMUNICATION TECHNOLOGY COMMITTEE (TTC)",
        "address_1": "1-1-12 Shiba Kouen, Minato-ku",
        "address_2": "MINATO-KU,    TOKYO  105-0011",
        "country": "JP"
    },
    "001008": {
        "oui_hex": "00-10-08",
        "organization": "VIENNA SYSTEMS CORPORATION",
        "address_1": "6651 FRASERWOOD PLACE",
        "address_2": "RICHMOND, B.C. V6W 1J3",
        "country": "CA"
    },
    "0010D1": {
        "oui_hex": "00-10-D1",
        "organization": "Top Layer Networks, Inc.",
        "address_1": "4 MECHANIC ST.- STE#212",
        "address_2": "NATICK  MA  01760",
        "country": "US"
    },
    "00106A": {
        "oui_hex": "00-10-6A",
        "organization": "DIGITAL MICROWAVE CORPORATION",
        "address_1": "170 ROSE ORCHARD WAY",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00106F": {
        "oui_hex": "00-10-6F",
        "organization": "TRENTON TECHNOLOGY INC.",
        "address_1": "2350 CENTENNIAL DRIVE",
        "address_2": "GAINESVILLE  GA  30504",
        "country": "US"
    },
    "001034": {
        "oui_hex": "00-10-34",
        "organization": "GNP Computers",
        "address_1": "555 E.Huntington Drive",
        "address_2": "Monrovia  CA  91016",
        "country": "US"
    },
    "001044": {
        "oui_hex": "00-10-44",
        "organization": "InnoLabs Corporation",
        "address_1": "2F-4, NO. 16, LANE 609, CHUNG-HSIN RD.",
        "address_2": "Taipei Hsien",
        "country": "TW"
    },
    "0010A1": {
        "oui_hex": "00-10-A1",
        "organization": "KENDIN SEMICONDUCTOR, INC.",
        "address_1": "1550 S. BASCOM AVE., STE. #250",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "0010A8": {
        "oui_hex": "00-10-A8",
        "organization": "RELIANCE COMPUTER CORP.",
        "address_1": "3032 BUNKER HILL LANE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00106E": {
        "oui_hex": "00-10-6E",
        "organization": "TADIRAN COM. LTD.",
        "address_1": "26 HASHOFTIM ST.",
        "address_2": "HOLON  58102",
        "country": "IL"
    },
    "00109A": {
        "oui_hex": "00-10-9A",
        "organization": "NETLINE",
        "address_1": "7, Rue de Bievres",
        "address_2": "92140 CLAMART",
        "country": "FR"
    },
    "001089": {
        "oui_hex": "00-10-89",
        "organization": "WebSonic",
        "address_1": "3466 EDWARD AVE.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0010E6": {
        "oui_hex": "00-10-E6",
        "organization": "APPLIED INTELLIGENT SYSTEMS, INC.",
        "address_1": "3923 RANCHERO DRIVE",
        "address_2": "ANN ARBOR  MI  48108",
        "country": "US"
    },
    "00103B": {
        "oui_hex": "00-10-3B",
        "organization": "HIPPI NETWORKING FORUM",
        "address_1": "PO BOX 10173",
        "address_2": "ALBUQUERQUE  NM  87184-0173",
        "country": "US"
    },
    "00E083": {
        "oui_hex": "00-E0-83",
        "organization": "JATO TECHNOLOGIES, INC.",
        "address_1": "505 EAST HUNTLAND DR. STE #550",
        "address_2": "AUSTIN  TX  78752",
        "country": "US"
    },
    "00E072": {
        "oui_hex": "00-E0-72",
        "organization": "LYNK",
        "address_1": "RABIN BUILDING",
        "address_2": "D.N. MISGAV 201",
        "country": "IL"
    },
    "00E0AD": {
        "oui_hex": "00-E0-AD",
        "organization": "EES TECHNOLOGY, LTD.",
        "address_1": "25 EASTWAYS",
        "address_2": "WITHAM, ESSEX, CM8 3AL",
        "country": "GB"
    },
    "00E094": {
        "oui_hex": "00-E0-94",
        "organization": "OSAI SRL",
        "address_1": "VIA TORINO",
        "address_2": "603-IVREA (TO)",
        "country": "IT"
    },
    "00E032": {
        "oui_hex": "00-E0-32",
        "organization": "MISYS FINANCIAL SYSTEMS, LTD.",
        "address_1": "BUCKHOLT DRIVE,",
        "address_2": "WARNDON, WORCESTER WR49SR",
        "country": "GB"
    },
    "00E0C0": {
        "oui_hex": "00-E0-C0",
        "organization": "SEIWA ELECTRIC MFG. CO., LTD.",
        "address_1": "86 TARADA SHIN-IKE,",
        "address_2": "KYOTO PREFECTURE",
        "country": "JP"
    },
    "00E0D1": {
        "oui_hex": "00-E0-D1",
        "organization": "TELSIS LIMITED",
        "address_1": "16 BARNES WALLACE ROAD",
        "address_2": "FAREHAM, HAMPSHIRE PO15 5TT  ENGLAND",
        "country": "GB"
    },
    "00E0F0": {
        "oui_hex": "00-E0-F0",
        "organization": "ABLER TECHNOLOGY, INC.",
        "address_1": "4F, NO. 54  SEC. 4",
        "address_2": "TAIPEI",
        "country": "TW"
    },
    "00E002": {
        "oui_hex": "00-E0-02",
        "organization": "CROSSROADS SYSTEMS, INC.",
        "address_1": "9390 RESEARCH BLVD.",
        "address_2": "AUSTIN  TX  78759",
        "country": "US"
    },
    "00E0D6": {
        "oui_hex": "00-E0-D6",
        "organization": "COMPUTER & COMMUNICATION RESEARCH LAB.",
        "address_1": "",
        "address_2": "CHUTUNG, HSINCHU",
        "country": "TW"
    },
    "00E074": {
        "oui_hex": "00-E0-74",
        "organization": "TIERNAN COMMUNICATIONS, INC.",
        "address_1": "11025 ROSELLE ST.",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "00E0D9": {
        "oui_hex": "00-E0-D9",
        "organization": "TAZMO CO., LTD.",
        "address_1": "6186 KINOKO, IBARA-SHI",
        "address_2": "OKAYAMA 715",
        "country": "JP"
    },
    "00E055": {
        "oui_hex": "00-E0-55",
        "organization": "INGENIERIA ELECTRONICA COMERCIAL INELCOM S.A.",
        "address_1": "CL. PIQUER NO.3",
        "address_2": "28033 MADRID",
        "country": "ES"
    },
    "00E0B4": {
        "oui_hex": "00-E0-B4",
        "organization": "TECHNO SCOPE CO., LTD.",
        "address_1": "13-6-7 KISHIMATI URAWASI",
        "address_2": "SAITAMA 336",
        "country": "JP"
    },
    "00E071": {
        "oui_hex": "00-E0-71",
        "organization": "EPIS MICROCOMPUTER",
        "address_1": "LAUTLINGER STRASSE 147",
        "address_2": "72458 ALBSTADT",
        "country": "DE"
    },
    "00E066": {
        "oui_hex": "00-E0-66",
        "organization": "ProMax Systems, Inc.",
        "address_1": "16 TECHNOLOGY DRIVE--BLDG.#106",
        "address_2": "IRVINE  CA  92656",
        "country": "US"
    },
    "00E093": {
        "oui_hex": "00-E0-93",
        "organization": "ACKFIN NETWORKS",
        "address_1": "575 N. PASTORIA AVE.",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00E042": {
        "oui_hex": "00-E0-42",
        "organization": "Pacom Systems Ltd.",
        "address_1": "UNIT 22 38/46 SOUTH ST.",
        "address_2": "RYDALMERE 2116  NSW",
        "country": "AU"
    },
    "00E0EB": {
        "oui_hex": "00-E0-EB",
        "organization": "DIGICOM SYSTEMS, INCORPORATED",
        "address_1": "188 TOPAZ STREET",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "00E01C": {
        "oui_hex": "00-E0-1C",
        "organization": "Cradlepoint, Inc",
        "address_1": "1199 Shoreline Lane",
        "address_2": "Boise  ID  83702",
        "country": "US"
    },
    "00E027": {
        "oui_hex": "00-E0-27",
        "organization": "DUX, INC.",
        "address_1": "5-18-19, NISHIKAMATA, OTA-KU",
        "address_2": "TOKYO-TO, 144",
        "country": "JP"
    },
    "00E04B": {
        "oui_hex": "00-E0-4B",
        "organization": "JUMP INDUSTRIELLE COMPUTERTECHNIK GmbH",
        "address_1": "",
        "address_2": "D94469 DEGGENDORF",
        "country": "DE"
    },
    "00E097": {
        "oui_hex": "00-E0-97",
        "organization": "CARRIER ACCESS CORPORATION",
        "address_1": "5395 PEARL PARKWAY",
        "address_2": "BOULDER  CO  80301",
        "country": "US"
    },
    "00E089": {
        "oui_hex": "00-E0-89",
        "organization": "ION Networks, Inc.",
        "address_1": "1551 South Washington Ave.",
        "address_2": "Piscataway  NJ  08854",
        "country": "US"
    },
    "00E070": {
        "oui_hex": "00-E0-70",
        "organization": "DH TECHNOLOGY",
        "address_1": "3003 ROLLIE GATES DRIVE",
        "address_2": "PASO ROBLES  CA  93446",
        "country": "US"
    },
    "00E05C": {
        "oui_hex": "00-E0-5C",
        "organization": "PHC Corporation",
        "address_1": "2-38-5 Nishishimbashi",
        "address_2": "Minato-ku  Tokyo  105-8433",
        "country": "JP"
    },
    "00E024": {
        "oui_hex": "00-E0-24",
        "organization": "GADZOOX NETWORKS",
        "address_1": "5850 HELLYER AVENUE",
        "address_2": "SAN JOSE  CA  95138",
        "country": "US"
    },
    "00605B": {
        "oui_hex": "00-60-5B",
        "organization": "IntraServer Technology, Inc.",
        "address_1": "125 HOPPING BROOK PARK",
        "address_2": "HOLLISTON  MA  01746",
        "country": "US"
    },
    "0060D7": {
        "oui_hex": "00-60-D7",
        "organization": "ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE (EPFL)",
        "address_1": "ECUBLENS",
        "address_2": "CH-1015 LAUSANNE",
        "country": "CH"
    },
    "00E0BA": {
        "oui_hex": "00-E0-BA",
        "organization": "BERGHOF AUTOMATIONSTECHNIK GmbH",
        "address_1": "HARRET STRASSE 1",
        "address_2": "D 72800 ENINGEN",
        "country": "DE"
    },
    "00E021": {
        "oui_hex": "00-E0-21",
        "organization": "FREEGATE CORP.",
        "address_1": "710 LAKEWAY  STE.#230",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "00E05B": {
        "oui_hex": "00-E0-5B",
        "organization": "WEST END SYSTEMS CORP.",
        "address_1": "39 WINNER'S CIRCLE DR.,",
        "address_2": "ARNPRIOR, ONTARIO    K7S 3G9",
        "country": "CA"
    },
    "00E044": {
        "oui_hex": "00-E0-44",
        "organization": "LSICS CORPORATION",
        "address_1": "3-8-3 NINOMIYA, TSKUKUBA SHI",
        "address_2": "IBARAGI-KEN, 305",
        "country": "JP"
    },
    "00E0CA": {
        "oui_hex": "00-E0-CA",
        "organization": "BEST DATA PRODUCTS",
        "address_1": "21800 NORDHOFF STREET",
        "address_2": "CHATSWORTH  CA  91311",
        "country": "US"
    },
    "00E0A7": {
        "oui_hex": "00-E0-A7",
        "organization": "IPC INFORMATION SYSTEMS, INC.",
        "address_1": "METRO CENTER",
        "address_2": "STAMFORD  CT  06907",
        "country": "US"
    },
    "00E062": {
        "oui_hex": "00-E0-62",
        "organization": "HOST ENGINEERING",
        "address_1": "200 EAST MAIN STREET -STE.#700",
        "address_2": "JOHNSON CITY  TN  37604",
        "country": "US"
    },
    "00E0CE": {
        "oui_hex": "00-E0-CE",
        "organization": "ARN",
        "address_1": "51, RUE GASTON LAURIAU",
        "address_2": "F-93512 MONTREUIL CEDEX",
        "country": "FR"
    },
    "00E05F": {
        "oui_hex": "00-E0-5F",
        "organization": "e-Net, Inc.",
        "address_1": "12325 HYMEADOW DRIVE",
        "address_2": "AUSTIN  TX  78750",
        "country": "US"
    },
    "00E01F": {
        "oui_hex": "00-E0-1F",
        "organization": "AVIDIA Systems, Inc.",
        "address_1": "135 NORTH PLAINS INDUSTRIAL RD",
        "address_2": "WALLINGFORD  CT  06492",
        "country": "US"
    },
    "00E0D0": {
        "oui_hex": "00-E0-D0",
        "organization": "NETSPEED, INC.",
        "address_1": "12303 TECHNOLOGY BLVD.",
        "address_2": "AUSTIN  TX  78727",
        "country": "US"
    },
    "00E060": {
        "oui_hex": "00-E0-60",
        "organization": "SHERWOOD",
        "address_1": "21056 FORBES STREET",
        "address_2": "HAYWARD  CA  94545",
        "country": "US"
    },
    "00E06A": {
        "oui_hex": "00-E0-6A",
        "organization": "KAPSCH AG",
        "address_1": "WAGENSEILGASSE 1",
        "address_2": "1120-VIENNA",
        "country": "AT"
    },
    "00E001": {
        "oui_hex": "00-E0-01",
        "organization": "STRAND LIGHTING LIMITED",
        "address_1": "GRANT WAY",
        "address_2": "MIDDLESEX  England TW7 5QD",
        "country": "GB"
    },
    "00E0D8": {
        "oui_hex": "00-E0-D8",
        "organization": "LANBit Computer, Inc.",
        "address_1": "12F, 552 CHUNG HSIAO E., RD.",
        "address_2": "",
        "country": "TW"
    },
    "00E0E7": {
        "oui_hex": "00-E0-E7",
        "organization": "RAYTHEON E-SYSTEMS, INC.",
        "address_1": "1301 E. COLLINS",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "00E03C": {
        "oui_hex": "00-E0-3C",
        "organization": "AdvanSys",
        "address_1": "1150 RINGWOOD COURT",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "00E073": {
        "oui_hex": "00-E0-73",
        "organization": "NATIONAL AMUSEMENT NETWORK, INC.",
        "address_1": "401 N. MICHIGAN AVENUE",
        "address_2": "CHICAGO  IL  60611",
        "country": "US"
    },
    "006066": {
        "oui_hex": "00-60-66",
        "organization": "LACROIX Trafic",
        "address_1": "1 ere Avenue, 11 eme rue",
        "address_2": "06516 CARROS",
        "country": "FR"
    },
    "0060F4": {
        "oui_hex": "00-60-F4",
        "organization": "ADVANCED COMPUTER SOLUTIONS, Inc.",
        "address_1": "12675 DANIELSON COURT",
        "address_2": "POWAY  CA  92064",
        "country": "US"
    },
    "006060": {
        "oui_hex": "00-60-60",
        "organization": "Data Innovations North America",
        "address_1": "120 Kimball Avenue Suite 100",
        "address_2": "South Burlington  VT  05403",
        "country": "US"
    },
    "006035": {
        "oui_hex": "00-60-35",
        "organization": "DALLAS SEMICONDUCTOR, INC.",
        "address_1": "4401 SOUTH BELTWOOD PARKWAY",
        "address_2": "DALLAS  TX  75244-3292",
        "country": "US"
    },
    "006007": {
        "oui_hex": "00-60-07",
        "organization": "ACRES GAMING, INC.",
        "address_1": "815 NW 9TH STREET",
        "address_2": "CORVALLIS  OR  97330",
        "country": "US"
    },
    "006058": {
        "oui_hex": "00-60-58",
        "organization": "COPPER MOUNTAIN COMMUNICATIONS, INC.",
        "address_1": "6650 LUSK BLVD.-STE #B103",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "0060FB": {
        "oui_hex": "00-60-FB",
        "organization": "PACKETEER, INC.",
        "address_1": "10201 N. DE ANZA BOULEVARD",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "0060C1": {
        "oui_hex": "00-60-C1",
        "organization": "WaveSpan Corporation",
        "address_1": "500 N. BERNARDO AVE.",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00603C": {
        "oui_hex": "00-60-3C",
        "organization": "HAGIWARA SYS-COM CO., LTD.",
        "address_1": "2-4-3 NISHIKI NAKA-KU",
        "address_2": "AICHI 460",
        "country": "JP"
    },
    "00607D": {
        "oui_hex": "00-60-7D",
        "organization": "SENTIENT NETWORKS INC.",
        "address_1": "2201 CANTU COURT-STE #205",
        "address_2": "SARASOTA  FL  34232",
        "country": "US"
    },
    "006019": {
        "oui_hex": "00-60-19",
        "organization": "Roche Diagnostics",
        "address_1": "9115 Hague Road",
        "address_2": "Indianapolis  IN  46250-0457",
        "country": "US"
    },
    "006059": {
        "oui_hex": "00-60-59",
        "organization": "TECHNICAL COMMUNICATIONS CORP.",
        "address_1": "100 DOMINO DRIVE",
        "address_2": "CONCORD  MA  01742",
        "country": "US"
    },
    "006003": {
        "oui_hex": "00-60-03",
        "organization": "TERAOKA WEIGH SYSTEM PTE, LTD.",
        "address_1": "3A TUAS AVENUE 8",
        "address_2": "  SINGAPORE 639128",
        "country": "SG"
    },
    "00607A": {
        "oui_hex": "00-60-7A",
        "organization": "DVS GMBH",
        "address_1": "KREPENSTRASSE 8",
        "address_2": "D-30165 HANNOVER",
        "country": "DE"
    },
    "0060F3": {
        "oui_hex": "00-60-F3",
        "organization": "Performance Analysis Broadband, Spirent plc",
        "address_1": "27349 Agoura Road",
        "address_2": "Calabasas Hills  CA  91301",
        "country": "US"
    },
    "00607C": {
        "oui_hex": "00-60-7C",
        "organization": "WaveAccess, Ltd.",
        "address_1": "P.O. BOX 2473",
        "address_2": "RA'ANANA 43663",
        "country": "IL"
    },
    "0060A0": {
        "oui_hex": "00-60-A0",
        "organization": "SWITCHED NETWORK TECHNOLOGIES, INC.",
        "address_1": "13805 1ST AVENUE NORTH",
        "address_2": "PLYMOUTH  MN  55441-5455",
        "country": "US"
    },
    "006017": {
        "oui_hex": "00-60-17",
        "organization": "TOKIMEC INC.",
        "address_1": "2-16, MINAMI-KAMATA, OHTA-KU",
        "address_2": "TOKYO 144",
        "country": "JP"
    },
    "006026": {
        "oui_hex": "00-60-26",
        "organization": "VIKING Modular Solutions",
        "address_1": "11 COLUMBIA",
        "address_2": "LAGUNA HILLS  CA  92656",
        "country": "US"
    },
    "00606E": {
        "oui_hex": "00-60-6E",
        "organization": "DAVICOM SEMICONDUCTOR, INC.",
        "address_1": "2457 AUGUSTINE DRIVE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0060C7": {
        "oui_hex": "00-60-C7",
        "organization": "AMATI COMMUNICATIONS CORP.",
        "address_1": "2043 SAMARITAN DRIVE",
        "address_2": "SAN JOSE  CA  95124",
        "country": "US"
    },
    "1000E8": {
        "oui_hex": "10-00-E8",
        "organization": "NATIONAL SEMICONDUCTOR",
        "address_1": "2900 SEMICONDUCTOR DRIVE",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "006073": {
        "oui_hex": "00-60-73",
        "organization": "REDCREEK COMMUNICATIONS, INC.",
        "address_1": "3900 NEWPARK MALL ROAD",
        "address_2": "NEWARK  CA  94560",
        "country": "US"
    },
    "0060FD": {
        "oui_hex": "00-60-FD",
        "organization": "NetICs, Inc.",
        "address_1": "42 NAGOG PARK",
        "address_2": "ACTON  MA  01720",
        "country": "US"
    },
    "0060CB": {
        "oui_hex": "00-60-CB",
        "organization": "HITACHI ZOSEN CORPORATION",
        "address_1": "3-4, SAKURAJIMA 1-CHOME",
        "address_2": "KONOHANA-KU, OSAKA 554",
        "country": "JP"
    },
    "0060C8": {
        "oui_hex": "00-60-C8",
        "organization": "KUKA WELDING SYSTEMS & ROBOTS",
        "address_1": "BLUECHERSTRASSE 144",
        "address_2": "D-86165 AUGSBURG",
        "country": "DE"
    },
    "006023": {
        "oui_hex": "00-60-23",
        "organization": "PERICOM SEMICONDUCTOR CORP.",
        "address_1": "2380 BERING DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "006063": {
        "oui_hex": "00-60-63",
        "organization": "PSION DACOM PLC.",
        "address_1": "PSION DACOM HOUSE",
        "address_2": "CROWNHILL  MILTON KEYNES  MK8 0EF",
        "country": "GB"
    },
    "006031": {
        "oui_hex": "00-60-31",
        "organization": "HRK SYSTEMS",
        "address_1": "P.O. BOX 514",
        "address_2": "WESTVILLE 3630",
        "country": "ZA"
    },
    "00600E": {
        "oui_hex": "00-60-0E",
        "organization": "WAVENET INTERNATIONAL, INC.",
        "address_1": "5825 KENNEDY ROAD",
        "address_2": "MISSISSAUGA, ONTARIO L4Z 2G3",
        "country": "CA"
    },
    "0060A3": {
        "oui_hex": "00-60-A3",
        "organization": "CONTINUUM TECHNOLOGY CORP.",
        "address_1": "220 CONTINUUM DRIVE",
        "address_2": "FLETCHER  NC  28732",
        "country": "US"
    },
    "00603D": {
        "oui_hex": "00-60-3D",
        "organization": "3CX",
        "address_1": "2085 HAMILTON AVE., -STE.#220",
        "address_2": "SAN JOSE  CA  95125",
        "country": "US"
    },
    "0060ED": {
        "oui_hex": "00-60-ED",
        "organization": "RICARDO TEST AUTOMATION LTD.",
        "address_1": "LOWESMOOR WHARF",
        "address_2": "WORCESTER, WR12RS",
        "country": "GB"
    },
    "006012": {
        "oui_hex": "00-60-12",
        "organization": "POWER COMPUTING CORPORATION",
        "address_1": "10261 BUBB ROAD",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00604D": {
        "oui_hex": "00-60-4D",
        "organization": "MMC NETWORKS, INC.",
        "address_1": "1134 EAST ARQUES AVENUE",
        "address_2": "SUNNYVALE  CA  94086-4602",
        "country": "US"
    },
    "0060F7": {
        "oui_hex": "00-60-F7",
        "organization": "DATAFUSION SYSTEMS",
        "address_1": "P.O. BOX 582",
        "address_2": "STELLENBOSCH,  7599",
        "country": "ZA"
    },
    "006020": {
        "oui_hex": "00-60-20",
        "organization": "PIVOTAL NETWORKING, INC.",
        "address_1": "7246 SHARON DR., STE",
        "address_2": "SAN JOSE  CA  95129",
        "country": "US"
    },
    "0060C0": {
        "oui_hex": "00-60-C0",
        "organization": "Nera Networks AS",
        "address_1": "Kokstadveien 23",
        "address_2": "Bergen    5020",
        "country": "NO"
    },
    "006077": {
        "oui_hex": "00-60-77",
        "organization": "PRISA NETWORKS",
        "address_1": "6620 Mesa Ridge Road,",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "006094": {
        "oui_hex": "00-60-94",
        "organization": "IBM Corp",
        "address_1": "3039 E Cornwallis Road",
        "address_2": "Research Triangle Park  NC  27709-2195",
        "country": "US"
    },
    "0060AB": {
        "oui_hex": "00-60-AB",
        "organization": "LARSCOM INCORPORATED",
        "address_1": "1845 MCCANDLESS DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "0060DD": {
        "oui_hex": "00-60-DD",
        "organization": "MYRICOM, INC.",
        "address_1": "325B N. SANTA ANITA AVE.",
        "address_2": "ARCADIA  CA  91006",
        "country": "US"
    },
    "006046": {
        "oui_hex": "00-60-46",
        "organization": "VMETRO, INC.",
        "address_1": "1880 DAIRY ASHFORD- STE #535",
        "address_2": "HOUSTON  TX  77077",
        "country": "US"
    },
    "006068": {
        "oui_hex": "00-60-68",
        "organization": "Dialogic Corporation",
        "address_1": "9800 Cavendish Blvd, 5th Floor",
        "address_2": "Montreal  Quebec  H4M 2V9",
        "country": "CA"
    },
    "00605A": {
        "oui_hex": "00-60-5A",
        "organization": "CELCORE, INC.",
        "address_1": "8001 CENTERVIEW PARKWAY",
        "address_2": "MEMPHIS  TN  38018",
        "country": "US"
    },
    "006095": {
        "oui_hex": "00-60-95",
        "organization": "ACCU-TIME SYSTEMS, INC.",
        "address_1": "420 SOMERS ROAD",
        "address_2": "ELLINGTON  CT  06029",
        "country": "US"
    },
    "00608A": {
        "oui_hex": "00-60-8A",
        "organization": "CITADEL COMPUTER",
        "address_1": "29 ARMORY RD",
        "address_2": "MILFORD  MA  03055",
        "country": "US"
    },
    "006093": {
        "oui_hex": "00-60-93",
        "organization": "VARIAN",
        "address_1": "2700 MITCHELL DR.",
        "address_2": "WALNUT GREEK  CA  94598",
        "country": "US"
    },
    "00A03F": {
        "oui_hex": "00-A0-3F",
        "organization": "COMPUTER SOCIETY MICROPROCESSOR & MICROPROCESSOR STANDARDS C",
        "address_1": "% APPLE COMPUTER, INC.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00A02D": {
        "oui_hex": "00-A0-2D",
        "organization": "1394 Trade Association",
        "address_1": "3925 WEST BRAKER LANE",
        "address_2": "AUSTIN  TX  78759",
        "country": "US"
    },
    "00A07C": {
        "oui_hex": "00-A0-7C",
        "organization": "TONYANG NYLON CO., LTD.",
        "address_1": "ELECTRONIC RESEARCH LAB",
        "address_2": "ANYANG-CITY, KYUNGKI-DO 430-080",
        "country": "KR"
    },
    "00A09A": {
        "oui_hex": "00-A0-9A",
        "organization": "NIHON KOHDEN AMERICA",
        "address_1": "2446 DUPONT DRIVE",
        "address_2": "IRVINE  CA  92715",
        "country": "US"
    },
    "00A093": {
        "oui_hex": "00-A0-93",
        "organization": "B/E AEROSPACE, Inc.",
        "address_1": "17481 RED HILL",
        "address_2": "IRVINE  CA  92714-5630",
        "country": "US"
    },
    "00A078": {
        "oui_hex": "00-A0-78",
        "organization": "Marconi Communications",
        "address_1": "1000 Fore Drive",
        "address_2": "Warrendale  PA  15086-7502",
        "country": "US"
    },
    "00A0BF": {
        "oui_hex": "00-A0-BF",
        "organization": "WIRELESS DATA GROUP MOTOROLA",
        "address_1": "1201 E. WILEY ROAD",
        "address_2": "SCHAUMBURG  IL  60173",
        "country": "US"
    },
    "00A05F": {
        "oui_hex": "00-A0-5F",
        "organization": "BTG Electronics Design BV",
        "address_1": "P.O. Box 1543",
        "address_2": "BA Oud Beijerland",
        "country": "NL"
    },
    "00A0CD": {
        "oui_hex": "00-A0-CD",
        "organization": "DR. JOHANNES HEIDENHAIN GmbH",
        "address_1": "DR.-JOHANNES-HEIDENHAIN STR.",
        "address_2": "83301 TRAUNREUT",
        "country": "DE"
    },
    "00A0DA": {
        "oui_hex": "00-A0-DA",
        "organization": "INTEGRATED SYSTEMS Technology, Inc.",
        "address_1": "4601 PRESIDENTS DRIVE",
        "address_2": "LANHAM  MD  20706",
        "country": "US"
    },
    "00A02A": {
        "oui_hex": "00-A0-2A",
        "organization": "TRANCELL SYSTEMS",
        "address_1": "3180 DE LA CRUZ BLVD.-STE#200",
        "address_2": "SANTA CLARA  CA  95054-2402",
        "country": "US"
    },
    "00A01C": {
        "oui_hex": "00-A0-1C",
        "organization": "NASCENT NETWORKS CORPORATION",
        "address_1": "277 MAIN STREET,  3RD FLR.",
        "address_2": "MARLBORO  MA  01752",
        "country": "US"
    },
    "00A08F": {
        "oui_hex": "00-A0-8F",
        "organization": "DESKNET SYSTEMS, INC.",
        "address_1": "80 BUSINESS PARK DRIVE",
        "address_2": "ARMONK  NY  10504",
        "country": "US"
    },
    "00A0CC": {
        "oui_hex": "00-A0-CC",
        "organization": "LITE-ON COMMUNICATIONS, INC.",
        "address_1": "720 S. HILLVIEW DRIVE",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "00A0E6": {
        "oui_hex": "00-A0-E6",
        "organization": "DIALOGIC CORPORATION",
        "address_1": "1515 ROUTE 10",
        "address_2": "PARSIPPANY  NJ  07054",
        "country": "US"
    },
    "00A04A": {
        "oui_hex": "00-A0-4A",
        "organization": "NISSHIN ELECTRIC CO., LTD.",
        "address_1": "5, MEOTOGOSHI, MUTSUSHI,",
        "address_2": "AICHI 481",
        "country": "JP"
    },
    "00A035": {
        "oui_hex": "00-A0-35",
        "organization": "CYLINK CORPORATION",
        "address_1": "3131 JAY STREET",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00A03D": {
        "oui_hex": "00-A0-3D",
        "organization": "OPTO-22",
        "address_1": "43044 BUSINESS PARK DR.",
        "address_2": "TEMECULA  CA  92590",
        "country": "US"
    },
    "00A056": {
        "oui_hex": "00-A0-56",
        "organization": "MICROPROSS",
        "address_1": "33, RUE GANTOIS",
        "address_2": "59000 LILLE",
        "country": "FR"
    },
    "00A0E1": {
        "oui_hex": "00-A0-E1",
        "organization": "WESTPORT RESEARCH ASSOCIATES, INC.",
        "address_1": "6102 ARLINGTON",
        "address_2": "RAYTOWN  MO  64133",
        "country": "US"
    },
    "00A0B7": {
        "oui_hex": "00-A0-B7",
        "organization": "CORDANT, INC.",
        "address_1": "11400 COMMERCE PARK DR.",
        "address_2": "RESTON  VA  22091-1506",
        "country": "US"
    },
    "00A026": {
        "oui_hex": "00-A0-26",
        "organization": "TELDAT, S.A.",
        "address_1": "PARQUE TECNOLOGICO MADRID",
        "address_2": "28760 TACS CAN TOS (MADRID)",
        "country": "ES"
    },
    "00A023": {
        "oui_hex": "00-A0-23",
        "organization": "APPLIED CREATIVE TECHNOLOGY, INC.",
        "address_1": "2626 LOMBARDY LANE--STE.#107",
        "address_2": "DALLAS  TX  75220",
        "country": "US"
    },
    "00A089": {
        "oui_hex": "00-A0-89",
        "organization": "XPOINT TECHNOLOGIES, INC.",
        "address_1": "902 CLINT MOORE RD.-STE#132",
        "address_2": "BOCA RATON  FL  33487",
        "country": "US"
    },
    "00A007": {
        "oui_hex": "00-A0-07",
        "organization": "APEXX TECHNOLOGY, INC.",
        "address_1": "506 S. 11TH",
        "address_2": "BOISE  ID  83707",
        "country": "US"
    },
    "00A047": {
        "oui_hex": "00-A0-47",
        "organization": "INTEGRATED FITNESS CORP.",
        "address_1": "26 6TH STREET",
        "address_2": "STAMFORD  CT  06905",
        "country": "US"
    },
    "00A032": {
        "oui_hex": "00-A0-32",
        "organization": "GES SINGAPORE PTE. LTD.",
        "address_1": "14 SUNGEI KADUT AVENUE",
        "address_2": "  SINGAPORE  2572",
        "country": "SG"
    },
    "00A0E3": {
        "oui_hex": "00-A0-E3",
        "organization": "XKL SYSTEMS CORP.",
        "address_1": "8420 154TH AVE. NE",
        "address_2": "REDMOND  WA  98052",
        "country": "US"
    },
    "00A014": {
        "oui_hex": "00-A0-14",
        "organization": "CSIR",
        "address_1": "P.O. BOX 395",
        "address_2": "  SOUTH  AFRICA",
        "country": "ZA"
    },
    "00A015": {
        "oui_hex": "00-A0-15",
        "organization": "WYLE",
        "address_1": "3000 BOWERS AVENUE",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "00A06A": {
        "oui_hex": "00-A0-6A",
        "organization": "Verilink Corporation",
        "address_1": "127 Jetplex Circle",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "00A018": {
        "oui_hex": "00-A0-18",
        "organization": "CREATIVE CONTROLLERS, INC.",
        "address_1": "128 KENDRICK LANE",
        "address_2": "PICAYUNE  MS  39466",
        "country": "US"
    },
    "00A0FE": {
        "oui_hex": "00-A0-FE",
        "organization": "BOSTON TECHNOLOGY, INC.",
        "address_1": "100 QUANNAPOWITT PARKWAY",
        "address_2": "WAKEFIELD  MA  01880",
        "country": "US"
    },
    "00A0EB": {
        "oui_hex": "00-A0-EB",
        "organization": "Encore Networks, Inc.",
        "address_1": "3800 Concorde Parkway,",
        "address_2": "Chantilly,  VA  20151",
        "country": "US"
    },
    "00A07D": {
        "oui_hex": "00-A0-7D",
        "organization": "SEEQ TECHNOLOGY, INC.",
        "address_1": "47131 BAYSIDE PARKWAY",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00A0D9": {
        "oui_hex": "00-A0-D9",
        "organization": "CONVEX COMPUTER CORPORATION",
        "address_1": "3000 WATERVIEW PARKWAY",
        "address_2": "RICHARDSON  TX  75083-3851",
        "country": "US"
    },
    "00A070": {
        "oui_hex": "00-A0-70",
        "organization": "COASTCOM",
        "address_1": "1151 HARBOR BAY PARKWAY",
        "address_2": "ALAMEDA  CA  94502-6511",
        "country": "US"
    },
    "0020DE": {
        "oui_hex": "00-20-DE",
        "organization": "JAPAN DIGITAL LABORAT'Y CO.LTD",
        "address_1": "JDL KAWASAKI R & D CENTER",
        "address_2": "KANAGAWA-KEN    215",
        "country": "JP"
    },
    "00200B": {
        "oui_hex": "00-20-0B",
        "organization": "OCTAGON SYSTEMS CORP.",
        "address_1": "7403 Church Ranch Blvd",
        "address_2": "Westminster  CO  80021",
        "country": "US"
    },
    "002094": {
        "oui_hex": "00-20-94",
        "organization": "CUBIX CORPORATION",
        "address_1": "2800 LOCKHEED WAY",
        "address_2": "CARSON CITY  NV  89706",
        "country": "US"
    },
    "0020F7": {
        "oui_hex": "00-20-F7",
        "organization": "CYBERDATA CORPORATION",
        "address_1": "3 Justin Court",
        "address_2": "MONTEREY  CA  93940",
        "country": "US"
    },
    "0020D7": {
        "oui_hex": "00-20-D7",
        "organization": "JAPAN MINICOMPUTER SYSTEMS CO., Ltd.",
        "address_1": "3-33-18 TAKAIDOHIGASHI",
        "address_2": "TOKYO 168",
        "country": "JP"
    },
    "0020C3": {
        "oui_hex": "00-20-C3",
        "organization": "COUNTER SOLUTIONS LTD.",
        "address_1": "263 HEAGE ROAD",
        "address_2": "RIPLEY, DERBYS DE5 3GH",
        "country": "GB"
    },
    "002047": {
        "oui_hex": "00-20-47",
        "organization": "STEINBRECHER CORP.",
        "address_1": "30 NORTH AVENUE",
        "address_2": "BURLINGTON  MA  01803",
        "country": "US"
    },
    "0020D5": {
        "oui_hex": "00-20-D5",
        "organization": "VIPA GMBH",
        "address_1": "WETTERKREUZ 27",
        "address_2": "",
        "country": "DE"
    },
    "00201A": {
        "oui_hex": "00-20-1A",
        "organization": "MRV Communications, Inc.",
        "address_1": "20415 Nordhoff St.",
        "address_2": "Chatsworth  CA  91311",
        "country": "US"
    },
    "0020F2": {
        "oui_hex": "00-20-F2",
        "organization": "Oracle Corporation",
        "address_1": "500 Oracle Parkway",
        "address_2": "Redwood Shores  CA  94065",
        "country": "US"
    },
    "0020B8": {
        "oui_hex": "00-20-B8",
        "organization": "PRIME OPTION, INC.",
        "address_1": "2341 W. 205TH STREET #116",
        "address_2": "TORRANCE  CA  90501",
        "country": "US"
    },
    "0020AD": {
        "oui_hex": "00-20-AD",
        "organization": "LINQ SYSTEMS",
        "address_1": "P.O. BOX 11040",
        "address_2": "TUCSON  AZ  85734",
        "country": "US"
    },
    "00207D": {
        "oui_hex": "00-20-7D",
        "organization": "ADVANCED COMPUTER APPLICATIONS",
        "address_1": "107 PENNS TRAIL",
        "address_2": "NEWTOWN  PA  18940",
        "country": "US"
    },
    "00202F": {
        "oui_hex": "00-20-2F",
        "organization": "ZETA COMMUNICATIONS, LTD.",
        "address_1": "ZENITH HOUSE",
        "address_2": "WREXHAM, CLWYD, LL12 8LX",
        "country": "GB"
    },
    "00209A": {
        "oui_hex": "00-20-9A",
        "organization": "THE 3DO COMPANY",
        "address_1": "600 GALVESTON DRIVE",
        "address_2": "REDWOOD CITY  CA  94063",
        "country": "US"
    },
    "002062": {
        "oui_hex": "00-20-62",
        "organization": "SCORPION LOGIC, LTD.",
        "address_1": "19 BROOKSIDE ROAD",
        "address_2": "HERTS WD1 4BW",
        "country": "GB"
    },
    "002081": {
        "oui_hex": "00-20-81",
        "organization": "TITAN ELECTRONICS",
        "address_1": "3033 SCIENCE PARK ROAD",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "0020D9": {
        "oui_hex": "00-20-D9",
        "organization": "PANASONIC TECHNOLOGIES, INC./MIECO-US",
        "address_1": "1703 N. RANDALL RD.",
        "address_2": "ELGIN  IL  60123",
        "country": "US"
    },
    "00206F": {
        "oui_hex": "00-20-6F",
        "organization": "FLOWPOINT CORPORATION",
        "address_1": "7291 CORONADO DRIVE, STE# 4",
        "address_2": "SAN JOSE  CA  95129",
        "country": "US"
    },
    "002020": {
        "oui_hex": "00-20-20",
        "organization": "MEGATRON COMPUTER INDUSTRIES PTY, LTD.",
        "address_1": "",
        "address_2": "",
        "country": "AU"
    },
    "00201B": {
        "oui_hex": "00-20-1B",
        "organization": "NORTHERN TELECOM/NETWORK",
        "address_1": "SYSTEMS CORPORATION",
        "address_2": "CANADA    K8N 5B7",
        "country": "CA"
    },
    "0020F3": {
        "oui_hex": "00-20-F3",
        "organization": "RAYNET CORPORATION",
        "address_1": "155 CONSTITUTION DRIVE",
        "address_2": "MENLO PARK  CA  94025",
        "country": "US"
    },
    "002090": {
        "oui_hex": "00-20-90",
        "organization": "ADVANCED COMPRESSION TECHNOLOGY, INC.",
        "address_1": "820 FLYNN ROAD",
        "address_2": "CAMARILLO  CA  93012",
        "country": "US"
    },
    "0020C0": {
        "oui_hex": "00-20-C0",
        "organization": "PULSE ELECTRONICS, INC.",
        "address_1": "5706 FREDERICK AVENUE",
        "address_2": "ROCKVILLE  MD  20852",
        "country": "US"
    },
    "00207E": {
        "oui_hex": "00-20-7E",
        "organization": "FINECOM CO., LTD.",
        "address_1": "1108 HWAKOK-DONG, KANGSEO-KU",
        "address_2": "SEOUL",
        "country": "KR"
    },
    "00204E": {
        "oui_hex": "00-20-4E",
        "organization": "NETWORK SECURITY SYSTEMS, INC.",
        "address_1": "9401 WAPLES STREET,STE. #100",
        "address_2": "SAN DIEGO  CA  92121",
        "country": "US"
    },
    "0020CA": {
        "oui_hex": "00-20-CA",
        "organization": "DIGITAL OCEAN",
        "address_1": "11206 THOMPSON AVENUE",
        "address_2": "LENEXA  KS  66219-2303",
        "country": "US"
    },
    "002095": {
        "oui_hex": "00-20-95",
        "organization": "RIVA ELECTRONICS",
        "address_1": "UNIT 17, BARRSFOLD RD.",
        "address_2": "LANCASHIRE  ENGLAND  BL5 3XW",
        "country": "GB"
    },
    "0020FB": {
        "oui_hex": "00-20-FB",
        "organization": "OCTEL COMMUNICATIONS CORP.",
        "address_1": "1001 MURPHY RANCH RD",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "002070": {
        "oui_hex": "00-20-70",
        "organization": "HYNET, LTD.",
        "address_1": "102 JABOTINSKY ST.",
        "address_2": "PETACH TIKVA 49130",
        "country": "IL"
    },
    "0020BE": {
        "oui_hex": "00-20-BE",
        "organization": "LAN ACCESS CORP.",
        "address_1": "2730 MONTEREY STREET, STE.#102",
        "address_2": "TORRANCE  CA  90503",
        "country": "US"
    },
    "00203F": {
        "oui_hex": "00-20-3F",
        "organization": "JUKI CORPORATION",
        "address_1": "8-2-1 KOKURYO-CHO",
        "address_2": "",
        "country": "JP"
    },
    "0020A9": {
        "oui_hex": "00-20-A9",
        "organization": "WHITE HORSE INDUSTRIAL",
        "address_1": "4F. NO.16, ALLEY 56, LANE 181",
        "address_2": "",
        "country": "TW"
    },
    "002096": {
        "oui_hex": "00-20-96",
        "organization": "Invensys",
        "address_1": "Robershaw Industrial Products",
        "address_2": "Marysville  TN  37801",
        "country": "US"
    },
    "00204A": {
        "oui_hex": "00-20-4A",
        "organization": "PRONET GMBH",
        "address_1": "KARLSTRASSE 49",
        "address_2": "",
        "country": "DE"
    },
    "0020FF": {
        "oui_hex": "00-20-FF",
        "organization": "SYMMETRICAL TECHNOLOGIES",
        "address_1": "500 HUNTMAR PARK DRIVE",
        "address_2": "HERNDON  VA  22070",
        "country": "US"
    },
    "002044": {
        "oui_hex": "00-20-44",
        "organization": "GENITECH PTY LTD",
        "address_1": "P.O. BOX 196",
        "address_2": "",
        "country": "AU"
    },
    "0020EF": {
        "oui_hex": "00-20-EF",
        "organization": "USC CORPORATION",
        "address_1": "6-4, OSAKI 1-CHOME",
        "address_2": "  141",
        "country": "JP"
    },
    "002030": {
        "oui_hex": "00-20-30",
        "organization": "ANALOG & DIGITAL SYSTEMS",
        "address_1": "1/2 LAVELLE ROAD",
        "address_2": "",
        "country": "IN"
    },
    "0020AC": {
        "oui_hex": "00-20-AC",
        "organization": "INTERFLEX DATENSYSTEME GMBH",
        "address_1": "GROBWIESENSTRASE 24",
        "address_2": "    WESTGERMANY",
        "country": "DE"
    },
    "0020D8": {
        "oui_hex": "00-20-D8",
        "organization": "Nortel Networks",
        "address_1": "4401 Great America Pkwy.",
        "address_2": "Santa Clara  CA  94588",
        "country": "US"
    },
    "002066": {
        "oui_hex": "00-20-66",
        "organization": "GENERAL MAGIC, INC.",
        "address_1": "2465 LATHAM STREET",
        "address_2": "MOUNTAIN VIEW  CA  94040",
        "country": "US"
    },
    "002001": {
        "oui_hex": "00-20-01",
        "organization": "DSP SOLUTIONS, INC.",
        "address_1": "2464 EMBARCADERO WAY",
        "address_2": "PALO ALTO  CA  94303",
        "country": "US"
    },
    "0020BF": {
        "oui_hex": "00-20-BF",
        "organization": "AEHR TEST SYSTEMS",
        "address_1": "1667 PLYMOUTH STREET",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "002053": {
        "oui_hex": "00-20-53",
        "organization": "HUNTSVILLE MICROSYSTEMS, INC.",
        "address_1": "P.O. BOX 12415",
        "address_2": "HUNTSVILLE  AL  35815",
        "country": "US"
    },
    "0020A1": {
        "oui_hex": "00-20-A1",
        "organization": "DOVATRON",
        "address_1": "PRODUCTS DIVISION",
        "address_2": "LONGMONT  CO  80501",
        "country": "US"
    },
    "00C02F": {
        "oui_hex": "00-C0-2F",
        "organization": "OKUMA CORPORATION",
        "address_1": "OGUCHI-CHO, NIWA-GUN",
        "address_2": "",
        "country": "JP"
    },
    "00C01E": {
        "oui_hex": "00-C0-1E",
        "organization": "LA FRANCAISE DES JEUX",
        "address_1": "CENTRE DE ROUSSY/DTI",
        "address_2": "",
        "country": "FR"
    },
    "00C0E1": {
        "oui_hex": "00-C0-E1",
        "organization": "SONIC SOLUTIONS",
        "address_1": "1891 E. FRANCISCO BLVD.",
        "address_2": "SAN RAFAEL  CA  94901",
        "country": "US"
    },
    "002036": {
        "oui_hex": "00-20-36",
        "organization": "BMC SOFTWARE",
        "address_1": "1600 CITY WEST BLVD., #1600",
        "address_2": "HOUSTON  TX  77042",
        "country": "US"
    },
    "0020F8": {
        "oui_hex": "00-20-F8",
        "organization": "CARRERA COMPUTERS, INC.",
        "address_1": "23181 VERDUGO DRIVE-STE.#105A",
        "address_2": "LAGUNA HILLS  CA  92653",
        "country": "US"
    },
    "00C065": {
        "oui_hex": "00-C0-65",
        "organization": "SCOPE COMMUNICATIONS, INC.",
        "address_1": "100 OTIS STREET",
        "address_2": "NORTHBORO  MA  01532",
        "country": "US"
    },
    "00C079": {
        "oui_hex": "00-C0-79",
        "organization": "FONSYS CO.,LTD.",
        "address_1": "209-5, YANGJAE, SEOCHO",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "00C00F": {
        "oui_hex": "00-C0-0F",
        "organization": "QUANTUM SOFTWARE SYSTEMS LTD.",
        "address_1": "175 TERRENCE MATTHEWS CRESCENT",
        "address_2": "  K2L  3T5",
        "country": "CA"
    },
    "00C087": {
        "oui_hex": "00-C0-87",
        "organization": "UUNET TECHNOLOGIES, INC.",
        "address_1": "3110 FAIRVIEW PARK DR. #570",
        "address_2": "FALLS CHURCH  VA  22042",
        "country": "US"
    },
    "00C006": {
        "oui_hex": "00-C0-06",
        "organization": "NIPPON AVIONICS CO., LTD.",
        "address_1": "INDUSTRIAL SYSTEM DIVISION",
        "address_2": "",
        "country": "JP"
    },
    "00C0A4": {
        "oui_hex": "00-C0-A4",
        "organization": "UNIGRAF OY",
        "address_1": "RUUKINTIE 18",
        "address_2": "",
        "country": "FI"
    },
    "00C029": {
        "oui_hex": "00-C0-29",
        "organization": "Nexans Deutschland GmbH - ANS",
        "address_1": "Bonnenbroicher Str. 100",
        "address_2": "",
        "country": "DE"
    },
    "00C0FA": {
        "oui_hex": "00-C0-FA",
        "organization": "CANARY COMMUNICATIONS, INC.",
        "address_1": "1851 ZANKER ROAD",
        "address_2": "SAN JOSE  CA  95112-4213",
        "country": "US"
    },
    "00C03A": {
        "oui_hex": "00-C0-3A",
        "organization": "MEN-MIKRO ELEKTRONIK GMBH",
        "address_1": "WIESENTALSTRASSE 40",
        "address_2": "",
        "country": "DE"
    },
    "00C040": {
        "oui_hex": "00-C0-40",
        "organization": "ECCI",
        "address_1": "15070-B AVENUE OF SCIENCE",
        "address_2": "SAN DIEGO  CA  92128",
        "country": "US"
    },
    "00C01C": {
        "oui_hex": "00-C0-1C",
        "organization": "INTERLINK COMMUNICATIONS LTD.",
        "address_1": "BRUNEL ROAD,",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00C042": {
        "oui_hex": "00-C0-42",
        "organization": "DATALUX CORP.",
        "address_1": "2836 CESSNA DRIVE",
        "address_2": "WINCHESTER  VA  22601",
        "country": "US"
    },
    "00C071": {
        "oui_hex": "00-C0-71",
        "organization": "AREANEX COMMUNICATIONS, INC.",
        "address_1": "3333 OCTAVIUS DRIVE UNIT C",
        "address_2": "SANTA CLARA  CA  95051",
        "country": "US"
    },
    "00C044": {
        "oui_hex": "00-C0-44",
        "organization": "EMCOM CORPORATION",
        "address_1": "840 AVENUE",
        "address_2": "PLANO  TX  75074",
        "country": "US"
    },
    "00C0E6": {
        "oui_hex": "00-C0-E6",
        "organization": "Verilink Corporation",
        "address_1": "127 Jetplex Circle",
        "address_2": "Madison  AL  35758",
        "country": "US"
    },
    "00C096": {
        "oui_hex": "00-C0-96",
        "organization": "TAMURA CORPORATION",
        "address_1": "COMMUNICATION SYSTEMS DIV.",
        "address_2": "",
        "country": "JP"
    },
    "00C04E": {
        "oui_hex": "00-C0-4E",
        "organization": "COMTROL CORPORATION",
        "address_1": "2675 PATTON ROAD",
        "address_2": "ST. PAUL  MN  55113",
        "country": "US"
    },
    "00C03F": {
        "oui_hex": "00-C0-3F",
        "organization": "STORES AUTOMATED SYSTEMS, INC.",
        "address_1": "1360 ADAMS ROAD",
        "address_2": "BENSALEM  PA  19020",
        "country": "US"
    },
    "00C036": {
        "oui_hex": "00-C0-36",
        "organization": "RAYTECH ELECTRONIC CORP.",
        "address_1": "2F, NO.6, LANE 497",
        "address_2": "  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00C0A2": {
        "oui_hex": "00-C0-A2",
        "organization": "INTERMEDIUM A/S",
        "address_1": "ODINSVEJ 19",
        "address_2": "",
        "country": "DK"
    },
    "00C053": {
        "oui_hex": "00-C0-53",
        "organization": "Aspect Software Inc.",
        "address_1": "6 Technology Park Drive",
        "address_2": "Westford  MA  01886",
        "country": "US"
    },
    "00C0CC": {
        "oui_hex": "00-C0-CC",
        "organization": "TELESCIENCES CO SYSTEMS, INC.",
        "address_1": "351 NEW ALBANY RD.",
        "address_2": "MOORESTOWN  NJ  08057-1177",
        "country": "US"
    },
    "00C0CE": {
        "oui_hex": "00-C0-CE",
        "organization": "CEI SYSTEMS & ENGINEERING PTE",
        "address_1": "BLK 73 #02-18 AYER RAJAH CRESC",
        "address_2": "  SINGAPORE  0513",
        "country": "SG"
    },
    "00404F": {
        "oui_hex": "00-40-4F",
        "organization": "SPACE & NAVAL WARFARE SYSTEMS",
        "address_1": "NUWC",
        "address_2": "NEWPORT  RI  02841-5047",
        "country": "US"
    },
    "00408F": {
        "oui_hex": "00-40-8F",
        "organization": "WM-DATA MINFO AB",
        "address_1": "OLOF ASKLUNDS GATA 14",
        "address_2": "",
        "country": "SE"
    },
    "0040D7": {
        "oui_hex": "00-40-D7",
        "organization": "STUDIO GEN INC.",
        "address_1": "3-12-8 TAKANAWA #202",
        "address_2": "",
        "country": "JP"
    },
    "004057": {
        "oui_hex": "00-40-57",
        "organization": "LOCKHEED - SANDERS",
        "address_1": "DANIEL WEBSTER HIGHWAY SOUTH",
        "address_2": "NASHUA  NH  03061-0868",
        "country": "US"
    },
    "004017": {
        "oui_hex": "00-40-17",
        "organization": "Silex Technology America",
        "address_1": "157 West 7065 South",
        "address_2": "Salt Lake City  UT  84047",
        "country": "US"
    },
    "00C0D9": {
        "oui_hex": "00-C0-D9",
        "organization": "QUINTE NETWORK CONFIDENTIALITY",
        "address_1": "EQUIPMENT INC.",
        "address_2": "CANADA  K8N  1C3",
        "country": "CA"
    },
    "00C0B1": {
        "oui_hex": "00-C0-B1",
        "organization": "GENIUS NET CO.",
        "address_1": "4F, HANSOO B/D 210-5",
        "address_2": "  SOUTH  KOREA",
        "country": "KR"
    },
    "00C0D2": {
        "oui_hex": "00-C0-D2",
        "organization": "SYNTELLECT, INC.",
        "address_1": "15810 N. 28TH AVENUE",
        "address_2": "PHOENIX  AZ  85023",
        "country": "US"
    },
    "00C07E": {
        "oui_hex": "00-C0-7E",
        "organization": "KUBOTA CORPORATION ELECTRONIC",
        "address_1": "DEVICE DEPT.",
        "address_2": "  JAPAN  #581",
        "country": "JP"
    },
    "00C0DD": {
        "oui_hex": "00-C0-DD",
        "organization": "QLogic Corporation",
        "address_1": "6321 Bury Dr.",
        "address_2": "Eden Prarie  MN  55346",
        "country": "US"
    },
    "00C01B": {
        "oui_hex": "00-C0-1B",
        "organization": "SOCKET COMMUNICATIONS, INC.",
        "address_1": "2823 WHIPPLE RD.",
        "address_2": "UNION CITY  CA  94587",
        "country": "US"
    },
    "00406F": {
        "oui_hex": "00-40-6F",
        "organization": "SYNC RESEARCH INC.",
        "address_1": "7 STUDEBAKER",
        "address_2": "IRVINE  CA  92718",
        "country": "US"
    },
    "0040F3": {
        "oui_hex": "00-40-F3",
        "organization": "NETCOR",
        "address_1": "850 AUBURN COURT",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00404B": {
        "oui_hex": "00-40-4B",
        "organization": "MAPLE COMPUTER SYSTEMS",
        "address_1": "P.O. BOX 10050",
        "address_2": "CANADA  ALA  4L5",
        "country": "CA"
    },
    "004033": {
        "oui_hex": "00-40-33",
        "organization": "ADDTRON TECHNOLOGY CO., LTD.",
        "address_1": "46560 FREMONT BLVD. #303",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00C08E": {
        "oui_hex": "00-C0-8E",
        "organization": "NETWORK INFORMATION TECHNOLOGY",
        "address_1": "10430 S. DE ANZA BLVD.",
        "address_2": "CUPERTINO  CA  95014",
        "country": "US"
    },
    "00C0C7": {
        "oui_hex": "00-C0-C7",
        "organization": "SPARKTRUM MICROSYSTEMS, INC.",
        "address_1": "2860 ZANKER ROAD,  STE.#210",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "00C0C4": {
        "oui_hex": "00-C0-C4",
        "organization": "COMPUTER OPERATIONAL",
        "address_1": "REQUIREMENT ANALYSTS LTD",
        "address_2": "GU12 4LZ  GU12 4LZ  ENGLAND",
        "country": "GB"
    },
    "00C012": {
        "oui_hex": "00-C0-12",
        "organization": "NETSPAN CORPORATION",
        "address_1": "1411 E. CAMPBELL RD",
        "address_2": "RICHARDSON  TX  75081",
        "country": "US"
    },
    "0040AD": {
        "oui_hex": "00-40-AD",
        "organization": "SMA REGELSYSTEME GMBH",
        "address_1": "HANNOVERSCHE STR. 1-5",
        "address_2": "",
        "country": "DE"
    },
    "00406D": {
        "oui_hex": "00-40-6D",
        "organization": "LANCO, INC.",
        "address_1": "800 WEST AIRPORT FREEWAY",
        "address_2": "IRVING  TX  75062",
        "country": "US"
    },
    "0040CD": {
        "oui_hex": "00-40-CD",
        "organization": "TERA MICROSYSTEMS, INC.",
        "address_1": "2500 GREAT AMERICA PARKWAY",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "0040F5": {
        "oui_hex": "00-40-F5",
        "organization": "OEM ENGINES",
        "address_1": "1190 DELL AVENUE, STE.",
        "address_2": "CAMPBELL  CA  95008",
        "country": "US"
    },
    "004039": {
        "oui_hex": "00-40-39",
        "organization": "OPTEC DAIICHI DENKO CO., LTD.",
        "address_1": "FIBER OPTICS & TELECOM. DIV.",
        "address_2": "    JAPAN",
        "country": ""
    },
    "004079": {
        "oui_hex": "00-40-79",
        "organization": "JUKO MANUFACTURE COMPANY, LTD.",
        "address_1": "FLAT C, 3RD FLOOR, CDW BLDG.",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "00C020": {
        "oui_hex": "00-C0-20",
        "organization": "ARCO ELECTRONIC, CONTROL LTD.",
        "address_1": "2750 NORTH 29TH AVE.-STE.#316",
        "address_2": "HOLLYWOOD  FL  33020",
        "country": "US"
    },
    "00C0E7": {
        "oui_hex": "00-C0-E7",
        "organization": "FIBERDATA AB",
        "address_1": "P.O. BOX 20095",
        "address_2": "",
        "country": "SE"
    },
    "00C05F": {
        "oui_hex": "00-C0-5F",
        "organization": "FINE-PAL COMPANY LIMITED",
        "address_1": "RM. 9, 11F, KINGSFORD IND. CTR",
        "address_2": "  HONG  KONG",
        "country": "HK"
    },
    "0040AE": {
        "oui_hex": "00-40-AE",
        "organization": "DELTA CONTROLS, INC.",
        "address_1": "13520 78TH AVENUE",
        "address_2": "CANADA  V3W  8J6",
        "country": "CA"
    },
    "0040F6": {
        "oui_hex": "00-40-F6",
        "organization": "KATRON COMPUTERS INC.",
        "address_1": "4 FL. NO. 2, ALLEY 23",
        "address_2": "TAIPEI  TAIPEI  TAIWAN",
        "country": "TW"
    },
    "004086": {
        "oui_hex": "00-40-86",
        "organization": "MICHELS & KLEBERHOFF COMPUTER",
        "address_1": "GATHE 117",
        "address_2": "",
        "country": "DE"
    },
    "004092": {
        "oui_hex": "00-40-92",
        "organization": "ASP COMPUTER PRODUCTS, INC.",
        "address_1": "160 SAN GABRIEL DRIVE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "004068": {
        "oui_hex": "00-40-68",
        "organization": "EXTENDED SYSTEMS",
        "address_1": "6123 NORTH MEEKER AVENUE",
        "address_2": "BOISE  ID  83704",
        "country": "US"
    },
    "004078": {
        "oui_hex": "00-40-78",
        "organization": "WEARNES AUTOMATION PTE LTD",
        "address_1": "801 LORONG 7, TOA PAYOH",
        "address_2": "  SINGAPORE  1231",
        "country": "SG"
    },
    "0040F4": {
        "oui_hex": "00-40-F4",
        "organization": "CAMEO COMMUNICATIONS, INC.",
        "address_1": "71 SPITBROOK ROAD, STE #410",
        "address_2": "NASHUA  NH  030603",
        "country": "US"
    },
    "0040B4": {
        "oui_hex": "00-40-B4",
        "organization": "NEXTCOM K.K.",
        "address_1": "1-12-1 SHIBUYA",
        "address_2": "",
        "country": "JP"
    },
    "0040B0": {
        "oui_hex": "00-40-B0",
        "organization": "BYTEX CORPORATION, ENGINEERING",
        "address_1": "13873 PARK CENTER ROAD",
        "address_2": "HERNDON  VA  22071",
        "country": "US"
    },
    "0080D9": {
        "oui_hex": "00-80-D9",
        "organization": "EMK Elektronik GmbH & Co. KG",
        "address_1": "Obere Bergstrasse 28",
        "address_2": "75335  Dobel",
        "country": "DE"
    },
    "004059": {
        "oui_hex": "00-40-59",
        "organization": "YOSHIDA KOGYO K. K.",
        "address_1": "TECHNICAL RESEARCH DEPT.",
        "address_2": "  939",
        "country": "JP"
    },
    "004095": {
        "oui_hex": "00-40-95",
        "organization": "R.P.T. INTERGROUPS INT'L LTD.",
        "address_1": "9F, 50 MIN CHUAN RD",
        "address_2": "TAIWAN  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "004035": {
        "oui_hex": "00-40-35",
        "organization": "OPCOM",
        "address_1": "1215 W. CROSBY RD.",
        "address_2": "CARROLLTON  TX  75006",
        "country": "US"
    },
    "00405C": {
        "oui_hex": "00-40-5C",
        "organization": "FUTURE SYSTEMS, INC.",
        "address_1": "ROOM 102 DONG BANG B/D,",
        "address_2": "SEOUL 130-080  SEOUL 130-080  KOREA",
        "country": "KR"
    },
    "004061": {
        "oui_hex": "00-40-61",
        "organization": "DATATECH ENTERPRISES CO., LTD.",
        "address_1": "(LIN KOU INDUSTRIAL ZONE SEC,4",
        "address_2": "TAOYUAN COUNTY  TAIWAN  R.O.C.",
        "country": "TW"
    },
    "00008C": {
        "oui_hex": "00-00-8C",
        "organization": "Alloy Computer Products (Australia) Pty Ltd",
        "address_1": "Unit 4/585 Blackburn Road",
        "address_2": "Notting Hill  Victoria  3168",
        "country": "AU"
    },
    "0040B9": {
        "oui_hex": "00-40-B9",
        "organization": "MACQ ELECTRONIQUE SA",
        "address_1": "RUE DE L'AERONEF 2",
        "address_2": "",
        "country": "BE"
    },
    "0040BB": {
        "oui_hex": "00-40-BB",
        "organization": "GOLDSTAR CABLE CO., LTD.",
        "address_1": "555, HOGYE-DONG, ANYANG-SHI",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0040B1": {
        "oui_hex": "00-40-B1",
        "organization": "CODONICS INC.",
        "address_1": "17991 ENGLEWOOD DRIVE",
        "address_2": "MIDDLEBURG HTS  OH  44130",
        "country": "US"
    },
    "0040F8": {
        "oui_hex": "00-40-F8",
        "organization": "SYSTEMHAUS DISCOM",
        "address_1": "DISTRIBUTED COMPUTING GMBH",
        "address_2": "",
        "country": "DE"
    },
    "0040D2": {
        "oui_hex": "00-40-D2",
        "organization": "PAGINE CORPORATION",
        "address_1": "1961-A CONCOURSE DRIVE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "004024": {
        "oui_hex": "00-40-24",
        "organization": "COMPAC INC.",
        "address_1": "16-7 NIHONBASI HAMACHO 3-CHO",
        "address_2": "",
        "country": "JP"
    },
    "0040E9": {
        "oui_hex": "00-40-E9",
        "organization": "ACCORD SYSTEMS, INC.",
        "address_1": "572 VALLEY WAY",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "004003": {
        "oui_hex": "00-40-03",
        "organization": "Emerson Process Management Power & Water Solutions, Inc.",
        "address_1": "200 Beta Drive",
        "address_2": "PITTSBURGH  PA  15238",
        "country": "US"
    },
    "004090": {
        "oui_hex": "00-40-90",
        "organization": "ANSEL COMMUNICATIONS",
        "address_1": "1701 JUNCTION COURT",
        "address_2": "SAN JOSE  CA  95112",
        "country": "US"
    },
    "0040C5": {
        "oui_hex": "00-40-C5",
        "organization": "MICOM COMMUNICATIONS INC.",
        "address_1": "4100 LOS ANGELES AVENUE",
        "address_2": "SIMI VALLEY  CA  93063",
        "country": "US"
    },
    "004020": {
        "oui_hex": "00-40-20",
        "organization": "CommScope Inc",
        "address_1": "Unit 1, Kinmel Park",
        "address_2": "Bodelwyddan  RHYL  LL18 5TZ",
        "country": "GB"
    },
    "004048": {
        "oui_hex": "00-40-48",
        "organization": "SMD INFORMATICA S.A.",
        "address_1": "LARGO MOVIMENTO DAS FORCAS",
        "address_2": "",
        "country": "PT"
    },
    "00407C": {
        "oui_hex": "00-40-7C",
        "organization": "QUME CORPORATION",
        "address_1": "500 YOSEMITE DRIVE, M/S-29",
        "address_2": "MILPITAS  CA  95035-5426",
        "country": "US"
    },
    "00407F": {
        "oui_hex": "00-40-7F",
        "organization": "FLIR Systems",
        "address_1": "BOX 3",
        "address_2": "",
        "country": "SE"
    },
    "00402D": {
        "oui_hex": "00-40-2D",
        "organization": "HARRIS ADACOM CORPORATION",
        "address_1": "1100 VENTURE COURT",
        "address_2": "CARROLLTON  TX  75006-5412",
        "country": "US"
    },
    "0080A6": {
        "oui_hex": "00-80-A6",
        "organization": "REPUBLIC TECHNOLOGY, INC.",
        "address_1": "P.O. BOX 141006",
        "address_2": "AUSTIN  TX  78714",
        "country": "US"
    },
    "0040DE": {
        "oui_hex": "00-40-DE",
        "organization": "Elsag Datamat spa",
        "address_1": "ELSAG S.P.A.",
        "address_2": "GENOVA    16154",
        "country": "IT"
    },
    "0040C9": {
        "oui_hex": "00-40-C9",
        "organization": "NCUBE",
        "address_1": "919 EAST HILLSDALE BLVD.",
        "address_2": "FOSTER CITY  CA  94404",
        "country": "US"
    },
    "008032": {
        "oui_hex": "00-80-32",
        "organization": "ACCESS CO., LTD.",
        "address_1": "HIEI-KUDAN BLDG. B1",
        "address_2": "",
        "country": "JP"
    },
    "0080CF": {
        "oui_hex": "00-80-CF",
        "organization": "EMBEDDED PERFORMANCE INC.",
        "address_1": "3385 SCOTT BLVD.",
        "address_2": "SANTA CLARA  CA  95054-3115",
        "country": "US"
    },
    "008090": {
        "oui_hex": "00-80-90",
        "organization": "MICROTEK INTERNATIONAL, INC.",
        "address_1": "3300 NW 211TH TERRACE",
        "address_2": "HILLSBOR  OR  97124-7136",
        "country": "US"
    },
    "004044": {
        "oui_hex": "00-40-44",
        "organization": "QNIX COMPUTER CO., LTD.",
        "address_1": "8,9F KOREAN TEACHER'S MUT.BLDG",
        "address_2": "SEOUL  KOREA  150-010",
        "country": "KR"
    },
    "0080C4": {
        "oui_hex": "00-80-C4",
        "organization": "DOCUMENT TECHNOLOGIES, INC.",
        "address_1": "1300 CHARLESTON ROAD",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "00805B": {
        "oui_hex": "00-80-5B",
        "organization": "CONDOR SYSTEMS, INC.",
        "address_1": "2133 SAMARILTAN DRIVE",
        "address_2": "SAN JOSE  CA  95124",
        "country": "US"
    },
    "008043": {
        "oui_hex": "00-80-43",
        "organization": "NETWORLD, INC.",
        "address_1": "KANDA 3 AMEREX BLDG.",
        "address_2": "",
        "country": "JP"
    },
    "0040DF": {
        "oui_hex": "00-40-DF",
        "organization": "DIGALOG SYSTEMS, INC.",
        "address_1": "3180 SOUTH 166TH STREET",
        "address_2": "NEW BERLIN  WI  53151",
        "country": "US"
    },
    "004009": {
        "oui_hex": "00-40-09",
        "organization": "TACHIBANA TECTRON CO., LTD.",
        "address_1": "SYSTEMATIC EQUIPMENT DIVISION",
        "address_2": "",
        "country": "JP"
    },
    "0040A0": {
        "oui_hex": "00-40-A0",
        "organization": "GOLDSTAR CO., LTD.",
        "address_1": "6 GA 3B MUNLAE YEONGDEUNGPO",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0040FC": {
        "oui_hex": "00-40-FC",
        "organization": "IBR COMPUTER TECHNIK GMBH",
        "address_1": "FRANKFURTER STR. 114",
        "address_2": "  WEST",
        "country": "DE"
    },
    "0080AF": {
        "oui_hex": "00-80-AF",
        "organization": "ALLUMER CO., LTD.",
        "address_1": "2-8-8 CHUO-CHO, MEGURO-KU",
        "address_2": "",
        "country": "JP"
    },
    "008084": {
        "oui_hex": "00-80-84",
        "organization": "THE CLOUD INC.",
        "address_1": "CLOUD BLDG.",
        "address_2": "    KOREA",
        "country": "KR"
    },
    "0080F3": {
        "oui_hex": "00-80-F3",
        "organization": "SUN ELECTRONICS CORP.",
        "address_1": "250 ASAHI KOCHINO-CHO",
        "address_2": "  483",
        "country": "JP"
    },
    "008099": {
        "oui_hex": "00-80-99",
        "organization": "Eaton Industries GmbH",
        "address_1": "Hein-Moeller - Straße 7-11",
        "address_2": "",
        "country": "DE"
    },
    "00808D": {
        "oui_hex": "00-80-8D",
        "organization": "WESTCOAST TECHNOLOGY B.V.",
        "address_1": "P.O. BOX 3317",
        "address_2": "",
        "country": "NL"
    },
    "0080BE": {
        "oui_hex": "00-80-BE",
        "organization": "ARIES RESEARCH",
        "address_1": "46791 FREMOND BLVD.",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "008015": {
        "oui_hex": "00-80-15",
        "organization": "SEIKO SYSTEMS, INC.",
        "address_1": "8,Nakase 1-chome,Mihama-ku",
        "address_2": "",
        "country": "JP"
    },
    "0080D2": {
        "oui_hex": "00-80-D2",
        "organization": "SHINNIHONDENKO CO., LTD.",
        "address_1": "6-8 NISHITENMA 2 CHOME",
        "address_2": "",
        "country": "JP"
    },
    "008089": {
        "oui_hex": "00-80-89",
        "organization": "TECNETICS (PTY) LTD.",
        "address_1": "P.O. BOX/POSBUS 56412",
        "address_2": "  SOUTH  AFRICA",
        "country": "ZA"
    },
    "00806F": {
        "oui_hex": "00-80-6F",
        "organization": "ONELAN LTD.",
        "address_1": "P.O. BOX 107",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "008081": {
        "oui_hex": "00-80-81",
        "organization": "KENDALL SQUARE RESEARCH CORP.",
        "address_1": "170 TRACER LANE",
        "address_2": "WALTHAM  MA  02154-1379",
        "country": "US"
    },
    "00809C": {
        "oui_hex": "00-80-9C",
        "organization": "LUXCOM, INC.",
        "address_1": "3249 LAURELVIEW COURT",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "008065": {
        "oui_hex": "00-80-65",
        "organization": "CYBERGRAPHIC SYSTEMS PTY LTD.",
        "address_1": "290 BURWOOD ROAD",
        "address_2": "",
        "country": "AU"
    },
    "008019": {
        "oui_hex": "00-80-19",
        "organization": "DAYNA COMMUNICATIONS, INC.",
        "address_1": "50 SOUTH MAIN STREET-#530",
        "address_2": "SALT LAKE CITY  UTAH  84144",
        "country": "US"
    },
    "008050": {
        "oui_hex": "00-80-50",
        "organization": "ZIATECH CORPORATION",
        "address_1": "3433 ROBERTO COURT",
        "address_2": "SAN LUIS OBISPO  CA  93401",
        "country": "US"
    },
    "0080A4": {
        "oui_hex": "00-80-A4",
        "organization": "LIBERTY ELECTRONICS",
        "address_1": "332 HARBOR WAY",
        "address_2": "SOUTH SAN FRANCISCO  CA  94080",
        "country": "US"
    },
    "0080CD": {
        "oui_hex": "00-80-CD",
        "organization": "MICRONICS COMPUTER, INC.",
        "address_1": "45365 NORTHPORT LOOP WEST",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "008003": {
        "oui_hex": "00-80-03",
        "organization": "HYTEC ELECTRONICS LTD.",
        "address_1": "5 CRADOCK ROAD",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "008052": {
        "oui_hex": "00-80-52",
        "organization": "TECHNICALLY ELITE CONCEPTS",
        "address_1": "2615 PACIFIC COAST HIGHWAY",
        "address_2": "HERMOSA BEACH  CA  90250",
        "country": "US"
    },
    "00805D": {
        "oui_hex": "00-80-5D",
        "organization": "CANSTAR",
        "address_1": "3900 VICTORIA PARK AVENUE",
        "address_2": "  M2H  3H7",
        "country": "CA"
    },
    "00804F": {
        "oui_hex": "00-80-4F",
        "organization": "DAIKIN INDUSTRIES, LTD.",
        "address_1": "ELECTRONICS DIVISION",
        "address_2": "  JAPAN  525",
        "country": "JP"
    },
    "008005": {
        "oui_hex": "00-80-05",
        "organization": "CACTUS COMPUTER INC.",
        "address_1": "1120 METROCREST DRIVE",
        "address_2": "CARROLLTON  TX  75006",
        "country": "US"
    },
    "00806D": {
        "oui_hex": "00-80-6D",
        "organization": "CENTURY SYSTEMS CORP.",
        "address_1": "2-8-12 MINAMI-CHO",
        "address_2": "  185",
        "country": "JP"
    },
    "008094": {
        "oui_hex": "00-80-94",
        "organization": "ALFA LAVAL AUTOMATION AB",
        "address_1": "ADN",
        "address_2": "",
        "country": "SE"
    },
    "000041": {
        "oui_hex": "00-00-41",
        "organization": "ICE CORPORATION",
        "address_1": "17945 SKYPARK CIRCLE",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "000086": {
        "oui_hex": "00-00-86",
        "organization": "MEGAHERTZ CORPORATION",
        "address_1": "605 NORTH--5600 WEST",
        "address_2": "SALT LAKE CITY  UT  84116-3738",
        "country": "US"
    },
    "000092": {
        "oui_hex": "00-00-92",
        "organization": "COGENT DATA TECHNOLOGIES",
        "address_1": "640 MULLIS STREET",
        "address_2": "FRIDAY HARBOR  WA  98250",
        "country": "US"
    },
    "000058": {
        "oui_hex": "00-00-58",
        "organization": "RACORE COMPUTER PRODUCTS INC.",
        "address_1": "2355 SOUTH 1070 WEST",
        "address_2": "SALT LAKE CITY  UT  84119",
        "country": "US"
    },
    "008074": {
        "oui_hex": "00-80-74",
        "organization": "FISHER CONTROLS",
        "address_1": "1712 CENTRE CREEK DRIVE",
        "address_2": "AUSTIN  TX  78754",
        "country": "US"
    },
    "008030": {
        "oui_hex": "00-80-30",
        "organization": "NEXUS ELECTRONICS",
        "address_1": "39 SPRINGFIELD ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "000055": {
        "oui_hex": "00-00-55",
        "organization": "COMMISSARIAT A L`ENERGIE ATOM.",
        "address_1": "31, RUE DE LA FEDERATION",
        "address_2": "",
        "country": "FR"
    },
    "0080C9": {
        "oui_hex": "00-80-C9",
        "organization": "ALBERTA MICROELECTRONIC CENTRE",
        "address_1": "318, 11315 - 87 AVENUE",
        "address_2": "",
        "country": "CA"
    },
    "00800C": {
        "oui_hex": "00-80-0C",
        "organization": "VIDECOM LIMITED",
        "address_1": "NEWTOWN ESTATE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "00807D": {
        "oui_hex": "00-80-7D",
        "organization": "EQUINOX SYSTEMS INC.",
        "address_1": "14260 SW 119TH AVENUE",
        "address_2": "MIAMI  FL  33186",
        "country": "US"
    },
    "008063": {
        "oui_hex": "00-80-63",
        "organization": "Hirschmann Automation and Control GmbH",
        "address_1": "Stuttgarter Straße 45-51",
        "address_2": "Neckartenzlingen    D-72654",
        "country": "DE"
    },
    "0080EE": {
        "oui_hex": "00-80-EE",
        "organization": "THOMSON CSF",
        "address_1": "51 ESPLANADE DU GENERAL",
        "address_2": "",
        "country": "FR"
    },
    "00808E": {
        "oui_hex": "00-80-8E",
        "organization": "RADSTONE TECHNOLOGY",
        "address_1": "WATER LANE, TOWCESTER",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "008096": {
        "oui_hex": "00-80-96",
        "organization": "HUMAN DESIGNED SYSTEMS, INC.",
        "address_1": "421 FEHELEY DRIVE",
        "address_2": "KING OF PRUSSIA  PA  19406",
        "country": "US"
    },
    "0080DA": {
        "oui_hex": "00-80-DA",
        "organization": "Bruel & Kjaer Sound & Vibration Measurement A/S",
        "address_1": "Skodsborgvej 307",
        "address_2": "",
        "country": "DK"
    },
    "00803E": {
        "oui_hex": "00-80-3E",
        "organization": "SYNERNETICS",
        "address_1": "85 RANGEWAY ROAD",
        "address_2": "NORTH BILLERICA  MA  01862",
        "country": "US"
    },
    "0080CE": {
        "oui_hex": "00-80-CE",
        "organization": "BROADCAST TELEVISION SYSTEMS",
        "address_1": "P.O. BOX 30816",
        "address_2": "  Utah  84130-0816",
        "country": "US"
    },
    "00801A": {
        "oui_hex": "00-80-1A",
        "organization": "BELL ATLANTIC",
        "address_1": "N92 W14612  ANTHONY AVENUE",
        "address_2": "MENOMONEE FALLS  WI  53051",
        "country": "US"
    },
    "0080DE": {
        "oui_hex": "00-80-DE",
        "organization": "GIPSI S.A.",
        "address_1": "2,BD VAUBAN - B.P. 268",
        "address_2": "",
        "country": "FR"
    },
    "008002": {
        "oui_hex": "00-80-02",
        "organization": "SATELCOM (UK) LTD",
        "address_1": "TECHNOLOGY TRANSFER CENTRE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "008064": {
        "oui_hex": "00-80-64",
        "organization": "WYSE TECHNOLOGY LLC",
        "address_1": "3471 NORTH FIRST STREET M/S",
        "address_2": "SAN JOSE  CA  95134",
        "country": "US"
    },
    "008048": {
        "oui_hex": "00-80-48",
        "organization": "COMPEX INCORPORATED",
        "address_1": "4055 EAST LA PALMA",
        "address_2": "ANAHEIM  CA  92807",
        "country": "US"
    },
    "008085": {
        "oui_hex": "00-80-85",
        "organization": "H-THREE SYSTEMS CORPORATION",
        "address_1": "100 PARK DRIVE, SUITE 204",
        "address_2": "  NC  27709",
        "country": "US"
    },
    "00804C": {
        "oui_hex": "00-80-4C",
        "organization": "CONTEC CO., LTD.",
        "address_1": "3-9-31, HIMESATO",
        "address_2": "",
        "country": "JP"
    },
    "00808F": {
        "oui_hex": "00-80-8F",
        "organization": "C. ITOH ELECTRONICS, INC.",
        "address_1": "2505 MCCABE WAY",
        "address_2": "IRVINE  CA  92714",
        "country": "US"
    },
    "000052": {
        "oui_hex": "00-00-52",
        "organization": "Intrusion.com, Inc.",
        "address_1": "1101 E. ARAPAHO ROAD",
        "address_2": "RICHARDSON  TX  75081",
        "country": ""
    },
    "0080FF": {
        "oui_hex": "00-80-FF",
        "organization": "SOC. DE TELEINFORMATIQUE RTC",
        "address_1": "P.O. BOX 955 PLACE DU PARC",
        "address_2": "CANADA  H2W  2N1",
        "country": ""
    },
    "0000F7": {
        "oui_hex": "00-00-F7",
        "organization": "YOUTH KEEP ENTERPRISE CO LTD",
        "address_1": "3/F NO. 712 MINTSU E. ROAD",
        "address_2": "    ROC",
        "country": "TW"
    },
    "0000C7": {
        "oui_hex": "00-00-C7",
        "organization": "ARIX CORPORATION",
        "address_1": "ENGINEERING MAIL STOP",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "0000D1": {
        "oui_hex": "00-00-D1",
        "organization": "ADAPTEC INCORPORATED",
        "address_1": "M/S 180",
        "address_2": "MILPITAS  CA  95035",
        "country": "US"
    },
    "000016": {
        "oui_hex": "00-00-16",
        "organization": "DU PONT PIXEL SYSTEMS     .",
        "address_1": "MEADLAKE PLACE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000E1": {
        "oui_hex": "00-00-E1",
        "organization": "GRID SYSTEMS",
        "address_1": "47211 LAKEVIEW BOULEVARD",
        "address_2": "FREMONT  CA  94537-5003",
        "country": "US"
    },
    "000081": {
        "oui_hex": "00-00-81",
        "organization": "Bay Networks",
        "address_1": "PO Box 58185",
        "address_2": "Santa Clara  CA  95052-8185",
        "country": "US"
    },
    "000029": {
        "oui_hex": "00-00-29",
        "organization": "IMC NETWORKS CORP.",
        "address_1": "16931 MILLIKEN AVE.",
        "address_2": "IRVINE  CA  92714-5013",
        "country": "US"
    },
    "00000A": {
        "oui_hex": "00-00-0A",
        "organization": "OMRON TATEISI ELECTRONICS CO.",
        "address_1": "SECTION NFF, SYSTEM R&D LABS.",
        "address_2": "KYOTO  617",
        "country": "JP"
    },
    "00000D": {
        "oui_hex": "00-00-0D",
        "organization": "FIBRONICS LTD.",
        "address_1": "MATAM TECHNOLOGY CENTER",
        "address_2": "",
        "country": "IL"
    },
    "000024": {
        "oui_hex": "00-00-24",
        "organization": "CONNECT AS",
        "address_1": "HOERKAER 7-9",
        "address_2": "",
        "country": "DK"
    },
    "000067": {
        "oui_hex": "00-00-67",
        "organization": "SOFT * RITE, INC.",
        "address_1": "15392 ASSEMBLY LANE, UNIT A",
        "address_2": "HUNTINGTON BEACH  CA  92649",
        "country": "US"
    },
    "0000D2": {
        "oui_hex": "00-00-D2",
        "organization": "SBE, INC.",
        "address_1": "4550 NORTH CANYON ROAD",
        "address_2": "SAN RAMON  CA  94583",
        "country": "US"
    },
    "000037": {
        "oui_hex": "00-00-37",
        "organization": "OXFORD METRICS LIMITED",
        "address_1": "UNIT 8, 7 WEST WAY,",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "0000FB": {
        "oui_hex": "00-00-FB",
        "organization": "RECHNER ZUR KOMMUNIKATION",
        "address_1": "BITZENSTR. 11",
        "address_2": "",
        "country": "DE"
    },
    "0000E2": {
        "oui_hex": "00-00-E2",
        "organization": "ACER TECHNOLOGIES CORP.",
        "address_1": "401 CHARCOT AVE.",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "0000BA": {
        "oui_hex": "00-00-BA",
        "organization": "SIIG, INC.",
        "address_1": "6078 STEWART AVENUE",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "00002A": {
        "oui_hex": "00-00-2A",
        "organization": "TRW - SEDD/INP",
        "address_1": "1800 GLENN CURTISS STREET",
        "address_2": "CARSON  CA  90746",
        "country": "US"
    },
    "00002C": {
        "oui_hex": "00-00-2C",
        "organization": "AUTOTOTE LIMITED",
        "address_1": "100 BELLEVUE ROAD",
        "address_2": "NEWARK  DELAWARE  19714",
        "country": "US"
    },
    "000083": {
        "oui_hex": "00-00-83",
        "organization": "TADPOLE TECHNOLOGY PLC",
        "address_1": "137 DITTON WALK",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "0000F3": {
        "oui_hex": "00-00-F3",
        "organization": "GANDALF DATA LIMITED",
        "address_1": "130 COLONNADE ROAD SOUTH",
        "address_2": "",
        "country": "CA"
    },
    "0000B0": {
        "oui_hex": "00-00-B0",
        "organization": "RND-RAD NETWORK DEVICES",
        "address_1": "ATIDIM TECHNOL'CL BLDG. 1",
        "address_2": "",
        "country": "IL"
    },
    "0000CF": {
        "oui_hex": "00-00-CF",
        "organization": "HAYES MICROCOMPUTER PRODUCTS",
        "address_1": "(CANADA) LTD.",
        "address_2": "",
        "country": "CA"
    },
    "000056": {
        "oui_hex": "00-00-56",
        "organization": "DR. B. STRUCK",
        "address_1": "POB 1147 BAECKERBARG 6",
        "address_2": "    W-GERMANY",
        "country": "DE"
    },
    "00006C": {
        "oui_hex": "00-00-6C",
        "organization": "Private",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "0000A9": {
        "oui_hex": "00-00-A9",
        "organization": "NETWORK SYSTEMS CORP.",
        "address_1": "7600 BOONE AVENUE NORTH",
        "address_2": "MINNEAPOLIS  MN  55428-1099",
        "country": "US"
    },
    "0000EF": {
        "oui_hex": "00-00-EF",
        "organization": "KTI",
        "address_1": "2157 O'TOOLE AVENUE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "000025": {
        "oui_hex": "00-00-25",
        "organization": "RAMTEK CORP.",
        "address_1": "810 W. MAUDE AVENUE",
        "address_2": "SUNNYVALE  CA  94086",
        "country": "US"
    },
    "0000AF": {
        "oui_hex": "00-00-AF",
        "organization": "Canberra Industries, Inc.",
        "address_1": "800 Research Parkway",
        "address_2": "Meriden  CT  06450",
        "country": "US"
    },
    "000076": {
        "oui_hex": "00-00-76",
        "organization": "ABEKAS VIDEO SYSTEM",
        "address_1": "101 GALVESTON DRIVE",
        "address_2": "REDWOOD CITY  CA  94063",
        "country": "US"
    },
    "080055": {
        "oui_hex": "08-00-55",
        "organization": "STANFORD TELECOMM. INC.",
        "address_1": "1221 CROSSMAN",
        "address_2": "SUNNYVALE  CA  94089",
        "country": "US"
    },
    "080053": {
        "oui_hex": "08-00-53",
        "organization": "MIDDLE EAST TECH. UNIVERSITY",
        "address_1": "DEPARTMENT OF",
        "address_2": "  ANKARA",
        "country": "TR"
    },
    "08008E": {
        "oui_hex": "08-00-8E",
        "organization": "Tandem Computers",
        "address_1": "14231 Tendem Blvd.",
        "address_2": "Austin  TX  78728 - 6610",
        "country": "US"
    },
    "080084": {
        "oui_hex": "08-00-84",
        "organization": "TOMEN ELECTRONICS CORP.",
        "address_1": "1-1 UCHISAIWAI-CHO 2CHOME",
        "address_2": "",
        "country": "JP"
    },
    "080085": {
        "oui_hex": "08-00-85",
        "organization": "ELXSI",
        "address_1": "2334 LUNDY PLACE",
        "address_2": "SAN JOSE  CA  95131",
        "country": "US"
    },
    "080082": {
        "oui_hex": "08-00-82",
        "organization": "VERITAS SOFTWARE",
        "address_1": "4800 GREAT AMERICA PARKWAY",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "080080": {
        "oui_hex": "08-00-80",
        "organization": "AES DATA INC.",
        "address_1": "1900 MINNESOTA COURT",
        "address_2": "CANADA  L5N  L5N 3C9",
        "country": "CA"
    },
    "080077": {
        "oui_hex": "08-00-77",
        "organization": "TSL COMMUNICATIONS LTD.",
        "address_1": "THE LANDSBURY ESTATE",
        "address_2": "    ENGLAND",
        "country": "GB"
    },
    "080074": {
        "oui_hex": "08-00-74",
        "organization": "CASIO COMPUTER CO. LTD.",
        "address_1": "3-2-1 SAKAE-CHO",
        "address_2": "  190-11",
        "country": "JP"
    },
    "08006E": {
        "oui_hex": "08-00-6E",
        "organization": "MASSCOMP",
        "address_1": "ONE TECHNOLOGY PARK",
        "address_2": "WESTFORD  MA  01886",
        "country": "US"
    },
    "080068": {
        "oui_hex": "08-00-68",
        "organization": "RIDGE COMPUTERS",
        "address_1": "2451 MISSION COLLEGE BLVD.",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "080063": {
        "oui_hex": "08-00-63",
        "organization": "PLESSEY",
        "address_1": "PLESSEY - UK LIMITED",
        "address_2": "JAMAICA  NY  11434",
        "country": "US"
    },
    "08007B": {
        "oui_hex": "08-00-7B",
        "organization": "SANYO ELECTRIC CO. LTD.",
        "address_1": "1-18-13 HASHIRIDANI",
        "address_2": "OSAKA  573",
        "country": "JP"
    },
    "08007C": {
        "oui_hex": "08-00-7C",
        "organization": "VITALINK COMMUNICATIONS CORP.",
        "address_1": "48761 KATO ROAD",
        "address_2": "FREMONT  CA  94538",
        "country": "US"
    },
    "0000DF": {
        "oui_hex": "00-00-DF",
        "organization": "BELL & HOWELL PUB SYS DIV",
        "address_1": "OLD MANSFIELD ROAD",
        "address_2": "WOOSTER  OH  44691-9050",
        "country": "US"
    },
    "0000F9": {
        "oui_hex": "00-00-F9",
        "organization": "QUOTRON SYSTEMS INC.",
        "address_1": "5454 BEETHOVEN ST.",
        "address_2": "LOS ANGELES  CA  90066",
        "country": "US"
    },
    "080060": {
        "oui_hex": "08-00-60",
        "organization": "INDUSTRIAL NETWORKING INC.",
        "address_1": "3990 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95050",
        "country": "US"
    },
    "08004C": {
        "oui_hex": "08-00-4C",
        "organization": "HYDRA COMPUTER SYSTEMS INC.",
        "address_1": "12 MERCER ROAD",
        "address_2": "NATICK  MA  01760",
        "country": "US"
    },
    "080047": {
        "oui_hex": "08-00-47",
        "organization": "SEQUENT COMPUTER SYSTEMS INC.",
        "address_1": "15450 S.W. KOLL PARKWAY   .",
        "address_2": "BEAVERTON  OR  97006",
        "country": "US"
    },
    "08004A": {
        "oui_hex": "08-00-4A",
        "organization": "BANYAN SYSTEMS INC.",
        "address_1": "135 FLANDERS ROAD",
        "address_2": "WESTBORO  MA  01581",
        "country": "US"
    },
    "080044": {
        "oui_hex": "08-00-44",
        "organization": "DAVID SYSTEMS INC.",
        "address_1": "615 TASMAN DRIVE",
        "address_2": "SUNNYVALE  CA  94088",
        "country": "US"
    },
    "080041": {
        "oui_hex": "08-00-41",
        "organization": "RACAL-MILGO INFORMATION SYS..",
        "address_1": "400 EMBASSY ROW",
        "address_2": "ATLANTA  GA  30328",
        "country": "US"
    },
    "080037": {
        "oui_hex": "08-00-37",
        "organization": "FUJI-XEROX CO. LTD.",
        "address_1": "ADVANCED TECH & ENG'G CENTER",
        "address_2": "",
        "country": "JP"
    },
    "080035": {
        "oui_hex": "08-00-35",
        "organization": "MICROFIVE CORPORATION",
        "address_1": "3560 HYLAND AVENUE",
        "address_2": "COSTA MESA  CA  92626",
        "country": "US"
    },
    "080032": {
        "oui_hex": "08-00-32",
        "organization": "TIGAN INCORPORATED",
        "address_1": "4020 FABIAN WAY",
        "address_2": "PALO ALTO  CA  94303",
        "country": "US"
    },
    "08008D": {
        "oui_hex": "08-00-8D",
        "organization": "XYVISION INC.",
        "address_1": "101 EDGEWATER DRIVE",
        "address_2": "WAKEFIELD  MA  01880",
        "country": "US"
    },
    "080015": {
        "oui_hex": "08-00-15",
        "organization": "STC BUSINESS SYSTEMS",
        "address_1": "HOLBROOK HOUSE",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "080042": {
        "oui_hex": "08-00-42",
        "organization": "JAPAN MACNICS CORP.",
        "address_1": "",
        "address_2": "",
        "country": "JP"
    },
    "080066": {
        "oui_hex": "08-00-66",
        "organization": "AGFA CORPORATION",
        "address_1": "200 BALLARDVALE STREET",
        "address_2": "WILMINGTON  MA  01887",
        "country": "US"
    },
    "080004": {
        "oui_hex": "08-00-04",
        "organization": "CROMEMCO INCORPORATED",
        "address_1": "280 BERNARDO AVENUE",
        "address_2": "MOUNTAIN VIEW  CA  94043",
        "country": "US"
    },
    "08003F": {
        "oui_hex": "08-00-3F",
        "organization": "FRED KOSCHARA ENTERPRISES",
        "address_1": "",
        "address_2": "",
        "country": ""
    },
    "08000B": {
        "oui_hex": "08-00-0B",
        "organization": "UNISYS CORPORATION",
        "address_1": "TOWNSHIP LINE ROAD",
        "address_2": "BLUE BELL  PA  19424",
        "country": "US"
    },
    "00DD01": {
        "oui_hex": "00-DD-01",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00DD06": {
        "oui_hex": "00-DD-06",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "AA0003": {
        "oui_hex": "AA-00-03",
        "organization": "DIGITAL EQUIPMENT CORPORATION",
        "address_1": "LKG 1-2/A19",
        "address_2": "LITTLETON  MA  01460-1289",
        "country": "US"
    },
    "000000": {
        "oui_hex": "00-00-00",
        "organization": "XEROX CORPORATION",
        "address_1": "M/S 105-50C",
        "address_2": "WEBSTER  NY  14580",
        "country": "US"
    },
    "080021": {
        "oui_hex": "08-00-21",
        "organization": "3M COMPANY",
        "address_1": "Telecom Division",
        "address_2": "Austin  TX  78726-9000",
        "country": "US"
    },
    "02BB01": {
        "oui_hex": "02-BB-01",
        "organization": "OCTOTHORPE CORP.",
        "address_1": "285 WEST GREEN STREET",
        "address_2": "PASADENA  CA  91105",
        "country": "US"
    },
    "08008A": {
        "oui_hex": "08-00-8A",
        "organization": "PerfTech, Inc.",
        "address_1": "613 NW Loop 410",
        "address_2": "SAN ANTONIO  TX  78216",
        "country": "US"
    },
    "00003E": {
        "oui_hex": "00-00-3E",
        "organization": "SIMPACT",
        "address_1": "9210 SKY PARK COURT",
        "address_2": "SAN DIEGO  CA  92123",
        "country": "US"
    },
    "00DD02": {
        "oui_hex": "00-DD-02",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "00DD04": {
        "oui_hex": "00-DD-04",
        "organization": "UNGERMANN-BASS INC.",
        "address_1": "3900 FREEDOM CIRCLE",
        "address_2": "SANTA CLARA  CA  95054",
        "country": "US"
    },
    "026086": {
        "oui_hex": "02-60-86",
        "organization": "LOGIC REPLACEMENT TECH. LTD.",
        "address_1": "14 ARKWRIGHT ROAD",
        "address_2": "  UNITED  KINGDOM",
        "country": "GB"
    },
    "74DA88": {
        "oui_hex": "74-DA-88",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "CC32E5": {
        "oui_hex": "CC-32-E5",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "1C3BF3": {
        "oui_hex": "1C-3B-F3",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "3C86D1": {
        "oui_hex": "3C-86-D1",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "301B97": {
        "oui_hex": "30-1B-97",
        "organization": "Lierda Science & Technology Group Co.,Ltd",
        "address_1": "Lierda Science Park?No.1326 WenyiWestRoad",
        "address_2": "Hangzhou  ZheJiang  311121",
        "country": "CN"
    },
    "2CD2E3": {
        "oui_hex": "2C-D2-E3",
        "organization": "Guangzhou Aoshi Electronic Co.,Ltd",
        "address_1": "B1,Huachuang industrial park,Jinshan Avenue,Panyu District",
        "address_2": "Guangzhou  Guangdong  511450",
        "country": "CN"
    },
    "1459C3": {
        "oui_hex": "14-59-C3",
        "organization": "Creative Chips GmbH",
        "address_1": "Im Bubenstück 1",
        "address_2": "Bingen  Rheinland-Pfalz  55411",
        "country": "DE"
    },
    "A0D86F": {
        "oui_hex": "A0-D8-6F",
        "organization": "ARGO AI, LLC",
        "address_1": "40, 24th Street, Second Floor",
        "address_2": "Pittsburgh  PA  15222",
        "country": "US"
    },
    "E4671E": {
        "oui_hex": "E4-67-1E",
        "organization": "SHEN ZHEN NUO XIN CHENG TECHNOLOGY co., Ltd.",
        "address_1": "Building A2 and 1 F/L, Building A1, 9 Wugang Rd, Xikeng Village, Xikeng Community, Henggang Sub-district, Longgang District",
        "address_2": "Shenzhen    518100",
        "country": "CN"
    },
    "682719": {
        "oui_hex": "68-27-19",
        "organization": "Microchip Technology Inc.",
        "address_1": "2355 W. Chandler Blvd.",
        "address_2": "Chandler  AZ  85224",
        "country": "US"
    },
    "24C17A": {
        "oui_hex": "24-C1-7A",
        "organization": "BEIJING IACTIVE NETWORK CO.,LTD",
        "address_1": "Room 525, Yiquanhui Building, No. 35 Shangdi East Road, Haidian District",
        "address_2": "BEIJING    100085",
        "country": "CN"
    },
    "1C9C8C": {
        "oui_hex": "1C-9C-8C",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "A4C939": {
        "oui_hex": "A4-C9-39",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "34D772": {
        "oui_hex": "34-D7-72",
        "organization": "Xiamen Yudian Automation Technology Co., Ltd",
        "address_1": "No. 17 North Huoju Rd., Huoju Park, Huoju Hi-Tech District",
        "address_2": "XIAMEN  FUJIAN   361000",
        "country": "CN"
    },
    "C0DCDA": {
        "oui_hex": "C0-DC-DA",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "04B429": {
        "oui_hex": "04-B4-29",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "48794D": {
        "oui_hex": "48-79-4D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "44F971": {
        "oui_hex": "44-F9-71",
        "organization": "SHENZHEN MERCURY COMMUNICATION TECHNOLOGIES CO.,LTD.",
        "address_1": "3/F, Building R1-B, High-Tech Industrial Park, Nanshan District",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "18F9C4": {
        "oui_hex": "18-F9-C4",
        "organization": "BAE Systems",
        "address_1": "21 continental boulevard",
        "address_2": "Merrimack  NH  03054",
        "country": "US"
    },
    "60ABD2": {
        "oui_hex": "60-AB-D2",
        "organization": "Bose Corporation",
        "address_1": "The Mountain",
        "address_2": "Framingham  MA  01701-9168",
        "country": "US"
    },
    "F0EF86": {
        "oui_hex": "F0-EF-86",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "E4C0CC": {
        "oui_hex": "E4-C0-CC",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "5CB13E": {
        "oui_hex": "5C-B1-3E",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "F4E5F2": {
        "oui_hex": "F4-E5-F2",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "541310": {
        "oui_hex": "54-13-10",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8CE5EF": {
        "oui_hex": "8C-E5-EF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A4CD23": {
        "oui_hex": "A4-CD-23",
        "organization": "Shenzhenshi Xinzhongxin  Co., Ltd",
        "address_1": "Building A3, Donghuan Industrial Zone, Nanpu Road, Shajing Town, Baoan District",
        "address_2": "Shenzhen  Guangdong  518125",
        "country": "CN"
    },
    "B83A5A": {
        "oui_hex": "B8-3A-5A",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "E4AAEA": {
        "oui_hex": "E4-AA-EA",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "A0946A": {
        "oui_hex": "A0-94-6A",
        "organization": "Shenzhen XGTEC Technology Co,.Ltd.",
        "address_1": "Room 312, Changhong Science and Technology Building, No.18, South 12 Rd., High-tech Community, Yuehai Street, Nanshan District, Shenzhen",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "1C2AA3": {
        "oui_hex": "1C-2A-A3",
        "organization": "Shenzhen HongRui Optical Technology Co., Ltd.",
        "address_1": "B#2F Shuangjinhui Industrial Park, Yonghe Road, Heping Village, Fuyong Town, Bao'an Dis",
        "address_2": "Shenzhen  Guangdong  518000",
        "country": "CN"
    },
    "388E7A": {
        "oui_hex": "38-8E-7A",
        "organization": "AUTOIT",
        "address_1": "212, Gasan digital 1-ro",
        "address_2": "Seoul  Geumcheon-gu  08502",
        "country": "KR"
    },
    "4C710C": {
        "oui_hex": "4C-71-0C",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "4C710D": {
        "oui_hex": "4C-71-0D",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "9C31C3": {
        "oui_hex": "9C-31-C3",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "6C24A6": {
        "oui_hex": "6C-24-A6",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "9C5F5A": {
        "oui_hex": "9C-5F-5A",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "E447B3": {
        "oui_hex": "E4-47-B3",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "FCDB21": {
        "oui_hex": "FC-DB-21",
        "organization": "SAMSARA NETWORKS INC",
        "address_1": "525 York St",
        "address_2": "San Francisco  CA  94110",
        "country": "US"
    },
    "607771": {
        "oui_hex": "60-77-71",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "D8CF89": {
        "oui_hex": "D8-CF-89",
        "organization": "Beijing DoSee Science and Technology Co., Ltd.",
        "address_1": "Room 819-158,Floor 8,XinCaiLiao Chuangye Building,No.7 FengHuiZhong Road, Haidian District",
        "address_2": "Beijing    100094",
        "country": "CN"
    },
    "04AAE1": {
        "oui_hex": "04-AA-E1",
        "organization": "BEIJING MICROVISION TECHNOLOGY CO.,LTD",
        "address_1": "ROOM 207-208,2/F,TAIXIANG COMMERCIAL BUILDING,NO.1A,LONGXIANG ROAD,HAIDIAN DISTRICT,BEIJING,P.R.C",
        "address_2": "BEIJING  BEIJING  100191",
        "country": "CN"
    },
    "44DC4E": {
        "oui_hex": "44-DC-4E",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "382A19": {
        "oui_hex": "38-2A-19",
        "organization": "Technica Engineering GmbH",
        "address_1": "Leopoldstraße 236",
        "address_2": "Munich    80807",
        "country": "DE"
    },
    "74D654": {
        "oui_hex": "74-D6-54",
        "organization": "GINT",
        "address_1": "9F, 47, Daehak-ro, Youngtong-gu",
        "address_2": "Suwon-si  Gyeonggi-do  16225",
        "country": "KR"
    },
    "B4E8C9": {
        "oui_hex": "B4-E8-C9",
        "organization": "XADA Technologies",
        "address_1": "No. 2-2, Xinyi Road Section 5, Lane 150, 1st Floor",
        "address_2": "Taipei City  Taipei City  110",
        "country": "TW"
    },
    "7C210E": {
        "oui_hex": "7C-21-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "942DDC": {
        "oui_hex": "94-2D-DC",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "54F294": {
        "oui_hex": "54-F2-94",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "245AB5": {
        "oui_hex": "24-5A-B5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "C0D2DD": {
        "oui_hex": "C0-D2-DD",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "AC1E92": {
        "oui_hex": "AC-1E-92",
        "organization": "Samsung Electronics Co.,LTD",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon    16677",
        "country": "KR"
    },
    "0068EB": {
        "oui_hex": "00-68-EB",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "7CB37B": {
        "oui_hex": "7C-B3-7B",
        "organization": "Qingdao Intelligent&Precise Electronics Co.,Ltd.",
        "address_1": "No.218 Qianwangang Road",
        "address_2": "Qingdao  Shangdong  266510",
        "country": "CN"
    },
    "484C86": {
        "oui_hex": "48-4C-86",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "88123D": {
        "oui_hex": "88-12-3D",
        "organization": "Suzhou Aquila Solutions Inc.",
        "address_1": "Room 201, Building 3, 18 Dongchang Road, Suzhou Industry Park, Suzhou, PRC. Zip Code: 215000",
        "address_2": "Suzhou    215000",
        "country": "CN"
    },
    "48210B": {
        "oui_hex": "48-21-0B",
        "organization": "PEGATRON CORPORATION",
        "address_1": "5F No. 76, Ligong St., Beitou District",
        "address_2": "Taipei City  Taiwan  112",
        "country": "TW"
    },
    "A01C8D": {
        "oui_hex": "A0-1C-8D",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "7C310E": {
        "oui_hex": "7C-31-0E",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Dr.",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F4DEAF": {
        "oui_hex": "F4-DE-AF",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "60123C": {
        "oui_hex": "60-12-3C",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "48A5E7": {
        "oui_hex": "48-A5-E7",
        "organization": "Nintendo Co.,Ltd",
        "address_1": "11-1 HOKOTATE-CHO KAMITOBA,MINAMI-KU",
        "address_2": "KYOTO  KYOTO  601-8501",
        "country": "JP"
    },
    "082CB6": {
        "oui_hex": "08-2C-B6",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "F84E73": {
        "oui_hex": "F8-4E-73",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "B4265D": {
        "oui_hex": "B4-26-5D",
        "organization": "Taicang T&W Electronics",
        "address_1": "89# Jiang Nan RD",
        "address_2": "Suzhou  Jiangsu  215412",
        "country": "CN"
    },
    "F07807": {
        "oui_hex": "F0-78-07",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "3CCD36": {
        "oui_hex": "3C-CD-36",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D4B709": {
        "oui_hex": "D4-B7-09",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "38144E": {
        "oui_hex": "38-14-4E",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "ACBD0B": {
        "oui_hex": "AC-BD-0B",
        "organization": "Leimac Ltd.",
        "address_1": "1551, Sazukawa-chou",
        "address_2": "Moriyama-shi  Shiga-ken  524-0215",
        "country": "JP"
    },
    "E0CCF8": {
        "oui_hex": "E0-CC-F8",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "98524A": {
        "oui_hex": "98-52-4A",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "3868A4": {
        "oui_hex": "38-68-A4",
        "organization": "Samsung Electronics Co.,LTD",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "B4A5AC": {
        "oui_hex": "B4-A5-AC",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "1C784E": {
        "oui_hex": "1C-78-4E",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "843E79": {
        "oui_hex": "84-3E-79",
        "organization": "Shenzhen Belon Technology CO.,LTD",
        "address_1": "Tsinghua Information",
        "address_2": "Shenzhen  Guangdong  518052",
        "country": "CN"
    },
    "B81904": {
        "oui_hex": "B8-19-04",
        "organization": "Nokia Shanghai Bell Co., Ltd.",
        "address_1": "No.388 Ning Qiao Road,Jin Qiao Pudong Shanghai",
        "address_2": "Shanghai     201206",
        "country": "CN"
    },
    "F4A59D": {
        "oui_hex": "F4-A5-9D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "E0F442": {
        "oui_hex": "E0-F4-42",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "F0C42F": {
        "oui_hex": "F0-C4-2F",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C0B47D": {
        "oui_hex": "C0-B4-7D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "444687": {
        "oui_hex": "44-46-87",
        "organization": "Realme Chongqing MobileTelecommunications Corp Ltd",
        "address_1": "No.24 Nichang Boulevard, Huixing Block, Yubei District, Chongqing.",
        "address_2": "Chongqing  China  401120",
        "country": "CN"
    },
    "E82689": {
        "oui_hex": "E8-26-89",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "20F375": {
        "oui_hex": "20-F3-75",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "84BB69": {
        "oui_hex": "84-BB-69",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "105FD4": {
        "oui_hex": "10-5F-D4",
        "organization": "Tendyron Corporation",
        "address_1": "Tendyron Building,Zhongguancun NO.1 Park,Beiqing Road,Haidian District,Beijing,China",
        "address_2": "Beijing    100000",
        "country": "CN"
    },
    "8CE38E": {
        "oui_hex": "8C-E3-8E",
        "organization": "Kioxia Corporation",
        "address_1": "1-21, Shibaura 3-chome",
        "address_2": "Minato-ku  Tokyo  108-0023",
        "country": "JP"
    },
    "A0B439": {
        "oui_hex": "A0-B4-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "A4B439": {
        "oui_hex": "A4-B4-39",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "001038": {
        "oui_hex": "00-10-38",
        "organization": "Micro Research Ltd.",
        "address_1": "2F Minami-Shinagawa N Bldg., 2-2-10 Minami-Shinagawa",
        "address_2": "Tokyo  Shinagawa-Ku  140-0004",
        "country": "JP"
    },
    "E81B4B": {
        "oui_hex": "E8-1B-4B",
        "organization": "amnimo Inc.",
        "address_1": "M21-4, 2-9-32 Nakacho",
        "address_2": "Musashino-shi  Tokyo  180-8750",
        "country": "JP"
    },
    "CCF411": {
        "oui_hex": "CC-F4-11",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "9C2DCF": {
        "oui_hex": "9C-2D-CF",
        "organization": "Shishi Tongyun Technology(Chengdu)Co.,Ltd.",
        "address_1": "No. 1268 Middle Section of Tianfu Avenue, Chengdu High-tech Zone, China (Sichuan) Pilot Free Trade Zone",
        "address_2": "Chengdu  Sichuan  610017",
        "country": "CN"
    },
    "9424B8": {
        "oui_hex": "94-24-B8",
        "organization": "GREE ELECTRIC APPLIANCES, INC. OF ZHUHAI",
        "address_1": "Jinji West Road, Qianshan,",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "C803F5": {
        "oui_hex": "C8-03-F5",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "000D0A": {
        "oui_hex": "00-0D-0A",
        "organization": "Barco Projection Systems NV",
        "address_1": "Beneluxpark 21",
        "address_2": "Kortrijk  West Flanders  8500",
        "country": "BE"
    },
    "C467D1": {
        "oui_hex": "C4-67-D1",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "9C8ACB": {
        "oui_hex": "9C-8A-CB",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "C8C465": {
        "oui_hex": "C8-C4-65",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "1C4363": {
        "oui_hex": "1C-43-63",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "94292F": {
        "oui_hex": "94-29-2F",
        "organization": "New H3C Technologies Co., Ltd",
        "address_1": "466 Changhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "D49AA0": {
        "oui_hex": "D4-9A-A0",
        "organization": "VNPT TECHNOLOGY",
        "address_1": "HoaLac Hi-Tech Park",
        "address_2": "HANOI  HANOI  10000",
        "country": "VN"
    },
    "F80FF9": {
        "oui_hex": "F8-0F-F9",
        "organization": "Google, Inc.",
        "address_1": "1600 Amphitheatre Parkway",
        "address_2": "Mountain View  CA  94043",
        "country": "US"
    },
    "8C5AC1": {
        "oui_hex": "8C-5A-C1",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A85AE0": {
        "oui_hex": "A8-5A-E0",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A4B61E": {
        "oui_hex": "A4-B6-1E",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C4FE5B": {
        "oui_hex": "C4-FE-5B",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "C03937": {
        "oui_hex": "C0-39-37",
        "organization": "GREE ELECTRIC APPLIANCES, INC. OF ZHUHAI",
        "address_1": "Jinji West Road, Qianshan,",
        "address_2": "Zhuhai  Guangdong  519070",
        "country": "CN"
    },
    "B44C3B": {
        "oui_hex": "B4-4C-3B",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "40A2DB": {
        "oui_hex": "40-A2-DB",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "4C6C13": {
        "oui_hex": "4C-6C-13",
        "organization": "IoT Company Solucoes Tecnologicas Ltda",
        "address_1": "Rua Jordao Schiavetto, 436 - Sala 6",
        "address_2": "Hortolandia  Sao Paulo  13184-080",
        "country": "BR"
    },
    "A885D7": {
        "oui_hex": "A8-85-D7",
        "organization": "Sangfor Technologies Inc.",
        "address_1": "block A1 ?nanshan ipark, No 1001, xueyuan road",
        "address_2": "Shenzhen    518100",
        "country": "CN"
    },
    "444ADB": {
        "oui_hex": "44-4A-DB",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "84F883": {
        "oui_hex": "84-F8-83",
        "organization": "Luminar Technologies",
        "address_1": "12601 Research Pkwy",
        "address_2": "Orlando  FL  32828-7335",
        "country": "US"
    },
    "9CA513": {
        "oui_hex": "9C-A5-13",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "1039E9": {
        "oui_hex": "10-39-E9",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "309048": {
        "oui_hex": "30-90-48",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D41F0C": {
        "oui_hex": "D4-1F-0C",
        "organization": "JAI Manufacturing",
        "address_1": "2960-14 Uenojo Nishikata",
        "address_2": "Kushima  Miyazaki  888-0004",
        "country": "JP"
    },
    "C8FA84": {
        "oui_hex": "C8-FA-84",
        "organization": "Trusonus corp.",
        "address_1": "6F., No.42, Songjiang Rd., Zhongshan Dist",
        "address_2": "Taipei    10455",
        "country": "TW"
    },
    "C402E1": {
        "oui_hex": "C4-02-E1",
        "organization": "Khwahish Technologies Private Limited",
        "address_1": "Plot # 42, Thirugnana Sambandhar Street, Srinivasa Nagar, Madipakkam",
        "address_2": "Chennai  TamilNadu  600091",
        "country": "IN"
    },
    "F85B3B": {
        "oui_hex": "F8-5B-3B",
        "organization": "ASKEY COMPUTER CORP",
        "address_1": "10F,No.119,JIANKANG RD,ZHONGHE DIST",
        "address_2": "NEW TAIPEI  TAIWAN  23585",
        "country": "TW"
    },
    "786DEB": {
        "oui_hex": "78-6D-EB",
        "organization": "GE Lighting",
        "address_1": "1975 Noble Rd",
        "address_2": "East Cleveland  OH  44112",
        "country": "US"
    },
    "88E9A4": {
        "oui_hex": "88-E9-A4",
        "organization": "Hewlett Packard Enterprise",
        "address_1": "8000 Foothills Blvd.",
        "address_2": "Roseville  CA  95747",
        "country": "US"
    },
    "2863BD": {
        "oui_hex": "28-63-BD",
        "organization": "APTIV SERVICES US, LLC",
        "address_1": "5725 Innovation Drive",
        "address_2": "Troy  MI  48098",
        "country": "US"
    },
    "1C721D": {
        "oui_hex": "1C-72-1D",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "F41C95": {
        "oui_hex": "F4-1C-95",
        "organization": "BEIJING YUNYI TIMES TECHNOLOGY CO,.LTD",
        "address_1": "Room 2005, 2f, building B, No.1 Kaituo Road, Shangdi Information Industry base, Haidian District",
        "address_2": "BEIJING    100085",
        "country": "CN"
    },
    "A0687E": {
        "oui_hex": "A0-68-7E",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "A8705D": {
        "oui_hex": "A8-70-5D",
        "organization": "ARRIS Group, Inc.",
        "address_1": "6450 Sequence Drive",
        "address_2": "San Diego  CA  92121",
        "country": "US"
    },
    "546503": {
        "oui_hex": "54-65-03",
        "organization": "Quectel Wireless Solutions Co., Ltd.",
        "address_1": "7th Floor, Hongye Building, No.1801 Hongmei Road, Xuhui District",
        "address_2": "Shanghai    200233",
        "country": "CN"
    },
    "9C9789": {
        "oui_hex": "9C-97-89",
        "organization": "1MORE",
        "address_1": "TianliaoBuilding F14, New Materials Industrial Park, Xueyuan Blvd?Nanshan",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "F0463B": {
        "oui_hex": "F0-46-3B",
        "organization": "Comcast Cable Corporation",
        "address_1": "1800 Arch Street",
        "address_2": "Philadelphia  PA  19103",
        "country": "US"
    },
    "1C05B7": {
        "oui_hex": "1C-05-B7",
        "organization": "Chongqing Trantor Technology Co., Ltd.",
        "address_1": "No.69,Huoju Avenue,Jiulongpo District.",
        "address_2": "Chongqing  Chongqing  400050",
        "country": "CN"
    },
    "000EF3": {
        "oui_hex": "00-0E-F3",
        "organization": "Smartlabs, Inc.",
        "address_1": "1621 Alton Parkway, Suite 100",
        "address_2": "Irvine  CA  92606",
        "country": "US"
    },
    "A043B0": {
        "oui_hex": "A0-43-B0",
        "organization": "Hangzhou BroadLink Technology Co.,Ltd",
        "address_1": "Room 101,1/F,Unit C,Building 1,No.57 Jiang'er Road,Changhe Street,Binjiang District,Hangzhou,Zhejiang,P.R.China",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "74ACB9": {
        "oui_hex": "74-AC-B9",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "F492BF": {
        "oui_hex": "F4-92-BF",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "D8C561": {
        "oui_hex": "D8-C5-61",
        "organization": "CommFront Communications Pte Ltd",
        "address_1": "No. 1 Yishun Industrial ST 1, #05-31 A'Posh BizHub",
        "address_2": "SG  SG  768160",
        "country": "SG"
    },
    "0C29EF": {
        "oui_hex": "0C-29-EF",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "60D89C": {
        "oui_hex": "60-D8-9C",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "B4C9B9": {
        "oui_hex": "B4-C9-B9",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou, Industrial Park",
        "address_2": "Mianyang  Sichuan  622650",
        "country": "CN"
    },
    "F82E8E": {
        "oui_hex": "F8-2E-8E",
        "organization": "Nanjing Kechen Electric Co., Ltd.",
        "address_1": "Room 202, Building 12, No. 50 Daguang road",
        "address_2": "Nanjing    210001",
        "country": "CN"
    },
    "68D79A": {
        "oui_hex": "68-D7-9A",
        "organization": "Ubiquiti Networks Inc.",
        "address_1": "2580 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "1C63BF": {
        "oui_hex": "1C-63-BF",
        "organization": "SHENZHEN BROADTEL  TELECOM CO.,LTD",
        "address_1": "No.14-1, Tongqing Road, Baolong street, Longgang District",
        "address_2": "ShenZhen  GuangDong  518116",
        "country": "CN"
    },
    "AC3651": {
        "oui_hex": "AC-36-51",
        "organization": "Jiangsu Hengtong Terahertz Technology Co., Ltd.",
        "address_1": "Room 1312, Beiyou Technology Building, Haidian District",
        "address_2": "Beijing  Beijing  100876",
        "country": "CN"
    },
    "684A76": {
        "oui_hex": "68-4A-76",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco  CA  94107",
        "country": "US"
    },
    "688FC9": {
        "oui_hex": "68-8F-C9",
        "organization": "Zhuolian (Shenzhen) Communication Co., Ltd",
        "address_1": "Shengli electromechanical Co., Ltd. 201, No.19, Xixiang section, Guangshen Road, Jingbei community, Xixiang street, Bao'an District",
        "address_2": "Shenzhen  Shenzhen  518101",
        "country": "CN"
    },
    "F08175": {
        "oui_hex": "F0-81-75",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "D84732": {
        "oui_hex": "D8-47-32",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B46E08": {
        "oui_hex": "B4-6E-08",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8C683A": {
        "oui_hex": "8C-68-3A",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "B48107": {
        "oui_hex": "B4-81-07",
        "organization": "SHENZHEN CHUANGWEI-RGB ELECTRONICS CO.,LTD",
        "address_1": "Unit East Block22-24/F,Skyworth semiconductor design  Bldg., Gaoxin Ave.4.S.,Nanshan District,Shenzhen,China",
        "address_2": "SHENZHEN  GUANGDONG  518057",
        "country": "CN"
    },
    "706655": {
        "oui_hex": "70-66-55",
        "organization": "AzureWave Technology Inc.",
        "address_1": "8F., No. 94, Baozhong Rd.",
        "address_2": "New Taipei City  Taiwan  231",
        "country": "TW"
    },
    "2864B0": {
        "oui_hex": "28-64-B0",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "04F169": {
        "oui_hex": "04-F1-69",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "5021EC": {
        "oui_hex": "50-21-EC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0C48C6": {
        "oui_hex": "0C-48-C6",
        "organization": "CELESTICA INC.",
        "address_1": "1900-5140 Yonge Street PO Box 42",
        "address_2": "Toronto  Ontario  M2N 6L7",
        "country": "CA"
    },
    "005E0C": {
        "oui_hex": "00-5E-0C",
        "organization": "HMD Global Oy",
        "address_1": "Bertel Jungin aukio 9",
        "address_2": "Espoo    02600",
        "country": "FI"
    },
    "A42985": {
        "oui_hex": "A4-29-85",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou, Industrial Park",
        "address_2": "Mianyang  Sichuan  622650",
        "country": "CN"
    },
    "647C34": {
        "oui_hex": "64-7C-34",
        "organization": "Ubee Interactive Co., Limited",
        "address_1": "Flat/RM 1202, 12/F, AT Tower",
        "address_2": "North Point  Hong Kong  180",
        "country": "HK"
    },
    "6C38A1": {
        "oui_hex": "6C-38-A1",
        "organization": "Ubee Interactive Co., Limited",
        "address_1": "Flat/RM 1202, 12/F, AT Tower",
        "address_2": "North Point  Hong Kong  180",
        "country": "HK"
    },
    "78530D": {
        "oui_hex": "78-53-0D",
        "organization": "Shenzhen Skyworth  Digital  Technology  CO., Ltd",
        "address_1": "4F,Block A, Skyworth?Building,",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "B8D4E7": {
        "oui_hex": "B8-D4-E7",
        "organization": "Aruba, a Hewlett Packard Enterprise Company",
        "address_1": "3333 Scott Blvd",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "BC0963": {
        "oui_hex": "BC-09-63",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "D84C90": {
        "oui_hex": "D8-4C-90",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "24D0DF": {
        "oui_hex": "24-D0-DF",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "6C4A85": {
        "oui_hex": "6C-4A-85",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "28F033": {
        "oui_hex": "28-F0-33",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "185869": {
        "oui_hex": "18-58-69",
        "organization": "Sailer Electronic Co., Ltd",
        "address_1": "No. 6, Sanxi Road, Ximagou Industrial Park, Jianxi District",
        "address_2": "Luoyang  Henan  471000",
        "country": "CN"
    },
    "BC2DEF": {
        "oui_hex": "BC-2D-EF",
        "organization": "Realme Chongqing Mobile Telecommunications Corp.,Ltd.",
        "address_1": "No.178 Yulong Avenue, Yufengshan, Yubei District, Chongqing.",
        "address_2": "Chongqing   China  401120",
        "country": "CN"
    },
    "78AC44": {
        "oui_hex": "78-AC-44",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "98C8B8": {
        "oui_hex": "98-C8-B8",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "7881CE": {
        "oui_hex": "78-81-CE",
        "organization": "China Mobile Iot Limited company",
        "address_1": "No. 8 Yangliu North Road, Yubei District, Chongqing, China",
        "address_2": "Chong Qing  Chong Qing  401120",
        "country": "CN"
    },
    "445CE9": {
        "oui_hex": "44-5C-E9",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "C01692": {
        "oui_hex": "C0-16-92",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "209EF7": {
        "oui_hex": "20-9E-F7",
        "organization": "Extreme Networks, Inc.",
        "address_1": "6480 Via Del Oro",
        "address_2": "San Jose  CA  95119",
        "country": "US"
    },
    "BCFF21": {
        "oui_hex": "BC-FF-21",
        "organization": "Smart Code(shenzhen)Technology Co.,Ltd",
        "address_1": "Room 1206, Satellite Building,2002 Keyuan Road, Nanshan",
        "address_2": "Shenzhen   Guangdong (Province)   518000",
        "country": "CN"
    },
    "381730": {
        "oui_hex": "38-17-30",
        "organization": "Ulrich Lippert GmbH & Co KG",
        "address_1": "Christian-Henkel-Str. 12",
        "address_2": "Berlin    12349",
        "country": "DE"
    },
    "28E34E": {
        "oui_hex": "28-E3-4E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "402E71": {
        "oui_hex": "40-2E-71",
        "organization": "Texas Instruments",
        "address_1": "12500 TI Blvd",
        "address_2": "Dallas  TX  75243",
        "country": "US"
    },
    "7076DD": {
        "oui_hex": "70-76-DD",
        "organization": "OxyGuard Internation A/S",
        "address_1": "Farum Gydevej 64",
        "address_2": "Farum    DK-3520",
        "country": "DK"
    },
    "E023FF": {
        "oui_hex": "E0-23-FF",
        "organization": "Fortinet, Inc.",
        "address_1": "899 Kifer Road",
        "address_2": "Sunnyvale    94086",
        "country": "US"
    },
    "8C59DC": {
        "oui_hex": "8C-59-DC",
        "organization": "ASR Microelectronics (Shanghai) Co., Ltd.",
        "address_1": "Building 2, NO.399 Keyuan Road,Pudong District",
        "address_2": "Shanghai  Shanghai  201210",
        "country": "CN"
    },
    "18828C": {
        "oui_hex": "18-82-8C",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "94E9EE": {
        "oui_hex": "94-E9-EE",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "78B8D6": {
        "oui_hex": "78-B8-D6",
        "organization": "Zebra Technologies Inc.",
        "address_1": "ONE ZEBRA PLAZA",
        "address_2": "HOLTSVILLE  NY  11742",
        "country": "US"
    },
    "D452EE": {
        "oui_hex": "D4-52-EE",
        "organization": "BSkyB Ltd",
        "address_1": "130 Kings Road",
        "address_2": "Brentwood  Essex  08854",
        "country": "GB"
    },
    "F490CB": {
        "oui_hex": "F4-90-CB",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "9CF029": {
        "oui_hex": "9C-F0-29",
        "organization": "Integrated Device Technology (Malaysia) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "2856C1": {
        "oui_hex": "28-56-C1",
        "organization": "Harman/Becker Automotive Systems GmbH",
        "address_1": "15th Fl, 400 Atlantic Street",
        "address_2": "Stamford  CT  06901",
        "country": "US"
    },
    "4CFCAA": {
        "oui_hex": "4C-FC-AA",
        "organization": "Tesla,Inc.",
        "address_1": "3500 Deer Creek Rd.",
        "address_2": "PALO ALTO  CA  94304",
        "country": "US"
    },
    "10CE45": {
        "oui_hex": "10-CE-45",
        "organization": "Miromico AG",
        "address_1": "Gallusstrasse 4",
        "address_2": "Zurich  Zurich  CH-8006",
        "country": "CH"
    },
    "BC4A56": {
        "oui_hex": "BC-4A-56",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "F8AF05": {
        "oui_hex": "F8-AF-05",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "B82FCB": {
        "oui_hex": "B8-2F-CB",
        "organization": "CMS Electracom",
        "address_1": "24 Binney Road",
        "address_2": "Kings Park  NSW  2148",
        "country": "AU"
    },
    "6C61F4": {
        "oui_hex": "6C-61-F4",
        "organization": "SFR",
        "address_1": "12 rue jean-philippe Rameau CS 80001",
        "address_2": "La plaine saint denis   FRANCE  93634",
        "country": "FR"
    },
    "00107F": {
        "oui_hex": "00-10-7F",
        "organization": "CRESTRON ELECTRONICS, INC.",
        "address_1": "15 Volvo Drive",
        "address_2": "Rockleigh  NJ  07647",
        "country": "US"
    },
    "001B85": {
        "oui_hex": "00-1B-85",
        "organization": "MAN Energy Solutions",
        "address_1": "Teglholmsgade 41",
        "address_2": "Copenhagen    2450",
        "country": "DK"
    },
    "CCAB2C": {
        "oui_hex": "CC-AB-2C",
        "organization": "HUMAX Co., Ltd.",
        "address_1": "HUMAX Village, 216, Hwangsaeul-ro, Bu",
        "address_2": "Seongnam-si  Gyeonggi-do  463-875",
        "country": "KR"
    },
    "5859C2": {
        "oui_hex": "58-59-C2",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "787D53": {
        "oui_hex": "78-7D-53",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "7C95B1": {
        "oui_hex": "7C-95-B1",
        "organization": "Extreme Networks, Inc.",
        "address_1": "1011 McCarthy Blvd",
        "address_2": "Milpitas  CA  95035",
        "country": "US"
    },
    "786D94": {
        "oui_hex": "78-6D-94",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "58493B": {
        "oui_hex": "58-49-3B",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "001B17": {
        "oui_hex": "00-1B-17",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "2443E2": {
        "oui_hex": "24-43-E2",
        "organization": "DASAN Network Solutions",
        "address_1": "DASAN Tower 8F, 49 Daewangpangyo-ro644beon-gil Bundang-gu",
        "address_2": "Seongnam-si  Gyeonggi-do  13493",
        "country": "KR"
    },
    "A86ABB": {
        "oui_hex": "A8-6A-BB",
        "organization": "Sagemcom Broadband SAS",
        "address_1": "250, route de l'Empereur",
        "address_2": "Rueil Malmaison Cedex  hauts de seine  92848",
        "country": "FR"
    },
    "EC6881": {
        "oui_hex": "EC-68-81",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "540E2D": {
        "oui_hex": "54-0E-2D",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "708F47": {
        "oui_hex": "70-8F-47",
        "organization": "vivo Mobile Communication Co., Ltd.",
        "address_1": "#283,BBK Road",
        "address_2": "Wusha,Chang'An  DongGuan City,Guangdong,  523860",
        "country": "CN"
    },
    "24E124": {
        "oui_hex": "24-E1-24",
        "organization": " Xiamen Ursalink Technology Co., Ltd.",
        "address_1": "4/F, No. 63-2 Wanghai Road, 2nd Software Park",
        "address_2": "Xiamen  Fujian  361008",
        "country": "CN"
    },
    "A0FF70": {
        "oui_hex": "A0-FF-70",
        "organization": "Technicolor CH USA Inc.",
        "address_1": "5030 Sugarloaf Parkway Bldg 6",
        "address_2": "Lawrenceville  GA  30044",
        "country": "US"
    },
    "6C6D09": {
        "oui_hex": "6C-6D-09",
        "organization": "Kyowa Electronics Co.,Ltd.",
        "address_1": "4-3-31 Takatsukasa",
        "address_2": "Takarazuka  Hyogo  665-0051",
        "country": "JP"
    },
    "90173F": {
        "oui_hex": "90-17-3F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "607ECD": {
        "oui_hex": "60-7E-CD",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "8C7CFF": {
        "oui_hex": "8C-7C-FF",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "889471": {
        "oui_hex": "88-94-71",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "78A6E1": {
        "oui_hex": "78-A6-E1",
        "organization": "Brocade Communications Systems LLC",
        "address_1": "1320 Ridder Park Dr",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "80CFA2": {
        "oui_hex": "80-CF-A2",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "0094EC": {
        "oui_hex": "00-94-EC",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "548ABA": {
        "oui_hex": "54-8A-BA",
        "organization": "Cisco Systems, Inc",
        "address_1": "80 West Tasman Drive",
        "address_2": "San Jose  CA  94568",
        "country": "US"
    },
    "080342": {
        "oui_hex": "08-03-42",
        "organization": "Palo Alto Networks",
        "address_1": "3000 Tannery Way",
        "address_2": "Santa Clara  CA  95054",
        "country": "US"
    },
    "C80739": {
        "oui_hex": "C8-07-39",
        "organization": "NAKAYO Inc",
        "address_1": "1-3-2, Soja-machi",
        "address_2": "Maebashi-shi  Gunma  371-0853",
        "country": "JP"
    },
    "EC4F82": {
        "oui_hex": "EC-4F-82",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "44657F": {
        "oui_hex": "44-65-7F",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "487746": {
        "oui_hex": "48-77-46",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "EC6CB5": {
        "oui_hex": "EC-6C-B5",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "C0B101": {
        "oui_hex": "C0-B1-01",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "A45006": {
        "oui_hex": "A4-50-06",
        "organization": "SHENZHEN HUACHUANG SHIDAI TECHNOLOGYCO.,LTD",
        "address_1": "longhua dalang huaronglu lianjiangongyeyuan 4-5",
        "address_2": "shenzhen  guangdong  518000",
        "country": "CN"
    },
    "C87125": {
        "oui_hex": "C8-71-25",
        "organization": "Johnson Outdoors Marine Electronics d/b/a Minnkota",
        "address_1": "1531 E Madison Ave",
        "address_2": "Mankato  MN  56001",
        "country": "US"
    },
    "686DBC": {
        "oui_hex": "68-6D-BC",
        "organization": "Hangzhou Hikvision Digital Technology Co.,Ltd.",
        "address_1": "No.555 Qianmo Road",
        "address_2": "Hangzhou  Zhejiang  310052",
        "country": "CN"
    },
    "AC3C8E": {
        "oui_hex": "AC-3C-8E",
        "organization": "Flextronics Computing(Suzhou)Co.,Ltd.",
        "address_1": "No.1 GuanPu Road. Guoxiang street , WuZhong District,Suzhou City, Jiangsu Province.",
        "address_2": "Suzhou        215124",
        "country": "CN"
    },
    "74452D": {
        "oui_hex": "74-45-2D",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "406234": {
        "oui_hex": "40-62-34",
        "organization": "Telink Semiconductor (Shanghai) Co., Ltd.",
        "address_1": "No. 1500 Zuchongzhi Rd, Building #3",
        "address_2": "Shanghai    201203",
        "country": "CN"
    },
    "FC3DA5": {
        "oui_hex": "FC-3D-A5",
        "organization": "Arcadyan Corporation",
        "address_1": "No.8, Sec.2, Guangfu Rd.",
        "address_2": "Hsinchu City  Hsinchu  30071",
        "country": "TW"
    },
    "BC33AC": {
        "oui_hex": "BC-33-AC",
        "organization": "Silicon Laboratories",
        "address_1": "7000 W. William Cannon Dr.",
        "address_2": "Austin  TX  78735",
        "country": "US"
    },
    "F05501": {
        "oui_hex": "F0-55-01",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "140152": {
        "oui_hex": "14-01-52",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "7CF2DD": {
        "oui_hex": "7C-F2-DD",
        "organization": "Vence Corp",
        "address_1": "16885 W Bernardo Dr., STE 209",
        "address_2": "San Diego  CA  92127",
        "country": "US"
    },
    "94FBA7": {
        "oui_hex": "94-FB-A7",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "988E79": {
        "oui_hex": "98-8E-79",
        "organization": "Qudelix, Inc.",
        "address_1": "605-ho, 21, Baekbeom-ro 31-gil, Mapo-gu",
        "address_2": "Seoul    12110",
        "country": "KR"
    },
    "C03EBA": {
        "oui_hex": "C0-3E-BA",
        "organization": "Dell Inc.",
        "address_1": "One Dell Way",
        "address_2": "Round Rock  TX  78682",
        "country": "US"
    },
    "1CFF59": {
        "oui_hex": "1C-FF-59",
        "organization": "Sichuan Tianyi Comheart Telecom Co., Ltd.",
        "address_1": "No.198,First Section,Snow Mountain Avenue, Jinyuan Town, Dayi County",
        "address_2": "Chengdu  Sichuan  611330",
        "country": "CN"
    },
    "98F621": {
        "oui_hex": "98-F6-21",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "C0395A": {
        "oui_hex": "C0-39-5A",
        "organization": "Zhejiang Dahua Technology Co., Ltd.",
        "address_1": "No.1199,Waterfront Road",
        "address_2": "Hangzhou  Zhejiang  310053",
        "country": "CN"
    },
    "2064CB": {
        "oui_hex": "20-64-CB",
        "organization": "GUANGDONG OPPO MOBILE TELECOMMUNICATIONS CORP.,LTD",
        "address_1": "NO.18 HAIBIN ROAD,",
        "address_2": "DONG GUAN  GUANG DONG  523860",
        "country": "CN"
    },
    "1413FB": {
        "oui_hex": "14-13-FB",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "D0768F": {
        "oui_hex": "D0-76-8F",
        "organization": "Calix Inc.",
        "address_1": "2777 Orchard Pkwy",
        "address_2": "San Jose  CA  95131",
        "country": "US"
    },
    "A49340": {
        "oui_hex": "A4-93-40",
        "organization": "Beijing Supvan Information Technology Co.,Ltd.",
        "address_1": "206.2/F,Building No.1.No.1 Gaoxin Three Street. Huilongguan Town,Changping District",
        "address_2": "Beijing  Beijing  102206",
        "country": "CN"
    },
    "F8E877": {
        "oui_hex": "F8-E8-77",
        "organization": "Harman/Becker Automotive Systems GmbH",
        "address_1": "Becker-Göring-Straße 16",
        "address_2": "Karlsbad  Baden-Württemberg  76307",
        "country": "DE"
    },
    "A09B12": {
        "oui_hex": "A0-9B-12",
        "organization": "China Mobile IOT Company Limited",
        "address_1": "NO.8 Yu Ma Road, NanAn Area",
        "address_2": "Chongqing  Chongqing  401336",
        "country": "CN"
    },
    "940853": {
        "oui_hex": "94-08-53",
        "organization": "Liteon Technology Corporation",
        "address_1": "4F, 90, Chien 1 Road",
        "address_2": "New Taipei City  Taiwan  23585",
        "country": "TW"
    },
    "B49E80": {
        "oui_hex": "B4-9E-80",
        "organization": "Sichuan Changhong Electric Ltd.",
        "address_1": "No.35,East MianXin Road,MianYang,Sichaun,China.",
        "address_2": "MianYang  SiChuan  PRC 621000",
        "country": "CN"
    },
    "00E0B7": {
        "oui_hex": "00-E0-B7",
        "organization": "Cosworth Electronics Ltd",
        "address_1": "The Octagon, St. James Mill Road",
        "address_2": "Northampton  Northamptonshire  NN5 5RA, GB",
        "country": "GB"
    },
    "74AB93": {
        "oui_hex": "74-AB-93",
        "organization": "Blink by Amazon",
        "address_1": "100 Riverpark Drive",
        "address_2": "North Reading   MA  01864",
        "country": "US"
    },
    "E87F95": {
        "oui_hex": "E8-7F-95",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "88C08B": {
        "oui_hex": "88-C0-8B",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "00E22C": {
        "oui_hex": "00-E2-2C",
        "organization": "China Mobile Group Device Co.,Ltd.",
        "address_1": "32 Xuanwumen West Street,Xicheng District",
        "address_2": "Beijing    100053",
        "country": "CN"
    },
    "74A7EA": {
        "oui_hex": "74-A7-EA",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "781100": {
        "oui_hex": "78-11-00",
        "organization": "Quantumsolution",
        "address_1": "Rm 903, STX V-Tower, 128, Gasandigital 1-ro, Geumcheon-gu",
        "address_2": "Seoul    08507",
        "country": "KR"
    },
    "4C7CD9": {
        "oui_hex": "4C-7C-D9",
        "organization": "Apple, Inc.",
        "address_1": "1 Infinite Loop",
        "address_2": "Cupertino  CA  95014",
        "country": "US"
    },
    "7CB27D": {
        "oui_hex": "7C-B2-7D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "04ED33": {
        "oui_hex": "04-ED-33",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5C80B6": {
        "oui_hex": "5C-80-B6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "84C5A6": {
        "oui_hex": "84-C5-A6",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "AC675D": {
        "oui_hex": "AC-67-5D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F8E4E3": {
        "oui_hex": "F8-E4-E3",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "38DEAD": {
        "oui_hex": "38-DE-AD",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "D46D6D": {
        "oui_hex": "D4-6D-6D",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "B46921": {
        "oui_hex": "B4-69-21",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "98063C": {
        "oui_hex": "98-06-3C",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "129, Samsung-ro, Youngtongl-Gu",
        "address_2": "Suwon  Gyeonggi-Do  16677",
        "country": "KR"
    },
    "7CA96B": {
        "oui_hex": "7C-A9-6B",
        "organization": "Syrotech Networks. Ltd.",
        "address_1": "UNIT NO.-5 20F, KIN WING INDUSTERIAL BUILDING,33 KIN WING STREET",
        "address_2": "TUEN MUN    999077",
        "country": "HK"
    },
    "F8F21E": {
        "oui_hex": "F8-F2-1E",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "A4C3F0": {
        "oui_hex": "A4-C3-F0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5076AF": {
        "oui_hex": "50-76-AF",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "F0D7AF": {
        "oui_hex": "F0-D7-AF",
        "organization": "IEEE Registration Authority",
        "address_1": "445 Hoes Lane",
        "address_2": "Piscataway  NJ  08554",
        "country": "US"
    },
    "D84F37": {
        "oui_hex": "D8-4F-37",
        "organization": "Proxis, spol. s r.o.",
        "address_1": "Slovenska 1",
        "address_2": "Bardejov  PSK  08501",
        "country": "SK"
    },
    "AC1203": {
        "oui_hex": "AC-12-03",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "DC1BA1": {
        "oui_hex": "DC-1B-A1",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "5CA5BC": {
        "oui_hex": "5C-A5-BC",
        "organization": "eero inc.",
        "address_1": "660 3rd Street",
        "address_2": "San Francisco    94107",
        "country": "US"
    },
    "0433C2": {
        "oui_hex": "04-33-C2",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "C858C0": {
        "oui_hex": "C8-58-C0",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "64BC58": {
        "oui_hex": "64-BC-58",
        "organization": "Intel Corporate",
        "address_1": "Lot 8, Jalan Hi-Tech 2/3",
        "address_2": "Kulim  Kedah  09000",
        "country": "MY"
    },
    "6CCE44": {
        "oui_hex": "6C-CE-44",
        "organization": "1MORE",
        "address_1": "TianliaoBuilding F14?New Materials Industrial Park,Xueyuan Blvd,Nanshan",
        "address_2": "Shenzhen  Guangdong  518055",
        "country": "CN"
    },
    "B0761B": {
        "oui_hex": "B0-76-1B",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "A41162": {
        "oui_hex": "A4-11-62",
        "organization": "Arlo Technology",
        "address_1": "3030 Orchard Parkway",
        "address_2": "San Jose  CA  95134",
        "country": "US"
    },
    "84EAED": {
        "oui_hex": "84-EA-ED",
        "organization": "Roku, Inc",
        "address_1": "150 Winchester Circle",
        "address_2": "Los Gatos  CA  95032",
        "country": "US"
    },
    "08B0A7": {
        "oui_hex": "08-B0-A7",
        "organization": "Truebeyond Co., Ltd",
        "address_1": "D-906, 60, Haan-ro",
        "address_2": "Gwangmyeong  Gyeonggi  14322",
        "country": "KR"
    },
    "98C97C": {
        "oui_hex": "98-C9-7C",
        "organization": "Shenzhen iComm Semiconductor CO,LTD",
        "address_1": "Room 504A,Block B,Digital Building,Garden City,No.1079 Nanhai Road,Nanshan District,Shenzhen",
        "address_2": "shenzhen  Guangdong  518067",
        "country": "CN"
    },
    "DC91BF": {
        "oui_hex": "DC-91-BF",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "C06369": {
        "oui_hex": "C0-63-69",
        "organization": "BINXIN TECHNOLOGY(ZHEJIANG) LTD.",
        "address_1": "B4066 Haichuang Park,368 Liuhe Road, Binjiang District",
        "address_2": "Hangzhou  Zhejiang  310051",
        "country": "CN"
    },
    "1841FE": {
        "oui_hex": "18-41-FE",
        "organization": "Digital 14",
        "address_1": "Elektroniikkatie 8",
        "address_2": "Oulu    90590",
        "country": "FI"
    },
    "18AB1D": {
        "oui_hex": "18-AB-1D",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "BCE92F": {
        "oui_hex": "BC-E9-2F",
        "organization": "HP Inc.",
        "address_1": "10300 Energy Dr",
        "address_2": "Spring  TX  77389",
        "country": "US"
    },
    "8437D5": {
        "oui_hex": "84-37-D5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "3482C5": {
        "oui_hex": "34-82-C5",
        "organization": "Samsung Electronics Co.,Ltd",
        "address_1": "#94-1, Imsoo-Dong",
        "address_2": "Gumi  Gyeongbuk  730-350",
        "country": "KR"
    },
    "E092A7": {
        "oui_hex": "E0-92-A7",
        "organization": "Feitian Technologies Co., Ltd",
        "address_1": "Floor 17, Tower B, Huizhi Mansion, No.9 Xueqing Rd, Haidian District",
        "address_2": "Beijing    100085",
        "country": "CN"
    },
    "001D05": {
        "oui_hex": "00-1D-05",
        "organization": "Cooper Lighting Solutions",
        "address_1": "1121 Highway 74 S",
        "address_2": "Peachtree City  GA  30269",
        "country": "US"
    },
    "3C846A": {
        "oui_hex": "3C-84-6A",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "84D81B": {
        "oui_hex": "84-D8-1B",
        "organization": "TP-LINK TECHNOLOGIES CO.,LTD.",
        "address_1": "Building 24(floors 1,3,4,5)and 28(floors 1-4)Central Science and Technology Park,Shennan Road,Nanshan",
        "address_2": "Shenzhen  Guangdong  518057",
        "country": "CN"
    },
    "7C2ADB": {
        "oui_hex": "7C-2A-DB",
        "organization": "Xiaomi Communications Co Ltd",
        "address_1": "The Rainbow City of China Resources",
        "address_2": "NO.68, Qinghe Middle Street  Haidian District, Beijing  100085",
        "country": "CN"
    },
    "8C0E60": {
        "oui_hex": "8C-0E-60",
        "organization": "Nanjing Juplink Intelligent Technologies Co., Ltd.",
        "address_1": " No. 757 Dixiu Road, Binjiang Economic Development Zone, Jiangning District",
        "address_2": "Nanjing  Jiangsu  211100",
        "country": "CN"
    },
    "340A33": {
        "oui_hex": "34-0A-33",
        "organization": "D-Link International",
        "address_1": "1 Internal Business Park, #03-12,The Synergy, Singapore",
        "address_2": "Singapore  Singapore  609917",
        "country": "SG"
    },
    "24A160": {
        "oui_hex": "24-A1-60",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "DCAEEB": {
        "oui_hex": "DC-AE-EB",
        "organization": "Ruckus Wireless",
        "address_1": "350 West Java Drive",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "E8A245": {
        "oui_hex": "E8-A2-45",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "882949": {
        "oui_hex": "88-29-49",
        "organization": "Renesas Electronics (Penang) Sdn. Bhd.",
        "address_1": "Phase 3, Bayan Lepas FIZ",
        "address_2": "Bayan Lepas  Penang  11900",
        "country": "MY"
    },
    "F864B8": {
        "oui_hex": "F8-64-B8",
        "organization": "zte corporation",
        "address_1": "12/F.,zte R&D building ,kejinan Road,Shenzhen,P.R.China",
        "address_2": "shenzhen  guangdong  518057",
        "country": "CN"
    },
    "145120": {
        "oui_hex": "14-51-20",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "C0D193": {
        "oui_hex": "C0-D1-93",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "7804E3": {
        "oui_hex": "78-04-E3",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "A43B0E": {
        "oui_hex": "A4-3B-0E",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "1C3D2F": {
        "oui_hex": "1C-3D-2F",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "EC753E": {
        "oui_hex": "EC-75-3E",
        "organization": "HUAWEI TECHNOLOGIES CO.,LTD",
        "address_1": "No.2 Xin Cheng Road, Room R6,Songshan Lake Technology Park",
        "address_2": "Dongguan    523808",
        "country": "CN"
    },
    "909164": {
        "oui_hex": "90-91-64",
        "organization": "ChongQing Lavid Technology Co., Ltd.",
        "address_1": "Plant No. 3, Block M2, Photoelectric Park, Wuqiao Lianhe Economic Development Zone, Wanzhou District",
        "address_2": "Chongqing    404100",
        "country": "CN"
    },
    "ECDB86": {
        "oui_hex": "EC-DB-86",
        "organization": "API-K",
        "address_1": "ZA Tire Poix",
        "address_2": "Saint Vincent de Mercuze  Isère  38660",
        "country": "FR"
    },
    "2481C7": {
        "oui_hex": "24-81-C7",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "FC862A": {
        "oui_hex": "FC-86-2A",
        "organization": "Huawei Device Co., Ltd.",
        "address_1": "No.2 of Xincheng Road, Songshan Lake Zone",
        "address_2": "Dongguan  Guangdong  523808",
        "country": "CN"
    },
    "083869": {
        "oui_hex": "08-38-69",
        "organization": "Hong Kong AMobile Intelligent Corp. Limited Taiwan Branch",
        "address_1": "8F.-1, No.700, Zhongzheng Rd., Zhonghe Dist.",
        "address_2": "New Taipei City 235    23552",
        "country": "TW"
    },
    "D89ED4": {
        "oui_hex": "D8-9E-D4",
        "organization": "Fiberhome Telecommunication Technologies Co.,LTD",
        "address_1": "No.5 DongXin Road",
        "address_2": "Wuhan  Hubei  430074",
        "country": "CN"
    },
    "AC9572": {
        "oui_hex": "AC-95-72",
        "organization": "Jovision Technology Co., Ltd.",
        "address_1": "Floor 12, Building 3, Aosheng Square, No.1166 Xinluo Street",
        "address_2": "Jinan  Shandong  250101",
        "country": "CN"
    },
    "00CBBD": {
        "oui_hex": "00-CB-BD",
        "organization": "Cambridge Broadband Networks Group",
        "address_1": "1 Hammersmith Broadway",
        "address_2": "London    W6 9DL",
        "country": "GB"
    },
    "4843DD": {
        "oui_hex": "48-43-DD",
        "organization": "Amazon Technologies Inc.",
        "address_1": "P.O Box 8102",
        "address_2": "Reno  NV  89507",
        "country": "US"
    },
    "5894A2": {
        "oui_hex": "58-94-A2",
        "organization": "KETEK GmbH",
        "address_1": "Hofer Str. 3",
        "address_2": "München    81737",
        "country": "DE"
    },
    "0019F5": {
        "oui_hex": "00-19-F5",
        "organization": "Imagination Technologies Ltd",
        "address_1": "Home Park Estate",
        "address_2": "Kings Langley  Hertfordshire  WD4 8LZ",
        "country": "GB"
    },
    "40D25F": {
        "oui_hex": "40-D2-5F",
        "organization": "ITEL MOBILE LIMITED",
        "address_1": "RM B3 & B4 BLOCK B, KO FAI INDUSTRIAL BUILDING  NO.7 KO FAI ROAD, YAU TONG, KLN, H.K",
        "address_2": "Hong Kong  KOWLOON  999077",
        "country": "HK"
    },
    "840328": {
        "oui_hex": "84-03-28",
        "organization": "Juniper Networks",
        "address_1": "1133 Innovation Way",
        "address_2": "Sunnyvale  CA  94089",
        "country": "US"
    },
    "089BB9": {
        "oui_hex": "08-9B-B9",
        "organization": "Nokia",
        "address_1": "Karaportti 3",
        "address_2": "Espoo  Finland  02610",
        "country": "FI"
    },
    "001CFC": {
        "oui_hex": "00-1C-FC",
        "organization": "Sumitomo Electric Industries, Ltd",
        "address_1": "1-1-3, Shimaya, Konohana-ku",
        "address_2": "Osaka    554-0024",
        "country": "JP"
    },
    "001636": {
        "oui_hex": "00-16-36",
        "organization": "Quanta Computer Inc.",
        "address_1": "No. 211, Wen Hwa 2Rd., Kuei Shan Hsiang",
        "address_2": "Tao Yuan Shien    0000",
        "country": "TW"
    },
    "54F15F": {
        "oui_hex": "54-F1-5F",
        "organization": "Sichuan AI-Link Technology Co., Ltd.",
        "address_1": "Anzhou, Industrial Park",
        "address_2": "Mianyang  Sichuan  622650",
        "country": "CN"
    },
    "E079C4": {
        "oui_hex": "E0-79-C4",
        "organization": "iRay Technology Company Limited",
        "address_1": "Building 45, No. 1000, Jinhai RD., Pudong New Area",
        "address_2": "Shanghai    201206",
        "country": "CN"
    },
    "884067": {
        "oui_hex": "88-40-67",
        "organization": "infomark",
        "address_1": "3F. Humaxvillage, 216 Hwangsaeul-ro",
        "address_2": "Seongnam-si    13595",
        "country": "KR"
    },
    "A8032A": {
        "oui_hex": "A8-03-2A",
        "organization": "Espressif Inc.",
        "address_1": "Room 204, Building 2, 690 Bibo Rd, Pudong New Area",
        "address_2": "Shanghai  Shanghai  201203",
        "country": "CN"
    },
    "AC9A96": {
        "oui_hex": "AC-9A-96",
        "organization": "Maxlinear, Inc",
        "address_1": "Am Campeon 3",
        "address_2": "Neubiberg  Bavaria  85579",
        "country": "DE"
    }
}